#
# spec file for package kernel-rt
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needssslcertforbuild


%define srcversion 6.12
%define patchversion 6.12.0
%define git_commit 0189b95e6e4ce9f26d8952b8121f192fa0c716df
%define variant %{nil}
%define compress_modules zstd
%define compress_vmlinux xz
%define livepatch livepatch%{nil}
%define livepatch_rt 1%{nil}
%define sb_efi_only 0
%define split_base 0
%define split_optional 1
%define supported_modules_check 1
%define build_flavor rt
%define generate_compile_commands 1
%define gcc_package gcc13
%define gcc_compiler gcc-13

%include %_sourcedir/kernel-spec-macros

%(chmod +x %_sourcedir/{guards,apply-patches,check-for-config-changes,group-source-files.pl,split-modules,modversions,kabi.pl,mkspec,compute-PATCHVERSION.sh,arch-symbols,log.sh,try-disable-staging-driver,compress-vmlinux.sh,mkspec-dtb,check-module-license,splitflist,mergedep,moddep,modflist,kernel-subpackage-build})

Name:           kernel-rt
Version:        6.12.0
%if 0%{?is_kotd}
Release:        160000.34.1.g0189b95
%else
Release:        160000.34.1
%endif
Summary:        Kernel with PREEMPT_RT (realtime) support
License:        GPL-2.0-only
Group:          System/Kernel
URL:            https://www.kernel.org/
%if 0%{?suse_version} > 1500 || 0%{?sle_version} > 150300
BuildRequires:  bash-sh
%endif
BuildRequires:  bc
BuildRequires:  bison
BuildRequires:  coreutils
BuildRequires:  fdupes
BuildRequires:  flex
# Cannot test %%CONFIG_GCC_PLUGINS here because the buildservice parser
# does not expand %%(...)
%if "%build_flavor" == "syzkaller"
# Needed by scripts/gcc-plugin.sh
BuildRequires:  %gcc_package-c++
BuildRequires:  %gcc_package-devel
%endif
BuildRequires:  hmaccalc
BuildRequires:  libopenssl-devel
BuildRequires:  modutils
BuildRequires:  python3-base
# Used to sign the kernel in the buildservice
BuildRequires:  openssl
BuildRequires:  pesign-obs-integration
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
# pahole for CONFIG_DEBUG_INFO_BTF
BuildRequires:  dwarves >= 1.22
%endif
BuildRequires:  %gcc_package
# for objtool
BuildRequires:  libelf-devel
# required for 50-check-kernel-build-id rpm check
BuildRequires:  elfutils
%ifarch %arm
BuildRequires:  u-boot-tools
%endif
# Do not install p-b and dracut for the install check, the %post script is
# able to handle this
#!BuildIgnore: perl-Bootloader dracut distribution-release suse-kernel-rpm-scriptlets
# Remove some packages that are installed automatically by the build system,
# but are not needed to build the kernel
#!BuildIgnore: autoconf automake gettext-runtime libtool cvs gettext-tools udev insserv
ExclusiveArch:  aarch64 x86_64

%ifarch %ix86 x86_64
%define image vmlinuz
%endif
%ifarch ppc ppc64 ppc64le
%define image vmlinux
%endif
%ifarch s390 s390x
%define image image
%endif
%ifarch %arm
%define image zImage
%endif
%ifarch aarch64 riscv64
%define image Image
%endif

%ifarch %ix86 x86_64
%define install_vdso 1
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150500
%define separate_vdso 1
%endif
%else
%define install_vdso 0
%endif

%define build_default	("%build_flavor" == "default")
%define build_vanilla	("%build_flavor" == "vanilla")
%define vanilla_only    %{lua: if (rpm.expand("%variant") == "-vanilla") then print(1) else print(0) end}

%if ! %build_vanilla
%define src_install_dir /usr/src/linux-%kernelrelease%variant
%else
%define src_install_dir /usr/src/linux-%kernelrelease-vanilla
%endif
%define obj_install_dir /usr/src/linux-%kernelrelease%variant-obj
%define rpm_install_dir %buildroot%obj_install_dir
%define kernel_build_dir %my_builddir/linux-%srcversion/linux-obj
%define modules_dir %kernel_module_directory/%kernelrelease-%build_flavor

%global cpu_arch %(%_sourcedir/arch-symbols %_target_cpu)
%define cpu_arch_flavor %cpu_arch/%build_flavor

%if 0%{?_project:1} && ( %(echo %_project | grep -Ex -f %_sourcedir/release-projects | grep -vc ^PTF) || %(echo %_project | grep -Ec "^(Devel:)?Kernel:") )
	%define klp_ipa_clones 1
%endif

# Define some CONFIG variables as rpm macros as well. (rpm cannot handle
# defining them all at once.)
%define config_vars CONFIG_MODULES CONFIG_MODULE_SIG CONFIG_MODULE_SIG_HASH CONFIG_KMSG_IDS CONFIG_SUSE_KERNEL_SUPPORTED CONFIG_EFI_STUB CONFIG_LIVEPATCH_IPA_CLONES CONFIG_DEBUG_INFO_BTF_MODULES CONFIG_PREEMPT_DYNAMIC
%{expand:%(eval "$(test -n "%cpu_arch_flavor" && tar -xjf %_sourcedir/config.tar.bz2 --to-stdout config/%cpu_arch_flavor)"; for config in %config_vars; do echo "%%global $config ${!config:-n}"; done)}
%define split_extra ("%CONFIG_MODULES" == "y" && "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y")

%if "%CONFIG_MODULES" != "y"
	%define klp_ipa_clones 0
%endif

%global certs %( space="" ; for f in %_sourcedir/*.crt; do                                              \
    if ! test -e "$f"; then                                                                             \
        continue                                                                                        \
    fi                                                                                                  \
    h=$(openssl x509 -inform PEM -fingerprint -noout -in "$f")                                          \
    if [ -z "$h" ] ; then                                                                               \
        echo Cannot parse "$f" >&2                                                                      \
        confinue                                                                                        \
    fi                                                                                                  \
    cert=$(echo "$h" | sed -rn 's/^SHA1 Fingerprint=//; T; s/://g; s/(.{8}).*/\\1/p')                   \
    echo Found signing certificate "$f" "($cert)" >&2                                                   \
    cat "$f" >>%_sourcedir/.kernel_signing_key.pem                                                      \
    mkdir -p %_sourcedir/.kernel_signing_certs                                                          \
    openssl x509 -inform PEM -in "$f" -outform DER -out %_sourcedir/.kernel_signing_certs/"$cert".crt   \
    echo -n "$space$cert" ; space=" "                                                                   \
done )

Source0:        https://www.kernel.org/pub/linux/kernel/v6.x/linux-%srcversion.tar.xz
Source3:        kernel-source.rpmlintrc
Source14:       series.conf
Source16:       guards
Source17:       apply-patches
Source19:       kernel-binary-conflicts
Source20:       obsolete-kmps
Source21:       config.conf
Source23:       supported.conf
Source33:       check-for-config-changes
Source35:       group-source-files.pl
Source36:       README.PATCH-POLICY.SUSE
Source37:       README.SUSE
Source38:       README.KSYMS
Source40:       source-timestamp
Source46:       split-modules
Source47:       modversions
Source48:       macros.kernel-source
Source49:       kernel-module-subpackage
Source50:       kabi.pl
Source51:       mkspec
Source52:       kernel-source%variant.changes
Source53:       kernel-source.spec.in
Source54:       kernel-binary.spec.in
Source55:       kernel-syms.spec.in
Source56:       kernel-docs.spec.in
Source57:       kernel-cert-subpackage
Source58:       constraints.in
Source60:       config.sh
Source61:       compute-PATCHVERSION.sh
Source62:       old-flavors
Source63:       arch-symbols
Source64:       package-descriptions
Source65:       kernel-spec-macros
Source67:       log.sh
Source68:       host-memcpy-hack.h
Source69:       try-disable-staging-driver
Source70:       kernel-obs-build.spec.in
Source71:       kernel-obs-qa.spec.in
Source72:       compress-vmlinux.sh
Source73:       dtb.spec.in.in
Source74:       mkspec-dtb
Source75:       release-projects
Source76:       check-module-license
Source78:       modules.fips
Source79:       splitflist
Source80:       mergedep
Source81:       moddep
Source82:       modflist
Source83:       kernel-subpackage-build
Source84:       kernel-subpackage-spec
Source85:       kernel-default-base.spec.txt
Source86:       old_changelog.txt
Source100:      config.tar.bz2
Source101:      config.addon.tar.bz2
Source102:      patches.arch.tar.bz2
Source103:      patches.drivers.tar.bz2
Source104:      patches.fixes.tar.bz2
Source105:      patches.rpmify.tar.bz2
Source106:      patches.suse.tar.bz2
Source108:      patches.addon.tar.bz2
Source109:      patches.kernel.org.tar.bz2
Source110:      patches.apparmor.tar.bz2
Source111:      patches.rt.tar.bz2
Source113:      patches.kabi.tar.bz2
Source114:      patches.drm.tar.bz2
Source120:      kabi.tar.bz2
Source121:      sysctl.tar.bz2
# These files are found in the kernel-source package:
NoSource:       0
NoSource:       3
NoSource:       14
NoSource:       16
NoSource:       17
NoSource:       19
NoSource:       20
NoSource:       21
NoSource:       23
NoSource:       33
NoSource:       35
NoSource:       36
NoSource:       37
NoSource:       38
NoSource:       40
NoSource:       46
NoSource:       47
NoSource:       48
NoSource:       49
NoSource:       50
NoSource:       51
NoSource:       52
NoSource:       53
NoSource:       54
NoSource:       55
NoSource:       56
NoSource:       57
NoSource:       58
NoSource:       60
NoSource:       61
NoSource:       62
NoSource:       63
NoSource:       64
NoSource:       65
NoSource:       67
NoSource:       68
NoSource:       69
NoSource:       70
NoSource:       71
NoSource:       72
NoSource:       73
NoSource:       74
NoSource:       75
NoSource:       76
NoSource:       78
NoSource:       79
NoSource:       80
NoSource:       81
NoSource:       82
NoSource:       83
NoSource:       84
NoSource:       85
NoSource:       86
NoSource:       100
NoSource:       101
NoSource:       102
NoSource:       103
NoSource:       104
NoSource:       105
NoSource:       106
NoSource:       108
NoSource:       109
NoSource:       110
NoSource:       111
NoSource:       113
NoSource:       114
NoSource:       120
NoSource:       121

%ifarch %ix86
# Only i386/default supports i586, mark other flavors' packages as i686
%if ! %build_default
BuildArch:      i686
%endif
%endif
# Force bzip2 instead of lzma compression to
# 1) allow install on older dist versions, and
# 2) decrease build times (bsc#962356 boo#1175882)
%define _binary_payload w9.bzdio
# Do not recompute the build-id of vmlinux in find-debuginfo.sh (bsc#964063)
%undefine _unique_build_ids
%define _no_recompute_build_ids 1
# prevent usr/lib/debug/boot/vmlinux-4.12.14-11.10-default-4.12.14-11.10.ppc64le.debug
%undefine _unique_debug_names

%if "%{compress_modules}" == "zstd"
BuildRequires:  zstd
# Make sure kmod supports zstd compressed modules
Requires(post): kmod-zstd
%endif
Provides:       %name = %version-%source_rel
# bnc#901925
Provides:       %name-%version-%source_rel
Provides:       %{name}_%_target_cpu = %version-%source_rel
Provides:       kernel-base = %version-%source_rel
Provides:       multiversion(kernel)
# In SLE11, kernel-$flavor complemented kernel-$flavor-base. With SLE12,
# kernel-$flavor itself contains all the needed files and kernel-$flavor-base
# is a subset that can replace kernel-$flavor in some scenarios. We need to
# obsolete the -base subpackage from SLE11, so that the base files are not
# owned by multiple packages now. The dependency is not correct wrt openSUSE
# 11.2 - 11.4, but we primarily care about the supported upgrade path.
Obsoletes:      %name-base < 3.1
%if ("%build_flavor" != "kvmsmall") && ("%build_flavor" != "azure")
Recommends: kernel-firmware
%endif
# The following is copied to the -base subpackage as well
# BEGIN COMMON DEPS
Requires(pre):  suse-kernel-rpm-scriptlets
Requires(post): suse-kernel-rpm-scriptlets
Requires:       suse-kernel-rpm-scriptlets
Requires(preun): suse-kernel-rpm-scriptlets
Requires(postun): suse-kernel-rpm-scriptlets
Requires(pre):  coreutils awk
# For /usr/lib/module-init-tools/weak-modules2 and /usr/lib/modprobe.d/*.conf
Requires(post): suse-module-tools
Requires:       suse-module-tools
# For depmod (modutils is a dependency provided by both module-init-tools and
# kmod-compat)
Requires(post): modutils
# Use OrderWithRequires to instruct the package manager to schedule the
# installation of bootloader and dracut related tools as if they were
# required. This will ensure they're there for post scripts without hard
# requiring them. (boo#1228659, boo#1240785)
OrderWithRequires(post): udev
OrderWithRequires(post): systemd-boot
OrderWithRequires(post): perl-Bootloader
OrderWithRequires(post): update-bootloader
OrderWithRequires(post): dracut
# Install the package providing /etc/SuSE-release early enough, so that
# the grub entry has correct title (bnc#757565)
Requires(post): distribution-release

%if %{usrmerged}
# make sure we have a post-usrmerge system
Conflicts:      filesystem < 16
%endif

Obsoletes:      microcode_ctl < 1.18

%{lua:	fd, err = io.open(rpm.expand('%_sourcedir') .. '/kernel-binary-conflicts')
	if not fd then io.stderr:write(err) end
	unpack = table.unpack or unpack
	for l in fd:lines() do
		if #l > 0 and l:sub(1,1) ~= '#' then
			words = {} ; for w in l:gmatch("([^%s]+)%s*") do table.insert(words, w) end
			package, version = unpack(words)
			print('Conflicts: ' .. package .. ' < '.. version .. '\n')
		end
	end
	fd:close()
}

%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
Provides:       kernel = %version-%source_rel
Provides:       kernel-%build_flavor-base-srchash-%git_commit
Provides:       kernel-srchash-%git_commit
# END COMMON DEPS
Provides:       %name-srchash-%git_commit
%ifarch x86_64
Provides:       kernel-compute = 3.13
Obsoletes:      kernel-compute <= 3.13
%endif
%ifarch x86_64
Provides:       kernel-compute-base = 3.13
Obsoletes:      kernel-compute-base <= 3.13
%endif
%obsolete_rebuilds %name

%define kmp_target_cpu %_target_cpu
%ifarch %ix86
# KMPs are always built as i586, because rpm does not allow to build
# subpackages for different architectures. Therefore, we change the
# /usr/src/linux-obj/<arch> symlink to i586.
%define kmp_target_cpu i586
%endif

%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kernel-preempt = %version-%release
Provides:       kernel-preempt_%_target_cpu = %version-%source_rel
%endif
%endif

%{lua:	fd, err = io.open(rpm.expand('%_sourcedir') .. '/obsolete-kmps')
	if not fd then io.stderr:write(err) end
	unpack = table.unpack or unpack
	for l in fd:lines() do
		if #l > 0 and l:sub(1,1) ~= '#' then
			words = {} ; for w in l:gmatch("([^%s]+)%s*") do table.insert(words, w) end
			package, version = unpack(words)
			print('Obsoletes: ' .. package .. '-kmp-' .. rpm.expand('%build_flavor') .. ' <= '.. version .. '\n')
			print('Provides: ' .. package .. '-kmp = ' .. version .. '.1\n')
			print('Provides: ' .. package .. '-kmp-' .. rpm.expand('%build_flavor') .. ' = '.. version .. '.1\n')
		end
	end
	fd:close()
}

%description
The kernel for arm64 and x86_64 architectures that supports CONFIG_PREEMPT_RT. Its
main purpose is to serve workloads with strict latency requirements with more
deterministic worst case behaviour than the default kernel.


%source_timestamp

%pre
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-pre --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%post
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-post --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%preun
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-preun --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%postun
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-postun --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%posttrans
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-posttrans --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%files -f kernel-main.files

%if "%CONFIG_MODULES" == "y" && %split_base
%package base
Summary:        Kernel with PREEMPT_RT (realtime) support - base modules
Group:          System/Kernel
Url:            http://www.kernel.org/
Provides:       kernel-base = %version-%source_rel
Provides:       multiversion(kernel)
Conflicts:      %name = %version-%source_rel
Requires(pre):  suse-kernel-rpm-scriptlets
Requires(post): suse-kernel-rpm-scriptlets
Requires:       suse-kernel-rpm-scriptlets
Requires(preun): suse-kernel-rpm-scriptlets
Requires(postun): suse-kernel-rpm-scriptlets
Requires(pre):  coreutils awk
# For /usr/lib/module-init-tools/weak-modules2 and /usr/lib/modprobe.d/*.conf
Requires(post): suse-module-tools
Requires:       suse-module-tools
# For depmod (modutils is a dependency provided by both module-init-tools and
# kmod-compat)
Requires(post): modutils
# Use OrderWithRequires to instruct the package manager to schedule the
# installation of bootloader and dracut related tools as if they were
# required. This will ensure they're there for post scripts without hard
# requiring them. (boo#1228659, boo#1240785)
OrderWithRequires(post): udev
OrderWithRequires(post): systemd-boot
OrderWithRequires(post): perl-Bootloader
OrderWithRequires(post): update-bootloader
OrderWithRequires(post): dracut
# Install the package providing /etc/SuSE-release early enough, so that
# the grub entry has correct title (bnc#757565)
Requires(post): distribution-release

%if %{usrmerged}
# make sure we have a post-usrmerge system
Conflicts:      filesystem < 16
%endif

Obsoletes:      microcode_ctl < 1.18

%{lua:	fd, err = io.open(rpm.expand('%_sourcedir') .. '/kernel-binary-conflicts')
	if not fd then io.stderr:write(err) end
	unpack = table.unpack or unpack
	for l in fd:lines() do
		if #l > 0 and l:sub(1,1) ~= '#' then
			words = {} ; for w in l:gmatch("([^%s]+)%s*") do table.insert(words, w) end
			package, version = unpack(words)
			print('Conflicts: ' .. package .. ' < '.. version .. '\n')
		end
	end
	fd:close()
}

%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
Provides:       kernel = %version-%source_rel
Provides:       kernel-%build_flavor-base-srchash-%git_commit
Provides:       kernel-srchash-%git_commit

%ifarch x86_64
Provides:       kernel-compute-base = 3.13
Obsoletes:      kernel-compute-base <= 3.13
%endif
%obsolete_rebuilds %name-base
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif

%description base
The kernel for arm64 and x86_64 architectures that supports CONFIG_PREEMPT_RT. Its
main purpose is to serve workloads with strict latency requirements with more
deterministic worst case behaviour than the default kernel.

This package contains only the base modules, required in all installs.


%source_timestamp
%pre base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-pre --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-post --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-preun --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-postun --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-posttrans --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files base -f kernel-base.files
%endif

%package extra
Summary:        Kernel with PREEMPT_RT (realtime) support - Unsupported kernel modules
Group:          System/Kernel
URL:            https://www.kernel.org/
Provides:       %name-extra_%_target_cpu = %version-%source_rel
Provides:       kernel-extra = %version-%source_rel
Provides:       multiversion(kernel)
Requires:       %{name}_%_target_cpu = %version-%source_rel
Requires(pre):  coreutils awk
Requires(post): modutils
Requires(post): perl-Bootloader
Requires(post): dracut
%ifarch x86_64
Provides:       kernel-compute-extra = 3.13
Obsoletes:      kernel-compute-extra <= 3.13
%endif
%obsolete_rebuilds %name-extra
Supplements:    packageand(product(SLED):%{name}_%_target_cpu)
Supplements:    packageand(product(sle-we):%{name}_%_target_cpu)
Supplements:    packageand(product(Leap):%{name}_%_target_cpu)
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kernel-preempt-extra = %version-%release
Provides:       kernel-preempt-extra_%_target_cpu = %version-%source_rel
%endif
%endif

%description extra
The kernel for arm64 and x86_64 architectures that supports CONFIG_PREEMPT_RT. Its
main purpose is to serve workloads with strict latency requirements with more
deterministic worst case behaviour than the default kernel.

This package contains additional modules not supported by SUSE.


%source_timestamp

%pre extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%if %split_extra

%files extra -f kernel-extra.files
%endif

%if %split_extra && %split_optional
%package optional
Summary:        Kernel with PREEMPT_RT (realtime) support - Optional kernel modules
Group:          System/Kernel
URL:            https://www.kernel.org/
Provides:       %name-optional_%_target_cpu = %version-%source_rel
Provides:       kernel-optional = %version-%source_rel
Provides:       multiversion(kernel)
Requires:       %name-extra_%_target_cpu = %version-%source_rel
Requires(pre):  coreutils awk
Requires(post): modutils
Requires(post): perl-Bootloader
Requires(post): dracut
%ifarch x86_64
Provides:       kernel-compute-optional = 3.13
Obsoletes:      kernel-compute-optional <= 3.13
%endif
%obsolete_rebuilds %name-optional
Supplements:    packageand(product(Leap):%{name}_%_target_cpu)
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kernel-preempt-optional = %version-%release
Provides:       kernel-preempt-optional_%_target_cpu = %version-%source_rel
%endif
%endif

%description optional
The kernel for arm64 and x86_64 architectures that supports CONFIG_PREEMPT_RT. Its
main purpose is to serve workloads with strict latency requirements with more
deterministic worst case behaviour than the default kernel.

This package contains optional modules only for openSUSE Leap.


%source_timestamp

%pre optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files optional -f kernel-optional.files
%endif

%if "%CONFIG_KMSG_IDS" == "y"

%package man
Summary:        The collection of man pages generated by the kmsg script
Group:          System/Kernel

%description man
This package includes the man pages that have been generated from the
kmsg message documentation comments.


%source_timestamp
%files man
/usr/share/man/man9/*
%endif

%if 0%{?separate_vdso}
%package vdso
Summary:        vdso binaries for debugging purposes
Group:          System/Kernel

%description vdso
This package includes the vdso binaries. They can be used for debugging. The
actual binary linked to the programs is loaded from the in-memory image, not
from this package.


%source_timestamp
%files vdso
%dir %modules_dir
%modules_dir/vdso/
%endif

%package devel
Summary:        Development files necessary for building kernel modules
Group:          Development/Sources
Provides:       %name-devel = %version-%source_rel
Provides:       multiversion(kernel)
%if ! %build_vanilla && ! %vanilla_only
Requires:       kernel-devel%variant = %version-%source_rel
Recommends:     make
Recommends:     gcc
Recommends:     perl
# for objtool
Requires:	libelf-devel
Supplements:    packageand(%name:kernel-devel%variant)
%else
Requires:       kernel-source-vanilla = %version-%source_rel
Supplements:    packageand(%name:kernel-source-vanilla)
%endif
%if "%{compress_modules}" == "zstd"
Requires:       zstd
%endif
%if "%CONFIG_DEBUG_INFO_BTF_MODULES" == "y"
Requires:       dwarves >= 1.22
%endif
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kernel-preempt-devel = %version-%release
%endif
%endif
Requires:       %gcc_package
%ifarch x86_64
Provides:       kernel-compute-devel = 3.13
Obsoletes:      kernel-compute-devel <= 3.13
%endif
%obsolete_rebuilds %name-devel
PreReq:         coreutils

%description devel
This package contains files necessary for building kernel modules (and
kernel module packages) against the %build_flavor flavor of the kernel.


%source_timestamp

%if "%CONFIG_MODULES" == "y"

%pre devel

# handle update from an older kernel-source with linux-obj as symlink
if [ -h /usr/src/linux-obj ]; then
    rm -vf /usr/src/linux-obj
fi

%post devel
%relink_function

relink ../../linux-%{kernelrelease}%{variant}-obj/"%cpu_arch_flavor" /usr/src/linux-obj/"%cpu_arch_flavor"

%files devel -f kernel-devel.files
%dir /usr/src/linux-obj
%dir /usr/src/linux-obj/%cpu_arch
%ghost /usr/src/linux-obj/%cpu_arch_flavor
%if %generate_compile_commands
%exclude %obj_install_dir/%cpu_arch_flavor/compile_commands.json
%endif
%if "%kmp_target_cpu" != "%cpu_arch"
%obj_install_dir/%kmp_target_cpu
/usr/src/linux-obj/%kmp_target_cpu
%endif

%if "%livepatch" != "" && "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y" && (("%variant" == "" && %build_default) || ("%build_flavor" == "rt" && 0%livepatch_rt))
%if "%livepatch" == "kgraft"
%define patch_package %{livepatch}-patch
%else
%define patch_package kernel-%{livepatch}
%endif
%package %{livepatch}
Summary:        Metapackage to pull in matching %patch_package package
Group:          System/Kernel
Requires:       %{patch_package}-%(echo %{version}-%{source_rel} | sed 'y/\./_/')-%{build_flavor}
Provides:       multiversion(kernel)
%if "%variant" != "-rt"
Provides:	kernel-default-kgraft = %version
Provides:	kernel-xen-kgraft = %version
%if "%livepatch" != "kgraft"
Obsoletes:	kernel-default-kgraft < %version
Obsoletes:	kernel-xen-kgraft < %version
%endif
%endif

%description %{livepatch}
This is a metapackage that pulls in the matching %patch_package package for a
given kernel version. The advantage of the metapackage is that its name is
static, unlike the %{patch_package}-<kernel-version>-flavor package names.

%files %{livepatch}
# rpmlint complains about empty packages, so lets own something
%dir %modules_dir
%endif

%if 0%{?klp_ipa_clones} && "%livepatch" != "" && "%CONFIG_LIVEPATCH_IPA_CLONES" == "y"
%package %{livepatch}-devel
Summary:	Kernel symbols file used during kGraft patch development
Group:		System/Kernel

%description %{livepatch}-devel
This package brings ipa-clones files, which are used to to track
set of functions where a code from another function can eventually occur.

%files %{livepatch}-devel -f livepatch-files
%endif

%if "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y"
%package -n cluster-md-kmp-%build_flavor
Summary:        Clustering support for MD devices
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       cluster-md-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       cluster-md-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:cluster-md-kmp-%build_flavor)
Requires:       dlm-kmp-%build_flavor = %version-%release

%description -n cluster-md-kmp-%build_flavor
Clustering support for MD devices. This enables locking and
synchronization across multiple systems on the cluster, so all
nodes in the cluster can access the MD devices simultaneously.

%pre -n cluster-md-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "cluster-md-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n cluster-md-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "cluster-md-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n cluster-md-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "cluster-md-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n cluster-md-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "cluster-md-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n cluster-md-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "cluster-md-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n cluster-md-kmp-%build_flavor -f cluster-md-kmp.files

%package -n dlm-kmp-%build_flavor
Summary:        DLM kernel modules
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       dlm-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       dlm-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:dlm-kmp-%build_flavor)

%description -n dlm-kmp-%build_flavor
DLM stands for Distributed Lock Manager, a means to synchronize access to
shared resources over the cluster.

%pre -n dlm-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "dlm-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n dlm-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "dlm-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n dlm-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "dlm-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n dlm-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "dlm-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n dlm-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "dlm-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n dlm-kmp-%build_flavor -f dlm-kmp.files

%package -n gfs2-kmp-%build_flavor
Summary:        GFS2 kernel modules
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       gfs2-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       gfs2-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:gfs2-kmp-%build_flavor)
Requires:       dlm-kmp-%build_flavor = %version-%release

%description -n gfs2-kmp-%build_flavor
GFS2 is Global Filesystem, a shared device filesystem.

%pre -n gfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "gfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n gfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "gfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n gfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "gfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n gfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "gfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n gfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "gfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n gfs2-kmp-%build_flavor -f gfs2-kmp.files

%package -n kselftests-kmp-%build_flavor
Summary:        Kernel sefltests
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       kselftests-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kselftests-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:kselftests-kmp-%build_flavor)

%description -n kselftests-kmp-%build_flavor
This package contains kernel modules which are part of the upstream kernel
selftest effort. kselftest is the name of the upstream kernel target to build
and run all selftests. You can also run each test individually from the
respective upstream tools/testing/selftests/ directory, this package is
intended to be used using individial upstream selftest scripts given only
select supported selftest drivers are enabled.

It should always be possible to always run the latest linux-next version of the
selftest scripts and tests against any older kernel selftest driver.  Certain
tests facilities may be backported onto older kernels to enable further
testing.

Selftests also provide for a vehicle or proof of concept issues to be
reproduced, verified and corrected.

Selftest drivers are intended to be supported only in testing and QA
environments, they are not intended to be run on production systems.

%pre -n kselftests-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "kselftests-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n kselftests-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "kselftests-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n kselftests-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "kselftests-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n kselftests-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "kselftests-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n kselftests-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "kselftests-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n kselftests-kmp-%build_flavor -f kselftests-kmp.files

%package -n ocfs2-kmp-%build_flavor
Summary:        OCFS2 kernel modules
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       ocfs2-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       ocfs2-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:ocfs2-kmp-%build_flavor)
Requires:       dlm-kmp-%build_flavor = %version-%release

%description -n ocfs2-kmp-%build_flavor
OCFS2 is the Oracle Cluster Filesystem, a filesystem for shared devices
accessible simultaneously from multiple nodes of a cluster.

%pre -n ocfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "ocfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n ocfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "ocfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n ocfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "ocfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n ocfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "ocfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n ocfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "ocfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n ocfs2-kmp-%build_flavor -f ocfs2-kmp.files

%endif # %CONFIG_SUSE_KERNEL_SUPPORTED
%endif # %CONFIG_MODULES

%prep
if ! [ -e %{S:0} ]; then
    echo "The %name-%version.nosrc.rpm package does not contain the" \
	 "complete sources. Please install kernel-source-%version.src.rpm."
    exit 1
fi

SYMBOLS=
if test -e %_sourcedir/extra-symbols; then
	SYMBOLS=$(cat %_sourcedir/extra-symbols)
	echo "extra symbol(s):" $SYMBOLS
fi

# Unpack all sources and patches
%setup -q -c -T -a 0 -a 100 -a 101 -a 102 -a 103 -a 104 -a 105 -a 106 -a 108 -a 109 -a 110 -a 111 -a 113 -a 114 -a 120 -a 121

mkdir -p %kernel_build_dir

# Generate a list of modules with their support status marking
# The first marker is supposed to be either "+external", "-" or "-!optional",
# where "+external" is for an externally supported module, "-" is for an
# unsuppored module, "-!optional" is for Leap-only unsupported module.
# There can be an optional arch-specific second marker with "+arch" (e.g.
# +arm64), which enforces the module to be supported on the specific arch.
%_sourcedir/guards --list --with-guards <%_sourcedir/supported.conf | \
awk '{
    t = "";
    for (i = 1; i < NF; i++) {
	if ($i == "+external") {
		t = " external";
	} else if ($i == "+'%cpu_arch'") {
		t = "";
	} else if ($i ~ "^-") {
		t = " no";
	}
    }
    print $(NF) t;
}' >%kernel_build_dir/Module.supported
subpackages=(
	base
%if "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y"
	cluster-md-kmp dlm-kmp gfs2-kmp kselftests-kmp ocfs2-kmp
%endif
)
for package in "${subpackages[@]}"; do
	%_sourcedir/guards --default=0 "$package" \
		<%_sourcedir/supported.conf | sed 's,.*/,,; s,\.ko$,,' | \
		sort -u >%kernel_build_dir/Module."$package"
done
%if %split_extra && %split_optional
# Module.optional is in a special form, containing guard markers for
# both extra and optional modules, which is processed by split-modules
%_sourcedir/guards --list --with-guards <%_sourcedir/supported.conf | \
awk '{
    t = "";
    for (i = 1; i < NF; i++) {
	if ($i == "+'%cpu_arch'") {
		t = "";
	} else if ($i ~ "^-") {
		t = $i
	}
    }
    if (t != "") {print t,$(NF);}
}' >%kernel_build_dir/Module.optional
%endif

cd linux-%srcversion

%_sourcedir/apply-patches \
%if %{build_vanilla} && ! %vanilla_only
	--vanilla \
%endif
	%_sourcedir/series.conf .. $SYMBOLS

sed -i -e 's/\$(CROSS_COMPILE)gcc/\$(CROSS_COMPILE)%gcc_compiler/g' Makefile
grep '\$(CROSS_COMPILE)%gcc_compiler' Makefile

cd %kernel_build_dir

# Override the timestamp 'uname -v' reports with the source timestamp and
# the commit hash.
date=$(head -n 1 %_sourcedir/source-timestamp)
commit=$(sed -n 's/GIT Revision: //p' %_sourcedir/source-timestamp)
cat > .kernel-binary.spec.buildenv <<EOF
export KBUILD_BUILD_TIMESTAMP="$(LANG=C date -d "$date") (${commit:0:7})"
export KBUILD_VERBOSE=0
export KBUILD_SYMTYPES=1
export KBUILD_BUILD_USER=geeko
export KBUILD_BUILD_HOST=buildhost
export HOST_EXTRACFLAGS="-include %_sourcedir/host-memcpy-hack.h"
EOF
source .kernel-binary.spec.buildenv

if [ -f %_sourcedir/localversion ] ; then
    cat %_sourcedir/localversion > localversion
fi

config_base="default"
%ifarch %ix86
config_base="pae"
%endif
if ! [ -f %my_builddir/config/%cpu_arch/$config_base ] ; then
    config_base=%variant
    config_base=${config_base#-}
fi
if ! grep -q CONFIG_MMU= "%my_builddir/config/%cpu_arch_flavor"; then
cp "%my_builddir/config/%cpu_arch/$config_base" .config
../scripts/kconfig/merge_config.sh -m .config \
                                   %my_builddir/config/%cpu_arch_flavor
else
cp %my_builddir/config/%cpu_arch_flavor .config
fi
if test -e %my_builddir/config.addon/%cpu_arch_flavor; then
	# FIXME: config.addon doesn't affect the %CONFIG_ macros defined at
	# the top of the specfile
	../scripts/kconfig/merge_config.sh -m .config %my_builddir/config.addon/%cpu_arch_flavor
fi

CONFIG_SUSE_KERNEL_RELEASED="--disable CONFIG_SUSE_KERNEL_RELEASED"
%if 0%{?_project:1}
if echo %_project | grep -Eqx -f %_sourcedir/release-projects; then
	CONFIG_SUSE_KERNEL_RELEASED="--enable CONFIG_SUSE_KERNEL_RELEASED"
fi
%endif

DEBUG_INFO_TYPE="$(grep "CONFIG_DEBUG_INFO_DWARF.*=y" .config)"
DEBUG_INFO_TYPE="${DEBUG_INFO_TYPE%%=y}"
DEBUG_INFO_TYPE="${DEBUG_INFO_TYPE##CONFIG_DEBUG_INFO_}"
echo "Kernel debuginfo type: ${DEBUG_INFO_TYPE}"

../scripts/config \
	--set-str CONFIG_LOCALVERSION -%source_rel-%build_flavor \
	--enable  CONFIG_SUSE_KERNEL \
	$CONFIG_SUSE_KERNEL_RELEASED \
%if 0%{?__debug_package:1}
	--enable  CONFIG_DEBUG_INFO
%else
	--disable CONFIG_DEBUG_INFO \
	--disable CONFIG_DEBUG_INFO_"${DEBUG_INFO_TYPE}" \
	--enable  CONFIG_DEBUG_INFO_NONE
%endif

if [ %CONFIG_MODULE_SIG = "y" ]; then
	if [ -n "%certs" ] ; then
		ln -s %_sourcedir/.kernel_signing_key.pem .
	else
		if ! [ -f .kernel.genkey ] ; then
			cat > .kernel.genkey <<EOF
[ req ]
default_bits = 4096
distinguished_name = req_distinguished_name
prompt = no
string_mask = utf8only
x509_extensions = myexts

[ req_distinguished_name ]
CN = Build time autogenerated kernel key

[ myexts ]
basicConstraints=critical,CA:FALSE
keyUsage=digitalSignature
subjectKeyIdentifier=hash
authorityKeyIdentifier=keyid
extendedKeyUsage=codeSigning
EOF
		fi
		openssl req -new -nodes -utf8 -%CONFIG_MODULE_SIG_HASH -days 36500 \
			-batch -x509 -config .kernel.genkey \
			-outform PEM -out .kernel_signing_key.pem \
			-keyout .kernel_signing_key.pem
	fi
	../scripts/config --set-str CONFIG_MODULE_SIG_KEY ".kernel_signing_key.pem"
fi

case %cpu_arch in
    x86_64 | i386)
        MAKE_ARGS="$MAKE_ARGS ARCH=x86"
        ;;
    ppc*)
        MAKE_ARGS="$MAKE_ARGS ARCH=powerpc"
        ;;
    s390x)
        MAKE_ARGS="$MAKE_ARGS ARCH=s390"
        ;;
    arm64)
        MAKE_ARGS="$MAKE_ARGS ARCH=arm64"
        ;;
    armv*)
        MAKE_ARGS="$MAKE_ARGS ARCH=arm"
        ;;
    riscv*)
        MAKE_ARGS="$MAKE_ARGS ARCH=riscv"
        ;;
    *)
        MAKE_ARGS="$MAKE_ARGS ARCH=%cpu_arch"
        ;;
esac

makeoutputsync=
if make --output-sync --help >/dev/null 2>&1 ; then
        makeoutputsync=--output-sync
else
        echo make does not support --output-sync flag. Build messages may be mangled. 1>&2
fi
MAKE_ARGS="$MAKE_ARGS $makeoutputsync %{?_smp_mflags}"
echo export MAKE_ARGS=\""$MAKE_ARGS"\" >> .kernel-binary.spec.buildenv

KERN_DIRS="-C .. O=$PWD"
if test -e %_sourcedir/TOLERATE-UNKNOWN-NEW-CONFIG-OPTIONS; then
    yes '' | make oldconfig $MAKE_ARGS $KERN_DIRS
else
    cp .config .config.orig
    if test -f ../scripts/kconfig/Makefile && \
       grep -q syncconfig ../scripts/kconfig/Makefile; then
        syncconfig="syncconfig"
    else
        syncconfig="silentoldconfig"
    fi
    make $syncconfig $MAKE_ARGS $KERN_DIRS < /dev/null
    %_sourcedir/check-for-config-changes .config.orig .config
    rm .config.orig
fi

make prepare $MAKE_ARGS
make scripts $MAKE_ARGS
krel=$(make -s kernelrelease $MAKE_ARGS)

if [ "$krel" != "%kernelrelease-%build_flavor" ]; then
    echo "Kernel release mismatch: $krel != %kernelrelease-%build_flavor" >&2
    exit 1
fi

make clean $MAKE_ARGS

rm -f source
find . ! -type d ! -name 'Module.base' ! -name 'Module.*-kmp' ! -name 'Module.optional' -printf '%%P\n' \
	> %my_builddir/obj-files

%build
cd %kernel_build_dir
source .kernel-binary.spec.buildenv

# create *.symref files in the tree
if test -e %my_builddir/kabi/%cpu_arch/symtypes-%build_flavor; then
    %_sourcedir/modversions --unpack . < $_
fi

%if "%CONFIG_KMSG_IDS" == "y"
    chmod +x ../scripts/kmsg-doc
    MAKE_ARGS="$MAKE_ARGS D=2"
%endif

mkdir -p %_topdir/OTHER
log=%_topdir/OTHER/make-stderr.log
while true; do
    make all $MAKE_ARGS 2> >(tee "$log")
    if test "${PIPESTATUS[0]}" -eq 0; then
        break
    fi
    # In the linux-next and vanilla branches, we try harder to build a
    # package.
    if test 0%vanilla_only -gt 0 &&
			%_sourcedir/try-disable-staging-driver "$log"; then
        echo "Retrying make"
    else
        exit 1
    fi
done

%if 0%{?klp_ipa_clones} && %generate_compile_commands
    # Generate compile_commands.json
    make compile_commands.json $MAKE_ARGS
%endif

%install

# get rid of /usr/lib/rpm/brp-strip-debug
# strip removes too much from the vmlinux ELF binary
export NO_BRP_STRIP_DEBUG=true
export STRIP_KEEP_SYMTAB='*/vmlinux*'

# %kernel_module_directory/%kernelrelease-%build_flavor/source points to the source
# directory installed by kernel-devel. The kernel-%build_flavor-devel package
# has a correct dependency on kernel-devel, but the brp check does not see
# kernel-devel during build.
export NO_BRP_STALE_LINK_ERROR=yes

cd %kernel_build_dir
source .kernel-binary.spec.buildenv

mkdir -p %buildroot/boot
# (Could strip out non-public symbols.)
cp -p System.map %buildroot/boot/System.map-%kernelrelease-%build_flavor

add_vmlinux()
{
    local vmlinux=boot/vmlinux-%kernelrelease-%build_flavor

    cp vmlinux %buildroot/$vmlinux
    # make sure that find-debuginfo.sh picks it up. In the filelist, we
    # mark the file 0644 again
    chmod +x %buildroot/$vmlinux
    if test $1 == "--compressed"; then
        # avoid using the gzip -n option to make kdump happy (bnc#880848#c20)
        ts="$(head -n1 %_sourcedir/source-timestamp)"
        touch -d "$ts" %buildroot/$vmlinux
        touch %buildroot/$vmlinux.%{compress_vmlinux}
%if 0%{?__debug_package:1}
        # compress the vmlinux image after find-debuginfo.sh has processed it
%global __debug_install_post %__debug_install_post \
%_sourcedir/compress-vmlinux.sh %buildroot/boot/vmlinux-%kernelrelease-%build_flavor
%else
        %_sourcedir/compress-vmlinux.sh %buildroot/$vmlinux
%endif
        ghost_vmlinux=true
    else
        ghost_vmlinux=false
    fi
}

# architecture specifics
%ifarch %ix86 x86_64
    add_vmlinux --compressed
    cp -p arch/x86/boot/bzImage %buildroot/boot/%image-%kernelrelease-%build_flavor
%endif
%ifarch ppc ppc64 ppc64le
    add_vmlinux
%endif
%ifarch s390 s390x
    add_vmlinux --compressed
    image=image
    if test ! -f arch/s390/boot/$image; then
        image=bzImage
    fi
    cp -p arch/s390/boot/$image %buildroot/boot/%image-%kernelrelease-%build_flavor
%if "%CONFIG_KMSG_IDS" == "y"
    mkdir -p %buildroot/usr/share/man/man9
    find man -name '*.9' -exec install -m 644 -D '{}' %buildroot/usr/share/man/man9/ ';'
%endif
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
    s390x_vmlinux=arch/s390/boot/compressed/vmlinux
    if [ ! -f "$s390x_vmlinux" ]; then
        s390x_vmlinux=arch/s390/boot/vmlinux
    fi
    objcopy -R .rodata.compressed "$s390x_vmlinux" %buildroot/boot/zdebug-%kernelrelease-%build_flavor
%endif
%endif
%ifarch %arm
    add_vmlinux --compressed
    cp -p arch/arm/boot/%image %buildroot/boot/%image-%kernelrelease-%build_flavor
%endif
%ifarch aarch64
    add_vmlinux --compressed
    cp -p arch/arm64/boot/%image %buildroot/boot/%image-%kernelrelease-%build_flavor
%endif
%ifarch riscv64
    add_vmlinux --compressed
    cp -p arch/riscv/boot/%image %buildroot/boot/%image-%kernelrelease-%build_flavor
%endif

# sign the modules, firmware and possibly the kernel in the buildservice
BRP_PESIGN_FILES=""
%if "%CONFIG_EFI_STUB" == "y"
%if %{usrmerged}
BRP_PESIGN_FILES="%modules_dir/%image"
%else
BRP_PESIGN_FILES="/boot/%image-%kernelrelease-%build_flavor"
%endif
%endif
%if ! %sb_efi_only
%ifarch s390x ppc64 ppc64le
%if %{usrmerged}
BRP_PESIGN_FILES="%modules_dir/%image"
%else
BRP_PESIGN_FILES="/boot/%image-%kernelrelease-%build_flavor"
%endif
%endif
%endif
%if "%CONFIG_MODULE_SIG" == "y"
BRP_PESIGN_FILES="$BRP_PESIGN_FILES *.ko"
%endif
%ifarch %ix86
# XXX: do not sign on x86, as the repackaging changes kernel-pae
# from i686 to i586
BRP_PESIGN_FILES=""
%endif
export BRP_PESIGN_FILES
%if "%{compress_modules}" != "none"
export BRP_PESIGN_COMPRESS_MODULE=%{compress_modules}
%endif
# Do not sign vanilla kernels released in official projects
%if %build_vanilla && ! %vanilla_only
BRP_PESIGN_FILES=""
%endif

if test -x /usr/lib/rpm/pesign/gen-hmac; then
	$_ -r %buildroot /boot/%image-%kernelrelease-%build_flavor
fi

# Package the compiled-in certificates as DER files in /etc/uefi/certs
# and have mokutil enroll them when the kernel is installed
echo Signing certificates "%certs"
if test %CONFIG_MODULE_SIG = "y" -a -d %_sourcedir/.kernel_signing_certs ; then
    for f in %_sourcedir/.kernel_signing_certs/*.crt; do
            mkdir -p %buildroot/etc/uefi/certs
            cp -v $f %buildroot/etc/uefi/certs
    done
fi

cp -p .config %buildroot/boot/config-%kernelrelease-%build_flavor
sysctl_file=%buildroot/boot/sysctl.conf-%kernelrelease-%build_flavor
for file in %my_builddir/sysctl/{defaults,%cpu_arch/arch-defaults,%cpu_arch_flavor}; do
	if [ -f "$file" ]; then
		cat "$file"
	fi
done | sed '1i # Generated file - do not edit.' >$sysctl_file
if [ ! -s $sysctl_file ]; then
	rm $sysctl_file
fi

%if %install_vdso
# Install the unstripped vdso's that are linked in the kernel image
make vdso_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot
rm -rf %buildroot%kernel_module_directory/%kernelrelease-%build_flavor/vdso/.build-id
%endif

# Create a dummy initrd with roughly the size the real one will have.
# That way, YaST will know that this package requires some additional
# space in /boot.
dd if=/dev/zero of=%buildroot/boot/initrd-%kernelrelease-%build_flavor \
	bs=1024 seek=2047 count=1
# Also reserve some space for the kdump initrd
cp %buildroot/boot/initrd-%kernelrelease-%build_flavor{,-kdump}
%if 0%{?suse_version} >= 1500
# Use same permissions as dracut
chmod 0600 %buildroot/boot/initrd-%kernelrelease-%build_flavor{,-kdump}
%endif

if [ %CONFIG_MODULES = y ]; then
    mkdir -p %rpm_install_dir/%cpu_arch_flavor
    mkdir -p %buildroot/usr/src/linux-obj/%cpu_arch
    install -m 755 -D -t %rpm_install_dir/%cpu_arch_flavor/scripts/mod/ scripts/mod/ksym-provides

    gzip -n -c9 < Module.symvers > %buildroot/boot/symvers-%kernelrelease-%build_flavor.gz

    make modules_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot

%ifarch s390 s390x
    expoline=arch/s390/lib/expoline/expoline.o
    if test -f arch/s390/lib/expoline/expoline.o ; then
	install -m 644 -D -t %rpm_install_dir/%cpu_arch_flavor/$(dirname $expoline) $expoline
    fi
%endif

    # Also put the resulting file in %rpm_install_dir/%cpu_arch/%build_flavor
    # so that kernel-devel + kernel-%build_flavor is sufficient for building
    # modules that have modversions as well.
    mkdir -p %rpm_install_dir/%cpu_arch/%build_flavor
    cp Module.symvers %rpm_install_dir/%cpu_arch/%build_flavor

    # List of ipa-clones that are used to to track set of functions where a code from another function can eventually occur.
    %if 0%{?klp_ipa_clones} && "%CONFIG_LIVEPATCH_IPA_CLONES" == "y"
        %if %generate_compile_commands
		    cp compile_commands.json %rpm_install_dir/%cpu_arch/%build_flavor
		    echo %obj_install_dir/%cpu_arch/%build_flavor/compile_commands.json >> %my_builddir/livepatch-files.no_dir
        %endif

        find %kernel_build_dir -name "*.ipa-clones" ! -size 0 | sed -e 's|^%kernel_build_dir/||' | sort > ipa-clones.list
        cp ipa-clones.list %rpm_install_dir/%cpu_arch/%build_flavor
        echo %obj_install_dir/%cpu_arch/%build_flavor/ipa-clones.list >> %my_builddir/livepatch-files.no_dir
        tar -C %kernel_build_dir \
%if ! 0%{?suse_version} || 0%{?suse_version} >= 1500
            --verbatim-files-from \
%endif
            -T ipa-clones.list -cf- | tar -C %rpm_install_dir/%cpu_arch/%build_flavor -xvf-
        cat ipa-clones.list | sed -e 's|^|%obj_install_dir/%cpu_arch/%build_flavor/|' >> %my_builddir/livepatch-files.no_dir
    %endif

    # Table of types used in exported symbols (for modversion debugging).
    %_sourcedir/modversions --pack . > %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    if [ -s %buildroot/boot/symtypes-%kernelrelease-%build_flavor ]; then
	gzip -n -9 %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    else
	rm -f %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    fi

    # Some architecture's $(uname -m) output is different from the ARCH
    # parameter that needs to be passed to kbuild. Create symlinks from
    # $(uname -m) to the ARCH directory.
    if [ ! -e %rpm_install_dir/%kmp_target_cpu ]; then
        ln -sf %cpu_arch %rpm_install_dir/%kmp_target_cpu
        ln -sf %cpu_arch %buildroot/usr/src/linux-obj/%kmp_target_cpu
    fi

    # We were building in %my_builddir/linux-%srcversion, but the sources will
    # later be installed in /usr/src/linux-%srcversion-%source_rel. Fix up the
    # build symlink.
    rm -f %buildroot%kernel_module_directory/%kernelrelease-%build_flavor/{source,build}
    ln -s %src_install_dir \
	%buildroot%kernel_module_directory/%kernelrelease-%build_flavor/source
    ln -s %obj_install_dir/%cpu_arch/%build_flavor \
	%buildroot%kernel_module_directory/%kernelrelease-%build_flavor/build

    # Abort if there are any undefined symbols
    msg="$(/sbin/depmod -F %buildroot/boot/System.map-%kernelrelease-%build_flavor \
			-b %buildroot -ae %kernelrelease-%build_flavor 2>&1)"
    if [ $? -ne 0 ] || echo "$msg" | grep  'needs unknown symbol'; then
	exit 1
    fi

    %_sourcedir/split-modules -d %buildroot \
	-o %my_builddir \
	-b %kernel_build_dir \
%if "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y"
	-e \
%endif
%if ! %supported_modules_check
	-i \
%endif
	%nil
%if ! %split_extra
    cat %my_builddir/unsupported-modules >>%my_builddir/main-modules
%endif

    # The modules.dep file is sorted randomly which produces strange file
    # checksums. As the file is not included in the resulting RPM, it's
    # pointless to rely on its contents. Replacing by zeros to make the
    # checksums always the same for several builds of the same package.
    test -s %buildroot%kernel_module_directory/%kernelrelease-%build_flavor/modules.dep && \
    dd if=/dev/zero of=%buildroot%kernel_module_directory/%kernelrelease-%build_flavor/modules.dep ibs=$(stat -c%s %buildroot%kernel_module_directory/%kernelrelease-%build_flavor/modules.dep) count=1

    res=0
    if test -e %my_builddir/kabi/%cpu_arch/symvers-%build_flavor; then
        # check for kabi changes
        %_sourcedir/kabi.pl --rules %my_builddir/kabi/severities \
            %my_builddir/kabi/%cpu_arch/symvers-%build_flavor \
            Module.symvers || res=$?
    fi
    if [ $res -ne 0 ]; then
	# %ignore_kabi_badness is defined in the Kernel:* projects in the
	# OBS to be able to build the KOTD in spite of kabi errors
	if [ 0%{?ignore_kabi_badness} -eq 0 -a \
	     ! -e %my_builddir/kabi/%cpu_arch/ignore-%build_flavor -a \
	     ! -e %_sourcedir/IGNORE-KABI-BADNESS ]; then
	    echo "Create a file IGNORE-KABI-BADNESS in the kernel-source" \
		 "directory to build this kernel even though its badness is" \
		 "higher than allowed for an official kernel."
	   exit 1
	fi
    fi

    # Check the license in each module
    if ! sh %_sourcedir/check-module-license %buildroot; then
	echo "Please fix the missing licenses!"
%if "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y"
	exit 1
%endif
    fi

    # These files are required for building external modules
    for FILE in arch/powerpc/lib/crtsavres.o arch/arm64/kernel/ftrace-mod.o \
		arch/*/kernel/macros.s scripts/module.lds
    do
	    if [ -f %kernel_build_dir/$FILE ]; then
		echo $FILE >> %my_builddir/obj-files
	    fi
    done

    tar --exclude=\*.ipa-clones --exclude=.config.old --exclude=.kernel-binary.spec.buildenv \
        --exclude=.kernel_signing_key.pem --exclude=.kernel.genkey \
        -cf - -T %my_builddir/obj-files | \
	tar -xf - -C %rpm_install_dir/%cpu_arch_flavor
    # bnc#507084
    find %rpm_install_dir/%cpu_arch_flavor/scripts -type f -perm -111 | \
        while read f; do
            case "$(file -b "$f")" in
            ELF\ *\ executable*)
                strip "$f"
            esac
        done

    # Recreate the generated Makefile with correct path
    #
    # Linux 5.13 no longer has mkmakefile
    if [ -f ../scripts/mkmakefile ] ; then
        sh ../scripts/mkmakefile ../../../%{basename:%src_install_dir} \
            %rpm_install_dir/%cpu_arch_flavor \
            $(echo %srcversion | sed -r 's/^([0-9]+)\.([0-9]+).*/\1 \2/')
    else
       echo 'export KBUILD_OUTPUT = %obj_install_dir/%cpu_arch_flavor' > %rpm_install_dir/%cpu_arch_flavor/Makefile
       echo 'include ../../../%{basename:%src_install_dir}/Makefile' >> %rpm_install_dir/%cpu_arch_flavor/Makefile
    fi
fi

# CONFIG_GDB_SCRIPTS
if [ -e vmlinux-gdb.py ]; then
    DEST=%rpm_install_dir/%cpu_arch_flavor/
    install -m 755 -d "$DEST"
    # set sys.path to our devel.rpm scripts
    sed 's@\(sys\.path\.insert(0, \).*@\1"%obj_install_dir/%cpu_arch_flavor/scripts/gdb/")@' vmlinux-gdb.py > "$DEST/vmlinux-gdb.py"

    DEST=%rpm_install_dir/%cpu_arch_flavor/scripts/gdb/linux
    install -m 755 -d "$DEST"
    pushd scripts/gdb/linux/
    for file in *.py; do
	if test -L "$file"; then
	    # relink against our devel.rpm sources, not of buildroot's
	    ln -s "%src_install_dir/scripts/gdb/linux/$file" "$DEST/$file"
	else
	    cp -p "$file" "$DEST"
	fi
    done
    popd

    DEST=%{buildroot}%{_datadir}/gdb/auto-load%modules_dir
    install -m 755 -d "$DEST"
    ln -s %obj_install_dir/%cpu_arch_flavor/vmlinux-gdb.py "$DEST/vmlinux-gdb.py"
fi

rm -rf %{buildroot}/lib/firmware

add_dirs_to_filelist() {
    sed -rn '
        # print file name
        p
        # remove filelist macros
        s:%%[a-z]+(\([^)]+\))? ?::g
        # add %%dir prefix
        s:^:%%dir :
        # print all parents
        :a
            # skip directories owned by other packages
            s:^%%dir (/boot|/etc|(/usr)?/lib/(modules|firmware)|/usr/share|/usr/src)/[^/]+$::
            s:/[^/]+$::p
        ta
    ' "$@" | sort -u
}

# Collect the file lists.
if [ -f %my_builddir/livepatch-files.no_dir ] ; then
    cat %my_builddir/livepatch-files.no_dir | add_dirs_to_filelist > %my_builddir/livepatch-files
fi

# does not exist for non-modularized kernels
%if %{usrmerged}
        mkdir -p %{buildroot}%modules_dir
%endif
shopt -s nullglob dotglob
> %my_builddir/kernel-devel.files
{
    echo "%modules_dir/build"
    echo "%modules_dir/source"
    cd %buildroot
    for file in boot/symtypes*; do
%if %{usrmerged}
        l="${file##*/}"
        l="%modules_dir/${l//-%kernelrelease-%build_flavor}"
        mv "$file" "%{buildroot}$l"
        ln -s "..$l" $file
        echo "$l"
        echo "%%ghost /$file"
%else
        echo "/$file"
%endif
    done
    if test -d .%{_datadir}/gdb/; then
	find .%obj_install_dir/%cpu_arch_flavor/scripts/gdb/linux/ -name '*.py' -type l | sed -e 's/^[.]//'
	echo "%{_datadir}/gdb/auto-load%modules_dir/vmlinux-gdb.py"
    fi
} | add_dirs_to_filelist >%my_builddir/kernel-devel.files
( cd %buildroot ; find .%obj_install_dir/%cpu_arch_flavor -type f ; ) | \
sed -e 's/^[.]//' | grep -v -e '[.]ipa-clones$' -e '/ipa-clones[.]list$'| \
add_dirs_to_filelist >> %my_builddir/kernel-devel.files

{   echo %ghost /boot/%image
    echo %ghost /boot/initrd
    cd %buildroot
    for f in boot/*; do
        l="${f##*/}"
        l="%modules_dir/${l//-%kernelrelease-%build_flavor}"
        if test -L "$f"; then
            echo "%%ghost /$f"
            continue
        elif test ! -f "$f"; then
            continue
        fi
        case "$f" in
        boot/initrd-*)
            echo "%%ghost /$f"
            continue
            ;;
        boot/vmlinux-*.%{compress_vmlinux})
            ;;
        boot/vmlinux-*)
            if $ghost_vmlinux; then
                # fall through to mark next echo as %ghost
                echo -n "%%ghost "
            fi
            ;;
%if %{usrmerged}
        boot/vmlinuz-*)
            echo -n "%%attr(0644, root, root) "
            ;;
%endif
        boot/symtypes*)
%if %{usrmerged}
            echo "%exclude $l"
%endif
            continue
            ;;
        esac
%if %{usrmerged}
        mv "$f" "./$l"
        ln -s "..$l" $f
        # the find in the CONFIG_MODULES condition below also finds the files
        # but there's sort -u later, so this is ok
        echo "$l" # note: must be first after case statement above
        echo "%%ghost /$f"
%else
        echo "%%attr(0644, root, root) /$f"
%endif
    done

    if [ %CONFIG_MODULES = y ]; then
	MODULES=%{lua: print(rpm.expand('%kernel_module_directory'):sub(2))}/%kernelrelease-%build_flavor
	find "$MODULES" \
%if 0%{?separate_vdso}
	    -path "$MODULES/vdso" -prune -o \
%endif
	    -type d -o \
	    \( -path '*/modules.*' ! -path '*/modules.order' \
	     ! -path '*/modules.builtin' \
	     ! -path '*/modules.builtin.modinfo' \) -printf '%%%%ghost /%%p\n' \
	       -o -name '*.ko' -prune \
	       -o \( -type f \
%if %{usrmerged}
		! -path '*/symtypes*' ! -path '*/vmlinu*' \
%endif
		\) -printf '/%%p\n'
	cat %my_builddir/base-modules
    fi
    if test %CONFIG_MODULE_SIG = "y" -a -d etc/uefi/certs; then
        find etc/uefi/certs -type f -printf '/%%p\n'
    fi
    if test -d lib/firmware/%kernelrelease-%build_flavor; then
        echo "%%dir /lib/firmware/%kernelrelease-%build_flavor"
        cat %my_builddir/base-firmware
    fi
    if [ -e .%_docdir/%name ]; then
	echo "%%doc %_docdir/%name"
    fi
} | sort -u | add_dirs_to_filelist >%my_builddir/kernel-base.files

{
    add_dirs_to_filelist %my_builddir/kernel-base.files
    if [ %CONFIG_MODULES = y ]; then
        add_dirs_to_filelist %my_builddir/main-modules
    fi
    if test -d %buildroot/lib/firmware/%kernelrelease-%build_flavor; then
	echo "/lib/firmware/%kernelrelease-%build_flavor"
    fi
} > %my_builddir/kernel-main.files

%if %split_extra
    add_dirs_to_filelist %my_builddir/unsupported-modules > %my_builddir/kernel-extra.files
%if %split_extra && %split_optional
    add_dirs_to_filelist %my_builddir/optional-modules > %my_builddir/kernel-optional.files
%endif

%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150000
    # By default, loading unsupported modules is disabled on SLE through
    # /etc/modprobe.d/10-unsupported-modules.conf from the suse-module-tools
    # package.
    # modules in kernel-$flavor-extra don't have the supported flag set,
    # yet loading them should be possible if the package is installed.
    # CAUTION PACKAGERS: The file content below must not change between
    # kernel versions, otherwise file conflicts might arise with
    # multiversion(kernel).

    modprobe_d_dir=/etc/modprobe.d
    %if 0%{?suse_version} > 1500 || 0%{?sle_version} > 150300
    modprobe_d_dir=/lib/modprobe.d
    %endif
    %if %{usrmerged}
    modprobe_d_dir=/usr/lib/modprobe.d
    %endif

    mkdir -p %buildroot$modprobe_d_dir
    cat >%buildroot$modprobe_d_dir/20-kernel-%{build_flavor}-extra.conf <<EOF
# This file overrides the default from 10-unsupported-modules.conf.
# This is necessary to load kernel modules from the
# kernel-%{build_flavor}-extra package.
#
# WARNING: loading unsupported modules may compromise SLE support.
# Please read the comments in 10-unsupported-modules.conf.
allow_unsupported_modules 1
EOF
    echo "%%dir $modprobe_d_dir" >> %my_builddir/kernel-extra.files
    echo "%%config(noreplace) $modprobe_d_dir/20-kernel-%{build_flavor}-extra.conf" >> %my_builddir/kernel-extra.files
%endif
%endif
for f in %my_builddir/*-kmp-modules; do
	f2=${f%%-modules}.files
	add_dirs_to_filelist "$f" >"$f2"
done

if [ %CONFIG_MODULES = y ]; then
  install -m 644 %_sourcedir/modules.fips %{buildroot}%modules_dir/modules.fips
  echo %modules_dir/modules.fips >> %my_builddir/kernel-base.files
  echo %modules_dir/modules.fips >> %my_builddir/kernel-main.files
fi

# Hardlink duplicate files automatically (from package fdupes): It doesn't save
# much, but it keeps rpmlint from breaking the package build. Note that we skip
# /usr/src/linux-obj intentionally, to not accidentally break timestamps there
%fdupes %buildroot%modules_dir

%changelog
* Fri Jun  6 2025 mfranc@suse.cz
- s390/pci: Prevent self deletion in disable_slot() (LTC#213760
  bsc#1244147 git-fixes).
- commit f657f8e
* Fri Jun  6 2025 tiwai@suse.de
- Move upstreamed patches into sorted section
- commit dd92279
* Fri Jun  6 2025 tiwai@suse.de
- drm/amd/display: Fix default DC and AC levels (bsc#1240650).
- drm/amd/display: Add debugging message for brightness caps
  (bsc#1240650).
- commit d85b918
* Fri Jun  6 2025 pfalcato@suse.de
- net: fix udp gso skb_segment after pull from frag_list
  (git-fixes).
- commit 4e1b517
* Fri Jun  6 2025 pfalcato@suse.de
- page_pool: Fix use-after-free in page_pool_recycle_in_ring
  (git-fixes).
- commit 829ed89
* Fri Jun  6 2025 tiwai@suse.de
- Drop AMDGPU patch that may cause regressions (bsc#1243782)
  Deleted:
  patches.suse/drm-amd-display-more-liberal-vmin-vmax-update-for-fr.patch
- commit ac81323
* Fri Jun  6 2025 tiwai@suse.de
- wifi: ath12k: Avoid memory leak while enabling statistics
  (CVE-2025-37743 bsc#1242163).
- Refresh
  patches.suse/wifi-ath12k-fix-the-ampdu-id-fetch-in-the-HAL_RX_MPD.patch.
- commit 378a151
* Fri Jun  6 2025 jgross@suse.com
- KVM: x86: Add infrastructure for secure TSC (jsc#PED-348).
- commit b436268
* Fri Jun  6 2025 jgross@suse.com
- KVM: x86: Push down setting vcpu.arch.user_set_tsc
  (jsc#PED-348).
- commit 166cd1c
* Fri Jun  6 2025 jgross@suse.com
- Update config files: add TDX host support
- commit 069ff6c
* Fri Jun  6 2025 tiwai@suse.de
- can: kvaser_pciefd: refine error prone echo_skb_max handling
  logic (git-fixes).
- commit a9840f5
* Fri Jun  6 2025 jgross@suse.com
- x86/virt/tdx: Remove the !KEXEC_CORE dependency (jsc#PED-348).
- commit 2f85d4e
* Fri Jun  6 2025 jgross@suse.com
- x86/kexec: Disable kexec/kdump on platforms with TDX partial
  write erratum (jsc#PED-348).
- commit 0956988
* Fri Jun  6 2025 jgross@suse.com
- x86/virt/tdx: Mark memory cache state incoherent when making
  SEAMCALL (jsc#PED-348).
- commit 3db11ae
* Fri Jun  6 2025 jgross@suse.com
- x86/sme: Use percpu boolean to control wbinvd during kexec
  (jsc#PED-348).
- commit 7c35fae
* Thu Jun  5 2025 tiwai@suse.de
- ASoC: SOF: Intel: hda: Fix UAF when reloading module
  (git-fixes).
- commit 0011189
* Thu Jun  5 2025 tiwai@suse.de
- Update
  patches.suse/driver-core-introduce-device_set_driver-helper.patch
  (stable-fixes CVE-2025-37800 bsc#1242849).
- commit 07a018e
* Thu Jun  5 2025 tiwai@suse.de
- soc: qcom: smp2p: Fix fallback to qcom,ipc parse (git-fixes).
- commit 18bbd46
* Thu Jun  5 2025 tiwai@suse.de
- wifi: mt76: mt7996: fix RX buffer size of MCU event (git-fixes).
- wifi: mt76: mt7996: set EHT max ampdu length capability
  (git-fixes).
- commit 6de50b9
* Thu Jun  5 2025 tiwai@suse.de
- wifi: mt76: mt7925: ensure all MCU commands wait for response
  (git-fixes).
- wifi: mt76: mt7925: refine the sniffer commnad (git-fixes).
- wifi: mt76: mt7925: prevent multiple scan commands (git-fixes).
- wifi: mt76: mt7915: Fix null-ptr-deref in mt7915_mmio_wed_init()
  (git-fixes).
- wifi: mt76: mt7996: Fix null-ptr-deref in mt7996_mmio_wed_init()
  (git-fixes).
- wifi: mt76: mt7925: fix host interrupt register initialization
  (git-fixes).
- Revert "wifi: mt76: mt7996: fill txd by host driver"
  (stable-fixes).
- wifi: ath9k_htc: Abort software beacon handling if disabled
  (git-fixes).
- wifi: ath12k: fix ring-buffer corruption (git-fixes).
- wifi: ath11k: fix rx completion meta data corruption
  (git-fixes).
- wifi: ath11k: fix ring-buffer corruption (git-fixes).
- wifi: p54: prevent buffer-overflow in p54_rx_eeprom_readback()
  (git-fixes).
- wifi: rtw89: fix firmware scan delay unit for WiFi 6 chips
  (git-fixes).
- wifi: rtw88: fix the 'para' buffer size to avoid reading out
  of bounds (git-fixes).
- wifi: rtw88: usb: Reduce control message timeout to 500 ms
  (git-fixes).
- wifi: rtw89: pci: enlarge retry times of RX tag to 1000
  (git-fixes).
- commit 063c386
* Thu Jun  5 2025 tiwai@suse.de
- wifi: rtlwifi: disable ASPM for RTL8723BE with subsystem ID
  11ad:1723 (git-fixes).
- wifi: rtw88: do not ignore hardware read error during DPK
  (git-fixes).
- wifi: rtw88: sdio: call rtw_sdio_indicate_tx_status
  unconditionally (git-fixes).
- wifi: rtw88: sdio: map mgmt frames to queue TX_DESC_QSEL_MGMT
  (git-fixes).
- wifi: iwlfiwi: mvm: Fix the rate reporting (git-fixes).
- wifi: ath12k: fix node corruption in ar->arvifs list
  (git-fixes).
- wifi: ath12k: Fix the QoS control field offset to build QoS
  header (git-fixes).
- wifi: ath12k: Add MSDU length validation for TKIP MIC error
  (git-fixes).
- wifi: ath12k: fix invalid access to memory (git-fixes).
- wifi: ath12k: Handle error cases during extended skb allocation
  (git-fixes).
- wifi: ath12k: Fix buffer overflow in debugfs (git-fixes).
- wifi: ath12k: Fix WMI tag for EHT rate in peer assoc
  (git-fixes).
- wifi: ath12k: fix cleanup path after mhi init (git-fixes).
- wifi: ath12k: Fix invalid memory access while forming 802.11
  header (git-fixes).
- wifi: ath12k: Fix memory leak during vdev_id mismatch
  (git-fixes).
- wifi: ath11k: fix node corruption in ar->arvifs list
  (git-fixes).
- wifi: iwlwifi: add support for Killer on MTL (stable-fixes).
- wifi: mt76: only mark tx-status-failed frames as ACKed on
  mt76x0/2 (stable-fixes).
- commit bf4f1c9
* Thu Jun  5 2025 tiwai@suse.de
- wifi: mt76: mt7996: fix SER reset trigger on WED reset
  (stable-fixes).
- wifi: mt76: mt7996: revise TXS size (stable-fixes).
- wifi: mt76: mt7925: load the appropriate CLC data based on
  hardware type (stable-fixes).
- wifi: mt76: mt7925: fix fails to enter low power mode in
  suspend state (stable-fixes).
- wifi: rtw89: set force HE TB mode when connecting to 11ax AP
  (stable-fixes).
- wifi: rtw88: Fix rtw_init_vht_cap() for RTL8814AU
  (stable-fixes).
- wifi: rtw88: Fix rtw_init_ht_cap() for RTL8814AU (stable-fixes).
- wifi: rtw88: Fix rtw_desc_to_mcsrate() to handle MCS16-31
  (stable-fixes).
- wifi: rtw89: fw: propagate error code from rtw89_h2c_tx()
  (stable-fixes).
- wifi: rtw89: fw: get sb_sel_ver via get_unaligned_le32()
  (stable-fixes).
- wifi: rtw89: fw: add blacklist to avoid obsolete secure firmware
  (stable-fixes).
- wifi: rtw89: 8922a: fix incorrect STA-ID in EHT MU PPDU
  (stable-fixes).
- wifi: mwifiex: Fix HT40 bandwidth issue (stable-fixes).
- wifi: iwlwifi: mvm: fix setting the TK when associated
  (stable-fixes).
- wifi: iwlwifi: don't warn when if there is a FW error
  (stable-fixes).
- wifi: iwlwifi: w/a FW SMPS mode selection (stable-fixes).
- wifi: iwlwifi: fix debug actions order (stable-fixes).
- wifi: iwlwifi: mark Br device not integrated (stable-fixes).
- wifi: iwlwifi: fix the ECKV UEFI variable name (stable-fixes).
- wifi: mac80211: fix warning on disconnect during failed ML
  reconf (stable-fixes).
- commit 19ba18c
* Thu Jun  5 2025 tiwai@suse.de
- vgacon: Add check for vc_origin address range in vgacon_scroll()
  (git-fixes).
- watchdog: exar: Shorten identity name to fit correctly
  (git-fixes).
- thermal/drivers/mediatek/lvts: Fix debugfs unregister on failure
  (git-fixes).
- spi: sh-msiof: Fix maximum DMA transfer size (git-fixes).
- spi: tegra210-quad: modify chip select (CS) deactivation
  (git-fixes).
- spi: tegra210-quad: remove redundant error handling code
  (git-fixes).
- spi: tegra210-quad: Fix X1_X2_X4 encoding and support x4
  transfers (git-fixes).
- spi: spi-sun4i: fix early activation (stable-fixes).
- thunderbolt: Do not add non-active NVM if NVM upgrade is
  disabled for retimer (stable-fixes).
- thermal/drivers/mediatek/lvts: Start sensor interrupts disabled
  (stable-fixes).
- thermal/drivers/qoriq: Power down TMU on system suspend
  (stable-fixes).
- watchdog: aspeed: fix 64-bit division (git-fixes).
- watchdog: aspeed: Update bootstatus handling (stable-fixes).
- tpm: Convert warn to dbg in tpm2_start_auth_session()
  (stable-fixes).
- wifi: mac80211_hwsim: Fix MLD address translation
  (stable-fixes).
- wifi: cfg80211: allow IR in 20 MHz configurations
  (stable-fixes).
- wifi: ath12k: Report proper tx completion status to mac80211
  (stable-fixes).
- wifi: ath12k: Improve BSS discovery with hidden SSID in 6 GHz
  band (stable-fixes).
- wifi: ath12k: fix the ampdu id fetch in the HAL_RX_MPDU_START
  TLV (stable-fixes).
- wifi: ath12k: Avoid napi_sync() before napi_enable()
  (stable-fixes).
- wifi: ath12k: fix ath12k_hal_tx_cmd_ext_desc_setup() info1
  override (stable-fixes).
- wifi: ath9k: return by of_get_mac_address (stable-fixes).
- wifi: ath12k: Fetch regdb.bin file from board-2.bin
  (stable-fixes).
- wifi: ath12k: Fix end offset bit definition in monitor ring
  descriptor (stable-fixes).
- wifi: ath11k: Use dma_alloc_noncoherent for rx_tid buffer
  allocation (stable-fixes).
- wifi: rtw88: Fix download_firmware_validate() for RTL8814AU
  (stable-fixes).
- wifi: rtw88: Fix __rtw_download_firmware() for RTL8814AU
  (stable-fixes).
- wifi: rtw89: coex: Assign value over than 0 to avoid firmware
  timer hang (stable-fixes).
- wifi: rtw89: fw: validate multi-firmware header before getting
  its size (stable-fixes).
- wifi: rtw89: fw: validate multi-firmware header before accessing
  (stable-fixes).
- wifi: rtw89: call power_on ahead before selecting firmware
  (stable-fixes).
- wifi: rtl8xxxu: retry firmware download on error (stable-fixes).
- wifi: rtw88: Don't use static local variable in
  rtw8822b_set_tx_power_index_by_rate (stable-fixes).
- wifi: rtw89: add wiphy_lock() to work that isn't held
  wiphy_lock() yet (stable-fixes).
- wifi: rtw89: coex: Separated Wi-Fi connecting event from Wi-Fi
  scan event (stable-fixes).
- wifi: iwlwifi: use correct IMR dump variable (stable-fixes).
- wifi: iwlwifi: don't warn during reprobe (stable-fixes).
- wifi: mac80211: don't unconditionally call drv_mgd_complete_tx()
  (stable-fixes).
- wifi: mac80211: remove misplaced drv_mgd_complete_tx() call
  (stable-fixes).
- wifi: mac80211: set ieee80211_prep_tx_info::link_id upon Auth Rx
  (stable-fixes).
- commit 8e68f8c
* Thu Jun  5 2025 tiwai@suse.de
- selftests/mm: restore default nr_hugepages value during cleanup
  in hugetlb_reparenting_test.sh (git-fixes).
- soc: aspeed: Add NULL check in aspeed_lpc_enable_snoop()
  (git-fixes).
- soc: aspeed: lpc: Fix impossible judgment condition (git-fixes).
- soc: qcom: pmic_glink_altmode: fix spurious DP hotplug events
  (git-fixes).
- selftests/bpf: Fix caps for __xlated/jited_unpriv (git-fixes).
- selftests/bpf: Fix bpf_nf selftest failure (git-fixes).
- selinux: unify OOM handling in network hashtables (git-fixes).
- selftests/seccomp: fix negative_ENOSYS tracer tests on arm32
  (git-fixes).
- selftests/seccomp: fix syscall_restart test for arm compat
  (git-fixes).
- power: reset: at91-reset: Optimize at91_reset() (git-fixes).
- regulator: max20086: Change enable gpio to optional (git-fixes).
- regulator: max20086: Fix MAX200086 chip id (git-fixes).
- kselftest: cpufreq: Get rid of double suspend in rtcwake case
  (git-fixes).
- spi-rockchip: Fix register out of bounds access (stable-fixes).
- rtc: rv3032: fix EERD location (stable-fixes).
- rtc: ds1307: stop disabling alarms on probe (stable-fixes).
- serial: sh-sci: Save and restore more registers (git-fixes).
- serial: sh-sci: Update the suspend/resume support
  (stable-fixes).
- soundwire: amd: change the soundwire wake enable/disable
  sequence (stable-fixes).
- soundwire: cadence_master: set frame shape and divider based
  on actual clk freq (stable-fixes).
- power: supply: axp20x_battery: Update temp sensor for AXP717
  from device tree (stable-fixes).
- soc: ti: k3-socinfo: Do not use syscon helper to build regmap
  (stable-fixes).
- soc: samsung: include linux/array_size.h where needed
  (stable-fixes).
- soc: mediatek: mtk-mutex: Add DPI1 SOF/EOF to MT8188 mutex
  tables (stable-fixes).
- selftests/net: have `gro.sh -t` return a correct exit code
  (stable-fixes).
- spi: spi-mux: Fix coverity issue, unchecked return value
  (stable-fixes).
- spi: zynqmp-gqspi: Always acknowledge interrupts (stable-fixes).
- regulator: ad5398: Add device tree support (stable-fixes).
- commit 6feee74
* Thu Jun  5 2025 tiwai@suse.de
- pinctrl: armada-37xx: set GPIO output value before setting
  direction (git-fixes).
- pinctrl: armada-37xx: use correct OUTPUT_VAL register for
  GPIOs > 31 (git-fixes).
- pinctrl: at91: Fix possible out-of-boundary access (git-fixes).
- PM: sleep: Print PM debug messages during hibernation
  (git-fixes).
- PM: wakeup: Delete space in the end of string shown by
  pm_show_wakelocks() (git-fixes).
- PM: EM: Fix potential division-by-zero error in
  em_compute_costs() (git-fixes).
- pinctrl: qcom: switch to devm_register_sys_off_handler()
  (git-fixes).
- phy: renesas: rcar-gen3-usb2: Assert PLL reset on PHY power off
  (git-fixes).
- phy: renesas: rcar-gen3-usb2: Lock around hardware registers
  and driver data (git-fixes).
- pinctrl: meson: define the pull up/down resistor value as 60
  kOhm (stable-fixes).
- pinctrl: tegra: Fix off by one in tegra_pinctrl_get_group()
  (git-fixes).
- pinctrl-tegra: Restore SFSEL bit when freeing pins
  (stable-fixes).
- pinctrl: bcm281xx: Use "unsigned int" instead of bare "unsigned"
  (stable-fixes).
- pinctrl: renesas: rzg2l: Add suspend/resume support for pull
  up/down (stable-fixes).
- pinctrl: sophgo: avoid to modify untouched bit when setting
  cv1800 pinconf (stable-fixes).
- pinctrl: devicetree: do not goto err when probing hogs in
  pinctrl_dt_to_map (stable-fixes).
- PNP: Expand length of fixup id string (stable-fixes).
- commit 30aa389
* Thu Jun  5 2025 tiwai@suse.de
- PCI: rcar-gen4: set ep BAR4 fixed size (git-fixes).
- PCI: dwc: ep: Fix errno typo (git-fixes).
- PCI: dw-rockchip: Fix PHY function call sequence in
  rockchip_pcie_phy_deinit() (git-fixes).
- PCI: dw-rockchip: Remove PCIE_L0S_ENTRY check from
  rockchip_pcie_link_up() (git-fixes).
- PCI: cadence: Fix runtime atomic count underflow (git-fixes).
- PCI: apple: Use gpiod_set_value_cansleep in probe flow
  (git-fixes).
- PCI: cadence-ep: Correct PBA offset in .set_msix() callback
  (git-fixes).
- PCI: dwc: ep: Correct PBA offset in .set_msix() callback
  (git-fixes).
- PCI: Fix lock symmetry in pci_slot_unlock() (git-fixes).
- PCI: Explicitly put devices into D0 when initializing
  (git-fixes).
- PCI/ACPI: Fix allocated memory release on error in
  pci_acpi_scan_root() (git-fixes).
- PCI: Print the actual delay time in
  pci_bridge_wait_for_secondary_bus() (git-fixes).
- PCI/DPC: Log Error Source ID only when valid (git-fixes).
- PCI/DPC: Initialize aer_err_info before using it (git-fixes).
- phy: renesas: rcar-gen3-usb2: Move IRQ request in probe
  (stable-fixes).
- phy: phy-rockchip-samsung-hdptx: Fix PHY PLL output 50.25MHz
  error (stable-fixes).
- phy: starfive: jh7110-usb: Fix USB 2.0 host occasional detection
  failure (stable-fixes).
- phy: rockchip: usbdp: Only verify link rates/lanes/voltage
  when the corresponding set flags are set (stable-fixes).
- phy: phy-rockchip-samsung-hdptx: Swap the definitions of
  LCPLL_REF and ROPLL_REF (stable-fixes).
- phy: core: don't require set_mode() callback for phy_get_mode()
  to work (stable-fixes).
- phy: exynos5-usbdrd: fix EDS distribution tuning (gs101)
  (stable-fixes).
- PCI: dwc: ep: Ensure proper iteration over outbound map windows
  (stable-fixes).
- PCI: dwc: Use resource start as ioremap() input in
  dw_pcie_pme_turn_off() (stable-fixes).
- PCI: brcmstb: Expand inbound window size up to 64GB
  (stable-fixes).
- PCI: brcmstb: Add a softdep to MIP MSI-X driver (stable-fixes).
- PCI: epf-mhi: Update device ID for SA8775P (stable-fixes).
- PCI: endpoint: pci-epf-test: Fix double free that causes kernel
  to oops (stable-fixes).
- PCI: Fix old_size lower bound in calculate_iosize() too
  (stable-fixes).
- PCI: vmd: Disable MSI remapping bypass under Xen (stable-fixes).
- commit 697d499
* Thu Jun  5 2025 tiwai@suse.de
- mfd: stmpe-spi: Correct the name used in MODULE_DEVICE_TABLE
  (git-fixes).
- mfd: exynos-lpass: Avoid calling exynos_lpass_disable() twice
  in exynos_lpass_remove() (git-fixes).
- mfd: exynos-lpass: Fix an error handling path in
  exynos_lpass_probe() (git-fixes).
- mtd: rawnand: brcmnand: legacy exec_op implementation
  (git-fixes).
- mtd: rawnand: sunxi: Add randomizer configuration in
  sunxi_nfc_hw_ecc_write_chunk (git-fixes).
- mtd: nand: sunxi: Add randomizer configuration before randomizer
  enable (git-fixes).
- mtd: spinand: esmt: fix id code for F50D1G41LB (git-fixes).
- mtd: rawnand: qcom: Fix read len for onfi param page
  (git-fixes).
- mtd: nand: ecc-mxic: Fix use of uninitialized variable ret
  (git-fixes).
- net: phy: mscc: Stop clearing the the UDPv4 checksum for L2
  frames (git-fixes).
- net: phy: mscc: Fix memory leak when using one step timestamping
  (git-fixes).
- net: phy: clear phydev->devlink when the link is deleted
  (git-fixes).
- net: phy: fix up const issues in to_mdio_device() and
  to_phy_device() (git-fixes).
- media: verisilicon: Free post processor buffers on error
  (git-fixes).
- mei: vsc: Use struct vsc_tp_packet as vsc-tp tx_buf and rx_buf
  type (stable-fixes).
- mfd: tps65219: Remove TPS65219_REG_TI_DEV_ID check
  (stable-fixes).
- mfd: axp20x: AXP717: Add AXP717_TS_PIN_CFG to writeable regs
  (stable-fixes).
- net: phy: nxp-c45-tja11xx: add match_phy_device to
  TJA1103/TJA1104 (stable-fixes).
- commit 80f0e45
* Thu Jun  5 2025 tiwai@suse.de
- media: uvcvideo: Fix deferred probing error (git-fixes).
- media: uvcvideo: Send control events for partial succeeds
  (git-fixes).
- media: uvcvideo: Return the number of processed controls
  (git-fixes).
- media: omap3isp: use sgtable-based scatterlist wrappers
  (git-fixes).
- media: videobuf2: use sgtable-based scatterlist wrappers
  (git-fixes).
- media: v4l2-dev: fix error handling in __video_register_device()
  (git-fixes).
- media: i2c: imx335: Fix frame size enumeration (git-fixes).
- media: ov8856: suppress probe deferral errors (git-fixes).
- media: ov5675: suppress probe deferral errors (git-fixes).
- media: imx335: Use correct register width for HNUM (git-fixes).
- media: nxp: imx8-isi: better handle the m2m usage_count
  (git-fixes).
- media: gspca: Add error handling for stv06xx_read_sensor()
  (git-fixes).
- media: davinci: vpif: Fix memory leak in probe error path
  (git-fixes).
- media: vivid: Change the siize of the composing (git-fixes).
- media: cxusb: no longer judge rbuf when the write fails
  (git-fixes).
- media: vidtv: Terminating the subsequent process of
  initialization failure (git-fixes).
- media: intel/ipu6: Fix dma mask for non-secure mode (git-fixes).
- media: ov2740: Move pm-runtime cleanup on probe-errors to
  proper place (git-fixes).
- media: ccs-pll: Correct the upper limit of maximum
  op_pre_pll_clk_div (git-fixes).
- media: ccs-pll: Check for too high VT PLL multiplier in dual
  PLL case (git-fixes).
- media: ccs-pll: Start VT pre-PLL multiplier search from correct
  value (git-fixes).
- media: ccs-pll: Start OP pre-PLL multiplier search from correct
  value (git-fixes).
- media: ipu6: Remove workaround for Meteor Lake ES2 (git-fixes).
- media: i2c: ds90ub913: Fix returned fmt from .set_fmt()
  (git-fixes).
- media: imx-jpeg: Cleanup after an allocation error (git-fixes).
- media: imx-jpeg: Reset slot data pointers when freed
  (git-fixes).
- media: imx-jpeg: Move mxc_jpeg_free_slot_data() ahead
  (git-fixes).
- media: imagination: fix a potential memory leak in e5010_probe()
  (git-fixes).
- media: imx-jpeg: Drop the first error frames (git-fixes).
- media: venus: Fix probe error handling (git-fixes).
- media: mediatek: vcodec: Correct vsi_core framebuffer size
  (git-fixes).
- media: rkvdec: Fix frame size enumeration (git-fixes).
- media: c8sectpfe: Call of_node_put(i2c_bus) only once in
  c8sectpfe_probe() (stable-fixes).
- media: cx231xx: set device_caps for 417 (stable-fixes).
- media: imx335: Set vblank immediately (stable-fixes).
- media: uvcvideo: Add sanity check to uvc_ioctl_xu_ctrl_map
  (stable-fixes).
- media: uvcvideo: Handle uvc menu translation inside
  uvc_get_le_value (stable-fixes).
- media: adv7180: Disable test-pattern control on adv7180
  (stable-fixes).
- media: tc358746: improve calculation of the D-PHY timing
  registers (stable-fixes).
- media: test-drivers: vivid: don't call schedule in loop
  (stable-fixes).
- commit 0c12415
* Thu Jun  5 2025 tiwai@suse.de
- Input: ims-pcu - check record size in ims_pcu_flash_firmware()
  (git-fixes).
- Input: gpio-keys - fix possible concurrent access in
  gpio_keys_irq_timer() (git-fixes).
- mailbox: mtk-cmdq: Refine GCE_GCTL_VALUE setting (git-fixes).
- mailbox: imx: Fix TXDB_V2 sending (git-fixes).
- intel_th: avoid using deprecated page->mapping, index fields
  (stable-fixes).
- ima: process_measurement() needlessly takes inode_lock()
  on MAY_READ (stable-fixes).
- i3c: master: svc: Fix implicit fallthrough in
  svc_i3c_master_ibi_work() (git-fixes).
- i3c: master: svc: Fix missing STOP for master request
  (stable-fixes).
- i3c: master: svc: Flush FIFO before sending Dynamic Address
  Assignment(DAA) (stable-fixes).
- i2c: qup: Vote for interconnect bandwidth to DRAM
  (stable-fixes).
- i2c: pxa: fix call balance of i2c->clk handling routines
  (stable-fixes).
- iio: adc: ad7944: don't use storagebits for sizing
  (stable-fixes).
- mailbox: use error ret code of of_parse_phandle_with_args()
  (stable-fixes).
- leds: pwm-multicolor: Add check for fwnode_property_read_u32
  (stable-fixes).
- leds: trigger: netdev: Configure LED blink interval for HW
  offload (stable-fixes).
- ieee802154: ca8210: Use proper setters and getters for bitwise
  types (stable-fixes).
- media: i2c: imx219: Correct the minimum vblanking value
  (stable-fixes).
- media: v4l: Memset argument to 0 before calling get_mbus_config
  pad op (stable-fixes).
- media: qcom: camss: csid: Only add TPG v4l2 ctrl if TPG hardware
  is available (stable-fixes).
- media: qcom: camss: Add default case in vfe_src_pad_code
  (stable-fixes).
- commit 71b3876
* Thu Jun  5 2025 tiwai@suse.de
- hwmon: (asus-ec-sensors) check sensor index in read_string()
  (git-fixes).
- gpiolib: Revert "Don't WARN on gpiod_put() for optional GPIO"
  (stable-fixes).
- gpio: virtuser: fix potential out-of-bound write (stable-fixes).
- HID: quirks: Add ADATA XPG alpha wireless mouse support
  (stable-fixes).
- fpga: altera-cvp: Increase credit timeout (stable-fixes).
- HID: usbkbd: Fix the bit shift number for LED_KANA
  (stable-fixes).
- hwmon: (dell-smm) Increment the number of fans (stable-fixes).
- hwmon: (gpio-fan) Add missing mutex locks (stable-fixes).
- hwmon: (xgene-hwmon) use appropriate type for the latency value
  (stable-fixes).
- commit 3023def
* Thu Jun  5 2025 tiwai@suse.de
- EDAC/altera: Use correct write width with the INTTEST register
  (git-fixes).
- fbdev: Fix fb_set_var to prevent null-ptr-deref in
  fb_videomode_to_var (git-fixes).
- fbdev: Fix do_register_framebuffer to prevent null-ptr-deref
  in fb_videomode_to_var (git-fixes).
- fbdev: core: fbcvt: avoid division by 0 in fb_cvt_hperiod()
  (git-fixes).
- firmware: arm_scmi: Ensure that the message-id supports
  fastchannel (git-fixes).
- efi/libstub: Describe missing 'out' parameter in efi_load_initrd
  (git-fixes).
- firmware: psci: Fix refcount leak in psci_dt_init (git-fixes).
- drm/msm/a6xx: Disable rgb565_predicator on Adreno 7c3
  (git-fixes).
- drm/msm/gpu: Fix crash when throttling GPU immediately during
  boot (git-fixes).
- drm/msm/dpu: enable SmartDMA on SC8180X (git-fixes).
- drm/msm/dpu: enable SmartDMA on SM8150 (git-fixes).
- drm/mediatek: mtk_drm_drv: Unbind secondary mmsys components
  on err (git-fixes).
- drm/mediatek: Fix kobject put for component sub-drivers
  (git-fixes).
- drm/mediatek: mtk_drm_drv: Fix kobject put for mtk_mutex device
  ptr (git-fixes).
- Revert "drm/amdgpu: don't allow userspace to create a doorbell
  BO" (stable-fixes).
- drm/amd/pp: Fix potential NULL pointer dereference in
  atomctrl_initialize_mc_reg_table (git-fixes).
- EDAC/skx_common: Fix general protection fault (git-fixes).
- eeprom: ee1004: Check chip before probing (stable-fixes).
- fbdev: fsl-diu-fb: add missing device_remove_file()
  (stable-fixes).
- fbcon: Use correct erase colour for clearing in fbcon
  (stable-fixes).
- fbdev: core: tileblit: Implement missing margin clearing for
  tileblit (stable-fixes).
- firmware: xilinx: Dont send linux address to get fpga config
  get status (stable-fixes).
- firmware: arm_ffa: Set dma_mask for ffa devices (stable-fixes).
- firmware: arm_ffa: Reject higher major version as incompatible
  (stable-fixes).
- firmware: arm_ffa: Handle the presence of host partition in
  the partition info (stable-fixes).
- firmware: arm_scmi: Relax duplicate name constraint across
  protocol ids (stable-fixes).
- commit 1c0c86d
* Thu Jun  5 2025 tiwai@suse.de
- drm/tegra: Fix a possible null pointer dereference (git-fixes).
- drm/tegra: rgb: Fix the unbound reference count (git-fixes).
- drm/tegra: Assign plane type before registration (git-fixes).
- drm/vkms: Adjust vkms_state->active_planes allocation type
  (git-fixes).
- drm: rcar-du: Fix memory leak in rcar_du_vsps_init()
  (git-fixes).
- drm/bridge: lt9611uxc: Fix an error handling path in
  lt9611uxc_probe() (git-fixes).
- drm/panel: samsung-sofef00: Drop s6e3fc2x01 support (git-fixes).
- drm/panthor: Update panthor_mmu::irq::mask when needed
  (git-fixes).
- drm/panthor: Fix GPU_COHERENCY_ACE[_LITE] definitions
  (git-fixes).
- drm/ast: Fix comment on modeset lock (git-fixes).
- drm/vc4: tests: Use return instead of assert (git-fixes).
- drm/bridge: cdns-dsi: Wait for Clk and Data Lanes to be ready
  (git-fixes).
- drm/bridge: cdns-dsi: Check return value when getting default
  PHY config (git-fixes).
- drm/bridge: cdns-dsi: Fix the clock variable for mode_valid()
  (git-fixes).
- drm/bridge: cdns-dsi: Fix phy de-init and flag it so
  (git-fixes).
- drm/bridge: cdns-dsi: Fix connecting to next bridge (git-fixes).
- drm/panic: add missing space (git-fixes).
- drm/udl: Unregister device before cleaning up on disconnect
  (git-fixes).
- drm/vmwgfx: Fix dumb buffer leak (git-fixes).
- drm/vmwgfx: Add error path for xa_store in
  vmw_bo_add_detached_resource (git-fixes).
- commit a60f216
* Thu Jun  5 2025 tiwai@suse.de
- drm/amd/display: Configure DTBCLK_P with OPTC only for dcn401
  (stable-fixes).
- Refresh
  patches.suse/drm-amd-display-prevent-hang-on-link-training-fail.patch.
- commit 16ba726
* Thu Jun  5 2025 tiwai@suse.de
- docs: dt: Update overlay file extension (git-fixes).
- drm/vmwgfx: Add seqno waiter for sync_files (git-fixes).
- drm/xe/d3cold: Set power state to D3Cold during s2idle/s3
  (git-fixes).
- Documentation: ACPI: Use all-string data node references
  (git-fixes).
- docs: doc-guide: clarify latest theme usage (git-fixes).
- Documentation/scheduler: Fix typo in sched-stats domain field
  description (git-fixes).
- Documentation/rtla: Fix typo in common_timerlat_description.rst
  (git-fixes).
- Documentation/rtla: Fix typo in rtla-timerlat.rst (git-fixes).
- Documentation/rtla: Fix duplicate text about timerlat tracer
  (git-fixes).
- crypto: api - Redo lookup on EEXIST (git-fixes).
- crypto: marvell/cesa - Do not chain submitted requests
  (git-fixes).
- crypto: sun8i-ce - move fallback ahash_request to the end of
  the struct (git-fixes).
- crypto: xts - Only add ecb if it is not already there
  (git-fixes).
- crypto: lrw - Only add ecb if it is not already there
  (git-fixes).
- crypto: marvell/cesa - Avoid empty transfer descriptor
  (git-fixes).
- crypto: marvell/cesa - Handle zero-length skcipher requests
  (git-fixes).
- crypto: sun8i-ce - undo runtime PM changes during driver removal
  (git-fixes).
- crypto: sun8i-ss - do not use sg_dma_len before calling DMA
  functions (git-fixes).
- crypto: sun8i-ce-cipher - fix error handling in
  sun8i_ce_cipher_prepare() (git-fixes).
- dmaengine: idxd: cdev: Fix uninitialized use of sva in
  idxd_cdev_open (stable-fixes).
- drm/xe: Save the gt pointer in lrc and drop the tile
  (stable-fixes).
- drm/xe/xe2hpg: Add Wa_22021007897 (stable-fixes).
- drm/amd/display: check stream id dml21 wrapper to get plane_id
  (stable-fixes).
- drm/amd/display: fix link_set_dpms_off multi-display MST corner
  case (stable-fixes).
- drm/amd/display: Defer BW-optimization-blocked DRR adjustments
  (git-fixes).
- drm/amd/display: Call FP Protect Before Mode Programming/Mode
  Support (stable-fixes).
- drm/amdgpu: Allow P2P access through XGMI (stable-fixes).
- drm/amdgpu/discovery: check ip_discovery fw file available
  (stable-fixes).
- drm/amdkfd: set precise mem ops caps to disabled for gfx 11
  and 12 (stable-fixes).
- drm/amdgpu: Skip pcie_replay_count sysfs creation for VF
  (stable-fixes).
- drm/amdgpu: release xcp_mgr on exit (stable-fixes).
- drm/amd/display: Guard against setting dispclk low for dcn31x
  (stable-fixes).
- drm/amdgpu: adjust drm_firmware_drivers_only() handling
  (stable-fixes).
- drm/amdkfd: Correct F8_MODE for gfx950 (git-fixes).
- drm/amdgpu/gfx12: don't read registers in mqd init
  (stable-fixes).
- drm/amdgpu/gfx11: don't read registers in mqd init
  (stable-fixes).
- drm/amdgpu: Fix the race condition for draining retry fault
  (stable-fixes).
- drm/amdgpu: Update SRIOV video codec caps (stable-fixes).
- drm/amd/display: remove minimum Dispclk and apply oem panel
  timing (stable-fixes).
- drm/amd/display: Correct timing_adjust_pending flag setting
  (stable-fixes).
- drm/amd/display: calculate the remain segments for all pipes
  (stable-fixes).
- drm/amd/display: not abort link train when bw is low
  (stable-fixes).
- drm/amd/display: Do not enable replay when vtotal update is
  pending (stable-fixes).
- drm/amd/display: Fix incorrect DPCD configs while Replay/PSR
  switch (stable-fixes).
- drm/mediatek: mtk_dpi: Add checks for reg_h_fre_con existence
  (stable-fixes).
- drm/xe: Nuke VM's mapping upon close (stable-fixes).
- drm/xe: Retry BO allocation (stable-fixes).
- drm/xe/vf: Retry sending MMIO request to GUC on timeout error
  (stable-fixes).
- drm/xe/pf: Create a link between PF and VF devices
  (stable-fixes).
- drm/xe: xe_gen_wa_oob: replace program_invocation_short_name
  (stable-fixes).
- drm/amdkfd: Set per-process flags only once for gfx9/10/11/12
  (stable-fixes).
- drm/amdkfd: Set per-process flags only once cik/vi
  (stable-fixes).
- drm/amdgpu: Fix missing drain retry fault the last entry
  (stable-fixes).
- drm/amdgpu: Do not program AGP BAR regs under SRIOV in
  gfxhub_v1_0.c (stable-fixes).
- drm/amd/display: Ensure DMCUB idle before reset on DCN31/DCN35
  (stable-fixes).
- drm/amd/display: Skip checking FRL_MODE bit for PCON BW
  determination (stable-fixes).
- drm/amd/display: Fix DMUB reset sequence for DCN401
  (stable-fixes).
- drm/amd/display: Fix p-state type when p-state is unsupported
  (stable-fixes).
- drm/amd/display: Request HW cursor on DCN3.2 with SubVP
  (stable-fixes).
- drm/amdkfd: KFD release_work possible circular locking
  (stable-fixes).
- drm/amd/display: handle max_downscale_src_width fail check
  (stable-fixes).
- drm/amd/display: fix dcn4x init failed (stable-fixes).
- drm/amdgpu: remove all KFD fences from the BO on release
  (stable-fixes).
- drm/rockchip: vop2: Add uv swap for cluster window
  (stable-fixes).
- drm/xe/oa: Ensure that polled read returns latest data
  (stable-fixes).
- drm/xe: Stop ignoring errors from xe_ttm_stolen_mgr_init()
  (stable-fixes).
- drm/xe: Fix xe_tile_init_noalloc() error propagation
  (stable-fixes).
- drm/xe/debugfs: fixed the return value of wedged_mode_set
  (stable-fixes).
- drm/xe/debugfs: Add missing xe_pm_runtime_put in wedge_mode_set
  (stable-fixes).
- drm/xe/relay: Don't use GFP_KERNEL for new transactions
  (stable-fixes).
- drm/xe/pf: Reset GuC VF config when unprovisioning critical
  resource (stable-fixes).
- drm/xe: Move suballocator init to after display init
  (stable-fixes).
- drm/xe: Do not attempt to bootstrap VF in execlists mode
  (stable-fixes).
- drm/xe/sa: Always call drm_suballoc_manager_fini()
  (stable-fixes).
- drm/xe: Reject BO eviction if BO is bound to current VM
  (stable-fixes).
- drm/amd/pm: Fetch current power limit from PMFW (stable-fixes).
- drm/amd/display: Add support for disconnected eDP streams
  (stable-fixes).
- drm/amd/display: Guard against setting dispclk low when active
  (stable-fixes).
- drm/amd/display: Fix BT2020 YCbCr limited/full range input
  (stable-fixes).
- drm/amd/display: Read LTTPR ALPM caps during link cap retrieval
  (stable-fixes).
- drm/amd/display: Don't treat wb connector as physical in
  create_validate_stream_for_sink (stable-fixes).
- drm/amdgpu/mes11: fix set_hw_resources_1 calculation
  (stable-fixes).
- drm/amdkfd: fix missing L2 cache info in topology
  (stable-fixes).
- drm/amdgpu: Set snoop bit for SDMA for MI series (stable-fixes).
- drm/amd/display: pass calculated dram_speed_mts to dml2
  (stable-fixes).
- drm/amd/display: Don't try AUX transactions on disconnected link
  (stable-fixes).
- drm/amdgpu: reset psp->cmd to NULL after releasing the buffer
  (stable-fixes).
- drm/amd/pm: Skip P2S load for SMU v13.0.12 (stable-fixes).
- drm/amd/display: Support multiple options during psr entry
  (stable-fixes).
- drm/amd/display: Update CR AUX RD interval interpretation
  (stable-fixes).
- drm/amd/display: Initial psr_version with correct setting
  (stable-fixes).
- drm/amd/display: Increase block_sequence array size
  (stable-fixes).
- drm/amd/display: Use Nominal vBlank If Provided Instead Of
  Capping It (stable-fixes).
- drm/amd/display: Populate register address for dentist for
  dcn401 (stable-fixes).
- drm/amdgpu: Use active umc info from discovery (stable-fixes).
- drm/amdgpu: enlarge the VBIOS binary size limit (stable-fixes).
- drm/amd/display/dm: drop hw_support check in
  amdgpu_dm_i2c_xfer() (stable-fixes).
- drm/v3d: Add clock handling (stable-fixes).
- drm/rockchip: vop2: Improve display modes handling on RK3588
  HDMI0 (stable-fixes).
- drm/ast: Find VBIOS mode from regular display size
  (stable-fixes).
- drm: bridge: adv7511: fill stream capabilities (stable-fixes).
- drm/nouveau: fix the broken marco GSP_MSG_MAX_SIZE
  (stable-fixes).
- drm/atomic: clarify the rules around
  drm_atomic_state->allow_modeset (stable-fixes).
- drm/buddy: fix issue that force_merge cannot free all roots
  (stable-fixes).
- drm/panel-edp: Add Starry 116KHD024006 (stable-fixes).
- drm: Add valid clones check (stable-fixes).
- commit 88828d8
* Thu Jun  5 2025 tiwai@suse.de
- crypto: sun8i-ce-hash - fix error handling in
  sun8i_ce_hash_run() (git-fixes).
- can: kvaser_pciefd: Continue parsing DMA buf after dropped RX
  (stable-fixes).
- can: kvaser_pciefd: Fix echo_skb race (stable-fixes).
- char: tpm: tpm-buf: Add sanity check fallback in read helpers
  (stable-fixes).
- crypto: octeontx2 - suppress auth failure screaming due to
  negative tests (stable-fixes).
- crypto: lzo - Fix compression buffer overrun (stable-fixes).
- crypto: mxs-dcp - Only set OTP_KEY bit for OTP key
  (stable-fixes).
- crypto: skcipher - Zap type in crypto_alloc_sync_skcipher
  (stable-fixes).
- commit a9645bd
* Thu Jun  5 2025 tiwai@suse.de
- backlight: pm8941: Add NULL check in wled_configure()
  (git-fixes).
- bus: fsl-mc: fix GET/SET_TAILDROP command ids (git-fixes).
- bus: fsl-mc: do not add a device-link for the UAPI used DPMCP
  device (git-fixes).
- bus: fsl-mc: fix double-free on mc_dev (git-fixes).
- Revert "bus: ti-sysc: Probe for l4_wkup and l4_cfg interconnect
  devices first" (stable-fixes).
- Bluetooth: btintel: Check dsbr size from EFI variable
  (git-fixes).
- Bluetooth: MGMT: iterate over mesh commands in
  mgmt_mesh_foreach() (git-fixes).
- ASoC: qcom: sdm845: Add error handling in
  sdm845_slim_snd_hw_params() (git-fixes).
- ASoC: apple: mca: Constrain channels according to TDM mask
  (git-fixes).
- ASoC: amd: sof_amd_sdw: Fix unlikely uninitialized variable
  use in create_sdw_dailinks() (git-fixes).
- ASoC: SOF: amd: add missing acp descriptor field (git-fixes).
- ASoC: SOF: ipc4-pcm: Adjust pipeline_list->pipelines allocation
  type (git-fixes).
- ASoC: meson: meson-card-utils: use of_property_present()
  for DT parsing (git-fixes).
- Bluetooth: btmtksdio: Do close if SDIO card removed without
  close (git-fixes).
- Bluetooth: btmtksdio: Check function enabled before doing close
  (git-fixes).
- Bluetooth: btmtksdio: Prevent enabling interrupts after IRQ
  handler removal (stable-fixes).
- Bluetooth: Disable SCO support if READ_VOICE_SETTING is
  unsupported/broken (stable-fixes).
- can: c_can: Use of_property_present() to test existence of DT
  property (stable-fixes).
- commit 8fe3f19
* Thu Jun  5 2025 tiwai@suse.de
- ASoC: mediatek: mt8195: Set ETDM1/2 IN/OUT to COMP_DUMMY()
  (git-fixes).
- ASoC: tas2764: Enable main IRQs (git-fixes).
- ASoC: tas2764: Reinit cache on part reset (git-fixes).
- ASoC: intel/sdw_utils: Add volume limit to cs42l43 speakers
  (stable-fixes).
- ASoC: Intel: bytcr_rt5640: Add DMI quirk for Acer Aspire SW3-013
  (stable-fixes).
- ASoC: cs42l43: Disable headphone clamps during type detection
  (stable-fixes).
- ASoC: imx-card: Adjust over allocation of memory in
  imx_card_parse_of() (stable-fixes).
- ASoC: codecs: wsa884x: Correct VI sense channel mask
  (stable-fixes).
- ASoC: codecs: wsa883x: Correct VI sense channel mask
  (stable-fixes).
- commit 86bb694
* Thu Jun  5 2025 tiwai@suse.de
- ALSA: hda/realtek: Add quirk for Lenovo Yoga Pro 7 14ASP10
  (stable-fixes).
- ALSA: hda/realtek - restore auto-mute mode for Dell Chrome
  platform (stable-fixes).
- ALSA: pcm: Fix race of buffer access at PCM OSS layer
  (stable-fixes).
- ALSA: usb-audio: Fix duplicated name in MIDI substream names
  (stable-fixes).
- ALSA: hda/realtek: Add quirk for HP Spectre x360 15-df1xxx
  (stable-fixes).
- ASoC: pcm6240: Drop bogus code handling IRQ as GPIO
  (stable-fixes).
- ASoC: mediatek: mt6359: Add stub for
  mt6359_accdet_enable_jack_detect (stable-fixes).
- ASoC: sun4i-codec: support hp-det-gpios property (stable-fixes).
- ASoC: qcom: sm8250: explicitly set format in
  sm8250_be_hw_params_fixup() (stable-fixes).
- ASoC: mediatek: mt8188: Treat DMIC_GAINx_CUR as non-volatile
  (stable-fixes).
- ASoC: mediatek: mt8188: Add reference for dmic clocks
  (stable-fixes).
- ASoC: soc-dai: check return value at snd_soc_dai_set_tdm_slot()
  (stable-fixes).
- ASoC: tas2764: Add reg defaults for TAS2764_INT_CLK_CFG
  (stable-fixes).
- ASoC: tas2764: Mark SW_RESET as volatile (stable-fixes).
- ASoC: tas2764: Power up/down amp on mute ops (stable-fixes).
- ASoC: ops: Enforce platform maximum on initial value
  (stable-fixes).
- ASoC: codecs: pcm3168a: Allow for 24-bit in provider mode
  (stable-fixes).
- ASoC: rt722-sdca: Add some missing readable registers
  (stable-fixes).
- ALSA: seq: Improve data consistency at polling (stable-fixes).
- commit 08338b9
* Thu Jun  5 2025 tiwai@suse.de
- kABI workaround for hda_codec.beep_just_power_on flag
  (git-fixes).
- commit 2932a2f
* Thu Jun  5 2025 tiwai@suse.de
- acpi-cpufreq: Fix nominal_freq units to KHz in
  get_max_boost_ratio() (git-fixes).
- ACPI: resource: fix a typo for MECHREVO in
  irq1_edge_low_force_override[] (git-fixes).
- ACPICA: Utilities: Fix spelling mistake "Incremement" ->
  "Increment" (git-fixes).
- ACPICA: exserial: don't forget to handle FFixedHW opregions
  for reading (git-fixes).
- ACPI: OSI: Stop advertising support for "3.0 _SCP Extensions"
  (git-fixes).
- ACPI: PNP: Add Intel OC Watchdog IDs to non-PNP device list
  (stable-fixes).
- accel/qaic: Mask out SR-IOV PCI resources (stable-fixes).
- ALSA: hda/realtek: Enable PC beep passthrough for HP EliteBook
  855 G7 (stable-fixes).
- ACPI: HED: Always initialize before evged (stable-fixes).
- commit a49c2aa
* Thu Jun  5 2025 nik.borisov@suse.com
- Update patches.suse/mm-execmem-Unify-early-execmem_cache-behaviour.patch (bsc#1244062).
- commit d02c14c
* Thu Jun  5 2025 pjakobsson@suse.de
- accel/ivpu: Correct mutex unlock order in job submission
  (git-fixes).
- commit 9044b56
* Thu Jun  5 2025 pfalcato@suse.de
- net: ethernet: mtk-star-emac: fix spinlock recursion issues
  on rx/tx poll (CVE-2025-37917 bsc#1243475).
- commit 6f4e259
* Thu Jun  5 2025 pfalcato@suse.de
- net: ethernet: mtk_eth_soc: fix SER panic with 4GB+ RAM
  (CVE-2025-37935 bsc#1243546).
- commit 8eb532f
* Thu Jun  5 2025 rgoldwyn@suse.com
- Delete patches.suse/procfs-add-tunable-for-fd-fdinfo-dentry-retention.patch.
- commit c9207ce
* Thu Jun  5 2025 oneukum@suse.com
- platform/x86: thinkpad_acpi: Ignore battery threshold change
  event notification (git-fixes).
- commit de4db35
* Thu Jun  5 2025 oneukum@suse.com
- platform/x86: fujitsu-laptop: Support Lifebook S2110 hotkeys
  (git-fixes).
- commit aad5008
* Thu Jun  5 2025 oneukum@suse.com
- platform/x86: thinkpad_acpi: Support also NEC Lavie X1475JAS
  (git-fixes).
- commit 3d5ab3a
* Thu Jun  5 2025 pjakobsson@suse.de
- accel/ivpu: Fix locking order in ivpu_job_submit (CVE-2025-37907 bsc#1243464).
- commit 9c91371
* Thu Jun  5 2025 pjakobsson@suse.de
- accel/ivpu: Abort all jobs after command queue unregister (CVE-2025-37907 bsc#1243464).
- commit de61fba
* Thu Jun  5 2025 jgross@suse.com
- kABI: kabi fixes after tdx host patches (jsc#PED-348).
- commit d736c22
* Wed Jun  4 2025 lduncan@suse.com
- Delete
  patches.suse/scsi-target-iscsi-don-t-warn-of-R-W-when-no-data.patch.
  This patch was never accepted upstream, and it has a simple
  workaround.
- commit f19bccd
* Wed Jun  4 2025 lduncan@suse.com
- Delete
  patches.suse/scsi-target-iscsi-handle-SCSI-immediate-commands.patch.
  This patch was never accepted upstream, and it has a simple
  workaround.
- commit b76df52
* Wed Jun  4 2025 vkarasulli@suse.de
- iommu: Protect against overflow in iommu_pgsize() (git-fixes).
- commit 447faef
* Wed Jun  4 2025 mbrugger@suse.com
- Drop unneeded guarded patches
- Delete
  patches.suse/0001-regulator-mt6360-Add-OF-match-table.patch.
- Delete
  patches.suse/0002-regulator-mt6358-Add-OF-match-table.patch.
- Delete
  patches.suse/0003-regulator-mt6323-Add-OF-match-table.patch.
- commit 109a1a7
* Wed Jun  4 2025 jack@suse.cz
- ext4: ignore xattrs past end (bsc#1242846 CVE-2025-37738).
- commit 4250787
* Wed Jun  4 2025 jgross@suse.com
- KVM: VMX: use __always_inline for is_td_vcpu and is_td
  (git-fixes).
- commit b92c31e
* Wed Jun  4 2025 jgross@suse.com
- KVM: x86: Revert kvm_x86_ops.mem_enc_ioctl() back to an OPTIONAL
  hook (git-fixes).
- commit 60d9b39
* Wed Jun  4 2025 jgross@suse.com
- KVM: x86: Do not use kvm_rip_read() unconditionally for
  KVM_PROFILING (git-fixes).
- commit 6275fc3
* Wed Jun  4 2025 jgross@suse.com
- KVM: x86: Do not use kvm_rip_read() unconditionally in KVM
  tracepoints (git-fixes).
- commit 4df0c10
* Wed Jun  4 2025 oneukum@suse.com
- usb: xhci: Don't change the status of stalled TDs on failed
  Stop EP (git-fixes).
- commit c602063
* Wed Jun  4 2025 oneukum@suse.com
- net: usb: aqc111: fix error handling of usbnet read calls
  (git-fixes).
- commit 161e4aa
* Wed Jun  4 2025 oneukum@suse.com
- r8152: add vendor/device ID pair for Dell Alienware AW1022z
  (git-fixes).
- commit 0be40bd
* Wed Jun  4 2025 nik.borisov@suse.com
- mm/execmem: Unify early execmem_cache behaviour (git-fixes).
- commit 2b988fd
* Wed Jun  4 2025 dsterba@suse.com
- iio: light: opt3001: fix deadlock due to concurrent flag access (CVE-2025-37968 bsc#1243571)
- commit 38c1f6f
* Wed Jun  4 2025 pfalcato@suse.de
- tc: Ensure we have enough buffer space when sending filter
  netlink notifications (git-fixes).
- commit e91ebf9
* Wed Jun  4 2025 pfalcato@suse.de
- net: pktgen: fix mpls maximum labels list parsing (git-fixes).
- commit 23ee838
* Wed Jun  4 2025 dsterba@suse.com
- perf/x86/intel: KVM: Mask PEBS_ENABLE loaded for guest with vCPU's value (CVE-2025-37936 bsc#1243537)
- commit 595605e
* Wed Jun  4 2025 pfalcato@suse.de
- net: pktgen: fix access outside of user given buffer in
  pktgen_thread_write() (git-fixes).
- commit dc28109
* Wed Jun  4 2025 pfalcato@suse.de
- netdev: fix repeated netlink messages in queue stats
  (git-fixes).
- commit 35d6fa6
* Wed Jun  4 2025 pfalcato@suse.de
- net: sched: fix erspan_opt settings in cls_flower (git-fixes).
- commit 3501db1
* Wed Jun  4 2025 pfalcato@suse.de
- net/sched: tbf: correct backlog statistic for GSO packets
  (git-fixes).
- commit dec223e
* Wed Jun  4 2025 dsterba@suse.com
- pds_core: Prevent possible adminq overflow/stuck condition (CVE-2025-37987 bsc#1243542)
- commit 1019426
* Wed Jun  4 2025 pfalcato@suse.de
- netfilter: fib: avoid lookup if socket is available (git-fixes).
- commit 2ec4377
* Wed Jun  4 2025 pfalcato@suse.de
- tcp: reorganize tcp_in_ack_event() and tcp_count_delivered()
  (git-fixes).
- commit bb6f90b
* Wed Jun  4 2025 pfalcato@suse.de
- net: ipv6: Init tunnel link-netns before registering dev
  (git-fixes).
- commit 7594ce3
* Wed Jun  4 2025 pfalcato@suse.de
- net: ipv6: fix missing dst ref drop in ila lwtunnel (git-fixes).
- commit c1b70b1
* Wed Jun  4 2025 pfalcato@suse.de
- net: ipv6: fix dst ref loop in ila lwtunnel (git-fixes).
- commit 86493f5
* Wed Jun  4 2025 pfalcato@suse.de
- net: ipv6: fix dst ref loop on input in rpl lwt (git-fixes).
- commit 4009ad2
* Wed Jun  4 2025 pfalcato@suse.de
- net: ipv6: fix dst ref loop on input in seg6 lwt (git-fixes).
- commit 6e27dbd
* Wed Jun  4 2025 ailiop@suse.com
- SUNRPC: Prevent hang on NFS mount with xprtsec=[m]tls
  (git-fixes).
- commit fd7832d
* Wed Jun  4 2025 ailiop@suse.com
- nfs: ignore SB_RDONLY when remounting nfs (git-fixes).
- commit da5b33e
* Wed Jun  4 2025 ailiop@suse.com
- nfs: clear SB_RDONLY before getting superblock (git-fixes).
- commit 35b5d18
* Wed Jun  4 2025 ailiop@suse.com
- NFSv4: Don't check for OPEN feature support in v4.1 (git-fixes).
- commit cb622d7
* Wed Jun  4 2025 ailiop@suse.com
- fs/nfs/read: fix double-unlock bug in nfs_return_empty_folio()
  (git-fixes).
- commit d3f8f13
* Wed Jun  4 2025 iivanov@suse.de
- arm64: sysreg: Drag linux/kconfig.h to work around vdso build issue (git-fixes)
- commit 1cc351d
* Wed Jun  4 2025 iivanov@suse.de
- i2c: tegra: check msg length in SMBUS block read (bsc#1242086)
- commit d765f59
* Wed Jun  4 2025 oneukum@suse.com
- soc: qcom: ice: introduce devm_of_qcom_ice_get (git-fixes).
- commit 6cb417e
* Wed Jun  4 2025 msuchanek@suse.de
- powerpc/pseries/msi: Avoid reading PCI device registers in
  reduced power states (bsc#1215199).
- KVM: powerpc: Enable commented out BUILD_BUG_ON() assertion
  (bsc#1215199).
- commit 679f2a3
* Wed Jun  4 2025 nmorey@suse.com
- RDMA/uverbs: Propagate errors from rdma_lookup_get_uobject() (git-fixes)
- commit cad8ec2
* Wed Jun  4 2025 nmorey@suse.com
- RDMA/core: Fix best page size finding when it can cross SG entries (git-fixes)
- commit 3f842a4
* Wed Jun  4 2025 jgross@suse.com
- Documentation/virt/kvm: Document on Trust Domain Extensions
  (TDX) (jsc#PED-348).
- commit 8414857
* Wed Jun  4 2025 jgross@suse.com
- KVM: TDX: Make TDX VM type supported (jsc#PED-348).
- commit 707d68f
* Wed Jun  4 2025 jgross@suse.com
- KVM: TDX: KVM: TDX: Always honor guest PAT on TDX enabled guests
  (jsc#PED-348).
- commit 1989f3c
* Wed Jun  4 2025 jgross@suse.com
- KVM: x86: remove shadow_memtype_mask (jsc#PED-348).
- commit be496d7
* Wed Jun  4 2025 jgross@suse.com
- KVM: x86: Introduce Intel specific quirk
  KVM_X86_QUIRK_IGNORE_GUEST_PAT (jsc#PED-348).
- commit a4399ff
* Wed Jun  4 2025 jgross@suse.com
- KVM: x86: Introduce supported_quirks to block disabling quirks
  (jsc#PED-348).
- commit b2c7cdd
* Wed Jun  4 2025 jgross@suse.com
- KVM: x86: Allow vendor code to disable quirks (jsc#PED-348).
- commit e2dd0d6
* Wed Jun  4 2025 jgross@suse.com
- KVM: x86: do not allow re-enabling quirks (jsc#PED-348).
- commit e772bf3
* Wed Jun  4 2025 jgross@suse.com
- KVM: TDX: Enable guest access to MTRR MSRs (jsc#PED-348).
- commit b2b6235
* Wed Jun  4 2025 jgross@suse.com
- KVM: TDX: Add a method to ignore hypercall patching
  (jsc#PED-348).
- commit d85513a
* Wed Jun  4 2025 jgross@suse.com
- KVM: TDX: Ignore setting up mce (jsc#PED-348).
- commit 94cc52d
* Wed Jun  4 2025 jgross@suse.com
- KVM: TDX: Add methods to ignore accesses to TSC (jsc#PED-348).
- commit f3fab48
* Wed Jun  4 2025 jgross@suse.com
- KVM: TDX: Add methods to ignore VMX preemption timer
  (jsc#PED-348).
- commit 9856061
* Wed Jun  4 2025 jgross@suse.com
- KVM: TDX: Add method to ignore guest instruction emulation
  (jsc#PED-348).
- commit 1b78596
* Wed Jun  4 2025 jgross@suse.com
- KVM: TDX: Add methods to ignore accesses to CPU state
  (jsc#PED-348).
- commit 6a204e7
* Wed Jun  4 2025 jgross@suse.com
- KVM: TDX: Handle TDG.VP.VMCALL<GetTdVmCallInfo> hypercall
  (jsc#PED-348).
- commit c70683b
* Wed Jun  4 2025 jgross@suse.com
- KVM: TDX: Enable guest access to LMCE related MSRs
  (jsc#PED-348).
- commit 38a0d91
* Wed Jun  4 2025 jgross@suse.com
- KVM: TDX: Handle TDX PV rdmsr/wrmsr hypercall (jsc#PED-348).
- commit 4e4c4ee
* Wed Jun  4 2025 jgross@suse.com
- KVM: TDX: Implement callbacks for MSR operations (jsc#PED-348).
- commit c357360
* Wed Jun  4 2025 jgross@suse.com
- KVM: x86: Move KVM_MAX_MCE_BANKS to header file (jsc#PED-348).
- commit 4352152
* Wed Jun  4 2025 jgross@suse.com
- KVM: TDX: Handle TDX PV HLT hypercall (jsc#PED-348).
- commit 5047fe8
* Wed Jun  4 2025 jgross@suse.com
- KVM: TDX: Handle TDX PV CPUID hypercall (jsc#PED-348).
- commit d83ca6d
* Wed Jun  4 2025 jgross@suse.com
- KVM: TDX: Kick off vCPUs when SEAMCALL is busy during TD page
  removal (jsc#PED-348).
- commit 723b654
* Wed Jun  4 2025 jgross@suse.com
- KVM: TDX: Handle EXIT_REASON_OTHER_SMI (jsc#PED-348).
- Refresh
  patches.suse/KVM-TDX-Handle-EPT-violation-misconfig-exit.patch.
- commit ea445d7
* Tue Jun  3 2025 vkarasulli@suse.de
- iommu/tegra241-cmdqv: Fix warnings due to  dmam_free_coherent()
  (CVE-2025-37837 bsc#1242952).
- commit 94c2388
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Retry locally in TDX EPT violation handler on
  RET_PF_RETRY (jsc#PED-348).
- commit 372dc9e
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Handle EXCEPTION_NMI and EXTERNAL_INTERRUPT
  (jsc#PED-348).
- commit 9331c7d
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Detect unexpected SEPT violations due to pending SPTEs
  (jsc#PED-348).
- commit 2a1fde3
* Tue Jun  3 2025 jgross@suse.com
- KVM: VMX: Add a helper for NMI handling (jsc#PED-348).
- commit 24f802e
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Handle EPT violation/misconfig exit (jsc#PED-348).
- commit a0ec838
* Tue Jun  3 2025 dsterba@suse.com
- net: ngbe: fix memory leak in ngbe_probe() error path (CVE-2025-37874 bsc#1242940)
- commit bafeaea
* Tue Jun  3 2025 dsterba@suse.com
- net: txgbe: fix memory leak in txgbe_probe() error path (CVE-2025-37872 bsc#1242950)
- commit 185c018
* Tue Jun  3 2025 jgross@suse.com
- KVM: VMX: Move emulation_required to struct vcpu_vt
  (jsc#PED-348).
- commit 9434e32
* Tue Jun  3 2025 dsterba@suse.com
- net: dsa: mv88e6xxx: fix -ENOENT when deleting VLANs and MST is unsupported (CVE-2025-37865 bsc#1242954)
- commit ee6b079
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Add methods to ignore virtual apic related operation
  (jsc#PED-348).
- commit bf9bca9
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Force APICv active for TDX guest (jsc#PED-348).
- commit d79a636
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Enforce KVM_IRQCHIP_SPLIT for TDX guests
  (jsc#PED-348).
- commit 9e38109
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Always block INIT/SIPI (jsc#PED-348).
- commit 622c0b5
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Handle SMI request as !CONFIG_KVM_SMM (jsc#PED-348).
- commit 1d4c6d0
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Implement methods to inject NMI (jsc#PED-348).
- commit 27010d8
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Handle TDX PV MMIO hypercall (jsc#PED-348).
- commit d3a7554
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Wait lapic expire when timer IRQ was injected
  (jsc#PED-348).
- commit df10413
* Tue Jun  3 2025 oneukum@suse.com
- generic_pm_domain_data: hide new member in hole (git-fixes).
- commit 2492c7a
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Handle TDX PV port I/O hypercall (jsc#PED-348).
- commit a4d0ab3
* Tue Jun  3 2025 jgross@suse.com
- KVM: x86: Assume timer IRQ was injected if APIC state is
  protected (jsc#PED-348).
- commit d27ed33
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Handle TDG.VP.VMCALL<ReportFatalError> (jsc#PED-348).
- commit f0081ab
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Implement non-NMI interrupt injection (jsc#PED-348).
- commit 6430243
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Handle TDG.VP.VMCALL<MapGPA> (jsc#PED-348).
- commit 06d28ef
* Tue Jun  3 2025 jgross@suse.com
- KVM: VMX: Move posted interrupt delivery code to common header
  (jsc#PED-348).
- commit 4cdd8be
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Handle KVM hypercall with TDG.VP.VMCALL (jsc#PED-348).
- commit b711514
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Disable PI wakeup for IPIv (jsc#PED-348).
- commit 0083672
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Add a place holder for handler of TDX hypercalls
  (TDG.VP.VMCALL) (jsc#PED-348).
- commit bbfe1d3
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Add support for find pending IRQ in a protected
  local APIC (jsc#PED-348).
- commit 0ac86e2
* Tue Jun  3 2025 jgross@suse.com
- KVM: x86: Add a switch_db_regs flag to handle TDX's
  auto-switched behavior (jsc#PED-348).
- commit e59aad1
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Add a place holder to handle TDX VM exit
  (jsc#PED-348).
- commit f6d9d03
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Save and restore IA32_DEBUGCTL (jsc#PED-348).
- commit 16db600
* Tue Jun  3 2025 jgross@suse.com
- KVM: x86: Move pv_unhalted check out of kvm_vcpu_has_events()
  (jsc#PED-348).
- commit 43d4480
* Tue Jun  3 2025 oneukum@suse.com
- pmdomain: core: Introduce dev_pm_genpd_rpm_always_on()
  (git-fixes).
- commit 0ef07f9
* Tue Jun  3 2025 davide.benini@suse.com
- net: switchdev: Convert blocking notification chain to a raw
  one (CVE-2025-21986 bsc#1240810).
- commit 85f36f1
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Disable support for TSX and WAITPKG (jsc#PED-348).
- commit bc35c5e
* Tue Jun  3 2025 jgross@suse.com
- KVM: x86: Have ____kvm_emulate_hypercall() read the GPRs
  (jsc#PED-348).
- commit 850ed89
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: restore user ret MSRs (jsc#PED-348).
- commit cfdcb3d
* Tue Jun  3 2025 jgross@suse.com
- KVM: x86: Allow to update cached values in kvm_user_return_msrs
  w/o wrmsr (jsc#PED-348).
- commit 8a2fb55
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: restore host xsave state when exit from the guest TD
  (jsc#PED-348).
- commit 611c719
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: vcpu_run: save/restore host state(host kernel gs)
  (jsc#PED-348).
- commit 06d5ada
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Implement TDX vcpu enter/exit path (jsc#PED-348).
- commit 38e314c
* Tue Jun  3 2025 jgross@suse.com
- KVM: VMX: Move common fields of struct vcpu_{vmx,tdx} to a
  struct (jsc#PED-348).
- commit dd35aa6
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Handle SEPT zap error due to page add error in premap
  (jsc#PED-348).
- commit 046d39c
* Tue Jun  3 2025 jgross@suse.com
- x86/virt/tdx: Add SEAMCALL wrapper to enter/exit TDX guest
  (jsc#PED-348).
- commit 12e92a7
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Skip updating CPU dirty logging request for TDs
  (jsc#PED-348).
- commit 95e549f
* Tue Jun  3 2025 jgross@suse.com
- KVM: x86: Make cpu_dirty_log_size a per-VM value (jsc#PED-348).
- commit 94f097d
* Tue Jun  3 2025 jgross@suse.com
- KVM: x86/mmu: Add parameter "kvm" to
  kvm_mmu_page_ad_need_write_protect() (jsc#PED-348).
- commit 1e27dc3
* Tue Jun  3 2025 jgross@suse.com
- KVM: Add parameter "kvm" to kvm_cpu_dirty_log_size() and its
  callers (jsc#PED-348).
- commit 74de069
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Handle vCPU dissociation (jsc#PED-348).
- commit 9718bb2
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Finalize VM initialization (jsc#PED-348).
- commit f6520b5
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Add an ioctl to create initial guest memory
  (jsc#PED-348).
- commit ff60511
* Tue Jun  3 2025 jgross@suse.com
- KVM: x86/mmu: Export kvm_tdp_map_page() (jsc#PED-348).
- commit 3465834
* Tue Jun  3 2025 jgross@suse.com
- KVM: x86/mmu: Bail out kvm_tdp_map_page() when VM dead
  (jsc#PED-348).
- commit 144e592
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Implement hook to get max mapping level of private
  pages (jsc#PED-348).
- commit 554515d
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Implement hooks to propagate changes of TDP MMU
  mirror page table (jsc#PED-348).
- commit f1d4b55
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Handle TLB tracking for TDX (jsc#PED-348).
- commit f0faa8e
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Set per-VM shadow_mmio_value to 0 (jsc#PED-348).
- commit 49dae5c
* Tue Jun  3 2025 jgross@suse.com
- KVM: x86/mmu: Add setter for shadow_mmio_value (jsc#PED-348).
- commit b058430
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Require TDP MMU, mmio caching and EPT A/D bits for
  TDX (jsc#PED-348).
- commit 7d874e9
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Set gfn_direct_bits to shared bit (jsc#PED-348).
- commit ef0e482
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Add load_mmu_pgd method for TDX (jsc#PED-348).
- commit d5b9d6f
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Add accessors VMX VMCS helpers (jsc#PED-348).
- commit 1f2f6c1
* Tue Jun  3 2025 jgross@suse.com
- KVM: VMX: Teach EPT violation helper about private mem
  (jsc#PED-348).
- commit 7088974
* Tue Jun  3 2025 jgross@suse.com
- KVM: VMX: Split out guts of EPT violation to common/exposed
  function (jsc#PED-348).
- commit 72c8f3e
* Tue Jun  3 2025 jgross@suse.com
- KVM: x86/mmu: Do not enable page track for TD guest
  (jsc#PED-348).
- commit de6c038
* Tue Jun  3 2025 jgross@suse.com
- KVM: x86/tdp_mmu: Add a helper function to walk down the TDP
  MMU (jsc#PED-348).
- commit 44a0f73
* Tue Jun  3 2025 jgross@suse.com
- KVM: x86/mmu: Implement memslot deletion for TDX (jsc#PED-348).
- commit 3d2ab8b
* Tue Jun  3 2025 jgross@suse.com
- x86/virt/tdx: Add SEAMCALL wrappers for TD measurement of
  initial contents (jsc#PED-348).
- commit abf2eb5
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Register TDX host key IDs to cgroup misc controller
  (jsc#PED-348).
- commit b50c816
* Tue Jun  3 2025 jgross@suse.com
- x86/virt/tdx: Add SEAMCALL wrappers to remove a TD private page
  (jsc#PED-348).
- commit 466591d
* Tue Jun  3 2025 jgross@suse.com
- KVM: x86/mmu: Taking guest pa into consideration when calculate
  tdp level (jsc#PED-348).
- commit 3904d80
* Tue Jun  3 2025 jgross@suse.com
- x86/virt/tdx: Add SEAMCALL wrappers to manage TDX TLB tracking
  (jsc#PED-348).
- commit a485453
* Tue Jun  3 2025 jgross@suse.com
- KVM: x86: Introduce KVM_TDX_GET_CPUID (jsc#PED-348).
- commit fe28688
* Tue Jun  3 2025 jgross@suse.com
- x86/virt/tdx: Add SEAMCALL wrappers to add TD private pages
  (jsc#PED-348).
- commit 2498b76
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Do TDX specific vcpu initialization (jsc#PED-348).
- commit 165bc3a
* Tue Jun  3 2025 jgross@suse.com
- x86/virt/tdx: Add SEAMCALL wrapper tdh_mem_sept_add() to add
  SEPT pages (jsc#PED-348).
- commit 7395169
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: create/free TDX vcpu structure (jsc#PED-348).
- commit 98bd9d9
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Don't offline the last cpu of one package when
  there's TDX guest (jsc#PED-348).
- commit e74a04c
* Tue Jun  3 2025 msuchanek@suse.de
- powerpc/pseries/dlpar: Search DRC index from ibm,drc-indexes
  for IO add (bsc#1243042 ltc#212167).
- commit 87e2def
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Make pmu_intel.c ignore guest TD case (jsc#PED-348).
- commit 7db5893
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: add ioctl to initialize VM with TDX specific
  parameters (jsc#PED-348).
- commit 9a8f7c4
* Tue Jun  3 2025 jgross@suse.com
- KVM: x86: expose cpuid_entry2_find for TDX (jsc#PED-348).
- commit d6d74c0
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Support per-VM KVM_CAP_MAX_VCPUS extension check
  (jsc#PED-348).
- commit 99f1ef2
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: create/destroy VM structure (jsc#PED-348).
- commit ff395b9
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Get system-wide info about TDX module on
  initialization (jsc#PED-348).
- commit f966b83
* Tue Jun  3 2025 dsterba@suse.com
- cifs: avoid NULL pointer dereference in dbg call (CVE-2025-37844 bsc#1242946)
- commit 13ce184
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Add place holder for TDX VM specific mem_enc_op ioctl
  (jsc#PED-348).
- commit fb81451
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Add helper functions to print TDX SEAMCALL error
  (jsc#PED-348).
- commit c7850a7
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Add TDX "architectural" error codes (jsc#PED-348).
- commit ae6dde8
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Define TDX architectural definitions (jsc#PED-348).
- commit 0b39ad1
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Add placeholders for TDX VM/vCPU structures
  (jsc#PED-348).
- commit 4331504
* Tue Jun  3 2025 jgross@suse.com
- KVM: TDX: Get TDX global information (jsc#PED-348).
- commit 2639f49
* Tue Jun  3 2025 jgross@suse.com
- KVM: VMX: Initialize TDX during KVM module load (jsc#PED-348).
- commit e605aaf
* Tue Jun  3 2025 jgross@suse.com
- KVM: VMX: Refactor VMX module init/exit functions (jsc#PED-348).
- commit 3880b0c
* Tue Jun  3 2025 dsterba@suse.com
- scsi: ufs: core: Add NULL check in ufshcd_mcq_compl_pending_transfer() (CVE-2025-37826 bsc#1242862)
- commit d04f316
* Tue Jun  3 2025 jgross@suse.com
- KVM: Export hardware virtualization enabling/disabling functions
  (jsc#PED-348).
- commit dbb21b7
* Tue Jun  3 2025 jgross@suse.com
- x86/virt/tdx: Add tdx_guest_keyid_alloc/free() to alloc and
  free TDX guest KeyID (jsc#PED-348).
- commit 4dc8a98
* Tue Jun  3 2025 jgross@suse.com
- x86/virt/tdx: Read essential global metadata for KVM
  (jsc#PED-348).
- commit 8ddca0b
* Tue Jun  3 2025 jgross@suse.com
- x86/virt/tdx: allocate tdx_sys_info in static memory
  (jsc#PED-348).
- commit 6a14d13
* Tue Jun  3 2025 jgross@suse.com
- x86/virt/tdx: Add SEAMCALL wrappers for TDX flush operations
  (jsc#PED-348).
- commit c2d6ae0
* Tue Jun  3 2025 jgross@suse.com
- x86/virt/tdx: Add SEAMCALL wrappers for TDX VM/vCPU field access
  (jsc#PED-348).
- commit a4a8ea9
* Tue Jun  3 2025 jgross@suse.com
- x86/virt/tdx: Add SEAMCALL wrappers for TDX page cache
  management (jsc#PED-348).
- commit f562ade
* Tue Jun  3 2025 jgross@suse.com
- x86/virt/tdx: Add SEAMCALL wrappers for TDX vCPU creation
  (jsc#PED-348).
- commit 4596a12
* Tue Jun  3 2025 jgross@suse.com
- x86/virt/tdx: Add SEAMCALL wrappers for TDX TD creation
  (jsc#PED-348).
- commit 67ea0be
* Tue Jun  3 2025 jgross@suse.com
- x86/virt/tdx: Add SEAMCALL wrappers for TDX KeyID management
  (jsc#PED-348).
- commit 4535d8f
* Tue Jun  3 2025 joao.povoas@suse.com
- Update
  patches.suse/9p-net-fix-improper-handling-of-bogus-negative-read-.patch
  (git-fixes CVE-2025-37879 bsc#1243077).
- Update
  patches.suse/ALSA-ump-Fix-buffer-overflow-at-UMP-SysEx-message-co.patch
  (bsc#1242044 CVE-2025-37891 bsc#1243589).
- Update
  patches.suse/ASoC-Intel-avs-Fix-null-ptr-deref-in-avs_component_p.patch
  (git-fixes CVE-2025-37793 bsc#1242584).
- Update
  patches.suse/ASoC-amd-acp-Fix-NULL-pointer-deref-in-acp_i2s_set_t.patch
  (git-fixes CVE-2025-37919 bsc#1243478).
- Update
  patches.suse/ASoC-codecs-wcd937x-fix-a-potential-memory-leak-in-w.patch
  (git-fixes CVE-2025-37941 bsc#1243525).
- Update
  patches.suse/ASoC-imx-card-Add-NULL-check-in-imx_card_probe.patch
  (git-fixes CVE-2025-22066 bsc#1241340).
- Update
  patches.suse/ASoC-ops-Consistently-treat-platform_max-as-control-.patch
  (git-fixes CVE-2025-37889 bsc#1242945).
- Update
  patches.suse/ASoC-qcom-Fix-sc7280-lpass-potential-buffer-overflow.patch
  (git-fixes CVE-2025-37979 bsc#1243545).
- Update
  patches.suse/ASoC-simple-card-utils-Fix-pointer-check-in-graph_ut.patch
  (git-fixes CVE-2025-37934 bsc#1243548).
- Update
  patches.suse/Bluetooth-btrtl-Prevent-potential-NULL-dereference.patch
  (git-fixes CVE-2025-37792 bsc#1242591).
- Update
  patches.suse/Bluetooth-btusb-avoid-NULL-pointer-dereference-in-sk.patch
  (git-fixes CVE-2025-37918 bsc#1243476).
- Update
  patches.suse/HID-pidff-Fix-null-pointer-dereference-in-pidff_find.patch
  (stable-fixes CVE-2025-37862 bsc#1242982).
- Update
  patches.suse/HID-pidff-Make-sure-to-fetch-pool-before-checking-SI.patch
  (stable-fixes CVE-2025-37942 bsc#1243576).
- Update
  patches.suse/HSI-ssi_protocol-Fix-use-after-free-vulnerability-in.patch
  (stable-fixes CVE-2025-37838 bsc#1241641).
- Update
  patches.suse/Input-mtk-pmic-keys-fix-possible-null-pointer-derefe.patch
  (git-fixes CVE-2025-37972 bsc#1243573).
- Update
  patches.suse/KVM-SVM-Forcibly-leave-SMM-mode-on-SHUTDOWN-intercep.patch
  (git-fixes CVE-2025-37957 bsc#1243513).
- Update
  patches.suse/KVM-x86-Reset-IRTE-to-host-control-if-new-route-isn-.patch
  (git-fixes CVE-2025-37885 bsc#1242960).
- Update
  patches.suse/PCI-Fix-reference-leak-in-pci_register_host_bridge.patch
  (git-fixes CVE-2025-37836 bsc#1242957).
- Update
  patches.suse/PCI-brcmstb-Fix-error-path-after-a-call-to-regulator.patch
  (git-fixes CVE-2025-22095 bsc#1241519).
- Update
  patches.suse/PCI-pciehp-Avoid-unnecessary-device-replacement-chec.patch
  (git-fixes CVE-2025-37843 bsc#1242956).
- Update
  patches.suse/PCI-vmd-Make-vmd_dev-cfg_lock-a-raw_spinlock_t-type.patch
  (stable-fixes CVE-2025-23161 bsc#1242792).
- Update
  patches.suse/PM-hibernate-Avoid-deadlock-in-hibernate_compressor_.patch
  (stable-fixes CVE-2025-37745 bsc#1242853).
- Update
  patches.suse/RDMA-cma-Fix-workqueue-crash-in-cma_netevent_work_ha.patch
  (git-fixes CVE-2025-37772 bsc#1242563).
- Update
  patches.suse/RDMA-core-Don-t-expose-hw_counters-outside-of-init-n.patch
  (git-fixes CVE-2025-22089 bsc#1241538).
- Update
  patches.suse/RDMA-core-Silence-oversized-kvmalloc-warning.patch
  (git-fixes CVE-2025-37867 bsc#1242948).
- Update
  patches.suse/USB-wdm-close-race-between-wdm_open-and-wdm_wwan_por.patch
  (git-fixes CVE-2025-37985 bsc#1243529).
- Update
  patches.suse/accel-ivpu-Fix-PM-related-deadlocks-in-MS-IOCTLs.patch
  (git-fixes CVE-2025-37848 bsc#1242943).
- Update
  patches.suse/accel-ivpu-Fix-deadlock-in-ivpu_ms_cleanup.patch
  (git-fixes CVE-2025-37847 bsc#1242947).
- Update
  patches.suse/arm64-errata-Add-missing-sentinels-to-Spectre-BHB-MIDR-arr.patch
  (git-fixes CVE-2025-37929 bsc#1243624).
- Update
  patches.suse/arm64-mops-Do-not-dereference-src-reg-for-a-set-operation.patch
  (git-fixes CVE-2025-37846 bsc#1242963).
- Update
  patches.suse/ata-pata_pxa-Fix-potential-NULL-pointer-dereference-.patch
  (git-fixes CVE-2025-37758 bsc#1242514).
- Update
  patches.suse/backlight-led_bl-Hold-led_access-lock-when-calling-l.patch
  (git-fixes CVE-2025-23144 bsc#1242568).
- Update
  patches.suse/block-fix-resource-leak-in-blk_register_queue-error-path.patch
  (git-fixes CVE-2025-37980 bsc#1243522).
- Update
  patches.suse/block-integrity-Do-not-call-set_page_dirty_lock.patch
  (git-fixes CVE-2025-37978 bsc#1243516).
- Update patches.suse/block-mark-GFP_NOIO-around-sysfs-store.patch
  (jsc#PED-9651 CVE-2025-21817 bsc#1239106).
- Update
  patches.suse/bnxt_en-Fix-error-handling-path-in-bnxt_init_chip.patch
  (git-fixes CVE-2025-37895 bsc#1243532).
- Update
  patches.suse/bnxt_en-Fix-out-of-bound-memcpy-during-ethtool-w.patch
  (git-fixes CVE-2025-37911 bsc#1243469).
- Update
  patches.suse/book3s64-radix-Align-section-vmemmap-start-address-t.patch
  (bsc#1238318 bsc#1243298 ltc#212689 CVE-2025-37922 bsc#1243481).
- Update patches.suse/bpf-Scrub-packet-on-bpf_redirect_peer.patch
  (git-fixes CVE-2025-37959 bsc#1243517).
- Update
  patches.suse/bpf-check-changes_pkt_data-property-for-extension-pr.patch
  (bsc#1241590 CVE-2024-58100 bsc#1242564).
- Update
  patches.suse/bpf-consider-that-tail-calls-invalidate-packet-point.patch
  (git-fixes CVE-2024-58237 bsc#1242574).
- Update
  patches.suse/bpf-track-changes_pkt_data-property-for-global-funct.patch
  (bsc#1241590 CVE-2024-58098 bsc#1242565).
- Update
  patches.suse/btrfs-adjust-subpage-bit-start-based-on-sectorsize.patch
  (bsc#1241492 CVE-2025-37931 bsc#1243626).
- Update
  patches.suse/bus-mhi-host-Fix-race-between-unprepare-and-queue_bu.patch
  (git-fixes CVE-2025-23151 bsc#1242512).
- Update
  patches.suse/crypto-null-Use-spin-lock-instead-of-mutex.patch
  (stable-fixes CVE-2025-37808 bsc#1242923).
- Update
  patches.suse/cxgb4-fix-memory-leak-in-cxgb4_init_ethtool_filters-.patch
  (git-fixes CVE-2025-37788 bsc#1242766).
- Update
  patches.suse/dm-bufio-don-t-schedule-in-atomic-context.patch
  (git-fixes CVE-2025-37928 bsc#1243621).
- Update
  patches.suse/dmaengine-fsl-edma-free-irq-correctly-in-remove-path.patch
  (git-fixes CVE-2025-38479 bsc#1242036).
- Update
  patches.suse/driver-core-fix-potential-NULL-pointer-dereference-i.patch
  (stable-fixes CVE-2025-37800 bsc#1242849).
- Update
  patches.suse/drm-amd-display-Fix-slab-use-after-free-in-hdcp.patch
  (git-fixes CVE-2025-37903 bsc#1243562).
- Update
  patches.suse/drm-amd-display-prevent-hang-on-link-training-fail.patch
  (stable-fixes CVE-2025-37870 bsc#1243056).
- Update
  patches.suse/drm-amd-pm-Prevent-division-by-zero-4b8c3c0.patch
  (git-fixes CVE-2025-37770 bsc#1242764).
- Update
  patches.suse/drm-amd-pm-Prevent-division-by-zero-4e3d950.patch
  (git-fixes CVE-2025-37766 bsc#1242785).
- Update
  patches.suse/drm-amd-pm-Prevent-division-by-zero-7c246a0.patch
  (git-fixes CVE-2025-37768 bsc#1242567).
- Update
  patches.suse/drm-amd-pm-Prevent-division-by-zero-7d641c2.patch
  (git-fixes CVE-2025-37771 bsc#1242781).
- Update patches.suse/drm-amd-pm-Prevent-division-by-zero.patch
  (git-fixes CVE-2025-37767 bsc#1242501).
- Update
  patches.suse/drm-amd-pm-smu11-Prevent-division-by-zero.patch
  (git-fixes CVE-2025-37769 bsc#1242587).
- Update
  patches.suse/drm-amdgpu-handle-amdgpu_cgs_create_device-errors-in.patch
  (stable-fixes CVE-2025-37852 bsc#1243074).
- Update patches.suse/drm-amdkfd-Fix-mode1-reset-crash-issue.patch
  (stable-fixes CVE-2025-37854 bsc#1243082).
- Update
  patches.suse/drm-amdkfd-debugfs-hang_hws-skip-GPU-with-MES.patch
  (stable-fixes CVE-2025-37853 bsc#1243076).
- Update
  patches.suse/drm-i915-huc-Fix-fence-not-released-on-early-probe-e.patch
  (git-fixes CVE-2025-37754 bsc#1242524).
- Update
  patches.suse/drm-imagination-fix-firmware-memory-leaks.patch
  (git-fixes CVE-2025-37764 bsc#1242577).
- Update
  patches.suse/drm-imagination-take-paired-job-reference.patch
  (git-fixes CVE-2025-37763 bsc#1242508).
- Update
  patches.suse/drm-mediatek-dp-drm_err-dev_err-in-HPD-path-to-avoid.patch
  (git-fixes CVE-2025-38240 bsc#1241457).
- Update
  patches.suse/drm-nouveau-Fix-WARN_ON-in-nouveau_fence_context_kil.patch
  (git-fixes CVE-2025-37930 bsc#1243625).
- Update
  patches.suse/drm-nouveau-prime-fix-ttm_bo_delayed_delete-oops.patch
  (git-fixes CVE-2025-37765 bsc#1242761).
- Update
  patches.suse/drm-v3d-Add-job-to-pending-list-if-the-reset-was-ski.patch
  (stable-fixes CVE-2025-37951 bsc#1243659).
- Update
  patches.suse/drm-xe-Fix-an-out-of-bounds-shift-when-invalidating-.patch
  (git-fixes CVE-2025-37761 bsc#1242724).
- Update
  patches.suse/drm-xe-Use-local-fence-in-error-path-of-xe_migrate_c.patch
  (git-fixes CVE-2025-37869 bsc#1242967).
- Update
  patches.suse/drm-xe-userptr-fix-notifier-vs-folio-deadlock.patch
  (git-fixes CVE-2025-37868 bsc#1242966).
- Update
  patches.suse/drm-xe-vf-Don-t-try-to-trigger-a-full-GT-reset-if-VF.patch
  (stable-fixes CVE-2025-23162 bsc#1242834).
- Update
  patches.suse/eth-bnxt-fix-missing-ring-index-trim-on-error-path.patch
  (git-fixes CVE-2025-37873 bsc#1242961).
- Update
  patches.suse/ethtool-cmis_cdb-use-correct-rpl-size-in-ethtool_cmi.patch
  (git-fixes CVE-2025-37791 bsc#1242729).
- Update patches.suse/fbdev-omapfb-Add-plane-value-check.patch
  (stable-fixes CVE-2025-37851 bsc#1242977).
- Update
  patches.suse/firmware-arm_scmi-Balance-device-refcount-when-destr.patch
  (git-fixes CVE-2025-37905 bsc#1243456).
- Update
  patches.suse/i2c-cros-ec-tunnel-defer-probe-if-parent-EC-is-not-p.patch
  (git-fixes CVE-2025-37781 bsc#1242575).
- Update
  patches.suse/i3c-Add-NULL-pointer-check-in-i3c_master_queue_ibi.patch
  (git-fixes CVE-2025-23147 bsc#1242530).
- Update
  patches.suse/ice-Check-VF-VSI-Pointer-Value-in-ice_vc_add_fdir_fl.patch
  (git-fixes CVE-2025-37912 bsc#1243470).
- Update patches.suse/igc-fix-PTM-cycle-trigger-logic.patch
  (git-fixes CVE-2025-37875 bsc#1242959).
- Update
  patches.suse/iio-backend-make-sure-to-NULL-terminate-stack-buffer.patch
  (git-fixes CVE-2025-22082 bsc#1241336).
- Update
  patches.suse/iio-imu-st_lsm6dsx-fix-possible-lockup-in-st_lsm6dsx-8114ef8.patch
  (git-fixes CVE-2025-37969 bsc#1243574).
- Update
  patches.suse/iio-imu-st_lsm6dsx-fix-possible-lockup-in-st_lsm6dsx.patch
  (git-fixes CVE-2025-37970 bsc#1243575).
- Update
  patches.suse/iio-light-Add-check-for-array-bounds-in-veml6075_rea.patch
  (git-fixes CVE-2025-40114 bsc#1241639).
- Update
  patches.suse/iommu-Fix-two-issues-in-iommu_copy_struct_from_user.patch
  (git-fixes CVE-2025-37900 bsc#1243560).
- Update
  patches.suse/irqchip-gic-v2m-Prevent-use-after-free-of-gicv2m_get.patch
  (git-fixes CVE-2025-37819 bsc#1242873).
- Update
  patches.suse/irqchip-qcom-mpm-Prevent-crash-when-trying-to-handle.patch
  (git-fixes CVE-2025-37901 bsc#1243559).
- Update patches.suse/jbd2-remove-wrong-sb-s_sequence-check.patch
  (bsc#1242343 CVE-2025-37839 bsc#1242990).
- Update
  patches.suse/lib-iov_iter-fix-to-increase-non-slab-folio-refcount.patch
  (bsc#1241169 (MM functional and performance backports)
  CVE-2025-37779 bsc#1242525).
- Update
  patches.suse/md-md-bitmap-fix-wrong-bitmap_limit-for-clustermd-wh.patch
  (bsc#1238212 CVE-2025-22124 bsc#1241595).
- Update
  patches.suse/media-mediatek-vcodec-Fix-a-resource-leak-related-to.patch
  (git-fixes CVE-2025-23160 bsc#1242507).
- Update
  patches.suse/media-venus-hfi-add-a-check-to-handle-OOB-in-sfr-reg.patch
  (git-fixes CVE-2025-23159 bsc#1242529).
- Update
  patches.suse/media-venus-hfi-add-check-to-handle-incorrect-queue-.patch
  (git-fixes CVE-2025-23158 bsc#1242531).
- Update
  patches.suse/media-venus-hfi_parser-add-check-to-avoid-out-of-bou.patch
  (git-fixes CVE-2025-23157 bsc#1242532).
- Update
  patches.suse/media-venus-hfi_parser-refactor-hfi-packet-parsing-l.patch
  (git-fixes CVE-2025-23156 bsc#1242569).
- Update
  patches.suse/mei-vsc-Fix-fortify-panic-caused-by-invalid-counted_.patch
  (git-fixes CVE-2025-37816 bsc#1242863).
- Update
  patches.suse/mfd-ene-kb3930-Fix-a-potential-NULL-pointer-derefere.patch
  (git-fixes CVE-2025-23146 bsc#1242559).
- Update
  patches.suse/misc-microchip-pci1xxxx-Fix-Kernel-panic-during-IRQ-.patch
  (git-fixes CVE-2025-37815 bsc#1242871).
- Update patches.suse/mm-slab-clean-up-slab-obj_exts-always.patch
  (git-fixes CVE-2025-37908 bsc#1243466).
- Update
  patches.suse/mtd-inftlcore-Add-error-check-for-inftl_read_oob.patch
  (git-fixes CVE-2025-37892 bsc#1243536).
- Update
  patches.suse/mtd-rawnand-brcmnand-fix-PM-resume-warning.patch
  (git-fixes CVE-2025-37840 bsc#1242953).
- Update
  patches.suse/net-decrease-cached-dst-counters-in-dst_release.patch
  (git-fixes CVE-2025-22057 bsc#1241533).
- Update
  patches.suse/net-mlx5-Fix-null-ptr-deref-in-mlx5_create_-inner_-t.patch
  (git-fixes CVE-2025-37888 bsc#1242964).
- Update
  patches.suse/net-phy-allow-MDIO-bus-PM-ops-to-start-stop-state-ma.patch
  (git-fixes CVE-2025-37945 bsc#1243538).
- Update patches.suse/net-phy-leds-fix-memory-leak.patch
  (git-fixes CVE-2025-37989 bsc#1243511).
- Update patches.suse/net-tls-explicitly-disallow-disconnect.patch
  (git-fixes CVE-2025-37756 bsc#1242515).
- Update
  patches.suse/net-use-sock_gen_put-when-sk_state-is-TCP_TIME_WAIT.patch
  (git-fixes CVE-2025-37894 bsc#1243533).
- Update
  patches.suse/net_sched-drr-Fix-double-list-add-in-class-with-nete.patch
  (git-fixes CVE-2025-37915 bsc#1243473).
- Update
  patches.suse/net_sched-ets-Fix-double-list-add-in-class-with-nete.patch
  (git-fixes CVE-2025-37914 bsc#1243472).
- Update
  patches.suse/net_sched-hfsc-Fix-a-UAF-vulnerability-in-class-with.patch
  (git-fixes CVE-2025-37890 bsc#1243330).
- Update
  patches.suse/net_sched-qfq-Fix-double-list-add-in-class-with-nete.patch
  (git-fixes CVE-2025-37913 bsc#1243471).
- Update
  patches.suse/nfsd-allow-SC_STATUS_FREEABLE-when-searching-via-nfs4_lookup_stateid.patch
  (git-fixes CVE-2025-39688 bsc#1241652).
- Update
  patches.suse/nfsd-decrease-sc_count-directly-if-fail-to-queue-dl_recall.patch
  (git-fixes CVE-2025-37871 bsc#1242949).
- Update
  patches.suse/nvmet-fix-out-of-bounds-access-in-nvmet_enable_port.patch
  (jsc#PED-9651 CVE-2025-37825 bsc#1242874).
- Update
  patches.suse/objtool-media-dib8000-Prevent-divide-by-zero-in-dib8.patch
  (git-fixes CVE-2025-37937 bsc#1243540).
- Update
  patches.suse/objtool-nvmet-Fix-out-of-bounds-stack-access-in-nvme.patch
  (git-fixes CVE-2025-39778 bsc#1241632).
- Update
  patches.suse/objtool-spi-amd-Fix-out-of-bounds-stack-access-in-am.patch
  (git-fixes CVE-2025-40014 bsc#1241644).
- Update
  patches.suse/page_pool-avoid-infinite-loop-to-schedule-delayed-wo.patch
  (git-fixes CVE-2025-37859 bsc#1243051).
- Update
  patches.suse/powerpc64-ftrace-fix-module-loading-without-patchabl.patch
  (jsc#PED-10909 git-fixes bsc#1236402 CVE-2025-37898
  bsc#1243549).
- Update
  patches.suse/pwm-mediatek-Prevent-divide-by-zero-in-pwm_mediatek_.patch
  (git-fixes CVE-2025-37850 bsc#1242955).
- Update patches.suse/qibfs-fix-_another_-leak.patch (git-fixes
  CVE-2025-37983 bsc#1243567).
- Update
  patches.suse/remoteproc-core-Clear-table_sz-when-rproc_shutdown.patch
  (git-fixes CVE-2025-38152 bsc#1241627).
- Update
  patches.suse/s390-pci-Fix-duplicate-pci_dev_put-in-disable_slot-w.patch
  (git-fixes CVE-2025-37946 bsc#1243506).
- Update patches.suse/sch_htb-make-htb_deactivate-idempotent.patch
  (CVE-2025-37798 bsc#1242414 CVE-2025-37953 bsc#1243543).
- Update
  patches.suse/sch_htb-make-htb_qlen_notify-idempotent.patch
  (CVE-2025-37798 bsc#1242414 CVE-2025-37932 bsc#1243627).
- Update
  patches.suse/scsi-smartpqi-Use-is_kdump_kernel-to-check-for-kdump.patch
  (git-fixes CVE-2025-37981 bsc#1243514).
- Update
  patches.suse/sfc-fix-NULL-dereferences-in-ef100_process_design_pa.patch
  (git-fixes CVE-2025-37860 bsc#1241452).
- Update
  patches.suse/soc-samsung-exynos-chipid-Add-NULL-pointer-check-in-.patch
  (git-fixes CVE-2025-23148 bsc#1242578).
- Update
  patches.suse/sound-virtio-Fix-cancel_sync-warnings-on-uninitializ.patch
  (stable-fixes CVE-2025-37805 bsc#1242930).
- Update
  patches.suse/staging-vchiq_arm-Fix-possible-NPR-of-keep-alive-thr.patch
  (git-fixes CVE-2025-22078 bsc#1241418).
- Update
  patches.suse/tipc-fix-NULL-pointer-dereference-in-tipc_mon_reinit.patch
  (git-fixes CVE-2025-37824 bsc#1242867).
- Update patches.suse/tpm-do-not-start-chip-while-suspended.patch
  (git-fixes CVE-2025-23149 bsc#1242758).
- Update
  patches.suse/tty-Require-CAP_SYS_ADMIN-for-all-usages-of-TIOCL_SE.patch
  (git-fixes CVE-2025-37814 bsc#1242865).
- Update
  patches.suse/ublk-fix-handling-recovery-reissue-in-ublk_abort_queue.patch
  (git-fixes CVE-2025-37759 bsc#1242519).
- Update
  patches.suse/usb-cdns3-Fix-deadlock-when-using-NCM-gadget.patch
  (git-fixes CVE-2025-37812 bsc#1242908).
- Update
  patches.suse/usb-chipidea-ci_hdrc_imx-fix-usbmisc-handling.patch
  (git-fixes CVE-2025-37811 bsc#1242907).
- Update
  patches.suse/usb-dwc3-gadget-check-that-event-count-does-not-exce.patch
  (git-fixes CVE-2025-37810 bsc#1242906).
- Update
  patches.suse/usb-gadget-aspeed-Add-NULL-pointer-check-in-ast_vhub.patch
  (git-fixes CVE-2025-37881 bsc#1242973).
- Update
  patches.suse/usb-typec-class-Fix-NULL-pointer-access.patch
  (git-fixes CVE-2025-37809 bsc#1242856).
- Update
  patches.suse/usb-typec-class-Invalidate-USB-device-pointers-on-pa.patch
  (git-fixes CVE-2025-37986 bsc#1243515).
- Update
  patches.suse/usb-typec-ucsi-displayport-Fix-deadlock.patch
  (git-fixes CVE-2025-37967 bsc#1243572).
- Update
  patches.suse/usb-xhci-Don-t-skip-on-Stopped-Length-Invalid.patch
  (git-fixes CVE-2025-22023 bsc#1241298).
- Update
  patches.suse/usb-xhci-Fix-invalid-pointer-dereference-in-Etron-wo.patch
  (git-fixes CVE-2025-37813 bsc#1242909).
- Update
  patches.suse/usb-xhci-Fix-isochronous-Ring-Underrun-Overrun-event.patch
  (stable-fixes CVE-2025-37882 bsc#1243234).
- Update
  patches.suse/virtio-net-free-xsk_buffs-on-error-in-virtnet_xsk_po.patch
  (git-fixes CVE-2025-37955 bsc#1243507).
- Update
  patches.suse/wifi-at76c50x-fix-use-after-free-access-in-at76_disc.patch
  (git-fixes CVE-2025-37796 bsc#1242727).
- Update
  patches.suse/wifi-ath12k-Fix-invalid-data-access-in-ath12k_dp_rx_.patch
  (stable-fixes CVE-2025-37943 bsc#1243509).
- Update
  patches.suse/wifi-ath12k-Fix-invalid-entry-fetch-in-ath12k_dp_mon.patch
  (stable-fixes CVE-2025-37944 bsc#1243530).
- Update
  patches.suse/wifi-brcm80211-fmac-Add-error-handling-for-brcmf_usb.patch
  (git-fixes CVE-2025-37990 bsc#1243528).
- Update
  patches.suse/wifi-cfg80211-init-wiphy_work-before-allocating-rfki.patch
  (git-fixes CVE-2025-22119 bsc#1241576).
- Update
  patches.suse/wifi-mac80211-Purge-vif-txq-in-ieee80211_do_stop.patch
  (git-fixes CVE-2025-37794 bsc#1242566).
- Update
  patches.suse/wifi-plfxlc-Remove-erroneous-assert-in-plfxlc_mac_re.patch
  (git-fixes CVE-2025-37897 bsc#1243534).
- Update
  patches.suse/wifi-wl1251-fix-memory-leak-in-wl1251_tx_work.patch
  (git-fixes CVE-2025-37982 bsc#1243524).
- Update
  patches.suse/xen-netfront-handle-NULL-returned-by-xdp_convert_buf.patch
  (git-fixes CVE-2025-37820 bsc#1242866).
- Update patches.suse/xenbus-Use-kref-to-track-req-lifetime.patch
  (git-fixes CVE-2025-37949 bsc#1243541).
- Update
  patches.suse/xsk-fix-an-integer-overflow-in-xp_create_and_assign_.patch
  (git-fixes CVE-2025-21997 bsc#1240823).
- commit bc63f80
* Tue Jun  3 2025 svarbanov@suse.de
- arm64: Add override for MPAM (bsc#1242843)
- commit eb086b5
* Tue Jun  3 2025 pmladek@suse.com
- printk: Check CON_SUSPEND when unblanking a console
  (bsc#1243998).
- commit bab4aa6
* Tue Jun  3 2025 pmladek@suse.com
- Flush console log from kernel_power_off() (bsc#1243996).
- commit cd77fb7
* Tue Jun  3 2025 iivanov@suse.de
- arm64/mm: Permit lazy_mmu_mode to be nested (git-fixes)
- commit ed7a958
* Tue Jun  3 2025 iivanov@suse.de
- arm64/mm: Disable barrier batching in interrupt contexts (git-fixes)
- commit dabd452
* Tue Jun  3 2025 iivanov@suse.de
- smccc: kvm_guest: Align with DISCOVER_IMPL_CPUS ABI (git-fixes)
- commit cbe1757
* Mon Jun  2 2025 pfalcato@suse.de
- kABI: net: page_pool: avoid false positive warning if NAPI
  was never added (git-fixes).
- commit 06adb55
* Mon Jun  2 2025 henrique.carvalho@suse.com
- smb: cached directories can be more than root file handle
  (git-fixes).
- commit afb4d0b
* Mon Jun  2 2025 henrique.carvalho@suse.com
- smb: client: remove unnecessary checks in open_cached_dir()
  (git-fixes).
- commit a9818f2
* Mon Jun  2 2025 henrique.carvalho@suse.com
- smb: client: change return value in open_cached_dir_by_dentry()
  if !cfids (git-fixes).
- commit 3994f63
* Mon Jun  2 2025 henrique.carvalho@suse.com
- smb: client: Avoid race in open_cached_dir with lease breaks
  (CVE-2025-37954 bsc#1243664).
- commit af201ef
* Mon Jun  2 2025 iivanov@suse.de
- KVM: arm64: Specify hypercall ABI for retrieving target (git-fixes)
- commit 5a6faf6
* Mon Jun  2 2025 msuchanek@suse.de
- KVM: PPC: Book3S HV: Fix IRQ map warnings with XICS on pSeries
  KVM Guest (bsc#1242205 ltc#212592).
- commit d1b31ab
* Mon Jun  2 2025 iivanov@suse.de
- arm64: errata: Work around AmpereOne's erratum AC04_CPU_23 (git-fixes)
  Enable workaround for this errata and remove one slot of kABI
  preservation list.
- commit 0a959f3
* Mon Jun  2 2025 iivanov@suse.de
- KVM: arm64: Force HCR_EL2.xMO to 1 at all times in VHE mode (git-fixes)
- commit 92b45e1
* Mon Jun  2 2025 iivanov@suse.de
- arm64: sysreg: Add layout for ICH_HCR_EL2 (git-fixes)
- commit 10c80f5
* Mon Jun  2 2025 pmladek@suse.com
- objtool, panic: Disable SMAP in __stack_chk_fail()
  (bsc#1243963).
- commit 1d39035
* Mon Jun  2 2025 dsterba@suse.com
- net: stmmac: Fix accessing freed irq affinity_hint (CVE-2025-23155 bsc#1242573)
- commit b63c5f4
* Mon Jun  2 2025 pfalcato@suse.de
- memblock: Accept allocated memory before use in
  memblock_double_array() (CVE-2025-37960 bsc#1243519).
- commit 754095c
* Mon Jun  2 2025 pfalcato@suse.de
- mm/huge_memory: fix dereferencing invalid pmd migration entry
  (CVE-2025-37958 bsc#1243539).
- commit 675ffa4
* Mon Jun  2 2025 mwilck@suse.com
- dm: restrict dm device size to 2^63-512 bytes (git-fixes).
- commit ae2ce2b
* Mon Jun  2 2025 mwilck@suse.com
- dm cache: prevent BUG_ON by blocking retries on failed device
  resumes (git-fixes).
- commit d254a94
* Mon Jun  2 2025 mwilck@suse.com
- dm: fix unconditional IO throttle caused by REQ_PREFLUSH
  (git-fixes).
- commit fec8e9d
* Mon Jun  2 2025 mwilck@suse.com
- dm vdo indexer: prevent unterminated string warning (git-fixes).
- commit 379a5f2
* Mon Jun  2 2025 mwilck@suse.com
- dm vdo: use a short static string for thread name prefix
  (git-fixes).
- commit 8084a50
* Mon Jun  2 2025 dsterba@suse.com
- net_sched: sch_sfq: move the limit validation (CVE-2025-37752 bsc#1242504)
- commit c353024
* Mon Jun  2 2025 pfalcato@suse.de
- net: lwtunnel: disable BHs when required (git-fixes).
- commit 304c8c4
* Mon Jun  2 2025 oneukum@suse.com
- mmc: sdhci-of-dwcmshc: add PD workaround on RK3576 (git-fixes).
- commit 19be083
* Mon Jun  2 2025 oneukum@suse.com
- mmc: sdhci-msm: fix dev reference leaked through of_qcom_ice_get
  (git-fixes).
- commit e8bf316
* Mon Jun  2 2025 oneukum@suse.com
- mmc: host: Wait for Vdd to settle on card power off (git-fixes).
- commit 6799785
* Mon Jun  2 2025 oneukum@suse.com
- mmc: dw_mmc: add exynos7870 DW MMC support (git-fixes).
- commit 2d642c3
* Mon Jun  2 2025 oneukum@suse.com
- mmc: sdhci: Disable SD card clock before changing parameters
  (git-fixes).
- commit eab27bb
* Mon Jun  2 2025 oneukum@suse.com
- platform/x86/intel/pmc: Fix Arrow Lake U/H NPU PCI ID
  (git-fixes).
- commit 2916acb
* Mon Jun  2 2025 oneukum@suse.com
- platform/x86: dell-wmi-sysman: Avoid buffer overflow in
  current_password_store() (git-fixes).
- commit d257f90
* Mon Jun  2 2025 oneukum@suse.com
- platform/x86: ideapad-laptop: add support for some new buttons
  (git-fixes).
- commit 1e3c868
* Mon Jun  2 2025 oneukum@suse.com
- platform/x86: asus-wmi: Disable OOBE state after resume from
  hibernation (git-fixes).
- commit c9e24c6
* Mon Jun  2 2025 oneukum@suse.com
- platform/x86/intel: hid: Add Pantherlake support (git-fixes).
- commit 460cc0c
* Mon Jun  2 2025 oneukum@suse.com
- Input: synaptics-rmi - fix crash with unsupported versions of
  F34 (git-fixes).
- commit b62a334
* Mon Jun  2 2025 oneukum@suse.com
- Input: xpad - add more controllers (git-fixes).
- commit b79f69c
* Mon Jun  2 2025 oneukum@suse.com
- Input: xpad - fix xpad_device sorting (git-fixes).
- commit 46af804
* Mon Jun  2 2025 oneukum@suse.com
- Input: xpad - add support for several more controllers
  (git-fixes).
- commit ab01d4f
* Mon Jun  2 2025 iivanov@suse.de
- arm64/sysreg: Expose MTE_frac so that it is visible to KVM (git-fixes)
- commit 53f8737
* Mon Jun  2 2025 iivanov@suse.de
- arm64/cpuinfo: only show one cpu's info in c_show() (git-fixes)
- commit c7e06a7
* Mon Jun  2 2025 iivanov@suse.de
- arm64/mm: Batch barriers when updating kernel mappings (git-fixes)
- commit 133d7c0
* Mon Jun  2 2025 iivanov@suse.de
- arm64/cpufeature: Add missing id_aa64mmfr4 feature reg update (git-fixes)
- commit 0d85371
* Mon Jun  2 2025 iivanov@suse.de
- arm64: Rework checks for broken Cavium HW in the PI code (git-fixes)
- commit 589c17e
* Mon Jun  2 2025 iivanov@suse.de
- arm64: Add support for HIP09 Spectre-BHB mitigation (git-fixes)
- commit f8ba796
* Mon Jun  2 2025 iivanov@suse.de
- arm64: topology: Support SMT control on ACPI based system (git-fixes)
- commit 48b6d40
* Mon Jun  2 2025 pfalcato@suse.de
- kABI: ipv6: save dontfrag in cork (git-fixes).
  Patch-up the kABI change with an #ifdef __GENKSYMS__. This change is
  safe (as detailed in the patch commit message) due to the struct
  having a 6-byte hole at the end we can use.
- commit c19b923
* Mon Jun  2 2025 pfalcato@suse.de
- ipv6: save dontfrag in cork (git-fixes).
- commit f07ae24
* Mon Jun  2 2025 pfalcato@suse.de
- tcp: bring back NUMA dispersion in inet_ehash_locks_alloc()
  (git-fixes).
- commit 3096e43
* Mon Jun  2 2025 pfalcato@suse.de
- net: page_pool: avoid false positive warning if NAPI was never
  added (git-fixes).
- commit 13d3621
* Mon Jun  2 2025 pfalcato@suse.de
- ipv4: ip_gre: Fix set but not used warning in ipgre_err()
  if IPv4-only (git-fixes).
- commit e7bb54c
* Mon Jun  2 2025 pfalcato@suse.de
- net: flush_backlog() small changes (git-fixes).
- commit db8d6de
* Mon Jun  2 2025 pfalcato@suse.de
- kABI: net: lwtunnel: fix recursion loops (git-fixes).
- commit 0d4c30c
* Mon Jun  2 2025 iivanov@suse.de
- arm64/mm: Define PTDESC_ORDER (git-fixes)
- commit fe6a508
* Mon Jun  2 2025 iivanov@suse.de
- arm64/kernel: Always use level 2 or higher for early mappings (git-fixes)
- commit c847735
* Mon Jun  2 2025 iivanov@suse.de
- arm64/sysreg: Rename POE_RXW to POE_RWX (git-fixes)
- commit 81d3162
* Mon Jun  2 2025 iivanov@suse.de
- arm64/sysreg: Improve PIR/POR helpers (git-fixes)
- commit 8cac771
* Mon Jun  2 2025 iivanov@suse.de
- smccc/kvm_guest: Enable errata based on implementation CPUs (git-fixes)
- commit cca968d
* Mon Jun  2 2025 iivanov@suse.de
- arm64: Make  _midr_in_range_list() an exported function (git-fixes)
- commit 27f4bc5
* Mon Jun  2 2025 iivanov@suse.de
- arm64: Modify _midr_range() functions to read MIDR/REVIDR internally (git-fixes)
- commit 52f11f0
* Mon Jun  2 2025 iivanov@suse.de
- arm64: cpufeature: Handle NV_frac as a synonym of NV2 (git-fixes)
- commit 1c65e7c
* Mon Jun  2 2025 dwagner@suse.de
- nvme: avoid creating multipath sysfs group under namespace
  path devices (git-fixes).
- nvmet: pci-epf: clear completion queue IRQ flag on delete
  (git-fixes).
- nvme-pci: acquire cq_poll_lock in nvme_poll_irqdisable
  (git-fixes bsc#1223096).
- nvme-pci: make nvme_pci_npages_prp() __always_inline
  (git-fixes).
- nvmet-auth: always free derived key data (git-fixes).
- nvmet-tcp: don't restore null sk_state_change (git-fixes).
- nvme-pci: add quirks for WDC Blue SN550 15b7:5009 (git-fixes).
- nvme-pci: add quirks for device 126f:1001 (git-fixes).
- commit 4e0829c
* Mon Jun  2 2025 msuchanek@suse.de
- Remove debug flavor (bsc#1243919).
- commit ddb9b4c
* Mon Jun  2 2025 jslaby@suse.cz
- rpm/check-for-config-changes: add more to IGNORED_CONFIGS_RE
  Useful when someone tries (needs) to build the kernel with clang.
- commit 06918e3
* Mon Jun  2 2025 ailiop@suse.com
- Squashfs: check return result of sb_min_blocksize (git-fixes).
- commit 2e52086
* Mon Jun  2 2025 msuchanek@suse.de
- powerpc/pseries/iommu: Fix kmemleak in TCE table userspace view
  (jsc#PED-10539 git-fixes).
- commit 4182148
* Mon Jun  2 2025 nmorey@suse.com
- RDMA/cma: Fix hang when cma_netevent_callback fails to queue_work (git-fixes)
- commit a0be830
* Mon Jun  2 2025 nmorey@suse.com
- RDMA/iwcm: Fix use-after-free of work objects after cm_id destruction (git-fixes)
- commit 0ac05e4
* Mon Jun  2 2025 nmorey@suse.com
- RDMA/mlx5: Fix error flow upon firmware failure for RQ destruction (git-fixes)
- commit f3c40d5
* Mon Jun  2 2025 nmorey@suse.com
- IB/cm: Drop lockdep assert and WARN when freeing old msg (git-fixes)
- commit a7456d7
* Mon Jun  2 2025 nmorey@suse.com
- RDMA/hns: Include hnae3.h in hns_roce_hw_v2.h (git-fixes)
- commit 7f90606
* Mon Jun  2 2025 nmorey@suse.com
- RDMA/rxe: Fix "trying to register non-static key in rxe_qp_do_cleanup" bug (git-fixes)
- commit a59c563
* Mon Jun  2 2025 nmorey@suse.com
- IB/cm: use rwlock for MAD agent lock (git-fixes)
- commit c06f30d
* Mon Jun  2 2025 ddiss@suse.de
- fix a couple of races in MNT_TREE_BENEATH handling by
  do_move_mount() (bsc#1243521 CVE-2025-37988).
- commit e9c9973
* Sat May 31 2025 tonyj@suse.de
- perf/x86/intel: Fix segfault with PEBS-via-PT with sample_freq
  (git-fixes).
- perf/x86/intel: Only check the group flag for X86 leader
  (git-fixes).
- perf/x86: Fix non-sampling (counting) events on certain x86
  platforms (git-fixes).
- perf/x86/intel: Allow to update user space GPRs from PEBS
  records (git-fixes).
- perf/x86/intel/uncore: Fix the scale of IIO free running
  counters on SPR (git-fixes).
- perf/x86/intel/uncore: Fix the scale of IIO free running
  counters on ICX (git-fixes).
- perf/x86/intel/uncore: Fix the scale of IIO free running
  counters on SNR (git-fixes).
- perf tools: Remove evsel__handle_error_quirks() (git-fixes).
- perf tools: Fix up some comments and code to properly use the
  event_source bus (git-fixes).
- commit 2275c01
* Fri May 30 2025 ailiop@suse.com
- erofs: initialize decompression early (git-fixes).
- commit 2d8813f
* Fri May 30 2025 ailiop@suse.com
- pstore: Change kmsg_bytes storage size to u32 (git-fixes).
- commit 6956b60
* Fri May 30 2025 ailiop@suse.com
- exfat: call bh_read in get_block only when necessary
  (git-fixes).
- commit 7dd637f
* Fri May 30 2025 ailiop@suse.com
- NFSv4: Check for delegation validity in
  nfs_start_delegation_return_locked() (git-fixes).
- commit 418b04a
* Fri May 30 2025 ailiop@suse.com
- NFS: Don't allow waiting for exiting tasks (git-fixes).
- Refresh
  patches.suse/nfs-add-missing-selections-of-CONFIG_CRC32.patch.
- commit bba0843
* Fri May 30 2025 ailiop@suse.com
- SUNRPC: Don't allow waiting for exiting tasks (git-fixes).
- commit 66f99da
* Fri May 30 2025 ailiop@suse.com
- NFSv4: Treat ENETUNREACH errors as fatal for state recovery
  (git-fixes).
- commit 9c48276
* Fri May 30 2025 ailiop@suse.com
- SUNRPC: rpc_clnt_set_transport() must not change the autobind
  setting (git-fixes).
- commit 3c4ee4b
* Fri May 30 2025 ailiop@suse.com
- SUNRPC: rpcbind should never reset the port to the value '0'
  (git-fixes).
- commit 754a098
* Fri May 30 2025 ailiop@suse.com
- pNFS/flexfiles: Report ENETDOWN as a connection error
  (git-fixes).
- commit 3294f72
* Fri May 30 2025 vkarasulli@suse.de
- iommu/mediatek: Fix NULL pointer deference in
  mtk_iommu_device_group (CVE-2025-37748 bsc#1242523).
- commit 6ffeaed
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: Make clone() compatible with ZA lazy saving (git-fixes)
- commit 958752f
* Fri May 30 2025 ykaukab@suse.de
- kABI: update definitions after genksyms update
  Restore arm64 kABI definitions as following patch fixed genksyms issue:
  https://lore.kernel.org/linux-kbuild/20250527142318.14175-1-petr.pavlu@suse.com/
- commit 0244242
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: signal: Consistently read FPSIMD context (git-fixes)
- commit 58794fb
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: signal: Simplify preserve_tpidr2_context() (git-fixes)
- commit 6c25a15
* Fri May 30 2025 mfranc@suse.cz
- hypfs_create_cpu_files(): add missing check for hypfs_mkdir()
  failure (git-fixes bsc#1243839).
- s390/tlb: Use mm_has_pgste() instead of mm_alloc_pgste()
  (git-fixes bsc#1243840).
- commit cd720c1
* Fri May 30 2025 ggherdovich@suse.cz
- cpufreq: scpi: Fix null-ptr-deref in scpi_cpufreq_get_rate()
  (bsc#1242875 CVE-2025-37829).
- commit 48ff1cf
* Fri May 30 2025 ggherdovich@suse.cz
- cpufreq: scmi: Fix null-ptr-deref in scmi_cpufreq_get_rate()
  (bsc#1242860 CVE-2025-37830).
- commit c157f2a
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: ptrace: Gracefully handle errors (git-fixes)
- commit 4628747
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: ptrace: Mandate SVE payload for streaming-mode state (git-fixes)
- commit fc027c7
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: ptrace: Do not present register data for inactive mode (git-fixes)
- commit a5f9b46
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: ptrace: Save task state before generating SVE header (git-fixes)
- commit 5fbb1e4
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: Clear PSTATE.SM during clone() (git-fixes)
- commit 7019526
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: Consistently preserve FPSIMD state during clone() (git-fixes)
- commit 3571c11
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: Remove redundant task->mm check (git-fixes)
- commit 18353bd
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: signal: Use SMSTOP behaviour in setup_return() (git-fixes)
- commit 7171c52
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: signal: Mandate SVE payload for streaming-mode state (git-fixes)
- commit 8081e49
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: signal: Clear PSTATE.SM when restoring FPSIMD frame (git-fixes)
- commit c18043d
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: signal: Clear TPIDR2 when delivering signals (git-fixes)
- commit b7319ad
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: signal32: Always save+flush state early (git-fixes)
- commit 2c12b65
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: ptrace/prctl: Ensure VL changes leave task in a valid (git-fixes)
- commit eee117a
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: ptrace/prctl: Ensure VL changes do not resurrect stale (git-fixes)
- commit 6fdd7ce
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: Add task_smstop_sm() (git-fixes)
- commit 2b4d7f8
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: Factor out {sve,sme}_state_size() helpers (git-fixes)
- commit 75d2e8f
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: Clarify sve_sync_*() functions (git-fixes)
- commit b1c77e1
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: ptrace: Consistently handle partial writes to (git-fixes)
- commit e488352
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: Do not discard modified SVE state (git-fixes)
- commit 399b562
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: Avoid warning when sve_to_fpsimd() is unused (git-fixes)
- commit 970f616
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: Avoid unnecessary per-CPU buffers for EFI runtime calls (git-fixes)
- commit b6b5636
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: signal: Always save+flush state early (git-fixes)
- commit 03d771f
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: Add fpsimd_save_and_flush_current_state() (git-fixes)
- commit 5b8e5fb
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: Fix merging of FPSIMD state during signal return (git-fixes)
- commit dbab629
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: Reset FPMR upon exec() (git-fixes)
- commit 8dda200
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: Avoid clobbering kernel FPSIMD state with SMSTOP (git-fixes)
- commit c32fbdc
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: Don't corrupt FPMR when streaming mode changes (git-fixes)
- commit 6a5279e
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: Discard stale CPU state when handling SME traps (git-fixes)
- commit afd7c13
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: Remove opportunistic freeing of SME state (git-fixes)
- commit 017ab7e
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: Remove redundant SVE trap manipulation (git-fixes)
- commit 88e70b0
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: Remove unused fpsimd_force_sync_to_sve() (git-fixes)
- commit ec25502
* Fri May 30 2025 iivanov@suse.de
- arm64/fpsimd: Avoid RES0 bits in the SME trap handler (git-fixes)
- commit 0d0c04f
* Thu May 29 2025 krisman@suse.de
- io_uring/net: fix io_req_post_cqe abuse by send bundle
  (CVE-2025-23154 bsc#1242533).
- commit 2870613
* Thu May 29 2025 jlee@suse.com
- mtd: phram: Add the kernel lock down check (bsc#1232649).
- commit 984e9a9
* Thu May 29 2025 krisman@suse.de
- io_uring: always do atomic put from iowq (CVE-2025-37804
  bsc#1242854).
- commit cd0bf60
* Thu May 29 2025 mfranc@suse.cz
- s390/bpf: Store backchain even for leaf progs (git-fixes
  bsc#1243803).
- commit d2e89ff
* Thu May 29 2025 ggherdovich@suse.cz
- cpufreq: apple-soc: Fix null-ptr-deref in
  apple_soc_cpufreq_get_rate() (bsc#1242861 CVE-2025-37831).
- commit bb8e639
* Thu May 29 2025 msuchanek@suse.de
- selftests/mm: vm_util: split up /proc/self/smaps parsing
  (bsc#1243354 ltc#213242).
- commit e8e0348
* Thu May 29 2025 ailiop@suse.com
- svcrdma: Reduce the number of rdma_rw contexts per-QP
  (git-fixes).
- commit 978dec2
* Thu May 29 2025 ailiop@suse.com
- svcrdma: Unregister the device if svc_rdma_accept() fails
  (git-fixes).
- commit 8ddd85f
* Thu May 29 2025 ailiop@suse.com
- nfsd: Initialize ssc before laundromat_work to prevent NULL
  dereference (git-fixes).
- commit a2f7bec
* Thu May 29 2025 ailiop@suse.com
- NFSD: unregister filesystem in case genl_register_family()
  fails (git-fixes).
- commit f290746
* Thu May 29 2025 osalvador@suse.de
- mm: memory-failure: enhance comments for return value of
  memory_failure() (CVE-2022-49145 bsc#1238162).
- commit 2586946
* Thu May 29 2025 osalvador@suse.de
- mm/hwpoison: do not send SIGBUS to processes with recovered
  clean pages (CVE-2022-49145 bsc#1238162).
- commit ac8ff11
* Thu May 29 2025 osalvador@suse.de
- x86/mce: use is_copy_from_user() to determine copy-from-user
  context (CVE-2025-39989 bsc#1241629).
- commit 4cc844d
* Thu May 29 2025 tonyj@suse.de
- perf/core: Fix WARN_ON(!ctx) in __free_event() for partial init
  (bsc#1243235 CVE-2025-37878).
- commit ee25a1b
* Wed May 28 2025 dsterba@suse.com
- perf/dwc_pcie: fix duplicate pci_dev devices (CVE-2025-37746 bsc#1242885)
- commit dea67be
* Wed May 28 2025 dsterba@suse.com
- perf/dwc_pcie: Qualify RAS DES VSEC Capability by Vendor, Revision (bsc#1242885)
- commit ffcf22b
* Wed May 28 2025 dsterba@suse.com
- isofs: Prevent the use of too small fid (CVE-2025-37780 bsc#1242786)
- commit 5c5ba6b
* Wed May 28 2025 dsterba@suse.com
- ext4: fix off-by-one error in do_split (CVE-2025-23150 bsc#1242513)
- commit 0080833
* Wed May 28 2025 dsterba@suse.com
- net: dsa: mv88e6xxx: avoid unregistering devlink regions which were never registered (CVE-2025-37787 bsc#1242585)
- commit 9e7d0f2
* Wed May 28 2025 pfalcato@suse.de
- xfrm: Fix UDP GRO handling for some corner cases (git-fixes).
- commit 1c0c1c5
* Wed May 28 2025 pfalcato@suse.de
- espintcp: fix skb leaks (git-fixes).
- commit 15cdb39
* Wed May 28 2025 pfalcato@suse.de
- xsk: Bring back busy polling support in XDP_COPY (git-fixes).
- commit 6c2f2b4
* Wed May 28 2025 pfalcato@suse.de
- net/tls: fix kernel panic when alloc_page failed (git-fixes).
- commit 92ec148
* Wed May 28 2025 pfalcato@suse.de
- gre: Fix again IPv6 link-local address generation (git-fixes).
- commit c3ee537
* Wed May 28 2025 pfalcato@suse.de
- net: lwtunnel: fix recursion loops (git-fixes).
- commit 9d17465
* Wed May 28 2025 pfalcato@suse.de
- tcp/dccp: allow a connection when sk_max_ack_backlog is zero
  (git-fixes).
- commit 28fd02b
* Wed May 28 2025 pfalcato@suse.de
- netpoll: Use rcu_access_pointer() in __netpoll_setup
  (git-fixes).
- commit bc4dbd6
* Wed May 28 2025 pfalcato@suse.de
- net: ipv4: Cache pmtu for all packet paths if multipath enabled
  (git-fixes).
- commit 5efb982
* Wed May 28 2025 pfalcato@suse.de
- ipv4: Convert ip_route_input() to dscp_t (git-fixes).
- commit 2191938
* Wed May 28 2025 pfalcato@suse.de
- ipv4: Convert icmp_route_lookup() to dscp_t (git-fixes).
- commit 24dfb21
* Wed May 28 2025 jgross@suse.com
- vfio/pci: Virtualize zero INTx PIN if no pdev->irq
  (bsc#1241486).
- commit b964ce4
* Wed May 28 2025 shung-hsi.yu@suse.com
- arm64: proton-pack: Add new CPUs 'k' values for branch
  mitigation (bsc#1242778).
- arm64: bpf: Only mitigate cBPF programs loaded by unprivileged
  users (bsc#1242778 bsc#1243660 CVE-2025-37963).
- arm64: bpf: Add BHB mitigation to the epilogue for cBPF programs
  (bsc#1242778 bsc#1243649 CVE-2025-37948).
- arm64: proton-pack: Expose whether the branchy loop k value
  (bsc#1242778).
- arm64: proton-pack: Expose whether the platform is mitigated
  by firmware (bsc#1242778).
- arm64: insn: Add support for encoding DSB (bsc#1242778).
- commit 994f7ea
* Wed May 28 2025 shung-hsi.yu@suse.com
- x86/bhi: Do not set BHI_DIS_S in 32-bit mode (bsc#1242778).
- x86/bpf: Add IBHF call at end of classic BPF (bsc#1242778).
- x86/bpf: Call branch history clearing sequence on exit
  (bsc#1242778).
- commit 03f85af
* Wed May 28 2025 dsterba@suse.com
- net: libwx: handle page_pool_dev_alloc_pages error (CVE-2025-37755 bsc#1242506)
- commit f2b10a7
* Wed May 28 2025 dsterba@suse.com
- virtiofs: add filesystem context source name check (CVE-2025-37773 bsc#1242502).
- commit b34e55c
* Wed May 28 2025 dsterba@suse.com
- net_sched: skbprio: Remove overly strict queue assertions (CVE-2025-38637 bsc#1241657)
- commit 688fda2
* Wed May 28 2025 dsterba@suse.com
- fs/9p: fix NULL pointer dereference on mkdir (CVE-2025-22070 bsc#1241305)
- commit 77c1602
* Wed May 28 2025 wqu@suse.com
- btrfs: zoned: fix extent range end unlock in cow_file_range()
  (bsc#1239514).
- commit 6f500d2
* Wed May 28 2025 wqu@suse.com
- btrfs: do proper folio cleanup when run_delalloc_nocow()
  failed (CVE-2024-57975 bsc#1239099).
- commit 1c61c63
* Wed May 28 2025 wqu@suse.com
- btrfs: do proper folio cleanup when cow_file_range()  failed
  (CVE-2024-57976 bsc#1239100).
- commit a599667
* Wed May 28 2025 wqu@suse.com
- btrfs: simplify range tracking in cow_file_range()
  (bsc#1239514).
- commit 31063e8
* Wed May 28 2025 wqu@suse.com
- btrfs: fix error handling of submit_uncompressed_range()
  (bsc#1243744).
- commit 923ac9f
* Wed May 28 2025 wqu@suse.com
- btrfs: fix double accounting race when  extent_writepage_io()
  failed (bsc#1243743).
- commit f484c24
* Wed May 28 2025 wqu@suse.com
- btrfs: do not assume the full page range is not dirty in
  extent_writepage_io() (bsc#1239514).
- commit 06b104d
* Wed May 28 2025 wqu@suse.com
- btrfs: fix double accounting race when
  btrfs_run_delalloc_range() failed (CVE-2024-58089 bsc#1239514).
- commit b3345e8
* Wed May 28 2025 wqu@suse.com
- btrfs: use btrfs_inode in extent_writepage() (bsc#1239514).
- commit 06adcd7
* Wed May 28 2025 wqu@suse.com
- btrfs: rename btrfs_folio_(set|start|end)_writer_lock()
  (bsc#1239514).
- commit 7ce4bd6
* Wed May 28 2025 wqu@suse.com
- btrfs: unify to use writer locks for subpage locking
  (bsc#1239514).
- commit 9a6e0a9
* Wed May 28 2025 wqu@suse.com
- btrfs: remove unused btrfs_folio_start_writer_lock()
  (bsc#1239514).
- commit 9326b94
* Wed May 28 2025 wqu@suse.com
- btrfs: mark all dirty sectors as locked inside
  writepage_delalloc() (bsc#1239514).
- commit 760b074
* Wed May 28 2025 wqu@suse.com
- btrfs: move the delalloc range bitmap search into  extent_io.c
  (bsc#1239514).
- commit fd2855a
* Wed May 28 2025 dsterba@suse.com
- net: fix NULL pointer dereference in l3mdev_l3_rcv (CVE-2025-22103 bsc#1241448)
- commit 694b073
* Wed May 28 2025 dsterba@suse.com
- udmabuf: fix a buf size overflow issue during udmabuf creation (CVE-2025-37803 bsc#1242852)
- commit 2b275c3
* Tue May 27 2025 ohering@suse.de
- add bug reference for an existing hv_netvsc change (bsc#1243737).
- commit c741e73
* Tue May 27 2025 petr.pavlu@suse.com
- genksyms: Fix enum consts from a reference affecting new values.
- commit 2ee402c
* Tue May 27 2025 mfranc@suse.cz
- s390/pci: Serialize device addition and removal (git-fixes
  bsc#1243729).
- s390/pci: Allow re-add of a reserved but not yet removed device
  (git-fixes bsc#1243727).
- s390/pci: Remove redundant bus removal and disable from
  zpci_release_device() (git-fixes bsc#1243728).
- commit e9987df
* Tue May 27 2025 pfalcato@suse.de
- scsi: ufs: mcq: Add NULL check in ufshcd_mcq_abort()
  (CVE-2025-37828 bsc#1242869).
- commit 8116e01
* Tue May 27 2025 ailiop@suse.com
- xfs: don't assume perags are initialised when trimming AGs
  (git-fixes).
- commit 67a3805
* Tue May 27 2025 ailiop@suse.com
- erofs: avoid using multiple devices with different type
  (git-fixes).
- commit 0af5a86
* Tue May 27 2025 ailiop@suse.com
- erofs: fix file handle encoding for 64-bit NIDs (git-fixes).
- commit 740cd9e
* Tue May 27 2025 pfalcato@suse.de
- net_sched: hfsc: Fix a potential UAF in hfsc_dequeue() too
  (CVE-2025-37823 bsc#1242924).
- commit caed7b7
* Tue May 27 2025 dsterba@suse.com
- btrfs: zoned: return EIO on RAID1 block group write pointer mismatch (CVE-2025-37827 bsc#1242876)
- commit c5ee090
* Tue May 27 2025 dsterba@suse.com
- team: better TEAM_OPTION_TYPE_STRING validation (CVE-2025-21787 bsc#1238774)
- commit 857f4eb
* Tue May 27 2025 dsterba@suse.com
- scsi: ufs: bsg: Set bsg_queue to NULL after removal (CVE-2024-54458 bsc#1238992)
- commit 3efcbdb
* Tue May 27 2025 hare@suse.de
- cxl: Fix warning from emitting resource_size_t as long long
  int on 32bit systems (bsc#1241258).
- commit 536fb73
* Mon May 26 2025 dsterba@suse.com
- pfifo_tail_enqueue: Drop new packet when sch->limit == 0 (CVE-2025-21702 bsc#1237312)
- commit e108fd0
* Mon May 26 2025 dsterba@suse.com
- ptp: Ensure info->enable callback is always set (CVE-2025-21814 bsc#1238473)
- commit 0465308
* Mon May 26 2025 ykaukab@suse.de
- kABI: arm64: delete definitions
  kABI checks are currently broken for arm64 and causing most of the
  branches to fail integration tests. Remove arm64 kABI files to
  workaround till this issue is fixed.
- commit dfeef4c
* Mon May 26 2025 oneukum@suse.com
- Revert "rndis_host: Flag RNDIS modems as WWAN devices"
  (git-fixes).
- commit 2a0aeda
* Mon May 26 2025 hare@suse.com
- kernel/range: Const-ify range_contains parameters (bsc#1241258).
- commit b9d16ed
* Mon May 26 2025 hare@suse.com
- cxl: core/region - ignore interleave granularity when ways=1 (bsc#1241258).
- cxl: Add extended linear cache address alias emission for cxl events (bsc#1241258).
- acpi/hmat / cxl: Add extended linear cache support for CXL
  (bsc#1241258).
- acpi: numa: Add support to enumerate and store extended linear
  address mode (bsc#1241258).
- cxl: core/region - ignore interleave granularity when ways=1 (bsc#1241258).
- cxl: Add extended linear cache address alias emission for cxl events (bsc#1241258).
- acpi/hmat / cxl: Add extended linear cache support for CXL
  (bsc#1241258).
- acpi: numa: Add support to enumerate and store extended linear
  address mode (bsc#1241258).
- commit 95333c7
* Mon May 26 2025 hare@suse.com
- scripts/python/git_sort/git_sort.yaml: Add 'cxl/next'
  Add 'cxl/next' tree for git sort.
- commit 61a26cf
* Mon May 26 2025 mfranc@suse.cz
- s390/pci: Fix missing check for zpci_create_device() error
  return (git-fixes CVE-2025-37974 bsc#1243547).
- commit 8413a5a
* Mon May 26 2025 mfranc@suse.cz
- s390/entry: Fix last breaking event handling in case of stack
  corruption (git-fixes bsc#1243654).
- KVM: s390: Don't use %%pK through debug printing (git-fixes
  bsc#1243652).
- KVM: s390: Don't use %%pK through tracepoints (git-fixes
  bsc#1243653).
- commit c3b5d9b
* Mon May 26 2025 ykaukab@suse.de
- kABI: arm64: drop second PIDTYPE_MAX definition
  scripts/update-symvers is adding a second PIDTYPE_MAX definition which
  is causing kbuild failures. Remove it manually as a workaround till the
  source of the issue is identified.
- commit 467e42f
* Sun May 25 2025 tiwai@suse.de
- spi: spi-fsl-dspi: Reset SR flags before sending a new message
  (git-fixes).
- spi: spi-fsl-dspi: Halt the module after a new message transfer
  (git-fixes).
- spi: spi-fsl-dspi: restrict register range for regmap access
  (git-fixes).
- spi: use container_of_cont() for to_spi_device() (git-fixes).
- commit 96f52d2
* Sat May 24 2025 lduncan@suse.com
- loop: don't require ->write_iter for writable files in
  loop_configure (git-fixes).
- commit e9b3c58
* Sat May 24 2025 tiwai@suse.de
- drm/amd: Add Suspend/Hibernate notification callback support
  (stable-fixes).
- Refresh
  patches.suse/drm-amd-Keep-display-off-while-going-into-S4.patch.
- commit da887b2
* Sat May 24 2025 tiwai@suse.de
- accel/ivpu: Refactor functions in ivpu_fw_log.c (stable-fixes).
- Refresh patches.suse/accel-ivpu-Add-coredump-support.patch.
- commit 0c5d673
* Sat May 24 2025 tiwai@suse.de
- accel/ivpu: Reset fw log on cold boot (stable-fixes).
- Refresh patches.suse/accel-ivpu-Add-coredump-support.patch.
- commit 836180c
* Sat May 24 2025 tiwai@suse.de
- Revert "drm/amd: Keep display off while going into S4"
  (git-fixes).
- drm/edid: fixed the bug that hdr metadata was not reset
  (git-fixes).
- thermal: intel: x86_pkg_temp_thermal: Fix bogus trip temperature
  (git-fixes).
- platform/x86: think-lmi: Fix attribute name usage for
  non-compliant items (git-fixes).
- pmdomain: core: Fix error checking in
  genpd_dev_pm_attach_by_id() (git-fixes).
- pmdomain: renesas: rcar: Remove obsolete nullify checks
  (git-fixes).
- can: slcan: allow reception of short error messages (git-fixes).
- can: bcm: add missing rcu read protection for procfs content
  (git-fixes).
- can: bcm: add locking for bcm_op runtime updates (git-fixes).
- Bluetooth: btusb: use skb_pull to avoid unsafe access in QCA
  dump handling (git-fixes).
- Bluetooth: L2CAP: Fix not checking l2cap_chan security level
  (git-fixes).
- ASoc: SOF: topology: connect DAI to a single DAI link
  (git-fixes).
- ASoC: SOF: Intel: hda-bus: Use PIO mode on ACE2+ platforms
  (git-fixes).
- ASoC: SOF: ipc4-pcm: Delay reporting is only supported for
  playback direction (git-fixes).
- ASoC: SOF: ipc4-control: Use SOF_CTRL_CMD_BINARY as numid for
  bytes_ext (git-fixes).
- drm/amd/display: Avoid flooding unnecessary info messages
  (git-fixes).
- drm/amd/display: Correct the reply value when AUX write
  incomplete (git-fixes).
- drm/amdgpu: fix incorrect MALL size for GFX1151 (stable-fixes).
- drm/amdgpu: csa unmap use uninterruptible lock (stable-fixes).
- ALSA: usb-audio: Add sample rate quirk for Microdia JP001 USB
  Camera (stable-fixes).
- HID: bpf: abort dispatch if device destroyed (git-fixes).
- HID: uclogic: Add NULL check in uclogic_input_configured()
  (git-fixes).
- HID: thrustmaster: fix memory leak in thrustmaster_interrupts()
  (git-fixes).
- wifi: mt76: disable napi on driver removal (git-fixes).
- wifi: mac80211: Set n_channels after allocating struct
  cfg80211_scan_request (git-fixes).
- drm/amdgpu: fix pm notifier handling (git-fixes).
- Revert "drm/amd: Stop evicting resources on APUs in suspend"
  (stable-fixes).
- accel/ivpu: Fix fw log printing (stable-fixes).
- accel/ivpu: Rename ivpu_log_level to fw_log_level
  (stable-fixes).
- commit 6014984
* Fri May 23 2025 tonyj@suse.de
- perf vendor events: Add Clearwaterforest events (jsc#PED-10528).
- commit fe52204
* Fri May 23 2025 msuchanek@suse.de
- Update patches.suse/book3s64-radix-Align-section-vmemmap-start-address-t.patch
  (bsc#1238318 bsc#1243298 ltc#212689).
- commit 1e96a7d
* Fri May 23 2025 ykaukab@suse.de
- kABI: arm64: fix put_pid_ns definition
  arm64 -rt build is currently failing in ibs so its definition is not
  updated yet.
- commit 576371e
* Fri May 23 2025 nik.borisov@suse.com
- x86/speculation: Remove the extra #ifdef around CALL_NOSPEC (bsc#1242006 CVE-2024-28956).
- commit 92a4d4d
* Fri May 23 2025 nik.borisov@suse.com
- x86/speculation: Add a conditional CS prefix to CALL_NOSPEC (bsc#1242006 CVE-2024-28956).
- commit 0e463b4
* Fri May 23 2025 nik.borisov@suse.com
- x86/speculation: Simplify and make CALL_NOSPEC consistent (bsc#1242006 CVE-2024-28956).
- commit 18673e3
* Fri May 23 2025 jlee@suse.com
- supported.conf: set einj module to unsupported (bsc#1243232)
  Finally we still build EINJ as module on SLE16 but set it to
  unsupported. (bsc#1243232)
  The original plan is removing EINJ module from SLE16 kernel because it
  should NOT be used on production system. (bsc#1023051 CVE-2016-3695)
  But then Lenovo raised that they need einj module for testing RAS
  features. We do not have a approach for shipping a module to partner
  for testing only. So we build EINJ as module on SLE16 but set it to
  unsupported. Which means that EINJ module will be included in
  kernel-default-extra package. (bsc#1243232)
  User can still grab signed EINJ module from kernel-default-extra through
  Leap repo on OBS. So we continue maintain a downstream patch to lock down
  EINJ.
- Refresh
  patches.suse/acpi-Disable-APEI-error-injection-if-the-kernel-is-lockeddown.patch.
  (bsc#1243232 bsc#1023051 CVE-2016-3695)
- Update config files.
    x86_64/default
  CONFIG_ACPI_APEI_EINJ=m
  [#] CONFIG_ACPI_APEI_EINJ_CXL is not set
- commit 96a1c16
* Thu May 22 2025 lduncan@suse.com
- loop: Add sanity check for read/write_iter (git-fixes).
- commit 6c2e9cd
* Thu May 22 2025 tbogendoerfer@suse.de
- net/niu: Niu requires MSIX ENTRY_DATA fields touch before
  entry reads (CVE-2025-37833 bsc#1242868).
- commit 720f829
* Thu May 22 2025 jroedel@suse.de
- tpm: Add SNP SVSM vTPM driver (bsc#1241191).
- Update config files.
- supported.conf: Add SNP SVSM vTPM driver
- commit 0f75d8f
* Thu May 22 2025 nik.borisov@suse.com
- platform/x86/intel/ifs: Add Clearwater Forest to CPU support list (jsc#PED-10558).
- commit 718d39f
* Wed May 21 2025 ykaukab@suse.de
- kABI: freeze it
  Generated on commit a36af99b035b ("Merge branch 'users/tiwai/SL-16.0/for-next' into SL-16.0")
- commit 2f7ad33
* Wed May 21 2025 fdmanana@suse.com
- btrfs: check folio mapping after unlock in put_file_data()
  (git-fixes).
- commit af1da2c
* Wed May 21 2025 fdmanana@suse.com
- btrfs: don't loop for nowait writes when checking for cross
  references (git-fixes).
- commit 8661911
* Wed May 21 2025 fdmanana@suse.com
- btrfs: fix improper generation check in snapshot delete
  (git-fixes).
- commit 3532f6f
* Wed May 21 2025 fdmanana@suse.com
- btrfs: fix missing snapshot drew unlock when root is dead
  during swap activation (bsc#1241204).
- commit ee4fa40
* Wed May 21 2025 fdmanana@suse.com
- btrfs: fix folio leak in submit_one_async_extent() (git-fixes).
- commit 78685ec
* Wed May 21 2025 fdmanana@suse.com
- btrfs: fix reclaimed bytes accounting after automatic block
  group reclaim (git-fixes).
- btrfs: get used bytes while holding lock at
  btrfs_reclaim_bgs_work() (git-fixes).
- btrfs: get zone unusable bytes while holding lock at
  btrfs_reclaim_bgs_work() (git-fixes).
- btrfs: fix reclaimed bytes accounting after automatic block
  group reclaim (git-fixes).
- btrfs: get used bytes while holding lock at
  btrfs_reclaim_bgs_work() (git-fixes).
- btrfs: get zone unusable bytes while holding lock at
  btrfs_reclaim_bgs_work() (git-fixes).
- commit 2eb9b7c
* Wed May 21 2025 fdmanana@suse.com
- btrfs: fix a leaked chunk map issue in read_one_chunk()
  (git-fixes).
- commit f35fbb4
* Wed May 21 2025 fdmanana@suse.com
- btrfs: avoid monopolizing a core when activating a swap file
  (git-fixes).
- commit 2db5c34
* Wed May 21 2025 fdmanana@suse.com
- btrfs: allow swap activation to be interruptible (git-fixes).
- commit 17cd587
* Wed May 21 2025 fdmanana@suse.com
- btrfs: fix swap file activation failure due to extents that
  used to be shared (bsc#1241204).
- commit 97cbdcc
* Wed May 21 2025 fdmanana@suse.com
- btrfs: fix race with memory mapped writes when activating swap
  file (bsc#1241204).
- commit 2943521
* Wed May 21 2025 fdmanana@suse.com
- btrfs: fix stale page cache after race between readahead and
  direct IO write (git-fixes).
- btrfs: rename __get_extent_map() and pass btrfs_inode
  (git-fixes).
- btrfs: fix stale page cache after race between readahead and
  direct IO write (git-fixes).
- btrfs: rename __get_extent_map() and pass btrfs_inode
  (git-fixes).
- commit eedd048
* Wed May 21 2025 iivanov@suse.de
- iommu/arm-smmu-v3: Fix pgsize_bit for sva domains (bsc#1243341)
- commit 95c386e
* Wed May 21 2025 tiwai@suse.de
- crypto: algif_hash - fix double free in hash_accept (git-fixes).
- padata: do not leak refcount in reorder_work (git-fixes).
- Bluetooth: hci_event: Fix not using key encryption size when
  its known (git-fixes).
- Bluetooth: MGMT: Fix MGMT_OP_ADD_DEVICE invalid device flags
  (git-fixes).
- Bluetooth: btnxpuart: Handle bootloader error during cmd5 and
  cmd7 (git-fixes).
- Bluetooth: btnxpuart: Add correct bootloader error codes
  (git-fixes).
- Bluetooth: btusb: Fix regression in the initialization of fake
  Bluetooth controllers (git-fixes).
- commit 65e80ed
* Tue May 20 2025 tonyj@suse.de
- perf: Fix hang while freeing sigtrap event (bsc#1242520
  CVE-2025-37747).
- commit 6aa371b
* Tue May 20 2025 fdmanana@suse.com
- btrfs: fix non-empty delayed iputs list on unmount due to
  compressed write workers (git-fixes).
- commit 62a7e9f
* Tue May 20 2025 fdmanana@suse.com
- btrfs: fix discard worker infinite loop after disabling discard
  (bsc#1242012).
- commit 19ab462
* Tue May 20 2025 fdmanana@suse.com
- btrfs: fix hole expansion when writing at an offset beyond EOF
  (bsc#1241151).
- commit 8f434d2
* Tue May 20 2025 ailiop@suse.com
- NFSv4/pnfs: Reset the layout state after a layoutreturn
  (git-fixes).
- commit f1c7782
* Tue May 20 2025 ailiop@suse.com
- nfs: handle failure of nfs_get_lock_context in unlock path
  (git-fixes).
- commit c89f442
* Tue May 20 2025 trenn@suse.de
- platform/x86/intel/pmc: Disable C1 auto-demotion during suspend
  (jsc#PED-12855).
- commit 9c3ceb9
* Tue May 20 2025 wqu@suse.com
- btrfs: avoid NULL pointer dereference if no valid csum tree
  (bsc#1243342).
- commit 78306f4
* Tue May 20 2025 wqu@suse.com
- btrfs: avoid NULL pointer dereference if no valid extent tree
  (bsc#1236208).
- commit 2b0bc81
* Tue May 20 2025 wqu@suse.com
- btrfs: adjust subpage bit start based on sectorsize
  (bsc#1241492).
- commit 8f98bfc
* Mon May 19 2025 tiwai@suse.de
- Input: xpad - fix Share button on Xbox One controllers
  (stable-fixes).
- Input: synaptics - enable InterTouch on Dell Precision M3800
  (stable-fixes).
- Input: synaptics - enable InterTouch on TUXEDO InfinityBook
  Pro 14 v5 (stable-fixes).
- Input: synaptics - enable InterTouch on Dynabook Portege X30L-G
  (stable-fixes).
- Input: synaptics - enable InterTouch on Dynabook Portege X30-D
  (stable-fixes).
- Input: synaptics - enable SMBus for HP Elitebook 850 G1
  (stable-fixes).
- Input: xpad - add support for 8BitDo Ultimate 2 Wireless
  Controller (stable-fixes).
- drm/xe/tests/mocs: Hold XE_FORCEWAKE_ALL for LNCF regs
  (git-fixes).
- drm/amdgpu/vcn: using separate VCN1_AON_SOC offset
  (stable-fixes).
- drm/amd/display: Fix the checking condition in dmub aux handling
  (stable-fixes).
- drm/amd/display: more liberal vmin/vmax update for freesync
  (stable-fixes).
- drm/v3d: Add job to pending list if the reset was skipped
  (stable-fixes).
- Bluetooth: btmtk: Remove the resetting step before downloading
  the fw (stable-fixes).
- Bluetooth: btmtk: Remove resetting mt7921 before downloading
  the fw (stable-fixes).
- drm/xe/tests/mocs: Update xe_force_wake_get() return handling
  (stable-fixes).
- commit c7fcf05
* Mon May 19 2025 dwagner@suse.de
- update metadata
- Update
  patches.suse/nvme-fixup-scan-failure-for-non-ANA-multipath-contro.patch
  (jsc#PED-9651 bsc#1235149).
- Update
  patches.suse/nvme-re-read-ANA-log-page-after-ns-scan-completes.patch
  (jsc#PED-9651 bsc#1235149).
- commit fec09ab
* Mon May 19 2025 ohering@suse.de
- Drivers: hv: vmbus: Remove vmbus_sendpacket_pagebuffer() (git-fixes).
- hv_netvsc: Remove rmsg_pgcnt (git-fixes).
- hv_netvsc: Preserve contiguous PFN grouping in the page buffer array (git-fixes).
- hv_netvsc: Use vmbus_sendpacket_mpb_desc() to send VMBus messages (git-fixes).
- Drivers: hv: Allow vmbus_sendpacket_mpb_desc() to create multiple ranges (git-fixes).
- RDMA/mana_ib: Fix integer overflow during queue creation (git-fixes).
- RDMA/mana_ib: Handle net event for pointing to the current netdev (git-fixes).
- net: mana: Change the function signature of mana_get_primary_netdev_rcu (git-fixes).
- RDMA/mana_ib: Use safer allocation function() (git-fixes).
- RDMA/mana_ib: Implement DMABUF MR support (git-fixes).
- RDMA/mana_ib: Fix error code in probe() (git-fixes).
- RDMA/mana_ib: Add port statistics support (git-fixes).
- RDMA/mana_ib: request error CQEs when supported (git-fixes).
- RDMA/mana_ib: Query feature_flags bitmask from FW (git-fixes).
- RDMA/mana_ib: indicate CM support (git-fixes).
- RDMA/mana_ib: polling of CQs for GSI/UD (git-fixes).
- RDMA/mana_ib: extend mana QP table (git-fixes).
- RDMA/mana_ib: implement req_notify_cq (git-fixes).
- RDMA/mana_ib: UD/GSI work requests (git-fixes).
- RDMA/mana_ib: create/destroy AH (git-fixes).
- RDMA/mana_ib: UD/GSI QP creation for kernel (git-fixes).
- RDMA/mana_ib: Create and destroy UD/GSI QP (git-fixes).
- RDMA/mana_ib: create kernel-level CQs (git-fixes).
- RDMA/mana_ib: helpers to allocate kernel queues (git-fixes).
- RDMA/mana_ib: implement get_dma_mr (git-fixes).
- RDMA/mana_ib: Allow registration of DMA-mapped memory in PDs (git-fixes).
- commit 354638c
* Mon May 19 2025 tbogendoerfer@suse.de
- octeontx2-pf: Do not reallocate all ntuple filters (git-fixes).
- netlink: specs: tc: all actions are indexed arrays (git-fixes).
- netlink: specs: tc: fix a couple of attribute names (git-fixes).
- octeontx2-pf: Fix ethtool support for SDP representors
  (git-fixes).
- net/mlx5e: Disable MACsec offload for uplink representor profile
  (git-fixes).
- net: qede: Initialize qede_ll_ops with designated initializer
  (git-fixes).
- ice: use DSN instead of PCI BDF for ice_adapter index
  (git-fixes).
- igc: fix lock order in igc_ptp_reset (git-fixes).
- idpf: protect shutdown from reset (git-fixes).
- idpf: fix potential memory leak on kcalloc() failure
  (git-fixes).
- bnxt_en: fix module unload sequence (git-fixes).
- bnxt_en: Fix ethtool -d byte order for 32-bit values
  (git-fixes).
- bnxt_en: Fix out-of-bound memcpy() during ethtool -w
  (git-fixes).
- bnxt_en: Fix coredump logic to free allocated buffer
  (git-fixes).
- bnxt_en: call pci_alloc_irq_vectors() after bnxt_reserve_rings()
  (git-fixes).
- bnxt_en: Add missing skb_mark_for_recycle() in bnxt_rx_vlan()
  (git-fixes).
- bnxt_en: Fix ethtool selftest output in one of the failure cases
  (git-fixes).
- bnxt_en: Fix error handling path in bnxt_init_chip()
  (git-fixes).
- idpf: fix offloads support for encapsulated packets (git-fixes).
- ice: Check VF VSI Pointer Value in ice_vc_add_fdir_fltr()
  (git-fixes).
- ice: fix Get Tx Topology AQ command error on E830 (git-fixes).
- bnxt_en: improve TX timestamping FIFO configuration (git-fixes).
- net/mlx5: E-switch, Fix error handling for enabling roce
  (git-fixes).
- net/mlx5e: Fix lock order in
  mlx5e_tx_reporter_ptpsq_unhealthy_recover (git-fixes).
- net/mlx5e: TC, Continue the attr process even if encap entry
  is invalid (git-fixes).
- net/mlx5: E-Switch, Initialize MAC Address for Default GID
  (git-fixes).
- net/mlx5e: Use custom tunnel header for vxlan gbp (git-fixes).
- pds_core: make wait_context part of q_info (CVE-2025-37886
  bsc#1242944).
- pds_core: handle unsupported PDS_CORE_CMD_FW_CONTROL result
  (CVE-2025-37887 bsc#1242962).
- ice: Remove unnecessary ice_is_e8xx() functions (git-fixes).
- ice: Don't check device type when checking GNSS presence
  (git-fixes).
- net: don't dump Tx and uninitialized NAPIs (git-fixes).
- netdev-genl: avoid empty messages in napi get (git-fixes).
- netdev-genl: avoid empty messages in queue dump (git-fixes).
- netdev: fix repeated netlink messages in queue dump (git-fixes).
- commit 18e8329
* Mon May 19 2025 nmorey@suse.com
- net: ppp: Add bound checking for skb data on ppp_sync_txmung (CVE-2025-37749 bsc#1242859)
- commit 37d30d4
* Mon May 19 2025 nmorey@suse.com
- netlabel: Fix NULL pointer exception caused by CALIPSO on IPv4 sockets (CVE-2025-22063 bsc#1241351)
- commit 948ed51
* Mon May 19 2025 msuchanek@suse.de
- rpm: Stop using is_kotd_qa macro
  This macro is set by bs-upload-kernel, and a conditional in each spec
  file is used to determine when to build the spec file.
  This logic should not really be in the spec file. Previously this was
  done with package links and package meta for the individula links.
  However, the use of package links is rejected for packages in git based
  release projects (nothing to do with git actually, new policy). An
  alternative to package links is multibuild. However, for multibuild
  packages package meta cannot be used to set which spec file gets built.
  Use prjcon buildflags instead, and remove this conditional. Depends on
  bs-upload-kernel adding the build flag.
- commit 9eb8a6f
* Mon May 19 2025 msuchanek@suse.de
- kernel-obs-qa: Use srchash for dependency as well
- commit 485ae1d
* Mon May 19 2025 jslaby@suse.cz
- scripts/common-functions: lower curl's connection timeout
  Set it to 2 seconds. Either it can reach the server or not...
  ftp.suse.com is currently unreachable and it takes minutes to have a
  reply from check-kernel-fixes.
- commit f9f1100
* Mon May 19 2025 mfranc@suse.cz
- Fix Patch-mainline tags.
- Refresh
  patches.suse/RDMA-core-Fix-KASAN-slab-use-after-free-Read-in-ib_r.patch.
- Refresh
  patches.suse/RDMA-rxe-Fix-slab-use-after-free-Read-in-rxe_queue_c.patch.
- commit a8f3f2a
* Mon May 19 2025 jslaby@suse.cz
- PCI/MSI: Handle the NOMASK flag correctly for all PCI/MSI
  backends (git-fixes).
- Refresh
  patches.suse/PCI-MSI-Add-an-option-to-write-MSIX-ENTRY_DATA-befor.patch.
- commit bedc18c
* Mon May 19 2025 jslaby@suse.cz
- s390/pci: Fix duplicate pci_dev_put() in disable_slot() when
  PF has child VFs (git-fixes).
- PCI/MSI: Convert pci_msi_ignore_mask to per MSI domain flag
  (git-fixes).
- commit 55e48e2
* Mon May 19 2025 heming.zhao@suse.com
- ocfs2: fix the issue with discontiguous allocation in the
  global_bitmap (git-fixes).
- commit 309b543
* Sun May 18 2025 tiwai@suse.de
- dmaengine: mediatek: drop unused variable (git-fixes).
- dmaengine: idxd: Fix ->poll() return value (git-fixes).
- phy: tegra: xusb: remove a stray unlock (git-fixes).
- commit 3ca33c7
* Sun May 18 2025 tiwai@suse.de
- dmaengine: fsl-edma: Fix return code for unhandled interrupts
  (git-fixes).
- dmaengine: mediatek: Fix a possible deadlock error in
  mtk_cqdma_tx_status() (git-fixes).
- dmaengine: idxd: Refactor remove call with idxd_cleanup()
  helper (git-fixes).
- dmaengine: idxd: Add missing idxd cleanup to fix memory leak
  in remove call (git-fixes).
- dmaengine: idxd: fix memory leak in error handling path of
  idxd_pci_probe (git-fixes).
- dmaengine: idxd: fix memory leak in error handling path of
  idxd_alloc (git-fixes).
- dmaengine: idxd: Add missing cleanups in cleanup internals
  (git-fixes).
- dmaengine: idxd: Add missing cleanup for early error out in
  idxd_setup_internals (git-fixes).
- dmaengine: idxd: fix memory leak in error handling path of
  idxd_setup_groups (git-fixes).
- dmaengine: idxd: fix memory leak in error handling path of
  idxd_setup_engines (git-fixes).
- dmaengine: idxd: fix memory leak in error handling path of
  idxd_setup_wqs (git-fixes).
- dmaengine: idxd: Fix allowing write() from different address
  spaces (git-fixes).
- dmaengine: ti: k3-udma: Add missing locking (git-fixes).
- dmaengine: ti: k3-udma: Use cap_mask directly from dma_device
  structure instead of a local copy (git-fixes).
- dmaengine: Revert "dmaengine: dmatest: Fix dmatest waiting
  less when interrupted" (git-fixes).
- phy: Fix error handling in tegra_xusb_port_init (git-fixes).
- phy: renesas: rcar-gen3-usb2: Set timing registers only once
  (git-fixes).
- phy: renesas: rcar-gen3-usb2: Fix role detection on unbind/bind
  (git-fixes).
- phy: tegra: xusb: Use a bitmask for UTMI pad power state
  tracking (git-fixes).
- soundwire: bus: Fix race on the creation of the IRQ domain
  (git-fixes).
- i2c: designware: Fix an error handling path in
  i2c_dw_pci_probe() (git-fixes).
- commit eac523c
* Sun May 18 2025 lduncan@suse.com
- loop: aio inherit the ioprio of original request (git-fixes).
- Refresh
  patches.suse/loop-stop-using-vfs_iter_-read-write-for-buffered-I-O.patch.
- commit 3ecd666
* Sat May 17 2025 lduncan@suse.com
- block: fix conversion of GPT partition name to 7-bit
  (git-fixes).
- block: fix 'kmem_cache of name 'bio-108' already exists'
  (git-fixes).
- commit 3799862
* Sat May 17 2025 tiwai@suse.de
- drm/xe: Save CTX_TIMESTAMP mmio value instead of LRC value
  (git-fixes).
- commit 239d430
* Sat May 17 2025 tiwai@suse.de
- dma-buf: insert memory barrier before updating num_fences
  (git-fixes).
- drm/meson: Use 1000ULL when operating with mode->clock
  (git-fixes).
- Revert "drm/amd/display: Hardware cursor changes color when
  switched to software cursor" (stable-fixes).
- ACPI: PPTT: Fix processor subtable walk (git-fixes).
- spi: tegra114: Use value to check for invalid delays
  (git-fixes).
- spi: loopback-test: Do not split 1024-byte hexdumps (git-fixes).
- regulator: max20086: fix invalid memory access (git-fixes).
- gpio: pca953x: fix IRQ storm on system wake up (git-fixes).
- ALSA: es1968: Add error handling for
  snd_pcm_hw_constraint_pow2() (git-fixes).
- ALSA: sh: SND_AICA should depend on SH_DMA_API (git-fixes).
- ALSA: usb-audio: Add sample rate quirk for Audioengine D1
  (git-fixes).
- ALSA: ump: Fix a typo of snd_ump_stream_msg_device_info
  (git-fixes).
- ALSA: seq: Fix delivery of UMP events to group ports
  (git-fixes).
- commit c704699
* Fri May 16 2025 lduncan@suse.com
- scsi: Improve CDL control (git-fixes).
- md/raid1: Add check for missing source disk in process_checks()
  (git-fixes).
- scsi: pm80xx: Set phy_attached to zero when device is gone
  (git-fixes).
- scsi: hisi_sas: Fix I/O errors caused by hardware port ID
  changes (git-fixes).
- scsi: mpi3mr: Avoid reply queue full condition (git-fixes).
- scsi: core: Use GFP_NOIO to avoid circular locking dependency
  (git-fixes).
- commit 0aaea76
* Fri May 16 2025 jroedel@suse.de
- x86/sev: Register tpm-svsm platform device (bsc#1241191).
- svsm: Add header with SVSM_VTPM_CMD helpers (bsc#1241191).
- x86/sev: Add SVSM vTPM probe/send_command functions
  (bsc#1241191).
- tpm: Make chip->{status,cancel,req_canceled} opt (bsc#1241191).
- commit a35885f
* Fri May 16 2025 nik.borisov@suse.com
- x86/its: Fix build errors when CONFIG_MODULES=n (git-fixes).
- commit ed63681
* Fri May 16 2025 nik.borisov@suse.com
- x86/ibt: Fix hibernate (git-fixes).
- commit 8f9d1f8
* Fri May 16 2025 nik.borisov@suse.com
- module: don't annotate ROX memory as kmemleak_not_leak() (git-fixes).
- commit d3cd47f
* Fri May 16 2025 nik.borisov@suse.com
- module: fix writing of livepatch relocations in ROX text (git-fixes).
- Refresh
  patches.suse/module-switch-to-execmem-API-for-remapping-as-RW-and-resto.patch.
- commit 422351f
* Fri May 16 2025 nik.borisov@suse.com
- x86/execmem: fix ROX cache usage in Xen PV guests (git-fixes).
- commit f9895f4
* Fri May 16 2025 mhocko@suse.com
- scripts/common-functions: fix sha_to_patch_in_branch
  sha_to_patch_in_branch f13abc1e8e1a3b7455511c4e122750127f6bc9b0 origin/SLE15-SP6
  returns
  origin/SLE15-SP6:patches.suse/watch_queue-fix-pipe-accounting-mismatch.patch
  which is obviously incorrect. We need to trim the branch name before
  filtering.
- commit e2cf22b
* Fri May 16 2025 tiwai@suse.de
- spi: fsl-qspi: Fix double cleanup in probe error path
  (CVE-2025-37842 bsc#1242951).
- spi: fsl-qspi: use devm function instead of driver remove
  (CVE-2025-37842 bsc#1242951).
- commit 60d462a
* Fri May 16 2025 nmorey@suse.com
- qibfs: fix _another_ leak (git-fixes)
- commit 62b6060
* Fri May 16 2025 pfalcato@suse.de
- mm/vma: add give_up_on_oom option on modify/merge, use in uffd
  release (CVE-2025-37760 bsc#1242726).
- commit 5e60119
* Fri May 16 2025 nmorey@suse.com
- RDMA/core: Fix "KASAN: slab-use-after-free Read in ib_register_device" problem (git-fixes)
- commit 86e6715
* Fri May 16 2025 nmorey@suse.com
- RDMA/rxe: Fix slab-use-after-free Read in rxe_queue_cleanup bug (git-fixes)
- commit 1900b07
* Fri May 16 2025 tiwai@suse.de
- tpm: Mask TPM RC in tpm2_start_auth_session() (git-fixes).
- commit 6d86701
* Fri May 16 2025 ddiss@suse.de
- ovl: don't allow datadir only (CVE-2025-37863 bsc#1242969).
- commit 56c14ec
* Thu May 15 2025 nik.borisov@suse.com
- x86/its: FineIBT-paranoid vs ITS (bsc#1242006 CVE-2024-28956).
- commit 053af3b
* Thu May 15 2025 nik.borisov@suse.com
- x86/ibt: Optimize the fineibt-bhi arity 1 case (git-fixes).
- commit 83c2d1c
* Thu May 15 2025 nik.borisov@suse.com
- x86/ibt: Implement FineIBT-BHI mitigation (git-fixes).
- commit 7af7513
* Thu May 15 2025 nik.borisov@suse.com
- x86/bhi: Add BHI stubs (git-fixes).
- commit 5c4d2d3
* Thu May 15 2025 nik.borisov@suse.com
- x86/ibt: Add paranoid FineIBT mode (git-fixes).
- commit 58c8356
* Thu May 15 2025 nik.borisov@suse.com
- x86/traps: Decode LOCK Jcc.d8 as #UD (git-fixes).
- commit c6f07d8
* Thu May 15 2025 nik.borisov@suse.com
- x86/ibt: Optimize the FineIBT instruction sequence (git-fixes).
- commit 5993f66
* Thu May 15 2025 nik.borisov@suse.com
- x86/traps: Decode 0xEA instructions as #UD (git-fixes).
- commit 6913267
* Thu May 15 2025 nik.borisov@suse.com
- x86/early_printk: Harden early_serial (git-fixes).
- commit bf7d518
* Thu May 15 2025 nik.borisov@suse.com
- x86/ibt: Clean up poison_endbr() (git-fixes).
- Refresh patches.suse/x86-ibt-Add-exact_endbr-helper.patch.
- commit 17b408c
* Thu May 15 2025 nik.borisov@suse.com
- x86/traps: Cleanup and robustify decode_bug() (git-fixes).
- commit a5c24d4
* Thu May 15 2025 nik.borisov@suse.com
- x86/alternative: Simplify callthunk patching (git-fixes).
- commit 1ba25b6
* Thu May 15 2025 nik.borisov@suse.com
- x86/boot: Mark start_secondary() with __noendbr (git-fixes).
- commit 22d80e7
* Thu May 15 2025 nik.borisov@suse.com
- objtool: Warn about unknown annotation types (git-fixes).
- commit e893f80
* Thu May 15 2025 nik.borisov@suse.com
- objtool: Fix ANNOTATE_REACHABLE to be a normal annotation (git-fixes).
- commit 52cfaf7
* Thu May 15 2025 nik.borisov@suse.com
- objtool: Convert {.UN}REACHABLE to ANNOTATE (git-fixes).
- commit 223c7d6
* Thu May 15 2025 nik.borisov@suse.com
- objtool: Remove annotate_{,un}reachable() (git-fixes).
- commit 2954713
* Thu May 15 2025 nik.borisov@suse.com
- unreachable: Unify (git-fixes).
- commit e72eec4
* Thu May 15 2025 nik.borisov@suse.com
- objtool: Collect more annotations in objtool.h (git-fixes).
- Refresh
  patches.suse/x86-its-Add-support-for-ITS-safe-indirect-thunk.patch.
- commit 0bcdfcd
* Thu May 15 2025 nik.borisov@suse.com
- objtool: Collapse annotate sequences (git-fixes).
- commit d9cc842
* Thu May 15 2025 nik.borisov@suse.com
- objtool: Convert ANNOTATE_INTRA_FUNCTION_CALL to ANNOTATE (git-fixes).
- commit c425677
* Thu May 15 2025 nik.borisov@suse.com
- objtool: Convert ANNOTATE_IGNORE_ALTERNATIVE to ANNOTATE (git-fixes).
- commit 384a5a4
* Thu May 15 2025 nik.borisov@suse.com
- objtool: Convert VALIDATE_UNRET_BEGIN to ANNOTATE (git-fixes).
- commit 6f86771
* Thu May 15 2025 nik.borisov@suse.com
- objtool: Convert instrumentation_{begin,end}() to ANNOTATE (git-fixes).
- commit 9d3ff83
* Thu May 15 2025 nik.borisov@suse.com
- objtool: Convert ANNOTATE_RETPOLINE_SAFE to ANNOTATE  (git-fixes).
- Refresh
  patches.suse/x86-its-Add-support-for-ITS-safe-indirect-thunk.patch.
- commit e2c7195
* Thu May 15 2025 nik.borisov@suse.com
- objtool: Convert ANNOTATE_NOENDBR to ANNOTATE (git-fixes).
- commit 727a06d
* Thu May 15 2025 nik.borisov@suse.com
- objtool: Generic annotation infrastructure (git-fixes).
- commit 0fba83d
* Thu May 15 2025 nik.borisov@suse.com
- x86/cfi: Clean up linkage (git-fixes).
- Refresh
  patches.suse/x86-bugs-Rename-entry_ibpb-to-write_ibpb.patch.
- Refresh
  patches.suse/x86-bugs-Use-SBPB-in-write_ibpb-if-applicable.patch.
- Refresh
  patches.suse/x86-its-Align-RETs-in-BHB-clear-sequence-to-avoid-thunking.patch.
- commit 6fb4977
* Thu May 15 2025 nik.borisov@suse.com
- x86,kcfi: Fix EXPORT_SYMBOL vs kCFI (git-fixes).
- commit 4e0ae6a
* Thu May 15 2025 nik.borisov@suse.com
- x86/ibt: Clean up is_endbr() (git-fixes).
- Refresh patches.suse/x86-ibt-Add-exact_endbr-helper.patch.
- commit 23dc2db
* Thu May 15 2025 nik.borisov@suse.com
- x86/alternatives: Clean up preprocessor conditional block comments (git-fixes).
- commit 8cb2529
* Thu May 15 2025 nik.borisov@suse.com
- x86/ibt: Add exact_endbr() helper (git-fixes).
- commit 6768e40
* Thu May 15 2025 nik.borisov@suse.com
- x86/ibt: Handle FineIBT in handle_cfi_failure() (git-fixes).
- commit e514559
* Thu May 15 2025 nik.borisov@suse.com
- x86/cfi: Add 'cfi=warn' boot option (git-fixes).
- commit 40703d1
* Thu May 15 2025 nik.borisov@suse.com
- x86/its: Use dynamic thunks for indirect branches (bsc#1242006 CVE-2024-28956).
- commit f7978bc
* Thu May 15 2025 nik.borisov@suse.com
- x86: re-enable EXECMEM_ROX support (git-fixes).
- commit f4fd78c
* Thu May 15 2025 nik.borisov@suse.com
- module: drop unused module_writable_address() (git-fixes).
- commit 49a69cd
* Thu May 15 2025 nik.borisov@suse.com
- Revert "x86/module: prepare module loading for ROX allocations of text" (git-fixes).
- Refresh
  patches.suse/x86-ibt-Keep-IBT-disabled-during-alternative-patching.patch.
- Refresh
  patches.suse/x86-its-Add-support-for-ITS-safe-return-thunk.patch.
- commit 4e57a83
* Thu May 15 2025 nik.borisov@suse.com
- module: switch to execmem API for remapping as RW and restoring ROX (git-fixes).
- commit fff908c
* Thu May 15 2025 nik.borisov@suse.com
- execmem: add API for temporal remapping as RW and restoring ROX afterwards (git-fixes).
- commit e928bfd
* Thu May 15 2025 nik.borisov@suse.com
- execmem: don't remove ROX cache from the direct map (git-fixes).
- commit eee583e
* Thu May 15 2025 nik.borisov@suse.com
- x86/mm/pat: restore large ROX pages after fragmentation (git-fixes).
- commit 5598b75
* Thu May 15 2025 nik.borisov@suse.com
- x86/mm/pat: drop duplicate variable in cpa_flush() (git-fixes).
- commit f93080f
* Thu May 15 2025 nik.borisov@suse.com
- x86/mm/pat: cpa-test: fix length for CPA_ARRAY test (git-fixes).
- commit adde21b
* Thu May 15 2025 nik.borisov@suse.com
- x86: Disable EXECMEM_ROX support (git-fixes).
- commit de5aac5
* Thu May 15 2025 nik.borisov@suse.com
- x86/module: enable ROX caches for module text on 64 bit (git-fixes).
- commit 76a51ba
* Thu May 15 2025 nik.borisov@suse.com
- execmem: add support for cache of large ROX pages (git-fixes).
- commit 4295212
* Thu May 15 2025 nik.borisov@suse.com
- x86/module: prepare module loading for ROX allocations of text  (git-fixes).
- Refresh
  patches.suse/x86-ibt-Keep-IBT-disabled-during-alternative-patching.patch.
- Refresh
  patches.suse/x86-its-Add-support-for-ITS-safe-return-thunk.patch.
- commit ec664c3
* Thu May 15 2025 nik.borisov@suse.com
- arch: introduce set_direct_map_valid_noflush() (git-fixes).
- commit dab315c
* Thu May 15 2025 nik.borisov@suse.com
- module: prepare to handle ROX allocations for text (git-fixes).
- commit 68b6958
* Thu May 15 2025 nik.borisov@suse.com
- asm-generic: introduce text-patching.h (git-fixes).
- commit de10e1e
* Thu May 15 2025 nik.borisov@suse.com
- mm: vmalloc: don't account for number of nodes for HUGE_VMAP allocations (git-fixes).
- commit 1090fe7
* Thu May 15 2025 nik.borisov@suse.com
- mm: vmalloc: group declarations depending on CONFIG_MMU together (git-fixes).
- commit 2949d85
* Thu May 15 2025 mfranc@suse.cz
- Fix Patch-mainline tags.
- Refresh
  patches.suse/vhost-scsi-Fix-vhost_scsi_send_bad_target.patch.
- Refresh
  patches.suse/virtio-net-disable-delayed-refill-when-pausing-rx.patch.
- Refresh
  patches.suse/virtio_console-fix-missing-byte-order-handling-for-c.patch.
- Refresh
  patches.suse/xen-netfront-handle-NULL-returned-by-xdp_convert_buf.patch.
- commit a02aff8
* Thu May 15 2025 nik.borisov@suse.com
- x86/ibt: Keep IBT disabled during alternative patching (bsc#1242006 CVE-2024-28956).
- commit 08c6924
* Thu May 15 2025 nik.borisov@suse.com
- x86/its: Align RETs in BHB clear sequence to avoid thunking (bsc#1242006 CVE-2024-28956).
- commit a549c4e
* Thu May 15 2025 tiwai@suse.de
- misc: pci_endpoint_test: Avoid issue of interrupts remaining
  after request_irq error (CVE-2025-23140 bsc#1242763).
- commit 7abc3f5
* Thu May 15 2025 nik.borisov@suse.com
- x86/its: Add support for RSB stuffing mitigation (bsc#1242006 CVE-2024-28956).
- commit daf020d
* Thu May 15 2025 nik.borisov@suse.com
- x86/its: Add "vmexit" option to skip mitigation on some CPUs (bsc#1242006 CVE-2024-28956).
- commit cfbe6c2
* Thu May 15 2025 nik.borisov@suse.com
- x86/its: Enable Indirect Target Selection mitigation (bsc#1242006 CVE-2024-28956).
- commit 0d65b9c
* Thu May 15 2025 nik.borisov@suse.com
- x86/its: Add support for ITS-safe return thunk (bsc#1242006 CVE-2024-28956).
- commit fd877d7
* Thu May 15 2025 nik.borisov@suse.com
- x86/its: Add support for ITS-safe indirect thunk (bsc#1242006 CVE-2024-28956).
- commit 30641d4
* Thu May 15 2025 nik.borisov@suse.com
- x86/its: Enumerate Indirect Target Selection (ITS) bug (bsc#1242006 CVE-2024-28956).
- commit ba99e99
* Thu May 15 2025 nik.borisov@suse.com
- x86/cpu: Expose only stepping min/max interface (bsc#1242006 CVE-2024-28956).
- commit 8b54e17
* Thu May 15 2025 nik.borisov@suse.com
- Documentation: x86/bugs/its: Add ITS documentation (bsc#1242006 CVE-2024-28956).
- commit 9540fdb
* Thu May 15 2025 msuchanek@suse.de
- Refresh patches.suse/tpm-tis-Double-the-timeout-B-to-4s.patch.
- commit e6d0a02
* Thu May 15 2025 mhocko@suse.com
- scripts/check-kernel-fix: wait for git-fixes background run properly
  we are printing potential follow up fixes only if there is an action
  required which is an intendeded behavior. We do want to wait for the run
  to finish regardless of the final outcome though as we do not want the
  git-fixes to outlive the script runtime. Theoretically we could just kill
  git_fixes_pid but this could get more tricky if the process terminated
  and the pid got recycled.
- commit 4d3770f
* Thu May 15 2025 mhocko@suse.com
- scripts/check-kernel-fix: print ACTION NEEDED at the end
  ACTION NEEDED has been printed as soon as it is clear there is an action
  required for a certain branch. This works well for regular run but it
  generates a confusing output for verbose mode
    Link: https://git.kernel.org/linus/f9a9f43a62a04ec3183fb0da9226c7706eed0115
    SL-16.0: nope_commit_in_base
    SLE11-SP4-LTSS: nope_unaffected
    SLE12-SP3-TD: nope_unaffected
    ACTION NEEDED!
    SLE12-SP5: MANUAL: backport f9a9f43a62a04ec3183fb0da9226c7706eed0115 (Fixes v4.12)
  fix this by printing this at the very end after all the processing is
  done.
- commit fe72ee2
* Thu May 15 2025 iivanov@suse.de
- arm64: dts: imx8mp-var-som: Fix LDO5 shutdown causing SD card timeout (git-fixes)
- commit e0761c4
* Thu May 15 2025 iivanov@suse.de
- arm64: dts: rockchip: Assign RT5616 MCLK rate on (git-fixes)
- commit 85e792e
* Thu May 15 2025 iivanov@suse.de
- arm64: dts: rockchip: Add pinmuxing for eMMC on QNAP TS433 (git-fixes)
- commit 3120557
* Thu May 15 2025 iivanov@suse.de
- arm64: dts: rockchip: Remove overdrive-mode OPPs from RK3588J SoC (git-fixes)
- commit 9670342
* Thu May 15 2025 iivanov@suse.de
- arm64: cpufeature: Move arm64_use_ng_mappings to the .data section to (git-fixes)
- commit 407716a
* Thu May 15 2025 iivanov@suse.de
- arm64: dts: st: Use 128kB size for aliased GIC400 register access on (git-fixes)
- commit 12333da
* Thu May 15 2025 iivanov@suse.de
- arm64: dts: st: Adjust interrupt-controller for stm32mp25 SoCs (git-fixes)
- commit 120fe1f
* Thu May 15 2025 iivanov@suse.de
- arm64: dts: imx8mm-verdin: Link reg_usdhc2_vqmmc to usdhc2 (git-fixes)
- commit 16c5fbc
* Thu May 15 2025 iivanov@suse.de
- arm64: dts: imx95: Correct the range of PCIe app-reg region (git-fixes)
- commit 2139ecb
* Thu May 15 2025 iivanov@suse.de
- arm64: errata: Add missing sentinels to Spectre-BHB MIDR arrays (git-fixes)
- commit 4976c35
* Wed May 14 2025 dsterba@suse.com
- netfilter: conntrack: clamp maximum hashtable size to INT_MAX (CVE-2025-21648 bsc#1236142)
- commit fd771b8
* Wed May 14 2025 ematsumiya@suse.de
- smb: client: fix UAF in decryption with multichannel
  (bsc#1242510, CVE-2025-37750).
- commit 68f2d81
* Wed May 14 2025 dsterba@suse.com
- cpufreq/amd-pstate: Add missing NULL ptr check in amd_pstate_update (CVE-2025-23137 bsc#1241363)
- commit 48dc7df
* Wed May 14 2025 lduncan@suse.com
- Update
  patches.suse/md-raid10-wait-barrier-before-returning-discard-request-wi.patch
  (git-fixes CVE-2025-40325 bsc#1241638).
  Update meta-data, adding CVE and bug#.
- commit b0a6c4b
* Wed May 14 2025 mkubecek@suse.cz
- sch_htb: make htb_deactivate() idempotent (CVE-2025-37798
  bsc#1242414).
- sch_ets: make est_qlen_notify() idempotent (CVE-2025-37798
  bsc#1242414).
- sch_qfq: make qfq_qlen_notify() idempotent (CVE-2025-37798
  bsc#1242414).
- sch_hfsc: make hfsc_qlen_notify() idempotent (CVE-2025-37798
  bsc#1242414).
- sch_drr: make drr_qlen_notify() idempotent (CVE-2025-37798
  bsc#1242414).
- sch_htb: make htb_qlen_notify() idempotent (CVE-2025-37798
  bsc#1242414).
- commit c3254e9
* Wed May 14 2025 msuchanek@suse.de
- Refresh sorted patches.
- commit 327f25e
* Wed May 14 2025 oneukum@suse.com
- drivers/platform/x86/amd: pmf: Check for invalid Smart PC
  Policies (git-fixes).
- commit 70e0f6a
* Wed May 14 2025 msuchanek@suse.de
- Refresh patches.suse/powerpc-boot-Fix-build-with-gcc-15.patch
- commit 2f5ab59
* Wed May 14 2025 pfalcato@suse.de
- sctp: detect and prevent references to a freed transport in
  sendmsg (CVE-2025-23142 bsc#1242760).
- commit 23a3fc0
* Wed May 14 2025 mhocko@suse.com
- scripts/check-kernel-fix: do a full check in verbose mode
  we are skipping evaluation of ineligible (based on CVSS scoring) branches
  to save runtime because a common case is a low score CVE that is not
  eligible to any LTSS branches. Security team would like to know whether
  as specific branch is affected even in those case so let's change the
  implementation and do the full evaluation even if a branch is not
  eligible based on the scoring.
  With the current implementation we are getting
  ./scripts/check-kernel-fix -v CVE-2022-49320
  Security fix for CVE-2022-49320 bsc#1238394 with CVSS 5.5
  = f9a9f43a62a0 ("dmaengine: zynqmp_dma: In struct zynqmp_dma_chan fix desc_size data type") merged v5.19-rc1~100^2~37
  Fixes: b0cc417c1637 ("dmaengine: Add Xilinx zynqmp dma engine driver support") merged v4.8-rc1~117^2~7^2~2
  Experts candidates:  tiwai@suse.com (36) subsystem/role="DRIVERS"
  Link: https://git.kernel.org/linus/f9a9f43a62a04ec3183fb0da9226c7706eed0115
  SL-16.0: nope_commit_in_base
  SLE11-SP4-LTSS: nope_cvss
  SLE12-SP3-TD: nope_unaffected
  ACTION NEEDED!
  SLE12-SP5: MANUAL: backport f9a9f43a62a04ec3183fb0da9226c7706eed0115 (Fixes v4.12)
  SLE15-SP6: nope_commit_in_base
  SLE15-SP7-GA: nope_cvss
  cve/linux-5.14-LTSS: ok_reference_present
  cve/linux-5.3-LTSS: nope_cvss
  SUSE-2024: nope_commit_in_base
  SLE15-SP6-RT: nope_commit_in_base
  SLE15-SP6-COCO: nope_commit_in_base
  SLE15-SP6-AZURE: nope_commit_in_base
  SLE15-SP7: nope_commit_in_base
  SLE15-SP2-LTSS: nope_cvss
  SLE15-SP3-LTSS: ok_reference_present
  SUSE-2024-RT: nope_commit_in_base
  SLE15-SP7-RT: nope_commit_in_base
  SLE15-SP7-COCO: nope_commit_in_base
  SLE15-SP7-AZURE: nope_commit_in_base
  With the updated one we are getting a more specific answer for
  all branches whether they are eligible or not.
  ./scripts/check-kernel-fix -v CVE-2022-49320
  Security fix for CVE-2022-49320 bsc#1238394 with CVSS 5.5
  = f9a9f43a62a0 ("dmaengine: zynqmp_dma: In struct zynqmp_dma_chan fix desc_size data type") merged v5.19-rc1~100^2~37
  Fixes: b0cc417c1637 ("dmaengine: Add Xilinx zynqmp dma engine driver support") merged v4.8-rc1~117^2~7^2~2
  Experts candidates:  tiwai@suse.com (36) subsystem/role="DRIVERS"
  Link: https://git.kernel.org/linus/f9a9f43a62a04ec3183fb0da9226c7706eed0115
  SL-16.0: nope_commit_in_base
  SLE11-SP4-LTSS: nope_unaffected
  SLE12-SP3-TD: nope_unaffected
  ACTION NEEDED!
  SLE12-SP5: MANUAL: backport f9a9f43a62a04ec3183fb0da9226c7706eed0115 (Fixes v4.12)
  SLE15-SP6: nope_commit_in_base
  SLE15-SP7-GA: nope_commit_in_base
  cve/linux-5.14-LTSS: ok_reference_present
  cve/linux-5.3-LTSS: missing_commit_nope_cvss
  SLE12-SP5-RT: MANUAL: backport f9a9f43a62a04ec3183fb0da9226c7706eed0115 (Fixes v4.12)
  WW CONFIG_XILINX_ZYNQMP_DMA not enabled.
  SUSE-2024: nope_commit_in_base
  SLE15-SP6-RT: nope_commit_in_base
  SLE15-SP6-COCO: nope_commit_in_base
  SLE15-SP6-AZURE: nope_commit_in_base
  SLE15-SP7: nope_commit_in_base
  SLE15-SP4-LTSS: ok_reference_present
  SLE15-SP5-LTSS: ok_reference_present
  SLE15-SP2-LTSS: missing_commit_nope_cvss
  SLE15-SP3-LTSS: ok_reference_present
  SUSE-2024-RT: nope_commit_in_base
  SLE15-SP7-RT: nope_commit_in_base
  SLE15-SP7-COCO: nope_commit_in_base
  SLE15-SP7-AZURE: nope_commit_in_base
  SLE15-SP4-RT-LTSS: ok_reference_present
  SLE15-SP5-RT-LTSS: ok_reference_present
  SLE15-SP3-RT-LTSS: ok_reference_present
- commit 2022652
* Tue May 13 2025 lduncan@suse.com
- Update
  patches.suse/md-fix-mddev-uaf-while-iterating-all_mddevs-list.patch
  (git-fixes CVE-20255-22126 bsc#1241597).
  Update metadata, adding CVE and bug references
- commit f526dd7
* Tue May 13 2025 lduncan@suse.com
- Update patches.suse/md-raid1-raid10-don-t-ignore-IO-flags.patch
  (git-fixes CVE-2025-22125 bsc#1241596).
  Update meta-data: add CVE and bug reference
- commit e4da8bd
* Tue May 13 2025 mbenes@suse.cz
- Delete
  patches.suse/Revert-kallsyms-unexport-kallsyms_lookup_name-and-kallsyms_on_each_symbol.patch.
- commit a0dbeff
* Tue May 13 2025 fmancera@suse.de
- net: openvswitch: fix nested key length validation in the set()
  action (CVE-2025-37789 bsc#1242762).
- commit f1c1667
* Tue May 13 2025 oneukum@suse.com
- platform/x86: asus-wmi: Fix wlan_ctrl_by_user detection
  (git-fixes).
- commit d054e55
* Tue May 13 2025 oneukum@suse.com
- platform/x86/amd/pmc: Declare quirk_spurious_8042 for MECHREVO
  Wujie 14XA (GX4HRXL) (git-fixes).
- commit 6ed7e5e
* Tue May 13 2025 oneukum@suse.com
- drivers/platform/x86/amd: pmf: Check for invalid sideloaded
  Smart PC Policies (git-fixes).
- commit 9f77444
* Tue May 13 2025 mfranc@suse.cz
- s390/cpumf: Update CPU Measurement facility extended counter
  set support (bsc#1243118).
- s390: Add z17 elf platform (bsc#1243119).
- commit 342b428
* Tue May 13 2025 dwagner@suse.de
- nvme-pci: add quirk for Samsung PM173x/PM173xa disk
  (bsc#1241148).
- nvme: Add warning when a partiually unique NID is detected
  (bsc#1241148).
- nvme: Add 'partial_nid' quirk (bsc#1241148).
- commit 1ee5e84
* Tue May 13 2025 fmancera@suse.de
- netfilter: nft_tunnel: fix geneve_opt type confusion addition
  (CVE-2025-22056 bsc#1241525).
- commit c55bcc7
* Tue May 13 2025 jgross@suse.com
- net: export a helper for adding up queue stats (git-fixes).
- commit 60dc7bb
* Tue May 13 2025 jgross@suse.com
- virtio-net: fix total qstat values (git-fixes).
- commit 8780e19
* Tue May 13 2025 vbabka@suse.cz
- mm, slab: clean up slab->obj_exts always (git-fixes).
- commit 82e1c69
* Tue May 13 2025 vbabka@suse.cz
- slab: ensure slab->obj_exts is clear in a newly allocated slab
  page (CVE-2025-37774 bsc#1242783).
- commit bf2c798
* Tue May 13 2025 vbabka@suse.cz
- alloc_tag: uninline code gated by mem_alloc_profiling_key in
  slab allocator (git-fixes dependency).
- commit fdcf54b
* Tue May 13 2025 jgross@suse.com
- virtio-net: free xsk_buffs on error in virtnet_xsk_pool_enable()
  (git-fixes).
- commit 70be972
* Tue May 13 2025 vbabka@suse.cz
- mm: zswap: fix crypto_free_acomp() deadlock in
  zswap_cpu_comp_dead() (CVE-2025-22030 bsc#1241376).
- commit b15b5e1
* Tue May 13 2025 jgross@suse.com
- virtio-net: don't re-enable refill work too early when NAPI
  is disabled (git-fixes).
- commit 36d0adc
* Tue May 13 2025 mhocko@suse.com
- scripts/check-kernel-fix: recognized reserved but not published yet CVEs
  We have seen a large pile of CVEs that are not released yet.
  c-k-f currently says
  $ ./scripts/check-kernel-fix CVE-2025-37846
  Can't find sha in upstream: CVE-2025-37846.
  Let's check whether the said CVE is reserved and say so to make the fact
  $ ./scripts/check-kernel-fix CVE-2025-37846
  CVE-2025-37846 is reserved but not fully published
- commit 97893d4
* Tue May 13 2025 jgross@suse.com
- virtio-net: disable delayed refill when pausing rx (git-fixes).
- commit 896d338
* Tue May 13 2025 jgross@suse.com
- vhost-scsi: Fix vhost_scsi_send_bad_target() (git-fixes).
- commit bc9266a
* Tue May 13 2025 tiwai@suse.de
- platform/x86: asus-wmi: Fix wlan_ctrl_by_user detection
  (git-fixes).
- platform/x86/amd/pmc: Declare quirk_spurious_8042 for MECHREVO
  Wujie 14XA (GX4HRXL) (git-fixes).
- drivers/platform/x86/amd: pmf: Check for invalid sideloaded
  Smart PC Policies (git-fixes).
- commit 44333aa
* Tue May 13 2025 jgross@suse.com
- virtio_console: fix missing byte order handling for cols and
  rows (git-fixes).
- commit 6700379
* Mon May 12 2025 jgross@suse.com
- KVM: x86/mmu: Prevent installing hugepages when mem attributes
  are changing (git-fixes).
- commit 0174a2a
* Mon May 12 2025 jgross@suse.com
- KVM: SVM: Update dump_ghcb() to use the GHCB snapshot fields
  (git-fixes).
- commit 891290f
* Mon May 12 2025 jgross@suse.com
- KVM: x86/mmu: Check and free obsolete roots in kvm_mmu_reload()
  (git-fixes).
- commit 774db33
* Mon May 12 2025 dwagner@suse.de
- nvme: unblock ctrl state transition for firmware update
  (git-fixes).
- nvmet-tcp: select CONFIG_TLS from CONFIG_NVME_TARGET_TCP_TLS
  (git-fixes).
- nvme-tcp: select CONFIG_TLS from CONFIG_NVME_TCP_TLS
  (git-fixes).
- nvme-tcp: fix premature queue removal and I/O failover
  (git-fixes).
- nvme-pci: fix queue unquiesce check on slot_reset (git-fixes).
- commit a2b4b26
* Mon May 12 2025 jgross@suse.com
- KVM: x86: Check that the high 32bits are clear in
  kvm_arch_vcpu_ioctl_run() (git-fixes).
- commit fe32097
* Mon May 12 2025 jgross@suse.com
- KVM: SVM: Forcibly leave SMM mode on SHUTDOWN interception
  (git-fixes).
- commit c609983
* Mon May 12 2025 jgross@suse.com
- KVM: x86: Take irqfds.lock when adding/deleting IRQ bypass
  producer (git-fixes).
- commit 60e8b26
* Mon May 12 2025 jgross@suse.com
- KVM: x86: Explicitly treat routing entry type changes as changes
  (git-fixes).
- commit 00025dc
* Mon May 12 2025 dwagner@suse.de
- scsi: qla2xxx: Remove duplicate struct crb_addr_pair
  (bsc#1243090).
- scsi: qla2xxx: Remove unused module parameters (bsc#1243090).
- scsi: qla2xxx: Remove unused qla2x00_gpsc() (bsc#1243090).
- scsi: qla2xxx: Remove unused ql_log_qp (bsc#1243090).
- scsi: qla2xxx: Remove unused qla82xx_wait_for_state_change()
  (bsc#1243090).
- scsi: qla2xxx: Remove unused qla82xx_pci_region_offset()
  (bsc#1243090).
- scsi: qla2xxx: Remove unused qlt_83xx_iospace_config()
  (bsc#1243090).
- scsi: qla2xxx: Remove unused qlt_fc_port_deleted()
  (bsc#1243090).
- scsi: qla2xxx: Remove unused qlt_free_qfull_cmds()
  (bsc#1243090).
- scsi: qla2xxx: Fix typos in a comment (bsc#1243090).
- scsi: qla2xxx: Mark device strings as nonstring (bsc#1243090).
- commit 3480857
* Mon May 12 2025 jgross@suse.com
- KVM: x86: Reset IRTE to host control if *new* route isn't
  postable (git-fixes).
- commit 9592682
* Mon May 12 2025 jgross@suse.com
- KVM: SVM: Allocate IR data using atomic allocation (git-fixes).
- commit 853028b
* Mon May 12 2025 jgross@suse.com
- KVM: arm64: Fix memory check in host_stage2_set_owner_locked()
  (git-fixes).
- commit f1fda19
* Mon May 12 2025 jgross@suse.com
- KVM: arm64: Fix uninitialized memcache pointer in
  user_mem_abort() (git-fixes).
- commit 090f76d
* Mon May 12 2025 jgross@suse.com
- xenbus: Allow PVH dom0 a non-local xenstore (git-fixes).
- commit eeaa5aa
* Mon May 12 2025 jgross@suse.com
- xenbus: Use kref to track req lifetime (git-fixes).
- commit 49fbb67
* Mon May 12 2025 krisman@suse.de
- Refresh
  patches.suse/io_uring-sqpoll-Increase-task_work-submission-batch-.patch.
  Patch was accepted upstream.  Update the version and add final headers.
- commit 52da9d4
* Mon May 12 2025 jgross@suse.com
- xen: swiotlb: Use swiotlb bouncing if kmalloc allocation
  demands it (git-fixes).
- commit bef02e3
* Mon May 12 2025 jgross@suse.com
- xen-netfront: handle NULL returned by
  xdp_convert_buff_to_frame() (git-fixes).
- commit fba38b4
* Mon May 12 2025 dwagner@suse.de
- scsi: lpfc: Copyright updates for 14.4.0.9 patches
  (bsc#1242995).
- scsi: lpfc: Update lpfc version to 14.4.0.9 (bsc#1242995).
- scsi: lpfc: Create lpfc_vmid_info sysfs entry (bsc#1242995).
- scsi: lpfc: Avoid potential ndlp use-after-free in
  dev_loss_tmo_callbk (bsc#1242995).
- scsi: lpfc: Prevent failure to reregister with NVMe transport
  after PRLI retry (bsc#1242995).
- scsi: lpfc: Restart eratt_poll timer if HBA_SETUP flag still
  unset (bsc#1242995).
- scsi: lpfc: Notify FC transport of rport disappearance during
  PCI fcn reset (bsc#1242995).
- scsi: lpfc: Fix lpfc_check_sli_ndlp() handling for GEN_REQUEST64
  commands (bsc#1242995).
- scsi: lpfc: Fix spelling mistake 'Toplogy' -> 'Topology'
  (bsc#1242995).
- scsi: lpfc: Convert timeouts to secs_to_jiffies() (bsc#1242995).
- scsi: lpfc: convert timeouts to secs_to_jiffies() (bsc#1242995).
- commit 45811f8
* Mon May 12 2025 dwagner@suse.de
- scsi: lpfc: Use memcpy() for BIOS version (bsc#1240965).
- commit 53e46c0
* Mon May 12 2025 msuchanek@suse.de
- Update patches.suse/powerpc-pseries-iommu-create-DDW-for-devices-with-DM.patch
  (bsc#1239691 bsc#1243044 ltc#212555).
- commit ebbb0e6
* Mon May 12 2025 oneukum@suse.com
- usb: typec: tcpm: delay SNK_TRY_WAIT_DEBOUNCE to SRC_TRYWAIT
  transition (git-fixes).
- commit 8f8f222
* Mon May 12 2025 oneukum@suse.com
- USB: usbtmc: use interruptible sleep in usbtmc_read (git-fixes).
- commit b7a1a0c
* Mon May 12 2025 oneukum@suse.com
- usb: typec: ucsi: displayport: Fix NULL pointer access
  (git-fixes).
- commit 0670aa5
* Mon May 12 2025 oneukum@suse.com
- usb: typec: ucsi: displayport: Fix deadlock (git-fixes).
- commit b6bdc79
* Mon May 12 2025 mwilck@suse.com
- dm-integrity: fix a warning on invalid table line (git-fixes).
- commit a020eab
* Mon May 12 2025 oneukum@suse.com
- usb: gadget: tegra-xudc: ACK ST_RC after clearing CTRL_RUN
  (git-fixes).
- commit e100777
* Mon May 12 2025 pfalcato@suse.de
- bpf: Scrub packet on bpf_redirect_peer (git-fixes).
- commit 652efa2
* Mon May 12 2025 msuchanek@suse.de
- check-for-config-changes: Fix flag name typo
- commit 1046b16
* Mon May 12 2025 fmancera@suse.de
- netfilter: socket: Lookup orig tuple for IPv6 SNAT
  (CVE-2025-22021 bsc#1241282).
- commit 19d5805
* Mon May 12 2025 ohering@suse.de
- Drivers: hv: Make the sysfs node size for the ring buffer
  dynamic (git-fixes).
- uio_hv_generic: Fix sysfs creation path for ring buffer
  (git-fixes).
- commit 5be80b8
* Mon May 12 2025 tiwai@suse.de
- Move upstreamed sound patch into sorted section
- commit bb3dd19
* Mon May 12 2025 tiwai@suse.de
- Input: xpad - fix two controller table values (git-fixes).
- Input: mtk-pmic-keys - fix possible null pointer dereference
  (git-fixes).
- Input: cyttsp5 - fix power control issue on wakeup (git-fixes).
- Input: cyttsp5 - ensure minimum reset pulse width (git-fixes).
- commit bc65477
* Sun May 11 2025 tiwai@suse.de
- xhci: dbc: Avoid event polling busyloop if pending rx transfers
  are inactive (git-fixes).
- usb: usbtmc: Fix erroneous generic_read ioctl return
  (git-fixes).
- usb: usbtmc: Fix erroneous wait_srq ioctl return (git-fixes).
- usb: usbtmc: Fix erroneous get_stb ioctl error returns
  (git-fixes).
- usb: typec: tcpm: delay SNK_TRY_WAIT_DEBOUNCE to SRC_TRYWAIT
  transition (git-fixes).
- USB: usbtmc: use interruptible sleep in usbtmc_read (git-fixes).
- usb: cdnsp: fix L1 resume issue for RTL_REVISION_NEW_LPM version
  (git-fixes).
- usb: typec: ucsi: displayport: Fix NULL pointer access
  (git-fixes).
- usb: typec: ucsi: displayport: Fix deadlock (git-fixes).
- usb: misc: onboard_usb_dev: fix support for Cypress HX3 hubs
  (git-fixes).
- usb: uhci-platform: Make the clock really optional (git-fixes).
- usb: dwc3: gadget: Make gadget_wakeup asynchronous (git-fixes).
- usb: gadget: Use get_status callback to set remote wakeup
  capability (git-fixes).
- usb: gadget: f_ecm: Add get_status callback (git-fixes).
- usb: host: tegra: Prevent host controller crash when OTG port
  is used (git-fixes).
- usb: cdnsp: Fix issue with resuming from L1 (git-fixes).
- usb: gadget: tegra-xudc: ACK ST_RC after clearing CTRL_RUN
  (git-fixes).
- staging: axis-fifo: Remove hardware resets for user errors
  (git-fixes).
- staging: axis-fifo: Correct handling of tx_fifo_depth for size
  validation (git-fixes).
- staging: bcm2835-camera: Initialise dev in v4l2_dev (git-fixes).
- iio: adis16201: Correct inclinometer channel resolution
  (git-fixes).
- iio: adc: ad7606: fix serial register access (git-fixes).
- staging: iio: adc: ad7816: Correct conditional logic for store
  mode (git-fixes).
- iio: temp: maxim-thermocouple: Fix potential lack of DMA safe
  buffer (git-fixes).
- iio: imu: inv_mpu6050: align buffer for timestamp (git-fixes).
- iio: adc: rockchip: Fix clock initialization sequence
  (git-fixes).
- iio: imu: st_lsm6dsx: fix possible lockup in
  st_lsm6dsx_read_tagged_fifo (git-fixes).
- iio: imu: st_lsm6dsx: fix possible lockup in
  st_lsm6dsx_read_fifo (git-fixes).
- iio: accel: adxl367: fix setting odr for activity time update
  (git-fixes).
- drm/xe: Add page queue multiplier (git-fixes).
- drm/amdgpu/hdp7: use memcfg register to post the write for
  HDP flush (git-fixes).
- drm/amdgpu/hdp6: use memcfg register to post the write for
  HDP flush (git-fixes).
- drm/amdgpu/hdp5.2: use memcfg register to post the write for
  HDP flush (git-fixes).
- drm/amdgpu/hdp5: use memcfg register to post the write for
  HDP flush (git-fixes).
- drm/amdgpu/hdp4: use memcfg register to post the write for
  HDP flush (git-fixes).
- drm/amd/display: Fix wrong handling for AUX_DEFER case
  (git-fixes).
- drm/amd/display: Copy AUX read reply data whenever length >
  0 (git-fixes).
- drm/amd/display: Remove incorrect checking in dmub aux handler
  (git-fixes).
- drm/amd/display: Shift DMUB AUX reply command if necessary
  (git-fixes).
- drm/amd/display: Fix invalid context error in dml helper
  (git-fixes).
- drm/panel: simple: Update timings for AUO G101EVN010
  (git-fixes).
- accel/ivpu: Increase state dump msg timeout (git-fixes).
- wifi: mac80211: fix the type of status_code for negotiated
  TID to Link Mapping (git-fixes).
- wifi: cfg80211: fix out-of-bounds access during multi-link
  element defragmentation (git-fixes).
- can: gw: fix RCU/BH usage in cgw_create_job() (git-fixes).
- can: mcan: m_can_class_unregister(): fix order of unregistration
  calls (git-fixes).
- can: rockchip_canfd: rkcanfd_remove(): fix order of
  unregistration calls (git-fixes).
- can: mcp251xfd: mcp251xfd_remove(): fix order of unregistration
  calls (git-fixes).
- can: mcp251xfd: fix TDC setting for low data bit rates
  (git-fixes).
- can: m_can: m_can_class_allocate_dev(): initialize spin lock
  on device probe (git-fixes).
- EDAC/altera: Set DDR and SDMMC interrupt mask before
  registration (git-fixes).
- EDAC/altera: Test the correct error reg offset (git-fixes).
- ALSA: usb-audio: Add second USB ID for Jabra Evolve 65 headset
  (stable-fixes).
- ALSA: usb-audio: Add retry on -EPROTO from usb_set_interface()
  (stable-fixes).
- drm/amdgpu: Fix offset for HDP remap in nbio v7.11
  (stable-fixes).
- drm/amd/display: Fix slab-use-after-free in hdcp (git-fixes).
- platform/x86/amd: pmc: Require at least 2.5 seconds between
  HW sleep cycles (stable-fixes).
- drm/amd/display: Add scoped mutexes for amdgpu_dm_dhcp
  (stable-fixes).
- Bluetooth: btusb: Add 13 USB device IDs for Qualcomm WCN785x
  (stable-fixes).
- Bluetooth: btusb: Add new VID/PID for WCN785x (stable-fixes).
- ASoC: soc-core: Stop using of_property_read_bool() for
  non-boolean properties (stable-fixes).
- EDAC/{skx_common,i10nm}: Fix some missing error reports on
  Emerald Rapids (git-fixes).
- Bluetooth: btusb: Add ID 0x2c7c:0x0130 for Qualcomm WCN785x
  (stable-fixes).
- accel/ivpu: Use xa_alloc_cyclic() instead of custom function
  (stable-fixes).
- accel/ivpu: Make DB_ID and JOB_ID allocations incremental
  (stable-fixes).
- accel/ivpu: Update VPU FW API headers (stable-fixes).
- accel/ivpu: Fix a typo (stable-fixes).
- commit f4b367d
* Fri May  9 2025 mwilck@suse.com
- dm: fix copying after src array boundaries (git-fixes).
- commit d245386
* Fri May  9 2025 mwilck@suse.com
- dm: add missing unlock on in dm_keyslot_evict() (git-fixes).
- commit 7c774eb
* Fri May  9 2025 mwilck@suse.com
- dm-ebs: fix prefetch-vs-suspend race (git-fixes).
- commit ca47a3a
* Fri May  9 2025 mwilck@suse.com
- dm-verity: fix prefetch-vs-suspend race (git-fixes).
- commit 08de9d9
* Fri May  9 2025 mwilck@suse.com
- dm-integrity: fix non-constant-time tag verification
  (git-fixes).
- commit 08671cf
* Fri May  9 2025 mwilck@suse.com
- dm-integrity: set ti->error on memory allocation failure
  (git-fixes).
- commit a523edf
* Fri May  9 2025 pfalcato@suse.de
- net: mctp: Set SOCK_RCU_FREE (CVE-2025-37790 bsc#1242509).
- commit b2b89d2
* Fri May  9 2025 pfalcato@suse.de
- net_sched: hfsc: Fix a UAF vulnerability in class handling
  (CVE-2025-37797 bsc#1242417).
- commit 5054069
* Fri May  9 2025 msuchanek@suse.de
- powerpc/pseries/iommu: create DDW for devices with DMA mask
  less than 64-bits (bsc#1239691).
- commit 73b27f8
* Fri May  9 2025 mkubecek@suse.cz
- codel: remove sch->q.qlen check before
  qdisc_tree_reduce_backlog() (CVE-2025-37798 bsc#1242414).
- commit 1c8963f
* Fri May  9 2025 mkubecek@suse.cz
- Update
  patches.suse/mptcp-fix-NULL-pointer-in-can_accept_new_subflow.patch
  references (add CVE-2025-23145 bsc#1242596).
- commit 86cf0bb
* Fri May  9 2025 iivanov@suse.de
- supported.conf: Make imx93-adc driver supported (jsc#PED-12016)
- commit 0844125
* Thu May  8 2025 iivanov@suse.de
- perf: arm_cspmu: nvidia: monitor all ports by default (bsc#1242172)
- commit bf39dd6
* Thu May  8 2025 iivanov@suse.de
- perf: arm_cspmu: nvidia: enable NVLINK-C2C port filtering (bsc#1242172)
- commit db95d42
* Thu May  8 2025 iivanov@suse.de
- perf: arm_cspmu: nvidia: fix sysfs path in the kernel doc (bsc#1242172)
- commit 61a8aee
* Thu May  8 2025 iivanov@suse.de
- perf: arm_cspmu: nvidia: remove unsupported SCF events (bsc#1242172)
- commit 1b5aa51
* Thu May  8 2025 henrique.carvalho@suse.com
- cifs: Fix integer overflow while processing actimeo mount option
  (git-fixes).
- commit cc7bbc9
* Thu May  8 2025 henrique.carvalho@suse.com
- cifs: Fix integer overflow while processing closetimeo mount
  option (CVE-2025-21962 bsc#1240655).
- commit 365c443
* Thu May  8 2025 henrique.carvalho@suse.com
- cifs: Fix integer overflow while processing acdirmax mount
  option (CVE-2025-21963 bsc#1240717).
- commit 19fafdd
* Thu May  8 2025 henrique.carvalho@suse.com
- cifs: Fix integer overflow while processing acregmax mount
  option (CVE-2025-21964 bsc#1240740).
- commit 4cde60f
* Thu May  8 2025 rgoldwyn@suse.com
- watch_queue: fix pipe accounting mismatch (CVE-2025-23138 bsc#1241648).
- commit 7f670bc
* Thu May  8 2025 oneukum@suse.com
- wifi: nl80211: store chandef on the correct link when starting
  CAC (git-fixes).
- commit c3b2b6d
* Thu May  8 2025 oneukum@suse.com
- wifi: nl80211: remove redundant null pointer check in coalescing
  (git-fixes).
- commit da447dd
* Thu May  8 2025 tzimmermann@suse.com
- Remove simpledrm workarounds for Nvidia (bsc#1242886)
  These workarounds were required for fbdev-based console support
  with old Nvidia drivers before release 570. These are not supported
  on SLE16. Recent Nvidia drivers provide a DRM-based console.
- commit 7b5dbb9
* Thu May  8 2025 oneukum@suse.com
- wifi: mac80211, cfg80211: miscellaneous spelling fixes
  (git-fixes).
- commit 26269ed
* Thu May  8 2025 oneukum@suse.com
- platform/x86/amd/pmf: fix cleanup in amd_pmf_init_smart_pc()
  (git-fixes).
- commit 22af071
* Thu May  8 2025 oneukum@suse.com
- platform/x86/amd/pmf: Switch to platform_get_resource() and
  devm_ioremap_resource() (git-fixes).
- commit 6ee242c
* Thu May  8 2025 oneukum@suse.com
- media: i2c: imx214: Add vblank and hblank controls (git-fixes).
- commit d20bc08
* Thu May  8 2025 oneukum@suse.com
- media: i2c: imx214: Drop IMX214_REG_EXPOSURE from mode reg
  arrays (git-fixes).
- commit 8641706
* Thu May  8 2025 oneukum@suse.com
- media: ipu6: move the l2_unmap() up before l2_map() (git-fixes).
- commit 15eadf0
* Thu May  8 2025 oneukum@suse.com
- media: intel/ipu6: remove buttress ish structure (git-fixes).
- commit b671d23
* Thu May  8 2025 tbogendoerfer@suse.de
- vmxnet3: Fix malformed packet sizing in vmxnet3_process_xdp
  (CVE-2025-37799 bsc#1242283).
- commit 4b5767a
* Thu May  8 2025 ailiop@suse.com
- erofs: ensure the extra temporary copy is valid for shortened
  bvecs (git-fixes).
- commit 30165a9
* Thu May  8 2025 ailiop@suse.com
- fs/erofs/fileio: call erofs_onlinefolio_split() after
  bio_add_folio() (git-fixes).
- commit 287888e
* Wed May  7 2025 oneukum@suse.com
- platform/x86/amd/pmf: Update PMF Driver for Compatibility with
  new PMF-TA (git-fixes).
- commit cc3df34
* Wed May  7 2025 duwe@suse.de
- dmaengine: idxd: Enable Function Level Reset (FLR) for halt
  (jsc#PED-10722).
- dmaengine: idxd: Refactor halt handler (jsc#PED-10722).
- dmaengine: idxd: Add idxd_device_config_save() and
  idxd_device_config_restore() helpers (jsc#PED-10722).
- dmaengine: idxd: Binding and unbinding IDXD device and driver
  (jsc#PED-10722).
- dmaengine: idxd: Add idxd_pci_probe_alloc() helper
  (jsc#PED-10722).
- dmaengine: idxd: Remove unused idxd_(un)register_bus_type
  (git-fixes).
- commit c5788f1
* Wed May  7 2025 tzimmermann@suse.com
- Review various patches for kABI changes
  Several patches require a refresh. No functional changes.
- commit c1ac5ba
* Wed May  7 2025 msuchanek@suse.de
- Update references for rtas patches (jsc#PED-12801).
- commit 4634c37
* Wed May  7 2025 pfalcato@suse.de
- net: ipv6: ioam6: fix lwtunnel_output() loop (git-fixes).
- commit c113f7e
* Wed May  7 2025 pfalcato@suse.de
- net: ipv6: fix dst refleaks in rpl, seg6 and ioam6 lwtunnels
  (git-fixes).
- commit 96d8aa2
* Wed May  7 2025 pfalcato@suse.de
- net: ipv6: ioam6_iptunnel: mitigate 2-realloc issue (git-fixes).
- commit 2d48008
* Wed May  7 2025 nik.borisov@suse.com
- x86/cpu/amd: Fix workaround for erratum 1054 (git-fixes).
- commit d81a358
* Tue May  6 2025 tiwai@suse.de
- usb: xhci: Fix Short Packet handling rework ignoring errors
  (git-fixes).
- media: i2c: imx214: Fix uninitialized variable in
  imx214_set_ctrl() (git-fixes).
- media: i2c: imx214: Fix link frequency validation (git-fixes).
- commit 9465e52
* Tue May  6 2025 tiwai@suse.de
- xhci: Handle spurious events on Etron host isoc enpoints
  (stable-fixes).
- Refresh patches.suse/padding-XHCI-additional-padding.patch.
- commit 292fe8c
* Tue May  6 2025 tiwai@suse.de
- firmware: arm_ffa: Skip Rx buffer ownership release if not
  acquired (git-fixes).
- firmware: arm_scmi: Fix timeout checks on polling path
  (git-fixes).
- firmware: arm_scmi: Balance device refcount when destroying
  devices (git-fixes).
- irqchip/qcom-mpm: Prevent crash when trying to handle non-wake
  GPIOs (git-fixes).
- i2c: imx-lpi2c: Fix clock count when probe defers (git-fixes).
- spi: tegra114: Don't fail set_cs_timing when delays are zero
  (git-fixes).
- drm/i915/pxp: fix undefined reference to
  `intel_pxp_gsccs_is_ready_for_sessions' (git-fixes).
- drm/mipi-dbi: Fix blanking for non-16 bit formats (git-fixes).
- drm/tests: shmem: Fix memleak (git-fixes).
- drm: Select DRM_KMS_HELPER from DRM_DEBUG_DP_MST_TOPOLOGY_REFS
  (git-fixes).
- drm/fdinfo: Protect against driver unbind (git-fixes).
- drm/nouveau: Fix WARN_ON in nouveau_fence_context_kill()
  (git-fixes).
- pinctrl: imx: Return NULL if no group is matched and found
  (git-fixes).
- drm/amd/display: Force full update in gpu reset (stable-fixes).
- USB: OHCI: Add quirk for LS7A OHCI controller (rev 0x02)
  (stable-fixes).
- xhci: Limit time spent with xHC interrupts disabled during
  bus resume (stable-fixes).
- mei: me: add panther lake H DID (stable-fixes).
- driver core: fix potential NULL pointer dereference in
  dev_uevent() (stable-fixes).
- driver core: introduce device_set_driver() helper
  (stable-fixes).
- drm/amdgpu: Use the right function for hdp flush (stable-fixes).
- drm/amdgpu: use a dummy owner for sysfs triggered cleaner
  shaders v4 (stable-fixes).
- spi: tegra210-quad: add rate limiting and simplify timeout
  error message (stable-fixes).
- spi: tegra210-quad: use WARN_ON_ONCE instead of WARN_ON for
  timeouts (stable-fixes).
- drm/xe/xe3lpg: Apply Wa_14022293748, Wa_22019794406
  (stable-fixes).
- drm/amdgpu: Increase KIQ invalidate_tlbs timeout (stable-fixes).
- gpiolib: of: Move Atmel HSMCI quirk up out of the regulator
  comment (stable-fixes).
- ntb_hw_amd: Add NTB PCI ID for new gen CPU (stable-fixes).
- ntb: reduce stack usage in idt_scan_mws (stable-fixes).
- rtc: pcf85063: do a SW reset if POR failed (stable-fixes).
- usb: host: xhci-plat: mvebu: use ->quirks instead of
  - >init_quirk() func (stable-fixes).
- usb: xhci: Avoid Stop Endpoint retry loop if the endpoint
  seems Running (stable-fixes).
- usb: xhci: Fix isochronous Ring Underrun/Overrun event handling
  (stable-fixes).
- usb: xhci: Complete 'error mid TD' transfers when handling
  Missed Service (stable-fixes).
- sound/virtio: Fix cancel_sync warnings on uninitialized
  work_structs (stable-fixes).
- i3c: master: svc: Add support for Nuvoton npcm845 i3c
  (stable-fixes).
- phy: rockchip: usbdp: Avoid call hpd_event_trigger in
  dp_phy_init (stable-fixes).
- iio: adc: ad7768-1: Fix conversion result sign (git-fixes).
- iio: adc: ad7768-1: Move setting of val a bit later to avoid
  unnecessary return value check (stable-fixes).
- pinctrl: renesas: rza2: Fix potential NULL pointer dereference
  (stable-fixes).
- pinctrl: mcp23s08: Get rid of spurious level interrupts
  (stable-fixes).
- media: i2c: imx214: Check number of lanes from device tree
  (stable-fixes).
- media: i2c: imx214: Replace register addresses with macros
  (stable-fixes).
- media: i2c: imx214: Convert to CCI register access helpers
  (stable-fixes).
- media: i2c: imx214: Simplify with dev_err_probe()
  (stable-fixes).
- media: i2c: imx214: Use subdev active state (stable-fixes).
- media: ov08x40: Add missing ov08x40_identify_module() call on
  stream-start (git-fixes).
- media: ov08x40: Move ov08x40_identify_module() function up
  (stable-fixes).
- commit 783db07
* Tue May  6 2025 tiwai@suse.de
- ASoC: simple-card-utils: Fix pointer check in
  graph_util_parse_link_direction (git-fixes).
- ASoC: amd: acp: Fix NULL pointer deref in acp_i2s_set_tdm_slot
  (git-fixes).
- ASoC: Intel: sof_sdw: Add NULL check in
  asoc_sdw_rt_dmic_rtd_init() (git-fixes).
- ata: libata-scsi: Improve CDL control (git-fixes).
- ata: libata-scsi: Fix ata_msense_control_ata_feature()
  (git-fixes).
- ata: libata-scsi: Fix ata_mselect_control_ata_feature() return
  type (git-fixes).
- dmaengine: dmatest: Fix dmatest waiting less when interrupted
  (stable-fixes).
- crypto: null - Use spin lock instead of mutex (stable-fixes).
- crypto: ccp - Add support for PCI device 0x1134 (stable-fixes).
- commit 957df2c
* Tue May  6 2025 tiwai@suse.de
- ASoC: cs-amp-lib-test: Don't select SND_SOC_CS_AMP_LIB
  (git-fixes).
- ASoC: soc-pcm: Fix hw_params() and DAPM widget sequence
  (git-fixes).
- ALSA: hda/realtek: Fix built-mic regression on other ASUS models
  (git-fixes).
- ALSA: hda/realtek - Enable speaker for HP platform (git-fixes).
- accel/ivpu: Fix the NPU's DPU frequency calculation (git-fixes).
- ASoC: fsl_asrc_dma: get codec or cpu dai from backend
  (stable-fixes).
- ACPI: EC: Set ec_no_wakeup for Lenovo Go S (stable-fixes).
- ACPI PPTT: Fix coding mistakes in a couple of sizeof() calls
  (stable-fixes).
- accel/ivpu: Add auto selection logic for job scheduler
  (stable-fixes).
- commit 1ad8ed8
* Tue May  6 2025 mgorman@suse.de
- sched/topology: Refinement to topology_span_sane speedup
  (bsc#1242119).
- sched/topology: improve topology_span_sane speed (bsc#1242119).
- commit 2cbf7fc
* Tue May  6 2025 mgorman@suse.de
- include/{topology,cpuset}: Move dl_rebuild_rd_accounting to
  cpuset.h (bsc#1234634 (Scheduler functional and performance
  backports)).
- sched/topology: Stop exposing partition_sched_domains_locked
  (bsc#1234634 (Scheduler functional and performance backports)).
- cgroup/cpuset: Remove partition_and_rebuild_sched_domains
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/topology: Remove redundant dl_clear_root_domain call
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/deadline: Rebuild root domain accounting after every
  update (bsc#1234634 (Scheduler functional and performance
  backports)).
- sched/deadline: Generalize unique visiting of root domains
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/topology: Wrappers for sched_domains_mutex (bsc#1234634
  (Scheduler functional and performance backports)).
- sched/deadline: Ignore special tasks when rebuilding domains
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/deadline: Use online cpus for validating runtime
  (bsc#1234634 (Scheduler functional and performance backports)).
- commit b339599
* Tue May  6 2025 rgoldwyn@suse.com
- config: enable INTEGRITY_CA_MACHINE_KEYRING and IMA_BLACKLIST_KEYRING (jsc#PED-12554)
- commit f6725b4
* Tue May  6 2025 pfalcato@suse.de
- xfrm: Add error handling when nla_put_u32() returns an error
  (git-fixes).
- commit a36fe76
* Tue May  6 2025 pfalcato@suse.de
- ipv6: add exception routes to GC list in rt6_insert_exception
  (git-fixes).
- commit a48e9e6
* Tue May  6 2025 pfalcato@suse.de
- net: Handle napi_schedule() calls from non-interrupt
  (git-fixes).
- commit a752323
* Tue May  6 2025 oneukum@suse.com
- thunderbolt: Scan retimers after device router has been
  enumerated (git-fixes).
- commit 0362b7d
* Tue May  6 2025 oneukum@suse.com
- USB: serial: simple: add OWON HDS200 series oscilloscope support
  (git-fixes).
- USB: serial: ftdi_sio: add support for Abacus Electrics Optical
  Probe (git-fixes).
- commit 6c8ea90
* Tue May  6 2025 jack@suse.cz
- ext4: goto right label 'out_mmap_sem' in ext4_setattr()
  (bsc#1242556).
- commit 5bcf26f
* Tue May  6 2025 mhocko@suse.com
- mm/hugetlb: fix hugepage allocation for interleaved memory nodes
  (bsc#1242263).
- commit 72a27cc
* Tue May  6 2025 oneukum@suse.com
- USB: serial: option: add Sierra Wireless EM9291 (git-fixes).
- usb: quirks: Add delay init quirk for SanDisk 3.2Gen1 Flash
  Drive (git-fixes).
- commit d78f11a
* Tue May  6 2025 oneukum@suse.com
- USB: VLI disk crashes if LPM is used (git-fixes).
- commit 13ff8cb
* Tue May  6 2025 ailiop@suse.com
- xfs: lock dquot buffer before detaching dquot from b_li_list
  (git-fixes).
- commit b938ffb
* Tue May  6 2025 mkubecek@suse.cz
- Update patches.suse/ax25-Remove-broken-autobind.patch references
  (add CVE-2025-22109 bsc#1241573).
- commit 6b3aedd
* Tue May  6 2025 ailiop@suse.com
- xfs: release the dquot buf outside of qli_lock (git-fixes).
- commit 487de6b
* Tue May  6 2025 ailiop@suse.com
- nfs: Add missing release on error in
  nfs_lock_and_join_requests() (git-fixes).
- commit fb1389e
* Tue May  6 2025 ailiop@suse.com
- NFS: Shut down the nfs_client only after all the superblocks
  (git-fixes).
- commit 6e7562f
* Tue May  6 2025 ailiop@suse.com
- NFS: fix open_owner_id_maxsz and related fields (git-fixes).
- commit 8562675
* Tue May  6 2025 mkubecek@suse.cz
- Update patches.suse/udp-Fix-memory-accounting-leak.patch
  references (add CVE-2025-22058 bsc#1241332).
- commit 4f32ba3
* Tue May  6 2025 ailiop@suse.com
- NFSv4: Avoid unnecessary scans of filesystems for delayed
  delegations (git-fixes).
- commit f3951e3
* Tue May  6 2025 ailiop@suse.com
- NFSv4: Avoid unnecessary scans of filesystems for expired
  delegations (git-fixes).
- commit 4cb5ad5
* Tue May  6 2025 ailiop@suse.com
- NFSv4: Avoid unnecessary scans of filesystems for returning
  delegations (git-fixes).
- commit af0cb65
* Tue May  6 2025 ailiop@suse.com
- NFSv4: Don't trigger uneccessary scans for return-on-close
  delegations (git-fixes).
- commit 7f34852
* Tue May  6 2025 pfalcato@suse.de
- tipc: fix NULL pointer dereference in tipc_mon_reinit_self()
  (git-fixes).
- commit c34766d
* Tue May  6 2025 pfalcato@suse.de
- net_sched: sch_sfq: use a temporary work area for validating
  configuration (git-fixes).
- commit 39b7b36
* Tue May  6 2025 pfalcato@suse.de
- 9p/trans_fd: mark concurrent read and writes to p9_conn->err
  (git-fixes).
- commit 0dddd74
* Tue May  6 2025 pfalcato@suse.de
- 9p/net: fix improper handling of bogus negative read/write
  replies (git-fixes).
- commit 045504b
* Tue May  6 2025 pfalcato@suse.de
- page_pool: avoid infinite loop to schedule delayed worker
  (git-fixes).
- commit 610f372
* Tue May  6 2025 pfalcato@suse.de
- net: page_pool: don't cast mp param to devmem (git-fixes).
- commit 7466806
* Tue May  6 2025 pfalcato@suse.de
- net: devmem: do not WARN conditionally after
  netdev_rx_queue_restart() (git-fixes).
- commit 76cc252
* Tue May  6 2025 pfalcato@suse.de
- sctp: Fix undefined behavior in left shift operation
  (git-fixes).
- commit 27c992e
* Tue May  6 2025 ailiop@suse.com
- NFS: Adjust delegated timestamps for O_DIRECT reads and writes
  (git-fixes).
- commit ffa994c
* Tue May  6 2025 ailiop@suse.com
- NFS: O_DIRECT writes must check and adjust the file length
  (git-fixes).
- commit 9122df8
* Tue May  6 2025 ailiop@suse.com
- xfs: convert quotacheck to attach dquot buffers (git-fixes).
- commit 938df21
* Tue May  6 2025 ailiop@suse.com
- xfs: fix superfluous clearing of info->low in
  __xfs_getfsmap_datadev (git-fixes).
- commit e17f851
* Tue May  6 2025 ailiop@suse.com
- xfs: remove the unused pag_active_wq field in struct xfs_perag
  (git-fixes).
- commit 2df6330
* Tue May  6 2025 ailiop@suse.com
- xfs: remove the unused pagb_count field in struct xfs_perag
  (git-fixes).
- commit 02c5f7f
* Tue May  6 2025 ailiop@suse.com
- xfs: attach dquot buffer to dquot log item buffer (git-fixes).
- commit 6c7c9e4
* Tue May  6 2025 ailiop@suse.com
- xfs: don't over-report free space or inodes in statvfs
  (git-fixes).
- commit 11521f9
* Tue May  6 2025 ailiop@suse.com
- xfs: unmapped buffer item size straddling mismatch (git-fixes).
- commit c49d035
* Tue May  6 2025 ailiop@suse.com
- erofs: set error to bio if file-backed IO fails (git-fixes).
- commit a6727e0
* Tue May  6 2025 ailiop@suse.com
- erofs: fix potential return value overflow of
  z_erofs_shrink_scan() (git-fixes).
- commit 17881c6
* Tue May  6 2025 ailiop@suse.com
- erofs: sunset `struct erofs_workgroup` (git-fixes).
- commit a08db22
* Tue May  6 2025 ailiop@suse.com
- erofs: move erofs_workgroup operations into zdata.c (git-fixes).
- commit 2057765
* Tue May  6 2025 ailiop@suse.com
- erofs: get rid of erofs_{find,insert}_workgroup (git-fixes).
- commit 3d3733d
* Tue May  6 2025 oneukum@suse.com
- USB: storage: quirk for ADATA Portable HDD CH94 (git-fixes).
- commit 11e9a18
* Tue May  6 2025 ailiop@suse.com
- xfs: rename xfs_iomap_swapfile_activate to xfs_vm_swap_activate
  (git-fixes).
- commit 2dad561
* Tue May  6 2025 oneukum@suse.com
- usb: quirks: add DELAY_INIT quirk for Silicon Motion Flash Drive
  (git-fixes).
- commit ebb282b
* Tue May  6 2025 ailiop@suse.com
- xfs: do not check NEEDSREPAIR if ro,norecovery mount
  (git-fixes).
- commit cca9581
* Tue May  6 2025 ailiop@suse.com
- xfs: clean up log item accesses in xfs_qm_dqflush{,_done}
  (git-fixes).
- commit 350d255
* Tue May  6 2025 ailiop@suse.com
- xfs: separate dquot buffer reads from xfs_dqflush (git-fixes).
- commit 192f33e
* Tue May  6 2025 ailiop@suse.com
- NFSD: Encode COMPOUND operation status on page boundaries
  (git-fixes).
- commit fecafc3
* Tue May  6 2025 oneukum@suse.com
- usb: gadget: aspeed: Add NULL pointer check in
  ast_vhub_init_dev() (git-fixes).
- commit 0168bff
* Tue May  6 2025 oneukum@suse.com
- usb: dwc3: gadget: Avoid using reserved endpoints on Intel
  Merrifield (git-fixes).
- commit c302821
* Tue May  6 2025 oneukum@suse.com
- usb: dwc3: gadget: Refactor loop to avoid NULL endpoints
  (git-fixes).
- commit d64f040
* Tue May  6 2025 oneukum@suse.com
- usb: host: max3421-hcd: Add missing spi_device_id table
  (git-fixes).
- commit f198730
* Tue May  6 2025 pfalcato@suse.de
- net: ipv6: rpl_iptunnel: mitigate 2-realloc issue (git-fixes).
- commit d054524
* Tue May  6 2025 pfalcato@suse.de
- net: ipv6: seg6_iptunnel: mitigate 2-realloc issue (git-fixes).
- commit ca9fbb2
* Tue May  6 2025 pfalcato@suse.de
- include: net: add static inline dst_dev_overhead() to dst.h
  (git-fixes).
- commit 22ecdb9
* Tue May  6 2025 pfalcato@suse.de
- xfrm: Add support for per cpu xfrm state handling (git-fixes).
- commit e9b8e0a
* Tue May  6 2025 pfalcato@suse.de
- mptcp: fix possible integer overflow in mptcp_reset_tout_timer
  (git-fixes).
- commit 980364e
* Tue May  6 2025 pfalcato@suse.de
- mptcp: annotate data-races around subflow->fully_established
  (git-fixes).
- commit 76ae7cb
* Tue May  6 2025 pfalcato@suse.de
- net/sched: cbs: Fix integer overflow in cbs_set_port_rate()
  (git-fixes).
- commit 616b7a0
* Tue May  6 2025 pfalcato@suse.de
- net_sched: sch_sfq: handle bigger packets (git-fixes).
- commit d218638
* Tue May  6 2025 tzimmermann@suse.com
- drm/amdgpu: Replace Mutex with Spinlock for RLCG register access to (bsc#1241635 CVE-2025-38104)
- commit 6887f04
* Tue May  6 2025 shung-hsi.yu@suse.com
- selftests/bpf: Add strparser test for bpf (bsc#1242438).
- selftests/bpf: Fix invalid flag of recv() (bsc#1242438).
- bpf: Fix wrong copied_seq calculation (bsc#1242438).
- strparser: Add read_sock callback (bsc#1242438).
- selftests/bpf: Add some tests with sockmap SK_PASS
  (bsc#1242438).
- commit 01d874a
* Tue May  6 2025 shung-hsi.yu@suse.com
- selftests/bpf: Select NUMA_NO_NODE to create map (git-fixes).
- selftests/bpf: Define SYS_PREFIX for powerpc (git-fixes).
- selftests/bpf: Avoid generating untracked files when running
  bpf selftests (git-fixes).
- bpf: Use refcount_t instead of atomic_t for mmap_count
  (git-fixes).
- selftests/bpf: Fix fill_link_info selftest on powerpc
  (git-fixes).
- tools/testing/selftests/bpf/test_tc_tunnel.sh: Fix wait for
  server bind (git-fixes).
- selftests/bpf: Actuate tx_metadata_len in xdp_hw_metadata
  (git-fixes).
- selftests/bpf: Fix compilation error in get_uprobe_offset()
  (git-fixes).
- commit 9c7f218
* Tue May  6 2025 lduncan@suse.com
- md/md-bitmap: fix stats collection for external bitmaps
  (git-fixes).
- md/raid10: fix missing discard IO accounting (git-fixes).
- md/raid10: wait barrier before returning discard request with
  REQ_NOWAIT (git-fixes).
- md/raid1,raid10: don't ignore IO flags (git-fixes).
- md: fix mddev uaf while iterating all_mddevs list (git-fixes).
- md/raid1: fix memory leak in raid1_run() if no active rdev
  (git-fixes).
- md: ensure resync is prioritized over recovery (git-fixes).
- commit d9fa75e
* Mon May  5 2025 joao.povoas@suse.com
- Update
  patches.suse/ALSA-timer-Don-t-take-register_mutex-with-copy_from-.patch
  (git-fixes CVE-2025-23134 bsc#1241628).
- Update
  patches.suse/Bluetooth-btnxpuart-Fix-kernel-panic-during-FW-relea.patch
  (git-fixes CVE-2025-22102 bsc#1241456).
- Update
  patches.suse/HID-ignore-non-functional-sensor-in-HP-5MP-Camera.patch
  (stable-fixes CVE-2025-21992 bsc#1240796).
- Update
  patches.suse/PCI-ASPM-Fix-link-state-exit-during-switch-upstream-.patch
  (git-fixes CVE-2024-58093 bsc#1241347).
- Update
  patches.suse/RDMA-core-Fix-use-after-free-when-rename-device-name.patch
  (git-fixes CVE-2025-22085 bsc#1241419).
- Update
  patches.suse/RDMA-erdma-Prevent-use-after-free-in-erdma_accept_ne.patch
  (git-fixes CVE-2025-22088 bsc#1241528).
- Update
  patches.suse/RDMA-mlx5-Fix-mlx5_poll_one-cur_qp-update-flow.patch
  (git-fixes CVE-2025-22086 bsc#1241458).
- Update
  patches.suse/RDMA-mlx5-Fix-page_size-variable-overflow.patch
  (git-fixes CVE-2025-22091 bsc#1241535).
- Update
  patches.suse/acpi-nfit-fix-narrowing-conversion-in-acpi_nfit_ctl.patch
  (git-fixes CVE-2025-22044 bsc#1241424).
- Update
  patches.suse/arm64-Don-t-call-NULL-in-do_compat_alignment_fixup.patch
  (git-fixes CVE-2025-22033 bsc#1241436).
- Update patches.suse/block-fix-adding-folio-to-bio.patch
  (git-fixes CVE-2025-22122 bsc#1241594).
- Update
  patches.suse/block-fix-queue-freeze-vs-limits-lock-order-in-sysfs.patch
  (jsc#PED-9651 CVE-2025-21807 bsc#1238756).
- Update
  patches.suse/bnxt_en-Mask-the-bd_cnt-field-in-the-TX-BD-properly.patch
  (git-fixes CVE-2025-22108 bsc#1241574).
- Update
  patches.suse/bpf-Fix-bpf_sk_select_reuseport-memory-leak.patch
  (git-fixes CVE-2025-21683 bsc#1236704).
- Update
  patches.suse/bpf-avoid-holding-freeze_mutex-during-mmap-operation.patch
  (git-fixes CVE-2025-21853 bsc#1239476).
- Update
  patches.suse/dlm-prevent-NPD-when-writing-a-positive-value-to-event_done.patch
  (git-fixes CVE-2025-23131 bsc#1241601).
- Update
  patches.suse/drm-amd-display-avoid-NPD-when-ASIC-does-not-support.patch
  (git-fixes CVE-2025-22093 bsc#1241545).
- Update
  patches.suse/drm-vkms-Fix-use-after-free-and-double-free-on-init-.patch
  (git-fixes CVE-2025-22097 bsc#1241541).
- Update
  patches.suse/efi-Don-t-map-the-entire-mokvar-table-to-determine-i.patch
  (stable-fixes CVE-2025-21872 bsc#1240323).
- Update
  patches.suse/eth-bnxt-fix-out-of-range-access-of-vnic_info-array.patch
  (jsc#PED-11923 CVE-2025-22112 bsc#1241581).
- Update patches.suse/exfat-fix-missing-shutdown-check.patch
  (git-fixes CVE-2025-22076 bsc#1241417).
- Update
  patches.suse/exfat-fix-random-stack-corruption-after-get_block.patch
  (git-fixes CVE-2025-22036 bsc#1241426).
- Update
  patches.suse/idpf-check-error-for-register_netdev-on-init.patch
  (git-fixes CVE-2025-22116 bsc#1241459).
- Update
  patches.suse/idpf-fix-adapter-NULL-pointer-dereference-on-reboot.patch
  (git-fixes CVE-2025-22065 bsc#1241333).
- Update
  patches.suse/ipv6-mcast-add-RCU-protection-to-mld_newpack.patch
  (git-fixes CVE-2025-21758 bsc#1238737).
- Update
  patches.suse/media-streamzap-fix-race-between-device-disconnectio.patch
  (git-fixes CVE-2025-22027 bsc#1241369).
- Update
  patches.suse/media-vimc-skip-.s_stream-for-stopped-entities.patch
  (git-fixes CVE-2025-22028 bsc#1241362).
- Update
  patches.suse/mm-clear-uffd-wp-PTE-PMD-state-on-mremap.patch
  (bsc#1236648 CVE-2025-21696 bsc#1237111).
- Update
  patches.suse/mptcp-fix-scheduling-while-atomic-in-mptcp_pm_nl_app.patch
  (git-fixes CVE-2025-21938 bsc#1240723).
- Update
  patches.suse/msft-hv-3167-fbdev-hyperv_fb-Allow-graceful-removal-of-framebuffe.patch
  (git-fixes CVE-2025-21976 bsc#1241145).
- Update
  patches.suse/net-9p-usbg-fix-handling-of-the-failed-kzalloc-memor.patch
  (git-fixes CVE-2024-56730 bsc#1235610).
- Update
  patches.suse/net-Remove-RTNL-dance-for-SIOCBRADDIF-and-SIOCBRDELI.patch
  (git-fixes CVE-2025-22111 bsc#1241572).
- Update
  patches.suse/net-ethtool-netlink-Allow-NULL-nlattrs-when-getting-.patch
  (git-fixes CVE-2025-21921 bsc#1240637).
- Update patches.suse/net-rose-lock-the-socket-in-rose_bind.patch
  (git-fixes CVE-2025-21749 bsc#1238904).
- Update
  patches.suse/netfilter-ipset-add-missing-range-check-in-bitmap_ip.patch
  (git-fixes CVE-2024-53141 bsc#1234381).
- Update
  patches.suse/netfilter-nft_socket-remove-WARN_ON_ONCE-on-maximum-.patch
  (git-fixes CVE-2024-56783 bsc#1235625).
- Update
  patches.suse/nfsd-fix-legacy-client-tracking-initialization.patch
  (git-fixes CVE-2024-58092 bsc#1241285).
- Update
  patches.suse/nfsd-fix-management-of-listener-transports.patch
  (git-fixes CVE-2025-22024 bsc#1241348).
- Update
  patches.suse/nfsd-put-dl_stid-if-fail-to-queue-dl_recall.patch
  (git-fixes CVE-2025-22025 bsc#1241361).
- Update
  patches.suse/ntb_hw_switchtec-Fix-shift-out-of-bounds-in-switchte.patch
  (git-fixes CVE-2023-53034 bsc#1241341).
- Update
  patches.suse/ocfs2-handle-a-symlink-read-error-correctly.patch
  (git-fixes CVE-2024-58001 bsc#1239079).
- Update
  patches.suse/ovl-support-encoding-fid-from-inode-with-no-alias.patch
  (bsc#1238448 CVE-2025-21654 bsc#1236162).
- Update
  patches.suse/powerpc-perf-Fix-ref-counting-on-the-PMU-vpa_pmu.patch
  (git-fixes CVE-2025-22094 bsc#1241512).
- Update
  patches.suse/riscv-kvm-Fix-out-of-bounds-array-access.patch
  (jsc#PED-348 CVE-2024-53228 bsc#1235094).
- Update
  patches.suse/rtnetlink-Allocate-vfinfo-size-for-VF-GUIDs-when-sup.patch
  (bsc#1224013 CVE-2025-22075 bsc#1241402).
- Update
  patches.suse/sctp-add-mutual-exclusion-in-proc_sctp_do_udp_port.patch
  (git-fixes CVE-2025-22062 bsc#1241412).
- Update
  patches.suse/thermal-int340x-Add-NULL-check-for-adev.patch
  (git-fixes CVE-2025-23136 bsc#1241357).
- Update
  patches.suse/ublk-make-sure-ubq-canceling-is-set-when-queue-is-frozen.patch
  (git-fixes CVE-2025-22068 bsc#1241411).
- Update patches.suse/udp-Fix-memory-accounting-leak.patch
  (git-fixes CVE-2025-22058 bsc#1241332).
- Update
  patches.suse/usb-xhci-Apply-the-link-chain-quirk-on-NEC-isoc-endp.patch
  (git-fixes CVE-2025-22022 bsc#1241292).
- Update patches.suse/usbnet-fix-NPE-during-rx_complete.patch
  (git-fixes CVE-2025-22050 bsc#1241441).
- Update
  patches.suse/vhost-scsi-Fix-handling-of-multiple-calls-to-vhost_s.patch
  (git-fixes CVE-2025-22083 bsc#1241414).
- Update
  patches.suse/w1-fix-NULL-pointer-dereference-in-probe.patch
  (git-fixes CVE-2025-22084 bsc#1241338).
- Update
  patches.suse/wifi-ath11k-Clear-affinity-hint-before-calling-ath11.patch
  (git-fixes CVE-2025-23129 bsc#1241599).
- Update
  patches.suse/wifi-ath11k-add-srng-lock-for-ath11k_hal_srng_-in-mo.patch
  (git-fixes CVE-2024-58096 bsc#1241344).
- Update
  patches.suse/wifi-ath11k-fix-RCU-stall-while-reaping-monitor-dest.patch
  (git-fixes CVE-2024-58097 bsc#1241343).
- Update
  patches.suse/wifi-ath11k-update-channel-list-in-reg-notifier-inst.patch
  (git-fixes CVE-2025-23133 bsc#1241451).
- Update
  patches.suse/wifi-ath12k-Clear-affinity-hint-before-calling-ath12.patch
  (git-fixes CVE-2025-22128 bsc#1241598).
- Update
  patches.suse/wifi-mt76-mt7921-fix-kernel-panic-due-to-null-pointe.patch
  (git-fixes CVE-2025-22032 bsc#1241425).
- commit a5369e9
* Mon May  5 2025 jack@suse.cz
- ext4: add more ext4_emergency_state() checks around sb_rdonly()
  (bsc#1242340).
- commit e34367c
* Mon May  5 2025 jack@suse.cz
- ext4: add ext4_emergency_state() helper function (bsc#1242340).
- commit 2802292
* Mon May  5 2025 jack@suse.cz
- ext4: add EXT4_FLAGS_EMERGENCY_RO bit (bsc#1242340).
- commit 726006a
* Mon May  5 2025 jack@suse.cz
- ext4: convert EXT4_FLAGS_* defines to enum (bsc#1242340).
- commit a75e7cb
* Mon May  5 2025 jack@suse.cz
- ext4: make block validity check resistent to sb bh corruption
  (bsc#1242348).
- commit 7d22394
* Mon May  5 2025 jack@suse.cz
- ext4: don't treat fhandle lookup of ea_inode as FS corruption
  (bsc#1242347).
- commit ba6203b
* Mon May  5 2025 jack@suse.cz
- jbd2: add a missing data flush during file and fs
  synchronization (bsc#1242346).
- commit fa4ed15
* Mon May  5 2025 vkarasulli@suse.de
- iommu: Fix two issues in iommu_copy_struct_from_user()
  (git-fixes).
- commit 86e4261
* Mon May  5 2025 jack@suse.cz
- ext4: don't over-report free space or inodes in statvfs
  (bsc#1242345).
- commit 8be4480
* Mon May  5 2025 jack@suse.cz
- jbd2: fix off-by-one while erasing journal (bsc#1242344).
- commit 123caf6
* Mon May  5 2025 jack@suse.cz
- jbd2: remove wrong sb->s_sequence check (bsc#1242343).
- commit f026605
* Mon May  5 2025 jack@suse.cz
- ext4: add missing brelse() for bh2 in ext4_dx_add_entry()
  (bsc#1242342).
- commit 383a1e1
* Mon May  5 2025 jack@suse.cz
- ext4: show 'emergency_ro' when EXT4_FLAGS_EMERGENCY_RO is set
  (bsc#1242340).
- commit d5057af
* Mon May  5 2025 jack@suse.cz
- ext4: correct behavior under errors=remount-ro mode
  (bsc#1242337).
- blacklist.conf: Blacklist 57e7239ce0ed
- commit a79e7b9
* Mon May  5 2025 jack@suse.cz
- ext4: partial zero eof block on unaligned inode size extension
  (bsc#1242336).
- commit cacba0b
* Mon May  5 2025 jack@suse.cz
- ext4: protect ext4_release_dquot against freezing (bsc#1242335).
- commit 457d212
* Mon May  5 2025 jack@suse.cz
- ext4: introduce linear search for dentries (bsc#1242334).
- commit 58bf0d9
* Mon May  5 2025 jack@suse.cz
- jbd2: flush filesystem device before updating tail sequence
  (bsc#1242333).
- commit 3798ec5
* Mon May  5 2025 jack@suse.cz
- jbd2: increase IO priority for writing revoke records
  (bsc#1242332).
- commit a382b37
* Mon May  5 2025 jack@suse.cz
- ext4: fix race in buffer_head read fault injection
  (bsc#1242331).
- commit 994f6d0
* Mon May  5 2025 jack@suse.cz
- splice: remove duplicate noinline from pipe_clear_nowait
  (bsc#1242328).
- commit 62a8d5e
* Mon May  5 2025 jack@suse.cz
- mm: fix filemap_get_folios_contig returning batches of identical
  folios (bsc#1242327).
- commit 7222583
* Mon May  5 2025 jack@suse.cz
- mm: fix error handling in __filemap_get_folio() with FGP_NOWAIT
  (bsc#1242326).
- commit 4a38c7a
* Mon May  5 2025 jack@suse.cz
- mm/readahead: fix large folio support in async readahead
  (bsc#1242321).
- commit e2de4df
* Mon May  5 2025 jack@suse.cz
- mm/filemap: don't call folio_test_locked() without a reference
  in next_uptodate_folio() (bsc#1242318).
- commit 2a71dc7
* Mon May  5 2025 jack@suse.cz
- mm: don't set readahead flag on a folio when lookahead_size >
  nr_to_read (bsc#1242317).
- commit 06b8a5d
* Mon May  5 2025 jack@suse.cz
- mm/truncate: reset xa_has_values flag on each iteration
  (bsc#1242316).
- commit 33fa0e9
* Mon May  5 2025 jack@suse.cz
- udf: Skip parent dir link count update if corrupted
  (bsc#1242315).
- commit 8928a78
* Mon May  5 2025 jack@suse.cz
- udf: Verify inode link counts before performing rename
  (bsc#1242314).
- commit d1d387f
* Mon May  5 2025 jack@suse.cz
- udf: Fix inode_getblk() return value (bsc#1242313).
- commit 9d52630
* Mon May  5 2025 jack@suse.cz
- fsnotify: fix sending inotify event with unexpected filename
  (bsc#1234198).
- commit 4e33fd9
* Mon May  5 2025 jack@suse.cz
- block: never reduce ra_pages in blk_apply_bdi_limits
  (bsc#1242308).
- commit 9418247
* Mon May  5 2025 jack@suse.cz
- isofs: fix KMSAN uninit-value bug in do_isofs_readdir()
  (bsc#1242307).
- commit 051b9f7
* Mon May  5 2025 rgoldwyn@suse.com
- ext4: avoid journaling sb update on error if journal is destroying (bsc#1241967).
- commit 4c6dcbd
* Mon May  5 2025 rgoldwyn@suse.com
- ext4: define ext4_journal_destroy wrapper (bsc#1241967).
- commit b1ba8b2
* Mon May  5 2025 davide.benini@suse.com
- mptcp: consolidate suboption status (CVE-2025-21707
  bsc#1238862).
- commit 83b24f9
* Mon May  5 2025 mfranc@suse.cz
- reenable TN3270 so that conmode=3270 keep working (bsc#1242296)
- commit 41f697e
* Mon May  5 2025 tzimmermann@suse.com
- drm/mgag200: Added support for the new device G200eH5 (bsc#1242129 jsc#PED-10427)
- commit ed5dd29
* Mon May  5 2025 msuchanek@suse.de
- Documentation: Fix description format for powerpc RTAS ioctls
  (jsc#PED-4486).
- powerpc/pseries: Include linux/types.h in papr-platform-dump.h
  (jsc#PED-4486).
- commit 0825081
* Mon May  5 2025 msuchanek@suse.de
- make use of anon_inode_getfile_fmode() (jsc#PED-4486).
- Refresh patches.suse/powerpc-pseries-Add-a-char-driver-for-physical-attes.patch.
- Refresh patches.suse/powerpc-pseries-Add-ibm-get-dynamic-sensor-state-RTA.patch.
- Refresh patches.suse/powerpc-pseries-Add-ibm-set-dynamic-indicator-RTAS-c.patch.
- Refresh patches.suse/powerpc-pseries-Add-papr-indices-char-driver-for-ibm.patch.
- Refresh patches.suse/powerpc-pseries-Add-papr-platform-dump-character-dri.patch.
- Refresh patches.suse/powerpc-pseries-Define-common-functions-for-RTAS-seq.patch.
- Refresh patches.suse/powerpc-pseries-Define-papr_indices_io_block-for-pap.patch.
- commit e8f7e0c
* Mon May  5 2025 msuchanek@suse.de
- powerpc/bpf: fix JIT code size calculation of bpf trampoline
  (jsc#PED-10909 git-fixes).
- commit e7da6dd
* Mon May  5 2025 msuchanek@suse.de
- powerpc: Don't use --- in kernel logs (git-fixes).
- commit ecb31d5
* Mon May  5 2025 msuchanek@suse.de
- powerpc64/ftrace: fix clobbered r15 during livepatching
  (jsc#PED-10909 git-fixes).
- commit a971e4a
* Mon May  5 2025 pfalcato@suse.de
- mptcp: only inc MPJoinAckHMacFailure for HMAC failures
  (git-fixes).
- commit d5bbe65
* Mon May  5 2025 pfalcato@suse.de
- mptcp: fix NULL pointer in can_accept_new_subflow (git-fixes).
- commit e4b6b25
* Mon May  5 2025 pfalcato@suse.de
- mptcp: sockopt: fix getting freebind & transparent (git-fixes).
- commit 3a57f0a
* Mon May  5 2025 pfalcato@suse.de
- mptcp: sockopt: fix getting IPV6_V6ONLY (git-fixes).
- commit 3a8bd3c
* Mon May  5 2025 pfalcato@suse.de
- mptcp: Fix data stream corruption in the address announcement
  (git-fixes).
- commit 9194c38
* Mon May  5 2025 pfalcato@suse.de
- mptcp: fix 'scheduling while atomic' in
  mptcp_pm_nl_append_new_local_addr (git-fixes).
- commit 8aeaf4b
* Mon May  5 2025 pfalcato@suse.de
- mptcp: reset when MPTCP opts are dropped after join (git-fixes).
- commit 71d9d00
* Mon May  5 2025 pfalcato@suse.de
- mptcp: blackhole only if 1st SYN retrans w/o MPC is accepted
  (git-fixes).
- commit 32e4230
* Mon May  5 2025 pfalcato@suse.de
- netdev: avoid CFI problems with sock priv helpers (git-fixes).
- commit 9750c47
* Mon May  5 2025 pfalcato@suse.de
- mptcp: be sure to send ack when mptcp-level window re-opens
  (git-fixes).
- commit 3f7ccb9
* Mon May  5 2025 pfalcato@suse.de
- mptcp: sysctl: avail sched: remove write access (git-fixes).
- commit d8519fb
* Mon May  5 2025 pfalcato@suse.de
- mptcp: prevent excessive coalescing on receive (git-fixes).
- commit 261188f
* Mon May  5 2025 pfalcato@suse.de
- mptcp: don't always assume copied data in mptcp_cleanup_rbuf()
  (git-fixes).
- commit 7d46f2f
* Mon May  5 2025 ohering@suse.de
- Drivers: hv: Fix bad ref to hv_synic_eventring_tail when CPU
  goes offline (git-fixes).
- tools/hv: update route parsing in kvp daemon (git-fixes).
- Drivers: hv: Fix bad pointer dereference in hv_get_partition_id
  (git-fixes).
- commit 72ebc30
* Fri May  2 2025 mwilck@suse.com
- scsi: megaraid_sas: Driver version update to 07.734.00.00-rc1
  (jsc#PED-11259).
- commit c5e6340
* Fri May  2 2025 mwilck@suse.com
- scsi: megaraid_sas: Block zero-length ATA VPD inquiry
  (jsc#PED-11259).
- commit 5d51b2e
* Fri May  2 2025 mwilck@suse.com
- scsi: megaraid_sas: Make most module parameters static
  (jsc#PED-11259).
- commit 3864bb1
* Fri May  2 2025 mwilck@suse.com
- scsi: usb: Rename the RESERVE and RELEASE constants
  (jsc#PED-11259).
- commit d4d26d7
* Fri May  2 2025 mwilck@suse.com
- scsi: Constify struct pci_device_id (jsc#PED-11259).
- commit 29e45b8
* Fri May  2 2025 mwilck@suse.com
- scsi: Eliminate scsi_register() and scsi_unregister() usage &
  docs (jsc#PED-11259).
- commit 4ca2668
* Fri May  2 2025 mwilck@suse.com
- scsi: hpsa: Replace deprecated strncpy() with strscpy_pad()
  (jsc#PED-11374).
- commit 4f60ab0
* Fri May  2 2025 mwilck@suse.com
- scsi: hpsa: Remove deprecated and unnecessary strncpy()
  (jsc#PED-11374).
- commit 5f4ce17
* Fri May  2 2025 dsterba@suse.com
- net: dsa: sja1105: fix kasan out-of-bounds warning in sja1105_table_delete_entry() (CVE-2025-22107 bsc#1241575)
- commit dc509e5
* Fri May  2 2025 dsterba@suse.com
- ibmvnic: Use kernel helpers for hex dumps (CVE-2025-22104 bsc#1241550)
- commit 850c60b
* Fri May  2 2025 mwilck@suse.com
- dm: always update the array size in realloc_argv on success
  (git-fixes).
- commit 87e3281
* Fri May  2 2025 mwilck@suse.com
- dm-bufio: don't schedule in atomic context (git-fixes).
- commit c14d078
* Fri May  2 2025 pfalcato@suse.de
- net: use sock_gen_put() when sk_state is TCP_TIME_WAIT
  (git-fixes).
- commit 76d8aa5
* Fri May  2 2025 pfalcato@suse.de
- net: ipv6: fix UDPv6 GSO segmentation with NAT (git-fixes).
- commit 92c5da0
* Fri May  2 2025 pfalcato@suse.de
- net_sched: qfq: Fix double list add in class with netem as
  child qdisc (git-fixes).
- commit 0d2103f
* Fri May  2 2025 pfalcato@suse.de
- net_sched: ets: Fix double list add in class with netem as
  child qdisc (git-fixes).
- commit 9b56c28
* Fri May  2 2025 pfalcato@suse.de
- net_sched: hfsc: Fix a UAF vulnerability in class with netem
  as child qdisc (git-fixes).
- commit 42d57cb
* Fri May  2 2025 pfalcato@suse.de
- net_sched: drr: Fix double list add in class with netem as
  child qdisc (git-fixes).
- commit 0f8e965
* Fri May  2 2025 tiwai@suse.de
- Bluetooth: L2CAP: copy RX timestamp to new fragments
  (git-fixes).
- Bluetooth: btintel_pcie: Add additional to checks to clear
  TX/RX paths (git-fixes).
- Bluetooth: btusb: avoid NULL pointer dereference in
  skb_dequeue() (git-fixes).
- Bluetooth: btintel_pcie: Avoid redundant buffer allocation
  (git-fixes).
- Bluetooth: hci_conn: Fix not setting timeout for BIG Create Sync
  (git-fixes).
- Bluetooth: hci_conn: Fix not setting conn_timeout for Broadcast
  Receiver (git-fixes).
- wifi: brcm80211: fmac: Add error handling for
  brcmf_usb_dl_writeimage() (git-fixes).
- wifi: plfxlc: Remove erroneous assert in plfxlc_mac_release
  (git-fixes).
- wifi: iwlwifi: fix the check for the SCRATCH register upon
  resume (git-fixes).
- wifi: iwlwifi: don't warn if the NIC is gone in resume
  (git-fixes).
- commit bc2d5f4
* Wed Apr 30 2025 davide.benini@suse.com
- net: ipv6: fix dst ref loops in rpl, seg6 and ioam6 lwtunnels
  (CVE-2025-21768 bsc#1238714).
- commit 9b3a0ce
* Wed Apr 30 2025 ailiop@suse.com
- Reassign patches.suse/md-display-timeout-error.patch
- commit 800a738
* Wed Apr 30 2025 lduncan@suse.com
- devtmpfs: don't use vfs_getattr_nosec to query i_mode
  (git-fixes).
- commit 8b172cd
* Wed Apr 30 2025 ailiop@suse.com
- Delete patches.suse/NFS-never-reuse-a-NFSv4-0-lock-owner.patch.
  This patch was upstreamed in commit d98f72272500 ("nfs: simplify and guarantee
  owner uniqueness.") in v6.12-rc1, and as such is already part of the SL-16.0
  base.
- commit cd65cf6
* Wed Apr 30 2025 ailiop@suse.com
- Refresh patches.suse/nfs-serialize-opens.patch.
- commit ed1030a
* Wed Apr 30 2025 ailiop@suse.com
- Refresh
  patches.suse/NFS-Handle-missing-attributes-in-OPEN-reply.patch.
- commit 54cd6de
* Wed Apr 30 2025 ailiop@suse.com
- Refresh patches.suse/nfs-access-cache-no-negative.patch.
- commit a7a5059
* Wed Apr 30 2025 ailiop@suse.com
- Delete patches.suse/nfsd-dont-revoke-v4-0-states.patch.
  This patch was upstreamed in commit d688d8585e6b ("nfsd: allow admin-revoked
  NFSv4.0 state to be freed.") in v6.9-rc1, and as such is already part of the
  SL-16.0 base.
- commit 4a72771
* Wed Apr 30 2025 ailiop@suse.com
- Delete
  patches.suse/nfsd-allow-delegation-state-ids-to-be-revoked-and-th.patch.
  This patch was upstreamed in commit 06efa66750a6 ("nfsd: allow delegation state
  ids to be revoked and then freed") in v6.9-rc1, and as such is already part of
  the SL-16.0 base.
- commit eafba28
* Wed Apr 30 2025 ailiop@suse.com
- Delete
  patches.suse/nfsd-allow-lock-state-ids-to-be-revoked-and-then-fre.patch.
  This patch was upstreamed in commit 1c13bf9f2e3c ("nfsd: allow lock state ids
  to be revoked and then freed") in v6.9-rc1, and as such is already part of the
  SL-16.0 base.
- commit 629688d
* Wed Apr 30 2025 ailiop@suse.com
- Delete
  patches.suse/nfsd-allow-open-state-ids-to-be-revoked-and-then-fre.patch.
  This patch was upstreamed in commit 39657c740644 ("nfsd: allow open state ids
  to be revoked and then freed") in v6.9-rc1, and as such is already part of the
  SL-16.0 base.
- commit c5ad100
* Wed Apr 30 2025 ailiop@suse.com
- Delete
  patches.suse/nfsd-prepare-for-supporting-admin-revocation-of-stat.patch.
  This patch was upstreamed in commit 1ac3629bf012 ("nfsd: prepare for supporting
  admin-revocation of state") in v6.9-rc1, and as such is already part of the
  SL-16.0 base.
- commit 1e7e247
* Wed Apr 30 2025 ailiop@suse.com
- Delete
  patches.suse/NFS-only-invalidate-dentrys-that-are-clearly-invalid.patch.
  This patch was upstreamed in commit 0c8c7c559740 ("nfs: don't invalidate
  dentries on transient errors") in v6.10-rc4, and as such is already part of the
  SL-16.0 base.
- commit 2b97bc1
* Wed Apr 30 2025 ailiop@suse.com
- Refresh patches.suse/nfs-set-acl-perm.patch.
- commit 212c3c6
* Wed Apr 30 2025 ailiop@suse.com
- Refresh patches.suse/mvfs-workaround.patch.
- commit 96b23c0
* Wed Apr 30 2025 ailiop@suse.com
- Refresh patches.suse/NFS-flush-dirty-data-on-fput-fix.patch.
- commit 4cff336
* Wed Apr 30 2025 davide.benini@suse.com
- Update
  patches.suse/batman-adv-Drop-unmanaged-ELP-metric-worker.patch
  (CVE-2025-21823 bsc#1238475).
- commit ccc0061
* Wed Apr 30 2025 ailiop@suse.com
- Refresh
  patches.suse/0001-NFS-flush-out-dirty-data-on-file-fput.patch.
- commit 003497d
* Wed Apr 30 2025 ailiop@suse.com
- Delete
  patches.suse/NFSv3-only-use-NFS-timeout-for-MOUNT-when-protocols-.patch.
  This patch was upstreamed in commit 6e2a10343ecb ("NFSv3: only use NFS
  timeout for MOUNT when protocols are compatible") in v6.12-rc7, and as
  such is already part of the SL-16.0 base.
- commit 9433e96
* Wed Apr 30 2025 oneukum@suse.com
- Update
  patches.suse/memstick-rtsx_usb_ms-Fix-slab-use-after-free-in-rtsx.patch
  (bsc#1241280 CVE-2025-22020).
  Added CVE to reference
- commit a22621c
* Wed Apr 30 2025 jgross@suse.com
- Delete
  patches.suse/kabi-placeholders-for-coco-host-support.patch.
- commit fb7d9fc
* Wed Apr 30 2025 fdmanana@suse.com
- btrfs: fix block group refcount race in
  btrfs_create_pending_block_groups() (bsc#1241578
  CVE-2025-22115).
- commit 8326b59
* Wed Apr 30 2025 msuchanek@suse.de
- Update patches.suse/KVM-PPC-Enable-CAP_SPAPR_TCE_VFIO-on-pSeries-KVM-gue.patch
  (jsc#PED-10539 git-fixes bsc#1240419 ltc#212279).
- commit 28f1cb3
* Wed Apr 30 2025 pfalcato@suse.de
- netfilter: nf_tables: don't unregister hook when table is
  dormant (CVE-2025-22064 bsc#1241413).
- commit 3c1fc05
* Wed Apr 30 2025 pfalcato@suse.de
- net: libwx: fix Tx L4 checksum (CVE-2025-22101 bsc#1241555).
- commit ca8ce70
* Wed Apr 30 2025 shung-hsi.yu@suse.com
- Delete
  patches.suse/bpf-selftests-adapt-bpf_iter_task_vma-to-got_inode_dev.patch.
  I no longer use openSUSE/SLES VM to run BPF selftests, and instead uses
  upstream's BPF CI to run it. Since the rootfs use is not BTRFS, this
  patch isn't needed.
- commit b4b1b2f
* Wed Apr 30 2025 dsterba@suse.com
- Update references for patches.suse/atm-Fix-NULL-pointer-dereference.patch (CVE-2025-22018 bsc#1241266 git-fixes)
- commit 6abef3a
* Wed Apr 30 2025 dsterba@suse.com
- bpf: bpf_local_storage: Always use bpf_mem_alloc in PREEMPT_RT (CVE-2024-58070 bsc#1238983)
- commit 99a99f3
* Wed Apr 30 2025 dsterba@suse.com
- Update references for patches.suse/udp-Fix-multiple-wraparounds-of-sk-sk_rmem_alloc.patch (CVE-2025-22059 bsc#1241385 git-fixes)
- commit 43e95fb
* Wed Apr 30 2025 jroedel@suse.de
- iommu/vt-d: Avoid use of NULL after WARN_ON_ONCE (CVE-2025-21833, bsc#1239108).
- commit 4e09108
* Wed Apr 30 2025 jack@suse.cz
- Fixup unused label in patches.suse/ext4-fix-out-of-bound-read-in-ext4_xattr_inode_dec_r.patch
- commit e7a7af8
* Wed Apr 30 2025 ptesarik@suse.com
- arm64: allow PREEMPT_LAZY, but keep disabled (bsc#1234370).
- commit 4aea89c
* Wed Apr 30 2025 tbogendoerfer@suse.de
- net: mvpp2: Prevent parser TCAM memory corruption
  (CVE-2025-22060 bsc#1241526).
- bonding: check xdp prog when set bond mode (CVE-2025-22105
  bsc#1241548).
- bonding: return detailed error when loading native XDP fails
  (CVE-2025-22105 bsc#1241548).
- commit 6dae3fd
* Wed Apr 30 2025 tiwai@suse.de
- ALSA: ump: Fix buffer overflow at UMP SysEx message conversion
  (bsc#1242044).
- commit a46f1d9
* Wed Apr 30 2025 tiwai@suse.de
- mmc: renesas_sdhi: Fix error handling in renesas_sdhi_probe
  (git-fixes).
- platform/x86/intel-uncore-freq: Fix missing uncore sysfs during
  CPU hotplug (git-fixes).
- commit 858bc92
* Wed Apr 30 2025 lduncan@suse.com
- scsi: core: Clear flags for scsi_cmnd that did not complete
  (git-fixes).
- scsi: mpi3mr: Fix pending I/O counter (git-fixes).
- fs: move the bdex_statx call to vfs_getattr_nosec (git-fixes).
- block: integrity: Do not call set_page_dirty_lock() (git-fixes).
- loop: stop using vfs_iter_{read,write} for buffered I/O
  (git-fixes).
- loop: LOOP_SET_FD: send uevents for partitions (git-fixes).
- loop: properly send KOBJ_CHANGED uevent for disk device
  (git-fixes).
- block: fix resource leak in blk_register_queue() error path
  (git-fixes).
- ublk: fix handling recovery & reissue in ublk_abort_queue()
  (git-fixes).
- ublk: make sure ubq->canceling is set when queue is frozen
  (git-fixes).
- block: fix adding folio to bio (git-fixes).
- block: make sure ->nr_integrity_segments is cloned in
  blk_rq_prep_clone (git-fixes).
- badblocks: fix missing bad blocks on retry in _badblocks_check()
  (git-fixes).
- badblocks: fix merge issue when new badblocks align with pre+1
  (git-fixes).
- badblocks: fix the using of MAX_BADBLOCKS (git-fixes).
- badblocks: return error if any badblock set fails (git-fixes).
- badblocks: return error directly when setting badblocks exceeds
  512 (git-fixes).
- badblocks: attempt to merge adjacent badblocks during
  ack_all_badblocks (git-fixes).
- badblocks: factor out a helper try_adjacent_combine (git-fixes).
- badblocks: Fix error shitf ops (git-fixes).
- block: Correctly initialize BLK_INTEGRITY_NOGENERATE and
  BLK_INTEGRITY_NOVERIFY (git-fixes).
- block: ensure correct integrity capability propagation in
  stacked devices (git-fixes).
- blk-throttle: fix lower bps rate by throtl_trim_slice()
  (git-fixes).
- block: change blk_mq_add_to_batch() third argument type to bool
  (git-fixes).
- ublk: set_params: properly check if parameters can be applied
  (git-fixes).
- commit c655911
* Tue Apr 29 2025 mwilck@suse.com
- Delete patches.suse/scsi_probe_lun-retry-after-timeout.patch.
  Obsoleted by 987d7d3db0b9 ("scsi: core: Retry INQUIRY after timeout")
- commit ec64964
* Tue Apr 29 2025 lduncan@suse.com
- ublk: refactor recovery configuration flag helpers (git-fixes).
- Refresh
  patches.suse/ublk-fix-ublk_ch_mmap-for-64K-page-size.patch.
- commit 0fb5300
* Tue Apr 29 2025 tonyj@suse.de
- Fix an incorrect Jira reference in the following patches (the correct reference
  is jsc#PED-12756):
    patches.suse/perf-amd-ibs-Add-PMU-specific-minimum-period.patch
    patches.suse/perf-amd-ibs-Add-check_period-callback.patch
    patches.suse/perf-amd-ibs-Add-support-for-OP-Load-Latency-Filtering.patch
    patches.suse/perf-amd-ibs-Ceil-sample_period-to-min_period.patch
    patches.suse/perf-amd-ibs-Don-t-allow-freq-mode-event-creation-through-config-interface.patch
    patches.suse/perf-amd-ibs-Fix-config-to-sample-period-calculation-for-OP-PMU.patch
    patches.suse/perf-amd-ibs-Fix-perf_ibs_op.cnt_mask-for-CurCnt.patch
    patches.suse/perf-amd-ibs-Prevent-leaking-sensitive-data-to-userspace.patch
    patches.suse/perf-amd-ibs-Remove-IBS_-FETCH-OP-_CONFIG_MASK-macros.patch
    patches.suse/perf-amd-ibs-Remove-pointless-sample-period-check.patch
    patches.suse/perf-amd-ibs-Update-DTLB-PageSize-decode-logic.patch
    patches.suse/perf-core-Check-sample_type-in-perf_sample_save_callchain.patch
    patches.suse/perf-core-Export-perf_exclude_event.patch
    patches.suse/perf-x86-Check-data-address-for-IBS-software-filter.patch
    patches.suse/perf-x86-Relax-privilege-filter-restriction-on-AMD-IBS.patch
- commit 57248d9
* Tue Apr 29 2025 msuchanek@suse.de
- Require zstd in kernel-default-devel when module compression is zstd
  To use ksym-provides tool modules need to be uncompressed.
  Without zstd at least kernel-default-base does not have provides.
  Link: https://github.com/openSUSE/rpm-config-SUSE/pull/82
- commit a3262dd
* Tue Apr 29 2025 pfalcato@suse.de
- net: ibmveth: make veth_pool_store stop hanging (CVE-2025-22053
  bsc#1241373).
- commit b891bbf
* Tue Apr 29 2025 mwilck@suse.com
- Enable patches.suse/dm_blk_ioctl-implement-path-failover-for-SG_IO.patch (jsc#PED-12763)
  also patches.suse/dm-multipath-dont-attempt-SG_IO-on-non-SCSI-disks-.patch
  These are downstream patches for T-systems.
- commit 51e8c0f
* Tue Apr 29 2025 oneukum@suse.com
- SUSE add padding for USB reset (jsc#PED-10906).
- commit 2638f23
* Tue Apr 29 2025 oneukum@suse.com
- usb: ulpi: Remove unused otg_ulpi_create (jsc#PED-10906).
- commit a3ee783
* Tue Apr 29 2025 oneukum@suse.com
- usb: Add base USB MCTP definitions (jsc#PED-10906).
- commit 41d5579
* Tue Apr 29 2025 jwiesner@suse.de
- Refreshed: clocksource: disable watchdog checks on TSC when TSC is watchdog
  (bsc#1215885).
- commit 58f80d7
* Tue Apr 29 2025 mkubecek@suse.cz
- Reenable patches.suse/netfilter-nf_tables-fix-64-bit-load-issue-in-nft_byt.patch
  The upstream solution was supposed to be disabling multivalue access but it
  never actually happened so that we still need this fix.
- commit e2924ba
* Tue Apr 29 2025 mkubecek@suse.cz
- Reenable and refresh
  patches.suse/net-allow-retransmitting-a-TCP-packet-if-original-is.patch.
  Unfortunately we still cannot be sure this hack is no longer needed.
- commit 742158c
* Tue Apr 29 2025 mkubecek@suse.cz
- Delete
  patches.suse/lan78xx-Enable-LEDs-and-auto-negotiation.patch.
  An old "not yet" patch that was likely never actually submitted to upstream
  and noone seems to miss it.
- commit d6ed239
* Tue Apr 29 2025 oneukum@suse.com
- usb: typec: ucsi: return CCI and message from sync_control
  callback (jsc#PED-10906).
- commit d935e14
* Tue Apr 29 2025 msuchanek@suse.de
- Update config files (bsc#1241057 ltc#211774).
  CONFIG_PCI_DYNAMIC_OF_NODES=n
- commit 33d2b82
* Tue Apr 29 2025 msuchanek@suse.de
- powerpc/boot: Fix dash warning (bsc#1215199).
- commit c77a110
* Tue Apr 29 2025 mhocko@suse.com
- exec: fix the racy usage of fs_struct->in_exec (CVE-2025-22029
  bsc#1241378).
- commit 151287d
* Tue Apr 29 2025 vbabka@suse.cz
- x86/mm: Fix flush_tlb_range() when used for zapping normal PMDs
  (CVE-2025-22045 bsc#1241433).
- commit 77541f2
* Tue Apr 29 2025 msuchanek@suse.de
- book3s64/radix : Align section vmemmap start address to
  PAGE_SIZE (bsc#1238318).
- commit 0843767
* Tue Apr 29 2025 msuchanek@suse.de
- powerpc/boot: Check for ld-option support (bsc#1215199).
- commit 8087188
* Tue Apr 29 2025 oneukum@suse.com
- typeC: kABI padding for new altmode operations (bsc#1220369).
- commit 283e965
* Tue Apr 29 2025 oneukum@suse.com
- i3c: adding kABI padding (bsc#1220369).
- commit 2d462b3
* Tue Apr 29 2025 oneukum@suse.com
- i2c: adding kABI paddings (bsc#1220369).
- commit 010bc3d
* Tue Apr 29 2025 mhocko@suse.com
- scripts/common-functions: drop is_upstream_sha
  is_upstream_sha is a misnomer because it only guarantees that the given
  commit is in the referenced repository. It doesn't really check whether
  it is reachable from a particular remote or branch. This is not a
  problem for its only existing user because Fixes tags are referring to
  upstream commits but the naming is misleading and more importantly we do
  have a proper function for the purpose so use sha_in_upstream instead.
- commit 5f15f6f
* Tue Apr 29 2025 tonyj@suse.de
- Add perf events kabi padding (kabi).
- commit b808f4b
* Tue Apr 29 2025 tonyj@suse.de
- tools headers: Update the uapi/linux/perf_event.h copy with
  the kernel sources (git-fixes).
- commit 1eecb3d
* Tue Apr 29 2025 tonyj@suse.de
- perf/core: Export perf_exclude_event() (jsc#PED-12549).
- commit 30abc8e
* Mon Apr 28 2025 tonyj@suse.de
- perf/amd/ibs: Update DTLB/PageSize decode logic (jsc#PED-12549).
- perf/amd/ibs: Add support for OP Load Latency Filtering
  (jsc#PED-12549).
- perf/amd/ibs: Ceil sample_period to min_period (jsc#PED-12549).
- perf/amd/ibs: Add ->check_period() callback (jsc#PED-12549).
- perf/amd/ibs: Add PMU specific minimum period (jsc#PED-12549).
- perf/amd/ibs: Don't allow freq mode event creation through
  - >config interface (jsc#PED-12549).
- perf/amd/ibs: Fix perf_ibs_op.cnt_mask for CurCnt
  (jsc#PED-12549).
- perf/amd/ibs: Fix ->config to sample period calculation for
  OP PMU (jsc#PED-12549).
- perf/amd/ibs: Remove pointless sample period check
  (jsc#PED-12549).
- perf/amd/ibs: Remove IBS_{FETCH|OP}_CONFIG_MASK macros
  (jsc#PED-12549).
- perf/amd/ibs: Prevent leaking sensitive data to userspace
  (jsc#PED-12549).
- perf/x86: Check data address for IBS software filter
  (jsc#PED-12549).
- perf/x86: Relax privilege filter restriction on AMD IBS
  (jsc#PED-12549).
- perf/core: Check sample_type in perf_sample_save_callchain
  (jsc#PED-12549).
- commit 02c932c
* Mon Apr 28 2025 tonyj@suse.de
- Delete patches.suse/perf-local-check-alloc-histogram-return.patch.
  Patch was inherited from SP6 where it required a local fix which
  is no longer needed.
- commit 0c4313d
* Mon Apr 28 2025 mhocko@suse.com
- scripts/check-kernel-fix: warn about all invalid shas for CVE
  There might be stable tree specific CVEs (e.g. CVE-2025-40364) which are
  referring to non-upstream (i.e. stable tree) commits. If we encounter
  such a CVE we simply bail out because we do not expect that a CVE would
  be mixing stable specific and upstream commits. If we ever have a case
  like that it would be good to learn about the fact and find out more
  about the reasoning. Therefore turn the hard failure into a warning and
  examine all commit associated with the CVE.
- commit b0969e1
* Mon Apr 28 2025 hare@suse.de
- kabi/severities: exclude CXL (jsc#PED-12211)
- commit 963a5c7
* Mon Apr 28 2025 hare@suse.de
- nvmet: pci-epf: Always configure BAR0 as 64-bit (jsc#PED-9651).
- commit 1bd69f0
* Mon Apr 28 2025 svarbanov@suse.de
- supported.conf: Mark HiSilicon I2C and GPIO modules as supported (jsc#PED-12808)
  Those two modules are needed for HiSilicon Kunpeng SoC.
- commit acc31d6
* Mon Apr 28 2025 svarbanov@suse.de
- supported.conf: Mark HiSilicon crypto ZIP, HPRE and SEC as supported (jsc#PED-12808)
- commit a59b2d2
* Mon Apr 28 2025 svarbanov@suse.de
- supported.conf: Mark HiSi PMU drivers as supported (jsc#PED-12808)
  - supported.conf:
  - drivers/perf/hisilicon/hisi_pcie_pmu
  - drivers/perf/hisilicon/hns3_pmu
    Those two will be handled by drivers/perf/hisilicon/*
- commit c220da8
* Mon Apr 28 2025 svarbanov@suse.de
- supported.conf: Mark HiSi DMA controller as supported (jsc#PED-12808)
  - supported.conf:
    + drivers/dma/hisi_dma
- commit ab21278
* Mon Apr 28 2025 svarbanov@suse.de
- supported.conf: Mark HiSi TRNG v2 as supported (jsc#PED-12808)
  - supported.conf:
  - drivers/char/hw_random/hisi-trng-v2
    + drivers/crypto/hisilicon/trng/hisi-trng-v2
- commit 02dc142
* Mon Apr 28 2025 mhocko@suse.com
- scripts/check-kernel-fix: make branch_file local
- scripts/common-functions: make branch_file local
  it doesn't have a global scope
- commit 57f575c
* Mon Apr 28 2025 svarbanov@suse.de
- supported.conf: Enable HiSi accel VFIO PCI (jsc#PED-12808)
  - supported.conf:
    + drivers/vfio/pci/hisilicon/hisi_acc_vfio_pci
- commit f5abe63
* Mon Apr 28 2025 svarbanov@suse.de
- supported.conf: Enable SPI DW mmio driver (jsc#PED-12808)
  - supported.conf
    + drivers/spi/spi-dw
    + drivers/spi/spi-dw-mmio
- commit 11a0f85
* Mon Apr 28 2025 hare@suse.de
- nvmet: fix out-of-bounds access in nvmet_enable_port
  (jsc#PED-9651).
- nvmet: pci-epf: cleanup link state management (jsc#PED-9651).
- commit 6121ef2
* Mon Apr 28 2025 hare@suse.de
- nvmet: pci-epf: clear CC and CSTS when disabling the controller
  (jsc#PED-9651).
- nvmet: pci-epf: always fully initialize completion entries
  (jsc#PED-9651).
- nvmet: auth: use NULL to clear a pointer in nvmet_auth_sq_free()
  (jsc#PED-9651).
- nvme-multipath: sysfs links may not be created for devices
  (jsc#PED-9651).
- nvme: fixup scan failure for non-ANA multipath controllers
  (jsc#PED-9651).
- commit 57152f2
* Mon Apr 28 2025 hare@suse.de
- nvmet-fc: put ref when assoc->del_work is already scheduled
  (jsc#PED-9651).
- nvmet-fc: take tgtport reference only once (jsc#PED-9651).
- nvmet-fc: update tgtport ref per assoc (jsc#PED-9651).
- nvmet-fc: inline nvmet_fc_free_hostport (jsc#PED-9651).
- nvmet-fc: inline nvmet_fc_delete_assoc (jsc#PED-9651).
- nvmet-fcloop: add ref counting to lport (jsc#PED-9651).
- commit ebd7542
* Mon Apr 28 2025 hare@suse.de
- nvmet-fcloop: replace kref with refcount (jsc#PED-9651).
- nvme-tcp: fix use-after-free of netns by kernel TCP socket
  (jsc#PED-9651).
- nvme: multipath: fix return value of nvme_available_path
  (jsc#PED-9651).
- nvme: re-read ANA log page after ns scan completes
  (jsc#PED-9651).
- nvme: requeue namespace scan on missed AENs (jsc#PED-9651).
- commit 9484ecd
* Mon Apr 28 2025 hare@suse.de
- nvme-multipath: change the NVME_MULTIPATH config option
  (jsc#PED-9651).
- nvme: update the multipath warning in nvme_init_ns_head
  (jsc#PED-9651).
- nvme/ioctl: move fixed buffer lookup to nvme_uring_cmd_io()
  (jsc#PED-9651).
- nvme/ioctl: move blk_mq_free_request() out of
  nvme_map_user_request() (jsc#PED-9651).
- nvmet: pci-epf: Keep completion queues mapped (jsc#PED-9651).
- nvme: convert timeouts to secs_to_jiffies() (jsc#PED-9651).
- commit b857496
* Mon Apr 28 2025 hare@suse.de
- nvme-multipath: Add visibility for queue-depth io-policy
  (jsc#PED-9651).
- nvme-multipath: Add visibility for numa io-policy
  (jsc#PED-9651).
- nvme-multipath: Add visibility for round-robin io-policy
  (jsc#PED-9651).
- nvmet: add tls_concat and tls_key debugfs entries
  (jsc#PED-9651).
- nvmet-tcp: support secure channel concatenation (jsc#PED-9651).
- commit 9372a5d
* Mon Apr 28 2025 hare@suse.de
- nvmet: Add 'sq' argument to alloc_ctrl_args (jsc#PED-9651).
- nvme-fabrics: reset admin connection for secure concatenation
  (jsc#PED-9651).
- nvme-tcp: request secure channel concatenation (jsc#PED-9651).
- Refresh patches.suse/nvme-tcp-add-recovery_delay-to-sysfs.patch.
- nvme-keyring: add nvme_tls_psk_refresh() (jsc#PED-9651).
- nvme: add nvme_auth_derive_tls_psk() (jsc#PED-9651).
- commit 0753eb8
* Mon Apr 28 2025 hare@suse.de
- nvme: add nvme_auth_generate_digest() (jsc#PED-9651).
- nvme: add nvme_auth_generate_psk() (jsc#PED-9651).
- crypto,fs: Separate out hkdf_extract() and hkdf_expand()
  (jsc#PED-9651).
- block: remove unused parameter 'q' parameter in
  __blk_rq_map_sg() (jsc#PED-9651).
- nvmet: pci-epf: Do not add an IRQ vector if not needed
  (jsc#PED-9651).
- commit 1de7609
* Mon Apr 28 2025 hare@suse.de
- nvmet: pci-epf: Set NVMET_PCI_EPF_Q_LIVE when a queue is fully
  created (jsc#PED-9651).
- nvme-pci: fix stuck reset on concurrent DPC and HP
  (jsc#PED-9651).
- block: change blk_mq_add_to_batch() third argument type to bool
  (jsc#PED-9651).
- nvme-pci: skip CMB blocks incompatible with PCI P2P DMA
  (jsc#PED-9651).
- nvme-pci: clean up CMBMSC when registering CMB fails
  (jsc#PED-9651).
- commit 7bcdfba
* Mon Apr 28 2025 hare@suse.de
- nvme-tcp: fix possible UAF in nvme_tcp_poll (jsc#PED-9651).
- nvmet: Use enum definitions instead of hardcoded values
  (jsc#PED-9651).
- nvme: Cleanup the definition of the controller config
  (jsc#PED-9651).
- nvmet: pci-epf: Avoid RCU stalls under heavy workload
  (jsc#PED-9651).
- nvmet: pci-epf: Do not uselessly write the CSTS register
  (jsc#PED-9651).
- nvmet: pci-epf: Correctly initialize CSTS when enabling the
  controller (jsc#PED-9651).
- commit 2ee3668
* Mon Apr 28 2025 hare@suse.de
- nvmet: add a missing endianess conversion in
  nvmet_execute_admin_connect (jsc#PED-9651).
- nvmet: the result field in nvmet_alloc_ctrl_args is little
  endian (jsc#PED-9651).
- nvmet: fix a memory leak in controller identify (jsc#PED-9651).
- nvme-pci: remove redundant dma frees in hmb (jsc#PED-9651).
- nvmet: fix rw control endian access (jsc#PED-9651).
- commit b37065f
* Mon Apr 28 2025 hare@suse.de
- nvme-pci: use correct size to free the hmb buffer
  (jsc#PED-9651).
- nvme-pci: fix comment typo (jsc#PED-9651).
- nvmet: New NVMe PCI endpoint function target driver
  (jsc#PED-9651).
- Update config files.
- nvmet: Implement arbitration feature support (jsc#PED-9651).
- nvmet: Implement interrupt config feature support
  (jsc#PED-9651).
- commit 355e9de
* Mon Apr 28 2025 hare@suse.de
- nvmet: Implement interrupt coalescing feature support
  (jsc#PED-9651).
- nvmet: Implement host identifier set feature support
  (jsc#PED-9651).
- nvmet: Introduce get/set_feature controller operations
  (jsc#PED-9651).
- nvmet: Do not require SGL for PCI target controller commands
  (jsc#PED-9651).
- nvmet: Add support for I/O queue management admin commands
  (jsc#PED-9651).
- nvmet: Introduce nvmet_sq_create() and nvmet_cq_create()
  (jsc#PED-9651).
- commit 3aebe42
* Mon Apr 28 2025 hare@suse.de
- nvmet: Introduce nvmet_req_transfer_len() (jsc#PED-9651).
- nvmet: Improve nvmet_alloc_ctrl() interface and implementation
  (jsc#PED-9651).
- nvme: Add PCI transport type (jsc#PED-9651).
- nvmet: Add drvdata field to struct nvmet_ctrl (jsc#PED-9651).
- nvmet: Introduce nvmet_get_cmd_effects_admin() (jsc#PED-9651).
- commit 7f723e1
* Mon Apr 28 2025 hare@suse.de
- nvmet: Export nvmet_update_cc() and nvmet_cc_xxx() helpers
  (jsc#PED-9651).
- nvmet: Add vendor_id and subsys_vendor_id subsystem attributes
  (jsc#PED-9651).
- nvme: Move opcode string helper functions declarations
  (jsc#PED-9651).
- nvme: change return type of nvme_poll_cq() to bool
  (jsc#PED-9651).
- nvmet: handle rw's limited retry flag (jsc#PED-9651).
- commit 6e3ff3c
* Mon Apr 28 2025 hare@suse.de
- nvme-tcp: remove nvme_tcp_destroy_io_queues() (jsc#PED-9651).
- nvme: use blk_validate_block_size() for max LBA check
  (jsc#PED-9651).
- nvme-tcp: simplify nvme_tcp_teardown_io_queues() (jsc#PED-9651).
- nvme-tcp: no need to quiesce admin_q in
  nvme_tcp_teardown_io_queues() (jsc#PED-9651).
- nvme-pci: don't use dma_alloc_noncontiguous with 0 merge
  boundary (jsc#PED-9651).
- commit bc8ad33
* Mon Apr 28 2025 hare@suse.de
- nvmet: replace kmalloc + memset with kzalloc for data allocation
  (jsc#PED-9651).
- nvme-pci: remove two deallocate zeroes quirks (jsc#PED-9651).
- nvmet: use kzalloc instead of ZERO_PAGE in
  nvme_execute_identify_ns_nvm() (jsc#PED-9651).
- nvme: tuning pr code by using defined structs and macros
  (jsc#PED-9651).
- nvme: introduce change ptpl and iekey definition (jsc#PED-9651).
- nvme: define the remaining used sgls constants (jsc#PED-9651).
- commit cc50dac
* Mon Apr 28 2025 hare@suse.de
- nvmet: add tracing of reservation commands (jsc#PED-9651).
- nvme: parse reservation commands's action and rtype to string
  (jsc#PED-9651).
- nvmet: report ns's vwc not present (jsc#PED-9651).
- nvme: check ns's volatile write cache not present
  (jsc#PED-9651).
- nvme: add rotational support (jsc#PED-9651).
- commit 6d72f74
* Mon Apr 28 2025 hare@suse.de
- nvme: use command set independent id ns if available
  (jsc#PED-9651).
- nvmet: support for csi identify ns (jsc#PED-9651).
- nvmet: implement rotational media information log
  (jsc#PED-9651).
- nvmet: implement endurance groups (jsc#PED-9651).
- Refresh
  patches.suse/nvmet-loop-avoid-using-mutex-in-IO-hotpath.patch.
- nvmet: declare 2.1 version compliance (jsc#PED-9651).
- Refresh
  patches.suse/nvmet-loop-avoid-using-mutex-in-IO-hotpath.patch.
- nvmet: implement crto property (jsc#PED-9651).
- commit a9d87e8
* Mon Apr 28 2025 hare@suse.de
- nvmet: implement supported features log (jsc#PED-9651).
- nvmet: implement supported log pages (jsc#PED-9651).
- nvmet: implement active command set ns list (jsc#PED-9651).
- Refresh
  patches.suse/nvmet-loop-avoid-using-mutex-in-IO-hotpath.patch.
- nvmet: implement id ns for nvm command set (jsc#PED-9651).
- nvmet: support reservation feature (jsc#PED-9651).
- Refresh
  patches.suse/nvmet-Fix-crash-when-a-namespace-is-disabled.patch.
- Refresh
  patches.suse/nvmet-loop-avoid-using-mutex-in-IO-hotpath.patch.
- commit 88ed9df
* Mon Apr 28 2025 hare@suse.de
- nvme: add reservation command's defines (jsc#PED-9651).
- nvme-core: remove repeated wq flags (jsc#PED-9651).
- commit 1ad47bf
* Mon Apr 28 2025 hare@suse.de
- nvmet: make nvmet_wq visible in sysfs (jsc#PED-9651).
- commit 6767401
* Mon Apr 28 2025 hare@suse.de
- nvme-pci: use dma_alloc_noncontigous if possible (jsc#PED-9651).
- Refresh
  patches.suse/nvme-pci-add-support-for-sgl-metadata.patch.
- commit 26b5396
* Mon Apr 28 2025 hare@suse.de
- nvme-multipath: don't bother clearing max_hw_zone_append_sectors
  (jsc#PED-9651).
- commit bbefc23
* Mon Apr 28 2025 jroedel@suse.de
- iommu/amd: Fix header file (jsc#PED-12548).
- iommu/amd: Preserve default DTE fields when updating Host Page
  Table Root (jsc#PED-12548).
- commit e9648a6
* Mon Apr 28 2025 tbogendoerfer@suse.de
- net/mlx5: Move ttc allocation after switch case to prevent leaks
  (git-fixes).
- net/mlx5: Fix null-ptr-deref in mlx5_create_{inner_,}ttc_table()
  (git-fixes).
- netlink: specs: rt-link: adjust mctp attribute naming
  (git-fixes).
- netlink: specs: rtnetlink: attribute naming corrections
  (git-fixes).
- netlink: specs: rt-link: add an attr layer around alt-ifname
  (git-fixes).
- cxgb4: fix memory leak in cxgb4_init_ethtool_filters() error
  path (git-fixes).
- eth: bnxt: fix missing ring index trim on error path
  (git-fixes).
- octeontx2-pf: handle otx2_mbox_get_rsp errors (git-fixes).
- igc: add lock preventing multiple simultaneous PTM transactions
  (git-fixes).
- igc: cleanup PTP module if probe fails (git-fixes).
- igc: handle the IGC_PTP_ENABLED flag correctly (git-fixes).
- igc: move ktime snapshot into PTM retry loop (git-fixes).
- igc: increase wait time before retrying PTM (git-fixes).
- igc: fix PTM cycle trigger logic (git-fixes).
- netlink: specs: ovs_vport: align with C codegen capabilities
  (git-fixes).
- octeontx2-pf: qos: fix VF root node parent queue index
  (git-fixes).
- idpf: fix adapter NULL pointer dereference on reboot
  (git-fixes).
- ixgbe: fix media type detection for E610 device (git-fixes).
- e1000e: change k1 configuration on MTP and later platforms
  (git-fixes).
- igc: Fix XSK queue NAPI ID mapping (git-fixes).
- sfc: fix NULL dereferences in ef100_process_design_param()
  (git-fixes).
- gve: handle overflow when reporting TX consumed descriptors
  (git-fixes).
- net/mlx5e: SHAMPO, Make reserved size independent of page size
  (git-fixes).
- vdpa/mlx5: Fix oversized null mkey longer than 32bit
  (git-fixes).
- idpf: check error for register_netdev() on init (git-fixes).
- ice: fix using untrusted value of pkt_len in
  ice_vc_fdir_parse_raw() (CVE-2025-22117 bsc#1241633).
- ice: fix input validation for virtchnl BW (git-fixes).
- ice: validate queue quanta parameters to prevent OOB access
  (CVE-2025-22118 bsc#1241562).
- ice: stop truncating queue ids when checking (git-fixes).
- virtchnl: make proto and filter action count unsigned
  (git-fixes).
- ice: fix reservation of resources for RDMA when disabled
  (git-fixes).
- ice: ensure periodic output start time is in the future
  (git-fixes).
- net/mlx5: Start health poll after enable hca (git-fixes).
- net/mlx5: LAG, reload representors on LAG creation failure
  (git-fixes).
- bnxt_en: Linearize TX SKB if the fragments exceed the max
  (git-fixes).
- bnxt_en: Mask the bd_cnt field in the TX BD properly
  (git-fixes).
- net/mlx5e: Fix ethtool -N flow-type ip4 to RSS context
  (git-fixes).
- gve: unlink old napi only if page pool exists (git-fixes).
- igb: reject invalid external timestamp requests for 82580-based
  HW (git-fixes).
- bonding: fix incorrect MAC address setting to receive NS
  messages (git-fixes).
- net/mlx5: Fill out devlink dev info only for PFs (git-fixes).
- cxgb4: Avoid removal of uninserted tid (git-fixes).
- Revert "rtnetlink: add guard for RTNL" (git-fixes).
- commit 1c6076b
* Mon Apr 28 2025 jack@suse.cz
- ext4: avoid remount errors with 'abort' mount option
  (bsc#1241673).
- commit 7e45d00
* Mon Apr 28 2025 jack@suse.cz
- ext4: fix OOB read when checking dotdot dir (bsc#1241640
  CVE-2025-37785).
- commit 1f644d1
* Mon Apr 28 2025 jack@suse.cz
- ext4: fix out-of-bound read in ext4_xattr_inode_dec_ref_all()
  (bsc#1241593 CVE-2025-22121).
- commit 31cdb6e
* Mon Apr 28 2025 jack@suse.cz
- proc: fix UAF in proc_get_inode() (bsc#1240802 CVE-2025-21999).
- commit 17ecba0
* Mon Apr 28 2025 jack@suse.cz
- fs: relax assertions on failure to encode file handles
  (bsc#1236086 CVE-2024-57924).
- commit 7fa3943
* Mon Apr 28 2025 jack@suse.cz
- Revert "readahead: properly shorten readahead when falling
  back to do_page_cache_ra()" (bsc#1235799 CVE-2024-57839).
- commit 6921c3b
* Mon Apr 28 2025 jack@suse.cz
- isofs: avoid memory leak in iocharset (bsc#1234965
  CVE-2024-56534).
- commit 2bb1019
* Mon Apr 28 2025 jack@suse.cz
- quota: flush quota_release_work upon quota writeback
  (bsc#1235650 CVE-2024-56780).
- commit 9807ea9
* Mon Apr 28 2025 jack@suse.cz
- fsnotify: Fix ordering of iput() and watched_objects decrement
  (bsc#1234316 CVE-2024-53143).
- commit 80f01f0
* Mon Apr 28 2025 hare@suse.de
- dm-integrity: Do not emit journal configuration in DM table
  fro Inline mode (jsc#PED-9651).
- dm-crypt: don't initialize cc_sector again (jsc#PED-9651).
- dm-crypt: use bi_sector in bio when initialize integrity seed
  (jsc#PED-9651).
- dm-crypt: fully initialize clone->bi_iter in
  crypt_alloc_buffer() (jsc#PED-9651).
- dm-crypt: set atomic as false when calling crypt_convert()
  in kworker (jsc#PED-9651).
- dm-mirror: Support atomic writes (jsc#PED-9651).
- dm-io: Warn on creating multiple atomic write bios for a region
  (jsc#PED-9651).
- dm-stripe: Enable atomic writes (jsc#PED-9651).
- dm-linear: Enable atomic writes (jsc#PED-9651).
- dm: Ensure cloned bio is same length for atomic write
  (jsc#PED-9651).
- dm-table: atomic writes support (jsc#PED-9651).
- dm-transaction-manager: use red-black trees instead of linear
  lists (jsc#PED-9651).
- dm: disable REQ_NOWAIT for flushes (jsc#PED-9651).
- dm: remove useless test in alloc_multiple_bios (jsc#PED-9651).
- dm: change kzalloc to kcalloc (jsc#PED-9651).
- dm raid: fix spelling errors in raid_ctr() (jsc#PED-9651).
- dm-verity FEC: Avoid copying RS parity bytes twice
  (jsc#PED-9651).
- dm-verity: remove the unused "data_start" variable
  (jsc#PED-9651).
- dm-bufio: use kmalloc to allocate power-of-two sized buffers
  (jsc#PED-9651).
- dm: add support for get_unique_id (jsc#PED-9651).
- dm vdo: fix function doc comment formatting (jsc#PED-9651).
- dm vdo int-map: remove unused parameters (jsc#PED-9651).
- dm-vdo: reset bi_ioprio to the default value when the bio is
  reset (jsc#PED-9651).
- dm-vdo murmurhash: remove u64 alignment requirement
  (jsc#PED-9651).
- dm ioctl: rate limit a couple of ioctl based error messages
  (jsc#PED-9651).
- dm vdo: Remove unused uds_compute_index_size (jsc#PED-9651).
- dm vdo: Remove unused functions (jsc#PED-9651).
- dm: zoned: Remove unused functions (jsc#PED-9651).
- dm: Remove unused dm_table_bio_based (jsc#PED-9651).
- dm: Remove unused dm_set_md_type (jsc#PED-9651).
- dm cache: Remove unused functions in bio-prison-v1
  (jsc#PED-9651).
- dm cache: Remove unused dm_cache_size (jsc#PED-9651).
- dm cache: Remove unused dm_cache_dump (jsc#PED-9651).
- dm cache: Remove unused btracker_nr_writebacks_queued
  (jsc#PED-9651).
- commit abbc785
* Mon Apr 28 2025 jroedel@suse.de
- iommu/amd: Enable support for up to 2K interrupts per function
  (jsc#PED-12548).
- iommu/amd: Rename DTE_INTTABLEN* and MAX_IRQS_PER_TABLE macro
  (jsc#PED-12548).
- iommu/amd: Replace slab cache allocator with page allocator
  (jsc#PED-12548).
- iommu/amd: Introduce generic function to set multibit feature
  value (jsc#PED-12548).
- iommu/amd: Remove amd_iommu_apply_erratum_63() (jsc#PED-12548).
- iommu/amd: Lock DTE before updating the entry with WRITE_ONCE()
  (jsc#PED-12548).
- iommu/amd: Modify clear_dte_entry() to avoid in-place update
  (jsc#PED-12548).
- iommu/amd: Introduce helper function get_dte256()
  (jsc#PED-12548).
- iommu/amd: Modify set_dte_entry() to use 256-bit DTE helpers
  (jsc#PED-12548).
- iommu/amd: Introduce helper function to update 256-bit DTE
  (jsc#PED-12548).
- iommu/amd: Introduce struct ivhd_dte_flags to store persistent
  DTE flags (jsc#PED-12548).
- iommu/amd: Disable AMD IOMMU if CMPXCHG16B feature is not
  supported (jsc#PED-12548).
- iommu/amd: Misc ACPI IVRS debug info clean up (jsc#PED-12548).
- commit cea8105
* Mon Apr 28 2025 msuchanek@suse.de
- Update patches.suse/powerpc64-ftrace-fix-module-loading-without-patchabl.patch
  (jsc#PED-10909 git-fixes bsc#1236402).
- commit 851952d
* Mon Apr 28 2025 hare@kernel.org
- Delete patches.suse/dm-mpath-leastpending-path-update.
- commit 2fdb1ca
* Mon Apr 28 2025 hare@kernel.org
- Delete
  patches.suse/nvme_core-scan-namespaces-asynchronously.patch.
- commit b9417d4
* Mon Apr 28 2025 hare@kernel.org
- Delete
  patches.suse/nvme-multipath-suppress-partition-scan-until-the-dis.patch.
- commit e258b74
* Mon Apr 28 2025 hare@kernel.org
- Delete
  patches.suse/nvme-keyring-restrict-match-length-for-version-1-ide.patch.
- commit 9af6fe5
* Sun Apr 27 2025 mgorman@suse.de
- Delete
  patches.suse/sched-fair-Increase-wakeup_gran-if-current-task-has-not-executed-the-minimum-granularity.patch.
  Conceptually incompatible with EEVDF.
- commit e1d8356
* Sun Apr 27 2025 mgorman@suse.de
- Delete
- patches.suse/cpuidle-Poll-for-a-minimum-of-30ns-and-poll-for-a-tick-if-lower-c-states-are-disabled.patch.
- patches.suse/sched-nohz-Avoid-disabling-the-tick-for-very-short-durations.patch.
  Neither patch has been found for be beneficial recently except as a
  debugging aid.
- commit 2ffcdfb
* Sun Apr 27 2025 mgorman@suse.de
- Delete
  patches.suse/sched-fair-Revert-update_pick_idlest-Select-group-with-lowest-group_util-when-idle_cpus-are-equal.patch.
- commit c749b06
* Sun Apr 27 2025 mgorman@suse.de
- Delete
  patches.suse/sched-Temporarily-restore-deprecated-scheduler-sysctls-with-a-warning.patch.
  Deprecated sysctls can no longer be restored.
- commit 92b7eb8
* Sun Apr 27 2025 mgorman@suse.de
- Update
  patches.suse/cpufreq-ondemand-Set-default-up_threshold-to-30-on-multi-core-systems.patch
  (bsc#464461,bsc#981838,bsc#1064414,bsc#1144943,bsc#1193200,bsc#1193088,bsc#1217546,bsc#1241613).
- commit 4052251
* Sun Apr 27 2025 tiwai@suse.de
- Refresh patches.suse/iommu-Allow-attaching-static-domains-in-iommu_attach.patch (bsc#1241193)
  Refreshed to v3 patch
- commit 2d5f06a
* Sun Apr 27 2025 tiwai@suse.de
- irqchip/gic-v2m: Prevent use after free of gicv2m_get_fwnode()
  (git-fixes).
- drm/amd/display: Enable urgent latency adjustment on DCN35
  (stable-fixes).
- drm/amd/display: Fix gpu reset in multidisplay config
  (git-fixes).
- drm: panel: jd9365da: fix reset signal polarity in unprepare
  (git-fixes).
- drm/meson: use unsigned long long / Hz for frequency types
  (git-fixes).
- Revert "drm/meson: vclk: fix calculation of 59.94 fractional
  rates" (git-fixes).
- commit 6c8c3c2
* Sat Apr 26 2025 tiwai@suse.de
- usb: typec: class: Unlocked on error in typec_register_partner()
  (git-fixes).
- crypto: tegra - Fix format specifier in tegra_sha_prep_cmd()
  (git-fixes).
- commit db6edbe
* Sat Apr 26 2025 tiwai@suse.de
- crypto: tegra - Transfer HASH init function to crypto engine
  (git-fixes).
- Refresh
  patches.suse/crypto-tegra-Use-HMAC-fallback-when-keyslots-are-ful.patch.
- commit 21485d2
* Sat Apr 26 2025 tiwai@suse.de
- crypto: tegra - Do not use fixed size buffers (git-fixes).
- Refresh
  patches.suse/crypto-tegra-Fix-CMAC-intermediate-result-handling.patch.
- commit e3d6cdb
* Sat Apr 26 2025 tiwai@suse.de
- cxl/core/regs.c: Skip Memory Space Enable check for RCD and
  RCH Ports (git-fixes).
- USB: wdm: add annotation (git-fixes).
- USB: wdm: wdm_wwan_port_tx_complete mutex in atomic context
  (git-fixes).
- USB: wdm: close race between wdm_open and wdm_wwan_port_stop
  (git-fixes).
- USB: wdm: handle IO errors in wdm_wwan_port_start (git-fixes).
- usb: dwc3: gadget: check that event count does not exceed
  event buffer length (git-fixes).
- usb: dwc3: xilinx: Prevent spike in reset signal (git-fixes).
- usb: cdns3: Fix deadlock when using NCM gadget (git-fixes).
- usb: chipidea: ci_hdrc_imx: implement usb_phy_init() error
  handling (git-fixes).
- usb: chipidea: ci_hdrc_imx: fix call balance of regulator
  routines (git-fixes).
- usb: chipidea: ci_hdrc_imx: fix usbmisc handling (git-fixes).
- usb: typec: class: Invalidate USB device pointers on partner
  unregistration (git-fixes).
- usb: typec: class: Fix NULL pointer access (git-fixes).
- usb: xhci: Fix invalid pointer dereference in Etron workaround
  (git-fixes).
- serial: sifive: lock port in startup()/shutdown() callbacks
  (git-fixes).
- tty: Require CAP_SYS_ADMIN for all usages of
  TIOCL_SELMOUSEREPORT (git-fixes).
- serial: msm: Configure correct working mode before starting
  earlycon (git-fixes).
- firmware: stratix10-svc: Add of_platform_default_populate()
  (git-fixes).
- mei: vsc: Fix fortify-panic caused by invalid counted_by()
  use (git-fixes).
- misc: microchip: pci1xxxx: Fix incorrect IRQ status handling
  during ack (git-fixes).
- misc: microchip: pci1xxxx: Fix Kernel panic during IRQ handler
  registration (git-fixes).
- char: misc: register chrdev region with all possible minors
  (git-fixes).
- Revert "drivers: core: synchronize really_probe() and
  dev_uevent()" (stable-fixes).
- dma/contiguous: avoid warning about unused size_bytes
  (git-fixes).
- Bluetooth: l2cap: Process valid commands in too long frame
  (stable-fixes).
- Revert "wifi: mac80211: Update skb's control block key in
  ieee80211_tx_dequeue()" (git-fixes).
- wifi: mac80211: Update skb's control block key in
  ieee80211_tx_dequeue() (git-fixes).
- platform/x86: msi-wmi-platform: Workaround a ACPI firmware bug
  (git-fixes).
- platform/x86: msi-wmi-platform: Rename "data" variable
  (stable-fixes).
- crypto: tegra - Fix IV usage for AES ECB (git-fixes).
- drm/amd/display: Add HP Elitebook 645 to the quirk list for
  eDP on DP1 (stable-fixes).
- drm/amd/display: Add HP Probook 445 and 465 to the quirk list
  for eDP on DP1 (stable-fixes).
- drm/i915/gvt: fix unterminated-string-initialization warning
  (stable-fixes).
- drm/amd/display: prevent hang on link training fail
  (stable-fixes).
- drm/amd: Handle being compiled without SI or CIK support better
  (stable-fixes).
- clk: samsung: Fix UBSAN panic in samsung_clk_init()
  (CVE-2025-39728 bsc#1241626).
- crypto: tegra - Reserve keyslots to allocate dynamically
  (git-fixes).
- crypto: tegra - Fix HASH intermediate result handling
  (git-fixes).
- crypto: tegra - finalize crypto req on error (git-fixes).
- drm/amd/display: Temporarily disable hostvm on DCN31
  (stable-fixes).
- crypto: tegra - remove redundant error check on ret
  (stable-fixes).
- commit 01594c5
* Fri Apr 25 2025 tabraham@suse.com
- vmxnet3: unregister xdp rxq info in the reset path (bsc#1241394
  CVE-2025-22106 bsc#1241547).
- commit 98a3203
* Fri Apr 25 2025 vbabka@suse.cz
- mm: (un)track_pfn_copy() fix + doc improvements (CVE-2025-22090
  bsc#1241537).
- commit fdf32a4
* Fri Apr 25 2025 vbabka@suse.cz
- x86/mm/pat: Fix VM_PAT handling when fork() fails in
  copy_page_range() (CVE-2025-22090 bsc#1241537).
- commit 72666c0
* Fri Apr 25 2025 ailiop@suse.com
- fs/ntfs3: Prevent integer overflow in hdr_first_de()
  (bsc#1241416 CVE-2025-22080).
- commit 715db43
* Fri Apr 25 2025 ptesarik@suse.com
- Refresh
  patches.suse/add-product-identifying-information-to-vmcoreinfo.patch.
- commit 1b23642
* Fri Apr 25 2025 vbabka@suse.cz
- Refresh patches.suse/kabi-padding-for-vmstat-items.patch.
- fix up and re-enable the kabi padding for vmstat items
- commit cd9d69f
* Fri Apr 25 2025 jslaby@suse.cz
- Refresh patches.suse/crasher.patch and reenable it.
- Update config files.
- commit 7a517c9
* Fri Apr 25 2025 iivanov@suse.de
- padding: add placeholders to device controllers structures (git-fixes)
- commit bf484b5
* Fri Apr 25 2025 tiwai@suse.de
- Re-enable b43 patch for missing firmware notification
  The patch is still valid and applied to Tumbleweed as well
- commit 5a8e854
* Fri Apr 25 2025 tiwai@suse.de
- Add kABI placeholders for sound core
- Add kABI placeholders for regmap
- commit 864c7f1
* Fri Apr 25 2025 tiwai@suse.de
- net: phy: leds: fix memory leak (git-fixes).
- net: phy: microchip: force IRQ polling mode for lan88xx
  (git-fixes).
- crypto: atmel-sha204a - Set hwrng quality to lowest possible
  (git-fixes).
- commit 89bf1f8
* Fri Apr 25 2025 dsterba@suse.com
- bpf: Fix softlockup in arena_map_free on 64k page kernel (CVE-2025-21851 bsc#1239480)
- commit 125c4ff
* Fri Apr 25 2025 dsterba@suse.com
- netfs: Call `invalidate_cache` only if implemented (CVE-2025-22002 bsc#1240875)
- commit 5ef8097
* Fri Apr 25 2025 pjakobsson@suse.de
- Refresh patches.suse/drm-Add-kabi-placeholders-to-commonly-used-structs.patch.
  Use same drm kabi padding as in SLE15-SP7
- commit 27dd19d
* Thu Apr 24 2025 mhocko@suse.com
- scripts/check-kernel-fix: check for non upstream sha coming from VULN_GIT
  CVE-2025-40364 is refering to a stable specific vulnerability. We
  currently choke on that
  $ ./scripts/check-kernel-fix CVE-2025-40364
  Security fix for CVE-2025-40364 bsc#1241637 with CVSS 6.1
  fatal: bad object a94592ec30ff67dc36c424327f1e0a9ceeeb9bd3
  fatal: bad object a94592ec30ff67dc36c424327f1e0a9ceeeb9bd3
  = fatal: bad object a94592ec30ff67dc36c424327f1e0a9ceeeb9bd3
  merged Could not get object for a94592ec30ff67dc36c424327f1e0a9ceeeb9bd3. Skipping.
  No Fixes tag. Requires manual review for affected branches.
  Experts candidates:  subsystem/role=
  Link: https://git.kernel.org/linus/a94592ec30ff67dc36c424327f1e0a9ceeeb9bd3
  fatal: bad object a94592ec30ff67dc36c424327f1e0a9ceeeb9bd3
  Be more defensive and bail out on non upstream commits before prossing
  each sha for the CVE
  $ ./scripts/check-kernel-fix CVE-2025-40364
  Security fix for CVE-2025-40364 bsc#1241637 with CVSS 6.1
  a94592ec30ff67dc36c424327f1e0a9ceeeb9bd3 is not an upstream commit
- commit e3ed589
* Thu Apr 24 2025 mhocko@suse.com
- scripts/common-functions: sha_get_upstream_git_fixes be more careful about vulnerable files
  CVE.vulnerable file is not really designed for multi sha CVEs as it is
  not really easy to tell which fix they correspond to. E.g.
  $ cat CVE-2024-56705.vulnerable
  a49d25364dfb9f8a64037488a39ab1f56c5fa419
  ad85094b293e40e7a2f831b0311a389d952ebd5e
  $ cat CVE-2024-56705.sha1
  ed61c59139509f76d3592683c90dc3fdc6e23cd6
  51b8dc5163d2ff2bf04019f8bf7e3bd0e75bb654
  Our current implementation will print
  = ed61c5913950 ("media: atomisp: Add check for rgby_data memory allocation failure") merged v6.13-rc1~149^2~15
  Fixes: a49d25364dfb ("staging/atomisp: Add support for the Intel IPU v2") merged v4.12-rc1~84^2~796
  = 51b8dc5163d2 ("media: staging: atomisp: Remove driver") merged v4.18-rc1~107^2~112
  Fixes: a49d25364dfb ("staging/atomisp: Add support for the Intel IPU v2") merged v4.12-rc1~84^2~796
  Fixes: ad85094b293e ("Revert "media: staging: atomisp: Remove driver"") merged v5.8-rc1~162^2~125
  The output for ed61c5913950 is correct because the patch itself has
  Fixes tag. For 51b8dc5163d2 there is none so we fallback to .vulnerable
  file and it is quite clear that ad85094b293e cannot be breaker as it has
  been merged much later. The whole situation is quite confused and
  described in https://lore.kernel.org/all/2024122837-CVE-2024-56705-049b@gregkh/T/#m85050dadf9eef7608c25fe0108bee9dde056d557
  Reduce the confusion and only use .vulnerable entries which are
  ancestors of the sha so they are related from the development POV.
- commit 1988895
* Thu Apr 24 2025 mhocko@suse.com
- scripts/check-kernel-fix: implement multi sha CVEs handling
  CVE-2024-56705 has two upstream commits referenced in
  VULNS_GIT/cve/published/2024/CVE-2024-56705.sha1
  Reasons for that are arguably dubious (see
  https://lore.kernel.org/all/2024122837-CVE-2024-56705-049b@gregkh/T/#m85050dadf9eef7608c25fe0108bee9dde056d557)
  but we need to be able to handle CVEs associated with several upstream
  commits anyway.
  Preparatory patches have made this quite easy. The general logic is
  that we process and report each commit on its own. The final conclusion
  is printed after all of them are processed
  $ ./scripts/check-kernel-fix CVE-2024-56705
  Security fix for CVE-2024-56705 bsc#1235568 with CVSS 4.7
  = ed61c5913950 ("media: atomisp: Add check for rgby_data memory allocation failure") merged v6.13-rc1~149^2~15
  Fixes: a49d25364dfb ("staging/atomisp: Add support for the Intel IPU v2") merged v4.12-rc1~84^2~796
  Experts candidates:  tiwai@suse.com (33) subsystem/role="DRIVERS"
  Link: https://git.kernel.org/linus/ed61c59139509f76d3592683c90dc3fdc6e23cd6
  = 51b8dc5163d2 ("media: staging: atomisp: Remove driver") merged v4.18-rc1~107^2~112
  Fixes: a49d25364dfb ("staging/atomisp: Add support for the Intel IPU v2") merged v4.12-rc1~84^2~796
  Fixes: ad85094b293e ("Revert "media: staging: atomisp: Remove driver"") merged v5.8-rc1~162^2~125
  Experts candidates:  tiwai@suse.com (33) subsystem/role="DRIVERS"
  Link: https://git.kernel.org/linus/51b8dc5163d2ff2bf04019f8bf7e3bd0e75bb654
  ACTION NEEDED!
  SLE12-SP5: MANUAL: backport 51b8dc5163d2ff2bf04019f8bf7e3bd0e75bb654 (Fixes v4.12)
  WW CONFIG_INTEL_ATOMISP not enabled.
  WW CONFIG_VIDEO_ATOMISP not enabled.
  All eligible branches have warnings. If they are correct then there is NO ACTION NEEDED for 51b8dc5163d2ff2bf04019f8bf7e3bd0e75bb654
  Potential git-fixes for ed61c59139509f76d3592683c90dc3fdc6e23cd6 51b8dc5163d2ff2bf04019f8bf7e3bd0e75bb654
  ad85094b293e Revert "media: staging: atomisp: Remove driver"
- commit 998742a
* Thu Apr 24 2025 mhocko@suse.com
- scripts/check-kernel-fix: simplify no fixes case
  If there is no fixes tag then we cannot make an authoritative call for
  affected branches. We are still trying to capture situation that no
  branches might be actually affected e.g. because the code is not
  compiled in. E.g.
  36cef585e2a3 ("media: vimc: skip .s_stream() for stopped entities") merged v6.15-rc1~174^2~26
  Fixes: adc589d2a208 ("media: vimc: Add vimc-streamer for stream control") merged v5.1-rc1~88^2~133
  Security fix for CVE-2025-22028 bsc#1241362 with CVSS 5.5
  Experts candidates:  tiwai@suse.com (33) subsystem/role="MEDIA DRIVERS"
  Link: https://git.kernel.org/linus/36cef585e2a31e4ddf33a004b0584a7a572246de
  ACTION NEEDED!
  SLE15-SP6: MANUAL: backport 36cef585e2a31e4ddf33a004b0584a7a572246de (Fixes v6.4)
  WW CONFIG_VIDEO_VIMC not enabled.
  All eligible branches have warnings. If they are correct then there is NO ACTION NEEDED
  Potential git-fixes for 36cef585e2a31e4ddf33a004b0584a7a572246de
  Nothing found
  This works properly with the current code but it makes it harder to
  add a support for multi sha cves because the number of eligible branches
  tracking and gets more involved if we have a mixed bag of shas with and
  without known breakers.
  Therefore drop the heuristic and make multi sha tracking easier. That
  means to track all shas without breakers in no_fixes_shas file.
  Existence of the file triggers print_no_fixes_warning. Also collect
  per sha "all eligible branches have warning" hint into a global warning
  file.
- commit 0b7b897
* Thu Apr 24 2025 mhocko@suse.com
- scripts/common-functions: make cve2sha multi sha aware
- scripts/cve_tools/cve2metadata.sh: support multi sha CVEs
  cve2sha relied on the VULN_GIT/scripts/cve_search but that is harder to
  post process for multi sha CVEs so find and read the $CVE.sha1 file
  directly.
  make scipts/cve2metadata multi sha CVEs aware
  $ scripts/cve_tools/cve2metadata.sh CVE-2024-56705
  ed61c59139509f76d3592683c90dc3fdc6e23cd6 51b8dc5163d2ff2bf04019f8bf7e3bd0e75bb654  score:4.7 CVE-2024-56705 bsc#1235568
  $ scripts/cve_tools/cve2metadata.sh ed61c59139509f76d3592683c90dc3fdc6e23cd6
  ed61c59139509f76d3592683c90dc3fdc6e23cd6 51b8dc5163d2ff2bf04019f8bf7e3bd0e75bb654  score:4.7 CVE-2024-56705 bsc#1235568
  $ scripts/cve_tools/cve2metadata.sh 51b8dc5163d2ff2bf04019f8bf7e3bd0e75bb654
  ed61c59139509f76d3592683c90dc3fdc6e23cd6 51b8dc5163d2ff2bf04019f8bf7e3bd0e75bb654  score:4.7 CVE-2024-56705 bsc#1235568
- commit aae56b3
* Thu Apr 24 2025 mhocko@suse.com
- scripts/check-kernel-fix: make the whole state handling sha specific
  rename those functions to make the review easier. No function change is
  intended here.
- commit 752b100
* Thu Apr 24 2025 pfalcato@suse.de
- Revert "net: do not leave a dangling sk pointer, when socket
  creation fails" (git-fixes).
- commit 4fa271e
* Thu Apr 24 2025 pfalcato@suse.de
- net: warn, if pf->create does not clear sock->sk on error
  (git-fixes).
- commit 5c25b73
* Thu Apr 24 2025 mhocko@suse.com
- Delete
  patches.suse/memcg-deprecate-memory.force_empty-knob.patch.
  we do not enable CONFIG_MEMCG_V1 anymore
- commit 38e2616
* Thu Apr 24 2025 mhocko@suse.com
- re-enable patches.suse/mm-inform-about-enabling-mirrored-memory.patch
  reasons for having the patch are still true
- commit fe7580c
* Thu Apr 24 2025 mhocko@suse.com
- Delete
  patches.suse/mm-Warn-users-of-node-memory-hot-remove-if-the-memory-ratio-is-a-high-risk.patch.
  We haven't received any warning report so it seems this is not a real
  life problem. Drop the patch to minimize the divergence from upstream
- commit f02479f
* Thu Apr 24 2025 nik.borisov@suse.com
- Refresh patches.suse/kabi-reserve-cpuid-leaves.patch.
- commit e69c277
* Thu Apr 24 2025 mkubecek@suse.cz
- ethtool: cmis_cdb: use correct rpl size in
  ethtool_cmis_module_poll() (git-fixes).
- net: ethtool: Don't call .cleanup_data when prepare_data fails
  (git-fixes).
- net: ethtool: fix ethtool_ringparam_get_cfg() returns a
  hds_thresh value always as 0 (git-fixes).
- net: ethtool: tsinfo: Fix dump command (git-fixes).
- net: ethtool: netlink: Allow NULL nlattrs when getting a
  phy_device (git-fixes).
- ethtool: ntuple: fix rss + ring_cookie check (git-fixes).
- ethtool: rss: fix hiding unsupported fields in dumps
  (git-fixes).
- ethtool: Fix set RXNFC command with symmetric RSS hash
  (git-fixes).
- ethtool: Fix wrong mod state in case of verbose and no_mask
  bitset (git-fixes).
- commit 2ee5bc4
* Thu Apr 24 2025 msuchanek@suse.de
- Test the correct macro to detect RT kernel build
  Fixes: 470cd1a41502 ("kernel-binary: Support livepatch_rt with merged RT branch")
- commit 50e863e
* Thu Apr 24 2025 jgross@suse.com
- Update config files.
- commit f1cfbf4
* Wed Apr 23 2025 lduncan@suse.com
- scsi: smartpqi: Use is_kdump_kernel() to check for kdump
  (git-fixes).
- Refresh
  patches.suse/scsi-use-block-layer-helpers-to-calculate-num-of-queues.patch.
- commit fc8ffe9
* Wed Apr 23 2025 lduncan@suse.com
- scsi: iscsi: Fix missing scsi_host_put() in error path
  (git-fixes).
- scsi: hisi_sas: Enable force phy when SATA disk directly
  connected (git-fixes).
- scsi: lpfc: Restore clearing of NLP_UNREG_INP in ndlp->nlp_flag
  (git-fixes).
- scsi: hisi_sas: Fixed failure to issue vendor specific commands
  (git-fixes).
- scsi: scsi_debug: Remove a reference to in_use_bm (git-fixes).
- scsi: mpt3sas: Fix a locking bug in an error path (git-fixes).
- scsi: mpi3mr: Fix locking in an error path (git-fixes).
- scsi: mpt3sas: Reduce log level of ignore_delay_remove message
  to KERN_INFO (git-fixes).
- commit c213b0d
* Wed Apr 23 2025 msuchanek@suse.de
- kernel-source: Also update the search to match bin/env
  Fixes: dc2037cd8f94 ("kernel-source: Also replace bin/env"
- commit bae6b69
* Wed Apr 23 2025 jgross@suse.com
- xen: fix multicall debug feature (git-fixes).
- commit 22440da
* Wed Apr 23 2025 jgross@suse.com
- x86/xen: fix balloon target initialization for PVH dom0
  (git-fixes).
- commit 3ec180c
* Wed Apr 23 2025 jgross@suse.com
- xenfs/xensyms: respect hypervisor's "next" indication
  (git-fixes).
- commit 25e2e64
* Wed Apr 23 2025 jgross@suse.com
- s390/virtio_ccw: Don't allocate/assign airqs for non-existing
  queues (git-fixes).
- commit 39793ac
* Wed Apr 23 2025 jgross@suse.com
- vhost-scsi: Fix handling of multiple calls to
  vhost_scsi_set_endpoint (git-fixes).
- commit 3b90d10
* Wed Apr 23 2025 jgross@suse.com
- tools: virtio/linux/module.h add MODULE_DESCRIPTION() define
  (git-fixes).
- commit bb13108
* Wed Apr 23 2025 jgross@suse.com
- virtio_net: Allocate rss_hdr with devres (git-fixes).
- commit b12f322
* Wed Apr 23 2025 msuchanek@suse.de
- rpm/check-for-config-changes: Add GCC_ASM_FLAG_OUTPUT_BROKEN
  Both spellings are actually used
- rpm/check-for-config-changes: Add GCC_ASM_FLAG_OUTPUT_BROKEN
- commit d9e0b30
* Wed Apr 23 2025 jgross@suse.com
- virtio_net: Fix endian with virtio_net_ctrl_rss (git-fixes).
- commit ce0974f
* Wed Apr 23 2025 jgross@suse.com
- KVM: x86: block KVM_CAP_SYNC_REGS if guest state is protected
  (git-fixes).
- commit 81808c0
* Wed Apr 23 2025 jgross@suse.com
- KVM: x86: Set PVCLOCK_GUEST_STOPPED only for kvmclock, not
  for Xen PV clock (git-fixes).
- commit 0786f06
* Wed Apr 23 2025 jgross@suse.com
- KVM: x86: Don't bleed PVCLOCK_GUEST_STOPPED across PV clocks
  (git-fixes).
- commit 29423ad
* Wed Apr 23 2025 jgross@suse.com
- KVM: x86: Process "guest stopped request" once per guest time
  update (git-fixes).
- commit 036561e
* Wed Apr 23 2025 jgross@suse.com
- KVM: x86: Drop local pvclock_flags variable in
  kvm_guest_time_update() (git-fixes).
- commit 992c7b0
* Wed Apr 23 2025 jgross@suse.com
- KVM: x86/xen: Use guest's copy of pvclock when starting timer
  (git-fixes).
- commit 3737391
* Wed Apr 23 2025 jgross@suse.com
- KVM: x86: Don't take kvm->lock when iterating over vCPUs in
  suspend notifier (git-fixes).
- commit 6a2158b
* Wed Apr 23 2025 jgross@suse.com
- KVM: SVM: Don't change target vCPU state on AP Creation VMGEXIT
  error (git-fixes).
- commit fb05255
* Wed Apr 23 2025 jgross@suse.com
- KVM: SVM: Refuse to attempt VRMUN if an SEV-ES+ guest has an
  invalid VMSA (git-fixes).
- commit f1a16f5
* Wed Apr 23 2025 jgross@suse.com
- KVM: SVM: Inject #GP if memory operand for INVPCID is
  non-canonical (git-fixes).
- commit c2abbd2
* Wed Apr 23 2025 jgross@suse.com
- KVM: VMX: Don't modify guest XFD_ERR if CR0.TS=1 (git-fixes).
- commit 3071379
* Wed Apr 23 2025 jgross@suse.com
- KVM: x86: Remove the unreachable case for 0x80000022 leaf in
  __do_cpuid_func() (git-fixes).
- commit faa824f
* Wed Apr 23 2025 jgross@suse.com
- KVM: x86: Don't inject PV async #PF if SEND_ALWAYS=0 and guest
  state is protected (git-fixes).
- commit 8f330f9
* Wed Apr 23 2025 jgross@suse.com
- KVM: nVMX: Allow emulating RDPID on behalf of L2 (git-fixes).
- commit ec3ab2c
* Wed Apr 23 2025 jgross@suse.com
- KVM: nSVM: Pass next RIP, not current RIP, for nested VM-Exit
  on emulation (git-fixes).
- commit 42350b0
* Wed Apr 23 2025 jgross@suse.com
- KVM: nVMX: Check PAUSE_EXITING, not BUS_LOCK_DETECTION, on
  PAUSE emulation (git-fixes).
- commit cda8eef
* Wed Apr 23 2025 jgross@suse.com
- KVM: x86: Clear pv_unhalted on all transitions to
  KVM_MP_STATE_RUNNABLE (git-fixes).
- commit 7a65819
* Wed Apr 23 2025 jgross@suse.com
- KVM: x86: Introduce kvm_set_mp_state() (git-fixes).
- commit 04a2570
* Wed Apr 23 2025 mhocko@suse.com
- scripts/check-kernel-fix: prepare for per sha runs
  isolate sha and per CVE actions. Everything sha specific should live
  in handle_single_sha now.
- commit 17c1590
* Wed Apr 23 2025 jgross@suse.com
- KVM: x86: Wake vCPU for PIC interrupt injection iff a valid
  IRQ was found (git-fixes).
- commit c642d0c
* Wed Apr 23 2025 pfalcato@suse.de
- bpf: support SKF_NET_OFF and SKF_LL_OFF on skb frags
  (git-fixes).
- commit e6dede3
* Wed Apr 23 2025 pfalcato@suse.de
- atm: Fix NULL pointer dereference (git-fixes).
- commit 8fb9132
* Wed Apr 23 2025 pfalcato@suse.de
- net: Remove RTNL dance for SIOCBRADDIF and SIOCBRDELIF
  (git-fixes).
- commit 7729588
* Wed Apr 23 2025 mkubecek@suse.cz
- Update
  patches.suse/net-fix-geneve_opt-length-integer-overflow.patch
  references (add CVE-2025-22055 bsc#1241371).
- commit ba1e8a4
* Wed Apr 23 2025 jgross@suse.com
- KVM: arm64: Use acquire/release to communicate FF-A version
  negotiation (git-fixes).
- commit 50cc346
* Wed Apr 23 2025 pfalcato@suse.de
- xsk: fix an integer overflow in xp_create_and_assign_umem()
  (git-fixes).
- commit 7c4fb15
* Wed Apr 23 2025 pfalcato@suse.de
- net: ipv6: fix TCP GSO segmentation with NAT (git-fixes).
- commit 1c017db
* Wed Apr 23 2025 pfalcato@suse.de
- net-timestamp: support TCP GSO case for a few missing flags
  (git-fixes).
- commit c208f95
* Wed Apr 23 2025 jgross@suse.com
- KVM: Allow building irqbypass.ko as as module when kvm.ko is
  a module (git-fixes).
- commit 9b20684
* Wed Apr 23 2025 pfalcato@suse.de
- net: Clear old fragment checksum value in napi_reuse_skb
  (git-fixes).
- commit 2ce58e9
* Wed Apr 23 2025 pfalcato@suse.de
- net: set the minimum for net_hotdata.netdev_budget_usecs
  (git-fixes).
- commit 5ddd8ac
* Wed Apr 23 2025 pfalcato@suse.de
- bpf: Disable non stream socket for strparser (git-fixes).
- commit 7c4cfd5
* Wed Apr 23 2025 pfalcato@suse.de
- bpf: Remove unnecessary BTF lookups in
  bpf_sk_storage_tracing_allowed (git-fixes).
- commit 25b1d5d
* Wed Apr 23 2025 jgross@suse.com
- KVM: arm64: PMU: Fix SET_ONE_REG for vPMC regs (git-fixes).
- commit 2ecc7b5
* Wed Apr 23 2025 pfalcato@suse.de
- net: fib_rules: annotate data-races around rule->ifindex
  (git-fixes).
- commit cdcb902
* Wed Apr 23 2025 pfalcato@suse.de
- udp: gso: do not drop small packets when PMTU reduces
  (git-fixes).
- commit ab8803f
* Wed Apr 23 2025 jgross@suse.com
- KVM: arm64: PMU: Set raw values from user to
  PM{C,I}NTEN{SET,CLR}, PMOVS{SET,CLR} (git-fixes).
- commit a2da974
* Wed Apr 23 2025 jgross@suse.com
- KVM: arm64: Copy guest CTR_EL0 into hyp VM (git-fixes).
- commit d73af3d
* Wed Apr 23 2025 pfalcato@suse.de
- bpf: Fix bpf_sk_select_reuseport() memory leak (git-fixes).
- commit 7a6f651
* Wed Apr 23 2025 pfalcato@suse.de
- bpf: Check negative offsets in __bpf_skb_min_len() (git-fixes).
- commit e2c022f
* Wed Apr 23 2025 pfalcato@suse.de
- tcp_bpf: Add sk_rmem_alloc related logic for tcp_bpf ingress
  redirection (git-fixes).
- commit 4150633
* Wed Apr 23 2025 pfalcato@suse.de
- tcp_bpf: Charge receive socket buffer in bpf_tcp_ingress()
  (git-fixes).
- commit b09f3a4
* Wed Apr 23 2025 pfalcato@suse.de
- bpf, sockmap: Fix update element with same (git-fixes).
- commit 00fcef8
* Wed Apr 23 2025 pfalcato@suse.de
- xsk: always clear DMA mapping information when unmapping the
  pool (git-fixes).
- commit 839ef64
* Wed Apr 23 2025 jgross@suse.com
- KVM: arm64: Set HCR_EL2.TID1 unconditionally (git-fixes).
- commit 2a6d624
* Wed Apr 23 2025 pfalcato@suse.de
- 9p/xen: fix init sequence (git-fixes).
- commit 557d098
* Wed Apr 23 2025 pfalcato@suse.de
- net/9p/usbg: fix handling of the failed kzalloc() memory
  allocation (git-fixes).
- commit 27d9f0d
* Wed Apr 23 2025 pfalcato@suse.de
- rxrpc: Improve setsockopt() handling of malformed user input
  (git-fixes).
- commit d2d2373
* Wed Apr 23 2025 pfalcato@suse.de
- llc: Improve setsockopt() handling of malformed user input
  (git-fixes).
- commit cd07bbc
* Wed Apr 23 2025 jgross@suse.com
- KVM: arm64: vgic-v4: Fall back to software irqbypass if LPI
  not found (git-fixes).
- commit fa659dd
* Wed Apr 23 2025 pfalcato@suse.de
- bpf, sockmap: Fix sk_msg_reset_curr (git-fixes).
- commit c954950
* Wed Apr 23 2025 jgross@suse.com
- KVM: arm64: vgic-v4: Only attempt vLPI mapping for actual MSIs
  (git-fixes).
- commit 1fc4218
* Wed Apr 23 2025 pfalcato@suse.de
- bpf, sockmap: Several fixes to bpf_msg_push_data (git-fixes).
- commit 6a7ee1c
* Wed Apr 23 2025 mhocko@suse.com
- scripts/check-kernel-fix: move all the single sha processing into handle_single_sha
  No functional change intended.
- commit d024b31
* Wed Apr 23 2025 osalvador@suse.de
- mm: memory-failure: update ttu flag inside unmap_poisoned_folio
  (CVE-2025-21907 bsc#1240588).
  Refreshed:
  patches.suse/0001-hwpoison-memory_hotplug-lock-folio-before-unmap-hwpo.patch
- commit d0121cb
* Wed Apr 23 2025 osalvador@suse.de
- mm/migrate: fix shmem xarray update during migration
  (CVE-2025-22015 bsc#1240944).
- commit fe6b387
* Wed Apr 23 2025 mhocko@suse.com
- scripts/check-kernel-fix: prepare for multi sha CVEs
  c-k-f supports reverse mapping to a CVE when given a sha
  ./scripts/check-kernel-fix 5701875f9609
  Security fix for CVE-2025-22121 bsc#1241593 with CVSS 5.5
  5701875f9609 ("ext4: fix out-of-bound read in ext4_xattr_inode_dec_ref_all()") merged v6.15-rc1~145^2~16
  Fixes: e50e5129f384 ("ext4: xattr-in-inode support") merged v4.13-rc1~85^2~45
  [...]
  unify both CVE and sha paths to store CVE shas to cve_shas so that
  we are not mixing up sha used all over the place. In the next step
  we will iterate over multiple shas if they are associated with a CVE.
- commit 0aa8f42
* Wed Apr 23 2025 mhocko@suse.com
- scripts/check-kernel-fix: print CVE info before sha
  this is a preparatory work to allow a single CVE to refer to multiple
  commits.
- commit d1012d6
* Wed Apr 23 2025 osalvador@suse.de
- hwpoison, memory_hotplug: lock folio before unmap hwpoisoned
  folio (CVE-2025-21931 bsc#1240709).
- commit bac57bd
* Wed Apr 23 2025 jslaby@suse.cz
- PCI/MSI: Add an option to write MSIX ENTRY_DATA before any reads
  (git-fixes).
- irqchip/davinci: Remove leftover header (git-fixes).
- tty: serial: lpuart: only disable CTS instead of overwriting
  the whole UARTMODIR register (git-fixes).
- commit 766c734
* Wed Apr 23 2025 jslaby@suse.cz
- Update config files (set re-set CONFIG_DRM_MSM_VALIDATE_XML=n).
  This disappeared during merges:
  acf9414cc3c603ab6c14e333e7815bffda62c250
  f94b1c184933d28d9f3a47941de5779c4a52f56b
- commit 7d8dbec
* Wed Apr 23 2025 jslaby@suse.cz
- Revert "tty/serial: Add kgdb_nmi driver" (git-fixes).
- Update config files.
- serial: kgdb_nmi: Remove unused knock code (git-fixes).
- commit b9aff0c
* Wed Apr 23 2025 tiwai@suse.de
- iommu: Allow attaching static domains in
  iommu_attach_device_pasid() (bsc#1241193).
- Delete
  patches.suse/iommu-vt-d-Assign-owner-to-the-static-identity-domai.patch.
- commit f738282
* Wed Apr 23 2025 shung-hsi.yu@suse.com
- selftests/bpf: extend changes_pkt_data with cases w/o
  subprograms (bsc#1241590).
- bpf: fix null dereference when computing changes_pkt_data of
  prog w/o subprogs (bsc#1241590).
- selftests/bpf: freplace tests for tracking of
  changes_packet_data (bsc#1241590).
- commit 45d15f6
* Wed Apr 23 2025 shung-hsi.yu@suse.com
- bpf: check changes_pkt_data property for extension programs
  (bsc#1241590).
- selftests/bpf: test for changing packet data from global
  functions (bsc#1241590).
- Refresh patches.suse/selftests-bpf-validate-that-tail-call-invalidates-pa.patch
- bpf: track changes_pkt_data property for global functions
  (bsc#1241590).
- bpf: add find_containing_subprog() utility function
  (bsc#1241590).
- commit 11de59b
* Tue Apr 22 2025 mgorman@suse.de
- lib/iov_iter: fix to increase non slab folio refcount
  (bsc#1241169 (MM functional and performance backports)).
- commit 27fbba6
* Tue Apr 22 2025 mgorman@suse.de
- mm: decline to manipulate the refcount on a slab page
  (bsc#1241169 (MM functional and performance backports)).
- commit 953ff5e
* Tue Apr 22 2025 mgorman@suse.de
- mm: page_frag: fix a compile error when kernel is not compiled
  (bsc#1241169 (MM functional and performance backports)).
- commit 1cfdca8
* Tue Apr 22 2025 tiwai@suse.de
- drm/amd/display/dml2: use vzalloc rather than kzalloc
  (bsc#1241568).
- commit c6c7df4
* Tue Apr 22 2025 ailiop@suse.com
- nfsd: decrease sc_count directly if fail to queue dl_recall
  (git-fixes).
- commit dfbd8a7
* Tue Apr 22 2025 ailiop@suse.com
- nfs: add missing selections of CONFIG_CRC32 (git-fixes).
- commit 2f2f40e
* Tue Apr 22 2025 tiwai@suse.de
- iommu/vt-d: Assign owner to the static identity domain
  (bsc#1241193).
- commit 4c9babf
* Tue Apr 22 2025 dwagner@suse.de
- nvmet-fcloop: swap list_add_tail arguments (git-fixes).
- nvme-pci: skip nvme_write_sq_db on empty rqlist (git-fixes).
- nvme/ioctl: don't warn on vectorized uring_cmd with fixed buffer
  (git-fixes).
- objtool, nvmet: Fix out-of-bounds stack access in
  nvmet_ctrl_state_show() (git-fixes).
- commit 551ee35
* Tue Apr 22 2025 mgorman@suse.de
- mm/page_isolation: don't pass gfp flags to
  start_isolate_page_range() (bsc#1241169 (MM functional and
  performance backports)).
- commit 2482206
* Tue Apr 22 2025 mgorman@suse.de
- mm/page_isolation: don't pass gfp flags to
  isolate_single_pageblock() (bsc#1241169 (MM functional and
  performance backports)).
- commit 3532ecf
* Tue Apr 22 2025 mgorman@suse.de
- mm: page_alloc: tighten up find_suitable_fallback() (bsc#1241169
  (MM functional and performance backports)).
- mm: vmscan: fix kswapd exit condition in defrag_mode
  (bsc#1241169 (MM functional and performance backports)).
- mm: vmscan: restore high-cpu watermark safety in kswapd
  (bsc#1241169 (MM functional and performance backports)).
- mm: page_alloc: speed up fallbacks in rmqueue_bulk()
  (bsc#1241169 (MM functional and performance backports)).
- mm/page_alloc: replace flag check with PageHWPoison() in check_new_page_bad().
- mm: page_alloc: fix defrag_mode's retry & OOM path.
- mm/page_alloc: remove unnecessary __maybe_unused in.
- mm: page_alloc: defrag_mode kswapd/kcompactd watermarks.
- mm: page_alloc: defrag_mode kswapd/kcompactd assistance.
- mm: page_alloc: defrag_mode.
- mm: page_alloc: trace type pollution from compaction.
- mm: compaction: push watermark into compaction_suitable().
- mm: lock PGDAT_RECLAIM_LOCKED with acquire memory ordering.
- mm: add missing release barrier on PGDAT_RECLAIM_LOCKED.
- mm/page_alloc: clarify should_claim_block() commentary.
- mm/page_alloc: clarify terminology in migratetype fallback.
- mm/page_alloc: warn on nr_reserved_highatomic underflow.
- mm: page_alloc: group fallback functions together.
- mm: page_alloc: remove remnants of unlocked migratetype.
- mm: page_alloc: don't steal single pages from biggest buddy.
- vmscan, cleanup: add for_each_managed_zone_pgdat macro.
- mm/page_alloc: fix memory accept before watermarks gets.
- mm/page_alloc: fix uninitialized variable.
- mm: compaction: use the proper flag to determine watermarks.
- mm/vmscan: fix hard LOCKUP in function isolate_lru_folios.
- mm/page_alloc: remove the incorrect and misleading comment.
- mm: alloc_pages_bulk_noprof: drop page_list argument.
- mm: replace free hugepage folios after migration.
- mm/memory_hotplug: don't use __GFP_HARDWALL when migrating.
- mm/page_alloc: don't use __GFP_HARDWALL when migrating pages.
- powernv/memtrace: use __GFP_ZERO with alloc_contig_pages().
- mm/page_alloc: forward the gfp flags from.
- mm/page_alloc: sort out the alloc_contig_range() gfp flags.
- mm/page_alloc: make __alloc_contig_migrate_range() static.
- commit 6d27651
* Tue Apr 22 2025 mgorman@suse.de
- mm/memory_hotplug: move debug_pagealloc_map_pages() into.
- mm/page_alloc: add some detailed comments in.
- slab: allocate frozen pages.
- mm/mempolicy: add alloc_frozen_pages().
- mm/page_alloc: add __alloc_frozen_pages().
- mm/page_alloc: move set_page_refcounted() to end of
  __alloc_pages() (bsc#1241169 (MM functional and performance
  backports)).
- mm/page_alloc: move set_page_refcounted() to callers of
  __alloc_pages_slowpath() (bsc#1241169 (MM functional and
  performance backports)).
- mm/page_alloc: move set_page_refcounted() to callers of
  __alloc_pages_direct_reclaim() (bsc#1241169 (MM functional
  and performance backports)).
- mm/page_alloc: move set_page_refcounted() to callers of
  __alloc_pages_direct_compact() (bsc#1241169 (MM functional
  and performance backports)).
- mm/page_alloc: move set_page_refcounted() to callers of
  __alloc_pages_may_oom() (bsc#1241169 (MM functional and
  performance backports)).
- mm/page_alloc: move set_page_refcounted() to callers of
  __alloc_pages_cpuset_fallback() (bsc#1241169 (MM functional
  and performance backports)).
- mm/page_alloc: move set_page_refcounted() to callers of
  get_page_from_freelist() (bsc#1241169 (MM functional and
  performance backports)).
- mm/page_alloc: move set_page_refcounted() to callers of
  prep_new_page() (bsc#1241169 (MM functional and performance
  backports)).
- mm/page_alloc: move set_page_refcounted() to callers of
  post_alloc_hook() (bsc#1241169 (MM functional and performance
  backports)).
- mm/page_alloc: export free_frozen_pages() instead of
  free_unref_page() (bsc#1241169 (MM functional and performance
  backports)).
- mm: make alloc_pages_mpol() static.
- mm/page_alloc: cache page_zone() result in free_unref_page().
- mm: Create/affine kswapd to its preferred node.
- mm: Create/affine kcompactd to its preferred node.
- mm: page_alloc: fix missed updates of lowmem_reserve in.
- mm/mempolicy: count MPOL_WEIGHTED_INTERLEAVE to.
- mm/vmscan: wake up flushers conditionally to avoid cgroup OOM.
- mm/page_alloc: use str_off_on() helper in.
- mm/mempolicy: fix comments for better documentation.
- mm: fix shrink nr.unqueued_dirty counter issue.
- mm: move the page fragment allocator from page_alloc into its.
- mm: page_frag: add a test module for page_frag.
- commit bae8357
* Tue Apr 22 2025 vbabka@suse.cz
- selftests: mincore: fix tmpfs mincore test failure
  (jsc#PED-12649).
- commit fc35e0e
* Tue Apr 22 2025 vbabka@suse.cz
- docs: tmpfs: drop 'fadvise()' from the documentation
  (jsc#PED-12649).
- commit 65a3636
* Tue Apr 22 2025 vbabka@suse.cz
- docs: tmpfs: update the large folios policy for tmpfs and shmem
  (jsc#PED-12649).
- commit 30d861d
* Tue Apr 22 2025 vbabka@suse.cz
- mm: shmem: add a kernel command line to change the default
  huge policy for tmpfs (jsc#PED-12649).
- commit 39f6ebb
* Tue Apr 22 2025 vbabka@suse.cz
- mm: shmem: add large folio support for tmpfs (jsc#PED-12649).
- commit 1cd7838
* Tue Apr 22 2025 vbabka@suse.cz
- mm: shmem: change shmem_huge_global_enabled() to return huge
  order bitmap (jsc#PED-12649).
- commit 1f8c8c5
* Tue Apr 22 2025 vbabka@suse.cz
- mm: shmem: fix incorrect index alignment for within_size policy
  (jsc#PED-12649).
- commit 21b0427
* Tue Apr 22 2025 vbabka@suse.cz
- mm: shmem: remove __shmem_huge_global_enabled() (jsc#PED-12649).
- Refresh
  patches.suse/mm-shmem-control-THP-support-through-the-kernel-command-li.patch.
- commit 983ef62
* Tue Apr 22 2025 vbabka@suse.cz
- mm: huge_memory: move file_thp_enabled() into huge_memory.c
  (jsc#PED-12649).
- commit 7974c27
* Tue Apr 22 2025 vbabka@suse.cz
- tmpfs: don't enable large folios if not supported
  (jsc#PED-12649).
- commit 81e34da
* Tue Apr 22 2025 vbabka@suse.cz
- mm: factor out the order calculation into a new helper
  (jsc#PED-12649).
- commit e3e8297
* Tue Apr 22 2025 vbabka@suse.cz
- mm: shmem: fix khugepaged activation policy for shmem
  (jsc#PED-12649).
- commit c54323a
* Tue Apr 22 2025 vbabka@suse.cz
- mm: allocate THP on hugezeropage wp-fault (jsc#PED-12649).
- commit 8313bfa
* Tue Apr 22 2025 vbabka@suse.cz
- mm: abstract THP allocation (jsc#PED-12649).
- commit 928388d
* Tue Apr 22 2025 vbabka@suse.cz
- mm: huge_memory: use strscpy() instead of strcpy()
  (jsc#PED-12649).
- commit dcfbb69
* Tue Apr 22 2025 vbabka@suse.cz
- mm: shmem: override mTHP shmem default with a kernel parameter
  (jsc#PED-12649).
- commit 5989f8b
* Tue Apr 22 2025 vbabka@suse.cz
- mm: move ``get_order_from_str()`` to internal.h (jsc#PED-12649).
- commit 1451f9c
* Tue Apr 22 2025 msuchanek@suse.de
- powerpc64/ftrace: fix module loading without patchable function
  entries (jsc#PED-10909 git-fixes).
- commit 38a673f
* Tue Apr 22 2025 vbabka@suse.cz
- mm: shmem: control THP support through the kernel command line
  (jsc#PED-12649).
- commit f26d9e9
* Tue Apr 22 2025 tiwai@suse.de
- video: screen_info: Update framebuffers behind PCI bridges
  (bsc#1240696).
- commit 073be6a
* Tue Apr 22 2025 shung-hsi.yu@suse.com
- Refresh
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch.
  scripts/gen-suse_version_h.sh requires bash, yet in Makefile
  CONFIG_SHELL is defined to 'sh'. In openSUSE and SUSE products 'sh' is a
  symbolic link to 'bash', hence this isn't a problem. However
  distributions like Debian and Ubuntu 'sh' is symbolically linked to
  'dash' instead, and gen-suse_version_h.sh will fail to run with
  ./scripts/gen-suse_version_h.sh: 3: Syntax error: "(" unexpected
  make[1]: *** [/home/runner/work/libbpf/libbpf/.kernel/Makefile:1135: include/generated/uapi/linux/suse_version.h] Error 2
  make: *** [Makefile:224: __sub-make] Error 2
  Explicitly use bash to run scripts/gen-suse_version_h.sh to make sure
  it will always work.
- commit ed7450d
* Tue Apr 22 2025 shung-hsi.yu@suse.com
- Refresh
  patches.suse/lockdown-fix-kernel-lockdown-enforcement-issue-when-secure.patch.
  Fix build failure due to undefined reference to
  'lockdown_hooks_secure_boot'. This only happens when
  CONFIG_SECURITY_LOCKDOWN_LSM is disabled, which is never the case for a
  SUSE-supported SL-16.0 kernel, and only needed for custom bare-minimal
  kernel used to run BPF selftests.
- commit c8ec8b3
* Mon Apr 21 2025 nstange@suse.de
- kABI: restore tpm_pcr_extend()'s current upstream signature
  (jsc#PED-12225).
- commit 01d2be9
* Mon Apr 21 2025 nstange@suse.de
- ima: invalidate unsupported PCR banks only once (jsc#PED-12225).
- commit 0dd99c8
* Mon Apr 21 2025 nstange@suse.de
- ima: track the set of PCRs ever extended (jsc#PED-12225).
- commit 6e9d017
* Mon Apr 21 2025 nstange@suse.de
- tpm: enable bank selection for PCR extend (jsc#PED-12225).
- commit 6bfe5f8
* Mon Apr 21 2025 nstange@suse.de
- ima: move INVALID_PCR() to ima.h (jsc#PED-12225).
- commit 971e961
* Mon Apr 21 2025 nstange@suse.de
- ima: select CRYPTO_SHA256 from Kconfig (jsc#PED-12225).
- commit 3f70f02
* Mon Apr 21 2025 nstange@suse.de
- ima: make SHA1 non-mandatory (jsc#PED-12225).
- commit fc1fa39
* Mon Apr 21 2025 nstange@suse.de
- ima: invalidate unsupported PCR banks (jsc#PED-12225).
- commit 1e32a1d
* Mon Apr 21 2025 nstange@suse.de
- ima: always create runtime_measurements sysfs file for ima_hash
  (jsc#PED-12225).
- commit 280f136
* Mon Apr 21 2025 nstange@suse.de
- ima: don't expose runtime_measurements for unsupported hashes
  (jsc#PED-12225).
- commit 9d38add
* Mon Apr 21 2025 pfalcato@suse.de
- netfilter: nf_tables: must hold rcu read lock while iterating
  object type list (git-fixes).
- commit b390560
* Mon Apr 21 2025 pfalcato@suse.de
- ipv6: Align behavior across nexthops during path selection
  (git-fixes).
- commit 57b36ca
* Mon Apr 21 2025 pfalcato@suse.de
- net: tls: explicitly disallow disconnect (git-fixes).
- commit 2ba499d
* Mon Apr 21 2025 pfalcato@suse.de
- ipv6: Do not consider link down nexthops in path selection
  (git-fixes).
- commit 59d4d47
* Mon Apr 21 2025 pfalcato@suse.de
- ipv6: Start path selection from the first nexthop (git-fixes).
- commit 9eafb13
* Mon Apr 21 2025 pfalcato@suse.de
- net: fix geneve_opt length integer overflow (git-fixes).
- commit e87d20f
* Mon Apr 21 2025 pfalcato@suse.de
- ipv6: fix omitted netlink attributes when using
  RTEXT_FILTER_SKIP_STATS (git-fixes).
- commit d20db35
* Mon Apr 21 2025 pfalcato@suse.de
- net: decrease cached dst counters in dst_release (git-fixes).
- commit db1c23e
* Mon Apr 21 2025 pfalcato@suse.de
- udp: Fix memory accounting leak (git-fixes).
- commit a3ec081
* Mon Apr 21 2025 pfalcato@suse.de
- udp: Fix multiple wraparounds of sk->sk_rmem_alloc (git-fixes).
- commit b0fc2d4
* Mon Apr 21 2025 pfalcato@suse.de
- sctp: add mutual exclusion in proc_sctp_do_udp_port()
  (git-fixes).
- commit f8d22f9
* Mon Apr 21 2025 pfalcato@suse.de
- ipv6: Set errno after ip_fib_metrics_init() in
  ip6_route_info_create() (git-fixes).
- commit 32ff0b7
* Mon Apr 21 2025 pfalcato@suse.de
- netpoll: hold rcu read lock in __netpoll_send_skb() (git-fixes).
- commit 5fa9ec5
* Mon Apr 21 2025 pfalcato@suse.de
- net: Add non-RCU dev_getbyhwaddr() helper (git-fixes).
- commit 77512cd
* Mon Apr 21 2025 pfalcato@suse.de
- arp: switch to dev_getbyhwaddr() in arp_req_set_public()
  (git-fixes).
- commit 0696317
* Mon Apr 21 2025 pfalcato@suse.de
- ipv6: mcast: add RCU protection to mld_newpack() (git-fixes).
- commit a965980
* Mon Apr 21 2025 pfalcato@suse.de
- bpf: tcp: Mark bpf_load_hdr_opt() arg2 as read-write
  (git-fixes).
- commit e052c7d
* Mon Apr 21 2025 pfalcato@suse.de
- tcp_cubic: fix incorrect HyStart round start detection
  (git-fixes).
- commit 54c97fa
* Mon Apr 21 2025 pfalcato@suse.de
- dev: Acquire netdev_rename_lock before restoring dev->name in
  dev_change_name() (git-fixes).
- commit 1407d36
* Mon Apr 21 2025 pfalcato@suse.de
- inet: ipmr: fix data-races (git-fixes).
- commit 6ab03cc
* Mon Apr 21 2025 pfalcato@suse.de
- xsk: Bring back busy polling support (git-fixes).
- commit 2f4d213
* Mon Apr 21 2025 pfalcato@suse.de
- tls: Fix tls_sw_sendmsg error handling (git-fixes).
- commit 99fffb7
* Mon Apr 21 2025 pfalcato@suse.de
- netfilter: ipset: Fix for recursive locking warning (git-fixes).
- commit 2894b98
* Mon Apr 21 2025 pfalcato@suse.de
- netfilter: nft_socket: remove WARN_ON_ONCE on maximum cgroup
  level (git-fixes).
- commit e88b4d8
* Mon Apr 21 2025 pfalcato@suse.de
- Revert "udp: avoid calling sock_def_readable() if possible"
  (git-fixes).
- commit 94ab068
* Mon Apr 21 2025 pfalcato@suse.de
- ipmr: fix tables suspicious RCU usage (git-fixes).
- commit 135ece8
* Mon Apr 21 2025 pfalcato@suse.de
- ip6mr: fix tables suspicious RCU usage (git-fixes).
- commit 0af4c97
* Mon Apr 21 2025 pfalcato@suse.de
- net/ipv6: delete temporary address if mngtmpaddr is removed
  or unmanaged (git-fixes).
- commit d9ac2cf
* Mon Apr 21 2025 pfalcato@suse.de
- netfilter: ipset: add missing range check in bitmap_ip_uadt
  (git-fixes).
- commit f75ac14
* Mon Apr 21 2025 pfalcato@suse.de
- netdev-genl: Hold rcu_read_lock in napi_get (git-fixes).
- commit ff70928
* Mon Apr 21 2025 pfalcato@suse.de
- netfilter: nf_tables: must hold rcu read lock while iterating
  expression type list (git-fixes).
- commit 652d26e
* Mon Apr 21 2025 pfalcato@suse.de
- netfilter: nf_tables: avoid false-positive lockdep splat on
  rule deletion (git-fixes).
- commit 0bd3b16
* Mon Apr 21 2025 jgross@suse.com
- x86/mm: Convert unreachable() to BUG() (git-fixes).
- commit 069c530
* Mon Apr 21 2025 tiwai@suse.de
- PCI: Check BAR index for validity (stable-fixes).
- commit 55d043c
* Mon Apr 21 2025 tiwai@suse.de
- net: phy: allow MDIO bus PM ops to start/stop state machine
  for phylink-controlled PHY (git-fixes).
- net: phy: move phy_link_change() prior to
  mdio_bus_phy_may_suspend() (stable-fixes).
- PCI: vmd: Make vmd_dev::cfg_lock a raw_spinlock_t type
  (stable-fixes).
- PCI: Add Rockchip Vendor ID (stable-fixes).
- misc: pci_endpoint_test: Fix displaying 'irq_type' after
  'request_irq' error (git-fixes).
- PCI: Enable Configuration RRS SV early (stable-fixes).
- tpm: End any active auth session before shutdown (stable-fixes).
- wifi: mt76: mt76x2u: add TP-Link TL-WDN6200 ID to device table
  (stable-fixes).
- wifi: ath12k: Fix invalid data access in
  ath12k_dp_rx_h_undecap_nwifi (stable-fixes).
- wifi: ath12k: Fix invalid entry fetch in
  ath12k_dp_mon_srng_process (stable-fixes).
- wifi: ath11k: Fix DMA buffer allocation to resolve SWIOTLB
  issues (stable-fixes).
- wifi: mac80211: ensure sdata->work is canceled before
  initialized (stable-fixes).
- wifi: mac80211: add strict mode disabling workarounds
  (stable-fixes).
- net: usb: asix_devices: add FiberGecko DeviceID (stable-fixes).
- platform/x86: x86-android-tablets: Add select POWER_SUPPLY to
  Kconfig (stable-fixes).
- platform/chrome: cros_ec_lpc: Match on Framework ACPI device
  (stable-fixes).
- mmc: dw_mmc: add a quirk for accessing 64-bit FIFOs in two
  halves (stable-fixes).
- PM: hibernate: Avoid deadlock in
  hibernate_compressor_param_set() (stable-fixes).
- zstd: Increase DYNAMIC_BMI2 GCC version cutoff from 4.8 to
  11.0 to work around compiler segfault (stable-fixes).
- commit add9125
* Mon Apr 21 2025 tiwai@suse.de
- kbuild: exclude .rodata.(cst|str)* when building ranges
  (git-fixes).
- HSI: ssi_protocol: Fix use after free vulnerability in
  ssi_protocol Driver Due to Race Condition (stable-fixes).
- ima: limit the number of ToMToU integrity violations
  (stable-fixes).
- ima: limit the number of open-writers integrity violations
  (stable-fixes).
- ktest: Fix Test Failures Due to Missing LOG_FILE Directories
  (stable-fixes).
- HID: pidff: Fix set_device_control() (stable-fixes).
- HID: pidff: Fix 90 degrees direction name North -> East
  (stable-fixes).
- HID: pidff: Compute INFINITE value instead of using hardcoded
  0xffff (stable-fixes).
- HID: pidff: Clamp effect playback LOOP_COUNT value
  (stable-fixes).
- HID: pidff: Rename two functions to align them with naming
  convention (stable-fixes).
- HID: pidff: Remove redundant call to pidff_find_special_keys
  (stable-fixes).
- HID: pidff: Support device error response from PID_BLOCK_LOAD
  (stable-fixes).
- HID: pidff: Comment and code style update (stable-fixes).
- HID: hid-universal-pidff: Add Asetek wheelbases support
  (stable-fixes).
- HID: pidff: Make sure to fetch pool before checking
  SIMULTANEOUS_MAX (stable-fixes).
- HID: pidff: Factor out pool report fetch and remove excess
  declaration (stable-fixes).
- HID: pidff: Use macros instead of hardcoded min/max values
  for shorts (stable-fixes).
- HID: pidff: Simplify pidff_rescale_signed (stable-fixes).
- HID: pidff: Move all hid-pidff definitions to a dedicated header
  (stable-fixes).
- HID: pidff: Fix null pointer dereference in pidff_find_fields
  (stable-fixes).
- HID: pidff: Factor out code for setting gain (stable-fixes).
- HID: pidff: Rescale time values to match field units
  (stable-fixes).
- HID: pidff: Define values used in pidff_find_special_fields
  (stable-fixes).
- HID: pidff: Simplify pidff_upload_effect function
  (stable-fixes).
- HID: pidff: Completely rework and fix pidff_reset function
  (stable-fixes).
- HID: pidff: Add PERIODIC_SINE_ONLY quirk (stable-fixes).
- media: s5p-mfc: Corrected NV12M/NV21M plane-sizes
  (stable-fixes).
- media: uvcvideo: Add quirk for Actions UVC05 (stable-fixes).
- media: mediatek: vcodec: mark vdec_vp9_slice_map_counts_eob_coef
  noinline (stable-fixes).
- commit 9b73679
* Mon Apr 21 2025 tiwai@suse.de
- Update config files: CONFIG_HID_UNIVERSAL_PIDFF=m
- supported.conf:add hid-universal-pidff
- commit e9a63ce
* Mon Apr 21 2025 tiwai@suse.de
- gpio: zynq: Fix wakeup source leaks on device unbind
  (stable-fixes).
- HID: Add hid-universal-pidff driver and supported device ids
  (stable-fixes).
- HID: pidff: Stop all effects before enabling actuators
  (stable-fixes).
- HID: pidff: Add FIX_WHEEL_DIRECTION quirk (stable-fixes).
- HID: pidff: Add hid_pidff_init_with_quirks and export as GPL
  symbol (stable-fixes).
- HID: pidff: Add PERMISSIVE_CONTROL quirk (stable-fixes).
- HID: pidff: Add MISSING_PBO quirk and its detection
  (stable-fixes).
- HID: pidff: Add MISSING_DELAY quirk and its detection
  (stable-fixes).
- HID: pidff: Clamp PERIODIC effect period to device's logical
  range (stable-fixes).
- HID: pidff: Do not send effect envelope if it's empty
  (stable-fixes).
- HID: pidff: Convert infinite length from Linux API to PID
  standard (stable-fixes).
- commit a51995f
* Mon Apr 21 2025 tiwai@suse.de
- drm/tests: helpers: Create kunit helper to destroy a
  drm_display_mode (stable-fixes).
- drm/amdgpu: grab an additional reference on the gang fence v2
  (stable-fixes).
- drm/mediatek: mtk_dpi: Explicitly manage TVD clock in power
  on/off (stable-fixes).
- drm/mediatek: mtk_dpi: Move the input_2p_en bit to platform data
  (stable-fixes).
- drm/xe/xelp: Move Wa_16011163337 from tunings to workarounds
  (stable-fixes).
- drm/amdgpu: handle amdgpu_cgs_create_device() errors in
  amd_powerplay_create() (stable-fixes).
- drm/amdkfd: debugfs hang_hws skip GPU with MES (stable-fixes).
- drm/amdkfd: Fix pqm_destroy_queue race with GPU reset
  (stable-fixes).
- drm/amdkfd: Fix mode1 reset crash issue (stable-fixes).
- drm/amdkfd: clamp queue size to minimum (stable-fixes).
- drm/amd/display: stop DML2 from removing pipes based on planes
  (stable-fixes).
- drm/xe/vf: Don't try to trigger a full GT reset if VF
  (stable-fixes).
- drm/amdgpu: Unlocked unmap only clear page table leaves
  (stable-fixes).
- drm/amd/display: Update Cursor request mode to the beginning
  prefetch always (stable-fixes).
- drm/bridge: panel: forbid initializing a panel with unknown
  connector type (stable-fixes).
- drm/debugfs: fix printk format for bridge index (stable-fixes).
- drm: panel-orientation-quirks: Add quirk for OneXPlayer Mini
  (Intel) (stable-fixes).
- drm: panel-orientation-quirks: Add new quirk for GPD Win 2
  (stable-fixes).
- drm: panel-orientation-quirks: Add quirk for AYA NEO Slide
  (stable-fixes).
- drm: panel-orientation-quirks: Add quirks for AYA NEO Flip DS
  and KB (stable-fixes).
- drm: panel-orientation-quirks: Add support for AYANEO 2S
  (stable-fixes).
- drm: allow encoder mode_set even when connectors change for crtc
  (stable-fixes).
- fbdev: omapfb: Add 'plane' value check (stable-fixes).
- Bluetooth: Add quirk for broken READ_PAGE_SCAN_TYPE
  (stable-fixes).
- Bluetooth: Add quirk for broken READ_VOICE_SETTING
  (stable-fixes).
- Bluetooth: qca: simplify WCN399x NVM loading (stable-fixes).
- cdc_ether|r8152: ThinkPad Hybrid USB-C/A Dock quirk
  (stable-fixes).
- can: flexcan: add NXP S32G2/S32G3 SoC support (stable-fixes).
- can: flexcan: Add quirk to handle separate interrupt lines
  for mailboxes (stable-fixes).
- commit 3b991e8
* Mon Apr 21 2025 tiwai@suse.de
- drivers: base: devres: Allow to release group on device release
  (stable-fixes).
- Bluetooth: hci_qca: use the power sequencer for wcn6750
  (stable-fixes).
- Bluetooth: btusb: Add 2 HWIDs for MT7922 (stable-fixes).
- Bluetooth: hci_uart: Fix another race during initialization
  (git-fixes).
- Bluetooth: hci_uart: fix race during initialization
  (stable-fixes).
- Bluetooth: btintel_pcie: Add device id of Whale Peak
  (stable-fixes).
- ahci: Marvell 88SE9215 controllers prefer DMA for ATAPI
  (stable-fixes).
- ahci: add PCI ID for Marvell 88SE9215 SATA Controller
  (stable-fixes).
- ata: libata-eh: Do not use ATAPI DMA for a device limited to
  PIO mode (stable-fixes).
- ata: libata-core: Add 'external' to the libata.force kernel
  parameter (stable-fixes).
- ASoC: amd: yc: update quirk data for new Lenovo model
  (stable-fixes).
- ASoC: Intel: adl: add 2xrt1316 audio configuration
  (stable-fixes).
- ASoC: fsl_audmix: register card device depends on 'dais'
  property (stable-fixes).
- ASoC: amd: ps: use macro for ACP6.3 pci revision id
  (stable-fixes).
- ASoC: SOF: topology: Use krealloc_array() to replace krealloc()
  (stable-fixes).
- ASoC: amd: Add DMI quirk for ACP6X mic support (stable-fixes).
- ALSA: usb-audio: Fix CME quirk for UF series keyboards
  (stable-fixes).
- ALSA: hda: intel: Add Lenovo IdeaPad Z570 to probe denylist
  (stable-fixes).
- ALSA: hda: intel: Fix Optimus when GPU has no sound
  (stable-fixes).
- commit f8cceaa
* Mon Apr 21 2025 jgross@suse.com
- Update config files.
- commit ea75203
* Sun Apr 20 2025 tiwai@suse.de
- i2c: cros-ec-tunnel: defer probe if parent EC is not present
  (git-fixes).
- i2c: atr: Fix wrong include (git-fixes).
- drm/msm/a6xx+: Don't let IB_SIZE overflow (git-fixes).
- drm/xe/dma_buf: stop relying on placement in unmap (git-fixes).
- drm/xe/userptr: fix notifier vs folio deadlock (git-fixes).
- drm/xe: Set LRC addresses before guc load (git-fixes).
- drm/mgag200: Fix value in <VBLKSTR> register (git-fixes).
- dma-buf/sw_sync: Decrement refcount on error in
  sw_sync_ioctl_get_deadline() (git-fixes).
- drm/v3d: Fix Indirect Dispatch configuration for V3D 7.1.6
  and later (git-fixes).
- drm/amdgpu: Add back JPEG to video caps for carrizo and newer
  (git-fixes).
- drm/amdgpu: fix warning of drm_mm_clean (git-fixes).
- string: Add load_unaligned_zeropad() code path to
  sized_strscpy() (git-fixes).
- Documentation: PM: runtime: Fix a reference to
  pm_runtime_autosuspend() (git-fixes).
- kunit: qemu_configs: SH: Respect kunit cmdline (git-fixes).
- commit 2ff002e
* Sat Apr 19 2025 jgross@suse.com
- KVM: x86: Explicitly zero EAX and EBX when PERFMON_V2 isn't
  supported by KVM (jsc#PED-348).
- commit 6ea52a5
* Sat Apr 19 2025 jgross@suse.com
- KVM: SVM: Don't rely on DebugSwap to restore host DR0..DR3
  (jsc#PED-348).
- commit 444f443
* Sat Apr 19 2025 jgross@suse.com
- KVM: SVM: Save host DR masks on CPUs with DebugSwap
  (jsc#PED-348).
- commit 5ed001c
* Sat Apr 19 2025 jgross@suse.com
- kvm: retry nx_huge_page_recovery_thread creation (jsc#PED-348).
- commit 37391d6
* Sat Apr 19 2025 jgross@suse.com
- vhost: return task creation error instead of NULL (jsc#PED-348).
- commit ab9278d
* Sat Apr 19 2025 jgross@suse.com
- KVM: x86: Snapshot the host's DEBUGCTL after disabling IRQs
  (jsc#PED-348).
- commit dfe2ab4
* Sat Apr 19 2025 jgross@suse.com
- KVM: SVM: Manually context switch DEBUGCTL if LBR virtualization
  is disabled (jsc#PED-348).
- commit dd7305d
* Sat Apr 19 2025 jgross@suse.com
- KVM: x86: Snapshot the host's DEBUGCTL in common x86
  (jsc#PED-348).
- commit cce9ec5
* Sat Apr 19 2025 jgross@suse.com
- KVM: SVM: Suppress DEBUGCTL.BTF on AMD (jsc#PED-348).
- commit 6c4742c
* Sat Apr 19 2025 jgross@suse.com
- KVM: SVM: Drop DEBUGCTL[5:2] from guest's effective value
  (jsc#PED-348).
- commit 8ff18f3
* Sat Apr 19 2025 jgross@suse.com
- KVM: SVM: Set RFLAGS.IF=1 in C code, to get VMRUN out of the
  STI shadow (jsc#PED-348).
- commit a9f8b51
* Sat Apr 19 2025 jgross@suse.com
- KVM: nVMX: Process events on nested VM-Exit if injectable IRQ
  or NMI is pending (jsc#PED-348).
- commit 4ed5eed
* Sat Apr 19 2025 jgross@suse.com
- KVM: x86: Free vCPUs before freeing VM state (jsc#PED-348).
- commit df99449
* Sat Apr 19 2025 jgross@suse.com
- KVM: arm64: Ensure a VMID is allocated before programming
  VTTBR_EL2 (jsc#PED-348).
- commit b95233d
* Sat Apr 19 2025 jgross@suse.com
- KVM: arm64: Fix tcr_el2 initialisation in hVHE mode
  (jsc#PED-348).
- commit 611c563
* Sat Apr 19 2025 jgross@suse.com
- x86/sev: Fix broken SNP support with KVM module built-in
  (jsc#PED-348).
- commit 7022d3a
* Sat Apr 19 2025 jgross@suse.com
- x86/virt/tdx: Require the module to assert it has the NO_RBP_MOD
  mitigation (jsc#PED-348).
- commit e353bec
* Sat Apr 19 2025 jgross@suse.com
- x86/virt/tdx: Switch to use auto-generated global metadata
  reading code (jsc#PED-348).
- commit 166cc82
* Sat Apr 19 2025 jgross@suse.com
- x86/virt/tdx: Use dedicated struct members for PAMT entry sizes
  (jsc#PED-348).
- commit 71b25ee
* Sat Apr 19 2025 jgross@suse.com
- x86/virt/tdx: Use auto-generated code to read global metadata
  (jsc#PED-348).
- commit ee1f1c1
* Sat Apr 19 2025 jgross@suse.com
- x86/virt/tdx: Start to track all global metadata in one
  structure (jsc#PED-348).
- commit 2ebc496
* Sat Apr 19 2025 jgross@suse.com
- x86/virt/tdx: Rename 'struct tdx_tdmr_sysinfo' to reflect the
  spec better (jsc#PED-348).
- commit 7ed2a91
* Sat Apr 19 2025 jgross@suse.com
- x86/sev: Add full support for a segmented RMP table
  (jsc#PED-348).
- commit be63ba4
* Sat Apr 19 2025 jgross@suse.com
- x86/sev: Treat the contiguous RMP table as a single RMP segment
  (jsc#PED-348).
- commit d7caf03
* Sat Apr 19 2025 jgross@suse.com
- x86/sev: Map only the RMP table entries instead of the full
  RMP range (jsc#PED-348).
- commit 8f23caf
* Sat Apr 19 2025 jgross@suse.com
- x86/sev: Move the SNP probe routine out of the way
  (jsc#PED-348).
- commit a6edabd
* Sat Apr 19 2025 jgross@suse.com
- x86/sev: Add support for the RMPREAD instruction (jsc#PED-348).
- commit 3f98d95
* Fri Apr 18 2025 jgross@suse.com
- x86/sev: Prepare for using the RMPREAD instruction to access
  the RMP (jsc#PED-348).
- commit 7285465
* Fri Apr 18 2025 jgross@suse.com
- x86/virt: Provide "nosnp" boot option for sev kernel command
  line (jsc#PED-348).
- commit 9aba991
* Fri Apr 18 2025 jgross@suse.com
- KVM: SVM: Ensure PSP module is initialized if KVM module is
  built-in (jsc#PED-348).
- commit 833f5aa
* Fri Apr 18 2025 jgross@suse.com
- crypto: ccp: Add external API interface for PSP module
  initialization (jsc#PED-348).
- commit a5d6aaa
* Fri Apr 18 2025 jgross@suse.com
- KVM: arm64: vgic: Hoist SGI/PPI alloc from vgic_init() to
  kvm_create_vgic() (jsc#PED-348).
- commit 10c96b3
* Fri Apr 18 2025 jgross@suse.com
- KVM: arm64: timer: Drop warning on failed interrupt signalling
  (jsc#PED-348).
- commit 51183b7
* Fri Apr 18 2025 jgross@suse.com
- KVM: arm64: Convert timer offset VA when accessed in HYP code
  (jsc#PED-348).
- commit 268c80f
* Fri Apr 18 2025 jgross@suse.com
- KVM: arm64: Simplify warning in kvm_arch_vcpu_load_fp()
  (jsc#PED-348).
- commit 1bc1f92
* Fri Apr 18 2025 jgross@suse.com
- KVM: arm64: Eagerly switch ZCR_EL{1,2} (jsc#PED-348).
- commit 7a22e64
* Fri Apr 18 2025 jgross@suse.com
- KVM: arm64: Mark some header functions as inline (jsc#PED-348).
- commit 1cfd25c
* Fri Apr 18 2025 jgross@suse.com
- KVM: arm64: Refactor exit handlers (jsc#PED-348).
- commit e5402fd
* Fri Apr 18 2025 jgross@suse.com
- KVM: arm64: Refactor CPTR trap deactivation (jsc#PED-348).
- commit 83cdb48
* Fri Apr 18 2025 jgross@suse.com
- KVM: arm64: Remove VHE host restore of CPACR_EL1.SMEN
  (jsc#PED-348).
- commit 8be93a3
* Fri Apr 18 2025 jgross@suse.com
- KVM: arm64: Remove VHE host restore of CPACR_EL1.ZEN
  (jsc#PED-348).
- commit d88a1d3
* Fri Apr 18 2025 jgross@suse.com
- KVM: arm64: Remove host FPSIMD saving for non-protected KVM
  (jsc#PED-348).
- commit 5181b6b
* Fri Apr 18 2025 jgross@suse.com
- KVM: arm64: Fix __pkvm_host_mkyoung_guest() return value
  (jsc#PED-348).
- commit faf9635
* Fri Apr 18 2025 jgross@suse.com
- KVM: arm64: Simplify np-guest hypercalls (jsc#PED-348).
- commit b546f47
* Fri Apr 18 2025 jgross@suse.com
- KVM: arm64: Improve error handling from
  check_host_shared_guest() (jsc#PED-348).
- commit 2f08e8b
* Fri Apr 18 2025 jgross@suse.com
- KVM: x86/mmu: Ensure NX huge page recovery thread is alive
  before waking (jsc#PED-348).
- commit 05116bb
* Fri Apr 18 2025 jgross@suse.com
- KVM: remove kvm_arch_post_init_vm (jsc#PED-348).
- commit 773d5f0
* Fri Apr 18 2025 jgross@suse.com
- KVM: arm64: timer: Don't adjust the EL2 virtual timer offset
  (jsc#PED-348).
- commit 92a7c8b
* Fri Apr 18 2025 jgross@suse.com
- KVM: arm64: timer: Correctly handle EL1 timer emulation when
  !FEAT_ECV (jsc#PED-348).
- commit a65b9fa
* Fri Apr 18 2025 jgross@suse.com
- KVM: arm64: timer: Always evaluate the need for a soft timer
  (jsc#PED-348).
- commit a0fcc9f
* Fri Apr 18 2025 jgross@suse.com
- KVM: arm64: Fail protected mode init if no vgic hardware is
  present (jsc#PED-348).
- commit 8888838
* Fri Apr 18 2025 jgross@suse.com
- KVM: arm64: Flush/sync debug state in protected mode
  (jsc#PED-348).
- commit 14c9899
* Fri Apr 18 2025 jgross@suse.com
- KVM: s390: fake memslot for ucontrol VMs (jsc#PED-348).
- commit 8e19c9f
* Fri Apr 18 2025 jgross@suse.com
- KVM: s390: wrapper for KVM_BUG (jsc#PED-348).
- commit 54b5f7a
* Fri Apr 18 2025 jgross@suse.com
- KVM: Do not restrict the size of KVM-internal memory regions
  (jsc#PED-348).
- commit 8fd4c93
* Fri Apr 18 2025 jgross@suse.com
- KVM: s390: vsie: stop using "struct page" for vsie page
  (jsc#PED-348).
- commit efa5690
* Fri Apr 18 2025 jgross@suse.com
- KVM: s390: vsie: stop messing with page refcount (jsc#PED-348).
- commit 7a84437
* Fri Apr 18 2025 jgross@suse.com
- KVM: s390: vsie: stop using page->index (jsc#PED-348).
- commit 6ed9ce8
* Fri Apr 18 2025 jgross@suse.com
- x86/sev: Disable jump tables in SEV startup code (jsc#PED-348).
- commit 6c45685
* Fri Apr 18 2025 jgross@suse.com
- kvm: defer huge page recovery vhost task to later (jsc#PED-348).
- blacklist.conf:
- commit 3499024
* Fri Apr 18 2025 jgross@suse.com
- KVM: x86/mmu: Return RET_PF* instead of 1 in
  kvm_mmu_page_fault() (jsc#PED-348).
- commit 067a012
* Fri Apr 18 2025 jgross@suse.com
- KVM: Disallow all flags for KVM-internal memslots (jsc#PED-348).
- commit 12a97a6
* Fri Apr 18 2025 jgross@suse.com
- KVM: x86: Drop double-underscores from __kvm_set_memory_region()
  (jsc#PED-348).
- commit 5ce4734
* Fri Apr 18 2025 jgross@suse.com
- KVM: Add a dedicated API for setting KVM-internal memslots
  (jsc#PED-348).
- commit a323072
* Fri Apr 18 2025 jgross@suse.com
- KVM: Assert slots_lock is held when setting memory regions
  (jsc#PED-348).
- commit fb6ddb3
* Fri Apr 18 2025 jgross@suse.com
- KVM: Open code kvm_set_memory_region() into its sole caller
  (ioctl() API) (jsc#PED-348).
- commit 256fe59
* Fri Apr 18 2025 jgross@suse.com
- x86/sev: Disable ftrace branch profiling in SEV startup code
  (jsc#PED-348).
- commit b52c766
* Fri Apr 18 2025 jgross@suse.com
- KVM: arm64: nv: Apply RESx settings to sysreg reset values
  (jsc#PED-348).
- commit 45b8348
* Fri Apr 18 2025 tiwai@suse.de
- Revert "PCI: Avoid reset when disabled via sysfs" (git-fixes).
- Bluetooth: vhci: Avoid needless snprintf() calls (git-fixes).
- can: rockchip_canfd: fix broken quirks checks (git-fixes).
- wifi: wl1251: fix memory leak in wl1251_tx_work (git-fixes).
- wifi: mac80211: Purge vif txq in ieee80211_do_stop()
  (git-fixes).
- wifi: at76c50x: fix use after free access in at76_disconnect
  (git-fixes).
- Bluetooth: l2cap: Check encryption key size on incoming
  connection (git-fixes).
- Bluetooth: btrtl: Prevent potential NULL dereference
  (git-fixes).
- Bluetooth: hci_event: Fix sending MGMT_EV_DEVICE_FOUND for
  invalid address (git-fixes).
- ASoC: fsl: fsl_qmc_audio: Reset audio data pointers on
  TRIGGER_START event (git-fixes).
- ASoC: cs42l43: Reset clamp override on jack removal (git-fixes).
- ASoC: codecs:lpass-wsa-macro: Fix logic of enabling vi channels
  (git-fixes).
- ASoC: codecs:lpass-wsa-macro: Fix vi feedback rate (git-fixes).
- ASoC: Intel: avs: Fix null-ptr-deref in avs_component_probe()
  (git-fixes).
- ASoC: qcom: Fix sc7280 lpass potential buffer overflow
  (git-fixes).
- ASoC: dwc: always enable/disable i2s irqs (git-fixes).
- ASoC: Intel: sof_sdw: Add quirk for Asus Zenbook S16
  (git-fixes).
- ALSA: hda/realtek - Fixed ASUS platform headset Mic issue
  (git-fixes).
- ALSA: hda/cirrus_scodec_test: Don't select dependencies
  (git-fixes).
- platform/x86: amd: pmf: Fix STT limits (git-fixes).
- asus-laptop: Fix an uninitialized variable (git-fixes).
- ata: libata-sata: Save all fields from sense data descriptor
  (git-fixes).
- commit dc52581
* Thu Apr 17 2025 mgorman@suse.de
- Update -rt config files.
- commit eb8f856
* Thu Apr 17 2025 mgorman@suse.de
- config/arm64/rt*: Use delta configs for rt and rt_debug
- commit 50e0baa
* Thu Apr 17 2025 mgorman@suse.de
- config/x86_64/rt*: Use delta configs for rt and rt_debug
- commit 91bfd3c
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: nv: Always evaluate HCR_EL2 using sanitising
  accessors (jsc#PED-348).
- commit 00f9d3e
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Support trace filtering for guests (jsc#PED-348).
- commit 4c7c76f
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: coresight: Give TRBE enabled state to KVM
  (jsc#PED-348).
- commit 11d152f
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Drop pkvm_mem_transition for host/hyp donations
  (jsc#PED-348).
- commit f924906
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Drop pkvm_mem_transition for host/hyp sharing
  (jsc#PED-348).
- commit 046b34b
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Drop pkvm_mem_transition for FF-A (jsc#PED-348).
- commit 5b52a59
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Explicitly handle BRBE traps as UNDEFINED
  (jsc#PED-348).
- commit ed370c6
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: vgic: Use str_enabled_disabled() in vgic_v3_probe()
  (jsc#PED-348).
- commit 3bb6ff9
* Thu Apr 17 2025 jgross@suse.com
- KVM: SVM: Use str_enabled_disabled() helper in
  svm_hardware_setup() (jsc#PED-348).
- commit 6f41c4e
* Thu Apr 17 2025 jgross@suse.com
- KVM: VMX: read the PML log in the same order as it was written
  (jsc#PED-348).
- commit bccbcae
* Thu Apr 17 2025 jgross@suse.com
- KVM: VMX: refactor PML terminology (jsc#PED-348).
- commit b544ed3
* Thu Apr 17 2025 jgross@suse.com
- KVM: VMX: Reinstate __exit attribute for vmx_exit()
  (jsc#PED-348).
- commit 14a4dce
* Thu Apr 17 2025 jgross@suse.com
- KVM: SVM: Use str_enabled_disabled() helper in
  sev_hardware_setup() (jsc#PED-348).
- commit 2552094
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Use LVT_TIMER instead of an open coded literal
  (jsc#PED-348).
- commit c79d364
* Thu Apr 17 2025 jgross@suse.com
- x86/tsc: Init the TSC for Secure TSC guests (jsc#PED-348).
- commit e1bf1ec
* Thu Apr 17 2025 jgross@suse.com
- arm64: rsi: Add automatic arm-cca-guest module loading
  (jsc#PED-348).
- commit ba7ca3a
* Thu Apr 17 2025 jgross@suse.com
- arm64/sysreg: Update ID_AA64ISAR3_EL1 to DDI0601 2024-09
  (jsc#PED-348).
- commit 418c6dd
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Allow control of dpISA extensions in
  ID_AA64ISAR3_EL1 (jsc#PED-348).
- Refresh
  patches.suse/KVM-arm64-Work-around-x1e-s-CNTVOFF_EL2-bogosity.patch.
- commit 17e5fed
* Thu Apr 17 2025 jgross@suse.com
- arm64: kvm: Introduce nvhe stack size constants (jsc#PED-348).
- commit 3346c3a
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Fix nVHE stacktrace VA bits mask (jsc#PED-348).
- commit fba9974
* Thu Apr 17 2025 jgross@suse.com
- x86/sev: Prevent RDTSC/RDTSCP interception for Secure TSC
  enabled guests (jsc#PED-348).
- commit 91e1f0f
* Thu Apr 17 2025 jgross@suse.com
- x86/sev: Prevent GUEST_TSC_FREQ MSR interception for Secure
  TSC enabled guests (jsc#PED-348).
- commit 1619aae
* Thu Apr 17 2025 jgross@suse.com
- x86/sev: Change TSC MSR behavior for Secure TSC enabled guests
  (jsc#PED-348).
- commit 11fb1e6
* Thu Apr 17 2025 jgross@suse.com
- virt: sev-guest: Move SNP Guest Request data pages handling
  under snp_cmd_mutex (jsc#PED-348).
- blacklist.conf:
- commit 733c44d
* Thu Apr 17 2025 jgross@suse.com
- x86/sev: Add Secure TSC support for SNP guests (jsc#PED-348).
- Refresh
  patches.suse/x86-sev-Don-t-hang-but-terminate-on-failure-to-remap.patch.
- commit b533cc5
* Thu Apr 17 2025 jgross@suse.com
- x86/sev: Don't hang but terminate on failure to remap SVSM CA
  (jsc#PED-348).
- commit 8116c53
* Thu Apr 17 2025 jgross@suse.com
- x86/sev: Relocate SNP guest messaging routines to common code
  (jsc#PED-348).
- commit 552d0ba
* Thu Apr 17 2025 jgross@suse.com
- x86/sev: Carve out and export SNP guest messaging init routines
  (jsc#PED-348).
- commit 2443d39
* Thu Apr 17 2025 jgross@suse.com
- virt: sev-guest: Replace GFP_KERNEL_ACCOUNT with GFP_KERNEL
  (jsc#PED-348).
- commit 90d0384
* Thu Apr 17 2025 jgross@suse.com
- virt: sev-guest: Remove is_vmpck_empty() helper (jsc#PED-348).
- commit 1f8e8db
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Work around x1e's CNTVOFF_EL2 bogosity
  (jsc#PED-348).
- commit f93e623
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: nv: Sanitise CNTHCTL_EL2 (jsc#PED-348).
- commit 203632a
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: nv: Propagate CNTHCTL_EL2.EL1NV{P,V}CT bits
  (jsc#PED-348).
- commit 60a8ea7
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: nv: Add trap routing for
  CNTHCTL_EL2.EL1{NVPCT,NVVCT,TVT,TVCT} (jsc#PED-348).
- commit d9c7361
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Handle counter access early in non-HYP context
  (jsc#PED-348).
- commit ffbbbd0
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: nv: Accelerate EL0 counter accesses from hypervisor
  context (jsc#PED-348).
- commit 1753972
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: nv: Accelerate EL0 timer read accesses when FEAT_ECV
  in use (jsc#PED-348).
- commit b3d1aef
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: nv: Use FEAT_ECV to trap access to EL0 timers
  (jsc#PED-348).
- commit e031801
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: nv: Publish emulated timer interrupt state in the
  in-memory state (jsc#PED-348).
- commit 0a26877
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: nv: Sync nested timer state with FEAT_NV2
  (jsc#PED-348).
- commit 1650047
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: nv: Add handling of EL2-specific timer registers
  (jsc#PED-348).
- commit 207d743
* Thu Apr 17 2025 jgross@suse.com
- x86/sev: Disable UBSAN on SEV code that may execute very early
  (jsc#PED-348).
- commit 876b85f
* Thu Apr 17 2025 jgross@suse.com
- RISC-V: KVM: Add SBI system suspend support (jsc#PED-348).
- commit f08bd14
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86/mmu: Prevent aliased memslot GFNs (jsc#PED-348).
- commit a6d398c
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86/tdp_mmu: Don't zap valid mirror roots in
  kvm_tdp_mmu_zap_all() (jsc#PED-348).
- commit 54a655a
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86/tdp_mmu: Take root types for
  kvm_tdp_mmu_invalidate_all_roots() (jsc#PED-348).
- commit a57e36b
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86/tdp_mmu: Propagate tearing down mirror page tables
  (jsc#PED-348).
- commit 1a40f72
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86/tdp_mmu: Propagate building mirror page tables
  (jsc#PED-348).
- commit 3cccd94
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86/tdp_mmu: Propagate attr_filter to MMU notifier
  callbacks (jsc#PED-348).
- commit b7f9b9b
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86/tdp_mmu: Support mirror root for TDP MMU (jsc#PED-348).
- commit 517d32a
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86/tdp_mmu: Take root in tdp_mmu_for_each_pte()
  (jsc#PED-348).
- commit d476e94
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86/tdp_mmu: Introduce KVM MMU root types to specify page
  table type (jsc#PED-348).
- commit 0ed70b6
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86/tdp_mmu: Extract root invalid check from
  tdx_mmu_next_root() (jsc#PED-348).
- commit dd22ac6
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86/mmu: Support GFN direct bits (jsc#PED-348).
- commit d7ff58c
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86/tdp_mmu: Take struct kvm in iter loops (jsc#PED-348).
- commit f86a705
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86/mmu: Make kvm_tdp_mmu_alloc_root() return void
  (jsc#PED-348).
- commit a83e9e3
* Thu Apr 17 2025 mhocko@suse.com
- enabled CONFIG_DAMON (jsc#PED-12520)
- commit 0674446
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86/mmu: Add an is_mirror member for union
  kvm_mmu_page_role (jsc#PED-348).
- commit c30eeae
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Add a VM type define for TDX (jsc#PED-348).
- commit ee9ed63
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86/mmu: Add an external pointer to struct kvm_mmu_page
  (jsc#PED-348).
- commit e95d7d7
* Thu Apr 17 2025 jgross@suse.com
- KVM: Add member to struct kvm_gfn_range to indicate
  private/shared (jsc#PED-348).
- commit 1c2ff6d
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86/mmu: Zap invalid roots with mmu_lock holding for
  write at uninit (jsc#PED-348).
- commit 13bf1e1
* Thu Apr 17 2025 jgross@suse.com
- KVM: guest_memfd: Remove RCU-protected attribute from
  slot->gmem.file (jsc#PED-348).
- commit 4d8e2b2
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Refactor __kvm_emulate_hypercall() into a macro
  (jsc#PED-348).
- commit fe456a9
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Always complete hypercall via function callback
  (jsc#PED-348).
- commit 6308fc3
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Bump hypercall stat prior to fully completing
  hypercall (jsc#PED-348).
- commit e5b686b
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Move "emulate hypercall" function declarations to
  x86.h (jsc#PED-348).
- commit 823ce3c
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Add a helper to check for user interception of KVM
  hypercalls (jsc#PED-348).
- commit 18023dd
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: clear vcpu->run->hypercall.ret before exiting for
  KVM_EXIT_HYPERCALL (jsc#PED-348).
- commit 5595e7d
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: nv: Advertise the lack of AArch32 EL0 support
  (jsc#PED-348).
- commit 2506605
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Use kvm_vcpu_has_feature() directly for struct kvm
  (jsc#PED-348).
- commit 0cabcd6
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Fix FEAT_MTE in pKVM (jsc#PED-348).
- blacklist.conf:
- commit afe065b
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Convert the SVE guest vcpu flag to a vm flag
  (jsc#PED-348).
- commit 57f384a
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Remove PtrAuth guest vcpu flag (jsc#PED-348).
- commit 1727949
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Fix the value of the CPTR_EL2 RES1 bitmask for nVHE
  (jsc#PED-348).
- commit b2aa45c
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Refactor kvm_reset_cptr_el2() (jsc#PED-348).
- commit a627719
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Calculate cptr_el2 traps on activating traps
  (jsc#PED-348).
- commit ee465fa
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Remove redundant setting of HCR_EL2 trap bit
  (jsc#PED-348).
- commit 28bdeb3
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Remove fixed_config.h header (jsc#PED-348).
- commit 5791ec1
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Rework specifying restricted features for protected
  VMs (jsc#PED-348).
- commit 2f8220d
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Set protected VM traps based on its view of feature
  registers (jsc#PED-348).
- commit f831267
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Fix RAS trapping in pKVM for protected VMs
  (jsc#PED-348).
- commit 6cee1f3
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Initialize feature id registers for protected VMs
  (jsc#PED-348).
- commit 1ac9df5
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Use KVM extension checks for allowed protected VM
  capabilities (jsc#PED-348).
- commit 13df3e5
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Remove KVM_ARM_VCPU_POWER_OFF from protected VMs
  allowed features in pKVM (jsc#PED-348).
- commit 5b3a7f3
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Move checking protected vcpu features to a separate
  function (jsc#PED-348).
- commit c2816cc
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Group setting traps for protected VMs by control
  register (jsc#PED-348).
- commit 16f522d
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Consolidate allowed and restricted VM feature checks
  (jsc#PED-348).
- commit 077b10b
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Plumb the pKVM MMU in KVM (jsc#PED-348).
- commit 06d9e82
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Introduce the EL1 pKVM MMU (jsc#PED-348).
- commit 77ef574
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Introduce __pkvm_tlb_flush_vmid() (jsc#PED-348).
- commit f67a1b6
* Thu Apr 17 2025 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Also order against update-bootloader
  (boo#1228659, boo#1240785, boo#1241038).
- commit fe0a8c9
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Introduce __pkvm_host_mkyoung_guest() (jsc#PED-348).
- commit 4b5f88b
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Introduce __pkvm_host_test_clear_young_guest()
  (jsc#PED-348).
- commit 35723b2
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Introduce __pkvm_host_wrprotect_guest()
  (jsc#PED-348).
- commit 245cc05
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Introduce __pkvm_host_relax_guest_perms()
  (jsc#PED-348).
- commit c7cc89c
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Introduce __pkvm_host_unshare_guest() (jsc#PED-348).
- commit d7cae74
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Introduce __pkvm_host_share_guest() (jsc#PED-348).
- commit e6080ad
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Introduce __pkvm_vcpu_{load,put}() (jsc#PED-348).
- commit 6802451
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Add {get,put}_pkvm_hyp_vm() helpers (jsc#PED-348).
- commit 9121741
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Make kvm_pgtable_stage2_init() a static inline
  function (jsc#PED-348).
- commit c15dc2c
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Pass walk flags to kvm_pgtable_stage2_relax_perms
  (jsc#PED-348).
- commit 06b61af
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Pass walk flags to kvm_pgtable_stage2_mkyoung
  (jsc#PED-348).
- commit 93eac59
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Move host page ownership tracking to the hyp vmemmap
  (jsc#PED-348).
- commit 5ea671f
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Make hyp_page::order a u8 (jsc#PED-348).
- commit 7081de3
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Move enum pkvm_page_state to memory.h (jsc#PED-348).
- commit 7e99c55
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Change the layout of enum pkvm_page_state
  (jsc#PED-348).
- commit 38fe175
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Promote guest ownership for DBGxVR/DBGxCR reads
  (jsc#PED-348).
- commit a24d033
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Fold DBGxVR/DBGxCR accessors into common set
  (jsc#PED-348).
- commit a959b03
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Avoid reading ID_AA64DFR0_EL1 for debug save/restore
  (jsc#PED-348).
- commit 42d7f35
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: nv: Honor MDCR_EL2.TDE routing for debug exceptions
  (jsc#PED-348).
- commit a690913
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Manage software step state at load/put
  (jsc#PED-348).
- commit 318d8db
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Don't hijack guest context MDSCR_EL1 (jsc#PED-348).
- commit c57ed08
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Compute MDCR_EL2 at vcpu_load() (jsc#PED-348).
- commit 8b69d67
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Reload vCPU for accesses to OSLAR_EL1 (jsc#PED-348).
- commit f901dd3
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Use debug_owner to track if debug regs need
  save/restore (jsc#PED-348).
- commit 0d72241
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Remove vestiges of debug_ptr (jsc#PED-348).
- commit 55a0c51
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Remove debug tracepoints (jsc#PED-348).
- commit 072a66f
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Select debug state to save/restore based on debug
  owner (jsc#PED-348).
- commit 5d875f7
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Clean up KVM_SET_GUEST_DEBUG handler (jsc#PED-348).
- commit 23c64df
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Evaluate debug owner at vcpu_load() (jsc#PED-348).
- commit bf4bfe0
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Write MDCR_EL2 directly from
  kvm_arm_setup_mdcr_el2() (jsc#PED-348).
- commit e06e0a3
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Move host SME/SVE tracking flags to host data
  (jsc#PED-348).
- Refresh
  patches.suse/KVM-arm64-Unconditionally-save-flush-host-FPSIMD-SVE-SME-state.patch.
- commit 96b52e1
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Track presence of SPE/TRBE in kvm_host_data instead
  of vCPU (jsc#PED-348).
- commit 02bb671
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Get rid of __kvm_get_mdcr_el2() and related warts
  (jsc#PED-348).
- commit 360d175
* Thu Apr 17 2025 jgross@suse.com
- KVM: arm64: Drop MDSCR_EL1_DEBUG_MASK (jsc#PED-348).
- commit 654a038
* Thu Apr 17 2025 jgross@suse.com
- arm64/sysreg: Get rid of CPACR_ELx SysregFields (jsc#PED-348).
- commit 4f6a67e
* Thu Apr 17 2025 jgross@suse.com
- arm64/sysreg: Convert *_EL12 accessors to Mapping (jsc#PED-348).
- commit ab8171a
* Thu Apr 17 2025 jgross@suse.com
- arm64/sysreg: Get rid of the TCR2_EL1x SysregFields
  (jsc#PED-348).
- commit ac99b49
* Thu Apr 17 2025 jgross@suse.com
- arm64: setup: name 'tcr2' register (jsc#PED-348).
- commit 083cc0a
* Thu Apr 17 2025 jgross@suse.com
- arm64/sysreg: Allow a 'Mapping' descriptor for system registers
  (jsc#PED-348).
- commit e10ff75
* Thu Apr 17 2025 jgross@suse.com
- arm64/kvm: Avoid invalid physical addresses to signal owner
  updates (jsc#PED-348).
- commit 5332312
* Thu Apr 17 2025 jgross@suse.com
- arm64/kvm: Configure HYP TCR.PS/DS based on host stage1
  (jsc#PED-348).
- commit 3fa17e8
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Remove hwapic_irr_update() from kvm_x86_ops
  (jsc#PED-348).
- commit ec44993
* Thu Apr 17 2025 jgross@suse.com
- KVM: nVMX: Honor event priority when emulating PI delivery
  during VM-Enter (jsc#PED-348).
- commit 8b35f41
* Thu Apr 17 2025 jgross@suse.com
- KVM: nVMX: Use vmcs01's controls shadow to check for IRQ/NMI
  windows at VM-Enter (jsc#PED-348).
- commit 227df19
* Thu Apr 17 2025 jgross@suse.com
- KVM: nVMX: Drop manual vmcs01.GUEST_INTERRUPT_STATUS.RVI check
  at VM-Enter (jsc#PED-348).
- commit 2678d06
* Thu Apr 17 2025 jgross@suse.com
- KVM: nVMX: Check for pending INIT/SIPI after entering non-root
  mode (jsc#PED-348).
- commit 5281aec
* Thu Apr 17 2025 jgross@suse.com
- KVM: nVMX: Explicitly update vPPR on successful nested VM-Enter
  (jsc#PED-348).
- commit d094324
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Add information about pending requests to kvm_exit
  tracepoint (jsc#PED-348).
- commit 62af53f
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Add interrupt injection information to the kvm_entry
  tracepoint (jsc#PED-348).
- commit 19c8851
* Thu Apr 17 2025 jgross@suse.com
- KVM: SVM: Handle event vectoring error in
  check_emulate_instruction() (jsc#PED-348).
- commit 9866a06
* Thu Apr 17 2025 jgross@suse.com
- KVM: VMX: Handle event vectoring error in
  check_emulate_instruction() (jsc#PED-348).
- commit 3f9c1bc
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Try to unprotect and retry on unhandleable emulation
  failure (jsc#PED-348).
- commit 23860d1
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Add emulation status for unhandleable exception
  vectoring (jsc#PED-348).
- commit 9d2063a
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Add function for vectoring error generation
  (jsc#PED-348).
- commit b30b581
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Use only local variables (no bitmask) to init
  kvm_cpu_caps (jsc#PED-348).
- commit 7fe2c13
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Explicitly track feature flags that are enabled at
  runtime (jsc#PED-348).
- commit ee49c88
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Explicitly track feature flags that require vendor
  enabling (jsc#PED-348).
- commit 50a4cc7
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Rename "SF" macro to "SCATTERED_F" (jsc#PED-348).
- commit fc020fe
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Pull CPUID capabilities from boot_cpu_data only as
  needed (jsc#PED-348).
- commit dad6907
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Add a macro for features that are synthesized into
  boot_cpu_data (jsc#PED-348).
- commit 90f17ed
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Drop superfluous host XSAVE check when adjusting
  guest XSAVES caps (jsc#PED-348).
- commit eeb8bd7
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Replace (almost) all guest CPUID feature queries
  with cpu_caps (jsc#PED-348).
- commit bafc961
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Shuffle code to prepare for dropping guest_cpuid_has()
  (jsc#PED-348).
- commit ae3d20d
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Update guest cpu_caps at runtime for dynamic
  CPUID-based features (jsc#PED-348).
- commit 088e022
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Update OS{XSAVE,PKE} bits in guest CPUID irrespective
  of host support (jsc#PED-348).
- commit e29333b
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Drop unnecessary check that cpuid_entry2_find()
  returns right leaf (jsc#PED-348).
- commit 3744528
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Avoid double CPUID lookup when updating MWAIT at
  runtime (jsc#PED-348).
- commit b1910e2
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Initialize guest cpu_caps based on KVM support
  (jsc#PED-348).
- commit 9ca94f2
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Treat MONTIOR/MWAIT as a "partially emulated" feature
  (jsc#PED-348).
- commit 12694d7
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Extract code for generating per-entry emulated CPUID
  information (jsc#PED-348).
- commit 6b47ba9
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Initialize guest cpu_caps based on guest CPUID
  (jsc#PED-348).
- commit c4ec6d7
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Replace guts of "governed" features with comprehensive
  cpu_caps (jsc#PED-348).
- commit 744133e
* Thu Apr 17 2025 tiwai@suse.de
- radix-tree: add missing cleanup.h (git-fixes).
- crypto: caam/qi - Fix drv_ctx refcount bug (git-fixes).
- commit 3c5ba83
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Rename "governed features" helpers to use
  "guest_cpu_cap" (jsc#PED-348).
- commit 0fff997
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Advertise HYPERVISOR in KVM_GET_SUPPORTED_CPUID
  (jsc#PED-348).
- commit 3203ab7
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Advertise TSC_DEADLINE_TIMER in
  KVM_GET_SUPPORTED_CPUID (jsc#PED-348).
- commit a3e58fe
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Remove all direct usage of cpuid_entry2_find()
  (jsc#PED-348).
- commit bf23d0c
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Move kvm_find_cpuid_entry{,_index}() up near
  cpuid_entry2_find() (jsc#PED-348).
- commit 2a644e6
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Always operate on kvm_vcpu data in cpuid_entry2_find()
  (jsc#PED-348).
- commit 843079b
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Remove unnecessary caching of KVM's PV CPUID base
  (jsc#PED-348).
- commit cdb8730
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Clear PV_UNHALT for !HLT-exiting only when userspace
  sets CPUID (jsc#PED-348).
- commit 74aaac1
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Swap incoming guest CPUID into vCPU before massaging
  in KVM_SET_CPUID2 (jsc#PED-348).
- commit 9defaee
* Thu Apr 17 2025 jgross@suse.com
- KVM: x86: Add a macro to init CPUID features that KVM emulates
  in software (jsc#PED-348).
- commit eb8f359
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Add a macro to init CPUID features that ignore host
  kernel support (jsc#PED-348).
- commit 08b20bc
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Harden CPU capabilities processing against
  out-of-scope features (jsc#PED-348).
- commit 510b6f1
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: #undef SPEC_CTRL_SSBD in cpuid.c to avoid macro
  collisions (jsc#PED-348).
- commit 21d3e95
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Handle kernel- and KVM-defined CPUID words in a
  single helper (jsc#PED-348).
- commit 276a84b
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Add a macro to precisely handle aliased 0x1.EDX
  CPUID features (jsc#PED-348).
- commit 634ca32
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Add a macro to init CPUID features that are 64-bit
  only (jsc#PED-348).
- commit ad2d27f
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Rename kvm_cpu_cap_mask() to kvm_cpu_cap_init()
  (jsc#PED-348).
- commit 07cb013
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Unpack F() CPUID feature flag macros to one flag
  per line of code (jsc#PED-348).
- commit 94d8a41
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Account for max supported CPUID leaf when getting
  raw host CPUID (jsc#PED-348).
- commit e01ea13
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Do reverse CPUID sanity checks in __feature_leaf()
  (jsc#PED-348).
- commit 386c0e7
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Don't update PV features caches when enabling
  enforcement capability (jsc#PED-348).
- commit e32cc5c
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Disallow KVM_CAP_X86_DISABLE_EXITS after vCPU creation
  (jsc#PED-348).
- Refresh
  patches.suse/KVM-x86-Reject-disabling-of-MWAIT-HLT-interception-w.patch.
- commit 7ab259a
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Drop now-redundant MAXPHYADDR and GPA rsvd bits from
  vCPU creation (jsc#PED-348).
- commit 24d1858
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86/pmu: Drop now-redundant refresh() during init()
  (jsc#PED-348).
- commit bdd0c1f
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Move __kvm_is_valid_cr4() definition to x86.h
  (jsc#PED-348).
- commit 43b554e
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Explicitly do runtime CPUID updates "after" initial
  setup (jsc#PED-348).
- commit e180b3c
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Do all post-set CPUID processing during vCPU creation
  (jsc#PED-348).
- commit d8bccfa
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Limit use of F() and SF() to
  kvm_cpu_cap_{mask,init_kvm_defined}() (jsc#PED-348).
- commit 988beee
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Use feature_bit() to clear CONSTANT_TSC when emulating
  CPUID (jsc#PED-348).
- commit edd2809
* Wed Apr 16 2025 jgross@suse.com
- KVM: SVM: Remove redundant TLB flush on guest CR4.PGE change
  (jsc#PED-348).
- commit a1d30ca
* Wed Apr 16 2025 jgross@suse.com
- KVM: SVM: Macrofy SEV=n versions of sev_xxx_guest()
  (jsc#PED-348).
- commit 2eb6ad5
* Wed Apr 16 2025 jgross@suse.com
- KVM/x86: add comment to kvm_mmu_do_page_fault() (jsc#PED-348).
- commit f8b9220
* Wed Apr 16 2025 jgross@suse.com
- KVM: Drop hack that "manually" informs lockdep of kvm->lock
  vs. vcpu->mutex (jsc#PED-348).
- commit 8bb2bd9
* Wed Apr 16 2025 jgross@suse.com
- KVM: Don't BUG() the kernel if xa_insert() fails with -EBUSY
  (jsc#PED-348).
- commit 49c66f6
* Wed Apr 16 2025 jgross@suse.com
- Revert "KVM: Fix vcpu_array[0] races" (jsc#PED-348).
- commit 413becc
* Wed Apr 16 2025 jgross@suse.com
- KVM: Grab vcpu->mutex across installing the vCPU's fd and
  bumping online_vcpus (jsc#PED-348).
- commit 7f30aeb
* Wed Apr 16 2025 jgross@suse.com
- x86/tdx: Dump attributes and TD_CTLS on boot (jsc#PED-348).
- commit 74acffc
* Wed Apr 16 2025 jgross@suse.com
- x86/boot: Disable UBSAN in early boot code (jsc#PED-348).
- commit 3c2b2d2
* Wed Apr 16 2025 jgross@suse.com
- x86/sev: Avoid WARN()s and panic()s in early boot code
  (jsc#PED-348).
- commit 4125835
* Wed Apr 16 2025 jgross@suse.com
- x86/tdx: Disable unnecessary virtualization exceptions
  (jsc#PED-348).
- commit abda8db
* Wed Apr 16 2025 jgross@suse.com
- x86/mtrr: Rename mtrr_overwrite_state() to
  guest_force_mtrr_state() (jsc#PED-348).
- commit 8430eb6
* Wed Apr 16 2025 jgross@suse.com
- x86: Convert unreachable() to BUG() (jsc#PED-348).
- commit e4cd586
* Wed Apr 16 2025 jgross@suse.com
- Documentation: KVM: fix malformed table (jsc#PED-348).
- commit 12a0164
* Wed Apr 16 2025 vbabka@suse.cz
- mm/vmscan: accumulate nr_demoted for accurate demotion
  statistics (bsc#1241017).
- commit dee521e
* Wed Apr 16 2025 vbabka@suse.cz
- mm: vmscan : pgdemote vmstat is not getting updated when MGLRU
  is enabled (bsc#1241017).
- commit c383344
* Wed Apr 16 2025 nik.borisov@suse.com
- x86/tdx: Emit warning if IRQs are enabled during HLT #VE handling (git-fixes).
- commit 821f908
* Wed Apr 16 2025 nik.borisov@suse.com
- x86/tdx: Fix arch_safe_halt() execution for TDX VMs (git-fixes).
- commit fba743c
* Wed Apr 16 2025 nik.borisov@suse.com
- x86/paravirt: Move halt paravirt calls under CONFIG_PARAVIRT (git-fixes).
- commit 18b7232
* Wed Apr 16 2025 nik.borisov@suse.com
- x86/coco: Replace 'static const cc_mask' with the newly introduced  cc_get_mask() function (git-fixes).
- commit 297d234
* Wed Apr 16 2025 nik.borisov@suse.com
- x86/entry: Add __init to ia32_emulation_override_cmdline() (git-fixes).
- commit 8ea5b5f
* Wed Apr 16 2025 nik.borisov@suse.com
- x86/uaccess: Improve performance by aligning writes to 8 bytes in  copy_user_generic(), on non-FSRM/ERMS CPUs (git-fixes).
- commit 7e6aaa6
* Wed Apr 16 2025 jgross@suse.com
- Update config files.
- commit 2b9e98a
* Wed Apr 16 2025 jgross@suse.com
- KVM: e500: perform hugepage check after looking up the PFN
  (jsc#PED-348).
- commit 3d3cc93
* Wed Apr 16 2025 jgross@suse.com
- KVM: e500: map readonly host pages for read (jsc#PED-348).
- commit bf95e9e
* Wed Apr 16 2025 jgross@suse.com
- KVM: e500: track host-writability of pages (jsc#PED-348).
- commit 0c38772
* Wed Apr 16 2025 jgross@suse.com
- KVM: e500: use shadow TLB entry as witness for writability
  (jsc#PED-348).
- commit b72acdd
* Wed Apr 16 2025 jgross@suse.com
- KVM: e500: always restore irqs (jsc#PED-348).
- commit 25407ab
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: let it be known that ignore_msrs is a bad idea
  (jsc#PED-348).
- commit 667c8d0
* Wed Apr 16 2025 jgross@suse.com
- KVM: VMX: don't include '<linux/find.h>' directly (jsc#PED-348).
- commit a37309e
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86/mmu: Treat TDP MMU faults as spurious if access is
  already allowed (jsc#PED-348).
- commit 4aa85bd
* Wed Apr 16 2025 jgross@suse.com
- KVM: SVM: Disable AVIC on SNP-enabled system without
  HvInUseWrAllowed feature (jsc#PED-348).
- commit cce39fd
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: Only apply PMCR_EL0.P to the guest range of counters
  (jsc#PED-348).
- commit 8343d6d
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: nv: Reload PMU events upon MDCR_EL2.HPME change
  (jsc#PED-348).
- commit 760f548
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: Use KVM_REQ_RELOAD_PMU to handle PMCR_EL0.E change
  (jsc#PED-348).
- commit 3439829
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: Add unified helper for reprogramming counters by
  mask (jsc#PED-348).
- commit 7b982cc
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: Always check the state from hyp_ack_unshare()
  (jsc#PED-348).
- commit 4d50406
* Wed Apr 16 2025 nik.borisov@suse.com
- x86/bugs: Add RSB mitigation document (git-fixes).
- commit 256a12f
* Wed Apr 16 2025 nik.borisov@suse.com
- x86/bugs: Don't fill RSB on context switch with eIBRS (git-fixes).
- commit aed0c44
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Cache CPUID.0xD XSTATE offsets+sizes during module
  init (jsc#PED-348).
- commit 9ce0023
* Wed Apr 16 2025 jgross@suse.com
- RISC-V: KVM: Fix csr_write -> csr_set for HVIEN PMU overflow
  bit (jsc#PED-348).
- commit ee3ee05
* Wed Apr 16 2025 jgross@suse.com
- coco: virt: arm64: Do not enable cca guest driver by default
  (jsc#PED-348).
- commit a4bf6c7
* Wed Apr 16 2025 jgross@suse.com
- drivers/virt: pkvm: Don't fail ioremap() call if MMIO_GUARD
  fails (jsc#PED-348).
- commit 64169e7
* Wed Apr 16 2025 nik.borisov@suse.com
- x86/bugs: Don't fill RSB on VMEXIT with eIBRS+retpoline (git-fixes).
- commit 54d8017
* Wed Apr 16 2025 nik.borisov@suse.com
- x86/bugs: Fix RSB clearing in indirect_branch_prediction_barrier() (git-fixes).
- commit 677de47
* Wed Apr 16 2025 jgross@suse.com
- LoongArch: KVM: Protect kvm_io_bus_{read,write}() with SRCU
  (jsc#PED-348).
- commit 56dbbd7
* Wed Apr 16 2025 jgross@suse.com
- LoongArch: KVM: Protect kvm_check_requests() with SRCU
  (jsc#PED-348).
- commit 0a3d0d9
* Wed Apr 16 2025 jgross@suse.com
- KVM: s390: Increase size of union sca_utility to four bytes
  (jsc#PED-348).
- commit 64d89b3
* Wed Apr 16 2025 jgross@suse.com
- KVM: s390: Remove one byte cmpxchg() usage (jsc#PED-348).
- commit 59db533
* Wed Apr 16 2025 jgross@suse.com
- s390/asm: Helper macros for flag output operand handling
  (jsc#PED-348).
- commit f370957
* Wed Apr 16 2025 nik.borisov@suse.com
- x86/bugs: Use SBPB in write_ibpb() if applicable (git-fixes).
- commit b35b815
* Wed Apr 16 2025 jgross@suse.com
- s390/cmpxchg: Provide arch_try_cmpxchg() (jsc#PED-348).
- commit 7cfc4f9
* Wed Apr 16 2025 jgross@suse.com
- KVM: s390: Use try_cmpxchg() instead of cmpxchg() loops
  (jsc#PED-348).
- commit 7cac529
* Wed Apr 16 2025 nik.borisov@suse.com
- x86/bugs: Rename entry_ibpb() to write_ibpb() (git-fixes).
- commit 7709e9f
* Wed Apr 16 2025 jgross@suse.com
- arm64: Fix usage of new shifted MDCR_EL2 values (jsc#PED-348).
- commit 92356bc
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: Use MDCR_EL2.HPME to evaluate overflow of hyp
  counters (jsc#PED-348).
- commit 162887d
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: Mark set_sysreg_masks() as inline to avoid build
  failure (jsc#PED-348).
- commit 268b927
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: vgic-its: Add stronger type-checking to the ITS
  entry sizes (jsc#PED-348).
- commit 4cd8d38
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: vgic: Kill VGIC_MAX_PRIVATE definition
  (jsc#PED-348).
- commit 0b6d63c
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: vgic: Make vgic_get_irq() more robust (jsc#PED-348).
- commit 201dd08
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: switch hugepage recovery thread to vhost_task
  (jsc#PED-348).
- Refresh
  patches.suse/msft-hv-3141-hyperv-Clean-up-unnecessary-includes.patch.
- commit 45a316b
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: expose MSR_PLATFORM_INFO as a feature MSR
  (jsc#PED-348).
- commit 35b6eee
* Wed Apr 16 2025 jgross@suse.com
- x86: KVM: Advertise CPUIDs for new instructions in Clearwater
  Forest (jsc#PED-348).
- commit c3aa0c5
* Wed Apr 16 2025 jgross@suse.com
- s390/kvm: Convert to use flag output macros (jsc#PED-348).
- Refresh
  patches.suse/KVM-s390-add-concurrent-function-facility-to-cpu-model.patch.
- commit e5c65be
* Wed Apr 16 2025 jgross@suse.com
- LoongArch: KVM: Add irqfd support (jsc#PED-348).
- commit b40a03d
* Wed Apr 16 2025 jgross@suse.com
- LoongArch: KVM: Add PCHPIC user mode read and write functions
  (jsc#PED-348).
- commit 68a054f
* Wed Apr 16 2025 jgross@suse.com
- LoongArch: KVM: Add PCHPIC read and write functions
  (jsc#PED-348).
- commit 3c665e0
* Wed Apr 16 2025 jgross@suse.com
- LoongArch: KVM: Add PCHPIC device support (jsc#PED-348).
- commit f815008
* Wed Apr 16 2025 jgross@suse.com
- LoongArch: KVM: Add EIOINTC user mode read and write functions
  (jsc#PED-348).
- commit eb0dbd3
* Wed Apr 16 2025 jgross@suse.com
- LoongArch: KVM: Add EIOINTC read and write functions
  (jsc#PED-348).
- commit 8dc3259
* Wed Apr 16 2025 jgross@suse.com
- LoongArch: KVM: Add EIOINTC device support (jsc#PED-348).
- commit edb0a3f
* Wed Apr 16 2025 jgross@suse.com
- LoongArch: KVM: Add IPI user mode read and write function
  (jsc#PED-348).
- commit 36d79fb
* Wed Apr 16 2025 jgross@suse.com
- LoongArch: KVM: Add IPI read and write function (jsc#PED-348).
- commit 0131900
* Wed Apr 16 2025 jgross@suse.com
- LoongArch: KVM: Add IPI device support (jsc#PED-348).
- commit 854022c
* Wed Apr 16 2025 jgross@suse.com
- LoongArch: KVM: Add iocsr and mmio bus simulation in kernel
  (jsc#PED-348).
- commit 7b8524b
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: Pass on SVE mapping failures (jsc#PED-348).
- commit aa7cc11
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: vgic-its: Clear ITE when DISCARD frees an ITE
  (jsc#PED-348).
- commit dcc7422
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: vgic-its: Clear DTE when MAPD unmaps a device
  (jsc#PED-348).
- commit 35b98e1
* Wed Apr 16 2025 shung-hsi.yu@suse.com
- selftests/bpf: Adjust data size to have ETH_HLEN (bsc#1240181
  CVE-2025-21867).
- bpf, test_run: Fix use-after-free issue in eth_skb_pkt_type()
  (bsc#1240181 CVE-2025-21867).
- selftests/bpf: check program redirect in xdp_cpumap_attach
  (bsc#1240181 CVE-2025-21867).
- selftests/bpf: make xdp_cpumap_attach keep redirect prog
  attached (bsc#1240181 CVE-2025-21867).
- selftests/bpf: fix bpf_map_redirect call for cpu map test
  (bsc#1240181 CVE-2025-21867).
- selftests/bpf: Adjust data size to have ETH_HLEN (bsc#1240181
  CVE-2025-21867).
- bpf, test_run: Fix use-after-free issue in eth_skb_pkt_type()
  (bsc#1240181 CVE-2025-21867).
- selftests/bpf: check program redirect in xdp_cpumap_attach
  (bsc#1240181 CVE-2025-21867).
- selftests/bpf: make xdp_cpumap_attach keep redirect prog
  attached (bsc#1240181 CVE-2025-21867).
- selftests/bpf: fix bpf_map_redirect call for cpu map test
  (bsc#1240181 CVE-2025-21867).
- commit a4cc2a4
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: vgic-its: Add a data length check in vgic_its_save_*
  (jsc#PED-348).
- commit d51cc10
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: Make L1Ip feature in CTR_EL0 writable from userspace
  (jsc#PED-348).
- commit 03af8fa
* Wed Apr 16 2025 jgross@suse.com
- KVM: powerpc: remove remaining traces of KVM_CAP_PPC_RMA
  (jsc#PED-348).
- commit dfc6040
* Wed Apr 16 2025 jgross@suse.com
- x86/tdx: Enable CPU topology enumeration (jsc#PED-348).
- commit add304a
* Wed Apr 16 2025 jgross@suse.com
- x86/sev: Cleanup vc_handle_msr() (jsc#PED-348).
- commit 58e7dcc
* Wed Apr 16 2025 jgross@suse.com
- s390/kvm: Mask extra bits from program interrupt code
  (jsc#PED-348).
- commit ae18f46
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86/xen: Initialize hrtimer in kvm_xen_init_vcpu()
  (jsc#PED-348).
- commit a62436a
* Wed Apr 16 2025 jgross@suse.com
- riscv: kvm: Fix out-of-bounds array access (jsc#PED-348).
- commit 889deb8
* Wed Apr 16 2025 jgross@suse.com
- RISC-V: KVM: Fix APLIC in_clrip and clripnum write emulation
  (jsc#PED-348).
- commit 68b09dc
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Short-circuit all of kvm_apic_set_base() if MSR
  value is unchanged (jsc#PED-348).
- commit 3509130
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Unpack msr_data structure prior to calling
  kvm_apic_set_base() (jsc#PED-348).
- Refresh
  patches.suse/KVM-nVMX-Defer-SVI-update-to-vmcs01-on-EOI-when-L2-i-04bc93cf49d1.patch.
- commit 2e2dd13
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Make kvm_recalculate_apic_map() local to lapic.c
  (jsc#PED-348).
- commit f2d4992
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Rename APIC base setters to better capture their
  relationship (jsc#PED-348).
- Refresh
  patches.suse/KVM-nVMX-Defer-SVI-update-to-vmcs01-on-EOI-when-L2-i-04bc93cf49d1.patch.
- commit 01cbb78
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Move kvm_set_apic_base() implementation to lapic.c
  (from x86.c) (jsc#PED-348).
- commit d4905e6
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Inline kvm_get_apic_mode() in lapic.h (jsc#PED-348).
- Refresh
  patches.suse/KVM-nVMX-Defer-SVI-update-to-vmcs01-on-EOI-when-L2-i-04bc93cf49d1.patch.
- commit 9a4a16c
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Get vcpu->arch.apic_base directly and drop
  kvm_get_apic_base() (jsc#PED-348).
- commit 0360cf7
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Drop superfluous kvm_lapic_set_base() call when
  setting APIC state (jsc#PED-348).
- commit 29aec95
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Short-circuit all kvm_lapic_set_base() if MSR value
  isn't changing (jsc#PED-348).
- commit 5459e02
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86/mmu: Drop per-VM zapped_obsolete_pages list
  (jsc#PED-348).
- commit c7a188a
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86/mmu: Remove KVM's MMU shrinker (jsc#PED-348).
- commit bfb6ee0
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86/mmu: WARN if huge page recovery triggered during
  dirty logging (jsc#PED-348).
- commit 753cf9e
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86/mmu: Rename make_huge_page_split_spte() to
  make_small_spte() (jsc#PED-348).
- commit ac83548
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86/mmu: Recover TDP MMU huge page mappings in-place
  instead of zapping (jsc#PED-348).
- commit 004050f
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86/mmu: Refactor TDP MMU iter need resched check
  (jsc#PED-348).
- commit a6df396
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86/mmu: Demote the WARN on yielded in xxx_cond_resched()
  to KVM_MMU_WARN_ON (jsc#PED-348).
- commit f4b05f2
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86/mmu: Check yielded_gfn for forward progress iff
  resched is needed (jsc#PED-348).
- commit bdd5722
* Wed Apr 16 2025 jgross@suse.com
- assorted variants of irqfd setup: convert to CLASS(fd)
  (jsc#PED-348).
- commit f721c33
* Wed Apr 16 2025 jgross@suse.com
- fdget(), more trivial conversions (jsc#PED-348).
- commit 30e47bb
* Wed Apr 16 2025 jgross@suse.com
- fdget(), trivial conversions (jsc#PED-348).
- commit 2f28bfd
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Remove ordering check b/w MSR_PLATFORM_INFO and
  MISC_FEATURES_ENABLES (jsc#PED-348).
- commit 988d494
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Reject userspace attempts to access ARCH_CAPABILITIES
  w/o support (jsc#PED-348).
- commit 06e97ce
* Wed Apr 16 2025 jgross@suse.com
- KVM: VMX: Remove restriction that PMU version > 0 for
  PERF_CAPABILITIES (jsc#PED-348).
- commit dfd8959
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Reject userspace attempts to access PERF_CAPABILITIES
  w/o PDCM (jsc#PED-348).
- commit 06280a1
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Quirk initialization of feature MSRs to KVM's max
  configuration (jsc#PED-348).
- commit 995d691
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Disallow changing MSR_PLATFORM_INFO after vCPU has
  run (jsc#PED-348).
- commit 91f2e05
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Co-locate initialization of feature MSRs in
  kvm_arch_vcpu_create() (jsc#PED-348).
- commit 1844716
* Wed Apr 16 2025 jgross@suse.com
- KVM: nVMX: fix canonical check of vmcs12 HOST_RIP (jsc#PED-348).
- commit ff28b79
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: model canonical checks more precisely (jsc#PED-348).
- commit cad7c10
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Add X86EMUL_F_MSR and X86EMUL_F_DT_LOAD to aid
  canonical checks (jsc#PED-348).
- commit 89eefbe
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Route non-canonical checks in emulator through
  emulate_ops (jsc#PED-348).
- commit 32514ac
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: drop x86.h include from cpuid.h (jsc#PED-348).
- commit 92ed878
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Use '0' for guest RIP if PMI encounters protected
  guest state (jsc#PED-348).
- commit 233268f
* Wed Apr 16 2025 vbabka@suse.cz
- fs/proc/task_mmu: add guard region bit to pagemap
  (jsc#PED-11997).
- commit 1dbd453
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Add lockdep-guarded asserts on register cache usage
  (jsc#PED-348).
- commit 220a6e4
* Wed Apr 16 2025 vbabka@suse.cz
- mm: allow guard regions in file-backed and read-only mappings
  (jsc#PED-11997).
- commit 6e3700c
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Advertise AMD_IBPB_RET to userspace (jsc#PED-348).
- commit 36ee592
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Ensure vcpu->mode is loaded from memory in
  kvm_vcpu_exit_request() (jsc#PED-348).
- commit 8c2b6da
* Wed Apr 16 2025 jgross@suse.com
- KVM: x86: Fix a comment inside kvm_vcpu_update_apicv()
  (jsc#PED-348).
- commit 71218c5
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: nv: Reprogram PMU events affected by nested
  transition (jsc#PED-348).
- commit b92fc52
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: nv: Apply EL2 event filtering when in hyp context
  (jsc#PED-348).
- commit 100a2fa
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: nv: Honor MDCR_EL2.HLP (jsc#PED-348).
- commit 8baeb0f
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: nv: Honor MDCR_EL2.HPME (jsc#PED-348).
- commit 8f5ac10
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: Add helpers to determine if PMC counts at a given EL
  (jsc#PED-348).
- commit 3723d87
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: nv: Adjust range of accessible PMCs according to
  HPMN (jsc#PED-348).
- commit 0746fdf
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: Rename kvm_pmu_valid_counter_mask() (jsc#PED-348).
- commit 175c7bc
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: nv: Advertise support for FEAT_HPMN0 (jsc#PED-348).
- commit 51c1cf8
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: nv: Describe trap behaviour of MDCR_EL2.HPMN
  (jsc#PED-348).
- commit a7132a5
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: nv: Honor MDCR_EL2.{TPM, TPMCR} in Host EL0
  (jsc#PED-348).
- commit 3284e56
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: nv: Reinject traps that take effect in Host EL0
  (jsc#PED-348).
- commit 8342c68
* Wed Apr 16 2025 tiwai@suse.de
- accel/ivpu: Increase DMA address range (jsc#PED-12366).
- commit 40c638e
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: nv: Rename BEHAVE_FORWARD_ANY (jsc#PED-348).
- commit 2f590ae
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: nv: Allow coarse-grained trap combos to use complex
  traps (jsc#PED-348).
- commit 33415da
* Wed Apr 16 2025 jgross@suse.com
- arm64: sysreg: Add new definitions for ID_AA64DFR0_EL1
  (jsc#PED-348).
- commit d84a3cb
* Wed Apr 16 2025 jgross@suse.com
- arm64: sysreg: Describe ID_AA64DFR2_EL1 fields (jsc#PED-348).
- commit e2d4281
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: Describe RES0/RES1 bits of MDCR_EL2 (jsc#PED-348).
- commit 2ae3f33
* Wed Apr 16 2025 jgross@suse.com
- arm64: sysreg: Migrate MDCR_EL2 definition to table
  (jsc#PED-348).
- commit 3384192
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: Initialize trap register values in hyp in pKVM
  (jsc#PED-348).
- commit f99fff0
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: Initialize the hypervisor's VM state at EL2
  (jsc#PED-348).
- commit 95114e0
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: Refactor kvm_vcpu_enable_ptrauth() for hyp use
  (jsc#PED-348).
- commit 7187aea
* Wed Apr 16 2025 jgross@suse.com
- KVM: arm64: Move pkvm_vcpu_init_traps() to init_pkvm_hyp_vcpu()
  (jsc#PED-348).
- Refresh
  patches.suse/KVM-arm64-Get-rid-of-userspace_irqchip_in_use.patch.
- commit 2076e77
* Wed Apr 16 2025 mgorman@suse.de
- rpm/package-descriptions: Add rt and rt_debug descriptions
- commit 09573c0
* Tue Apr 15 2025 trenn@suse.de
- tools/power turbostat: Increase CPU_SUBSET_MAXCPUS to 8192
  (bsc#1241175).
- commit 0ef38a2
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Disable MPAM visibility by default and ignore VMM
  writes (jsc#PED-348).
- commit e3beeb3
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Add a macro for creating filtered sys_reg_descs
  entries (jsc#PED-348).
- commit 84c72db
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Fix missing traps of guest accesses to the MPAM
  registers (jsc#PED-348).
- commit e04fac3
* Tue Apr 15 2025 jgross@suse.com
- arm64/sysreg: Convert existing MPAM sysregs and add the
  remaining entries (jsc#PED-348).
- commit fc877ac
* Tue Apr 15 2025 jgross@suse.com
- arm64: cpufeature: discover CPU support for MPAM (jsc#PED-348).
- Refresh
  patches.suse/arm64-sme-Move-storage-of-reg_smidr-to-__cpuinfo_store_cpu.patch.
- commit 4273e38
* Tue Apr 15 2025 jgross@suse.com
- s390/kvm: Initialize uninitialized flags variable (jsc#PED-348).
- commit bd0573c
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Handle WXN attribute (jsc#PED-348).
- commit 9517663
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Handle stage-1 permission overlays (jsc#PED-348).
- commit f65766f
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Make PAN conditions part of the S1 walk context
  (jsc#PED-348).
- commit c70d3fb
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Disable hierarchical permissions when POE is enabled
  (jsc#PED-348).
- commit dcfbd15
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Add POE save/restore for AT emulation fast-path
  (jsc#PED-348).
- commit 89f6f7b
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Add save/restore support for POR_EL2 (jsc#PED-348).
- commit 4e2e599
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Add basic support for POR_EL2 (jsc#PED-348).
- commit 54dfec0
* Tue Apr 15 2025 jgross@suse.com
- arm64: Add encoding for POR_EL2 (jsc#PED-348).
- commit 9267b41
* Tue Apr 15 2025 vbabka@suse.cz
- mm: fix kernel BUG when userfaultfd_move encounters swapcache
  (CVE-2025-21984 bsc#1240793).
- commit 8567e65
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Add kvm_has_s1poe() helper (jsc#PED-348).
- commit da6756a
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Subject S1PIE/S1POE registers to HCR_EL2.{TVM,TRVM}
  (jsc#PED-348).
- commit 1d7e9b8
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Drop bogus CPTR_EL2.E0POE trap routing
  (jsc#PED-348).
- commit 9eac74b
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Rely on visibility to let PIR*_ELx/TCR2_ELx UNDEF
  (jsc#PED-348).
- commit 694ef1d
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Hide S1PIE registers from userspace when disabled
  for guests (jsc#PED-348).
- commit 2dec159
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Hide TCR2_EL1 from userspace when disabled for
  guests (jsc#PED-348).
- commit f97c2f8
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Define helper for EL2 registers with custom
  visibility (jsc#PED-348).
- commit 3d235f5
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Add a composite EL2 visibility helper (jsc#PED-348).
- commit f47be3b
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Implement AT S1PIE support (jsc#PED-348).
- commit 820b016
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Disable hierarchical permissions when S1PIE is
  enabled (jsc#PED-348).
- commit e14aa8f
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Split S1 permission evaluation into direct and
  hierarchical parts (jsc#PED-348).
- commit f4fb624
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Add AT fast-path support for S1PIE (jsc#PED-348).
- commit 1a3afec
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Handle PIR{,E0}_EL2 traps (jsc#PED-348).
- commit e7ff115
* Tue Apr 15 2025 jgross@suse.com
- arm64: Add encoding for PIRE0_EL2 (jsc#PED-348).
- commit 83735b4
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Add save/restore for PIR{,E0}_EL2 (jsc#PED-348).
- commit 20ffc77
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Add PIR{,E0}_EL2 to the sysreg arrays (jsc#PED-348).
- commit 88c8532
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Add save/restore for TCR2_EL2 (jsc#PED-348).
- commit ff41ff0
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Sanitise TCR2_EL2 (jsc#PED-348).
- commit f3d1cd4
* Tue Apr 15 2025 oneukum@suse.com
- usb: core: Don't use %%pK through printk (jsc#PED-10906).
- commit 451ccc3
* Tue Apr 15 2025 jgross@suse.com
- arm64/sysreg: Update ID_AA64MMFR1_EL1 register (jsc#PED-348).
- commit 9e3de0a
* Tue Apr 15 2025 oneukum@suse.com
- usb: core: replace usb_sndaddr0pipe macro with usb_sndctrlpipe
  (jsc#PED-10906).
- commit d5e9e32
* Tue Apr 15 2025 oneukum@suse.com
- USB: core: Add eUSB2 descriptor and parsing in USB core
  (jsc#PED-10906).
- commit 9bca1b9
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: nv: Save/Restore vEL2 sysregs (jsc#PED-348).
- commit f6a4e31
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Add TCR2_EL2 to the sysreg arrays (jsc#PED-348).
- commit 451336d
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Extend masking facility to arbitrary registers
  (jsc#PED-348).
- commit b513a82
* Tue Apr 15 2025 oneukum@suse.com
- usb: hcd: Bump local buffer size in rh_string() (jsc#PED-10906).
- commit 68d4f73
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: nv: Handle CNTHCTL_EL2 specially (jsc#PED-348).
- commit 6e65067
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: nv: Add missing EL2->EL1 mappings in
  get_el2_to_el1_mapping() (jsc#PED-348).
- commit 12505d9
* Tue Apr 15 2025 davide.benini@suse.com
- net: atm: fix use after free in lec_send() (CVE-2025-22004
  bsc#1240835).
- commit adce8b1
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Drop useless struct s2_mmu in __kvm_at_s1e2()
  (jsc#PED-348).
- commit fc823e4
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Batch TLB flushes when zapping collapsible TDP
  MMU SPTEs (jsc#PED-348).
- commit de109d1
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Drop @max_level from kvm_mmu_max_mapping_level()
  (jsc#PED-348).
- commit dd47125
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86: Don't emit TLB flushes when aging SPTEs for
  mmu_notifiers (jsc#PED-348).
- Refresh
  patches.suse/KVM-x86-Break-CONFIG_KVM_X86-s-direct-dependency-on-.patch.
- Refresh
  patches.suse/KVM-x86-add-back-X86_LOCAL_APIC-dependency.patch.
- commit ae06851
* Tue Apr 15 2025 jgross@suse.com
- KVM: Allow arch code to elide TLB flushes when aging a young
  page (jsc#PED-348).
- commit 7716eab
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Set Dirty bit for new SPTEs, even if _hardware_
  A/D bits are disabled (jsc#PED-348).
- commit e1874d2
* Tue Apr 15 2025 oneukum@suse.com
- usb: typec: tcpm: Switch to use hrtimer_setup() (jsc#PED-10906).
- commit 6f682e4
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Dedup logic for detecting TLB flushes on leaf
  SPTE changes (jsc#PED-348).
- commit e07246c
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Stop processing TDP MMU roots for test_age if
  young SPTE found (jsc#PED-348).
- commit 27f92c8
* Tue Apr 15 2025 oneukum@suse.com
- usb: typec: ucsi: Enable UCSI commands in debugfs
  (jsc#PED-10906).
- commit c833f26
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Process only valid TDP MMU roots when aging a
  gfn range (jsc#PED-348).
- commit 943dc36
* Tue Apr 15 2025 oneukum@suse.com
- usb: typec: ucsi: Rename SET_UOM UCSI command to SET_CCOM
  (jsc#PED-10906).
- commit ab708c6
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Use Accessed bit even when _hardware_ A/D bits
  are disabled (jsc#PED-348).
- commit cfcfab1
* Tue Apr 15 2025 oneukum@suse.com
- usb: typec: ucsi: Add a macro definition for UCSI v1.0
  (jsc#PED-10906).
- commit 39299cc
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Set shadow_dirty_mask for EPT even if A/D bits
  disabled (jsc#PED-348).
- commit b2bf96d
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Set shadow_accessed_mask for EPT even if A/D
  bits disabled (jsc#PED-348).
- commit 566d28e
* Tue Apr 15 2025 oneukum@suse.com
- USB: typec: Use str_enable_disable-like helpers (jsc#PED-10906).
- commit 120ce5f
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Add a dedicated flag to track if A/D bits are
  globally enabled (jsc#PED-348).
- commit 3d2e74a
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: WARN and flush if resolving a TDP MMU fault
  clears MMU-writable (jsc#PED-348).
- commit 48ca2b6
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Fold mmu_spte_update_no_track() into
  mmu_spte_update() (jsc#PED-348).
- commit 75b98ac
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Drop ignored return value from
  kvm_tdp_mmu_clear_dirty_slot() (jsc#PED-348).
- commit a673add
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Don't flush TLBs when clearing Dirty bit in
  shadow MMU (jsc#PED-348).
- commit 5534036
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Don't force flush if SPTE update clears Accessed
  bit (jsc#PED-348).
- commit b286e77
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Fold all of make_spte()'s writable handling into
  one if-else (jsc#PED-348).
- commit af747d2
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Always set SPTE's dirty bit if it's created as
  writable (jsc#PED-348).
- commit c950df4
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Flush remote TLBs iff MMU-writable flag is
  cleared from RO SPTE (jsc#PED-348).
- commit d8a996f
* Tue Apr 15 2025 jgross@suse.com
- KVM: Protect vCPU's "last run PID" with rwlock, not RCU
  (jsc#PED-348).
- commit 33d08b8
* Tue Apr 15 2025 jgross@suse.com
- KVM: Return '0' directly when there's no task to yield to
  (jsc#PED-348).
- commit 61738c0
* Tue Apr 15 2025 jgross@suse.com
- KVM: Rework core loop of kvm_vcpu_on_spin() to use a single
  for-loop (jsc#PED-348).
- commit f053a79
* Tue Apr 15 2025 jgross@suse.com
- kvm/vfio: Constify struct kvm_device_ops (jsc#PED-348).
- commit d80fea1
* Tue Apr 15 2025 jgross@suse.com
- KVM: VMX: Remove the unused variable "gpa" in __invept()
  (jsc#PED-348).
- commit 7ec63c5
* Tue Apr 15 2025 jgross@suse.com
- s390/kvm: Stop using gmap_{en,dis}able() (jsc#PED-348).
- commit ad5699e
* Tue Apr 15 2025 jgross@suse.com
- s390/mm/fault: Handle guest-related program interrupts in KVM
  (jsc#PED-348).
- commit 6f895c5
* Tue Apr 15 2025 oneukum@suse.com
- usb: typec: ucsi: make yoga_c630_ucsi_ops be static (git-fixes).
- Refresh
  patches.suse/acpi-typec-ucsi-Introduce-a-poll_cci-method.patch.
- commit 1fd8834
* Tue Apr 15 2025 jgross@suse.com
- s390/entry: Remove __GMAP_ASCE and use _PIF_GUEST_FAULT again
  (jsc#PED-348).
- commit 9fb399c
* Tue Apr 15 2025 pfalcato@suse.de
- ipv6: Fix memleak of nhc_pcpu_rth_output in fib_check_nh_v6_gw()
  (CVE-2025-22005 bsc#1240866).
- commit 55ba3fc
* Tue Apr 15 2025 pfalcato@suse.de
- sched: address a potential NULL pointer dereference in the
  GRED scheduler (CVE-2025-21980 bsc#1240809).
- commit 6b4ede1
* Tue Apr 15 2025 pfalcato@suse.de
- llc: do not use skb_get() before dev_queue_xmit()
  (CVE-2025-21925 bsc#1240713).
- commit bda383b
* Tue Apr 15 2025 pfalcato@suse.de
- net: gso: fix ownership in __udp_gso_segment (CVE-2025-21926
  bsc#1240712).
- commit b665cba
* Tue Apr 15 2025 jgross@suse.com
- s390/kvm: Remove kvm_arch_fault_in_page() (jsc#PED-348).
- commit 3095779
* Tue Apr 15 2025 jgross@suse.com
- x86/sev: Convert shared memory back to private on kexec
  (jsc#PED-348).
- commit 0647d96
* Tue Apr 15 2025 jgross@suse.com
- x86/mm: Refactor __set_clr_pte_enc() (jsc#PED-348).
- commit ea457a5
* Tue Apr 15 2025 jgross@suse.com
- RISC-V: KVM: Use NACL HFENCEs for KVM request based HFENCEs
  (jsc#PED-348).
- commit d360325
* Tue Apr 15 2025 jgross@suse.com
- RISC-V: KVM: Save trap CSRs in kvm_riscv_vcpu_enter_exit()
  (jsc#PED-348).
- commit e8697fa
* Tue Apr 15 2025 jgross@suse.com
- RISC-V: KVM: Use SBI sync SRET call when available
  (jsc#PED-348).
- commit 3da5307
* Tue Apr 15 2025 jgross@suse.com
- RISC-V: KVM: Use nacl_csr_xyz() for accessing AIA CSRs
  (jsc#PED-348).
- commit 82bdae7
* Tue Apr 15 2025 jgross@suse.com
- RISC-V: KVM: Use nacl_csr_xyz() for accessing H-extension CSRs
  (jsc#PED-348).
- commit 6970419
* Tue Apr 15 2025 jgross@suse.com
- RISC-V: KVM: Add common nested acceleration support
  (jsc#PED-348).
- commit d82db7c
* Tue Apr 15 2025 jgross@suse.com
- RISC-V: KVM: Don't setup SGEI for zero guest external interrupts
  (jsc#PED-348).
- commit b1f1f2e
* Tue Apr 15 2025 jgross@suse.com
- RISC-V: KVM: Replace aia_set_hvictl() with aia_hvictl_value()
  (jsc#PED-348).
- commit 7003072
* Tue Apr 15 2025 jgross@suse.com
- RISC-V: KVM: Break down the __kvm_riscv_switch_to() into macros
  (jsc#PED-348).
- commit b08f02a
* Tue Apr 15 2025 jgross@suse.com
- RISC-V: KVM: Save/restore SCOUNTEREN in C source (jsc#PED-348).
- commit fe6d178
* Tue Apr 15 2025 jgross@suse.com
- RISC-V: KVM: Save/restore HSTATUS in C source (jsc#PED-348).
- commit c7799a4
* Tue Apr 15 2025 jgross@suse.com
- RISC-V: KVM: Order the object files alphabetically
  (jsc#PED-348).
- commit 559c6a4
* Tue Apr 15 2025 jgross@suse.com
- riscv: KVM: add basic support for host vs guest profiling
  (jsc#PED-348).
- commit 6ab0369
* Tue Apr 15 2025 jgross@suse.com
- KVM: Don't grab reference on VM_MIXEDMAP pfns that have a
  "struct page" (jsc#PED-348).
- commit 35de075
* Tue Apr 15 2025 jgross@suse.com
- KVM: Drop APIs that manipulate "struct page" via pfns
  (jsc#PED-348).
- commit 609bbfb
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Don't mark "struct page" accessed when making SPTE
  young (jsc#PED-348).
- commit 9484013
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Don't mark "struct page" accessed when zapping
  SPTEs (jsc#PED-348).
- commit cc2a92b
* Tue Apr 15 2025 jgross@suse.com
- KVM: Make kvm_follow_pfn.refcounted_page a required field
  (jsc#PED-348).
- commit 169d6a4
* Tue Apr 15 2025 jgross@suse.com
- KVM: s390: Use kvm_release_page_dirty() to unpin "struct page"
  memory (jsc#PED-348).
- commit 18e2728
* Tue Apr 15 2025 jgross@suse.com
- KVM: Drop gfn_to_pfn() APIs now that all users are gone
  (jsc#PED-348).
- commit 5338a4f
* Tue Apr 15 2025 jgross@suse.com
- KVM: PPC: Explicitly require struct page memory for Ultravisor
  sharing (jsc#PED-348).
- commit 21ddf5e
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Use __gfn_to_page() when copying MTE tags to/from
  userspace (jsc#PED-348).
- commit 3eaa98c
* Tue Apr 15 2025 jgross@suse.com
- KVM: Add support for read-only usage of gfn_to_page()
  (jsc#PED-348).
- commit 9d01822
* Tue Apr 15 2025 jgross@suse.com
- KVM: Convert gfn_to_page() to use kvm_follow_pfn()
  (jsc#PED-348).
- commit 9029bc7
* Tue Apr 15 2025 jgross@suse.com
- KVM: PPC: Use kvm_vcpu_map() to map guest memory to patch dcbz
  instructions (jsc#PED-348).
- commit bd2622b
* Tue Apr 15 2025 jgross@suse.com
- KVM: PPC: Remove extra get_page() to fix page refcount leak
  (jsc#PED-348).
- commit 8e1492f
* Tue Apr 15 2025 jgross@suse.com
- KVM: MIPS: Use kvm_faultin_pfn() to map pfns into the guest
  (jsc#PED-348).
- commit 518e429
* Tue Apr 15 2025 jgross@suse.com
- KVM: MIPS: Mark "struct page" pfns accessed prior to dropping
  mmu_lock (jsc#PED-348).
- commit ddd3591
* Tue Apr 15 2025 jgross@suse.com
- KVM: MIPS: Mark "struct page" pfns accessed only in "slow"
  page fault path (jsc#PED-348).
- commit 297d0d2
* Tue Apr 15 2025 jgross@suse.com
- KVM: MIPS: Mark "struct page" pfns dirty only in "slow" page
  fault path (jsc#PED-348).
- commit c07fb69
* Tue Apr 15 2025 jgross@suse.com
- KVM: LoongArch: Use kvm_faultin_pfn() to map pfns into the guest
  (jsc#PED-348).
- commit b0ce30a
* Tue Apr 15 2025 jgross@suse.com
- KVM: LoongArch: Mark "struct page" pfn accessed before dropping
  mmu_lock (jsc#PED-348).
- commit 19db987
* Tue Apr 15 2025 jgross@suse.com
- KVM: LoongArch: Mark "struct page" pfns accessed only in "slow"
  page fault path (jsc#PED-348).
- commit f4eecd8
* Tue Apr 15 2025 jgross@suse.com
- KVM: LoongArch: Mark "struct page" pfns dirty only in "slow"
  page fault path (jsc#PED-348).
- commit e66b533
* Tue Apr 15 2025 jgross@suse.com
- KVM: PPC: Use kvm_faultin_pfn() to handle page faults on Book3s
  PR (jsc#PED-348).
- commit 7939351
* Tue Apr 15 2025 jgross@suse.com
- KVM: PPC: Book3S: Mark "struct page" pfns dirty/accessed after
  installing PTE (jsc#PED-348).
- commit aa1dde6
* Tue Apr 15 2025 jgross@suse.com
- KVM: PPC: Drop unused @kvm_ro param from
  kvmppc_book3s_instantiate_page() (jsc#PED-348).
- commit cc34550
* Tue Apr 15 2025 jgross@suse.com
- KVM: PPC: Use __kvm_faultin_pfn() to handle page faults on
  Book3s Radix (jsc#PED-348).
- commit 0e15d53
* Tue Apr 15 2025 jgross@suse.com
- KVM: PPC: Use __kvm_faultin_pfn() to handle page faults on
  Book3s HV (jsc#PED-348).
- commit f67a3b8
* Tue Apr 15 2025 jgross@suse.com
- KVM: RISC-V: Use kvm_faultin_pfn() when mapping pfns into the
  guest (jsc#PED-348).
- commit 9d03d10
* Tue Apr 15 2025 jgross@suse.com
- KVM: RISC-V: Mark "struct page" pfns accessed before dropping
  mmu_lock (jsc#PED-348).
- commit 7c80cea
* Tue Apr 15 2025 jgross@suse.com
- KVM: RISC-V: Mark "struct page" pfns dirty iff a stage-2 PTE
  is installed (jsc#PED-348).
- commit 9552f6c
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Use __kvm_faultin_pfn() to handle memory aborts
  (jsc#PED-348).
- commit fa597ff
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Mark "struct page" pfns accessed/dirty before
  dropping mmu_lock (jsc#PED-348).
- commit a4270e1
* Tue Apr 15 2025 jgross@suse.com
- KVM: PPC: e500: Use __kvm_faultin_pfn() to handle page faults
  (jsc#PED-348).
- commit 6be6f59
* Tue Apr 15 2025 jgross@suse.com
- KVM: PPC: e500: Mark "struct page" pfn accessed before dropping
  mmu_lock (jsc#PED-348).
- commit 5546e1c
* Tue Apr 15 2025 jgross@suse.com
- KVM: PPC: e500: Mark "struct page" dirty in
  kvmppc_e500_shadow_map() (jsc#PED-348).
- commit 160e7cb
* Tue Apr 15 2025 jgross@suse.com
- KVM: VMX: Use __kvm_faultin_page() to get APIC access page/pfn
  (jsc#PED-348).
- commit 61408ef
* Tue Apr 15 2025 jgross@suse.com
- KVM: VMX: Hold mmu_lock until page is released when updating
  APIC access page (jsc#PED-348).
- Refresh
  patches.suse/KVM-x86-Plumb-in-the-vCPU-to-kvm_x86_ops.hwapic_isr_.patch.
- commit e97d169
* Tue Apr 15 2025 jgross@suse.com
- KVM: Move x86's API to release a faultin page to common KVM
  (jsc#PED-348).
- commit 035d4ba
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Don't mark unused faultin pages as accessed
  (jsc#PED-348).
- commit e82b47f
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Put refcounted pages instead of blindly releasing
  pfns (jsc#PED-348).
- commit 6c6ce8a
* Tue Apr 15 2025 jgross@suse.com
- KVM: guest_memfd: Provide "struct page" as output from
  kvm_gmem_get_pfn() (jsc#PED-348).
- commit feb8cad
* Tue Apr 15 2025 jgross@suse.com
- KVM: guest_memfd: Pass index, not gfn, to __kvm_gmem_get_pfn()
  (jsc#PED-348).
- commit bd6cf4e
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Convert page fault paths to kvm_faultin_pfn()
  (jsc#PED-348).
- commit 6ea159b
* Tue Apr 15 2025 jgross@suse.com
- KVM: Add kvm_faultin_pfn() to specifically service guest page
  faults (jsc#PED-348).
- commit 6ea3a1f
* Tue Apr 15 2025 jgross@suse.com
- KVM: Move declarations of memslot accessors up in kvm_host.h
  (jsc#PED-348).
- commit 346a8cc
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Mark pages/folios dirty at the origin of
  make_spte() (jsc#PED-348).
- commit b50aad2
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Add helper to "finish" handling a guest page fault
  (jsc#PED-348).
- commit 25e2704
* Tue Apr 15 2025 oneukum@suse.com
- usb: typec: Only use SVID for matching altmodes (jsc#PED-10906).
- commit 61e9ea2
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Add common helper to handle prefetching SPTEs
  (jsc#PED-348).
- commit cf1410f
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Put direct prefetched pages via
  kvm_release_page_clean() (jsc#PED-348).
- commit 7ec071e
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Add "mmu" prefix fault-in helpers to free up
  generic names (jsc#PED-348).
- commit 2a00967
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86: Don't fault-in APIC access page during initial
  allocation (jsc#PED-348).
- commit 78f29d5
* Tue Apr 15 2025 jgross@suse.com
- KVM: Disallow direct access (w/o mmu_notifier) to unpinned
  pfn by default (jsc#PED-348).
- commit f85530d
* Tue Apr 15 2025 jgross@suse.com
- KVM: Get writable mapping for __kvm_vcpu_map() only when
  necessary (jsc#PED-348).
- commit f777357
* Tue Apr 15 2025 jgross@suse.com
- KVM: Pass in write/dirty to kvm_vcpu_map(), not kvm_vcpu_unmap()
  (jsc#PED-348).
- commit 883428f
* Tue Apr 15 2025 oneukum@suse.com
- modpost: rename variables in handle_moddevtable()
  (jsc#PED-10906).
- commit aba5386
* Tue Apr 15 2025 jgross@suse.com
- KVM: nVMX: Mark vmcs12's APIC access page dirty when unmapping
  (jsc#PED-348).
- commit 6e89a6c
* Tue Apr 15 2025 jgross@suse.com
- KVM: Pin (as in FOLL_PIN) pages during kvm_vcpu_map()
  (jsc#PED-348).
- commit 16f3b31
* Tue Apr 15 2025 oneukum@suse.com
- modpost: move strstarts() to modpost.h (jsc#PED-10906).
- Refresh patches.suse/kbuild-modpost-integrate-klp-convert.patch.
- commit a756d33
* Tue Apr 15 2025 jgross@suse.com
- KVM: Migrate kvm_vcpu_map() to kvm_follow_pfn() (jsc#PED-348).
- commit d7f465b
* Tue Apr 15 2025 oneukum@suse.com
- modpost: convert do_usb_table() to a generic handler
  (git-fixes).
- commit ecc46de
* Tue Apr 15 2025 jgross@suse.com
- KVM: pfncache: Precisely track refcounted pages (jsc#PED-348).
- commit 0aff3f5
* Tue Apr 15 2025 oneukum@suse.com
- modpost: convert do_of_table() to a generic handler
  (jsc#PED-10906).
- commit d8f945d
* Tue Apr 15 2025 jgross@suse.com
- KVM: Add kvm_release_page_unused() API to put pages that KVM
  never consumes (jsc#PED-348).
- commit f3f2577
* Tue Apr 15 2025 oneukum@suse.com
- modpost: convert do_pnp_device_entry() to a generic handler
  (jsc#PED-10906).
- commit af13ab1
* Tue Apr 15 2025 oneukum@suse.com
- modpost: convert do_pnp_card_entries() to a generic handler
  (jsc#PED-10906).
- commit f180a34
* Tue Apr 15 2025 oneukum@suse.com
- modpost: call module_alias_printf() from all do_*_entry()
  functions (jsc#PED-10906).
- commit e34cda7
* Tue Apr 15 2025 oneukum@suse.com
- modpost: pass (struct module *) to do_*_entry() functions
  (jsc#PED-10906).
- commit cc012bd
* Tue Apr 15 2025 jgross@suse.com
- KVM: Move kvm_{set,release}_page_{clean,dirty}() helpers up
  in kvm_main.c (jsc#PED-348).
- commit 83af984
* Tue Apr 15 2025 oneukum@suse.com
- modpost: remove DEF_FIELD_ADDR_VAR() macro (jsc#PED-10906).
- commit 90a6f96
* Tue Apr 15 2025 jgross@suse.com
- KVM: Provide refcounted page as output field in struct
  kvm_follow_pfn (jsc#PED-348).
- commit 20e080e
* Tue Apr 15 2025 oneukum@suse.com
- modpost: deduplicate MODULE_ALIAS() for all drivers
  (jsc#PED-10906).
- commit 76f77e7
* Tue Apr 15 2025 jgross@suse.com
- KVM: Use plain "struct page" pointer instead of single-entry
  array (jsc#PED-348).
- commit 9282fe8
* Tue Apr 15 2025 jgross@suse.com
- KVM: nVMX: Add helper to put (unmap) vmcs12 pages (jsc#PED-348).
- commit b7b598e
* Tue Apr 15 2025 oneukum@suse.com
- modpost: introduce module_alias_printf() helper (jsc#PED-10906).
- Refresh patches.suse/add-suse-supported-flag.patch.
- Refresh
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch.
- commit 272330b
* Tue Apr 15 2025 jgross@suse.com
- KVM: nVMX: Drop pointless msr_bitmap_map field from struct
  nested_vmx (jsc#PED-348).
- commit d39c536
* Tue Apr 15 2025 oneukum@suse.com
- modpost: remove unnecessary check in do_acpi_entry()
  (jsc#PED-10906).
- commit a88bac3
* Tue Apr 15 2025 jgross@suse.com
- KVM: nVMX: Rely on kvm_vcpu_unmap() to track validity of eVMCS
  mapping (jsc#PED-348).
- commit 4f03277
* Tue Apr 15 2025 jgross@suse.com
- KVM: Use NULL for struct page pointer to indicate mremapped
  memory (jsc#PED-348).
- commit 8ec4686
* Tue Apr 15 2025 jgross@suse.com
- KVM: Explicitly initialize all fields at the start of
  kvm_vcpu_map() (jsc#PED-348).
- commit 0ee9c47
* Tue Apr 15 2025 jgross@suse.com
- KVM: Remove pointless sanity check on @map param to
  kvm_vcpu_(un)map() (jsc#PED-348).
- commit c5f3ebd
* Tue Apr 15 2025 jgross@suse.com
- KVM: Introduce kvm_follow_pfn() to eventually replace
  "gfn_to_pfn" APIs (jsc#PED-348).
- commit f0c102d
* Tue Apr 15 2025 jgross@suse.com
- KVM: Drop unused "hva" pointer from __gfn_to_pfn_memslot()
  (jsc#PED-348).
- commit fc13047
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Drop kvm_page_fault.hva, i.e. don't track
  intermediate hva (jsc#PED-348).
- commit a75fb71
* Tue Apr 15 2025 jgross@suse.com
- KVM: Replace "async" pointer in gfn=>pfn with "no_wait" and
  error code (jsc#PED-348).
- commit 267c432
* Tue Apr 15 2025 jgross@suse.com
- KVM: Drop extra GUP (via check_user_page_hwpoison()) to detect
  poisoned page (jsc#PED-348).
- commit 17f0d93
* Tue Apr 15 2025 jgross@suse.com
- KVM: Return ERR_SIGPENDING from hva_to_pfn() if GUP returns
  - EGAIN (jsc#PED-348).
- commit 3b658f3
* Tue Apr 15 2025 jgross@suse.com
- KVM: Annotate that all paths in hva_to_pfn() might sleep
  (jsc#PED-348).
- commit edfdc02
* Tue Apr 15 2025 jgross@suse.com
- KVM: Drop @atomic param from gfn=>pfn and hva=>pfn APIs
  (jsc#PED-348).
- commit 8f753c1
* Tue Apr 15 2025 jgross@suse.com
- KVM: Rename gfn_to_page_many_atomic() to kvm_prefetch_pages()
  (jsc#PED-348).
- commit da09c4e
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Use gfn_to_page_many_atomic() when prefetching
  indirect PTEs (jsc#PED-348).
- commit a2ea2a7
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Mark page/folio accessed only when zapping leaf
  SPTEs (jsc#PED-348).
- commit 7d8ddfe
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Mark folio dirty when creating SPTE, not when
  zapping/modifying (jsc#PED-348).
- commit 93e9c16
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Mark new SPTE as Accessed when synchronizing
  existing SPTE (jsc#PED-348).
- commit 0710a89
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Invert @can_unsync and renamed to @synchronizing
  (jsc#PED-348).
- commit 2af317d
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Don't overwrite shadow-present MMU SPTEs when
  prefaulting (jsc#PED-348).
- commit cf029e8
* Tue Apr 15 2025 jgross@suse.com
- KVM: x86/mmu: Skip the "try unsync" path iff the old SPTE was
  a leaf SPTE (jsc#PED-348).
- commit 8176a7a
* Tue Apr 15 2025 jgross@suse.com
- KVM: Allow calling kvm_release_page_{clean,dirty}() on a NULL
  page pointer (jsc#PED-348).
- commit dae8f22
* Tue Apr 15 2025 jgross@suse.com
- KVM: Drop KVM_ERR_PTR_BAD_PAGE and instead return NULL to
  indicate an error (jsc#PED-348).
- commit 7c4b876
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: nvhe: Pass through PSCI v1.3 SYSTEM_OFF2 call
  (jsc#PED-348).
- commit 932dd19
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Add support for PSCI v1.2 and v1.3 (jsc#PED-348).
- commit f451559
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Add PSCI v1.3 SYSTEM_OFF2 function for hibernation
  (jsc#PED-348).
- commit 6c5d08c
* Tue Apr 15 2025 jgross@suse.com
- firmware/psci: Add definitions for PSCI v1.3 specification
  (jsc#PED-348).
- commit d3ca0ff
* Tue Apr 15 2025 nmorey@suse.com
- RDMA/bnxt_re: Remove unusable nq variable (git-fixes)
- commit 047a720
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Don't map 'kvm_vgic_global_state' at EL2 with pKVM
  (jsc#PED-348).
- commit b6ff591
* Tue Apr 15 2025 jgross@suse.com
- KVM: arm64: Just advertise SEIS as 0 when emulating ICC_CTLR_EL1
  (jsc#PED-348).
- commit fa5285c
* Tue Apr 15 2025 shung-hsi.yu@suse.com
- selftest/bpf: Add vsock test for sockmap rejecting unconnected
  (bsc#1239470 CVE-2025-21854).
- commit 6e36f6b
* Tue Apr 15 2025 shung-hsi.yu@suse.com
- selftest/bpf: Adapt vsock_delete_on_close to sockmap rejecting
  unconnected (bsc#1239470 CVE-2025-21854).
- sockmap, vsock: For connectible sockets allow only connected
  (bsc#1239470 CVE-2025-21854).
- selftest/bpf: Add test for vsock removal from sockmap on close()
  (bsc#1239470 CVE-2025-21854).
- selftest/bpf: Add test for af_vsock poll() (bsc#1239470
  CVE-2025-21854).
- commit 750fb4b
* Tue Apr 15 2025 nmorey@suse.com
- RDMA/core: Silence oversized kvmalloc() warning (git-fixes)
- commit b40a0b3
* Tue Apr 15 2025 nmorey@suse.com
- RDMA/cma: Fix workqueue crash in cma_netevent_work_handler (git-fixes)
- commit 1195add
* Tue Apr 15 2025 nmorey@suse.com
- RDMA/hns: Fix wrong maximum DMA segment size (git-fixes)
- commit 10442e4
* Tue Apr 15 2025 nmorey@suse.com
- RDMA/usnic: Fix passing zero to PTR_ERR in usnic_ib_pci_probe() (git-fixes)
- commit a0ae514
* Tue Apr 15 2025 nmorey@suse.com
- RDMA/bnxt_re: Fix budget handling of notification queue (git-fixes)
- commit 4f16ca1
* Tue Apr 15 2025 shung-hsi.yu@suse.com
- selftests/net: Add test for loading devbound XDP program in
  generic mode (bsc#1238742 CVE-2025-21808).
- net: xdp: Disallow attaching device-bound programs in generic
  mode (bsc#1238742 CVE-2025-21808).
- commit 461e3db
* Tue Apr 15 2025 glass.su@suse.com
- Update
  patches.suse/md-md-bitmap-fix-wrong-bitmap_limit-for-clustermd-wh.patch
  (bsc#1238212).
- commit 43028e5
* Mon Apr 14 2025 dsterba@suse.com
- bpf: Fix deadlock when freeing cgroup storage (CVE-2024-58088 bsc#1239510)
- commit 16371d9
* Mon Apr 14 2025 dsterba@suse.com
- dpll: fix xa_alloc_cyclic() error handling (CVE-2025-22016 bsc#1240934)
- commit cc084a2
* Mon Apr 14 2025 dsterba@suse.com
- devlink: fix xa_alloc_cyclic() error handling (CVE-2025-22017 bsc#1240936)
- commit 768ef0a
* Mon Apr 14 2025 farosas@suse.de
- caif_virtio: fix wrong pointer check in cfv_probe()
  (CVE-2025-21904 bsc#1240576).
- commit 3c0bb89
* Mon Apr 14 2025 cfamullaconrad@suse.de
- tools/power turbostat: report CoreThr per measurement interval
  (git-fixes).
- commit f32d7c3
* Mon Apr 14 2025 mkoutny@suse.com
- cgroup/cpuset: Fix error handling in remote_partition_disable()
  (bsc#1241166).
- cgroup/cpuset: Fix incorrect isolated_cpus update in
  update_parent_effective_cpumask() (bsc#1241166).
- cgroup/cpuset: Fix spelling errors in file
  kernel/cgroup/cpuset.c (bsc#1241166).
- commit 9c766ef
* Mon Apr 14 2025 vbabka@suse.cz
- Update config files.
- Disabled CONFIG_SYSFS_SYSCALL (jsc#PED-12651)
- Had to enable CONFIG_EXPERT for config/s390x/zfcpdump to expose
  CONFIG_SYSFS_SYSCALL. The rest of new options exposed by CONFIG_EXPERT
  were set to match the other configs.
- commit 7bd5ed3
* Mon Apr 14 2025 jgross@suse.com
- arm64: realm: Use aliased addresses for device DMA to shared
  buffers (jsc#PED-11786).
- commit e3877ff
* Mon Apr 14 2025 jgross@suse.com
- dma: Introduce generic dma_addr_*crypted helpers
  (jsc#PED-11786).
- commit 5d1c551
* Mon Apr 14 2025 jgross@suse.com
- dma: Fix encryption bit clearing for dma_to_phys
  (jsc#PED-11786).
- commit dd8af28
* Mon Apr 14 2025 jgross@suse.com
- virt: sev-guest: Allocate request data dynamically
  (jsc#PED-348).
- commit e63518a
* Mon Apr 14 2025 jgross@suse.com
- Update config files.
- supported.conf: add drivers/virt/coco/arm-cca-guest/arm-cca-guest
- commit 758e23b
* Mon Apr 14 2025 jgross@suse.com
- patches.suse/arm64-Document-Arm-Confidential-Compute.patch:
  (jsc#PED-11786).
- commit 4c3c801
* Mon Apr 14 2025 jgross@suse.com
- Update config files.
- supported.conf: add lib/crypto/libaesgcm (needed for SEV guests)
- commit 989f69b
* Mon Apr 14 2025 pjakobsson@suse.de
- supported.conf: Mark Intel ivpu accel driver as supported (jsc#PED-10529 jsc#PED-10738)
- commit d6a0ec5
* Mon Apr 14 2025 ohering@suse.de
- RDMA/mana_ib: Ensure variable err is initialized (git-fixes).
- commit c0a5353
* Mon Apr 14 2025 jslaby@suse.cz
- wifi: ath11k: update channel list in worker when wait flag is
  set (bsc#1241134).
- commit 7612236
* Sun Apr 13 2025 tiwai@suse.de
- pwm: fsl-ftm: Handle clk_get_rate() returning 0 (git-fixes).
- pwm: rcar: Improve register calculation (git-fixes).
- pwm: mediatek: Prevent divide-by-zero in pwm_mediatek_config()
  (git-fixes).
- commit ef3f359
* Sat Apr 12 2025 tonyj@suse.de
- Fix error in "probe libc's inet_pton & backtrace" perf test
  perf test record+probe_libc_inet_pton: Make test resilient
  (git-fixes).
- commit ad50bb0
* Sat Apr 12 2025 tonyj@suse.de
- perf bpf-filter: Fix a parsing error with comma (git-fixes).
- perf tools: Fix is_compat_mode build break in ppc64 (git-fixes).
- perf vendor events arm64 AmpereOneX: Fix frontend_bound
  calculation (git-fixes).
- perf pmu: Handle memory failure in tool_pmu__new() (git-fixes).
- perf: intel-tpebs: Fix incorrect usage of zfree() (git-fixes).
- perf dso: fix dso__is_kallsyms() check (git-fixes).
- perf python: Check if there is space to copy all the event
  (git-fixes).
- perf python: Don't keep a raw_data pointer to consumed ring
  buffer space (git-fixes).
- perf python: Decrement the refcount of just created event on
  failure (git-fixes).
- perf python: Fixup description of sample.id event member
  (git-fixes).
- perf test stat_all_pmu.sh: Correctly check 'perf stat' result
  (git-fixes).
- perf units: Fix insufficient array space (git-fixes).
- perf x86/topdown: Fix topdown leader sampling test error on
  hybrid (git-fixes).
- perf evlist: Add success path to evlist__create_syswide_maps
  (git-fixes).
- perf debug: Avoid stack overflow in recursive error message
  (git-fixes).
- perf tests: Fix data symbol test with LTO builds (git-fixes).
- perf bench: Fix perf bench syscall loop count (git-fixes).
- perf test: Add timeout to datasym workload (git-fixes).
- perf arm-spe: Fix load-store operation checking (git-fixes).
- perf build: Fix in-tree build due to symbolic link (git-fixes).
- perf pmu: Don't double count common sysfs and json events
  (git-fixes).
- perf pmu: Dynamically allocate tool PMU (git-fixes).
- perf report: Fix input reload/switch with symbol sort key
  (git-fixes).
- perf report: Switch data file correctly in TUI (git-fixes).
- perf tests: Fix Tool PMU test segfault (git-fixes).
- perf tools: Add skip check in tool_pmu__event_to_str()
  (git-fixes).
- perf stat: Don't merge counters purely on name (git-fixes).
- perf pmu: Rename name matching for no suffix or wildcard
  variants (git-fixes).
- perf pmus: Restructure pmu_read_sysfs to scan fewer PMUs
  (git-fixes).
- perf test: Fix Hwmon PMU test endianess issue (git-fixes).
- perf: Always feature test reallocarray (git-fixes).
- perf stat: Fix find_stat for mixed legacy/non-legacy events
  (git-fixes).
- tools: Unify top-level quiet infrastructure (git-fixes).
- perf test: Skip syscall enum test if no landlock syscall
  (git-fixes).
- perf trace: Fix runtime error of index out of bounds
  (git-fixes).
- perf trace: Fix BPF loading failure (-E2BIG) (git-fixes).
- perf bench: Fix undefined behavior in cmpworker() (git-fixes).
- perf lock: Add percpu-rwsem for type filter (git-fixes).
- perf lock: Fix parse_lock_type which only retrieve one lock flag
  (git-fixes).
- perf tools: Expose quiet/verbose variables in Makefile.perf
  (git-fixes).
- perf inject: Fix use without initialization of local variables
  (git-fixes).
- perf report: Fix misleading help message about --demangle
  (git-fixes).
- perf MANIFEST: Add arch/*/include/uapi/asm/bpf_perf_event.h
  to the perf tarball (git-fixes).
- perf namespaces: Fixup the nsinfo__in_pidns() return type,
  its bool (git-fixes).
- perf namespaces: Introduce nsinfo__set_in_pidns() (git-fixes).
- perf machine: Don't ignore _etext when not a text symbol
  (git-fixes).
- perf maps: Fix display of kernel symbols (git-fixes).
- perf top: Don't complain about lack of vmlinux when not
  resolving some kernel samples (git-fixes).
- perf intel-pt: Add a test for pause / resume (jsc#PED-10651).
- perf intel-pt: Add documentation for pause / resume
  (jsc#PED-10651).
- perf intel-pt: Improve man page format (jsc#PED-10651).
- perf tools: Add missing_features for aux_start_paused,
  aux_pause, aux_resume (jsc#PED-10651).
- perf tools: Parse aux-action (jsc#PED-10651).
- perf tools: Add aux-action config term (jsc#PED-10651).
- perf tools: Add aux_start_paused, aux_pause and aux_resume
  (jsc#PED-10651).
- perf expr: Initialize is_test value in expr__ctx_new()
  (git-fixes).
- perf bpf: Fix two memory leakages when calling
  perf_env__insert_bpf_prog_info() (git-fixes).
- perf header: Fix one memory leakage in process_bpf_prog_info()
  (git-fixes).
- perf header: Fix one memory leakage in process_bpf_btf()
  (git-fixes).
- perf arm-spe: Prepare for adding data source packet
  implementations for other cores (git-fixes).
- tools headers: Sync uapi/linux/perf_event.h with the kernel
  sources (jsc#PED-10651).
- commit 16d8625
* Sat Apr 12 2025 tiwai@suse.de
- ata: sata_sx4: Add error handling in pdc20621_i2c_read()
  (git-fixes).
- ata: pata_pxa: Fix potential NULL pointer dereference in
  pxa_ata_probe() (git-fixes).
- APEI: GHES: Have GHES honor the panic= setting (stable-fixes).
- commit 2c30291
* Fri Apr 11 2025 pfalcato@suse.de
- config: Disable CONFIG_LATENCYTOP (jsc#PED-12529)
- commit c5b32c4
* Fri Apr 11 2025 tonyj@suse.de
- s390/cpumf: Fix double free on error in cpumf_pmu_event_init()
  (git-fixes).
- commit b32df18
* Fri Apr 11 2025 tiwai@suse.de
- Update config files: CONFIG_LAN966X_OIC and co are dropped
- commit 32dd855
* Fri Apr 11 2025 jgross@suse.com
- virt: arm-cca-guest: TSM_REPORT support for realms
  (jsc#PED-11786).
- commit c5ab2be
* Fri Apr 11 2025 jgross@suse.com
- arm64: Enable memory encrypt for Realms (jsc#PED-11786).
- commit 3213422
* Fri Apr 11 2025 jgross@suse.com
- arm64: mm: Avoid TLBI when marking pages as valid
  (jsc#PED-11786).
- commit eecca06
* Fri Apr 11 2025 jgross@suse.com
- arm64: Enforce bounce buffers for realm DMA (jsc#PED-11786).
- commit b10d721
* Fri Apr 11 2025 jgross@suse.com
- efi: arm64: Map Device with Prot Shared (jsc#PED-11786).
- commit aefd90e
* Fri Apr 11 2025 jgross@suse.com
- arm64: rsi: Map unprotected MMIO as decrypted (jsc#PED-11786).
- commit ce08db2
* Fri Apr 11 2025 jgross@suse.com
- arm64: rsi: Add support for checking whether an MMIO is
  protected (jsc#PED-11786).
- commit 442a9ae
* Fri Apr 11 2025 jgross@suse.com
- arm64: realm: Query IPA size from the RMM (jsc#PED-11786).
- commit 9a064e4
* Fri Apr 11 2025 jgross@suse.com
- arm64: Detect if in a realm and set RIPAS RAM (jsc#PED-11786).
- commit e4b4ff0
* Fri Apr 11 2025 jgross@suse.com
- arm64: rsi: Add RSI definitions (jsc#PED-11786).
- commit 9e7e749
* Fri Apr 11 2025 jgross@suse.com
- s390: Fix various typos (jsc#PED-348).
- commit ae11616
* Fri Apr 11 2025 jgross@suse.com
- RISC-V: KVM: Allow Smnpm and Ssnpm extensions for guests
  (jsc#PED-348).
- commit 5fc44fd
* Fri Apr 11 2025 jgross@suse.com
- virt: sev-guest: Carve out SNP message context structure
  (jsc#PED-348).
- commit 9276b20
* Fri Apr 11 2025 jgross@suse.com
- virt: sev-guest: Reduce the scope of SNP command mutex
  (jsc#PED-348).
- commit 72f46bd
* Fri Apr 11 2025 jgross@suse.com
- virt: sev-guest: Consolidate SNP guest messaging parameters
  to a struct (jsc#PED-348).
- commit e467c7c
* Fri Apr 11 2025 jgross@suse.com
- x86/sev: Cache the secrets page address (jsc#PED-348).
- commit d373d20
* Fri Apr 11 2025 vkarasulli@suse.de
- Update
  patches.suse/Bluetooth-Add-check-for-mgmt_alloc_skb-in-mgmt_devic.patch
  (git-fixes CVE-2025-21936 bsc#1240716).
- Update
  patches.suse/Bluetooth-Add-check-for-mgmt_alloc_skb-in-mgmt_remot.patch
  (git-fixes CVE-2025-21937 bsc#1240643).
- Update
  patches.suse/Bluetooth-Fix-error-code-in-chan_alloc_skb_cb.patch
  (git-fixes CVE-2025-22007 bsc#1240829).
- Update
  patches.suse/HID-appleir-Fix-potential-NULL-dereference-at-raw-ev.patch
  (git-fixes CVE-2025-21948 bsc#1240703).
- Update
  patches.suse/HID-hid-steam-Fix-use-after-free-when-detaching-devi.patch
  (git-fixes CVE-2025-21923 bsc#1240691).
- Update
  patches.suse/HID-intel-ish-hid-Fix-use-after-free-issue-in-hid_is.patch
  (git-fixes CVE-2025-21929 bsc#1240711).
- Update
  patches.suse/HID-intel-ish-hid-Fix-use-after-free-issue-in-ishtp_.patch
  (git-fixes CVE-2025-21928 bsc#1240722).
- Update
  patches.suse/KVM-arm64-Unconditionally-save-flush-host-FPSIMD-SVE-SME-state.patch
  (git-fixes CVE-2025-22013 bsc#1240938).
- Update
  patches.suse/NFSv4-Fix-a-deadlock-when-recovering-state-on-a-sillyrenamed-file.patch
  (git-fixes CVE-2025-21900 bsc#1240578).
- Update
  patches.suse/RDMA-bnxt_re-Add-sanity-checks-on-rdev-validity.patch
  (jsc#PED-10684 jsc#PED-11230 CVE-2025-21901 bsc#1240579).
- Update
  patches.suse/RDMA-hns-Fix-soft-lockup-during-bt-pages-loop.patch
  (git-fixes CVE-2025-22010 bsc#1240943).
- Update
  patches.suse/accel-qaic-Fix-integer-overflow-in-qaic_validate_req.patch
  (git-fixes CVE-2025-22001 bsc#1240873).
- Update
  patches.suse/acpi-typec-ucsi-Introduce-a-poll_cci-method.patch
  (git-fixes CVE-2025-21902 bsc#1240599).
- Update
  patches.suse/bus-mhi-host-pci_generic-Use-pci_try_reset_function-.patch
  (git-fixes CVE-2025-21951 bsc#1240718).
- Update
  patches.suse/can-ucan-fix-out-of-bound-read-in-strscpy-source.patch
  (git-fixes CVE-2025-22003 bsc#1240825).
- Update
  patches.suse/cdx-Fix-possible-UAF-error-in-driver_override_show.patch
  (git-fixes CVE-2025-21915 bsc#1240594).
- Update
  patches.suse/dm-flakey-Fix-memory-corruption-in-optional-corrupt_.patch
  (git-fixes CVE-2025-21966 bsc#1240779).
- Update
  patches.suse/drivers-virt-acrn-hsm-Use-kzalloc-to-avoid-info-leak.patch
  (git-fixes CVE-2025-21950 bsc#1240719).
- Update
  patches.suse/drm-amd-display-Assign-normalized_pix_clk-when-color.patch
  (stable-fixes CVE-2025-21956 bsc#1240739).
- Update
  patches.suse/drm-amd-display-Fix-null-check-for-pipe_ctx-plane_st-374c9fa.patch
  (git-fixes CVE-2025-21941 bsc#1240701).
- Update
  patches.suse/drm-amd-display-Fix-out-of-bound-accesses.patch
  (stable-fixes CVE-2025-21985 bsc#1240811).
- Update
  patches.suse/drm-amd-display-Fix-slab-use-after-free-on-hdcp_work.patch
  (git-fixes CVE-2025-21968 bsc#1240783).
- Update
  patches.suse/drm-amd-display-fix-missing-.is_two_pixels_per_conta.patch
  (git-fixes CVE-2025-21989 bsc#1240805).
- Update
  patches.suse/drm-amdgpu-NULL-check-BO-s-backing-store-when-determ.patch
  (git-fixes CVE-2025-21990 bsc#1240804).
- Update
  patches.suse/drm-amdgpu-init-return-value-in-amdgpu_ttm_clear_buf.patch
  (git-fixes CVE-2025-21987 bsc#1240798).
- Update
  patches.suse/drm-amdkfd-Fix-NULL-Pointer-Dereference-in-KFD-queue.patch
  (git-fixes CVE-2025-21940 bsc#1240702).
- Update
  patches.suse/drm-hyperv-Fix-address-space-leak-when-Hyper-V-DRM-d.patch
  (git-fixes CVE-2025-21978 bsc#1240806).
- Update
  patches.suse/drm-imagination-avoid-deadlock-on-fence-release.patch
  (git-fixes CVE-2025-21911 bsc#1240589).
- Update
  patches.suse/drm-radeon-fix-uninitialized-size-issue-in-radeon_vc.patch
  (git-fixes CVE-2025-21996 bsc#1240801).
- Update
  patches.suse/drm-sched-Fix-fence-reference-count-leak.patch
  (git-fixes CVE-2025-21995 bsc#1240821).
- Update
  patches.suse/drm-xe-hmm-Don-t-dereference-struct-page-pointers-wi.patch
  (git-fixes CVE-2025-21939 bsc#1240710).
- Update
  patches.suse/eth-bnxt-do-not-update-checksum-in-bnxt_xdp_build_sk.patch
  (jsc#PED-10684 jsc#PED-11230 CVE-2025-21960 bsc#1240815).
- Update
  patches.suse/eth-bnxt-fix-kernel-panic-in-the-bnxt_get_queue_stat.patch
  (jsc#PED-10684 jsc#PED-11230 CVE-2025-21973 bsc#1240803).
- Update
  patches.suse/eth-bnxt-fix-truesize-for-mb-xdp-pass-case.patch
  (jsc#PED-10684 jsc#PED-11230 CVE-2025-21961 bsc#1240816).
- Update
  patches.suse/eth-bnxt-return-fail-if-interface-is-down-in-bnxt_qu.patch
  (jsc#PED-10684 jsc#PED-11230 CVE-2025-21974 bsc#1240800).
- Update
  patches.suse/firmware-qcom-uefisecapp-fix-efivars-registration-ra.patch
  (git-fixes CVE-2025-21998 bsc#1240865).
- Update
  patches.suse/gpio-aggregator-protect-driver-attr-handlers-against.patch
  (git-fixes CVE-2025-21943 bsc#1240647).
- Update patches.suse/keys-Fix-UAF-in-key_put.patch (git-fixes
  CVE-2025-21893 bsc#1240427).
- Update
  patches.suse/msft-hv-3165-fbdev-hyperv_fb-Fix-hang-in-kdump-kernel-when-on-Hyp.patch
  (git-fixes CVE-2025-21977 bsc#1240876).
- Update
  patches.suse/msft-hv-3170-net-mana-cleanup-mana-struct-after-debugfs_remove.patch
  (git-fixes CVE-2025-21953 bsc#1240727).
- Update
  patches.suse/net-mlx5-Bridge-fix-the-crash-caused-by-LAG-state-ch.patch
  (jsc#PED-11331 CVE-2025-21970 bsc#1240819).
- Update
  patches.suse/net-mlx5-handle-errors-in-mlx5_chains_create_table.patch
  (jsc#PED-11331 CVE-2025-21975 bsc#1240812).
- Update
  patches.suse/nvme-tcp-fix-potential-memory-corruption-in-nvme_tcp.patch
  (git-fixes CVE-2025-21927 bsc#1240714).
- Update
  patches.suse/pinctrl-nuvoton-npcm8xx-Add-NULL-check-in-npcm8xx_gp.patch
  (git-fixes CVE-2025-21982 bsc#1240807).
- Update
  patches.suse/rapidio-add-check-for-rio_add_net-in-rio_scan_alloc_.patch
  (git-fixes CVE-2025-21935 bsc#1240700).
- Update
  patches.suse/rapidio-fix-an-API-misues-when-rio_add_net-fails.patch
  (git-fixes CVE-2025-21934 bsc#1240708).
- Update
  patches.suse/regulator-dummy-force-synchronous-probing.patch
  (git-fixes CVE-2025-22009 bsc#1240940).
- Update
  patches.suse/sched-fair-Fix-potential-memory-corruption-in-child_cfs_rq_on_list.patch
  (bsc#1234634 (Scheduler functional and performance backports)
  CVE-2025-21919 bsc#1240593).
- Update
  patches.suse/slimbus-messaging-Free-transaction-ID-in-delayed-int.patch
  (git-fixes CVE-2025-21914 bsc#1240595).
- Update
  patches.suse/soc-qcom-pdr-Fix-the-potential-deadlock.patch
  (git-fixes CVE-2025-22014 bsc#1240937).
- Update
  patches.suse/usb-atm-cxacru-fix-a-flaw-in-existing-endpoint-check.patch
  (git-fixes CVE-2025-21916 bsc#1240582).
- Update
  patches.suse/usb-renesas_usbhs-Flush-the-notify_hotplug_work.patch
  (git-fixes CVE-2025-21917 bsc#1240596).
- Update patches.suse/usb-typec-ucsi-Fix-NULL-pointer-access.patch
  (git-fixes CVE-2025-21918 bsc#1240592).
- Update
  patches.suse/wifi-cfg80211-cancel-wiphy_work-before-freeing-wiphy.patch
  (git-fixes CVE-2025-21979 bsc#1240808).
- Update
  patches.suse/wifi-cfg80211-regulatory-improve-invalid-hints-check.patch
  (git-fixes CVE-2025-21910 bsc#1240583).
- Update
  patches.suse/wifi-iwlwifi-limit-printed-string-from-FW-file.patch
  (git-fixes CVE-2025-21905 bsc#1240575).
- Update
  patches.suse/wifi-iwlwifi-mvm-clean-up-ROC-on-failure.patch
  (git-fixes CVE-2025-21906 bsc#1240587).
- Update
  patches.suse/wifi-iwlwifi-mvm-don-t-try-to-talk-to-a-dead-firmwar.patch
  (git-fixes CVE-2025-21930 bsc#1240715).
- Update
  patches.suse/wifi-nl80211-reject-cooked-mode-if-it-is-set-along-w.patch
  (git-fixes CVE-2025-21909 bsc#1240590).
- commit 759681a
* Fri Apr 11 2025 jgross@suse.com
- virt: sev-guest: Use AES GCM crypto library (jsc#PED-348).
- commit ffa1eb0
* Fri Apr 11 2025 ailiop@suse.com
- exfat: add a check for invalid data size (git-fixes).
- commit 9baf5c3
* Fri Apr 11 2025 ailiop@suse.com
- nfsd: put dl_stid if fail to queue dl_recall (git-fixes).
- commit 8a68217
* Fri Apr 11 2025 jgross@suse.com
- KVM: PPC: replace call_rcu by kfree_rcu for simple
  kmem_cache_free callback (jsc#PED-348).
- commit 5ad92ec
* Fri Apr 11 2025 jgross@suse.com
- x86/virt: Move SEV-specific parsing into arch/x86/virt/svm
  (jsc#PED-348).
- commit 7237a96
* Fri Apr 11 2025 tiwai@suse.de
- drm/amd: Keep display off while going into S4 (stable-fixes).
- Refresh
  patches.suse/drm-amd-display-Restore-correct-backlight-brightness.patch.
- commit 015cb7c
* Fri Apr 11 2025 tiwai@suse.de
- drm/xe/hw_engine: define sysfs_ops on all directories
  (git-fixes).
- drm/xe: Use local fence in error path of xe_migrate_clear
  (git-fixes).
- drm/xe: Fix an out-of-bounds shift when invalidating TLB
  (git-fixes).
- drm/tests: probe-helper: Fix drm_display_mode memory leak
  (git-fixes).
- drm/tests: modes: Fix drm_display_mode memory leak (git-fixes).
- drm/tests: cmdline: Fix drm_display_mode memory leak
  (git-fixes).
- drm/tests: modeset: Fix drm_display_mode memory leak
  (git-fixes).
- drm/sti: remove duplicate object names (git-fixes).
- accel/ivpu: Fix PM related deadlocks in MS IOCTLs (git-fixes).
- accel/ivpu: Fix deadlock in ivpu_ms_cleanup() (git-fixes).
- accel/ivpu: Fix warning in ivpu_ipc_send_receive_internal()
  (git-fixes).
- drm/nouveau: prime: fix ttm_bo_delayed_delete oops (git-fixes).
- drm/imagination: fix firmware memory leaks (git-fixes).
- drm/imagination: take paired job reference (git-fixes).
- drm/amdgpu/mes12: optimize MES pipe FW version fetching
  (git-fixes).
- drm/amd/pm/smu11: Prevent division by zero (git-fixes).
- drm/amd/display: Protect FPU in dml2_validate()/dml21_validate()
  (git-fixes).
- drm/amd/display: Protect FPU in dml2_init()/dml21_init()
  (git-fixes).
- drm/amd/display: Protect FPU in dml21_copy() (git-fixes).
- drm/amd/display: Do not enable Replay and PSR while VRR is on
  in amdgpu_dm_commit_planes() (git-fixes).
- drm/amdgpu/dma_buf: fix page_link check (git-fixes).
- drm/amdgpu: immediately use GTT for new allocations (git-fixes).
- drm/amdgpu/mes11: optimize MES pipe FW version fetching
  (git-fixes).
- drm/i915/huc: Fix fence not released on early probe errors
  (git-fixes).
- drm/i915/vrr: Add vrr.vsync_{start, end} in vrr_params_changed
  (git-fixes).
- drm/i915: Disable RPG during live selftest (git-fixes).
- gpiolib: of: Fix the choice for Ingenic NAND quirk (git-fixes).
- gpio: tegra186: fix resource handling in ACPI probe path
  (git-fixes).
- mtd: rawnand: Add status chack in r852_ready() (git-fixes).
- mtd: inftlcore: Add error check for inftl_read_oob()
  (git-fixes).
- ntb: use 64-bit arithmetic for the MSI doorbell mask
  (git-fixes).
- ntb_perf: Delete duplicate dmaengine_unmap_put() call in
  perf_copy_chunk() (git-fixes).
- ntb: intel: Fix using link status DB's (git-fixes).
- ntb_hw_switchtec: Fix shift-out-of-bounds in
  switchtec_ntb_mw_set_trans (git-fixes).
- tty: serial: fsl_lpuart: Use u32 and u8 for register variables
  (stable-fixes).
- tty: n_tty: use uint for space returned by tty_write_room()
  (stable-fixes).
- staging: vchiq_arm: Fix possible NPR of keep-alive thread
  (git-fixes).
- staging: vchiq_arm: Register debugfs after cdev (git-fixes).
- ACPI: resource: Skip IRQ override on ASUS Vivobook 14 X1404VAP
  (stable-fixes).
- mmc: sdhci-pxav3: set NEED_RSP_BUSY capability (stable-fixes).
- selinux: Chain up tool resolving errors in install_policy.sh
  (git-fixes).
- selinux: always check the file label in
  selinux_kernel_read_file() (git-fixes).
- can: statistics: use atomic access in hot path (stable-fixes).
- hwmon: (nct6775-core) Fix out of bounds access for NCT679{8,9}
  (stable-fixes).
- memory: omap-gpmc: drop no compatible check (stable-fixes).
- ASoC: rt1320: set wake_capable = 0 explicitly (stable-fixes).
- ASoC: codecs: wsa884x: report temps to hwmon in millidegree
  of Celsius (stable-fixes).
- selftests: netfilter: skip br_netfilter queue tests if kernel
  is tainted (stable-fixes).
- wifi: mac80211: fix SA Query processing in MLO (stable-fixes).
- wifi: mac80211: flush the station before moving it to
  UN-AUTHORIZED state (stable-fixes).
- platform/x86/amd/pmf: Propagate PMF-TA return codes
  (stable-fixes).
- platform/x86/intel/vsec: Add Diamond Rapids support
  (stable-fixes).
- platform/x86: intel-hid: fix volume buttons on Microsoft
  Surface Go 4 tablet (stable-fixes).
- wifi: brcmfmac: keep power during suspend if board requires it
  (stable-fixes).
- wifi: mac80211: Fix sparse warning for monitor_sdata
  (git-fixes).
- wifi: iwlwifi: mvm: use the right version of the rate API
  (stable-fixes).
- wifi: iwlwifi: fw: allocate chained SG tables for dump
  (stable-fixes).
- wifi: mac80211: remove debugfs dir for virtual monitor
  (stable-fixes).
- wifi: mac80211: Cleanup sta TXQs on flush (stable-fixes).
- HID: i2c-hid: improve i2c_hid_get_report error message
  (stable-fixes).
- commit 0295513
* Fri Apr 11 2025 tonyj@suse.de
- perf/core: Fix child_total_time_enabled accounting bug at task
  exit (git-fixes).
- powerpc/perf: Fix ref-counting on the PMU 'vpa_pmu' (git-fixes).
- perf: Clean up pmu specific data (git-fixes).
- perf/x86: Remove swap_task_ctx() (git-fixes).
- perf/x86/lbr: Fix shorter LBRs call stacks for the system-wide
  mode (git-fixes).
- perf: Supply task information to sched_task() (git-fixes).
- perf: attach/detach PMU specific data (git-fixes).
- locking/percpu-rwsem: Add guard support (git-fixes).
- perf: Save PMU specific data in task_struct (git-fixes).
- perf: Extend per event callchain limit to branch stack
  (git-fixes).
- perf/ring_buffer: Allow the EPOLLRDNORM flag for poll
  (git-fixes).
- perf/core: Clean up perf_try_init_event() (git-fixes).
- perf/core: Fix perf_mmap() failure path (git-fixes).
- perf/core: Detach 'struct perf_cpu_pmu_context' and 'struct pmu'
  lifetimes (git-fixes).
- perf/core: Lift event->mmap_mutex in perf_mmap() (git-fixes).
- perf/core: Remove retry loop from perf_mmap() (git-fixes).
- perf/core: Further simplify perf_mmap() (git-fixes).
- perf/core: Simplify the perf_mmap() control flow (git-fixes).
- perf/bpf: Robustify perf_event_free_bpf_prog() (git-fixes).
- perf/core: Introduce perf_free_addr_filters() (git-fixes).
- perf/core: Add this_cpc() helper (git-fixes).
- perf/core: Merge struct pmu::pmu_disable_count into struct
  perf_cpu_pmu_context::pmu_disable_count (git-fixes).
- perf/core: Simplify perf_event_alloc() (git-fixes).
- perf/core: Simplify perf_init_event() (git-fixes).
- perf/core: Simplify perf_pmu_register() (git-fixes).
- perf/core: Simplify the perf_pmu_register() error path
  (git-fixes).
- perf/core: Simplify the perf_event_alloc() error path
  (git-fixes).
- perf: Avoid the read if the count is already updated
  (git-fixes).
- perf/x86/intel: Avoid disable PMU if !cpuc->enabled in sample
  read (git-fixes).
- perf/x86/intel: Apply static call for drain_pebs (git-fixes).
- lockdep/mm: Fix might_fault() lockdep check of
  current->mm->mmap_lock (git-fixes).
- perf/x86/rapl: Fix error handling in init_rapl_pmus()
  (git-fixes).
- perf/core: Fix perf_pmu_register() vs. perf_init_event()
  (git-fixes).
- perf/core: Fix pmus_lock vs. pmus_srcu ordering (git-fixes).
- perf/x86/rapl: Add support for Intel Arrow Lake U (git-fixes).
- perf/x86/intel: Use better start period for frequency mode
  (git-fixes).
- perf/core: Fix low freq setting via IOC_PERIOD (git-fixes).
- perf/x86: Fix low freqency setting issue (git-fixes).
- perf/x86/intel: Fix event constraints for LNC (git-fixes).
- perf/x86/intel: Ensure LBRs are disabled when a CPU is starting
  (git-fixes).
- perf/x86/intel: Fix ARCH_PERFMON_NUM_COUNTER_LEAF (git-fixes).
- perf/x86/intel: Clean up PEBS-via-PT on hybrid (git-fixes).
- perf/x86/rapl: Fix the error checking order (git-fixes).
- perf: map pages in advance (git-fixes).
- perf/core: Save raw sample data conditionally based on sample
  type (git-fixes).
- perf/x86/intel: Fix bitmask of OCR and FRONTEND events for LNC
  (git-fixes).
- perf/x86/intel/ds: Add PEBS format 6 (git-fixes).
- perf/x86/intel/ds: Unconditionally drain PEBS DS when changing
  PEBS_DATA_CFG (git-fixes).
- perf/x86/intel: Do not enable large PEBS for events with aux
  actions or aux sampling (jsc#PED-10651).
- perf/x86/intel/pt: Add support for pause / resume
  (jsc#PED-10651).
- perf/core: Add aux_pause, aux_resume, aux_start_paused
  (jsc#PED-10651).
- perf/x86/intel/pt: Fix buffer full but size is 0 case
  (git-fixes).
- perf/x86/amd: Warn only on new bits set (git-fixes).
- commit 6f059e0
* Thu Apr 10 2025 tiwai@suse.de
- Revert "kheaders: Ignore silly-rename files" (stable-fixes).
- rust: kbuild: add -fzero-init-padding-bits to
  bindgen_skip_cflags (git-fixes).
- docs: rust: remove spurious item in `expect` list (git-fixes).
- commit 2d49340
* Thu Apr 10 2025 tiwai@suse.de
- USB: serial: ftdi_sio: add support for Altera USB Blaster 3
  (stable-fixes).
- USB: serial: option: fix Telit Cinterion FE990A name
  (stable-fixes).
- USB: serial: option: add Telit Cinterion FE990B compositions
  (stable-fixes).
- USB: serial: option: match on interface class for Telit FN990B
  (stable-fixes).
- thermal: gov_power_allocator: Update total_weight on bind and
  cdev updates (git-fixes).
- vmlinux.lds: Ensure that const vars with relocations are mapped
  R/O (stable-fixes).
- usb: phy: generic: Use proper helper for property detection
  (stable-fixes).
- commit cf7a1fa
* Thu Apr 10 2025 tiwai@suse.de
- selftests/mm: run_vmtests.sh: fix half_ufd_size_MB calculation
  (git-fixes).
- net: phy: nxp-c45-tja11xx: add TJA112XB SGMII PCS restart errata
  (git-fixes).
- net: phy: nxp-c45-tja11xx: add TJA112X PHY configuration errata
  (git-fixes).
- kbuild: userprogs: use correct lld when linking through clang
  (git-fixes).
- thermal/of: Fix cdev lookup in thermal_of_should_bind()
  (git-fixes).
- selftests/landlock: Test that MPTCP actions are not restricted
  (stable-fixes).
- selftests/landlock: Test TCP accesses with protocol=IPPROTO_TCP
  (stable-fixes).
- irqchip/jcore-aic, clocksource/drivers/jcore: Fix jcore-pit
  interrupt request (git-fixes).
- net: wwan: mhi_wwan_mbim: Silence sequence number glitch errors
  (stable-fixes).
- objtool: Ignore dangling jump table entries (stable-fixes).
- selftests/cgroup: use bash in test_cpuset_v1_hp.sh
  (stable-fixes).
- kbuild: Move -Wenum-enum-conversion to W=2 (git-fixes).
- powercap: call put_device() on an error path in
  powercap_register_control_type() (stable-fixes).
- selftests: always check mask returned by statmount(2)
  (stable-fixes).
- net: rose: lock the socket in rose_bind() (git-fixes).
- irqchip/apple-aic: Only handle PMC interrupt as FIQ when
  configured so (git-fixes).
- irqchip/irq-mvebu-icu: Fix access to msi_data from
  irq_domain::host_data (git-fixes).
- irqchip/lan966x-oic: Make CONFIG_LAN966X_OIC depend on
  CONFIG_MCHP_LAN966X_PCI (git-fixes).
- kbuild: Use -fzero-init-padding-bits=all (stable-fixes).
- kbuild: suppress stdout from merge_config for silent builds
  (stable-fixes).
- selftests: gpio: gpio-sim: Fix missing chip disablements
  (stable-fixes).
- kunit: platform: Resolve 'struct completion' warning
  (stable-fixes).
- mfd: lpc_ich: Add another Gemini Lake ISA bridge PCI device-id
  (stable-fixes).
- spi: atmel-qspi: Memory barriers after memory-mapped I/O
  (git-fixes).
- selftests/net/ipsec: Fix Null pointer dereference in
  rtattr_pack() (stable-fixes).
- net: wwan: iosm: Fix hibernation by re-binding the driver
  around it (stable-fixes).
- irqchip: Plug a OF node reference leak in
  platform_irqchip_probe() (git-fixes).
- selftests: tc-testing: reduce rshift value (stable-fixes).
- kheaders: Ignore silly-rename files (stable-fixes).
- kbuild: pacman-pkg: provide versioned linux-api-headers package
  (git-fixes).
- net: wwan: iosm: Properly check for valid exec stage in
  ipc_mmio_init() (git-fixes).
- sky2: Add device ID 11ab:4373 for Marvell 88E8075
  (stable-fixes).
- selftests/alsa: Fix circular dependency involving global-timer
  (stable-fixes).
- kbuild: switch from lz4c to lz4 for compression (stable-fixes).
- selftests: rtnetlink: update netdevsim ipsec output format
  (stable-fixes).
- libsubcmd: Silence compiler warning (stable-fixes).
- commit 875f3e3
* Thu Apr 10 2025 tiwai@suse.de
- efi/libstub: Avoid physical address 0x0 when doing random
  allocation (stable-fixes).
- efi: Don't map the entire mokvar table to determine its size
  (stable-fixes).
- ima: Reset IMA_NONACTION_RULE_FLAGS after post_setattr
  (git-fixes).
- gpio: vf610: add locking to gpio direction functions
  (git-fixes).
- efi: Avoid cold plugged memory for placing the kernel
  (stable-fixes).
- Input: allocate keycode for phone linking (stable-fixes).
- i2c: designware: Actually make use of the I2C_DW_COMMON and
  I2C_DW symbol namespaces (git-fixes).
- hwmon: (nct6775): Actually make use of the HWMON_NCT6775 symbol
  namespace (git-fixes).
- Input: serio - define serio_pause_rx guard to pause and resume
  serio ports (stable-fixes).
- commit dc90670
* Thu Apr 10 2025 tiwai@suse.de
- clk: samsung: update PLL locktime for PLL142XX used on FSD
  platform (git-fixes).
- clk: samsung: gs101: fix synchronous external abort in
  samsung_clk_save() (git-fixes).
- cpufreq: s3c64xx: Fix compilation warning (stable-fixes).
- clk: sunxi-ng: a64: drop redundant CLK_PLL_VIDEO0_2X and
  CLK_PLL_MIPI (git-fixes).
- Documentation: rust: discuss `#[expect(...)]` in the guidelines
  (stable-fixes).
- Documentation: rust: add coding guidelines on lints
  (stable-fixes).
- commit 6114330
* Thu Apr 10 2025 tiwai@suse.de
- ata: libata-core: Add ATA_QUIRK_NO_LPM_ON_ATI for certain
  Samsung SSDs (git-fixes).
- ASoC: dapm-graph: set fill colour of turned on nodes
  (stable-fixes).
- batman-adv: Drop unmanaged ELP metric worker (git-fixes).
- batman-adv: Ignore neighbor throughput metrics in error case
  (stable-fixes).
- accel/ivpu: Fix error handling in recovery/reset (git-fixes).
- ACPI: resource: IRQ override for Eluktronics MECH-17
  (stable-fixes).
- ACPI: x86: Add skip i2c clients quirk for Vexia EDU ATLA 10
  tablet 5V (stable-fixes).
- apparmor: allocate xmatch for nullpdb inside aa_alloc_null
  (stable-fixes).
- commit bbf19e0
* Thu Apr 10 2025 tiwai@suse.de
- HID: apple: disable Fn key handling on the Omoton KB066
  (git-fixes).
- gpio: sim: lock hog configfs items if present (git-fixes).
- ASoC: samsung: Add missing depends on I2C (git-fixes).
- thermal: gov_power_allocator: Add missing NULL pointer check
  (git-fixes).
- commit b2840e7
* Thu Apr 10 2025 tiwai@suse.de
- media: i2c: ds90ub953: Add error handling for i2c reads/writes
  (stable-fixes).
- media: i2c: ds90ub913: Add error handling to ub913_hw_init()
  (stable-fixes).
- media: cxd2841er: fix 64-bit division on gcc-9 (stable-fixes).
- commit 5d82128
* Thu Apr 10 2025 tiwai@suse.de
- mmc: sdhci-msm: Correctly set the load for the regulator
  (stable-fixes).
- mmc: sdhci-esdhc-imx: enable 'SDHCI_QUIRK_NO_LED' quirk for S32G
  (stable-fixes).
- mmc: core: Respect quirk_max_rate for non-UHS SDIO card
  (stable-fixes).
- commit c3e39a3
* Thu Apr 10 2025 tiwai@suse.de
- platform/x86: thinkpad_acpi: disable ACPI fan access for T495*
  and E560 (git-fixes).
- platform/x86: thinkpad_acpi: Add battery quirk for ThinkPad
  X131e (stable-fixes).
- platform/x86: int3472: Call "reset" GPIO "enable" for INT347E
  (stable-fixes).
- platform/x86: int3472: Use correct type for "polarity", call
  it gpio_flags (stable-fixes).
- platform/x86: thinkpad_acpi: Support for V9 DYTC platform
  profiles (stable-fixes).
- platform/x86: thinkpad_acpi: Fix invalid fan speed on ThinkPad
  X120e (stable-fixes).
- platform/x86/intel: pmc: fix ltr decode in pmc_core_ltr_show()
  (stable-fixes).
- commit 85fd67b
* Thu Apr 10 2025 tiwai@suse.de
- platform/x86: acer-wmi: Ignore AC events (stable-fixes).
- platform/x86: acer-wmi: add support for Acer Nitro AN515-58
  (stable-fixes).
- platform/x86: acer-wmi: Add support for Acer Predator PH16-72
  (stable-fixes).
- platform/x86: acer-wmi: Add support for Acer PH14-51
  (stable-fixes).
- platform/x86: ISST: Add Clearwater Forest to support list
  (stable-fixes).
- platform/x86/intel: power-domains: Add Clearwater Forest support
  (stable-fixes).
- platform/x86: thinkpad-acpi: Add support for hotkey 0x1401
  (stable-fixes).
- platform/x86: hp-wmi: mark 8A15 board for timed OMEN thermal
  profile (stable-fixes).
- commit f16312f
* Thu Apr 10 2025 tiwai@suse.de
- ASoC: SOF: Intel: don't check number of sdw links when set
  dmic_fixup (stable-fixes).
- ASoC: tas2764: Set the SDOUT polarity correctly (stable-fixes).
- ASoC: tas2764: Fix power control mask (stable-fixes).
- ASoC: tas2770: Fix volume scale (stable-fixes).
- ASoC: SOF: amd: Handle IPC replies before FW_BOOT_COMPLETE
  (stable-fixes).
- ASoC: SOF: amd: Add post_fw_run_delay ACP quirk (stable-fixes).
- ASoC: Intel: sof_sdw: Add quirk for Asus Zenbook S14
  (stable-fixes).
- commit a03c313
* Thu Apr 10 2025 tiwai@suse.de
- ASoC: Intel: sof_sdw: Add lookup of quirk using PCI subsystem ID
  (stable-fixes).
- ASoC: SOF: Intel: hda: add softdep pre to snd-hda-codec-hdmi
  module (stable-fixes).
- ASoC: arizona/madera: use fsleep() in up/down DAPM event delays
  (stable-fixes).
- ASoC: simple-card-utils.c: add missing dlc->of_node
  (stable-fixes).
- ASoC: Intel: soc-acpi-intel-mtl-match: declare adr as ull
  (stable-fixes).
- ASoC: Intel: bytcr_rt5640: Add DMI quirk for Vexia Edu Atla
  10 tablet 5V (stable-fixes).
- ASoC: amd: Add ACPI dependency to fix build error
  (stable-fixes).
- commit 8395ba3
* Thu Apr 10 2025 tiwai@suse.de
- ALSA: hda: cs35l56: Remove calls to
  cs35l56_force_sync_asp1_registers_from_cache() (stable-fixes).
- Refresh
  patches.suse/ASoC-cs35l56-Prevent-races-when-soft-resetting-using.patch.
- commit e8d62b1
* Thu Apr 10 2025 tiwai@suse.de
- ASoC: Intel: sof_sdw: Correct quirk for Lenovo Yoga Slim 7
  (stable-fixes).
- ASoC: cs42l43: Add codec force suspend/resume ops
  (stable-fixes).
- ASoC: samsung: Add missing selects for MFD_WM8994
  (stable-fixes).
- ASoC: codecs: es8316: Fix HW rate calculation for 48Mhz MCLK
  (stable-fixes).
- ASoC: wm8994: Add depends on MFD core (stable-fixes).
- ASoC: mediatek: disable buffer pre-allocation (stable-fixes).
- ASoC: rt722: add delay time to wait for the calibration
  procedure (stable-fixes).
- ASoC: audio-graph-card: Call of_node_put() on correct node
  (stable-fixes).
- ALSA: hda/ca0132: Use standard HD-audio quirk matching helpers
  (stable-fixes).
- commit d94e804
* Thu Apr 10 2025 tiwai@suse.de
- Input: i8042 - swap old quirk combination with new quirk for
  more devices (stable-fixes).
- Input: i8042 - swap old quirk combination with new quirk for
  several devices (stable-fixes).
- Input: i8042 - add required quirks for missing old boardnames
  (stable-fixes).
- Input: i8042 - swap old quirk combination with new quirk for
  NHxxRZQ (stable-fixes).
- Input: xpad - rename QH controller to Legion Go S
  (stable-fixes).
- Input: xpad - add support for TECNO Pocket Go (stable-fixes).
- Input: xpad - add support for ZOTAC Gaming Zone (stable-fixes).
- Input: xpad - add multiple supported devices (stable-fixes).
- Input: xpad - add 8BitDo SN30 Pro, Hyperkin X91 and Gamesir
  G7 SE controllers (stable-fixes).
- commit c0214ef
* Thu Apr 10 2025 tiwai@suse.de
- tty: serial: 8250: Add Brainboxes XC devices (stable-fixes).
- tty: serial: 8250: Add some more device IDs (stable-fixes).
- HID: hid-plantronics: Add mic mute mapping and generalize quirks
  (stable-fixes).
- commit 27219be
* Thu Apr 10 2025 tiwai@suse.de
- intel_th: pci: Add Panther Lake-P/U support (stable-fixes).
- intel_th: pci: Add Panther Lake-H support (stable-fixes).
- intel_th: pci: Add Arrow Lake support (stable-fixes).
- mei: me: add panther lake P DID (stable-fixes).
- gpio: rcar: Use raw_spinlock to protect register access
  (stable-fixes).
- phy: ti: gmii-sel: Do not use syscon helper to build regmap
  (stable-fixes).
- irqchip/gic-v3: Fix rk3399 workaround when secure interrupts
  are enabled (git-fixes).
- gpiolib: protect gpio_chip with SRCU in array_info paths in
  multi get/set (stable-fixes).
- commit a763c51
* Thu Apr 10 2025 tiwai@suse.de
- gpiolib: acpi: Add a quirk for Acer Nitro ANV14 (stable-fixes).
- thermal/cpufreq_cooling: Remove structure member documentation
  (stable-fixes).
- HID: apple: fix up the F6 key on the Omoton KB066 keyboard
  (stable-fixes).
- HID: hid-apple: Apple Magic Keyboard a3203 USB-C support
  (stable-fixes).
- HID: topre: Fix n-key rollover on Realforce R3S TKL boards
  (stable-fixes).
- HID: intel-ish-hid: ipc: Add Panther Lake PCI device IDs
  (stable-fixes).
- HID: hid-steam: Fix issues with disabling both gamepad mode
  and lizard mode (stable-fixes).
- HID: ignore non-functional sensor in HP 5MP Camera
  (stable-fixes).
- HID: intel-ish-hid: Send clock sync message immediately after
  reset (stable-fixes).
- HID: intel-ish-hid: fix the length of MNG_SYNC_FW_CLOCK in
  doorbell (stable-fixes).
- serial: 8250_pci: Share WCH IDs with parport_serial driver
  (stable-fixes).
- commit 2b5b959
* Thu Apr 10 2025 tiwai@suse.de
- Update config files: config files: CONFIG_MIPI_I3C_HCI_PCI=m
- supported.con
- commit 52bee05
* Thu Apr 10 2025 tiwai@suse.de
- HID: hid-steam: Make sure rumble work is canceled on removal
  (stable-fixes).
- Refresh
  patches.suse/HID-hid-steam-Fix-use-after-free-when-detaching-devi.patch.
- Refresh
  patches.suse/HID-hid-steam-Move-hidraw-input-un-registering-to-wo.patch.
- commit 051b5d1
* Thu Apr 10 2025 tiwai@suse.de
- i3c: mipi-i3c-hci: Add support for MIPI I3C HCI on PCI bus
  (stable-fixes).
- i3c: mipi-i3c-hci: Add Intel specific quirk to ring resuming
  (stable-fixes).
- soc/tegra: fuse: Update Tegra234 nvmem keepout list
  (stable-fixes).
- HID: Wacom: Add PCI Wacom device support (stable-fixes).
- HID: hid-asus: Disable OOBE mode on the ProArt P16
  (stable-fixes).
- HID: multitouch: Add quirk for Hantick 5288 touchpad
  (stable-fixes).
- commit cee8b14
* Thu Apr 10 2025 tiwai@suse.de
- i2c: Force ELAN06FA touchpad I2C bus freq to 100KHz
  (stable-fixes).
- spi: atmel-quadspi: Create `atmel_qspi_ops` to support newer
  SoC families (stable-fixes).
- irqchip/sunxi-nmi: Add missing SKIP_WAKE flag (stable-fixes).
- of/unittest: Add test that of_address_to_resource() fails on
  non-translatable address (stable-fixes).
- hwmon: (drivetemp) Set scsi command timeout to 10s
  (stable-fixes).
- gpio: sim: lock up configfs that an instantiated device depends
  on (stable-fixes).
- gpio: virtuser: lock up configfs that an instantiated device
  depends on (stable-fixes).
- irqchip/gic: Correct declaration of *percpu_base pointer in
  union gic_base (stable-fixes).
- spi: spi-cadence-qspi: Disable STIG mode for Altera SoCFPGA
  (stable-fixes).
- thermal: of: Simplify thermal_of_should_bind with scoped for
  each OF child (stable-fixes).
- commit 3bac618
* Thu Apr 10 2025 tiwai@suse.de
- accel/ivpu: Add FW state dump on TDR (stable-fixes).
- Refresh
  patches.suse/accel-ivpu-Prevent-recovery-invocation-during-probe-.patch.
- commit e154818
* Thu Apr 10 2025 tiwai@suse.de
- accel/ivpu: Add coredump support (stable-fixes).
- accel/ivpu: Limit FW version string length (stable-fixes).
- thermal: core: Move lists of thermal instances to trip
  descriptors (stable-fixes).
- commit 1b6fd5f
* Thu Apr 10 2025 tiwai@suse.de
- Bluetooth: qca: Fix poor RF performance for WCN6855 (git-fixes).
- commit 8f8d064
* Thu Apr 10 2025 tiwai@suse.de
- Bluetooth: qca: Update firmware-name to support board specific
  nvm (stable-fixes).
- Bluetooth: btusb: Add new VID/PID 13d3/3628 for MT7925
  (stable-fixes).
- Bluetooth: btusb: Add new VID/PID 13d3/3610 for MT7922
  (stable-fixes).
- commit ff34f1d
* Thu Apr 10 2025 oneukum@suse.com
- Input: xpad - rename QH controller to Legion Go S (git-fixes).
- commit aba26a6
* Thu Apr 10 2025 oneukum@suse.com
- Input: xpad - add support for TECNO Pocket Go (git-fixes).
- Input: xpad - add support for ZOTAC Gaming Zone (git-fixes).
- commit d081c97
* Thu Apr 10 2025 oneukum@suse.com
- Input: xpad - add multiple supported devices (git-fixes).
- commit 8c43ca9
* Thu Apr 10 2025 oneukum@suse.com
- Input: xpad - add 8BitDo SN30 Pro, Hyperkin X91 and Gamesir
  G7 SE controllers (git-fixes).
- commit a67b5a7
* Thu Apr 10 2025 vkarasulli@suse.de
- regulator: check that dummy regulator has been probed before
  using it (CVE-2025-22008 bsc#1240942).
- commit eab7c21
* Thu Apr 10 2025 krisman@suse.de
- io_uring/uring_cmd: unconditionally copy SQEs at prep time
  (CVE-2025-21837 bsc#1239064).
- io_uring/uring_cmd: switch sqe to async_data on EAGAIN
  (CVE-2025-21837 bsc#1239064).
- commit f44e166
* Wed Apr  9 2025 krisman@suse.de
- io_uring/kbuf: reallocate buf lists on upgrade (CVE-2025-21836
  bsc#1239066).
- commit e7bf444
* Wed Apr  9 2025 krisman@suse.de
- io_uring: prevent opcode speculation (CVE-2025-21863
  bsc#1239475).
- commit a129dda
* Wed Apr  9 2025 mkubecek@suse.cz
- net: mctp: unshare packets when reassembling (CVE-2025-21972
  bsc#1240813).
- commit 7e7e668
* Wed Apr  9 2025 jdelvare@suse.de
- gpio: rcar: Use raw_spinlock to protect register access
  (CVE-2025-21912 bsc#1240584).
- commit ef2385e
* Wed Apr  9 2025 mfranc@suse.cz
- s390: Remove ioremap_wt() and pgprot_writethrough() (git-fixes
  bsc#1240977).
- commit 8037d34
* Wed Apr  9 2025 mfranc@suse.cz
- s390/entry: Fix setting _CIF_MCCK_GUEST with lowcore relocation
  (git-fixes bsc#1240976).
- commit 4b51b40
* Wed Apr  9 2025 mfranc@suse.cz
- s390/pci: Fix zpci_bus_is_isolated_vf() for non-VFs (git-fixes, bsc#1240975).
- commit f780310
* Wed Apr  9 2025 tiwai@suse.de
- wifi: ath11k: fix memory leak in ath11k_xxx_remove()
  (git-fixes).
- Refresh
  patches.suse/wifi-ath11k-choose-default-PM-policy-for-hibernation.patch.
- Refresh
  patches.suse/wifi-ath11k-support-non-WoWLAN-mode-suspend-as-well.patch.
- commit f0a348c
* Wed Apr  9 2025 tiwai@suse.de
- Update upstream status for ath11k patches
- commit 4a45d06
* Wed Apr  9 2025 ykaukab@suse.de
- configs: update using run_oldconfig.sh
- commit d3805c5
* Wed Apr  9 2025 jslaby@suse.cz
- rpm/check-for-config-changes: add LD_CAN_ to IGNORED_CONFIGS_RE
  We now have LD_CAN_USE_KEEP_IN_OVERLAY since commit:
  e7607f7d6d81 ARM: 9443/1: Require linker to support KEEP within OVERLAY for DCE
- commit 7b55ff2
* Wed Apr  9 2025 tonyj@suse.de
- perf tools: annotate asm_pure_loop.S (bsc#1239906).
- commit 9969be2
* Tue Apr  8 2025 tonyj@suse.de
- perf/core: Order the PMU list to fix warning about unordered
  pmu_ctx_list (bsc#1240585 CVE-2025-21895).
- commit 820ecfc
* Tue Apr  8 2025 rgoldwyn@suse.com
- ext4: fix FS_IOC_GETFSMAP handling (bsc#1240557).
- commit 3d92358
* Tue Apr  8 2025 oneukum@suse.com
- gpio: idio-16: Actually make use of the GPIO_IDIO_16 symbol
  namespace (git-fixes).
- commit f08563d
* Tue Apr  8 2025 oneukum@suse.com
- module: Convert default symbol namespace to string literal
  (git-fixes).
- commit fd4c957
* Tue Apr  8 2025 oneukum@suse.com
- gpio: vf610: use generic device_get_match_data() (git-fixes).
- commit 7d5c89d
* Tue Apr  8 2025 rbrown@suse.com
- rpm/kernel-binary.spec.in: Use OrderWithRequires (boo#1228659 boo#1241038).
  OrderWithRequires was introduced in rpm 4.9 (ie. SLE12+) to allow
  a package to inform the order of installation of other package without
  hard requiring that package. This means our kernel-binary packages no
  longer need to hard require perl-Bootloader or dracut, resolving the
  long-commented issue there. This is also needed for udev & systemd-boot
  to ensure those packages are installed before being called by dracut
  (boo#1228659)
- commit 634be2c
* Tue Apr  8 2025 mfranc@suse.cz
- s390/sclp: Initialize sclp subsystem via arch_cpu_finalize_init()
  (git-fixes, bsc#1237055).
- Refresh
  patches.suse/s390-lock-down-kernel-in-secure-boot-mode.patch.
- commit daf9150
* Tue Apr  8 2025 rgoldwyn@suse.com
- ovl: support encoding fid from inode with no alias (bsc#1238448).
- commit 258d9fd
* Tue Apr  8 2025 rgoldwyn@suse.com
- ovl: pass realinode to ovl_encode_real_fh() instead of realdentry (git-fixes).
- commit 28b34c8
* Tue Apr  8 2025 rgoldwyn@suse.com
- ovl: properly handle large files in ovl_security_fileattr (git-fixes).
- commit 2f1a01a
* Tue Apr  8 2025 cfamullaconrad@suse.de
- tools/power turbostat: Restore GFX sysfs fflush() call
  (git-fixes).
- commit e034d9b
* Tue Apr  8 2025 cfamullaconrad@suse.de
- tools/power turbostat: Allow Zero return value for some RAPL
  registers (git-fixes).
- commit 39d1fd1
* Tue Apr  8 2025 oneukum@suse.com
- net: usb: qmi_wwan: add Telit Cinterion FE990B composition
  (git-fixes).
- commit b2dd890
* Tue Apr  8 2025 oneukum@suse.com
- net: usb: qmi_wwan: add Telit Cinterion FN990B composition
  (git-fixes).
- commit a3fe22b
* Tue Apr  8 2025 oneukum@suse.com
- usb: xhci: Apply the link chain quirk on NEC isoc endpoints
  (git-fixes).
- commit bec8bdb
* Tue Apr  8 2025 shung-hsi.yu@suse.com
- bpf: avoid holding freeze_mutex during mmap operation
  (git-fixes).
- bpf: unify VM_WRITE vs VM_MAYWRITE use in BPF map mmaping logic
  (git-fixes).
- selftests/bpf: Add test for narrow ctx load for pointer args
  (git-fixes).
- bpf: Check size for BTF-based ctx access of pointer members
  (git-fixes).
- bpf: Fix theoretical prog_array UAF in __uprobe_perf_func()
  (git-fixes).
- bpf: fix potential error return (git-fixes).
- bpf: handle implicit declaration of function gettid in
  bpf_iter.c (git-fixes).
- Refresh patches.suse/selftests-bpf-Clean-up-open-coded-gettid-syscall-inv.patch
- selftests/bpf: Fix uprobe consumer test (git-fixes).
- commit 2087211
* Tue Apr  8 2025 tiwai@suse.de
- drm/amd/display: Don't write DP_MSTM_CTRL after LT
  (stable-fixes).
- commit fa64fbb
* Tue Apr  8 2025 tonyj@suse.de
- libperf cpumap: Grow array of read CPUs in smaller increments
  (bsc#1234698 jsc#PED-12309).
- libperf cpumap: Remove use of perf_cpu_map__read() (bsc#1234698
  jsc#PED-12309).
- perf pmu: Remove use of perf_cpu_map__read() (bsc#1234698
  jsc#PED-12309).
- libperf cpumap: Be tolerant of newline at the end of a cpumask
  (bsc#1234698 jsc#PED-12309).
- libperf cpumap: Hide/reduce scope of MAX_NR_CPUS (bsc#1234698
  jsc#PED-12309).
- perf cpumap: Reduce transitive dependencies on libperf
  MAX_NR_CPUS (bsc#1234698 jsc#PED-12309).
- perf: Increase MAX_NR_CPUS to 4096 (bsc#1234698 jsc#PED-12309).
- commit 016f27b
* Mon Apr  7 2025 dsterba@suse.com
- netmem: prevent TX of unreadable skbs (CVE-2025-21954 bsc#1240734)
- commit a1c5aa6
* Mon Apr  7 2025 krisman@suse.de
- io_uring/sqpoll: Increase task_work submission batch size
  (bsc#1237349).
- commit 1fd5694
* Mon Apr  7 2025 dsterba@suse.com
- OPP: fix dev_pm_opp_find_bw_*() when bandwidth table not initialized (CVE-2024-58068 bsc#1238961)
- commit becf7cb
* Mon Apr  7 2025 dsterba@suse.com
- net: let net.core.dev_weight always be non-zero (CVE-2025-21806 bsc#1238746)
- commit 77296a7
* Mon Apr  7 2025 rgoldwyn@suse.com
- fs/netfs/read_collect: add to next->prev_donated (CVE-2025-21988 bsc#1240794).
- commit 266358d
* Mon Apr  7 2025 rgoldwyn@suse.com
- cachefiles: Fix missing pos updates in cachefiles_ondemand_fd_write_iter() (git-fixes).
- Refresh
  patches.suse/cachefiles-Fix-NULL-pointer-dereference-in-object-file.patch.
- commit a239da8
* Mon Apr  7 2025 rgoldwyn@suse.com
- cachefiles: Fix incorrect length return value in cachefiles_ondemand_fd_write_iter()
  (git-fixes).
- Refresh
  patches.suse/cachefiles-Fix-NULL-pointer-dereference-in-object-file.patch.
- commit f7aa4b2
* Mon Apr  7 2025 dsterba@suse.com
- OPP: add index check to assert to avoid buffer overflow in _read_freq() (CVE-2024-57998 bsc#1238527)
- commit ba92a26
* Mon Apr  7 2025 vbabka@suse.cz
- mm/mremap: do not set vrm->vma NULL immediately prior to
  checking it (bsc#1236648).
- commit c9bedf5
* Mon Apr  7 2025 vbabka@suse.cz
- mm/mremap: thread state through move page table operation
  (bsc#1236648).
- commit 587499d
* Mon Apr  7 2025 vbabka@suse.cz
- mm/mremap: refactor move_page_tables(), abstracting state
  (bsc#1236648).
- commit 3e4a075
* Mon Apr  7 2025 vbabka@suse.cz
- mm/mremap: complete refactor of move_vma() (bsc#1236648).
- commit d2e4046
* Mon Apr  7 2025 vbabka@suse.cz
- mm/mremap: initial refactor of move_vma() (bsc#1236648).
- commit 10aa9c0
* Mon Apr  7 2025 vbabka@suse.cz
- mm/mremap: introduce and use vma_remap_struct threaded state
  (bsc#1236648).
- commit d7aa505
* Mon Apr  7 2025 vbabka@suse.cz
- mm/mremap: refactor mremap() system call implementation
  (bsc#1236648).
- commit 3260e42
* Mon Apr  7 2025 vbabka@suse.cz
- mm: clear uffd-wp PTE/PMD state on mremap() (bsc#1236648).
- Refresh
  patches.suse/mm-hugetlb-Add-huge-page-size-param-to-huge_ptep_get_and_clear.patch.
- commit 3eabb30
* Mon Apr  7 2025 vbabka@suse.cz
- mm/mremap: remove goto from mremap_to() (bsc#1236648).
- commit b290f99
* Mon Apr  7 2025 vbabka@suse.cz
- mm/mremap: cleanup vma_to_resize() (bsc#1236648).
- commit 5eeb6b7
* Mon Apr  7 2025 vbabka@suse.cz
- mm/mremap: correctly handle partial mremap() of VMA starting
  at 0 (bsc#1236648).
- commit 0158c20
* Mon Apr  7 2025 vbabka@suse.cz
- mm: make vma cache SLAB_TYPESAFE_BY_RCU (bsc#1236648).
- commit 6632f8f
* Mon Apr  7 2025 vbabka@suse.cz
- mm: prepare lock_vma_under_rcu() for vma reuse possibility
  (bsc#1236648).
- commit 182064f
* Mon Apr  7 2025 vbabka@suse.cz
- mm: remove extra vma_numab_state_init() call (bsc#1236648).
- commit 4fa76bd
* Mon Apr  7 2025 vbabka@suse.cz
- mm/debug: print vm_refcnt state when dumping the vma
  (bsc#1236648).
- commit b0336b4
* Mon Apr  7 2025 vbabka@suse.cz
- mm: move lesser used vma_area_struct members into the last
  cacheline (bsc#1236648).
- Refresh
  patches.suse/kabi-Add-placeholders-to-a-couple-of-important-struc.patch.
- commit 3621034
* Mon Apr  7 2025 vbabka@suse.cz
- mm: replace vm_lock and detached flag with a reference count
  (bsc#1236648).
- Refresh
  patches.suse/kabi-Add-placeholders-to-a-couple-of-important-struc.patch.
- commit 20a4f53
* Mon Apr  7 2025 vbabka@suse.cz
- refcount: introduce
  __refcount_{add|inc}_not_zero_limited_acquire (bsc#1236648).
- commit 7cae058
* Mon Apr  7 2025 vbabka@suse.cz
- refcount: provide ops for cases when object's memory can be
  reused (bsc#1236648).
- commit 65378f2
* Mon Apr  7 2025 vbabka@suse.cz
- mm: uninline the main body of vma_start_write() (bsc#1236648).
- commit 07fd6a8
* Mon Apr  7 2025 vbabka@suse.cz
- mm: move mmap_init_lock() out of the header file (bsc#1236648).
- commit fef8887
* Mon Apr  7 2025 vbabka@suse.cz
- mm: allow vma_start_read_locked/vma_start_read_locked_nested
  to fail (bsc#1236648).
- commit 8ccc607
* Mon Apr  7 2025 vbabka@suse.cz
- types: move struct rcuwait into types.h (bsc#1236648).
- commit aafad00
* Mon Apr  7 2025 vbabka@suse.cz
- mm: mark vmas detached upon exit (bsc#1236648).
- commit f8b68a1
* Mon Apr  7 2025 vbabka@suse.cz
- mm: introduce vma_iter_store_attached() to use with attached
  vmas (bsc#1236648).
- commit 466e36f
* Mon Apr  7 2025 vbabka@suse.cz
- mm: move per-vma lock into vm_area_struct (bsc#1236648).
- Refresh
  patches.suse/kabi-Add-placeholders-to-a-couple-of-important-struc.patch.
- commit 95e3916
* Mon Apr  7 2025 vbabka@suse.cz
- mm: mark vma as detached until it's added into vma tree
  (bsc#1236648).
- commit 73de5d7
* Mon Apr  7 2025 oneukum@suse.com
- usbnet:fix NPE during rx_complete (git-fixes).
- commit 0174b0c
* Mon Apr  7 2025 neelx@suse.com
- Refresh patches.suse/btrfs-fix-use-after-free-waiting-for-encoded-read-en.patch (bsc#1240559).
  There was a trivial typo in commit 0406131af095 ("btrfs: fix use-after-free
  waiting for encoded read endios (bsc#1235128)") while backporting d29662695ed7c.
  This refresh fixes the typo.
- commit 7d8f5ea
* Mon Apr  7 2025 vbabka@suse.cz
- mm/slab/kvfree_rcu: Switch to WQ_MEM_RECLAIM wq (CVE-2025-21983
  bsc#1240792).
- commit 5558350
* Mon Apr  7 2025 vbabka@suse.cz
- mm/huge_memory: drop beyond-EOF folios with the right number
  of refs (CVE-2025-22000 bsc#1240834).
- commit 71ff73e
* Mon Apr  7 2025 vbabka@suse.cz
- mm: abort vma_modify() on merge out of memory failure
  (CVE-2025-21932 bsc#1240707).
- commit b1120f6
* Mon Apr  7 2025 ohering@suse.de
- net: mana: Switch to page pool for jumbo frames (git-fixes).
- net/mana: fix warning in the writer of client oob (git-fixes).
- PCI: hv: Correct a comment (git-fixes).
- net: mana: Add metadata support for xdp mode (git-fixes).
- net: mana: Add debug logs in MANA network driver (git-fixes).
- hv_netvsc: Use VF's tso_max_size value when data path is VF (git-fixes).
- net: mana: Allow tso_max_size to go up-to GSO_MAX_SIZE (git-fixes).
- scsi: storvsc: Don't report the host packet status as the hv status (git-fixes).
- x86/hyperv: fix an indentation issue in mshyperv.h (git-fixes).
- x86/hyperv: Add comments about hv_vpset and var size hypercall input args (git-fixes).
- Drivers: hv: Introduce mshv_root module to expose /dev/mshv to VMMs (git-fixes).
- hyperv: Add definitions for root partition driver to hv headers (git-fixes).
- x86: hyperv: Add mshv_handler() irq handler and setup function (git-fixes).
- Drivers: hv: Introduce per-cpu event ring tail (git-fixes).
- Drivers: hv: Export some functions for use by root partition module (git-fixes).
- acpi: numa: Export node_to_pxm() (git-fixes).
- hyperv: Introduce hv_recommend_using_aeoi() (git-fixes).
- arm64/hyperv: Add some missing functions to arm64 (git-fixes).
- x86/mshyperv: Add support for extended Hyper-V features (git-fixes).
- hyperv: Log hypercall status codes as strings (git-fixes).
- x86/hyperv: Fix check of return value from snp_set_vmsa() (git-fixes).
- x86/hyperv: Add VTL mode callback for restarting the system (git-fixes).
- x86/hyperv: Add VTL mode emergency restart callback (git-fixes).
- hyperv: Remove unused union and structs (git-fixes).
- hyperv: Add CONFIG_MSHV_ROOT to gate root partition support (git-fixes).
- hyperv: Change hv_root_partition into a function (git-fixes).
- hyperv: Convert hypercall statuses to linux error codes (git-fixes).
- drivers/hv: add CPU offlining support (git-fixes).
- drivers/hv: introduce vmbus_channel_set_cpu() (git-fixes).
- cpu: export lockdep_assert_cpus_held() (git-fixes).
- hyperv: Move arch/x86/hyperv/hv_proc.c to drivers/hv (git-fixes).
- hyperv: Move hv_current_partition_id to arch-generic code (git-fixes).
- x86/hyperv: Use named operands in inline asm (git-fixes).
- commit 3716372
* Mon Apr  7 2025 iivanov@suse.de
- ACPI/HMAT: Move HMAT messages to pr_debug() (bsc#1240653)
- commit c3391ab
* Mon Apr  7 2025 jslaby@suse.cz
- x86/microcode/AMD: Fix out-of-bounds on systems with CPU-less
  NUMA nodes (CVE-2025-21991 bsc#1240795).
- x86/amd_nb: Use rdmsr_safe() in amd_get_mmconfig_range()
  (CVE-2025-21913 bsc#1240591).
- commit 222a34e
* Mon Apr  7 2025 neilb@suse.de
- NFS: fix nfs_release_folio() to not deadlock via kcompactd
  writeback (CVE-2025-21908 bsc#1240600).
- commit bfa8b42
* Sun Apr  6 2025 tiwai@suse.de
- Bluetooth: L2CAP: Fix corrupted list in hci_chan_del
  (CVE-2025-21969 bsc#1240784).
- commit d0f474f
* Sun Apr  6 2025 tiwai@suse.de
- Bluetooth: L2CAP: Fix slab-use-after-free Read in l2cap_send_cmd
  (CVE-2025-21969 bsc#1240784).
- iscsi_ibft: Fix UBSAN shift-out-of-bounds warning in
  ibft_attr_show_nic() (CVE-2025-21993 bsc#1240797).
- commit 10fbb41
* Sun Apr  6 2025 tiwai@suse.de
- drm/amdgpu/gfx12: fix num_mec (git-fixes).
- drm/amdgpu/gfx11: fix num_mec (git-fixes).
- drm/amdgpu: Prefer shadow rom when available (git-fixes).
- drm/amd/display: Actually do immediate vblank disable
  (git-fixes).
- drm/amd/display: Increase vblank offdelay for PSR panels
  (git-fixes).
- drm/amd/pm: Prevent division by zero (git-fixes).
- Input: pm8941-pwrkey - fix dev_dbg() output in
  pm8941_pwrkey_irq() (git-fixes).
- Input: synaptics - hide unused smbus_pnp_ids[] array
  (git-fixes).
- commit 33c0e80
* Sat Apr  5 2025 tiwai@suse.de
- ALSA: hda/realtek: Enable Mute LED on HP OMEN 16 Laptop xd000xx
  (stable-fixes).
- ALSA: usb-audio: Add quirk for Plantronics headsets to fix
  control names (stable-fixes).
- ALSA: hda/realtek: Bass speaker fixup for ASUS UM5606KA
  (stable-fixes).
- ALSA: hda/realtek: Support mute LED on HP Laptop 15s-du3xxx
  (stable-fixes).
- commit 1c28dfb
* Sat Apr  5 2025 tiwai@suse.de
- usbnet:fix NPE during rx_complete (git-fixes).
- spi: bcm2835: Restore native CS probing when pinctrl-bcm2835
  is absent (git-fixes).
- spi: bcm2835: Do not call gpiod_put() on invalid descriptor
  (git-fixes).
- spi: cadence: Fix out-of-bounds array access in
  cdns_mrvl_xspi_setup_clock() (git-fixes).
- platform/x86: ISST: Correct command storage data length
  (git-fixes).
- ASoC: imx-card: Add NULL check in imx_card_probe() (git-fixes).
- ASoC: q6apm-dai: make use of q6apm_get_hw_pointer (git-fixes).
- ASoC: qdsp6: q6apm-dai: fix capture pipeline overruns
  (git-fixes).
- ASoC: qdsp6: q6apm-dai: set 10 ms period and buffer alignment
  (git-fixes).
- ASoC: q6apm: add q6apm_get_hw_pointer helper (git-fixes).
- ASoC: q6apm-dai: schedule all available frames to avoid dsp
  under-runs (git-fixes).
- ASoC: codecs: rt5665: Fix some error handling paths in
  rt5665_probe() (git-fixes).
- ASoC: qdsp6: q6asm-dai: fix q6asm_dai_compr_set_params error
  path (git-fixes).
- firmware: cs_dsp: Ensure cs_dsp_load[_coeff]() returns 0 on
  success (git-fixes).
- ALSA: hda/realtek: Fix built-in mic on another ASUS VivoBook
  model (git-fixes).
- ALSA: hda/realtek: Fix built-in mic breakage on ASUS VivoBook
  X515JA (git-fixes).
- commit eb0afe3
* Fri Apr  4 2025 msuchanek@suse.de
- Delete patches.suse/tpm-send_data-Wait-longer-for-the-TPM-to-become-read.patch.
  To be replaced with upstream fix.
- commit 05e2046
* Fri Apr  4 2025 msuchanek@suse.de
- rpm/config.sh: Enable LIVEPATCH_RT
  This will be needed with merged RT branch
- commit 3491368
* Fri Apr  4 2025 vbabka@suse.cz
- tools: add VM_WARN_ON_VMG definition (bsc#1236648).
- commit b9bc574
* Fri Apr  4 2025 vbabka@suse.cz
- seqlock: add missing parameter documentation for
  raw_seqcount_try_begin() (bsc#1236648).
- commit 1a97d75
* Fri Apr  4 2025 vbabka@suse.cz
- mm: introduce mmap_lock_speculate_{try_begin|retry}
  (bsc#1236648).
- commit d7eec4e
* Fri Apr  4 2025 vbabka@suse.cz
- mm: convert mm_lock_seq to a proper seqcount (bsc#1236648).
- commit 5975193
* Fri Apr  4 2025 vbabka@suse.cz
- mm/gup: Use raw_seqcount_try_begin() (bsc#1236648).
- commit 8a17d47
* Fri Apr  4 2025 vbabka@suse.cz
- seqlock: add raw_seqcount_try_begin (bsc#1236648).
- commit 0c393c8
* Fri Apr  4 2025 tbogendoerfer@suse.de
- rtnetlink: Allocate vfinfo size for VF GUIDs when supported
  (bsc#1224013).
- commit 93c2a65
* Fri Apr  4 2025 vbabka@suse.cz
- mm: introduce vma_start_read_locked{_nested} helpers
  (bsc#1236648).
- commit e4c793a
* Fri Apr  4 2025 vbabka@suse.cz
- mm: completely abstract unnecessary adj_start calculation
  (bsc#1236648).
- commit 3a293a4
* Fri Apr  4 2025 vbabka@suse.cz
- mm: make vmg->target consistent and further simplify
  commit_merge() (bsc#1236648).
- commit ce2f380
* Fri Apr  4 2025 vbabka@suse.cz
- mm: eliminate adj_start parameter from commit_merge()
  (bsc#1236648).
- commit 558534f
* Fri Apr  4 2025 vbabka@suse.cz
- mm: further refactor commit_merge() (bsc#1236648).
- commit 093c32c
* Fri Apr  4 2025 vbabka@suse.cz
- mm: simplify vma merge structure and expand comments
  (bsc#1236648).
- commit bd25498
* Fri Apr  4 2025 vbabka@suse.cz
- mm/debug: prefer VM_WARN_ON_VMG() to report VMG debug warnings
  (bsc#1236648).
- commit cd94aee
* Fri Apr  4 2025 mgorman@suse.de
- cpuidle: menu: Update documentation after get_typical_interval()
  changes (bsc#1234634 (Scheduler functional and performance
  backports)).
- commit 930e090
* Fri Apr  4 2025 mgorman@suse.de
- cpuidle: menu: Update documentation after previous changes
  (bsc#1234634 (Scheduler functional and performance backports)).
- commit 65fe202
* Fri Apr  4 2025 vbabka@suse.cz
- mm: make mmap_region() internal (bsc#1236648).
- commit d96d66d
* Fri Apr  4 2025 vbabka@suse.cz
- mm/debug: introduce VM_WARN_ON_VMG() to dump VMA merge state
  (bsc#1236648).
- commit 595e9aa
* Fri Apr  4 2025 vbabka@suse.cz
- mm: remove unnecessary calls to lru_add_drain (bsc#1236648).
- commit 4e1322b
* Fri Apr  4 2025 vbabka@suse.cz
- mm: add comments to do_mmap(), mmap_region() and vm_mmap()
  (bsc#1236648).
- commit f63b0a5
* Fri Apr  4 2025 vbabka@suse.cz
- mm: assert mmap write lock held on do_mmap(), mmap_region()
  (bsc#1236648).
- commit 9aa4cb9
* Fri Apr  4 2025 vbabka@suse.cz
- mm: perform all memfd seal checks in a single place
  (bsc#1236648).
- commit 5547229
* Fri Apr  4 2025 vbabka@suse.cz
- mm: enforce __must_check on VMA merge and split (bsc#1236648).
- commit 68d1342
* Fri Apr  4 2025 msuchanek@suse.de
- kernel-binary: Support livepatch_rt with merged RT branch
- commit 470cd1a
* Fri Apr  4 2025 mgorman@suse.de
- Update and enable
  patches.suse/cpuidle-menu-Bias-selection-of-a-shallower-c-state-when-CPU-idles-for-IO.patch
  (bsc#1193353,bsc#1237425).
- commit 0d14d31
* Fri Apr  4 2025 mgorman@suse.de
- cpuidle: menu: Avoid discarding useful information (bsc#1234634
  (Scheduler functional and performance backports)).
- cpuidle: menu: Eliminate outliers on both ends of the sample set
  (bsc#1234634 (Scheduler functional and performance backports)).
- cpuidle: menu: Tweak threshold use in get_typical_interval()
  (bsc#1234634 (Scheduler functional and performance backports)).
- cpuidle: menu: Use one loop for average and variance
  computations (bsc#1234634 (Scheduler functional and performance
  backports)).
- cpuidle: menu: Drop a redundant local variable (bsc#1234634
  (Scheduler functional and performance backports)).
- cpuidle: menu: Remove iowait influence (bsc#1234634 (Scheduler
  functional and performance backports)).
- commit 49ef926
* Fri Apr  4 2025 vbabka@suse.cz
- mm/vma: move __vm_munmap() to mm/vma.c (bsc#1236648).
- commit 206f77d
* Fri Apr  4 2025 vbabka@suse.cz
- mm/vma: move stack expansion logic to mm/vma.c (bsc#1236648).
- commit eceb38c
* Fri Apr  4 2025 vbabka@suse.cz
- mm: abstract get_arg_page() stack expansion and mmap read lock
  (bsc#1236648).
- commit e7be015
* Fri Apr  4 2025 vbabka@suse.cz
- mm/vma: move unmapped_area() internals to mm/vma.c
  (bsc#1236648).
- commit ae04c39
* Fri Apr  4 2025 vbabka@suse.cz
- mm/vma: move brk() internals to mm/vma.c (bsc#1236648).
- commit 71942ff
* Fri Apr  4 2025 iivanov@suse.de
- arm64: Don't call NULL in do_compat_alignment_fixup() (git-fixes)
- commit 7dce8aa
* Fri Apr  4 2025 iivanov@suse.de
- arm64: mm: Drop dead code for pud special bit handling (git-fixes)
- commit 1f7e15c
* Fri Apr  4 2025 iivanov@suse.de
- arm64: mops: Do not dereference src reg for a set operation (git-fixes)
- commit 41a6490
* Fri Apr  4 2025 iivanov@suse.de
- arm64: mm: Correct the update of max_pfn (git-fixes)
- commit 67d6463
* Fri Apr  4 2025 iivanov@suse.de
- arm64: Utilize for_each_cpu_wrap for reference lookup (bsc#1238052)
- commit e541ce3
* Fri Apr  4 2025 iivanov@suse.de
- arch_topology: init capacity_freq_ref to 0 (bsc#1238052)
- commit 8ce966e
* Fri Apr  4 2025 iivanov@suse.de
- cpufreq: Introduce an optional cpuinfo_avg_freq sysfs entry (bsc#1238052)
  Keep the feature disabled by default on x86_64
- commit 5f4c4bc
* Fri Apr  4 2025 iivanov@suse.de
- cpufreq: Allow arch_freq_get_on_cpu to return an error (bsc#1238052)
- commit 8850fea
* Fri Apr  4 2025 iivanov@suse.de
- arm64: Update AMU-based freq scale factor on entering idle (bsc#1238052)
- commit 50698c9
* Fri Apr  4 2025 iivanov@suse.de
- arm64: Provide an AMU-based version of arch_freq_get_on_cpu (bsc#1238052)
- commit 6a96c9a
* Fri Apr  4 2025 iivanov@suse.de
- arm64: amu: Delay allocating cpumask for AMU FIE support (bsc#1238052)
- commit dd18237
* Fri Apr  4 2025 msuchanek@suse.de
- tpm: tis: Double the timeout B to 4s (bsc#1235870).
- commit 1ff9564
* Fri Apr  4 2025 msuchanek@suse.de
- tpm, tpm_tis: Workaround failed command reception on Infineon
  devices (bsc#1235870).
- commit 76159f7
* Fri Apr  4 2025 tbogendoerfer@suse.de
- Update
  patches.suse/ice-fix-memory-leak-in-aRFS-after-reset.patch
  (jsc#PED-10419 CVE-2025-21981 bsc#1240612).
  Added CVE reference.
- commit a80c7dd
* Fri Apr  4 2025 tbogendoerfer@suse.de
- mctp i3c: handle NULL header address (CVE-2025-21903
  bsc#1240580).
- ppp: Fix KMSAN uninit-value warning with bpf (CVE-2025-21922
  bsc#1240639).
- net: hns3: make sure ptp clock is unregister and freed
  if hclge_ptp_get_cycle returns an error (CVE-2025-21924
  bsc#1240720).
- net: enetc: VFs do not support HWTSTAMP_TX_ONESTEP_SYNC
  (CVE-2025-21894 bsc#1240581).
- commit 4e4dcb0
* Fri Apr  4 2025 tiwai@suse.de
- lib: scatterlist: fix sg_split_phys to preserve original
  scatterlist offsets (git-fixes).
- acpi: nfit: fix narrowing conversion in acpi_nfit_ctl
  (git-fixes).
- commit 298ac86
* Thu Apr  3 2025 ailiop@suse.com
- nfsd: allow SC_STATUS_FREEABLE when searching via
  nfs4_lookup_stateid() (git-fixes).
- commit f2e6ba2
* Thu Apr  3 2025 ailiop@suse.com
- svcrdma: do not unregister device for listeners (git-fixes).
- commit 0694dd5
* Thu Apr  3 2025 ailiop@suse.com
- NFSD: Never return NFS4ERR_FILE_OPEN when removing a directory
  (git-fixes).
- commit 1db7344
* Thu Apr  3 2025 ailiop@suse.com
- NFSD: nfsd_unlink() clobbers non-zero status returned from
  fh_fill_pre_attrs() (git-fixes).
- commit d6e06f3
* Thu Apr  3 2025 ailiop@suse.com
- NFSD: Skip sending CB_RECALL_ANY when the backchannel isn't up
  (git-fixes).
- commit 1f12db0
* Thu Apr  3 2025 ailiop@suse.com
- nfsd: fix management of listener transports (git-fixes).
- commit 57c3828
* Thu Apr  3 2025 ailiop@suse.com
- exfat: fix potential wrong error return from get_block
  (git-fixes).
- commit f7ac77d
* Thu Apr  3 2025 ailiop@suse.com
- exfat: fix missing shutdown check (git-fixes).
- commit bddb6cb
* Thu Apr  3 2025 ailiop@suse.com
- exfat: fix the infinite loop in exfat_find_last_cluster()
  (git-fixes).
- commit 132ac47
* Thu Apr  3 2025 ailiop@suse.com
- exfat: fix random stack corruption after get_block (git-fixes).
- commit 00c87f9
* Thu Apr  3 2025 vkarasulli@suse.de
- rpm/check-for-config-changes: ignore DRM_MSM_VALIDATE_XML
  This option is dynamically enabled to build-test different configurations.
  This makes run_oldconfig.sh complain sporadically for arm64.
- commit 8fbe8b1
* Thu Apr  3 2025 tzimmermann@suse.com
- drm/fbdev-dma: Add shadow buffering for deferred I/O (bsc#1240174 CVE-2024-58091)
  Fix patch to make use of drm_fbdev_dma_helper_fb_probe()
- commit 777c5a6
* Thu Apr  3 2025 jgross@suse.com
- Update config files (jsc#PED-11779).
- commit b834b27
* Thu Apr  3 2025 tiwai@suse.de
- serial: stm32: do not deassert RS485 RTS GPIO prematurely
  (git-fixes).
- serial: 8250_dma: terminate correct DMA in tx_dma_flush()
  (git-fixes).
- tty: serial: fsl_lpuart: disable transmitter before changing
  RS485 related registers (git-fixes).
- staging: rtl8723bs: select CONFIG_CRYPTO_LIB_AES (git-fixes).
- counter: microchip-tcb-capture: Fix undefined counter channel
  state on probe (git-fixes).
- counter: stm32-lptimer-cnt: fix error handling when enabling
  (git-fixes).
- ACPI: x86: Extend Lenovo Yoga Tab 3 quirk with skip GPIO
  event-handlers (git-fixes).
- objtool: Fix verbose disassembly if CROSS_COMPILE isn't set
  (git-fixes).
- objtool: Fix segfault in ignore_unreachable_insn() (git-fixes).
- objtool, media: dib8000: Prevent divide-by-zero in
  dib8000_set_dds() (git-fixes).
- objtool, spi: amd: Fix out-of-bounds stack access in
  amd_set_spi_freq() (git-fixes).
- serial: stm32: do not deassert RS485 RTS GPIO prematurely
  (git-fixes).
- serial: 8250_dma: terminate correct DMA in tx_dma_flush()
  (git-fixes).
- tty: serial: fsl_lpuart: disable transmitter before changing
  RS485 related registers (git-fixes).
- staging: rtl8723bs: select CONFIG_CRYPTO_LIB_AES (git-fixes).
- counter: microchip-tcb-capture: Fix undefined counter channel
  state on probe (git-fixes).
- counter: stm32-lptimer-cnt: fix error handling when enabling
  (git-fixes).
- ACPI: x86: Extend Lenovo Yoga Tab 3 quirk with skip GPIO
  event-handlers (git-fixes).
- objtool: Fix verbose disassembly if CROSS_COMPILE isn't set
  (git-fixes).
- objtool: Fix segfault in ignore_unreachable_insn() (git-fixes).
- objtool, media: dib8000: Prevent divide-by-zero in
  dib8000_set_dds() (git-fixes).
- objtool, spi: amd: Fix out-of-bounds stack access in
  amd_set_spi_freq() (git-fixes).
- commit 72b8c37
* Thu Apr  3 2025 tiwai@suse.de
- Move upstreamed ACPI patch into sorted section
- commit 8422d4a
* Thu Apr  3 2025 oneukum@suse.com
- usb: xhci: correct debug message page size calculation
  (git-fixes).
- commit 762b059
* Thu Apr  3 2025 oneukum@suse.com
- usb: xhci: Don't skip on Stopped - Length Invalid (git-fixes).
- commit fa33a12
* Thu Apr  3 2025 oneukum@suse.com
- ucsi_ccg: Don't show failed to get FW build information error
  (git-fixes).
- commit b624e76
* Thu Apr  3 2025 oneukum@suse.com
- usb: typec: thunderbolt: Remove IS_ERR check for plug
  (git-fixes).
- commit 8424de6
* Thu Apr  3 2025 oneukum@suse.com
- usb: typec: thunderbolt: Fix loops that iterate TYPEC_PLUG_SOP_P
  and TYPEC_PLUG_SOP_PP (git-fixes).
- commit 3a55100
* Thu Apr  3 2025 wqu@suse.com
- btrfs: fix mount failure due to remount races (bsc#1240564).
- commit 2f2a4ad
* Thu Apr  3 2025 ddiss@suse.de
- config: drop CONFIG_INITRAMFS_PRESERVE_MTIME (bsc#1240389)
- commit afb8ef9
* Thu Apr  3 2025 mkubecek@suse.cz
- net: better track kernel sockets lifetime (CVE-2025-21884
  bsc#1240171).
- net: Add net_passive_inc() and net_passive_dec() (CVE-2025-21884
  bsc#1240171).
- commit 0a2a220
* Wed Apr  2 2025 ematsumiya@suse.de
- smb: During unmount, ensure all cached dir instances drop
  their dentry (bsc#1234894, CVE-2024-53176).
- commit 1197dc4
* Wed Apr  2 2025 ematsumiya@suse.de
- smb: prevent use-after-free due to open_cached_dir error paths
  (bsc#1234896, CVE-2024-53177).
- commit 418a7db
* Wed Apr  2 2025 ematsumiya@suse.de
- smb: Don't leak cfid when reconnect races with open_cached_dir
  (bsc#1234895, CVE-2024-53178).
- commit 1515dee
* Wed Apr  2 2025 oneukum@suse.com
- net: usb: usbnet: restore usb%%d name exception for local mac
  addresses (bsc#1234480).
- commit d54d858
* Wed Apr  2 2025 jslaby@suse.cz
- PCI: Allow relaxed bridge window tail sizing for optional
  resources (git-fixes).
- PCI: Simplify size1 assignment logic (git-fixes).
- PCI: mediatek-gen3: Rely on msleep() in
  mtk_pcie_en7581_power_up() (git-fixes).
- Refresh
  patches.suse/PCI-mediatek-gen3-Configure-PBUS_CSR-registers-for-E.patch.
- commit ae9c470
* Wed Apr  2 2025 nik.borisov@suse.com
- EDAC/ie31200: Switch Raptor Lake-S to interrupt mode (jsc#PED-10928).
- commit c9941a8
* Wed Apr  2 2025 nik.borisov@suse.com
- EDAC/ie31200: Add Intel Raptor Lake-S SoCs support (jsc#PED-10928).
- commit f51c2b8
* Wed Apr  2 2025 nik.borisov@suse.com
- EDAC/ie31200: Break up ie31200_probe1() (jsc#PED-10928).
- commit 62ea605
* Wed Apr  2 2025 nik.borisov@suse.com
- EDAC/ie31200: Fold the two channel loops into one loop (jsc#PED-10928).
- commit 6e2b5ee
* Wed Apr  2 2025 nik.borisov@suse.com
- EDAC/ie31200: Make struct dimm_data contain decoded information (jsc#PED-10928).
- commit 325dfcf
* Wed Apr  2 2025 nik.borisov@suse.com
- EDAC/ie31200: Make the memory controller resources configurable (jsc#PED-7619).
- commit eae70e1
* Wed Apr  2 2025 nik.borisov@suse.com
- EDAC/ie31200: work around false positive build warning (jsc#PED-7619).
- commit 7dc9d30
* Wed Apr  2 2025 nik.borisov@suse.com
- EDAC/ie31200: Simplify the pci_device_id table (jsc#PED-10928).
- commit 48616aa
* Wed Apr  2 2025 nik.borisov@suse.com
- EDAC/ie31200: Fix the 3rd parameter name of *populate_dimm_info() (jsc#PED-10928).
- commit 5eb75d7
* Wed Apr  2 2025 nik.borisov@suse.com
- EDAC/ie31200: Fix the error path order of ie31200_init() (jsc#PED-10928).
- commit b6e74b6
* Wed Apr  2 2025 nik.borisov@suse.com
- EDAC/ie31200: Fix the DIMM size mask for several SoCs (jsc#PED-10928).
- commit 362d87f
* Wed Apr  2 2025 nik.borisov@suse.com
- EDAC/ie31200: Fix the size of EDAC_MC_LAYER_CHIP_SELECT layer (jsc#PED-10928).
- commit 081264d
* Wed Apr  2 2025 nik.borisov@suse.com
- Delete patches.suse/RAS-AMD-FMPM-Fix-build-when-debugfs-is-not-enabled.patch.
  It's not needed as the kernel includes the upstream fix from
  a6b227d70d2a ("RAS: Avoid build errors when CONFIG_DEBUG_FS=n")
- commit 5f22656
* Wed Apr  2 2025 tiwai@suse.de
- selftests: mptcp: close fd_in before returning in main_loop
  (git-fixes).
- selftests: mptcp: fix incorrect fd checks in main_loop
  (git-fixes).
- net: phy: broadcom: Correct BCM5221 PHY model detection
  (git-fixes).
- rndis_host: Flag RNDIS modems as WWAN devices (git-fixes).
- thermal/drivers/mediatek/lvts: Disable Stage 3 thermal threshold
  (git-fixes).
- thermal/drivers/mediatek/lvts: Disable monitor mode during
  suspend (git-fixes).
- thermal: core: Remove duplicate struct declaration (git-fixes).
- thermal/drivers/rockchip: Add missing rk3328 mapping entry
  (git-fixes).
- i3c: Add NULL pointer check in i3c_master_queue_ibi()
  (git-fixes).
- i3c: master: svc: Use readsb helper for reading MDB (git-fixes).
- i3c: master: svc: Fix missing the IBI rules (git-fixes).
- dmaengine: fsl-edma: free irq correctly in remove path
  (git-fixes).
- dmaengine: fsl-edma: cleanup chan after
  dma_async_device_unregister (git-fixes).
- phy: freescale: imx8m-pcie: assert phy reset and perst in
  power off (git-fixes).
- phy: phy-rockchip-samsung-hdptx: Don't use dt aliases to
  determine phy-id (git-fixes).
- soundwire: slave: fix an OF node reference leak in soundwire
  slave device (git-fixes).
- w1: fix NULL pointer dereference in probe (git-fixes).
- bus: mhi: host: Fix race between unprepare and queue_buf
  (git-fixes).
- iio: light: Add check for array bounds in
  veml6075_read_int_time_ms (git-fixes).
- iio: adc: ad7768-1: set MOSI idle state to prevent accidental
  reset (git-fixes).
- iio: adc: ad7173: Fix comparison of channel configs (git-fixes).
- iio: adc: ad7124: Fix comparison of channel configs (git-fixes).
- iio: adc: ad4130: Fix comparison of channel setups (git-fixes).
- iio: backend: make sure to NULL terminate stack buffer
  (git-fixes).
- iio: accel: msa311: Fix failure to release runtime pm if direct
  mode claim fails (git-fixes).
- iio: accel: mma8452: Ensure error return on failure to matching
  oversampling ratio (git-fixes).
- driver core: Remove needless return in void API
  device_remove_group() (git-fixes).
- docs: thermal: sync hardware protection doc with code
  (git-fixes).
- selftests/mm/cow: fix the incorrect error handling (git-fixes).
- maple_tree: remove a BUG_ON() in mas_alloc_nodes() (git-fixes).
- selftests/mm: fix thuge-gen test name uniqueness (git-fixes).
- commit e915f3b
* Wed Apr  2 2025 nmorey@suse.com
- disable erdma driver (jsc#PED-12235)
- commit b893010
* Wed Apr  2 2025 nmorey@suse.com
- mark SIW and RXE as not supported (jsc#PED-12026)
- commit 7ca3899
* Tue Apr  1 2025 dsterba@suse.com
- uprobes: Reject the shared zeropage in uprobe_write_opcode() (CVE-2025-21881 bsc#1240185)
- commit 7d7f5f2
* Tue Apr  1 2025 dsterba@suse.com
- scsi: ufs: core: bsg: Fix crash when arpmb command fails (CVE-2025-21873 bsc#1240184)
- commit 8a3801b
* Tue Apr  1 2025 pjakobsson@suse.de
- supported.conf: Mark habanalabs drivers as supported (jsc#PED-10735)
- commit 83e7063
* Tue Apr  1 2025 msuchanek@suse.de
- rpm/release-projects: Update the ALP projects again (bsc#1231293).
- commit a2f9145
* Tue Apr  1 2025 trenn@suse.de
- platform/x86/intel/pmc: Add Arrow Lake U/H support to
  intel_pmc_core driver (jsc#PED-10628).
- commit 507d3c4
* Tue Apr  1 2025 trenn@suse.de
- platform/x86/intel/pmc: Remove simple init functions
  (jsc#PED-10628).
- commit 8c62b6b
* Tue Apr  1 2025 trenn@suse.de
- platform/x86:intel/pmc: Create generic_core_init() for all
  platforms (jsc#PED-10628).
- commit ea95203
* Tue Apr  1 2025 trenn@suse.de
- platform/x86/intel/pmc: Remove duplicate enum (jsc#PED-10628).
- commit e3e65be
* Tue Apr  1 2025 trenn@suse.de
- platform/x86:intel/pmc: Make tgl_core_generic_init() static
  (jsc#PED-10628).
- commit c7ac508
* Tue Apr  1 2025 shung-hsi.yu@suse.com
- Refresh patches.suse/kABI-padding-for-bpf.patch.
- Refresh and renable kABI padding for BPF
- Add padding for 'struct bpf_verifier_state'
- commit ae782d1
* Tue Apr  1 2025 shung-hsi.yu@suse.com
- Delete
  patches.suse/selftests-bpf-user_ringbuf-define-c_ringbuf_size.patch.
  SUSE-2025 uses GCC 13, so this workaround is no longer required.
- commit 3707020
* Tue Apr  1 2025 shung-hsi.yu@suse.com
- Delete
  patches.suse/selftests-bpf-lsm_cgroup-define-sockaddr_ll.patch.
  Switching to using kernel config found in tools/testing/selftests/bpf/
  instead, so this definition is no longer needed.
- commit 6df9702
* Tue Apr  1 2025 shung-hsi.yu@suse.com
- bpf: Add tracepoints with null-able arguments (bsc#1235501
  CVE-2024-56702).
- commit c49f936
* Mon Mar 31 2025 dsterba@suse.com
- ovl: fix UAF in ovl_dentry_update_reval by moving dput() in ovl_link_up (CVE-2025-21887 bsc#1240176)
- commit aefb37c
* Mon Mar 31 2025 dsterba@suse.com
- mptcp: always handle address removal under msk socket lock (CVE-2025-21875 bsc#1240168)
- commit 30269f0
* Mon Mar 31 2025 dsterba@suse.com
- perf/core: Add RCU read lock protection to perf_iterate_ctx() (CVE-2025-21889 bsc#1240167)
- commit 68c5afe
* Mon Mar 31 2025 dsterba@suse.com
- Update references for patches.suse/nvkm-correctly-calculate-the-available-space-of-the-.patch (CVE-2024-58018 bsc#1238990 stable-fixes)
- commit 5d4613b
* Mon Mar 31 2025 dsterba@suse.com
- team: prevent adding a device which is already a team device lower (CVE-2024-58071 bsc#1238970)
- commit e1c6462
* Mon Mar 31 2025 dwagner@suse.de
- nvme-tcp: Fix a C2HTermReq error message (git-fixes).
- commit 1aeab84
* Mon Mar 31 2025 dwagner@suse.de
- nvmet-fc: Remove unused functions (git-fixes).
- nvme-pci: remove stale comment (git-fixes).
- nvme: move error logging from nvme_end_req() to __nvme_end_req()
  (git-fixes).
- nvme-tcp: fix signedness bug in nvme_tcp_init_connection()
  (git-fixes).
- nvmet-tcp: Fix a possible sporadic response drops in weakly
  ordered arch (git-fixes).
- nvme-tcp: fix potential memory corruption in nvme_tcp_recv_pdu()
  (git-fixes).
- nvmet: remove old function prototype (git-fixes).
- nvme-ioctl: fix leaked requests on mapping error (git-fixes).
- nvme: only allow entering LIVE from CONNECTING state (git-fixes
  bsc#1222649).
- nvme-fc: rely on state transitions to handle connectivity loss
  (git-fixes bsc#1222649).
- nvmet-rdma: recheck queue state is LIVE in state lock in recv
  done (git-fixes).
- nvme-tcp: add basic support for the C2HTermReq PDU (git-fixes).
- nvme-pci: quirk Acer FA100 for non-uniqueue identifiers
  (git-fixes).
- nvme-fc: do not ignore connectivity loss during connecting
  (git-fixes bsc#1222649).
- nvme-fc: go straight to connecting state when initializing
  (git-fixes bsc#1222649).
- nvme-pci: use sgls for all user requests if possible
  (git-fixes).
- nvme-pci: add support for sgl metadata (git-fixes).
- commit af2f0ab
* Mon Mar 31 2025 dwagner@suse.de
- series: update metadata
- Refresh
  patches.suse/ARM-module-Use-RCU-in-all-users-of-__module_text_address.patch.
- Refresh
  patches.suse/Documentation-powerpc-fadump-add-additional-paramete.patch.
- Refresh
  patches.suse/arm-Rely-on-generic-printing-of-preemption-model.patch.
- Refresh
  patches.suse/arm64-Rely-on-generic-printing-of-preemption-model.patch.
- Refresh
  patches.suse/arm64-module-Use-RCU-in-all-users-of-__module_text_address.patch.
- Refresh
  patches.suse/bpf-Use-RCU-in-all-users-of-__module_text_address.patch.
- Refresh
  patches.suse/bug-Use-RCU-instead-RCU-sched-to-protect-module_bug_list.patch.
- Refresh
  patches.suse/cfi-Use-RCU-while-invoking-__module_address.patch.
- Refresh
  patches.suse/jump_label-Use-RCU-in-all-users-of-__module_address.patch.
- Refresh
  patches.suse/jump_label-Use-RCU-in-all-users-of-__module_text_address.patch.
- Refresh
  patches.suse/kprobes-Use-RCU-in-all-users-of-__module_text_address.patch.
- Refresh patches.suse/lib-dump_stack-Use-preempt_model_str.patch.
- Refresh
  patches.suse/module-Allow-__module_address-to-be-called-from-RCU-section.patch.
- Refresh
  patches.suse/module-Begin-to-move-from-RCU-sched-to-RCU.patch.
- Refresh
  patches.suse/module-Remove-module_assert_mutex_or_preempt-from-try_add_tainted_module.patch.
- Refresh
  patches.suse/module-Use-RCU-in-__find_kallsyms_symbol_value.patch.
- Refresh
  patches.suse/module-Use-RCU-in-__is_module_percpu_address.patch.
- Refresh
  patches.suse/module-Use-RCU-in-all-users-of-__module_address.patch.
- Refresh
  patches.suse/module-Use-RCU-in-all-users-of-__module_text_address.patch.
- Refresh
  patches.suse/module-Use-RCU-in-find_kallsyms_symbol.patch.
- Refresh patches.suse/module-Use-RCU-in-find_module_all.patch.
- Refresh patches.suse/module-Use-RCU-in-find_symbol.patch.
- Refresh patches.suse/module-Use-RCU-in-module_get_kallsym.patch.
- Refresh
  patches.suse/module-Use-RCU-in-module_kallsyms_on_each_symbol.patch.
- Refresh
  patches.suse/module-Use-RCU-in-search_module_extables.patch.
- Refresh
  patches.suse/module-Use-proper-RCU-assignment-in-add_kallsyms.patch.
- Refresh
  patches.suse/powerpc-Document-details-on-H_HTM-hcall.patch.
- Refresh
  patches.suse/powerpc-Rely-on-generic-printing-of-preemption-model.patch.
- Refresh patches.suse/powerpc-export-MIN-RMA-size.patch.
- Refresh
  patches.suse/powerpc-fadump-fix-additional-param-memory-reservati.patch.
- Refresh
  patches.suse/powerpc-increase-MIN-RMA-size-for-CAS-negotiation.patch.
- Refresh
  patches.suse/powerpc-pseries-Export-hardware-trace-macro-dump-via.patch.
- Refresh
  patches.suse/powerpc-pseries-Macros-and-wrapper-functions-for-H_H.patch.
- Refresh
  patches.suse/powerpc-pseries-iommu-memory-notifier-incorrectly-ad.patch.
- Refresh
  patches.suse/s390-Rely-on-generic-printing-of-preemption-model.patch.
- Refresh
  patches.suse/sched-Add-a-generic-function-to-return-the-preemption-string.patch.
- Refresh
  patches.suse/sched-Add-unlikey-branch-hints-to-several-system-calls.patch.
- Refresh
  patches.suse/sched-Cancel-the-slice-protection-of-the-idle-entity.patch.
- Refresh
  patches.suse/sched-Don-t-define-sched_clock_irqtime-as-static-key.patch.
- Refresh
  patches.suse/sched-Reduce-the-default-slice-to-avoid-tasks-getting-an-extra-tick.patch.
- Refresh
  patches.suse/sched-core-Remove-duplicate-included-header-file-stats.h.patch.
- Refresh
  patches.suse/sched-eevdf-Force-propagating-min_slice-of-cfs_rq-when-en-de-queue-tasks.patch.
- Refresh
  patches.suse/sched-fair-Refactor-can_migrate_task-to-elimate-looping.patch.
- Refresh
  patches.suse/sched-membarrier-Fix-redundant-load-of-membarrier_st.patch.
- Refresh
  patches.suse/static_call-Use-RCU-in-all-users-of-__module_text_address.patch.
- Refresh patches.suse/tracing-Use-preempt_model_str.patch.
- Refresh
  patches.suse/x86-Rely-on-generic-printing-of-preemption-model.patch.
- Refresh
  patches.suse/x86-Use-RCU-in-all-users-of-__module_address.patch.
- Refresh
  patches.suse/x86-tsc-Always-save-restore-TSC-sched_clock-on-suspend-resume.patch.
- Refresh
  patches.suse/xtensa-Rely-on-generic-printing-of-preemption-model.patch.
- commit 50abd21
* Mon Mar 31 2025 iivanov@suse.de
- arm64: cputype: Add MIDR_CORTEX_A76AE (git-fixes)
- commit 12c538d
* Mon Mar 31 2025 tzimmermann@suse.com
- drm/fbdev-dma: Add shadow buffering for deferred I/O (bsc#1240174 CVE-2024-58091)
- commit 81b755a
* Mon Mar 31 2025 iivanov@suse.de
- arm64: dts: rockchip: Fix PWM pinctrl names (git-fixes)
- commit e826378
* Mon Mar 31 2025 iivanov@suse.de
- arm64: dts: rockchip: Remove bluetooth node from rock-3a (git-fixes)
- commit 1354fe4
* Mon Mar 31 2025 iivanov@suse.de
- arm64: dts: imx8mp: change AUDIO_AXI_CLK_ROOT freq. to 800MHz (git-fixes)
- commit 9607ffc
* Mon Mar 31 2025 iivanov@suse.de
- arm64: dts: imx8mp: add AUDIO_AXI_CLK_ROOT to AUDIOMIX block (git-fixes)
- commit 79b8eb1
* Mon Mar 31 2025 iivanov@suse.de
- arm64: dts: imx8mp-skov: operate CPU at 850 mV by default (git-fixes)
- commit 54699e8
* Mon Mar 31 2025 iivanov@suse.de
- arm64: dts: imx8mp-skov: correct PMIC board limits (git-fixes)
- commit 864f35b
* Mon Mar 31 2025 iivanov@suse.de
- arm64: dts: exynos: gs101: disable pinctrl_gsacore node (git-fixes)
- commit ea03073
* Mon Mar 31 2025 iivanov@suse.de
- arm64: tegra: Remove the Orin NX/Nano suspend key (git-fixes)
- commit 5f41ffa
* Mon Mar 31 2025 iivanov@suse.de
- arm64/boot: Enable EL2 requirements for FEAT_PMUv3p9 (git-fixes)
- commit b053f6d
* Mon Mar 31 2025 iivanov@suse.de
- arm64: errata: Add newer ARM cores to the spectre_bhb_loop_affected() (git-fixes)
- commit 581e653
* Mon Mar 31 2025 iivanov@suse.de
- arm64: errata: Add KRYO 2XX/3XX/4XX silver cores to Spectre BHB safe (git-fixes)
- commit 4a0576a
* Mon Mar 31 2025 iivanov@suse.de
- arm64: errata: Assume that unknown CPUs _are_ vulnerable to Spectre (git-fixes)
- commit a914636
* Mon Mar 31 2025 iivanov@suse.de
- arm64: errata: Add QCOM_KRYO_4XX_GOLD to the spectre_bhb_k24_list (git-fixes)
- commit 318ba4c
* Mon Mar 31 2025 tbogendoerfer@suse.de
- bitmap: Align documentation between bitmap_gather() and
  bitmap_scatter() (git-fixes).
- commit 5ae3c5e
* Mon Mar 31 2025 tbogendoerfer@suse.de
- ipvlan: ensure network headers are in skb linear part
  (CVE-2025-21891 bsc#1240186).
- commit be4e602
* Mon Mar 31 2025 tiwai@suse.de
- Update config files: Enable CONFIG_FRAMEBUFFER_CONSOLE_DEFERRED_TAKEOVER (bsc#1237220)
- commit c79d4b3
* Mon Mar 31 2025 jlee@suse.com
- Update
  patches.suse/ASoC-SOF-ipc4-topology-Harden-loops-for-looking-up-A.patch
  (git-fixes CVE-2025-21870 bsc#1240191).
- Update
  patches.suse/RDMA-bnxt_re-Fix-the-page-details-for-the-srq-create.patch
  (jsc#PED-10684 jsc#PED-11230 CVE-2025-21885 bsc#1240169).
- Update
  patches.suse/RDMA-mlx5-Fix-a-WARN-during-dereg_mr-for-DM-type.patch
  (git-fixes CVE-2025-21888 bsc#1240177).
- Update
  patches.suse/RDMA-mlx5-Fix-implicit-ODP-hang-on-parent-deregistra.patch
  (git-fixes CVE-2025-21886 bsc#1240188).
- Update
  patches.suse/RDMA-mlx5-Fix-the-recovery-flow-of-the-UMR-QP.patch
  (git-fixes CVE-2025-21892 bsc#1240175).
- Update
  patches.suse/ata-libata-sff-Ensure-that-we-cannot-write-outside-t.patch
  (git-fixes CVE-2025-21738 bsc#1238917).
- Update
  patches.suse/cpufreq-amd-pstate-Fix-cpufreq_policy-ref-counting.patch
  (git-fixes CVE-2025-21841 bsc#1239062).
- Update
  patches.suse/dm-integrity-Avoid-divide-by-zero-in-table-status-in.patch
  (git-fixes CVE-2025-21874 bsc#1240190).
- Update patches.suse/drm-xe-userptr-fix-EFAULT-handling.patch
  (git-fixes CVE-2025-21880 bsc#1240170).
- Update
  patches.suse/i2c-npcm-disable-interrupt-enable-bit-before-devm_re.patch
  (git-fixes CVE-2025-21878 bsc#1240192).
- Update
  patches.suse/ice-Fix-deinitializing-VF-in-error-path.patch
  (jsc#PED-10419 CVE-2025-21883 bsc#1240189).
- Update patches.suse/idpf-fix-checksums-set-in-idpf_rx_rsc.patch
  (jsc#PED-10581 CVE-2025-21890 bsc#1240173).
- Update patches.suse/iommu-vt-d-Fix-suspicious-RCU-usage.patch
  (git-fixes CVE-2025-21876 bsc#1240179).
- Update
  patches.suse/net-mlx5-Fix-vport-QoS-cleanup-on-error.patch
  (jsc#PED-11331 CVE-2025-21882 bsc#1240187).
- Update
  patches.suse/powerpc-code-patching-Disable-KASAN-report-during-pa.patch
  (bsc#1215199 CVE-2025-21869 bsc#1240182).
- Update
  patches.suse/usbnet-gl620a-fix-endpoint-checking-in-genelink_bind.patch
  (git-fixes CVE-2025-21877 bsc#1240172).
- commit 608a30b
* Mon Mar 31 2025 jlee@suse.com
- Update
  patches.suse/media-vidtv-Fix-a-null-ptr-deref-in-vidtv_mux_stop_t.patch
  (git-fixes CVE-2024-57834 bsc#1238993).
- Update
  patches.suse/nvkm-correctly-calculate-the-available-space-of-the-.patch
  (stable-fixes CVE-2024-58018 bsc#1238990).
- commit 60408e9
* Mon Mar 31 2025 nmorey@suse.com
- IB/mad: Check available slots before posting receive WRs (git-fixes)
- commit 89aff72
* Mon Mar 31 2025 nmorey@suse.com
- RDMA/mlx5: Fix calculation of total invalidated pages (git-fixes)
- commit d8fa607
* Mon Mar 31 2025 nmorey@suse.com
- RDMA/mlx5: Fix mlx5_poll_one() cur_qp update flow (git-fixes)
- commit 7a3d709
* Mon Mar 31 2025 nmorey@suse.com
- RDMA/mlx5: Fix page_size variable overflow (git-fixes)
- commit d686296
* Mon Mar 31 2025 nmorey@suse.com
- RDMA/mlx5: Fix cache entry update on dereg error (git-fixes)
- commit 5b61d30
* Mon Mar 31 2025 nmorey@suse.com
- RDMA/mlx5: Fix MR cache initialization error flow (git-fixes)
- commit 977d207
* Mon Mar 31 2025 nmorey@suse.com
- RDMA/core: Fix use-after-free when rename device name (git-fixes)
- commit e693f34
* Mon Mar 31 2025 nmorey@suse.com
- RDMA/erdma: Prevent use-after-free in erdma_accept_newconn() (git-fixes)
- commit a2f7db1
* Mon Mar 31 2025 nmorey@suse.com
- RDMA/core: Don't expose hw_counters outside of init net namespace (git-fixes)
- commit ac060af
* Sun Mar 30 2025 tiwai@suse.de
- Move upstreamed patches into sorted section
- commit aabb1e8
* Sun Mar 30 2025 tiwai@suse.de
- crypto: qat - add shutdown handler to qat_c3xxx (bsc#1239934).
- crypto: qat - remove redundant prototypes in qat_c3xxx
  (bsc#1239934).
- crypto: qat - add shutdown handler to qat_c62x (bsc#1239934).
- crypto: qat - remove redundant prototypes in qat_c62x
  (bsc#1239934).
- crypto: qat - add shutdown handler to qat_dh895xcc
  (bsc#1239934).
- crypto: qat - remove redundant prototypes in qat_dh895xcc
  (bsc#1239934).
- crypto: qat - add shutdown handler to qat_420xx (bsc#1239934).
- crypto: qat - add shutdown handler to qat_4xxx (bsc#1239934).
- commit 94c5984
* Sun Mar 30 2025 tiwai@suse.de
- mailbox: tegra-hsp: Define dimensioning masks in SoC data
  (git-fixes).
- power: supply: max77693: Fix wrong conversion of charge input
  threshold value (git-fixes).
- power: supply: bq27xxx_battery: do not update cached flags
  prematurely (git-fixes).
- remoteproc: qcom_q6v5_pas: Make single-PD handling more robust
  (git-fixes).
- remoteproc: qcom_q6v5_pas: Use resource with CX PD for MSM8226
  (git-fixes).
- remoteproc: core: Clear table_sz when rproc_shutdown
  (git-fixes).
- remoteproc: qcom: pas: add minidump_id to SC7280 WPSS
  (git-fixes).
- remoteproc: qcom_q6v5_mss: Handle platforms with one power
  domain (git-fixes).
- pinctrl: npcm8xx: Fix incorrect struct npcm8xx_pincfg assignment
  (git-fixes).
- pinctrl: samsung: add support for eint_fltcon_offset
  (git-fixes).
- pinctrl: qcom: Clear latched interrupt status when changing
  IRQ type (git-fixes).
- pinctrl: tegra: Set SFIO mode to Mux Register (git-fixes).
- pinctrl: intel: Fix wrong bypass assignment in
  intel_pinctrl_probe_pwm() (git-fixes).
- pinctrl: renesas: rza2: Fix missing of_node_put() call
  (git-fixes).
- pinctrl: renesas: rzv2m: Fix missing of_node_put() call
  (git-fixes).
- pinctrl: renesas: rzg2l: Fix missing of_node_put() call
  (git-fixes).
- pinctrl: renesas: rzg2l: Suppress binding attributes
  (git-fixes).
- pinctrl: nuvoton: npcm8xx: Fix error handling in
  npcm8xx_gpio_fw() (git-fixes).
- leds: rgb: leds-qcom-lpg: Fix calculation of best period Hi-Res
  PWMs (git-fixes).
- mfd: ene-kb3930: Fix a potential NULL pointer dereference
  (git-fixes).
- mfd: sm501: Switch to BIT() to mitigate integer overflows
  (git-fixes).
- of: property: Increase NR_FWNODE_REFERENCE_ARGS (git-fixes).
- of/irq: Fix device node refcount leakages in of_irq_init()
  (git-fixes).
- of/irq: Fix device node refcount leakage in API
  irq_of_parse_and_map() (git-fixes).
- of/irq: Fix device node refcount leakages in of_irq_count()
  (git-fixes).
- of/irq: Fix device node refcount leakage in API
  of_irq_parse_raw() (git-fixes).
- of/irq: Fix device node refcount leakage in API
  of_irq_parse_one() (git-fixes).
- lib: 842: Improve error handling in sw842_compress()
  (git-fixes).
- commit f260551
* Sun Mar 30 2025 tiwai@suse.de
- backlight: led_bl: Hold led_access lock when calling
  led_sysfs_disable() (git-fixes).
- leds: rgb: leds-qcom-lpg: Fix pwm resolution max for Hi-Res PWMs
  (git-fixes).
- leds: Fix LED_OFF brightness race (git-fixes).
- Revert "leds-pca955x: Remove the unused function
  pca95xx_num_led_regs()" (stable-fixes).
- crypto: nx - Fix uninitialised hv_nxc on error (git-fixes).
- crypto: qat - remove access to parity register for QAT GEN4
  (git-fixes).
- crypto: qat - set parity error mask for qat_420xx (git-fixes).
- crypto: ccp - Fix uAPI definitions of PSP errors (git-fixes).
- crypto: iaa - Test the correct request flag (git-fixes).
- crypto: tegra - Use HMAC fallback when keyslots are full
  (git-fixes).
- crypto: tegra - Set IV to NULL explicitly for AES ECB
  (git-fixes).
- crypto: tegra - Fix CMAC intermediate result handling
  (git-fixes).
- crypto: tegra - check return value for hash do_one_req
  (git-fixes).
- crypto: tegra - Use separate buffer for setkey (git-fixes).
- crypto: bpf - Add MODULE_DESCRIPTION for skcipher (git-fixes).
- crypto: api - Fix larval relookup type and mask (git-fixes).
- crypto: hisilicon/sec2 - fix for sec spec check (git-fixes).
- crypto: hisilicon/sec2 - fix for aead authsize alignment
  (git-fixes).
- crypto: hisilicon/sec2 - fix for aead auth key length
  (git-fixes).
- commit aa5d485
* Sat Mar 29 2025 ailiop@suse.com
- landlock: Add erratum for TCP fix (git-fixes).
- commit 0d484c7
* Sat Mar 29 2025 ailiop@suse.com
- ocfs2: fix incorrect CPU endianness conversion causing mount
  failure (git-fixes).
- commit 8fd90d0
* Sat Mar 29 2025 ailiop@suse.com
- ocfs2: mark dquot as inactive if failed to start trans while
  releasing dquot (git-fixes).
- commit cc37a55
* Sat Mar 29 2025 ailiop@suse.com
- ocfs2: handle a symlink read error correctly (git-fixes).
- commit 444eb1b
* Sat Mar 29 2025 ailiop@suse.com
- ocfs2: check dir i_size in ocfs2_find_entry (git-fixes).
- commit c0e37b2
* Sat Mar 29 2025 ailiop@suse.com
- ocfs2: fix the space leak in LA when releasing LA (git-fixes).
- commit 1a397ea
* Sat Mar 29 2025 ailiop@suse.com
- ocfs2: update seq_file index in ocfs2_dlm_seq_next (git-fixes).
- commit 036dd0b
* Sat Mar 29 2025 ailiop@suse.com
- selftests/landlock: Add a new test for setuid() (git-fixes).
- commit 01c306d
* Sat Mar 29 2025 ailiop@suse.com
- selftests/landlock: Split signal_scoping_threads tests
  (git-fixes).
- commit 523b194
* Sat Mar 29 2025 ailiop@suse.com
- landlock: Always allow signals between threads of the same
  process (git-fixes).
- commit 1745380
* Sat Mar 29 2025 ailiop@suse.com
- landlock: Prepare to add second errata (git-fixes).
- commit 7565437
* Sat Mar 29 2025 ailiop@suse.com
- landlock: Add the errata interface (git-fixes).
- commit ab61616
* Sat Mar 29 2025 ailiop@suse.com
- landlock: Move code to ease future backports (git-fixes).
- commit 8bc7b59
* Sat Mar 29 2025 ailiop@suse.com
- landlock: Fix non-TCP sockets restriction (git-fixes).
- commit 10f3a13
* Sat Mar 29 2025 ailiop@suse.com
- dlm: fix error if active rsb is not hashed (git-fixes).
- commit dde3f38
* Sat Mar 29 2025 ailiop@suse.com
- dlm: fix error if inactive rsb is not hashed (git-fixes).
- commit 2a17834
* Sat Mar 29 2025 ailiop@suse.com
- dlm: prevent NPD when writing a positive value to event_done
  (git-fixes).
- commit 312be0b
* Sat Mar 29 2025 ailiop@suse.com
- Move upstreamed nfsd and sunrpc patches into sorted section
- commit 34f7d67
* Sat Mar 29 2025 tiwai@suse.de
- Move upstreamed PCI, initramfs and dlm patches into sorted section
- commit c907f08
* Sat Mar 29 2025 tiwai@suse.de
- drm/amd/display: Exit idle optimizations before accessing PHY
  (git-fixes).
- commit 56b98fb
* Sat Mar 29 2025 tiwai@suse.de
- PCI: xilinx-cpm: Fix IRQ domain leak in error path of probe
  (git-fixes).
- PCI: qcom-ep: Mark BAR0/BAR2 as 64bit BARs and BAR1/BAR3 as
  RESERVED (git-fixes).
- PCI: mediatek-gen3: Configure PBUS_CSR registers for EN7581 SoC
  (git-fixes).
- PCI: j721e: Fix the value of .linkdown_irq_regfield for J784S4
  (git-fixes).
- PCI: histb: Fix an error handling path in histb_pcie_probe()
  (git-fixes).
- PCI: dwc: ep: Return -ENOMEM for allocation failures
  (git-fixes).
- PCI: cadence-ep: Fix the driver to send MSG TLP for INTx
  without data payload (git-fixes).
- PCI: brcmstb: Fix potential premature regulator disabling
  (git-fixes).
- PCI: brcmstb: Fix error path after a call to
  regulator_bulk_get() (git-fixes).
- PCI: brcmstb: Use internal register to change link capability
  (git-fixes).
- PCI: brcmstb: Set generation limit before PCIe link up
  (git-fixes).
- PCI: brcmstb: Fix missing of_node_put() in brcm_pcie_probe()
  (git-fixes).
- PCI: Fix BAR resizing when VF BARs are assigned (git-fixes).
- PCI: Remove add_align overwrite unrelated to size0 (git-fixes).
- PCI: Avoid reset when disabled via sysfs (git-fixes).
- PCI: pciehp: Don't enable HPIE when resuming in poll mode
  (git-fixes).
- PCI: pciehp: Avoid unnecessary device replacement check
  (git-fixes).
- PCI/portdrv: Only disable pciehp interrupts early when needed
  (git-fixes).
- PCI: Remove stray put_device() in pci_register_host_bridge()
  (git-fixes).
- PCI: Fix reference leak in pci_alloc_child_bus() (git-fixes).
- PCI: Fix reference leak in pci_register_host_bridge()
  (git-fixes).
- PCI: Fix wrong length of devres array (git-fixes).
- PCI/ASPM: Fix link state exit during switch upstream function
  removal (git-fixes).
- tpm, tpm_tis: Fix timeout handling when waiting for TPM status
  (git-fixes).
- tpm: do not start chip while suspended (git-fixes).
- commit 9fad6ad
* Sat Mar 29 2025 tiwai@suse.de
- PCI/ACS: Fix 'pci=config_acs=' parameter (git-fixes).
- drm/amd/display: avoid NPD when ASIC does not support DMUB
  (git-fixes).
- drm/mediatek: dsi: fix error codes in mtk_dsi_host_transfer()
  (git-fixes).
- drm/mediatek: dp: drm_err => dev_err in HPD path to avoid NULL
  ptr (git-fixes).
- drm/mediatek: Fix config_updating flag never false when no
  mbox channel (git-fixes).
- drm/mediatek: mtk_hdmi: Fix typo for aud_sampe_size member
  (git-fixes).
- drm/mediatek: mtk_hdmi: Unregister audio platform device on
  failure (git-fixes).
- drm/msm/a6xx: Fix a6xx indexed-regs in devcoreduump (git-fixes).
- drm/msm/a6xx: Fix stale rpmh votes from GPU (git-fixes).
- drm/msm/dsi: Add check for devm_kstrdup() (git-fixes).
- drm/msm/dsi: Set PHY usescase (and mode) before registering
  DSI host (git-fixes).
- drm/msm/dsi: Use existing per-interface slice count in DSC
  timing (git-fixes).
- drm/msm/dsi/phy: Program clock inverters in correct register
  (git-fixes).
- drm/msm/dpu: don't use active in atomic_check() (git-fixes).
- drm/amd/display: fix type mismatch in
  CalculateDynamicMetadataParameters() (git-fixes).
- drm/amdkfd: Fix Circular Locking Dependency in
  'svm_range_cpu_invalidate_pagetables' (git-fixes).
- drm/amd/display: fix an indent issue in DML21 (git-fixes).
- drm/panthor: Update CS_STATUS_ defines to correct values
  (git-fixes).
- drm/bridge: Fix spelling mistake "gettin" -> "getting"
  (git-fixes).
- drm/repaper: fix integer overflows in repeat functions
  (git-fixes).
- drm/panel: ilitek-ili9882t: fix GPIO name in error message
  (git-fixes).
- drm/amdgpu/umsch: fix ucode check (git-fixes).
- drm/amdgpu/umsch: declare umsch firmware (git-fixes).
- drm/amdgpu: refine smu send msg debug log format (git-fixes).
- gpu: cdns-mhdp8546: fix call balance of mhdp->clk handling
  routines (git-fixes).
- fbdev: sm501fb: Add some geometry checks (git-fixes).
- mdacon: rework dependency list (git-fixes).
- dummycon: fix default rows/cols (git-fixes).
- fbdev: au1100fb: Move a variable assignment behind a null
  pointer check (git-fixes).
- commit ec5fccf
* Sat Mar 29 2025 tiwai@suse.de
- Revert "drm/amd/display: Exit idle optimizations before attempt
  to access PHY" (stable-fixes).
- drm/radeon/ci_dpm: Remove needless NULL checks of dpm tables
  (git-fixes).
- drm/vkms: Fix use after free and double free on init error
  (git-fixes).
- drm: xlnx: zynqmp: Fix max dma segment size (git-fixes).
- drm/bridge: it6505: fix HDCP V match check is not performed
  correctly (git-fixes).
- drm/ast: Fix ast_dp connection status (git-fixes).
- drm/dp_mst: Fix drm RAD print (git-fixes).
- drm/ssd130x: ensure ssd132x pitch is correct (git-fixes).
- drm/ssd130x: fix ssd132x encoding (git-fixes).
- drm/ssd130x: Set SPI .id_table to prevent an SPI core warning
  (git-fixes).
- drm/bridge: ti-sn65dsi86: Fix multiple instances (git-fixes).
- drm/amdgpu/pm: Handle SCLK offset correctly in overdrive for
  smu 14.0.2 (stable-fixes).
- drm/amd/display: Fix message for support_edp0_on_dp1
  (git-fixes).
- drm/amdgpu: Restore uncached behaviour on GFX12 (stable-fixes).
- drm/amdgpu/pm: wire up hwmon fan speed for smu 14.0.2
  (stable-fixes).
- drm/amd/pm: add unique_id for gfx12 (stable-fixes).
- drm/amdgpu: Remove JPEG from vega and carrizo video caps
  (stable-fixes).
- drm/amdgpu: Fix JPEG video caps max size for navi1x and raven
  (stable-fixes).
- drm/amdgpu: Fix MPEG2, MPEG4 and VC1 video caps max size
  (stable-fixes).
- commit 86197b9
* Fri Mar 28 2025 dsterba@suse.com
- mptcp: pm: only set fullmesh for subflow endp (CVE-2025-21706 bsc#1238528)
- commit 3791cc6
* Fri Mar 28 2025 mkoutny@suse.com
- memcg: drain obj stock on cpu hotplug teardown (bsc#1240336).
- commit 1dd26e6
* Fri Mar 28 2025 mkoutny@suse.com
- cgroup/rstat: Fix forceidle time in cpu.stat (bsc#1240335).
- cgroup/rstat: Tracking cgroup-level niced CPU time
  (bsc#1240335).
- commit cb11201
* Fri Mar 28 2025 mkoutny@suse.com
- splice: do not checksum AF_UNIX sockets (bsc#1240333).
- commit ffdef6b
* Fri Mar 28 2025 hare@suse.de
- cxl/core/regs: Refactor out functions to count regblocks of
  given type (jsc#PED-10013).
- cxl/events: Update Memory Module Event Record to CXL spec rev
  3.1 (jsc#PED-10013).
- cxl/events: Update DRAM Event Record to CXL spec rev 3.1
  (jsc#PED-10013).
- cxl/events: Update General Media Event Record to CXL spec rev
  3.1 (jsc#PED-10013).
- cxl/events: Add Component Identifier formatting for CXL spec
  rev 3.1 (jsc#PED-10013).
- cxl/events: Update Common Event Record to CXL spec rev 3.1
  (jsc#PED-10013).
- cxl/pci: Add CXL Type 1/2 support to cxl_dvsec_rr_decode()
  (jsc#PED-10013).
- cxl/pmem: Remove is_cxl_nvdimm_bridge() (jsc#PED-10013).
- cxl/pmem: Replace match_nvdimm_bridge() with API
  device_match_type() (jsc#PED-10013).
- commit 0d44ee1
* Fri Mar 28 2025 hare@suse.de
- cxl/pci: Check dport->regs.rcd_pcie_cap availability before
  accessing (jsc#PED-10013).
- cxl/region: Refactor common create region code (jsc#PED-10013).
- cxl/hdm: Use guard() in cxl_dpa_set_mode() (jsc#PED-10013).
- cxl/pci: Delay event buffer allocation (jsc#PED-10013).
- cxl/cdat: Use %%pra for dpa range outputs (jsc#PED-10013).
- cxl: downgrade a warning message to debug level in
  cxl_probe_component_regs() (jsc#PED-10013).
- cxl/pci: Add sysfs attribute for CXL 1.1 device link status
  (jsc#PED-10013).
- cxl/core/regs: Add rcd_pcie_cap initialization (jsc#PED-10013).
- commit 4e61860
* Fri Mar 28 2025 hare@suse.de
- drivers/block/sunvdc.c: update the correct AIP call
  (jsc#PED-9651).
- loop: don't clear LO_FLAGS_PARTSCAN on LOOP_SET_STATUS{,64}
  (jsc#PED-9651).
- commit f6c9b2f
* Fri Mar 28 2025 tiwai@suse.de
- Reapply "wifi: ath11k: restore country code during resume"
  (bsc#1207948).
- wifi: ath11k: choose default PM policy for hibernation
  (bsc#1207948).
- wifi: ath11k: support non-WoWLAN mode suspend as well
  (bsc#1207948).
- wifi: ath11k: refactor ath11k_core_suspend/_resume()
  (bsc#1207948).
- wifi: ath11k: introduce ath11k_core_continue_suspend_resume()
  (bsc#1207948).
- wifi: ath11k: determine PM policy based on machine model
  (bsc#1207948).
- commit 2b18011
* Fri Mar 28 2025 tiwai@suse.de
- tee: optee: Fix supplicant wait loop (CVE-2025-21871
  bsc#1240183).
- commit e277e7f
* Fri Mar 28 2025 tiwai@suse.de
- wifi: mt76: mt7925: fix the wrong link_idx when a p2p_device
  is present (git-fixes).
- commit c80ad3f
* Fri Mar 28 2025 tiwai@suse.de
- soc: samsung: exynos-chipid: Add NULL pointer check in
  exynos_chipid_probe() (git-fixes).
- soc: mediatek: mt8365-mmsys: Fix routing table masks and values
  (git-fixes).
- soc: mediatek: mt8167-mmsys: Fix missing regval in all entries
  (git-fixes).
- soc: mediatek: mtk-mmsys: Fix MT8188 VDO1 DPI1 output selection
  (git-fixes).
- wifi: mt76: mt7925: remove unused acpi function for clc
  (git-fixes).
- wifi: mt76: mt7925: fix the wrong simultaneous cap for MLO
  (git-fixes).
- wifi: mt76: mt7921: fix kernel panic due to null pointer
  dereference (git-fixes).
- wifi: mt76: Add check for devm_kstrdup() (git-fixes).
- wifi: mt76: mt7925: fix country count limitation for CLC
  (git-fixes).
- wifi: mt76: mt7925: ensure wow pattern command align fw format
  (git-fixes).
- wifi: mt76: mt7915: fix possible integer overflows in
  mt7915_muru_stats_show() (git-fixes).
- wifi: rtw89: pci: correct ISR RDU bit for 8922AE (git-fixes).
- wifi: rtw89: fw: correct debug message format in
  rtw89_build_txpwr_trk_tbl_from_elm() (git-fixes).
- wifi: rtw89: rtw8852b{t}: fix TSSI debug timestamps (git-fixes).
- wifi: mwifiex: Fix RF calibration data download from file
  (git-fixes).
- wifi: mwifiex: Fix premature release of RF calibration data
  (git-fixes).
- wifi: cfg80211: init wiphy_work before allocating rfkill fails
  (git-fixes).
- wifi: mac80211: check basic rates validity in
  sta_link_apply_parameters (git-fixes).
- wifi: ath12k: Clear affinity hint before calling
  ath12k_pci_free_irq() in error path (git-fixes).
- wifi: ath11k: Clear affinity hint before calling
  ath11k_pcic_free_irq() in error path (git-fixes).
- wifi: ath12k: Add missing htt_metadata flag in ath12k_dp_tx()
  (git-fixes).
- wifi: ath11k: add srng->lock for ath11k_hal_srng_* in monitor
  mode (git-fixes).
- wifi: ath11k: fix RCU stall while reaping monitor destination
  ring (git-fixes).
- wifi: ath11k: update channel list in reg notifier instead reg
  worker (git-fixes).
- wifi: ath11k: fix wrong overriding for VHT Beamformee STS
  Capability (git-fixes).
- wifi: ath9k: do not submit zero bytes to the entropy pool
  (git-fixes).
- wifi: ath12k: encode max Tx power in scan channel list command
  (git-fixes).
- wifi: ath12k: fix skb_ext_desc leak in ath12k_dp_tx() error path
  (git-fixes).
- wifi: mac80211: fix integer overflow in hwmp_route_info_get()
  (git-fixes).
- wifi: rtw89: Correct immediate cfg_len calculation for
  scan_offload_be (git-fixes).
- commit 413a548
* Fri Mar 28 2025 tiwai@suse.de
- kunit: qemu_configs: sparc: use Zilog console (git-fixes).
- bus: qcom-ssc-block-bus: Fix the error handling path of
  qcom_ssc_block_bus_probe() (git-fixes).
- bus: qcom-ssc-block-bus: Remove some duplicated iounmap()
  calls (git-fixes).
- memory: mtk-smi: Add ostd setting for mt8192 (git-fixes).
- firmware: arm_scmi: use ioread64() instead of ioread64_hi_lo()
  (git-fixes).
- firmware: arm_ffa: Skip the first/partition ID when parsing
  vCPU list (git-fixes).
- firmware: arm_ffa: Explicitly cast return value from
  NOTIFICATION_INFO_GET (git-fixes).
- firmware: arm_ffa: Explicitly cast return value from FFA_VERSION
  before comparison (git-fixes).
- ax25: Remove broken autobind (git-fixes).
- Bluetooth: btnxpuart: Fix kernel panic during FW release
  (git-fixes).
- Bluetooth: HCI: Add definition of hci_rp_remote_name_req_cancel
  (git-fixes).
- Bluetooth: hci_core: Enable buffer flow control for SCO/eSCO
  (git-fixes).
- broadcom: fix supported flag check in periodic output function
  (git-fixes).
- can: rockchip_canfd: rkcanfd_chip_fifo_setup(): remove
  duplicated setup of RX FIFO (git-fixes).
- ata: libata: Fix NCQ Non-Data log not supported print
  (git-fixes).
- clocksource/drivers/stm32-lptimer: Use wakeup capable instead
  of init wakeup (git-fixes).
- mtd: nand: Fix a kdoc comment (git-fixes).
- mtd: rawnand: brcmnand: fix PM resume warning (git-fixes).
- mtd: Add check for devm_kcalloc() (git-fixes).
- mtd: Replace kcalloc() with devm_kcalloc() (git-fixes).
- HID: Enable playstation driver independently of sony driver
  (git-fixes).
- HID: remove superfluous (and wrong) Makefile entry for
  CONFIG_INTEL_ISH_FIRMWARE_DOWNLOADER (git-fixes).
- platform/x86: dell-ddv: Fix temperature calculation (git-fixes).
- platform/x86: dell-uart-backlight: Make
  dell_uart_bl_serdev_driver static (git-fixes).
- platform/x86: lenovo-yoga-tab2-pro-1380-fastcharger: Make
  symbol static (git-fixes).
- commit ff0de4a
* Fri Mar 28 2025 tiwai@suse.de
- ALSA: hda/realtek: Fix built-in mic assignment on ASUS VivoBook
  X515UA (git-fixes).
- ASoC: codecs: wcd937x: fix a potential memory leak in
  wcd937x_soc_codec_probe() (git-fixes).
- ASoC: amd: acp: Fix for enabling DMIC on acp platforms via
  _DSD entry (git-fixes).
- ASoC: cs35l41: check the return value from spi_setup()
  (git-fixes).
- ALSA: timer: Don't take register_mutex with copy_from/to_user()
  (git-fixes).
- ASoC: ti: j721e-evm: Fix clock configuration for
  ti,j7200-cpb-audio compatible (git-fixes).
- ALSA: usb-audio: separate DJM-A9 cap lvl options (git-fixes).
- ALSA: hda/realtek: Always honor no_shutup_pins (git-fixes).
- ALSA: pcm: Drop superfluous NULL check in
  snd_pcm_format_set_silence() (git-fixes).
- commit 4fd931a
* Fri Mar 28 2025 hare@suse.de
- btrfs: zoned: calculate max_extent_size properly on non-zoned
  setup (jsc#PED-9651).
- arm64: patching: avoid early page_to_phys() (jsc#PED-9651).
- block: make struct rq_list available for !CONFIG_BLOCK
  (jsc#PED-9651).
- btrfs: validate queue limits (jsc#PED-9651).
- commit 587ec60
* Fri Mar 28 2025 hare@suse.de
- series.conf: move patches to sorted section (jsc#PED-9561)
- commit eb6beb7
* Fri Mar 28 2025 msuchanek@suse.de
- KVM: PPC: Enable CAP_SPAPR_TCE_VFIO on pSeries KVM guests
  (jsc#PED-10539 git-fixes).
- commit f5abb5d
* Fri Mar 28 2025 hare@suse.de
- block: add support for partition table defined in OF
  (jsc#PED-9651).
- Update config files.
- commit 842f5a7
* Thu Mar 27 2025 pfalcato@suse.de
- ipv6: mcast: extend RCU protection in igmp6_send()
  (CVE-2025-21759 bsc#1238738).
- commit d7804c2
* Thu Mar 27 2025 pfalcato@suse.de
- ndisc: extend RCU protection in ndisc_send_skb() (CVE-2025-21760
  bsc#1238763).
- commit 42e3dd1
* Thu Mar 27 2025 pfalcato@suse.de
- vrf: use RCU protection in l3mdev_l3_out() (CVE-2025-21791
  bsc#1238512).
- commit e9d9d17
* Thu Mar 27 2025 pfalcato@suse.de
- openvswitch: use RCU protection in ovs_vport_cmd_fill_info()
  (CVE-2025-21761 bsc#1238775).
- commit 78199de
* Thu Mar 27 2025 pfalcato@suse.de
- arp: use RCU protection in arp_xmit() (CVE-2025-21762
  bsc#1238780).
- commit 61a327a
* Thu Mar 27 2025 pfalcato@suse.de
- ndisc: use RCU protection in ndisc_alloc_skb() (CVE-2025-21764
  bsc#1237885).
- commit 71b670d
* Thu Mar 27 2025 pfalcato@suse.de
- ndisc: ndisc_send_redirect() must use dev_get_by_index_rcu()
  (bsc#1239994).
- commit eb3adeb
* Thu Mar 27 2025 pfalcato@suse.de
- ipv6: Use RCU in ip6_input() (bsc#1239994).
- commit c9a38e6
* Thu Mar 27 2025 pfalcato@suse.de
- ipv6: icmp: convert to dev_net_rcu() (bsc#1239994).
- commit 68b80e3
* Thu Mar 27 2025 pfalcato@suse.de
- ipv6: use RCU protection in ip6_default_advmss() (CVE-2025-21765
  bsc#1237906).
- commit 67b2d6d
* Thu Mar 27 2025 pfalcato@suse.de
- flow_dissector: use RCU protection to fetch dev_net()
  (bsc#1239994).
- commit bacdd89
* Thu Mar 27 2025 pfalcato@suse.de
- ipv4: icmp: convert to dev_net_rcu() (bsc#1239994).
- commit 7b71f37
* Thu Mar 27 2025 pfalcato@suse.de
- ipv4: use RCU protection in __ip_rt_update_pmtu()
  (CVE-2025-21766 bsc#1238754).
- commit 370b0fb
* Thu Mar 27 2025 pfalcato@suse.de
- ipv4: use RCU protection in inet_select_addr() (bsc#1239994).
- commit cb28364
* Thu Mar 27 2025 pfalcato@suse.de
- ipv4: use RCU protection in rt_is_expired() (bsc#1239994).
- commit 113e926
* Thu Mar 27 2025 pfalcato@suse.de
- ipv4: use RCU protection in ipv4_default_advmss() (bsc#1239994).
- commit e699546
* Thu Mar 27 2025 pfalcato@suse.de
- ipv4: use RCU protection in ip_dst_mtu_maybe_forward()
  (bsc#1239994).
- commit 60c5596
* Thu Mar 27 2025 pfalcato@suse.de
- ipv4: add RCU protection to ip4_dst_hoplimit() (bsc#1239994).
- commit c9e4bc0
* Thu Mar 27 2025 pfalcato@suse.de
- udp: Deal with race between UDP socket address change and rehash
  (CVE-2024-57974 bsc#1238532).
- commit 4eccbe0
* Thu Mar 27 2025 mfranc@suse.cz
- Patches moving to mainline causing merge conflicts.
- Refresh
  patches.suse/scsi-lpfc-Copyright-updates-for-14.4.0.8-patches.patch.
- Refresh
  patches.suse/scsi-lpfc-Free-phba-irq-in-lpfc_sli4_enable_msi-when.patch.
- Refresh
  patches.suse/scsi-lpfc-Handle-duplicate-D_IDs-in-ndlp-search-by-D.patch.
- Refresh
  patches.suse/scsi-lpfc-Ignore-ndlp-rport-mismatch-in-dev_loss_tmo.patch.
- Refresh
  patches.suse/scsi-lpfc-Reduce-log-message-generation-during-ELS-r.patch.
- Refresh
  patches.suse/scsi-lpfc-Update-lpfc-version-to-14.4.0.8.patch.
- commit 7e994f0
* Thu Mar 27 2025 jlee@suse.com
- Bluetooth: L2CAP: convert timeouts to secs_to_jiffies()
  (jsc#PED-12286).
- Bluetooth: SMP: convert timeouts to secs_to_jiffies()
  (jsc#PED-12286).
- Bluetooth: MGMT: convert timeouts to secs_to_jiffies()
  (jsc#PED-12286).
- Bluetooth: hci_vhci: convert timeouts to secs_to_jiffies()
  (jsc#PED-12286).
- Bluetooth: SCO: fix sco_conn refcounting on sco_conn_ready
  (jsc#PED-12286).
- bluetooth: mgmt: convert timeouts to secs_to_jiffies()
  (jsc#PED-12286).
- Bluetooth: SCO: remove the redundant sco_conn_put
  (jsc#PED-12286).
- Bluetooth: MGMT: Add initial implementation of
  MGMT_OP_HCI_CMD_SYNC (jsc#PED-12286).
- commit 352ae09
* Thu Mar 27 2025 jlee@suse.com
- Bluetooth: hci_bcm: Use the devm_clk_get_optional() helper
  (jsc#PED-12286).
- Bluetooth: hci_conn: Remove alloc from critical section
  (jsc#PED-12286).
- Bluetooth: SCO: Use kref to track lifetime of sco_conn
  (jsc#PED-12286).
- Bluetooth: HCI: Add IPC(11) bus type (jsc#PED-12286).
- Bluetooth: ISO: Update hci_conn_hash_lookup_big for Broadcast
  slave (jsc#PED-12286).
- Bluetooth: ISO: Fix matching parent socket for BIS slave
  (jsc#PED-12286).
- Bluetooth: btrtl: Decrease HCI_OP_RESET timeout from 10 s to
  2 s (jsc#PED-12286).
- Bluetooth: btintel_pcie: Replace deprecated PCI functions
  (jsc#PED-12286).
- Bluetooth: btintel_pcie: remove redundant assignment to variable
  ret (jsc#PED-12286).
- Bluetooth: btintel_pcie: Remove deadcode (jsc#PED-12286).
- Bluetooth: hci_qca: use
  devm_clk_get_optional_enabled_with_rate() (jsc#PED-12286).
- Bluetooth: btintel: Add DSBR support for BlazarIW, BlazarU
  and GaP (jsc#PED-12286).
- Bluetooth: btmtksdio: Lookup device node only as fallback
  (jsc#PED-12286).
- Bluetooth: btintel_pcie: Add recovery mechanism (jsc#PED-12286).
- Bluetooth: hci_core: Fix not checking skb length on
  hci_scodata_packet (jsc#PED-12286).
- Bluetooth: btnxpuart: Add GPIO support to power save feature
  (jsc#PED-12286).
- bluetooth: Fix typos in the comments (jsc#PED-12286).
- Bluetooth: btnxpuart: Rename IW615 to IW610 (jsc#PED-12286).
- Bluetooth: btnxpuart: Drop _v0 suffix from FW names
  (jsc#PED-12286).
- Bluetooth: btusb: Add one more ID 0x13d3:0x3623 for Qualcomm
  WCN785x (jsc#PED-12286).
- Bluetooth: btusb: Add one more ID 0x0489:0xe0f3 for Qualcomm
  WCN785x (jsc#PED-12286).
- Bluetooth: btusb: add Foxconn 0xe0fc for Qualcomm WCN785x
  (jsc#PED-12286).
- Bluetooth: add HAS_IOPORT dependencies (jsc#PED-12286).
- commit 638ded7
* Thu Mar 27 2025 tbogendoerfer@suse.de
- eth: bnxt: fix out-of-range access of vnic_info array
  (jsc#PED-11923).
- bnxt_en: Add TPH support in BNXT driver (jsc#PED-11923).
- bnxt_en: Extend queue stop/start for TX rings (jsc#PED-11923).
- bnxt_en: Refactor TX ring free logic (jsc#PED-11923).
- bnxt_en: Reallocate RX completion ring for TPH support
  (jsc#PED-11923).
- bnxt_en: Pass NQ ID to the FW when allocating RX/RX AGG rings
  (jsc#PED-11923).
- bnxt_en: Refactor RX/RX AGG ring parameters setup for P5_PLUS
  (jsc#PED-11923).
- bnxt_en: Refactor bnxt_free_tx_rings() to free per TX ring
  (jsc#PED-11923).
- bnxt_en: Refactor completion ring free routine (jsc#PED-11923).
- bnxt_en: Refactor TX ring allocation logic (jsc#PED-11923).
- bnxt_en: Refactor completion ring allocation logic for P5_PLUS
  chips (jsc#PED-11923).
- bnxt_en: Set NPAR 1.2 support when registering with firmware
  (jsc#PED-11923).
- netdev: define NETDEV_INTERNAL (jsc#PED-11923).
- commit 5d77362
* Thu Mar 27 2025 tbogendoerfer@suse.de
- ice: health.c: fix compilation on gcc 7.5 (jsc#PED-10419).
- commit 7e632c2
* Wed Mar 26 2025 msuchanek@suse.de
- Refresh patches.suse/tpm-send_data-Wait-longer-for-the-TPM-to-become-read.patch.
  Also extend the remaining tpm_tis_send_data timeout (bsc#1235870).
- commit 382e790
* Wed Mar 26 2025 davide.benini@suse.com
- af_packet: fix vlan_get_tci() vs MSG_PEEK (CVE-2024-57902
  bsc#1235950).
- commit fd3162f
* Wed Mar 26 2025 davide.benini@suse.com
- net: fix memory leak in tcp_conn_request() (CVE-2024-57841
  bsc#1235944).
- commit cf965e6
* Wed Mar 26 2025 hare@suse.de
- nvme: core: switch to non_owner variant of start_freeze/unfreeze
  queue (jsc#PED-9651).
- commit c314272
* Wed Mar 26 2025 davide.benini@suse.com
- net/smc: check smcd_v2_ext_offset when receiving proposal msg
  (CVE-2024-47408 bsc#1235711).
- commit 24369ad
* Wed Mar 26 2025 tbogendoerfer@suse.de
- Delete
  patches.suse/s390-Fix-mlx5-RoCE-throuput-degradtion.patch.
  With commit 1d5024f88dad ("net/mlx5e: Default to Striding RQ when
  not conflicting with CQE compression") added to v5.18-rc5 this
  patch is no longer needed.
- commit 7f247c8
* Wed Mar 26 2025 hare@suse.de
- asm-generic: add an optional pfn_valid check to page_to_phys
  (jsc#PED-9651).
- asm-generic: provide generic page_to_phys and phys_to_page
  (jsc#PED-9651).
- commit 8762cfe
* Wed Mar 26 2025 hare@suse.de
- block: use page_to_phys in bvec_phys (jsc#PED-9651).
- commit 6850cb9
* Wed Mar 26 2025 hare@suse.de
- block: fix NULL pointer dereferenced within __blk_rq_map_sg
  (jsc#PED-9651).
- block/merge: remove unnecessary min() with UINT_MAX
  (jsc#PED-9651).
- commit 41708a1
* Wed Mar 26 2025 hare@suse.de
- block: force noio scope in blk_mq_freeze_queue (jsc#PED-9651).
- nbd: fix partial sending (jsc#PED-9651).
- loop: remove the use_dio field in struct loop_device
  (jsc#PED-9651).
- loop: don't freeze the queue in loop_update_dio (jsc#PED-9651).
- loop: allow loop_set_status to re-enable direct I/O
  (jsc#PED-9651).
- commit 6d37915
* Wed Mar 26 2025 hare@suse.de
- loop: open code the direct I/O flag update in loop_set_dio
  (jsc#PED-9651).
- loop: only write back pagecache when starting to to use direct
  I/O (jsc#PED-9651).
- loop: create a lo_can_use_dio helper (jsc#PED-9651).
- loop: update commands in loop_set_status still referring to
  transfers (jsc#PED-9651).
- loop: move updating lo_flags out of loop_set_status_from_info
  (jsc#PED-9651).
- loop: fix queue freeze vs limits lock order (jsc#PED-9651).
- loop: refactor queue limits updates (jsc#PED-9651).
- loop: Fix ABBA locking race (jsc#PED-9651).
- nvme: use helpers to access io_uring cmd space (jsc#PED-9651).
- rbd: unfreeze queue after marking disk as dead (jsc#PED-9651).
- loop: Simplify discard granularity calc (jsc#PED-9651).
- loop: Use bdev limit helpers for configuring discard
  (jsc#PED-9651).
- commit a5f9b6f
* Wed Mar 26 2025 sjaeckel@suse.de
- netem: Update sch->q.qlen before qdisc_tree_reduce_backlog()
  (git-fixes CVE-2025-21703 bsc#1237313).
- commit f9fdeb8
* Wed Mar 26 2025 sjaeckel@suse.de
- net/smc: check v2_ext_offset/eid_cnt/ism_gid_cnt when receiving
  proposal msg (CVE-2024-49568 bsc#1235728).
- net/smc: protect link down work from execute after lgr freed
  (CVE-2024-56718 bsc#1235589).
- net/smc: fix LGR and link use-after-free issue (CVE-2024-56640
  bsc#1235436).
- drop_monitor: fix incorrect initialization order (CVE-2025-21862
  bsc#1239474).
- net/sched: cls_api: fix error handling causing NULL dereference
  (CVE-2025-21857 bsc#1239478).
- netfilter: nf_tables: reject mismatching sum of field_len with
  set key length (CVE-2025-21826 bsc#1238968).
- rxrpc, afs: Fix peer hash locking vs RCU callback
  (CVE-2025-21809 bsc#1238733).
- rds: sysctl: rds_tcp_{rcv,snd}buf: avoid using current->nsproxy
  (CVE-2025-21635 bsc#1236111).
- netfilter: nf_tables: do not defer rule destruction via call_rcu
  (CVE-2024-56655 bsc#1235446).
- netfilter: IDLETIMER: Fix for possible ABBA deadlock
  (CVE-2024-54683 bsc#1235729).
- net/sched: netem: account for backlog updates from child qdisc
  (CVE-2024-56770 bsc#1235637).
- netlink: fix false positive warning in extack during dumps
  (CVE-2024-53212 bsc#1234972).
- ipv6: Fix soft lockups in fib6_select_path under high next
  hop churn (CVE-2024-56703 bsc#1235455).
- ipv6: release nexthop on device removal (CVE-2024-56751
  bsc#1234936).
- commit fc26e30
* Wed Mar 26 2025 tiwai@suse.de
- gpio: 74x164: Remove unneeded dependency to OF_GPIO (git-fixes).
- Update config files.
- commit 9b9af75
* Wed Mar 26 2025 tiwai@suse.de
- media: vim2m: print device name after registering device
  (git-fixes).
- media: platform: stm32: Add check for clk_enable() (git-fixes).
- media: siano: Fix error handling in smsdvb_module_init()
  (git-fixes).
- media: v4l2-dv-timings: prevent possible overflow in
  v4l2_detect_gtf() (git-fixes).
- media: rockchip: rga: fix rga offset lookup (git-fixes).
- media: vimc: skip .s_stream() for stopped entities (git-fixes).
- media: omap3isp: Handle ARM dma_iommu_mapping (git-fixes).
- media: intel/ipu6: set the dev_parent of video device to pdev
  (git-fixes).
- media: venus: hfi: add a check to handle OOB in sfr region
  (git-fixes).
- media: venus: hfi: add check to handle incorrect queue size
  (git-fixes).
- media: venus: hfi_parser: refactor hfi packet parsing logic
  (git-fixes).
- media: venus: hfi_parser: add check to avoid out of bound access
  (git-fixes).
- media: visl: Fix ERANGE error when setting enum controls
  (git-fixes).
- media: nuvoton: Fix reference handling of ece_pdev (git-fixes).
- media: nuvoton: Fix reference handling of ece_node (git-fixes).
- media: mgb4: Fix switched CMT frequency range "magic values"
  sets (git-fixes).
- media: mgb4: Fix CMT registers update logic (git-fixes).
- media: platform: allgro-dvt: unregister v4l2_device on the
  error path (git-fixes).
- media: verisilicon: HEVC: Initialize start_bit field
  (git-fixes).
- media: i2c: adv748x: Fix test pattern selection mask
  (git-fixes).
- media: mediatek: vcodec: Fix a resource leak related to the
  scp device in FW initialization (git-fixes).
- media: uapi: rkisp1-config: Fix typo in extensible params
  example (git-fixes).
- media: mtk-vcodec: venc: avoid -Wenum-compare-conditional
  warning (git-fixes).
- media: imx219: Adjust PLL settings based on the number of MIPI
  lanes (git-fixes).
- media: i2c: ov7251: Introduce 1 ms delay between regulators
  and en GPIO (git-fixes).
- media: i2c: ov7251: Set enable GPIO low in probe (git-fixes).
- media: i2c: imx319: Rectify runtime PM handling probe and remove
  (git-fixes).
- media: i2c: imx219: Rectify runtime PM handling in probe and
  remove (git-fixes).
- media: i2c: ccs: Set the device's runtime PM status correctly
  in probe (git-fixes).
- media: i2c: ccs: Set the device's runtime PM status correctly
  in remove (git-fixes).
- media: i2c: imx214: Rectify probe error handling related to
  runtime PM (git-fixes).
- Revert "media: imx214: Fix the error handling in imx214_probe()"
  (git-fixes).
- media: hi556: Fix memory leak (on error) in hi556_check_hwcfg()
  (git-fixes).
- media: chips-media: wave5: Fix timeout while testing 10bit
  hevc fluster (git-fixes).
- media: chips-media: wave5: Fix a hang after seeking (git-fixes).
- media: chips-media: wave5: Avoid race condition in the interrupt
  handler (git-fixes).
- media: chips-media: wave5: Fix gray color on screen (git-fixes).
- media: streamzap: prevent processing IR data on URB failure
  (git-fixes).
- media: streamzap: fix race between device disconnection and
  urb callback (git-fixes).
- auxdisplay: panel: Fix an API misuse in panel.c (git-fixes).
- auxdisplay: hd44780: Fix an API misuse in hd44780.c (git-fixes).
- auxdisplay: MAX6959 should select BITREVERSE (git-fixes).
- mmc: omap: Fix memory leak in mmc_omap_new_slot (git-fixes).
- memstick: rtsx_usb_ms: Fix slab-use-after-free in
  rtsx_usb_ms_drv_remove (git-fixes).
- mmc: sdhci-omap: Disable MMC_CAP_AGGRESSIVE_PM for eMMC/SD
  (git-fixes).
- spi: cadence-qspi: Fix probe on AM62A LP SK (git-fixes).
- regulator: pca9450: Fix enable register for LDO5 (git-fixes).
- thermal: int340x: Add NULL check for adev (git-fixes).
- PM: sleep: Fix handling devices with direct_complete set on
  errors (git-fixes).
- PM: sleep: Adjust check before setting power.must_resume
  (git-fixes).
- selftests/x86/syscall: Fix coccinelle WARNING recommending
  the use of ARRAY_SIZE() (git-fixes).
- commit 5906346
* Wed Mar 26 2025 heming.zhao@suse.com
- dlm: make tcp still work in multi-link env (jsc#PED-11932).
- dlm: increase max number of links for corosync3/knet
  (jsc#PED-11932).
- commit 973d3b7
* Tue Mar 25 2025 dsterba@suse.com
- smb: client: Add check for next_buffer in receive_encrypted_standard() (CVE-2025-21844 bsc#1239512)
- commit 26d78d1
* Tue Mar 25 2025 nik.borisov@suse.com
- EDAC/i10nm: Add Intel Clearwater Forest server support (jsc#PED-10632).
- commit 74f0879
* Tue Mar 25 2025 hare@suse.de
- block: fix nr_hw_queue update racing with disk addition/removal
  (jsc#PED-9651).
- commit 1ad06cb
* Tue Mar 25 2025 hare@suse.de
- blk: Re-add symbols (jsc#PED-9651).
- commit b75f36f
* Tue Mar 25 2025 hare@suse.de
- block: get rid of request queue ->sysfs_dir_lock (jsc#PED-9651).
- commit 427cb3f
* Tue Mar 25 2025 hare@suse.de
- block: make bio_integrity_map_user() static inline
  (jsc#PED-9651).
- block: add support to pass user meta buffer (jsc#PED-9651).
- scsi: add support for user-meta interface (jsc#PED-9651).
- nvme: add support for passing on the application tag
  (jsc#PED-9651).
- block: introduce BIP_CHECK_GUARD/REFTAG/APPTAG bip_flags
  (jsc#PED-9651).
- io_uring: introduce attributes for read/write and PI support
  (jsc#PED-9651).
- fs: introduce IOCB_HAS_METADATA for metadata (jsc#PED-9651).
- fs, iov_iter: define meta io descriptor (jsc#PED-9651).
- block: modify bio_integrity_map_user to accept iov_iter as
  (jsc#PED-9651).
- commit 1783ba5
* Tue Mar 25 2025 hare@suse.de
- block: define set of integrity flags to be inherited by
  (jsc#PED-9651).
- block: Don't trim an atomic write (jsc#PED-9651).
- commit d4c21f0
* Tue Mar 25 2025 hare@suse.de
- block: Add common atomic writes enable flag (jsc#PED-9651).
- Refresh
  patches.suse/md-raid-Fix-the-set_queue_limits-implementations.patch.
- commit b34e56a
* Tue Mar 25 2025 hare@suse.de
- md: Replace deprecated kmap_atomic() with kmap_local_page()
  (jsc#PED-9651).
- commit 55de4aa
* Tue Mar 25 2025 hare@suse.de
- md/raid10: Atomic write support (jsc#PED-9651).
- Refresh
  patches.suse/md-raid-Fix-the-set_queue_limits-implementations.patch.
- commit 3025a42
* Tue Mar 25 2025 hare@suse.de
- md/raid1: Atomic write support (jsc#PED-9651).
- Refresh
  patches.suse/md-raid-Fix-the-set_queue_limits-implementations.patch.
- commit cddb7c9
* Tue Mar 25 2025 hare@suse.de
- md/raid0: Atomic write support (jsc#PED-9651).
- Refresh
  patches.suse/md-raid-Fix-the-set_queue_limits-implementations.patch.
- commit aa8067d
* Tue Mar 25 2025 jslaby@suse.cz
- lockdep: Don't disable interrupts on RT in
  disable_irq_nosync_lockdep.*() (git-fixes).
- kbuild: hdrcheck: fix cross build with clang (git-fixes).
- commit acb9e30
* Tue Mar 25 2025 hare@suse.de
- md/raid5: Increase r5conf.cache_name size (jsc#PED-9651).
- commit 0cb15e6
* Tue Mar 25 2025 hare@suse.de
- md/raid10: Handle bio_split() errors (jsc#PED-9651).
- md/raid1: Handle bio_split() errors (jsc#PED-9651).
- md/raid0: Handle bio_split() errors (jsc#PED-9651).
- commit 3e727d4
* Tue Mar 25 2025 hare@suse.de
- md/raid5: don't set Faulty rdev for blocked_rdev (jsc#PED-9651).
- md/raid10: don't wait for Faulty rdev in wait_blocked_rdev()
  (jsc#PED-9651).
- md/raid1: don't wait for Faulty rdev in wait_blocked_rdev()
  (jsc#PED-9651).
- commit a5e2aa8
* Tue Mar 25 2025 hare@suse.de
- md/raid1: factor out helper to handle blocked rdev from
  raid1_write_request() (jsc#PED-9651).
- Refresh
  patches.suse/md-md-bitmap-remove-the-last-parameter-for-bimtap_ops-endwrite.patch.
- commit 6d35bb1
* Tue Mar 25 2025 hare@suse.de
- md: don't record new badblocks for faulty rdev (jsc#PED-9651).
- md: don't wait faulty rdev in md_wait_for_blocked_rdev()
  (jsc#PED-9651).
- md: add a new helper rdev_blocked() (jsc#PED-9651).
- md/raid5-ppl: Use atomic64_inc_return() in ppl_new_iounit()
  (jsc#PED-9651).
- commit f925245
* Mon Mar 24 2025 hare@suse.de
- block: limit disk max sectors to (LLONG_MAX >> 9)
  (jsc#PED-9651).
- block: Change blk_stack_atomic_writes_limits() unit_min check
  (jsc#PED-9651).
- block: Ensure start sector is aligned for stacking atomic writes
  (jsc#PED-9651).
- blk-mq: Move more error handling into blk_mq_submit_bio()
  (jsc#PED-9651).
- block: Reorder the request allocation code in
  blk_mq_submit_bio() (jsc#PED-9651).
- commit ff53e6b
* Mon Mar 24 2025 hare@suse.de
- blk-cgroup: rwstat: fix kernel-doc warnings in header file
  (jsc#PED-9651).
- blacklist.conf:
- blk-cgroup: fix kernel-doc warnings in header file
  (jsc#PED-9651).
- block: mark GFP_NOIO around sysfs ->store() (jsc#PED-9651).
- usb-storage: fix queue freeze vs limits lock order
  (jsc#PED-9651).
- nbd: fix queue freeze vs limits lock order (jsc#PED-9651).
- nvme: fix queue freeze vs limits lock order (jsc#PED-9651).
- block: fix queue freeze vs limits lock order in sysfs store
  (jsc#PED-9651).
- block: add a store_limit operations for sysfs entries
  (jsc#PED-9651).
- commit db47806
* Mon Mar 24 2025 hare@suse.de
- block: add a queue_limits_commit_update_frozen helper
  (jsc#PED-9651).
- block: fix docs for freezing of queue limits updates
  (jsc#PED-9651).
- block: simplify tag allocation policy selection (jsc#PED-9651).
- block: remove BLK_MQ_F_NO_SCHED (jsc#PED-9651).
- block: remove blk_mq_init_bitmaps (jsc#PED-9651).
- block: better split mq vs non-mq code in add_disk_fwnode
  (jsc#PED-9651).
- block: add a dma mapping iterator (jsc#PED-9651).
- block: remove blk_rq_bio_prep (jsc#PED-9651).
- block: remove bio_add_pc_page (jsc#PED-9651).
- kyber: constify sysfs attributes (jsc#PED-9651).
- block, bfq: constify sysfs attributes (jsc#PED-9651).
- block: mq-deadline: Constify sysfs attributes (jsc#PED-9651).
- elevator: Enable const sysfs attributes (jsc#PED-9651).
- blk-zoned: Split queue_zone_wplugs_show() (jsc#PED-9651).
- blk-zoned: Improve the queue reference count strategy
  documentation (jsc#PED-9651).
- blk-zoned: Document locking assumptions (jsc#PED-9651).
- blk-zoned: Minimize #include directives (jsc#PED-9651).
- block: remove BLK_MQ_F_SHOULD_MERGE (jsc#PED-9651).
- commit aaae71e
* Mon Mar 24 2025 hare@suse.de
- blktrace: remove redundant return at end of function
  (jsc#PED-9651).
- block: Delete bio_set_prio() (jsc#PED-9651).
- block: Delete bio_prio() (jsc#PED-9651).
- commit c246365
* Mon Mar 24 2025 hare@suse.de
- blktrace: move copy_[to|from]_user() out of ->debugfs_lock
  (jsc#PED-9651).
- blktrace: don't centralize grabbing q->debugfs_mutex in
  blk_trace_ioctl (jsc#PED-9651).
- null_blk: Add rotational feature support (jsc#PED-9651).
- block: track queue dying state automatically for modeling
  queue freeze lockdep (jsc#PED-9651).
- block: don't verify queue freeze manually in elevator_init_mq()
  (jsc#PED-9651).
- block: track disk DEAD state automatically for modeling queue
  freeze lockdep (jsc#PED-9651).
- block: remove unnecessary check in blk_unfreeze_check_owner()
  (jsc#PED-9651).
- commit fc5adc6
* Mon Mar 24 2025 hare@suse.de
- block: Revert "block: Fix potential deadlock while freezing
  queue and acquiring sysfs_lock (jsc#PED-9651).
- block/bdev: use helper for max block size check (jsc#PED-9651).
- block: Fix potential deadlock while freezing queue and acquiring
  sysfs_lock (jsc#PED-9651).
- block: Fix queue_iostats_passthrough_show() (jsc#PED-9651).
- blk-mq: Clean up blk_mq_requeue_work() (jsc#PED-9651).
- mq-deadline: Remove a local variable (jsc#PED-9651).
- block: Make bio_iov_bvec_set() accept pointer to const iov_iter
  (jsc#PED-9651).
- commit f6d6aff
* Mon Mar 24 2025 hare@suse.de
- mq-deadline: don't call req_get_ioprio from the I/O completion
  handler (jsc#PED-9651).
- block: Remove extra part pointer NULLify in blk_rq_init()
  (jsc#PED-9651).
- commit bd669e8
* Mon Mar 24 2025 mgorman@suse.de
- sched/fair: Fix potential memory corruption in
  child_cfs_rq_on_list (bsc#1234634 (Scheduler functional and
  performance backports)).
- cpuidle, sched: Use smp_mb__after_atomic() in
  current_clr_polling() (bsc#1234634 (Scheduler functional and
  performance backports)).
- commit 3fdb94f
* Mon Mar 24 2025 hare@suse.de
- block: return bool from get_disk_ro and bdev_read_only
  (jsc#PED-9651).
- block: remove a duplicate definition for bdev_read_only
  (jsc#PED-9651).
- block: return bool from blk_rq_aligned (jsc#PED-9651).
- block: return unsigned int from blk_lim_dma_alignment_and_pad
  (jsc#PED-9651).
- block: return unsigned int from bdev_io_opt (jsc#PED-9651).
- block: req->bio is always set in the merge code (jsc#PED-9651).
- block: don't bother checking the data direction for merges
  (jsc#PED-9651).
- block: blk-mq: fix uninit-value in blk_rq_prep_clone and
  refactor (jsc#PED-9651).
- block: Support atomic writes limits for stacked devices
  (jsc#PED-9651).
- block: Add extra checks in blk_validate_atomic_write_limits()
  (jsc#PED-9651).
- block: Drop granularity check in queue_limit_discard_alignment()
  (jsc#PED-9651).
- commit 60a3d57
* Mon Mar 24 2025 hare@suse.de
- block/genhd: use seq_put_decimal_ull for diskstats decimal
  values (jsc#PED-9651).
- block: don't reorder requests in blk_mq_add_to_batch
  (jsc#PED-9651).
- block: don't reorder requests in blk_add_rq_to_plug
  (jsc#PED-9651).
- block: add a rq_list type (jsc#PED-9651).
- block: remove rq_list_move (jsc#PED-9651).
- commit ee68c48
* Mon Mar 24 2025 ohering@suse.de
- net: mana: Support holes in device list reply msg (git-fixes).
- net: mana: cleanup mana struct after debugfs_remove()
  (git-fixes).
- Drivers: hv: vmbus: Don't release fb_mmio resource in
  vmbus_free_mmio() (git-fixes).
- x86/hyperv: Fix output argument to hypercall that changes page
  visibility (git-fixes).
- fbdev: hyperv_fb: Allow graceful removal of framebuffer
  (git-fixes).
- fbdev: hyperv_fb: Simplify hvfb_putmem (git-fixes).
- fbdev: hyperv_fb: Fix hang in kdump kernel when on Hyper-V
  Gen 2 VMs (git-fixes).
- fbdev: hyperv_fb: iounmap() the correct memory when removing
  a device (git-fixes).
- x86/hyperv/vtl: Stop kernel from probing VTL0 low memory
  (git-fixes).
- commit 6ca88b5
* Mon Mar 24 2025 mgorman@suse.de
- kprobes: Use RCU in all users of __module_text_address()
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- kprobes: Reduce preempt disable scope
  in check_kprobe_access_safe() (bsc#1234370 (PREEMPT_RT
  prerequisite backports)).
- commit 8d86dd1
* Mon Mar 24 2025 hare@suse.de
- block: export blk_validate_limits (jsc#PED-9651).
- block: remove the ioprio field from struct request
  (jsc#PED-9651).
- block: remove the write_hint field from struct request
  (jsc#PED-9651).
- commit 4da93a9
* Mon Mar 24 2025 hare@suse.de
- Refresh
  patches.suse/block-pre-calculate-max_zone_append_sectors.patch.
- Delete
  patches.suse/Revert-block-pre-calculate-max_zone_append_sectors.patch.
- commit 176765a
* Mon Mar 24 2025 tbogendoerfer@suse.de
- net/mlx5e: Prevent bridge link show failure for
  non-eswitch-allowed devices (jsc#PED-11331).
- net/mlx5: Bridge, fix the crash caused by LAG state check
  (jsc#PED-11331).
- net/mlx5: Lag, Check shared fdb before creating MultiPort
  E-Switch (jsc#PED-11331).
- net/mlx5: Fix incorrect IRQ pool usage when releasing IRQs
  (jsc#PED-11331).
- net/mlx5: HWS, Rightsize bwc matcher priority (jsc#PED-11331).
- net/mlx5: DR, use the right action structs for STEv3
  (jsc#PED-11331).
- eth: bnxt: fix memory leak in queue reset (jsc#PED-10684
  jsc#PED-11230).
- eth: bnxt: fix kernel panic in the bnxt_get_queue_stats{rx |
  tx} (jsc#PED-10684 jsc#PED-11230).
- eth: bnxt: do not update checksum in bnxt_xdp_build_skb()
  (jsc#PED-10684 jsc#PED-11230).
- eth: bnxt: do not use BNXT_VNIC_NTUPLE unconditionally in
  queue restart logic (jsc#PED-10684 jsc#PED-11230).
- eth: bnxt: return fail if interface is down in
  bnxt_queue_mem_alloc() (jsc#PED-10684 jsc#PED-11230).
- eth: bnxt: fix truesize for mb-xdp-pass case (jsc#PED-10684
  jsc#PED-11230).
- net/mlx5: handle errors in mlx5_chains_create_table()
  (jsc#PED-11331).
- ice: register devlink prior to creating health reporters
  (jsc#PED-10419).
- ice: Fix switchdev slow-path in LAG (jsc#PED-10419).
- ice: fix memory leak in aRFS after reset (jsc#PED-10419).
- ice: do not configure destination override for switchdev
  (jsc#PED-10419).
- be2net: fix sleeping while atomic bugs in be_ndo_bridge_getlink
  (jsc#PED-8900 jsc#PED-11248).
- commit cffd61f
* Mon Mar 24 2025 hare@suse.de
- block: Handle bio_split() errors in bio_submit_split()
  (jsc#PED-9651).
- block: Error an attempt to split an atomic write in bio_split()
  (jsc#PED-9651).
- block: Rework bio_split() return value (jsc#PED-9651).
- commit cc36652
* Mon Mar 24 2025 hare@suse.de
- block: remove blk_freeze_queue() (jsc#PED-9651).
- Refresh
  patches.suse/block-always-verify-unfreeze-lock-on-the-owner-task.patch.
- commit c10f921
* Mon Mar 24 2025 hare@suse.de
- block: Replace sprintf() with sysfs_emit() (jsc#PED-9651).
- commit e18c441
* Mon Mar 24 2025 hare@suse.de
- block: Add a public bdev_zone_is_seq() helper (jsc#PED-9651).
- block: return unsigned int from queue_dma_alignment
  (jsc#PED-9651).
- Refresh
  patches.suse/block-Prevent-potential-deadlocks-in-zone-write-plug-error-recovery.patch.
- Refresh
  patches.suse/dm-Fix-dm-zoned-reclaim-zone-write-pointer-alignment.patch.
- commit 9f0b2a7
* Mon Mar 24 2025 dwagner@suse.de
- series: update metadata
  The lpfc driver update moved forward to the next stage on the way
  to mainline. Update the metadata to avoid breaking the kernel patch
  maintainance tooling.
- Refresh
  patches.suse/scsi-lpfc-Copyright-updates-for-14.4.0.8-patches.patch.
- Refresh
  patches.suse/scsi-lpfc-Free-phba-irq-in-lpfc_sli4_enable_msi-when.patch.
- Refresh
  patches.suse/scsi-lpfc-Handle-duplicate-D_IDs-in-ndlp-search-by-D.patch.
- Refresh
  patches.suse/scsi-lpfc-Ignore-ndlp-rport-mismatch-in-dev_loss_tmo.patch.
- Refresh
  patches.suse/scsi-lpfc-Reduce-log-message-generation-during-ELS-r.patch.
- Refresh
  patches.suse/scsi-lpfc-Update-lpfc-version-to-14.4.0.8.patch.
- commit 61224c0
* Mon Mar 24 2025 hare@suse.de
- Revert "block: pre-calculate max_zone_append_sectors"
  (jsc#PED-9651).
- commit 72c7300
* Mon Mar 24 2025 ykaukab@suse.de
- config: update using run_oldconfig.sh
- commit 71298c4
* Mon Mar 24 2025 hare@suse.de
- block: pre-calculate max_zone_append_sectors (jsc#PED-9651).
- commit 630582a
* Mon Mar 24 2025 hare@suse.de
- block: remove the max_zone_append_sectors check in
  blk_revalidate_disk_zones (jsc#PED-9651).
- block: update blk_stack_limits documentation (jsc#PED-9651).
- block: remove bio_add_zone_append_page (jsc#PED-9651).
- block: remove zone append special casing from the direct I/O
  path (jsc#PED-9651).
- blk-integrity: remove seed for user mapped buffers
  (jsc#PED-9651).
- block: add a bdev_limits helper (jsc#PED-9651).
- blk-mq: Unexport blk_mq_flush_busy_ctxs() (jsc#PED-9651).
- block: remove redundant explicit memory barrier from rq_qos
  waiter and waker (jsc#PED-9651).
- block: flush all throttled bios when deleting the cgroup
  (jsc#PED-9651).
- commit f26135d
* Mon Mar 24 2025 hare@suse.de
- block: sed-opal: add ioctl IOC_OPAL_SET_SID_PW (jsc#PED-9651
- commit 4f40e80
* Mon Mar 24 2025 hare@suse.de
- block: replace call_rcu by kfree_rcu for simple kmem_cache_free
  callback (jsc#PED-9651).
- block: enable passthrough command statistics (jsc#PED-9651).
- block: return void from the queue_sysfs_entry load_module method
  (jsc#PED-9651).
- block: add partition uuid into uevent as "PARTUUID"
  (jsc#PED-9651).
- block: move issue side time stamping to blk_account_io_start()
  (jsc#PED-9651).
- block: set issue time stamp based on queue state (jsc#PED-9651).
- block: introduce add_disk_fwnode() (jsc#PED-9651).
- block: add support for defining read-only partitions
  (jsc#PED-9651).
- block: kill blk_do_io_stat() helper (jsc#PED-9651).
- block: remove 'req->part' check for stats accounting
  (jsc#PED-9651).
- block: remove redundant passthrough check in
  blk_mq_need_time_stamp() (jsc#PED-9651).
- block: move iostat check into blk_acount_io_start()
  (jsc#PED-9651).
- commit 7ebf536
* Mon Mar 24 2025 tiwai@suse.de
- rpm/kernel-binary.spec.in: Fix missing 20-kernel-default-extra.conf (bsc#1239986)
  sle_version was obsoleted for SLE16.  It has to be combined with
  suse_version check.
- commit cbd5de3
* Mon Mar 24 2025 ykaukab@suse.de
- turbostat: rename patches using ./scripts/renamepatches
  Prepare to merge turbostat forklift backport
- commit c56074a
* Mon Mar 24 2025 mfranc@suse.cz
- s390/cio: Fix CHPID "configure" attribute caching (git-fixes
  bsc#1239979).
- commit 8905a0c
* Sun Mar 23 2025 tiwai@suse.de
- i2c: amd-mp2: drop free_irq() of devm_request_irq() allocated
  irq (git-fixes).
- keys: Fix UAF in key_put() (git-fixes).
- drm/i915/cdclk: Do cdclk post plane programming later
  (stable-fixes).
- drm/atomic: Filter out redundant DPMS calls (stable-fixes).
- drm/amd/amdkfd: Evict all queues even HWS remove queue failed
  (stable-fixes).
- drm/amd/display: Assign normalized_pix_clk when color depth =
  14 (stable-fixes).
- drm/amd/display: Restore correct backlight brightness after
  a GPU reset (stable-fixes).
- drm/amd/display: Disable unneeded hpd interrupts during dm_init
  (stable-fixes).
- drm/amdgpu/display: Allow DCC for video formats on GFX12
  (stable-fixes).
- drm/hyperv: Fix address space leak when Hyper-V DRM device is
  removed (git-fixes).
- drm/nouveau: Do not override forced connector status
  (stable-fixes).
- drm/vkms: Round fixp2int conversion in lerp_u16 (stable-fixes).
- drm/tests: hdmi: Remove redundant assignments (stable-fixes).
- drm/amd/display: Fix out-of-bound accesses (stable-fixes).
- commit f9bc5aa
* Sat Mar 22 2025 mgorman@suse.de
- Delete patches.suse/sysfs-Add-sys-kernel-realtime-entry.patch.
  No upstrem consensus on whether this is necessary. It's possible the same
  benefit could be achieved within udev with the risk that dynamic preempt
  may cause complications if preemption level changes during udev rule
  resolution.
- commit f984751
* Sat Mar 22 2025 mgorman@suse.de
- Delete
  patches.suse/preempt-Add-a-generic-function-to-return-the-preemption-string.patch.
  Will be replaced by upstream equivalent via SUSE-2025.
- commit 0d463f4
* Sat Mar 22 2025 tiwai@suse.de
- spi: Fix reference count leak in slave_show() (git-fixes).
- regulator: rtq2208: Fix the LDO DVS capability (git-fixes).
- regulator: rtq2208: Fix incorrect buck converter phase mapping
  (git-fixes).
- regulator: dummy: force synchronous probing (git-fixes).
- regulator: core: Fix deadlock in create_regulator() (git-fixes).
- spi: microchip-core: prevent RX overflows when transmit size >
  FIFO size (git-fixes).
- spi: omap2-mcspi: Correctly handle devm_clk_get_optional()
  errors (git-fixes).
- commit e7c032b
* Fri Mar 21 2025 vkarasulli@suse.de
- firmware: qcom: scm: smc: Handle missing SCM device
  (CVE-2024-57852 bsc#1239006).
- commit a7a0e2d
* Fri Mar 21 2025 vkarasulli@suse.de
- KVM: Explicitly verify target vCPU is online in  kvm_get_vcpu()
  (CVE-2024-58083 bsc#1239036).
- commit ea92b0c
* Fri Mar 21 2025 ggherdovich@suse.cz
- ACPI: processor: idle: Return an error if both P_LVL{2,3}
  idle states are invalid (bsc#1237530).
- commit c93b04f
* Fri Mar 21 2025 vkarasulli@suse.de
- nfp: bpf: Add check for nfp_app_ctrl_msg_alloc() (CVE-2025-21848
  bsc#1239479).
- commit 594a7b5
* Fri Mar 21 2025 jlee@suse.com
- lockdown: fix kernel lockdown enforcement issue when secure
  boot is enabled (bsc#1237521).
- commit f8669a3
* Fri Mar 21 2025 jlee@suse.com
- Delete
  patches.suse/0001-Lock-down-x86_64-kernel-in-secure-boot-mode-in-subsy.patch.
  Removed this patch because we will apply
  [PATCH] lockdown: fix kernel lockdown enforcement issue when secure boot
  is enabled
  from Srish Srinivasan <ssrish@linux.ibm.com>. (bsc#1237521)
  Refresh
  patches.suse/0001-initcall_blacklist-Does-not-allow-kernel_lockdown-be.patch.
- commit 5500cb2
* Fri Mar 21 2025 jlee@suse.com
- Delete
  patches.suse/0002-security-Add-a-kernel-lockdown-flag-for-early-boot-s.patch.
  Removed this patch because we will apply
  [PATCH] lockdown: fix kernel lockdown enforcement issue when secure boot
  is enabled
  from Srish Srinivasan <ssrish@linux.ibm.com>. (bsc#1237521)
  Refresh
  patches.suse/0001-security-create-hidden-area-to-keep-sensitive-data.patch.
- commit 331aba7
* Fri Mar 21 2025 jlee@suse.com
- Delete
  patches.suse/0003-efi-Set-early-kernel-lock-down-flag-if-booted-in-sec.patch.
  Removed this patch because we will apply
  [PATCH] lockdown: fix kernel lockdown enforcement issue when secure boot
  is enabled
  from Srish Srinivasan <ssrish@linux.ibm.com>. (bsc#1237521)
- commit 586858d
* Fri Mar 21 2025 jlee@suse.com
- Delete
  patches.suse/0004-ACPI-Check-early-kernel-lockdown-flag-before-overlay.patch.
  Removed this patch because we will apply
  [PATCH] lockdown: fix kernel lockdown enforcement issue when secure
  boot is enabled
  from Srish Srinivasan <ssrish@linux.ibm.com>. (bsc#1237521)
- commit 347398a
* Fri Mar 21 2025 jlee@suse.com
- Delete
  patches.suse/0005-kgdb-Check-early-kernel-lockdown-flag-before-using-k.patch.
  Removed this patch because we will apply
  [PATCH] lockdown: fix kernel lockdown enforcement issue when secure boot is enabled
  from Srish Srinivasan <ssrish@linux.ibm.com>. (bsc#1237521)
- commit 0872595
* Fri Mar 21 2025 ptesarik@suse.com
- dma-mapping: fix missing clear bdr in check_ram_in_range_map()
  (git-fixes).
- commit 3994034
* Fri Mar 21 2025 mgorman@suse.de
- tracing: Use preempt_model_str() (bsc#1234634 (Scheduler
  functional and performance backports)).
- xtensa: Rely on generic printing of preemption model
  (bsc#1234634 (Scheduler functional and performance backports)).
- x86: Rely on generic printing of preemption model (bsc#1234634
  (Scheduler functional and performance backports)).
- s390: Rely on generic printing of preemption model (bsc#1234634
  (Scheduler functional and performance backports)).
- powerpc: Rely on generic printing of preemption model
  (bsc#1234634 (Scheduler functional and performance backports)).
- arm64: Rely on generic printing of preemption model (bsc#1234634
  (Scheduler functional and performance backports)).
- arm: Rely on generic printing of preemption model (bsc#1234634
  (Scheduler functional and performance backports)).
- lib/dump_stack: Use preempt_model_str() (bsc#1234634 (Scheduler
  functional and performance backports)).
  Refresh
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  - patches.suse/kernel-add-release-status-to-kernel-build.patch
- sched: Add a generic function to return the preemption string
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched: Add unlikey branch hints to several system calls
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/core: Remove duplicate included header file stats.h
  (bsc#1234634 (Scheduler functional and performance backports)).
- x86/tsc: Always save/restore TSC sched_clock() on suspend/resume
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/rt: Update limit of sched_rt sysctl in documentation
  (bsc#1234634 (Scheduler functional and performance backports)).
- commit 0efe548
* Fri Mar 21 2025 tbogendoerfer@suse.de
- gve: unlink old napi when stopping a queue using queue API
  (jsc#PED-12442).
- gve: set xdp redirect target only when it is available
  (jsc#PED-12442).
- gve: Convert timeouts to secs_to_jiffies() (jsc#PED-12442).
- net: ena: Fix incorrect indentation (jsc#PED-12441).
- gve: Remove unused gve_adminq_set_mtu (jsc#PED-12442).
- eth: gve: use appropriate helper to set xdp_features
  (jsc#PED-12442).
- gve: trigger RX NAPI instead of TX NAPI in gve_xsk_wakeup
  (jsc#PED-12442).
- gve: fix XDP allocation path in edge cases (jsc#PED-12442).
- gve: process XSK TX descriptors as part of RX NAPI
  (jsc#PED-12442).
- gve: clean XDP queues in gve_tx_stop_ring_gqi (jsc#PED-12442).
- gve: Flow steering trigger reset only for timeout error
  (jsc#PED-12442).
- net: ena: remove devm from ethtool (jsc#PED-12441).
- net: ena: Remove deadcode (jsc#PED-12441).
- net: ena: Remove autopolling mode (jsc#PED-12441).
- gve: change to use page_pool_put_full_page when recycling pages
  (jsc#PED-12442).
- gve: add support for basic queue stats (jsc#PED-12442).
- gve: adopt page pool for DQ RDA mode (jsc#PED-12442).
- gve: move DQO rx buffer management related code to a new file
  (jsc#PED-12442).
- gve: Map NAPI instances to queues (jsc#PED-12442).
- gve: Map IRQs to NAPI instances (jsc#PED-12442).
- ena: Link queues to NAPIs (jsc#PED-12441).
- ena: Link IRQs to NAPI instances (jsc#PED-12441).
- commit 7e86f33
* Fri Mar 21 2025 mwilck@suse.com
- config: drop CONFIG_RTS5208 (jsc#PED-12436)
- commit aa48231
* Fri Mar 21 2025 tiwai@suse.de
- drm/amd/display: Use HW lock mgr for PSR1 when only one eDP
  (git-fixes).
- drm/amdkfd: Fix user queue validation on Gfx7/8 (git-fixes).
- drm/amdgpu/gfx12: correct cleanup of 'me' field with
  gfx_v12_0_me_fini() (git-fixes).
- drm/radeon: fix uninitialized size issue in
  radeon_vce_cs_parse() (git-fixes).
- drm/xe: Fix exporting xe buffers multiple times (git-fixes).
- gpu: host1x: Do not assume that a NULL domain means no DMA IOMMU
  (git-fixes).
- accel/qaic: Fix integer overflow in qaic_validate_req()
  (git-fixes).
- accel/qaic: Fix possible data corruption in BOs > 2G
  (git-fixes).
- drm/v3d: Don't run jobs that have errors flagged in its fence
  (git-fixes).
- drm/sched: Fix fence reference count leak (git-fixes).
- batman-adv: Ignore own maximum aggregation size during RX
  (git-fixes).
- Bluetooth: hci_event: Fix connection regression between LE
  and non-LE adapters (git-fixes).
- Bluetooth: Fix error code in chan_alloc_skb_cb() (git-fixes).
- phy: fix xa_alloc_cyclic() error handling (git-fixes).
- can: flexcan: disable transceiver during system PM (git-fixes).
- can: flexcan: only change CAN state when link up in system PM
  (git-fixes).
- can: rcar_canfd: Fix page entries in the AFL list (git-fixes).
- can: ucan: fix out of bound read in strscpy() source
  (git-fixes).
- mmc: sdhci-brcmstb: add cqhci suspend/resume to PM ops
  (git-fixes).
- mmc: atmel-mci: Add missing clk_disable_unprepare() (git-fixes).
- commit b41c1ad
* Fri Mar 21 2025 nmorey@suse.com
- RDMA/hns: Fix wrong value of max_sge_rd (git-fixes)
- commit 27c0c16
* Fri Mar 21 2025 nmorey@suse.com
- RDMA/hns: Fix missing xa_destroy() (git-fixes)
- commit eb7233d
* Fri Mar 21 2025 nmorey@suse.com
- RDMA/hns: Fix a missing rollback in error path of hns_roce_create_qp_common() (git-fixes)
- commit 8cab2f7
* Fri Mar 21 2025 nmorey@suse.com
- RDMA/hns: Fix invalid sq params not being blocked (git-fixes)
- commit 78e84f5
* Fri Mar 21 2025 nmorey@suse.com
- RDMA/hns: Fix unmatched condition in error path of alloc_user_qp_db() (git-fixes)
- commit d091e88
* Fri Mar 21 2025 nmorey@suse.com
- RDMA/hns: Fix soft lockup during bt pages loop (git-fixes)
- commit f21c5dc
* Fri Mar 21 2025 nmorey@suse.com
- RDMA/bnxt_re: Avoid clearing VLAN_ID mask in modify qp path (git-fixes)
- commit 0cf903d
* Fri Mar 21 2025 nmorey@suse.com
- RDMA/mlx5: Handle errors returned from mlx5r_ib_rate() (git-fixes)
- commit 6773008
* Fri Mar 21 2025 nmorey@suse.com
- RDMA/bnxt_re: Fix reporting maximum SRQs on P7 chips (git-fixes)
- commit d02de7f
* Fri Mar 21 2025 nmorey@suse.com
- RDMA/bnxt_re: Add missing paranthesis in map_qp_id_to_tbl_indx (git-fixes)
- commit d2797fc
* Fri Mar 21 2025 nmorey@suse.com
- RDMA/bnxt_re: Fix allocation of QP table (git-fixes)
- commit 2120053
* Fri Mar 21 2025 nmorey@suse.com
- RDMA/rxe: Fix the failure of ibv_query_device() and ibv_query_device_ex() tests (git-fixes)
- commit 6ee5467
* Thu Mar 20 2025 msuchanek@suse.de
- Update MIN RMA patch metadata.
- commit 397880c
* Thu Mar 20 2025 mwilck@suse.com
- scsi: core: Update API documentation (jsc#PED-11374).
- commit afbed9f
* Thu Mar 20 2025 mwilck@suse.com
- scsi: core: Remove the .slave_configure() method
  (jsc#PED-11374).
- commit e23ac39
* Thu Mar 20 2025 mwilck@suse.com
- scsi: Convert SCSI drivers to .sdev_configure() (jsc#PED-11374).
- commit f727f99
* Thu Mar 20 2025 mwilck@suse.com
- scsi: Rename .device_configure() into .sdev_configure()
  (jsc#PED-11374).
- commit da24907
* Thu Mar 20 2025 mwilck@suse.com
- scsi: Rename .slave_alloc() and .slave_destroy()
  (jsc#PED-11374).
- commit 15bec2e
* Thu Mar 20 2025 msuchanek@suse.de
- powerpc/pseries: Add a char driver for physical-attestation RTAS
  (jsc#PED-4486).
- powerpc/pseries: Add papr-platform-dump character driver for
  dump retrieval (jsc#PED-4486).
- powerpc/pseries: Add ibm,get-dynamic-sensor-state RTAS call
  support (jsc#PED-4486).
- powerpc/pseries: Add ibm,set-dynamic-indicator RTAS call support
  (jsc#PED-4486).
- powerpc/pseries: Add papr-indices char driver for
  ibm,get-indices (jsc#PED-4486).
- powerpc/pseries: Define papr_indices_io_block for papr-indices
  ioctls (jsc#PED-4486).
- powerpc/pseries: Define common functions for RTAS sequence calls
  (jsc#PED-4486).
- commit c1d4c4f
* Thu Mar 20 2025 mwilck@suse.com
- ata: libata-sff: Ensure that we cannot write outside the
  allocated buffer (git-fixes).
- commit 3d8b30d
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: version 2025.02.02 (jsc#PED-10489).
- commit 7bf3da6
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Add CPU%%c1e BIC for CWF (jsc#PED-10489).
- commit 8256a23
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Harden one-shot mode against cpu offline
  (jsc#PED-10489).
- commit 366d8e0
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Fix forked child affinity regression
  (jsc#PED-10489).
- commit 6366db1
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Add tcore clock PMT type (jsc#PED-10489).
- commit afcffd8
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: version 2025.01.14 (jsc#PED-10489).
- commit ca12a02
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Allow adding PMT counters directly by
  sysfs path (jsc#PED-10489).
- commit 37b1df6
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Allow mapping multiple PMT files with
  the same GUID (jsc#PED-10489).
- commit 8a90e6f
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Add PMT directory iterator helper
  (jsc#PED-10489).
- commit 75d1b39
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Extend PMT identification with a sequence
  number (jsc#PED-10489).
- commit 0290a7e
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Return default value for unmapped PMT
  domains (jsc#PED-10489).
- commit 9817bf4
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Check for non-zero value when MSR probing
  (jsc#PED-10489).
- commit a43d1f2
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Enhance turbostat self-performance
  visibility (jsc#PED-10489).
- commit 6c19cae
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Add fixed RAPL PSYS divisor for SPR
  (jsc#PED-10489).
- commit bf6f8ef
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Fix PMT mmaped file size rounding
  (jsc#PED-10489).
- commit cf7c965
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Remove SysWatt from DISABLED_BY_DEFAULT
  (jsc#PED-10489).
- commit af2594a
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Add an NMI column (jsc#PED-10489).
- commit 5470be6
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: add Busy%% to "show idle" (jsc#PED-10489).
- commit 3646652
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Introduce --force parameter
  (jsc#PED-10489).
- commit 23ebcd1
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Improve --help output (jsc#PED-10489).
- commit b1c1e48
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Exit on unsupported Vendors
  (jsc#PED-10489).
- commit 9955156
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Exit on unsupported Intel models
  (jsc#PED-10489).
- commit ac6ed96
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: update turbostat(8) (jsc#PED-10489).
- commit 4189edc
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Add initial support for ClearwaterForest
  (jsc#PED-10489).
- commit 00868a5
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Add initial support for PantherLake
  (jsc#PED-10489).
- commit 6c786e0
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: 2024.11.30 (jsc#PED-10489).
- commit befcb16
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Add RAPL psys as a built-in counter
  (jsc#PED-10489).
- commit 461da30
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Force --no-perf in --dump mode
  (jsc#PED-10489).
- commit c44095e
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Add support for /sys/class/drm/card1
  (jsc#PED-10489).
- commit 58cfa1c
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Cache graphics sysfs file descriptors
  during probe (jsc#PED-10489).
- commit 1bd8b6e
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Consolidate graphics sysfs access
  (jsc#PED-10489).
- commit 0f0ae6c
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Remove unnecessary fflush() call
  (jsc#PED-10489).
- commit 044a10d
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Enhance platform divergence description
  (jsc#PED-10489).
- commit 5a915ac
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Remove PC3 support on Lunarlake
  (jsc#PED-10489).
- commit 5cdff5e
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Rename arl_features to lnl_features
  (jsc#PED-10489).
- commit 71430ca
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Add back PC8 support on Arrowlake
  (jsc#PED-10489).
- commit 1469155
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Remove PC7/PC9 support on MTL
  (jsc#PED-10489).
- commit adf5534
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Honor --show CPU, even when even when
  num_cpus=1 (jsc#PED-10489).
- commit dffe523
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Allow using cpu device in perf counters
  on hybrid platforms (jsc#PED-10489).
- commit adc2554
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: Fix column printing for PMT xtal_time
  counters (jsc#PED-10489).
- commit 5fa62f1
* Thu Mar 20 2025 cfamullaconrad@suse.com
- tools/power turbostat: fix GCC9 build regression
  (jsc#PED-10489).
- commit 50f1052
* Thu Mar 20 2025 ykaukab@suse.de
- config: s390x: update using run_oldconfig.sh
- commit fc516b9
* Thu Mar 20 2025 iivanov@suse.de
- arm64: dts: rockchip: Add missing PCIe supplies to RockPro64 board (git-fixes)
- commit e3ff48c
* Thu Mar 20 2025 iivanov@suse.de
- arm64: dts: rockchip: Add avdd HDMI supplies to RockPro64 board dtsi (git-fixes)
- commit 5516b5a
* Thu Mar 20 2025 iivanov@suse.de
- arm64: dts: rockchip: Remove undocumented sdmmc property from (git-fixes)
- commit 638d95e
* Thu Mar 20 2025 iivanov@suse.de
- arm64: dts: rockchip: fix pinmux of UART5 for PX30 Ringneck on Haikou (git-fixes)
- commit 80f0a4f
* Thu Mar 20 2025 iivanov@suse.de
- arm64: dts: rockchip: fix pinmux of UART0 for PX30 Ringneck on Haikou (git-fixes)
- commit fedab81
* Thu Mar 20 2025 iivanov@suse.de
- arm64: dts: rockchip: remove supports-cqe from rk3588 tiger (git-fixes)
- commit 178b294
* Thu Mar 20 2025 iivanov@suse.de
- arm64: dts: rockchip: remove supports-cqe from rk3588 jaguar (git-fixes)
- commit 3a1de74
* Thu Mar 20 2025 iivanov@suse.de
- arm64: dts: freescale: imx8mm-verdin-dahlia: add Microphone Jack to (git-fixes)
- commit d13da10
* Thu Mar 20 2025 iivanov@suse.de
- arm64: dts: freescale: imx8mp-verdin-dahlia: add Microphone Jack to (git-fixes)
- commit f19dbca
* Thu Mar 20 2025 iivanov@suse.de
- arm64: dts: freescale: tqma8mpql: Fix vqmmc-supply (git-fixes)
- commit 5d6cf39
* Thu Mar 20 2025 iivanov@suse.de
- arm64: dts: bcm2712: PL011 UARTs are actually r1p5 (git-fixes)
- commit 965834f
* Thu Mar 20 2025 iivanov@suse.de
- arm64: mm: Populate vmemmap at the page level if not section aligned (git-fixes)
- commit 11d7647
* Wed Mar 19 2025 vkarasulli@suse.de
- iommu/vt-d: Remove device comparison in
  context_setup_pass_through_cb (git-fixes).
- commit 6f00978
* Wed Mar 19 2025 vkarasulli@suse.de
- iommu/vt-d: Fix suspicious RCU usage (git-fixes).
- commit 5ad5ea1
* Wed Mar 19 2025 mgorman@suse.de
- Revert "drm/i915: Depend on !PREEMPT_RT." (bsc#1234370).
- drm/i915/guc: Consider also RCU depth in busy loop
  (bsc#1234370).
- drm/i915: Drop the irqs_disabled() check (bsc#1234370).
- drm/i915/gt: Use spin_lock_irq() instead of local_irq_disable()
  + spin_lock() (bsc#1234370).
- drm/i915: Disable tracing points on PREEMPT_RT (bsc#1234370).
- drm/i915: Don't check for atomic context on PREEMPT_RT
  (bsc#1234370).
- commit 88585fa
* Wed Mar 19 2025 mgorman@suse.de
- drm/i915: Don't disable interrupts on PREEMPT_RT during atomic
  updates (bsc#1234370).
- commit cdca27f
* Wed Mar 19 2025 mgorman@suse.de
- drm/i915: Use preempt_disable/enable_rt() where recommended
  (bsc#1234370).
- commit 63dfe9f
* Wed Mar 19 2025 mgorman@suse.de
- serial: 8250: Revert "drop lockdep annotation from
  serial8250_clear_IER()" (bsc#1234370 (PREEMPT_RT prerequisite
  backports)).
- blacklist.conf: Refresh
- serial: 8250: Switch to nbcon console (bsc#1234370 (PREEMPT_RT
  prerequisite backports)).
- serial: 8250: Provide flag for IER toggling for RS485
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- serial: 8250: Use high-level writing function for FIFO
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- serial: 8250: Use frame time to determine timeout (bsc#1234370
  (PREEMPT_RT prerequisite backports)).
- serial: 8250: Explain the role of @read_status_mask (bsc#1234370
  (PREEMPT_RT prerequisite backports)).
- serial: 8250: Never adjust UART_LSR_DR in @read_status_mask
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- serial: 8250: Do not set UART_LSR_THRE in @read_status_mask
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- serial: 8250: Use @ier bits to determine if Rx is stopped
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- serial: 8250_port: Assign UPIO_UNKNOWN instead of its direct
  value (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- tty: serial: Work around warning backtrace in
  serial8250_set_defaults (bsc#1234370 (PREEMPT_RT prerequisite
  backports)).
- tty: serial: export serial_8250_warn_need_ioport (bsc#1234370
  (PREEMPT_RT prerequisite backports)).
- tty: serial: handle HAS_IOPORT dependencies (bsc#1234370
  (PREEMPT_RT prerequisite backports)).
- commit 031ec61
* Wed Mar 19 2025 glass.su@suse.com
- md/md-bitmap: fix wrong bitmap_limit for clustermd when write sb (bsc#1238212)
- commit e36aa4c
* Wed Mar 19 2025 ddiss@suse.de
- initramfs: fix hardlink hash leak without TRAILER (bsc#1232848).
- initramfs: allocate heap buffers together (bsc#1232848).
- init: add initramfs_internal.h (bsc#1232848).
- commit 9d3eb63
* Wed Mar 19 2025 jlee@suse.com
- x86/efi: skip memattr table on kexec boot (jsc#PED-12274).
- efi/esrt: remove esre_attribute::store() (jsc#PED-12274).
- efi/zboot: Limit compression options to GZIP and ZSTD
  (jsc#PED-12274).
- efi: Fix memory leak in efivar_ssdt_load (jsc#PED-12274).
- efi/libstub: Take command line overrides into account for
  loaded files (jsc#PED-12274).
- efi/libstub: Fix command line fallback handling when loading
  files (jsc#PED-12274).
- efi/libstub: Parse builtin command line after bootloader
  provided one (jsc#PED-12274).
- x86/efi: Apply EFI Memory Attributes after kexec
  (jsc#PED-12274).
- x86/efi: Drop support for the EFI_PROPERTIES_TABLE
  (jsc#PED-12274).
  Refresh
  patches.suse/0002-efi-Add-an-EFI_SECURE_BOOT-flag-to-indicate-secure-boot-mode.patch.
- efi/memattr: Ignore table if the size is clearly bogus
  (jsc#PED-12274).
- efi/zboot: Fix outdated comment about using LoadImage/StartImage
  (jsc#PED-12274).
- libstub,tpm: do not ignore failure case when reading final
  event log (jsc#PED-12274).
- tpm: fix unsigned/signed mismatch errors related to
  __calc_tpm2_event_size (jsc#PED-12274).
- tpm: do not ignore memblock_reserve return value
  (jsc#PED-12274).
- efi/libstub: measure initrd to PCR9 independent of source
  (jsc#PED-12274).
- efi/libstub: remove unnecessary cmd_line_len from
  efi_convert_cmdline() (jsc#PED-12274).
- x86/cpu: Fix FAM5_QUARK_X1000 to use X86_MATCH_VFM()
  (jsc#PED-12274).
- commit b9ae6eb
* Wed Mar 19 2025 jlee@suse.com
- efi/libstub: Bump up EFI_MMAP_NR_SLACK_SLOTS to 32
  (bsc#1239349).
- commit f7e4da8
* Tue Mar 18 2025 tiwai@suse.de
- Update config files: set CONFIG_DRM_CLIENT_SELECTION and CONFIG_DRM_CLIENT_SETUP
- commit 97c1612
* Tue Mar 18 2025 tiwai@suse.de
- EDAC/qcom: Correct interrupt enable register configuration
  (git-fixes).
- commit cf86879
* Tue Mar 18 2025 tiwai@suse.de
- module: Don't fail module loading when setting ro_after_init
  section RO failed (git-fixes).
- mtd: hyperbus: hbmc-am654: fix an OF node reference leak
  (git-fixes).
- commit db53e48
* Tue Mar 18 2025 tiwai@suse.de
- rseq/selftests: Fix riscv rseq_offset_deref_addv inline asm
  (git-fixes).
- rseq: Fix rseq registration with CONFIG_DEBUG_RSEQ (git-fixes).
- commit d572a1b
* Tue Mar 18 2025 tiwai@suse.de
- samples/landlock: Fix possible NULL dereference in parse_path()
  (git-fixes).
- commit 9a41c2d
* Tue Mar 18 2025 tiwai@suse.de
- scripts: generate_rust_analyzer: add missing macros deps
  (git-fixes).
- scripts/Makefile.extrawarn: Do not show clang's non-kprintf
  warnings at W=1 (git-fixes).
- scripts/mksysmap: Fix escape chars '$' (git-fixes).
- scripts/sorttable: fix orc_sort_cmp() to maintain symmetry
  and transitivity (git-fixes).
- commit 8b3ebf9
* Tue Mar 18 2025 tiwai@suse.de
- selftests: bonding: fix incorrect mac address (git-fixes).
- selftests/damon/damon_nr_regions: sort collected regiosn before
  checking with min/max boundaries (git-fixes).
- selftests/damon/damon_nr_regions: set ops update for merge
  results check to 100ms (git-fixes).
- selftests/damon/damos_quota: make real expectation of quota
  exceeds (git-fixes).
- selftests/damon/damos_quota_goal: handle minimum quota that
  cannot be further reduced (git-fixes).
- Revert "selftests/mm: remove local __NR_* definitions"
  (git-fixes).
- commit f916b2c
* Tue Mar 18 2025 tiwai@suse.de
- tools/power turbostat: Fix forked child affinity regression
  (git-fixes).
- tools/power turbostat: Fix PMT mmaped file size rounding
  (git-fixes).
- commit 00c6f9a
* Tue Mar 18 2025 tiwai@suse.de
- usb: typec: ucsi: Set orientation as none when connector is
  unplugged (git-fixes).
- commit 5e217bd
* Tue Mar 18 2025 tiwai@suse.de
- HID: hid-steam: Fix use-after-free when detaching device
  (git-fixes).
- commit 23d7480
* Tue Mar 18 2025 tiwai@suse.de
- wifi: rtw89: pci: disable PCIE wake bit when PCIE deinit
  (stable-fixes).
- commit a65f71f
* Tue Mar 18 2025 tiwai@suse.de
- wifi: rtw89: tweak setting of channel and TX power for MLO
  (stable-fixes).
- Refresh
  patches.suse/wifi-rtw89-fix-proceeding-MCC-with-wrong-scanning-st.patch.
- commit 77488c0
* Tue Mar 18 2025 tiwai@suse.de
- wifi: mac80211: Support parsing EPCS ML element (stable-fixes).
- Refresh
  patches.suse/wifi-mac80211-fix-MLE-non-inheritance-parsing.patch.
- Refresh
  patches.suse/wifi-mac80211-fix-vendor-specific-inheritance.patch.
- commit 1421c5d
* Tue Mar 18 2025 tiwai@suse.de
- drm/nouveau: select FW caching (git-fixes).
- nvkm: correctly calculate the available space of the GSP cmdq
  buffer (stable-fixes).
- nvkm/gsp: correctly advance the read pointer of GSP message
  queue (stable-fixes).
- drm/nouveau: Run DRM default client setup (stable-fixes).
- drm/fbdev-ttm: Support struct drm_driver.fbdev_probe
  (stable-fixes).
- drm: Add client-agnostic setup helper (stable-fixes).
- drm/fbdev: Add memory-agnostic fbdev client (stable-fixes).
- drm/fbdev-helper: Move color-mode lookup into 4CC format helper
  (stable-fixes).
- commit 7808594
* Tue Mar 18 2025 mwilck@suse.com
- dm-flakey: Fix memory corruption in optional corrupt_bio_byte
  feature (git-fixes).
- commit 5ee65a9
* Tue Mar 18 2025 tiwai@suse.de
- soc: qcom: pdr: Fix the potential deadlock (git-fixes).
- firmware: qcom: uefisecapp: fix efivars registration race
  (git-fixes).
- firmware: qcom: scm: Fix error code in probe() (git-fixes).
- soc: imx8m: Unregister cpufreq and soc dev in cleanup path
  (git-fixes).
- firmware: imx-scu: fix OF node leak in .probe() (git-fixes).
- ubi: Add a check for ubi_num (git-fixes).
- commit 65fa628
* Mon Mar 17 2025 lduncan@suse.com
- scsi: ufs: core: Fix use-after free in init error and remove
  paths (CVE-2025-21739 bsc#1238506).
- commit df21342
* Mon Mar 17 2025 ggherdovich@suse.cz
- cpufreq/amd-pstate: Fix cpufreq_policy ref counting (git-fixes
  CVE-2025-21841).
- commit be4b6ae
* Mon Mar 17 2025 ggherdovich@suse.cz
- cpufreq/amd-pstate: Fix max_perf updation with schedutil
  (git-fixes).
- cpufreq/amd-pstate: Remove the goto label in
  amd_pstate_update_limits (git-fixes).
- commit 89584e6
* Mon Mar 17 2025 ggherdovich@suse.cz
- cpufreq/amd-pstate: Fix per-policy boost flag incorrect when
  fail (git-fixes).
- commit 3905635
* Mon Mar 17 2025 ggherdovich@suse.cz
- cpufreq/amd-pstate: Refactor max frequency calculation
  (bsc#1233975).
- commit 2243400
* Mon Mar 17 2025 ggherdovich@suse.cz
- cpufreq/amd-pstate: Drop boost_state variable (bsc#1233975).
- commit 8becee9
* Mon Mar 17 2025 ggherdovich@suse.cz
- cpufreq/amd-pstate: Drop ret variable from
  amd_pstate_set_energy_pref_index() (bsc#1233975).
- cpufreq/amd-pstate: Always write EPP value when updating perf
  (bsc#1233975).
- cpufreq/amd-pstate: Cache EPP value and use that everywhere
  (bsc#1233975).
- cpufreq/amd-pstate: Move limit updating code (bsc#1233975).
- cpufreq/amd-pstate: Change amd_pstate_update_perf() to return
  an int (bsc#1233975).
- cpufreq/amd-pstate: store all values in cpudata struct in khz
  (bsc#1233975).
- cpufreq/amd-pstate: Only update the cached value in
  msr_set_epp() on success (bsc#1233975).
- cpufreq/amd-pstate: Use FIELD_PREP and FIELD_GET macros
  (bsc#1233975).
- cpufreq/amd-pstate: Drop cached epp_policy variable
  (bsc#1233975).
- commit 72b6cbd
* Mon Mar 17 2025 ggherdovich@suse.cz
- cpufreq/amd-pstate: convert mutex use to guard() (stable-fixes).
- commit fff7e25
* Mon Mar 17 2025 ggherdovich@suse.cz
- cpufreq/amd-pstate: Add trace event for EPP perf updates
  (bsc#1233975).
- commit ff4fc8b
* Mon Mar 17 2025 ggherdovich@suse.cz
- cpufreq/amd-pstate: Merge amd_pstate_epp_cpu_offline() and
  amd_pstate_epp_offline() (stable-fixes).
- cpufreq/amd-pstate: Remove the cppc_state check in
  offline/online functions (stable-fixes).
- cpufreq/amd-pstate: Refactor amd_pstate_epp_reenable() and
  amd_pstate_epp_offline() (stable-fixes).
- commit 96308d8
* Mon Mar 17 2025 ggherdovich@suse.cz
- cpufreq/amd-pstate: Move the invocation of
  amd_pstate_update_perf() (bsc#1233975).
- cpufreq/amd-pstate: Convert the amd_pstate_get/set_epp()
  to static calls (bsc#1233975).
- commit d070175
* Mon Mar 17 2025 oneukum@suse.com
- media: vidtv: Fix a null-ptr-deref in vidtv_mux_stop_thread
  (git-fixes).
- commit 97cb127
* Mon Mar 17 2025 ggherdovich@suse.cz
- cpufreq/amd-pstate-ut: Add fix for min freq unit test
  (bsc#1233975).
- commit 9e7a47c
* Mon Mar 17 2025 ggherdovich@suse.cz
- cpufreq/amd-pstate: Drop needless EPP initialization
  (bsc#1233975).
- cpufreq/amd-pstate: Use amd_pstate_update_min_max_limit()
  for EPP limits (bsc#1233975).
- commit 441355e
* Mon Mar 17 2025 oneukum@suse.com
- media: uvcvideo: Add Kurokesu C1 PRO camera (git-fixes).
- commit ea77e6f
* Mon Mar 17 2025 oneukum@suse.com
- media: uvcvideo: Add new quirk definition for the Sonix
  Technology Co. 292a camera (git-fixes).
- commit 36000c4
* Mon Mar 17 2025 oneukum@suse.com
- media: uvcvideo: Implement dual stream quirk to fix loss of
  usb packets (git-fixes).
- commit 26eff04
* Mon Mar 17 2025 oneukum@suse.com
- media: bcm2835-unicam: Disable trigger mode operation
  (git-fixes).
- commit aed8a4d
* Mon Mar 17 2025 oneukum@suse.com
- usbnet: ipheth: document scope of NCM implementation
  (git-fixes).
- commit 59787c7
* Mon Mar 17 2025 oneukum@suse.com
- usb: quirks: Add DELAY_INIT and NO_LPM for Prolific Mass
  Storage Card Reader (git-fixes).
- commit 80d32a6
* Mon Mar 17 2025 oneukum@suse.com
- usb: xhci: Enable the TRB overfetch quirk on VIA VL805
  (git-fixes).
- commit 6690424
* Mon Mar 17 2025 oneukum@suse.com
- USB: pci-quirks: Fix HCCPARAMS register error for LS7A EHCI
  (git-fixes).
- commit a1670ac
* Mon Mar 17 2025 oneukum@suse.com
- usb: typec: ucsi: Set orientation as none when connector is
  unplugged (git-fixes).
- commit 5ce8719
* Mon Mar 17 2025 iivanov@suse.de
- Fix mmu notifiers for range-based invalidates (bsc#1239601)
- commit 2dfd96f
* Mon Mar 17 2025 trenn@suse.de
- supported.conf:
  Mark intel_plr_tpmi and intel_tpmi_power_domains as supported
  jsc#PED-10664
- commit 474b66f
* Mon Mar 17 2025 vkarasulli@suse.de
- Update
  patches.suse/ASoC-SOF-stream-ipc-Check-for-cstream-nullity-in-sof.patch
  (git-fixes CVE-2025-21847 bsc#1239471).
- Update
  patches.suse/HID-multitouch-Add-NULL-check-in-mt_input_configured.patch
  (git-fixes CVE-2024-58020 bsc#1239346).
- Update
  patches.suse/USB-gadget-f_midi-f_midi_complete-to-call-queue_work.patch
  (git-fixes CVE-2025-21859 bsc#1239467).
- Update patches.suse/acct-perform-last-write-from-workqueue.patch
  (git-fixes CVE-2025-21846 bsc#1239508).
- Update
  patches.suse/bpf-Reject-struct_ops-registration-that-uses-module-.patch
  (git-fixes CVE-2024-58060 bsc#1238967).
- Update
  patches.suse/drm-i915-gt-Use-spin_lock_irqsave-in-interruptible-c.patch
  (git-fixes CVE-2025-21849 bsc#1239485).
- Update
  patches.suse/fbdev-omap-use-threaded-IRQ-for-LCD-DMA.patch
  (stable-fixes CVE-2025-21821 bsc#1239174).
- Update
  patches.suse/ibmvnic-Don-t-reference-skb-after-sending-to-VIOS.patch
  (jsc#PED_10911 jsc#PED-3606 CVE-2025-21855 bsc#1239484).
- Update patches.suse/mtd-spi-nor-sst-Fix-SST-write-failure.patch
  (git-fixes CVE-2025-21845 bsc#1239511).
- Update
  patches.suse/net-Add-rx_skb-of-kfree_skb-to-raw_tp_null_args.patch
  (git-fixes CVE-2025-21852 bsc#1239487).
- Update
  patches.suse/nvmet-Fix-crash-when-a-namespace-is-disabled.patch
  (git-fixes CVE-2025-21850 bsc#1239477).
- Update
  patches.suse/powerpc-code-patching-Fix-KASAN-hit-by-not-flagging-.patch
  (bsc#1215199 CVE-2025-21866 bsc#1239473).
- Update
  patches.suse/s390-ism-add-release-function-for-struct-device.patch
  (git-fixes bsc#1237494 CVE-2025-21856 bsc#1239486).
- commit f5a5d00
* Mon Mar 17 2025 tzimmermann@suse.com
- Update "nvkm/gsp: correctly advance the read pointer of GSP message queue" (bsc#1238997 CVE-2024-58019)
- commit 31b49bf
* Mon Mar 17 2025 tzimmermann@suse.com
- drm/i915: Grab intel_display from the encoder to avoid potential (bsc#1238972 CVE-2024-58074)
- commit 04e6c21
* Mon Mar 17 2025 tiwai@suse.de
- i2c: sis630: Fix an error handling path in sis630_probe()
  (git-fixes).
- i2c: ali15x3: Fix an error handling path in ali15x3_probe()
  (git-fixes).
- i2c: ali1535: Fix an error handling path in ali1535_probe()
  (git-fixes).
- i2c: omap: fix IRQ storms (git-fixes).
- commit 4d52526
* Mon Mar 17 2025 jlee@suse.com
- ACPI: GTDT: Relax sanity checking on Platform Timers array count
  (jsc#PED-12273).
- ACPI: video: Fix random crashes due to bad kfree()
  (jsc#PED-12273).
- ACPI: resource: acpi_dev_irq_override(): Check DMI match last
  (jsc#PED-12273).
- ACPI: resource: Add TongFang GM5HG0A to
  irq1_edge_low_force_override (jsc#PED-12273).
- ACPI: resource: Add Asus Vivobook X1504VAP to
  irq1_level_low_skip_override (jsc#PED-12273).
- ACPI: introduce acpi_arch_init() (jsc#PED-12273).
- ACPI/CDAT: Add CDAT/DSMAS shared and read only flag values
  (jsc#PED-12273).
- ACPI/IORT: Support CANWBS memory access flag (jsc#PED-12273).
- ACPICA: IORT: Update for revision E.f (jsc#PED-12273).
- ACPI: Switch back to struct platform_driver::remove()
  (jsc#PED-12273).
- ACPI: scan: Use strscpy() instead of strcpy() (jsc#PED-12273).
- ACPI: SBSHC: Use strscpy() instead of strcpy() (jsc#PED-12273).
- ACPI: SBS: Use strscpy() instead of strcpy() (jsc#PED-12273).
- ACPI: power: Use strscpy() instead of strcpy() (jsc#PED-12273).
- ACPI: pci_root: Use strscpy() instead of strcpy()
  (jsc#PED-12273).
- ACPI: pci_link: Use strscpy() instead of strcpy()
  (jsc#PED-12273).
- ACPI: event: Use strscpy() instead of strcpy() (jsc#PED-12273).
- ACPI: EC: Use strscpy() instead of strcpy() (jsc#PED-12273).
- ACPI: APD: Use strscpy() instead of strcpy() (jsc#PED-12273).
- ACPI: thermal: Use strscpy() instead of strcpy()
  (jsc#PED-12273).
- ACPI: processor_perflib: extend X86 dependency (jsc#PED-12273).
- ACPI: allow building without CONFIG_HAS_IOPORT (jsc#PED-12273).
- ACPI: pfr_telemetry: remove redundant error check on ret
  (jsc#PED-12273).
- ACPI: EC: make EC support compile-time conditional
  (jsc#PED-12273).
  Update config files.
  CONFIG_ACPI_EC=y on x86_64
  CONFIG_ACPI_EC is not set on arm64
  blacklist.conf: add 0674188f2f4d Enable EC support on LoongArch by default
  Add '0674188f2f4d ACPI: EC: Enable EC support on LoongArch by default'
  because we do not support LoongArch.
- ACPI: battery: Check for error code from devm_mutex_init()
  call (jsc#PED-12273).
- ACPI: battery: use DEFINE_SIMPLE_DEV_PM_OPS (jsc#PED-12273).
- ACPI: battery: initialize mutexes through devm_ APIs
  (jsc#PED-12273).
- ACPI: battery: allocate driver data through devm_ APIs
  (jsc#PED-12273).
- ACPI: battery: check result of register_pm_notifier()
  (jsc#PED-12273).
- acpi/arm64: remove unnecessary cast (jsc#PED-12273).
- ACPI: GTDT: Tighten the check for the array of platform timer
  structures (jsc#PED-12273).
- commit 08aefe9
* Mon Mar 17 2025 mgorman@suse.de
- series.conf: Move kprobe patches to sorted section
- commit 50044e2
* Sun Mar 16 2025 mgorman@suse.de
- bug: Use RCU instead RCU-sched to protect module_bug_list
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- static_call: Use RCU in all users of __module_text_address()
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- bpf: Use RCU in all users of __module_text_address()
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- jump_label: Use RCU in all users of __module_text_address()
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- jump_label: Use RCU in all users of __module_address()
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- x86: Use RCU in all users of __module_address() (bsc#1234370
  (PREEMPT_RT prerequisite backports)).
- cfi: Use RCU while invoking __module_address() (bsc#1234370
  (PREEMPT_RT prerequisite backports)).
- arm64: module: Use RCU in all users of __module_text_address()
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- ARM: module: Use RCU in all users of __module_text_address()
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- module: Use RCU in all users of __module_text_address()
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- module: Use RCU in all users of __module_address() (bsc#1234370
  (PREEMPT_RT prerequisite backports)).
- module: Use RCU in search_module_extables() (bsc#1234370
  (PREEMPT_RT prerequisite backports)).
- module: Allow __module_address() to be called from RCU section
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- module: Use RCU in __is_module_percpu_address() (bsc#1234370
  (PREEMPT_RT prerequisite backports)).
- module: Use RCU in find_symbol() (bsc#1234370 (PREEMPT_RT
  prerequisite backports)).
- module: Remove module_assert_mutex_or_preempt() from
  try_add_tainted_module() (bsc#1234370 (PREEMPT_RT prerequisite
  backports)).
- module: Use RCU in module_kallsyms_on_each_symbol() (bsc#1234370
  (PREEMPT_RT prerequisite backports)).
- module: Use RCU in __find_kallsyms_symbol_value() (bsc#1234370
  (PREEMPT_RT prerequisite backports)).
- module: Use RCU in find_module_all() (bsc#1234370 (PREEMPT_RT
  prerequisite backports)).
- module: Use RCU in module_get_kallsym() (bsc#1234370 (PREEMPT_RT
  prerequisite backports)).
- module: Use RCU in find_kallsyms_symbol() (bsc#1234370
  (PREEMPT_RT prerequisite backports)).
- module: Use proper RCU assignment in add_kallsyms() (bsc#1234370
  (PREEMPT_RT prerequisite backports)).
- module: Begin to move from RCU-sched to RCU (bsc#1234370
  (PREEMPT_RT prerequisite backports)).
- module: Extend the preempt disabled section in
  dereference_symbol_descriptor() (bsc#1234370 (PREEMPT_RT
  prerequisite backports)).
- commit a01f490
* Sun Mar 16 2025 tiwai@suse.de
- Input: iqs7222 - preserve system status register (git-fixes).
- Input: goodix-berlin - fix vddio regulator references
  (git-fixes).
- Input: goodix-berlin - fix comment referencing wrong regulator
  (git-fixes).
- Input: ads7846 - fix gpiod allocation (git-fixes).
- commit 7b707af
* Sat Mar 15 2025 tiwai@suse.de
- ALSA: hda/realtek: Add mute LED quirk for HP Pavilion x360
  14-dy1xxx (stable-fixes).
- commit 7b3f84c
* Sat Mar 15 2025 tiwai@suse.de
- ASoC: amd: yc: Support mic on another Lenovo ThinkPad E16 Gen
  2 model (stable-fixes).
- commit dfd3c28
* Sat Mar 15 2025 tiwai@suse.de
- ASoC: codecs: wm0010: Fix error handling path in
  wm0010_spi_probe() (git-fixes).
- ASoC: rt722-sdca: add missing readable registers (git-fixes).
- ASoC: cs42l43: Fix maximum ADC Volume (git-fixes).
- ASoC: ops: Consistently treat platform_max as control value
  (git-fixes).
- ASoC: Intel: sof_sdw: Fix unlikely uninitialized variable use
  in create_sdw_dailinks() (git-fixes).
- drm/xe: remove redundant check in xe_vm_create_ioctl()
  (git-fixes).
- drm/xe/pm: Temporarily disable D3Cold on BMG (git-fixes).
- drm/xe/userptr: Fix an incorrect assert (git-fixes).
- drm/xe: Release guc ids before cancelling work (git-fixes).
- drm/i915: Increase I915_PARAM_MMAP_GTT_VERSION version to
  indicate support for partial mmaps (git-fixes).
- drm/dp_mst: Fix locking when skipping CSN before topology
  probing (git-fixes).
- drm/panic: fix overindented list items in documentation
  (git-fixes).
- drm/panic: use `div_ceil` to clean Clippy warning (git-fixes).
- drm/gma500: Add NULL check for pci_gfx_root in
  mid_get_vbt_data() (git-fixes).
- drm/amdgpu: NULL-check BO's backing store when determining
  GFX12 PTE flags (git-fixes).
- drm/amd/display: Fix slab-use-after-free on hdcp_work
  (git-fixes).
- drm/amd/display: fix default brightness (git-fixes).
- drm/amd/display: fix missing .is_two_pixels_per_container
  (git-fixes).
- commit a0a574a
* Fri Mar 14 2025 mgorman@suse.de
- tty: serial: export serial_8250_warn_need_ioport (bsc#1234370
  (PREEMPT_RT prerequisite backports)).
- commit 48458ed
* Fri Mar 14 2025 mgorman@suse.de
- Update patches to mainline versions (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Add
  kprobes: Reduce preempt disable scope in check_kprobe_access_safe()
- Update
  patches.suse/kprobes-Use-RCU-in-all-users-of-__module_text_address.patch
- commit d74e94a
* Fri Mar 14 2025 ggherdovich@suse.cz
- intel_idle: add Clearwater Forest SoC support (jsc#10590).
- commit 2854d6d
* Fri Mar 14 2025 vbabka@suse.cz
- mm/migrate_device: don't add folio to be freed to LRU in
  migrate_device_finalize() (CVE-2025-21861 bsc#1239483).
- commit fdddb9f
* Fri Mar 14 2025 mwilck@suse.com
- dm vdo: add missing spin_lock_init (git-fixes).
- commit b792a24
* Fri Mar 14 2025 mwilck@suse.com
- dm-integrity: Avoid divide by zero in table status in Inline
  mode (git-fixes).
- commit e905656
* Fri Mar 14 2025 mwilck@suse.com
- dm-crypt: track tag_offset in convert_context (git-fixes).
- commit 915d69f
* Fri Mar 14 2025 mwilck@suse.com
- dm-crypt: don't update io->sector after
  kcryptd_crypt_write_io_submit() (git-fixes).
- commit 8f09e8c
* Fri Mar 14 2025 mwilck@suse.com
- dm-ebs: don't set the flag DM_TARGET_PASSES_INTEGRITY
  (git-fixes).
- commit 0a56a91
* Fri Mar 14 2025 mwilck@suse.com
- dm-verity FEC: Fix RS FEC repair for roots unaligned to block
  size (take 2) (git-fixes).
- commit 54105ae
* Fri Mar 14 2025 mwilck@suse.com
- dm array: fix cursor index when skipping across block boundaries
  (git-fixes).
- commit 326fa75
* Fri Mar 14 2025 mwilck@suse.com
- dm array: fix unreleased btree blocks on closing a faulty
  array cursor (git-fixes).
- commit c753f51
* Fri Mar 14 2025 mwilck@suse.com
- dm thin: Add missing destroy_work_on_stack() (git-fixes).
- commit 9070649
* Fri Mar 14 2025 mwilck@suse.com
- dm: Fix typo in error message (git-fixes).
- commit e99a4d1
* Fri Mar 14 2025 tbogendoerfer@suse.de
- geneve: Suppress list corruption splat in
  geneve_destroy_tunnels() (CVE-2025-21858 bsc#1239468).
- gtp: Suppress list corruption splat in gtp_net_exit_batch_rtnl()
  (CVE-2025-21865 bsc#1239481).
- geneve: Fix use-after-free in geneve_find_dev() (CVE-2025-21858
  bsc#1239468).
- geneve: Suppress list corruption splat in
  geneve_destroy_tunnels() (CVE-2025-21858 bsc#1239468).
- gtp: Suppress list corruption splat in gtp_net_exit_batch_rtnl()
  (CVE-2025-21865 bsc#1239481).
- geneve: Fix use-after-free in geneve_find_dev() (CVE-2025-21858
  bsc#1239468).
- commit 3208c63
* Fri Mar 14 2025 mgorman@suse.de
- rt: Add clarification comments to series.conf
- commit dab06d0
* Fri Mar 14 2025 mgorman@suse.de
- Update 8250 closer to mainline implementation
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Add
  serial: 8250: Do not set UART_LSR_THRE in @read_status_mask
  serial: 8250: Explain the role of @read_status_mask
  serial: 8250: Never adjust UART_LSR_DR in @read_status_mask
  serial: 8250: Provide flag for IER toggling for RS485
  serial: 8250: Use frame time to determine timeout (bsc#1234370
  serial: 8250: Use high-level writing function for FIFO
  serial: 8250: Use @ier bits to determine if Rx is stopped
  serial: 8250_port: Assign UPIO_UNKNOWN instead of its direct value
  tty: serial: Work around warning backtrace in serial8250_set_defaults
  tty: serial: handle HAS_IOPORT dependencies
- Refresh
  patches.suse/serial-8250-Revert-drop-lockdep-annotation-from-serial8250_clear_IER.patch
  patches.suse/serial-8250-Switch-to-nbcon-console.patch
- blacklist.conf: Ignore reverts
- commit 156c7e3
* Fri Mar 14 2025 tiwai@suse.de
- wifi: cfg80211: cancel wiphy_work before freeing wiphy
  (git-fixes).
- wifi: mac80211: don't queue sdata::work for a non-running sdata
  (git-fixes).
- wifi: iwlwifi: mvm: fix PNVM timeout for non-MSI-X platforms
  (git-fixes).
- wifi: iwlwifi: pcie: Fix TSO preparation (git-fixes).
- Bluetooth: hci_event: Fix enabling passive scanning (git-fixes).
- drm/amd/pm: always allow ih interrupt from fw (stable-fixes).
- drm/radeon: Fix rs400_gpu_init for ATI mobility radeon Xpress
  200M (stable-fixes).
- drm/xe: Fix GT "for each engine" workarounds (stable-fixes).
- drm/xe: Remove double pageflip (git-fixes).
- HID: appleir: Fix potential NULL dereference at raw event handle
  (git-fixes).
- HID: intel-ish-hid: Fix use-after-free issue in
  ishtp_hid_remove() (git-fixes).
- HID: intel-ish-hid: Fix use-after-free issue in
  hid_ishtp_cl_remove() (git-fixes).
- HID: google: fix unused variable warning under !CONFIG_ACPI
  (git-fixes).
- drm/i915/dsi: Use TRANS_DDI_FUNC_CTL's own port width macro
  (git-fixes).
- drm/i915/dsi: convert to struct intel_display (stable-fixes).
- drm/i915: Plumb 'dsb' all way to the plane hooks (stable-fixes).
- drm/i915/color: Extract intel_color_modeset() (stable-fixes).
- wifi: cfg80211: cancel wiphy_work before freeing wiphy
  (git-fixes).
- wifi: mac80211: don't queue sdata::work for a non-running sdata
  (git-fixes).
- wifi: iwlwifi: mvm: fix PNVM timeout for non-MSI-X platforms
  (git-fixes).
- wifi: iwlwifi: pcie: Fix TSO preparation (git-fixes).
- Bluetooth: hci_event: Fix enabling passive scanning (git-fixes).
- drm/amd/pm: always allow ih interrupt from fw (stable-fixes).
- drm/radeon: Fix rs400_gpu_init for ATI mobility radeon Xpress
  200M (stable-fixes).
- drm/xe: Fix GT "for each engine" workarounds (stable-fixes).
- drm/xe: Remove double pageflip (git-fixes).
- HID: appleir: Fix potential NULL dereference at raw event handle
  (git-fixes).
- HID: intel-ish-hid: Fix use-after-free issue in
  ishtp_hid_remove() (git-fixes).
- HID: intel-ish-hid: Fix use-after-free issue in
  hid_ishtp_cl_remove() (git-fixes).
- HID: google: fix unused variable warning under !CONFIG_ACPI
  (git-fixes).
- drm/i915/dsi: Use TRANS_DDI_FUNC_CTL's own port width macro
  (git-fixes).
- drm/i915/dsi: convert to struct intel_display (stable-fixes).
- drm/i915: Plumb 'dsb' all way to the plane hooks (stable-fixes).
- drm/i915/color: Extract intel_color_modeset() (stable-fixes).
- commit a981d96
* Fri Mar 14 2025 nstange@suse.de
- crypto/testmgr: disallow sha1 in FIPS mode (jsc#PED-12225).
- commit 8e93183
* Fri Mar 14 2025 nstange@suse.de
- ipv6: sr: continue initialization at ENOENT HMAC instantiation
  failures (jsc#PED-12225).
- commit 27c4e79
* Fri Mar 14 2025 nstange@suse.de
- ipv6: sr: factor seg6_hmac_init_algo()'s per-algo code into
  separate function (jsc#PED-12225).
- commit 4e9bfd8
* Fri Mar 14 2025 nstange@suse.de
- ipv6: sr: factor seg6_hmac_exit()'s per-algo code into separate
  function (jsc#PED-12225).
- commit f60189c
* Fri Mar 14 2025 nstange@suse.de
- ipv6: sr: reject unsupported SR HMAC algos with -ENOENT
  (jsc#PED-12225).
- commit 6f2bd16
* Fri Mar 14 2025 pjakobsson@suse.de
- Refresh patches.suse/drm-xe-Move-the-coredump-registration-to-the-worker-.patch.
- Refresh patches.suse/drm-xe-Take-PM-ref-in-delayed-snapshot-capture-worke.patch.
- Refresh patches.suse/xe-oa-Fix-query-mode-of-operation-for-OAR-OAC.patch.
  Alt-commits
- commit 3371d69
* Thu Mar 13 2025 mgorman@suse.de
- Refresh
  patches.suse/serial-8250-Revert-drop-lockdep-annotation-from-serial8250_clear_IER.patch.
- blacklist.conf: Remove blacklisted dependency
- commit c753de3
* Thu Mar 13 2025 mgorman@suse.de
- Refresh patches.suse/serial-8250-Switch-to-nbcon-console.patch.
- commit 82ef2ab
* Thu Mar 13 2025 sjaeckel@suse.de
- tcp: Defer ts_recent changes until req is owned (git-fixes).
- tcp: devmem: don't write truncated dmabuf CMSGs to userspace
  (git-fixes).
- tcp: adjust rcvq_space after updating scaling ratio (git-fixes).
- tcp: Annotate data-race around sk->sk_mark in tcp_v4_send_reset
  (git-fixes).
- tcp: check space before adding MPTCP SYN options (git-fixes).
- net/tcp: Add missing lockdep annotations for TCP-AO hlist
  traversals (git-fixes).
- commit ac8e01e
* Thu Mar 13 2025 sjaeckel@suse.de
- tcp: drop secpath at the same time as we currently drop dst
  (CVE-2025-21864 bsc#1239482).
- commit 847360a
* Thu Mar 13 2025 davide.benini@suse.com
- net/smc: check iparea_offset and ipv6_prefixes_cnt when
  receiving proposal msg (CVE-2024-49571 bsc#1235733).
- commit 3e094ad
* Thu Mar 13 2025 jlee@suse.com
- Refresh
  patches.suse/0011-PM-hibernate-require-hibernate-snapshot-image-to-be-.patch.
  Improve the secret key invalid message.(bsc#1238797)
- commit 401f424
* Wed Mar 12 2025 mgorman@suse.de
- series.conf: Move modules patches to sorted section
- commit 3d9f4dd
* Wed Mar 12 2025 mgorman@suse.de
- scripts/python/git_sort/git_sort.yaml: update modules location
  Update the modules-next location jeyu/modules-next does not appear to have
  been used since 2021.
  See also ced75a2f5da7 ("MAINTAINERS: Add Luis Chamberlain as modules maintainer")
- commit 7c7198e
* Wed Mar 12 2025 mgorman@suse.de
- series.conf: Move patch to sorted section
- commit 3d9810e
* Wed Mar 12 2025 mgorman@suse.de
- ARM: module: Use RCU in all users of __module_text_address()
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update
  patches.suse/arm64-module-Use-RCU-in-all-users-of-__module_text_address.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update
  patches.suse/bpf-Use-RCU-in-all-users-of-__module_text_address.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update
  patches.suse/bug-Use-RCU-instead-RCU-sched-to-protect-module_bug_list.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update
  patches.suse/cfi-Use-RCU-while-invoking-__module_address.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update
  patches.suse/jump_label-Use-RCU-in-all-users-of-__module_address.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update
  patches.suse/jump_label-Use-RCU-in-all-users-of-__module_text_address.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update
  patches.suse/module-Allow-__module_address-to-be-called-from-RCU-section.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update
  patches.suse/module-Begin-to-move-from-RCU-sched-to-RCU.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update
  patches.suse/module-Extend-the-preempt-disabled-section-in-dereference_symbol_descriptor.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update
  patches.suse/module-Remove-module_assert_mutex_or_preempt-from-try_add_tainted_module.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update
  patches.suse/module-Use-RCU-in-__find_kallsyms_symbol_value.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update
  patches.suse/module-Use-RCU-in-__is_module_percpu_address.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update
  patches.suse/module-Use-RCU-in-all-users-of-__module_address.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update
  patches.suse/module-Use-RCU-in-all-users-of-__module_text_address.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update patches.suse/module-Use-RCU-in-find_kallsyms_symbol.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update patches.suse/module-Use-RCU-in-find_module_all.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update patches.suse/module-Use-RCU-in-find_symbol.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update patches.suse/module-Use-RCU-in-module_get_kallsym.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update
  patches.suse/module-Use-RCU-in-module_kallsyms_on_each_symbol.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update
  patches.suse/module-Use-RCU-in-search_module_extables.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update
  patches.suse/module-Use-proper-RCU-assignment-in-add_kallsyms.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update
  patches.suse/static_call-Use-RCU-in-all-users-of-__module_text_address.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- Update
  patches.suse/x86-Use-RCU-in-all-users-of-__module_address.patch
  (bsc#1234370 (PREEMPT_RT prerequisite backports)).
- commit bb9ab70
* Wed Mar 12 2025 mgorman@suse.de
- series.conf: Move RT-specific patches pending for mainline to top of RT section
- commit bc2a85a
* Wed Mar 12 2025 mkoutny@suse.com
- config: Disable CONFIG_CGROUP_FREEZER (jsc#PED-12329)
  We already have (by default):
  [#] CONFIG_MEMCG_V1 is not set
  [#] CONFIG_CPUSETS_V1 is not set
  that disable memory and cpuset v1 controllers respectively.
  Natural extension is disabling freezer v1 controller (as gradually going
  away from v1 controllers).
  This keeps the global freezer functionality (for suspend) and there is
  independent group freezing in cgroup v2.
- commit 46442b5
* Wed Mar 12 2025 mkoutny@suse.com
- config: Disable CONFIG_CGROUP_DEVICE (jsc#PED-12328)
  We already have (by default):
  [#] CONFIG_MEMCG_V1 is not set
  [#] CONFIG_CPUSETS_V1 is not set
  that disable memory and cpuset v1 controllers respectively.
  The replacement are BPF device-control programs attached to cgroups.
  openSUSE Tumbleweed switched to (such) v2 setup in 2021-03. Today is
  time for config cleanup.
- commit f845e63
* Wed Mar 12 2025 mkoutny@suse.com
- config: Disable CONFIG_CGROUP_CPUACCT (jsc#PED-12327)
  We already have (by default):
  [#] CONFIG_MEMCG_V1 is not set
  [#] CONFIG_CPUSETS_V1 is not set
  that disable memory and cpuset v1 controllers respectively.
  cpuacct is v1-only controller whose functionality was taken over with
  cgroup v2 core. It even adds slight overhead since it doubly-accounts
  CPU time in root cgroup even on v2-only runtimes.
  openSUSE Tumbleweed switched to v2 setup in 2021-03. Today (if not
  earlier) is time for config cleanup.
- commit fb4110d
* Wed Mar 12 2025 tbogendoerfer@suse.de
- net: ethernet: ti: am65-cpsw: fix memleak in certain XDP cases
  (CVE-2025-21788 bsc#1238761).
- net: ravb: Fix missing rtnl lock in suspend/resume path
  (CVE-2025-21801 bsc#1238758).
- net: hns3: fix oops when unload drivers paralleling
  (CVE-2025-21802 bsc#1238751).
- commit 3709944
* Wed Mar 12 2025 oneukum@suse.com
- pinctrl: nuvoton: npcm8xx: Add NULL check in npcm8xx_gpio_fw
  (git-fixes).
- pinctrl: bcm281xx: Fix incorrect regmap max_registers value
  (git-fixes).
- commit 53a34e8
* Wed Mar 12 2025 jlee@suse.com
- Bluetooth: MGMT: Fix slab-use-after-free Read in
  mgmt_remove_adv_monitor_sync (bsc#1239095 CVE-2024-58013).
- commit 828d19c
* Wed Mar 12 2025 jlee@suse.com
- Update
  patches.suse/Bluetooth-btusb-mediatek-Add-locks-for-usb_driver_cl.patch
  (git-fixes CVE-2025-21827 bsc#1238974).
- Update
  patches.suse/HID-hid-thrustmaster-fix-stack-out-of-bounds-read-in.patch
  (git-fixes CVE-2025-21794 bsc#1238502).
- Update
  patches.suse/Input-synaptics-fix-crash-when-enabling-pass-through.patch
  (bsc#1219522 CVE-2025-21746 bsc#1238498).
- Update
  patches.suse/KVM-x86-Load-DR6-with-guest-value-only-before-enteri.patch
  (git-fixes CVE-2025-21839 bsc#1239061).
- Update
  patches.suse/LoongArch-Fix-warnings-during-S3-suspend.patch
  (git-fixes CVE-2025-21803 bsc#1238744).
- Update
  patches.suse/NFC-nci-Add-bounds-checking-in-nci_hci_create_pipe.patch
  (git-fixes CVE-2025-21735 bsc#1238497).
- Update
  patches.suse/PCI-Avoid-putting-some-root-ports-into-D3-on-TUXEDO-.patch
  (git-fixes CVE-2025-21831 bsc#1239039).
- Update
  patches.suse/PCI-rcar-ep-Fix-incorrect-variable-used-when-calling.patch
  (git-fixes CVE-2025-21804 bsc#1238736).
- Update
  patches.suse/RDMA-mlx5-Fix-a-race-for-an-ODP-MR-which-leads-to-CQ.patch
  (git-fixes CVE-2025-21732 bsc#1237877).
- Update
  patches.suse/RDMA-mlx5-Fix-implicit-ODP-use-after-free.patch
  (git-fixes CVE-2025-21714 bsc#1237890).
- Update patches.suse/RDMA-rtrs-Add-missing-deinit-call.patch
  (git-fixes CVE-2025-21805 bsc#1238741).
- Update
  patches.suse/RDMA-rxe-Fix-the-warning-__rxe_cleanup-0x12c-0x170-r.patch
  (git-fixes CVE-2025-21829 bsc#1239030).
- Update
  patches.suse/Revert-drm-amd-display-Use-HW-lock-mgr-for-PSR1.patch
  (stable-fixes CVE-2025-21819 bsc#1238994).
- Update
  patches.suse/amdkfd-properly-free-gang_ctx_bo-when-failed-to-init.patch
  (git-fixes CVE-2025-21842 bsc#1239063).
- Update
  patches.suse/arm64-cacheinfo-Avoid-out-of-bounds-write-to-cacheinfo-array.patch
  (git-fixes CVE-2025-21785 bsc#1238747).
- Update
  patches.suse/ax25-Fix-refcount-leak-caused-by-setting-SO_BINDTODE.patch
  (git-fixes CVE-2025-21792 bsc#1238745).
- Update patches.suse/ax25-rcu-protect-dev-ax25_ptr.patch
  (git-fixes CVE-2025-21812 bsc#1238471).
- Update
  patches.suse/batman-adv-fix-panic-during-interface-removal.patch
  (git-fixes CVE-2025-21781 bsc#1238735).
- Update
  patches.suse/blk-cgroup-Fix-class-block_class-s-subsystem-refcount-leakage.patch
  (bsc#1237558 CVE-2025-21745 bsc#1238785).
- Update
  patches.suse/block-bfq-fix-waker_bfqq-UAF-after-bfq_split_bfqq.patch
  (git-fixes CVE-2025-21631 bsc#1236099).
- Update
  patches.suse/block-don-t-revert-iter-for-EIOCBQUEUED.patch
  (git-fixes CVE-2025-21832 bsc#1239105).
- Update
  patches.suse/can-ctucanfd-handle-skb-allocation-failure.patch
  (git-fixes CVE-2025-21775 bsc#1238501).
- Update
  patches.suse/can-etas_es58x-fix-potential-NULL-pointer-dereferenc.patch
  (git-fixes CVE-2025-21773 bsc#1238762).
- Update
  patches.suse/can-rockchip-rkcanfd_handle_rx_fifo_overflow_int-bai.patch
  (git-fixes CVE-2025-21774 bsc#1238770).
- Update
  patches.suse/driver-core-class-Fix-wild-pointer-dereferences-in-A.patch
  (git-fixes CVE-2025-21810 bsc#1238757).
- Update
  patches.suse/drm-amdgpu-avoid-buffer-overflow-attach-in-smu_sys_s.patch
  (stable-fixes CVE-2025-21780 bsc#1239115).
- Update
  patches.suse/drm-amdgpu-bail-out-when-failed-to-load-fw-in-psp_in.patch
  (git-fixes CVE-2025-21784 bsc#1238510).
- Update
  patches.suse/firewire-test-Fix-potential-null-dereference-in-fire.patch
  (git-fixes CVE-2025-21798 bsc#1238776).
- Update
  patches.suse/gpiolib-Fix-crash-on-error-in-gpiochip_get_ngpios.patch
  (git-fixes CVE-2025-21783 bsc#1238530).
- Update
  patches.suse/gpu-host1x-Fix-a-use-of-uninitialized-mutex.patch
  (git-fixes CVE-2025-21824 bsc#1238478).
- Update
  patches.suse/iommu-Fix-potential-memory-leak-in-iopf_queue_remove.patch
  (git-fixes CVE-2025-21770 bsc#1238495).
- Update patches.suse/landlock-Handle-weird-files.patch (git-fixes
  CVE-2025-21830 bsc#1239033).
- Update
  patches.suse/md-md-bitmap-Synchronize-bitmap_get_stats-with-bitmap-lifetime.patch
  (git-fixes CVE-2025-21712 bsc#1237886).
- Update patches.suse/misc-fastrpc-Fix-copy-buffer-page-size.patch
  (git-fixes CVE-2025-21734 bsc#1238734).
- Update
  patches.suse/mm-compaction-fix-UBSAN-shift-out-of-bounds-warning.patch
  (git fixes (mm/compaction) CVE-2025-21815 bsc#1238474).
- Update
  patches.suse/msft-hv-3160-KVM-x86-Reject-Hyper-V-s-SEND_IPI-hypercalls-if-loca.patch
  (git-fixes CVE-2025-21779 bsc#1238768).
- Update
  patches.suse/nbd-don-t-allow-reconnect-after-disconnect.patch
  (git-fixes CVE-2025-21731 bsc#1237881).
- Update
  patches.suse/neighbour-use-RCU-protection-in-__neigh_notify.patch
  (jsc#PED-10684 jsc#PED-11230 CVE-2025-21763 bsc#1237897).
- Update
  patches.suse/net-avoid-race-between-device-unregistration-and-eth.patch
  (jsc#PED-10684 jsc#PED-11230 CVE-2025-21701 bsc#1237164).
- Update
  patches.suse/net-mlx5-HWS-change-error-flow-on-matcher-disconnect.patch
  (jsc#PED-11331 CVE-2025-21751 bsc#1238907).
- Update
  patches.suse/net-mlx5-HWS-fix-definer-s-HWS_SET32-macro-for-negat.patch
  (jsc#PED-11331 CVE-2025-21800 bsc#1238743).
- Update
  patches.suse/net-mlx5e-add-missing-cpu_to_node-to-kvzalloc_node-i.patch
  (jsc#PED-11331 CVE-2025-21717 bsc#1238866).
- Update
  patches.suse/net-rose-fix-timer-races-against-user-threads.patch
  (git-fixes CVE-2025-21718 bsc#1239073).
- Update
  patches.suse/net-rose-prevent-integer-overflows-in-rose_setsockop.patch
  (git-fixes CVE-2025-21711 bsc#1239114).
- Update
  patches.suse/net-usb-rtl8150-enable-basic-endpoint-checking.patch
  (git-fixes CVE-2025-21708 bsc#1239087).
- Update
  patches.suse/netdev-prevent-accessing-NAPI-instances-from-another.patch
  (jsc#PED-12085 CVE-2025-21659 bsc#1236206).
- Update
  patches.suse/nfsd-clear-acl_access-acl_default-after-releasing-them.patch
  (git-fixes CVE-2025-21796 bsc#1238716).
- Update patches.suse/padata-avoid-UAF-for-reorder_work.patch
  (git-fixes CVE-2025-21726 bsc#1238865).
- Update patches.suse/padata-fix-UAF-in-padata_reorder.patch
  (git-fixes CVE-2025-21727 bsc#1237876).
- Update
  patches.suse/partitions-mac-fix-handling-of-bogus-partition-table.patch
  (git-fixes CVE-2025-21772 bsc#1238911).
- Update
  patches.suse/powerpc-pseries-iommu-Don-t-unset-window-if-it-was-n.patch
  (jsc#PED-10539 git-fixes CVE-2025-21713 bsc#1237887).
- Update
  patches.suse/sched_ext-Fix-incorrect-autogroup-migration-detection.patch
  (git fixes (sched) CVE-2025-21771 bsc#1238752).
- Update
  patches.suse/scsi-mpi3mr-Fix-possible-crash-when-setting-up-bsg-fails.patch
  (git-fixes CVE-2025-21723 bsc#1238864).
- Update
  patches.suse/seccomp-passthrough-uretprobe-systemcall-without-fil.patch
  (git-fixes CVE-2025-21834 bsc#1239026).
- Update patches.suse/spi-sn-f-ospi-Fix-division-by-zero.patch
  (git-fixes CVE-2025-21793 bsc#1238500).
- Update patches.suse/tty-xilinx_uartps-split-sysrq-handling.patch
  (git-fixes CVE-2025-21820 bsc#1238479).
- Update
  patches.suse/usb-cdc-acm-Check-control-transfer-buffer-size-befor.patch
  (git-fixes CVE-2025-21704 bsc#1237571).
- Update
  patches.suse/usb-gadget-core-flush-gadget-workqueue-after-device-.patch
  (git-fixes CVE-2025-21838 bsc#1239065).
- Update
  patches.suse/usb-gadget-f_midi-fix-MIDI-Streaming-descriptor-leng.patch
  (git-fixes CVE-2025-21835 bsc#1239068).
- Update patches.suse/usbnet-ipheth-fix-DPE-OoB-read.patch
  (git-fixes CVE-2025-21741 bsc#1238767).
- Update
  patches.suse/usbnet-ipheth-fix-possible-overflow-in-DPE-length-ch.patch
  (git-fixes CVE-2025-21743 bsc#1238781).
- Update
  patches.suse/usbnet-ipheth-use-static-NDP16-location-in-URB.patch
  (git-fixes CVE-2025-21742 bsc#1238771).
- Update
  patches.suse/vsock-Keep-the-binding-until-socket-destruction.patch
  (git-fixes CVE-2025-21756 bsc#1238876).
- Update
  patches.suse/vsock-Orphan-socket-after-transport-release.patch
  (jsc#PED-11028 CVE-2025-21755 bsc#1237882).
- Update
  patches.suse/wifi-brcmfmac-Check-the-return-value-of-of_property_.patch
  (stable-fixes CVE-2025-21750 bsc#1238905).
- Update
  patches.suse/wifi-mac80211-don-t-flush-non-uploaded-STAs.patch
  (git-fixes CVE-2025-21828 bsc#1238958).
- Update
  patches.suse/wifi-rtw89-avoid-to-init-mgnt_entry-list-twice-when-.patch
  (git-fixes CVE-2025-21730 bsc#1237878).
- Update
  patches.suse/wifi-rtw89-fix-race-between-cancel_hw_scan-and-hw_sc.patch
  (git-fixes CVE-2025-21729 bsc#1237874).
- Update
  patches.suse/workqueue-Put-the-pwq-after-detaching-the-rescuer-from-the-pool.patch
  (bsc#1237866 CVE-2025-21786 bsc#1238505).
- Update patches.suse/zram-fix-potential-UAF-of-zram-table.patch
  (git-fixes CVE-2025-21671 bsc#1236692).
- commit af45f0e
* Wed Mar 12 2025 jlee@suse.com
- Update
  patches.suse/ALSA-6fire-Release-resources-at-card-release.patch
  (git-fixes CVE-2024-53239 bsc#1235054 bsc#1234853).
- Update
  patches.suse/ASoC-soc-pcm-don-t-use-soc_pcm_ret-on-.prepare-callb.patch
  (stable-fixes CVE-2024-58077 bsc#1239090).
- Update
  patches.suse/Bluetooth-L2CAP-do-not-leave-dangling-sk-pointer-on-.patch
  (stable-fixes CVE-2024-56605 bsc#1235061 bsc#1234853).
- Update
  patches.suse/Bluetooth-L2CAP-handle-NULL-sock-pointer-in-l2cap_so.patch
  (git-fixes CVE-2024-58009 bsc#1238760).
- Update
  patches.suse/Bluetooth-btbcm-Fix-NULL-deref-in-btbcm_get_board_na.patch
  (git-fixes CVE-2024-57988 bsc#1237910).
- Update
  patches.suse/Bluetooth-btrtl-check-for-NULL-in-btrtl_setup_realte.patch
  (git-fixes CVE-2024-57987 bsc#1237905).
- Update
  patches.suse/HID-core-Fix-assumption-that-Resolution-Multipliers-.patch
  (git-fixes CVE-2024-57986 bsc#1237907).
- Update
  patches.suse/HID-hid-thrustmaster-Fix-warning-in-thrustmaster_pro.patch
  (git-fixes CVE-2024-57993 bsc#1237894).
- Update
  patches.suse/HID-winwing-Add-NULL-check-in-winwing_init_led.patch
  (git-fixes CVE-2024-58021 bsc#1238778).
- Update
  patches.suse/KEYS-trusted-dcp-fix-improper-sg-use-with-CONFIG_VMA.patch
  (git-fixes CVE-2024-58008 bsc#1238749).
- Update
  patches.suse/NFSv4.0-Fix-a-use-after-free-problem-in-the-asynchronous-open.patch
  (git-fixes CVE-2024-53173 bsc#1234891 bsc#1234853).
- Update
  patches.suse/PCI-dwc-ep-Prevent-changing-BAR-size-flags-in-pci_ep.patch
  (git-fixes CVE-2024-58006 bsc#1238772).
- Update
  patches.suse/block-Prevent-potential-deadlocks-in-zone-write-plug-error-recovery.patch
  (git-fixes CVE-2024-55642 bsc#1235744).
- Update
  patches.suse/block-avoid-to-reuse-hctx-not-removed-from-cpuhp-callback-list.patch
  (git-fixes CVE-2024-41149 bsc#1235698).
- Update
  patches.suse/bpf-Mark-raw_tp-arguments-with-PTR_MAYBE_NULL.patch
  (git-fixes CVE-2024-56702 bsc#1235501).
- Update
  patches.suse/clk-mmp2-call-pm_genpd_init-only-after-genpd.name-is.patch
  (git-fixes CVE-2024-58081 bsc#1239032).
- Update
  patches.suse/clk-qcom-dispcc-sm6350-Add-missing-parent_map-for-a-.patch
  (git-fixes CVE-2024-58080 bsc#1239027).
- Update
  patches.suse/clk-qcom-gcc-sm6350-Add-missing-parent_map-for-two-c.patch
  (git-fixes CVE-2024-58076 bsc#1239037).
- Update
  patches.suse/crypto-tegra-do-not-transfer-req-when-tegra-init-fai.patch
  (git-fixes CVE-2024-58075 bsc#1238976).
- Update
  patches.suse/drm-amdgpu-Fix-potential-NULL-pointer-dereference-in.patch
  (git-fixes CVE-2024-58052 bsc#1238986).
- Update
  patches.suse/drm-msm-gem-prevent-integer-overflow-in-msm_ioctl_ge.patch
  (git-fixes CVE-2024-52559 bsc#1238507).
- Update
  patches.suse/drm-v3d-Stop-active-perfmon-if-it-is-being-destroyed.patch
  (git-fixes CVE-2024-58086 bsc#1239038).
- Update
  patches.suse/drm-xe-tracing-Fix-a-potential-TP_printk-UAF.patch
  (git-fixes CVE-2024-49570 bsc#1238782).
- Update
  patches.suse/firmware-qcom-scm-Cleanup-global-__scm-on-probe-fail.patch
  (git-fixes CVE-2024-57985 bsc#1237914).
- Update
  patches.suse/firmware-qcom-scm-Fix-missing-read-barrier-in-qcom_s-b628510.patch
  (git-fixes CVE-2024-58084 bsc#1239028).
- Update
  patches.suse/i3c-dw-Fix-use-after-free-in-dw_i3c_master-driver-du.patch
  (git-fixes CVE-2024-57984 bsc#1237909).
- Update patches.suse/idpf-convert-workqueues-to-unbound.patch
  (jsc#PED-10581 CVE-2024-58057 bsc#1238969).
- Update
  patches.suse/ipmi-ipmb-Add-check-devm_kasprintf-returned-value.patch
  (git-fixes CVE-2024-58051 bsc#1238963).
- Update
  patches.suse/media-i2c-ds90ub9x3-Fix-extra-fwnode_handle_put.patch
  (git-fixes CVE-2024-58003 bsc#1238766).
- Update
  patches.suse/media-imx-jpeg-Fix-potential-error-pointer-dereferen.patch
  (git-fixes CVE-2024-57978 bsc#1238523).
- Update
  patches.suse/media-intel-ipu6-remove-cpu-latency-qos-request-on-e.patch
  (git-fixes CVE-2024-58004 bsc#1238508).
- Update
  patches.suse/media-nuvoton-Fix-an-error-check-in-npcm_video_ece_i.patch
  (git-fixes CVE-2024-58082 bsc#1239031).
- Update
  patches.suse/media-uvcvideo-Fix-crash-during-unbind-if-gpio-unit-.patch
  (git-fixes CVE-2024-58079 bsc#1239029).
- Update
  patches.suse/media-uvcvideo-Fix-deadlock-during-uvc_probe.patch
  (git-fixes CVE-2024-58059 bsc#1238960).
- Update
  patches.suse/media-uvcvideo-Fix-double-free-in-error-path.patch
  (git-fixes CVE-2024-57980 bsc#1237911).
- Update
  patches.suse/media-uvcvideo-Remove-dangling-pointers.patch
  (git-fixes CVE-2024-58002 bsc#1238503).
- Update
  patches.suse/memory-tegra20-emc-fix-an-OF-node-reference-bug-in-t.patch
  (git-fixes CVE-2024-58034 bsc#1238773).
- Update
  patches.suse/misc-misc_minor_alloc-to-use-ida-for-all-dynamic-mis.patch
  (git-fixes CVE-2024-58078 bsc#1239034).
- Update
  patches.suse/powerpc-pseries-iommu-IOMMU-incorrectly-marks-MMIO-r.patch
  (bsc#1218470 ltc#204531 CVE-2024-57999 bsc#1238526).
- Update patches.suse/pps-Fix-a-use-after-free.patch (git-fixes
  CVE-2024-57979 bsc#1238521).
- Update
  patches.suse/printk-Fix-signed-integer-overflow-when-defining-LOG_BUF_LEN_MAX.patch
  (bsc#1237950 CVE-2024-58017 bsc#1239112).
- Update
  patches.suse/rdma-cxgb4-Prevent-potential-integer-overflow-on-32b.patch
  (git-fixes CVE-2024-57973 bsc#1238531).
- Update
  patches.suse/remoteproc-core-Fix-ida_free-call-while-not-allocate.patch
  (git-fixes CVE-2024-58056 bsc#1238981).
- Update
  patches.suse/rhashtable-Fix-potential-deadlock-by-moving-schedule.patch
  (git-fixes CVE-2024-58042 bsc#1238769).
- Update
  patches.suse/rtc-pcf85063-fix-potential-OOB-write-in-PCF85063-NVM.patch
  (git-fixes CVE-2024-58069 bsc#1238978).
- Update
  patches.suse/rtc-tps6594-Fix-integer-overflow-on-32bit-systems.patch
  (git-fixes CVE-2024-57953 bsc#1238524).
- Update
  patches.suse/soc-qcom-socinfo-Avoid-out-of-bounds-read-of-serial-.patch
  (git-fixes CVE-2024-58007 bsc#1238511).
- Update
  patches.suse/staging-media-max96712-fix-kernel-oops-when-removing.patch
  (git-fixes CVE-2024-58054 bsc#1238975).
- Update
  patches.suse/tpm-Change-to-kvalloc-in-eventlog-acpi.c.patch
  (bsc#1233260 bsc#1233259 bsc#1232421 CVE-2024-58005
  bsc#1237873).
- Update
  patches.suse/ubi-fastmap-Fix-duplicate-slab-cache-names-while-att.patch
  (git-fixes CVE-2024-53172 bsc#1234898).
- Update
  patches.suse/usb-gadget-f_tcm-Don-t-free-command-immediately.patch
  (git-fixes CVE-2024-58055 bsc#1238959).
- Update
  patches.suse/usb-xhci-Fix-NULL-pointer-dereference-on-certain-com.patch
  (git-fixes CVE-2024-57981 bsc#1237912).
- Update
  patches.suse/wifi-ath12k-fix-read-pointer-after-free-in-ath12k_ma.patch
  (git-fixes CVE-2024-57995 bsc#1237895).
- Update
  patches.suse/wifi-brcmsmac-add-gain-range-check-to-wlc_phy_iqcal_.patch
  (stable-fixes CVE-2024-58014 bsc#1239109).
- Update
  patches.suse/wifi-cfg80211-tests-Fix-potential-NULL-dereference-i.patch
  (git-fixes CVE-2024-58064 bsc#1238977).
- Update
  patches.suse/wifi-iwlwifi-mvm-avoid-NULL-pointer-dereference.patch
  (git-fixes CVE-2024-58062 bsc#1238965).
- Update
  patches.suse/wifi-mac80211-prohibit-deactivating-all-links.patch
  (git-fixes CVE-2024-58061 bsc#1238973).
- Update
  patches.suse/wifi-mt76-mt7925-fix-NULL-deref-check-in-mt7925_chan.patch
  (git-fixes CVE-2024-57989 bsc#1237899).
- Update
  patches.suse/wifi-mt76-mt7925-fix-off-by-one-in-mt7925_load_clc.patch
  (git-fixes CVE-2024-57990 bsc#1237900).
- Update
  patches.suse/wifi-mwifiex-Fix-memcpy-field-spanning-write-warning.patch
  (git-fixes CVE-2024-56539 bsc#1234963 bsc#1234853).
- Update
  patches.suse/wifi-rtlwifi-fix-memory-leaks-and-invalid-access-at-.patch
  (git-fixes CVE-2024-58063 bsc#1238984).
- Update
  patches.suse/wifi-rtlwifi-remove-unused-check_buddy_priv.patch
  (git-fixes CVE-2024-58072 bsc#1238964).
- Update
  patches.suse/wifi-rtw89-chan-fix-soft-lockup-in-rtw89_entity_reca.patch
  (git-fixes CVE-2024-57991 bsc#1237896).
- Update
  patches.suse/wifi-wcn36xx-fix-channel-survey-memory-allocation-si.patch
  (git-fixes CVE-2024-57997 bsc#1238529).
- commit 214e3e7
* Wed Mar 12 2025 krisman@suse.de
- io_uring/waitid: don't abuse io_tw_state (git-fixes).
- io_uring/net: don't retry connect operation on EPOLLERR
  (git-fixes).
- commit 4470192
* Wed Mar 12 2025 krisman@suse.de
- io_uring: fix multishots with selected buffers (git-fixes).
- io_uring/uring_cmd: use cached cmd_op in io_uring_cmd_sock()
  (git-fixes).
- io_uring/timeout: fix multishot updates (git-fixes).
- io_uring/kbuf: use pre-committed buffer address for non-pollable
  file (git-fixes).
- io_uring/net: always initialize kmsg->msg.msg_inq upfront
  (git-fixes).
- io_uring/rw: fix downgraded mshot read (git-fixes).
- io_uring/sqpoll: fix sqpoll error handling races (git-fixes).
- commit 1987e55
* Tue Mar 11 2025 tiwai@suse.de
- r8169: don't apply UDP padding quirk on RTL8126A (stable-fixes).
- commit 68384e2
* Tue Mar 11 2025 tiwai@suse.de
- drm/xe: Fix and re-enable xe_print_blob_ascii85() (git-fixes).
- commit 3db422a
* Tue Mar 11 2025 mhocko@suse.com
- sched/membarrier: Fix redundant load of membarrier_state
  (bsc#1232743).
- commit bf44b2b
* Tue Mar 11 2025 shung-hsi.yu@suse.com
- bpf: Reject struct_ops registration that uses module ptr and
  the module btf_id is missing (git-fixes).
- commit 3b9c73b
* Tue Mar 11 2025 shung-hsi.yu@suse.com
- selftests/bpf: Add test case for the freeing of bpf_timer
  (bsc#1238971 CVE-2025-21825).
- bpf: Cancel the running bpf_timer through kworker for PREEMPT_RT
  (bsc#1238971 CVE-2025-21825).
- bpf: Free element after unlock in
  __htab_map_lookup_and_delete_elem() (bsc#1238971
  CVE-2025-21825).
- bpf: Bail out early in __htab_map_lookup_and_delete_elem()
  (bsc#1238971 CVE-2025-21825).
- bpf: Free special fields after unlock in
  htab_lru_map_delete_node() (bsc#1238971 CVE-2025-21825).
- commit 1cd4c2e
* Mon Mar 10 2025 oneukum@suse.com
- Input: atkbd - map F23 key to support default copilot shortcut
  (git-fixes).
- commit bfe2bb7
* Mon Mar 10 2025 oneukum@suse.com
- Input: xpad - add unofficial Xbox 360 wireless receiver clone
  (git-fixes).
- Input: xpad - add support for wooting two he (arm) (git-fixes).
- Input: xpad - improve name of 8BitDo controller 2dc8:3106
  (git-fixes).
- Input: xpad - add QH Electronics VID/PID (git-fixes).
- Input: xpad - add support for Nacon Evol-X Xbox One Controller
  (git-fixes).
- commit 4710207
* Mon Mar 10 2025 oneukum@suse.com
- Input: xpad - add support for Nacon Pro Compact (git-fixes).
- commit 3a2bb67
* Mon Mar 10 2025 iivanov@suse.de
- KVM: arm64: Initialize SCTLR_EL1 in __kvm_hyp_init_cpu() (git-fixes)
- commit 2805274
* Mon Mar 10 2025 iivanov@suse.de
- KVM: arm64: Initialize HCR_EL2.E2H early (git-fixes)
- commit 0ff07a9
* Mon Mar 10 2025 oneukum@suse.com
- USB: hub: Ignore non-compliant devices with too many configs
  or interfaces (bsc#1238909 CVE-2025-21776).
- commit 1601393
* Mon Mar 10 2025 msuchanek@suse.de
- powerpc/pseries/iommu: memory notifier incorrectly adds TCEs
  for pmemory (bsc#1239167 ltc#211055).
- commit 5ee1b4c
* Mon Mar 10 2025 mfranc@suse.cz
- s390/traps: Fix test_monitor_call() inline assembly (git-fixes
  bsc#1239160).
- commit 1a519e2
* Mon Mar 10 2025 mhocko@suse.com
- platform/x86: int3472: Check for adev == NULL (CVE-2024-58011
  bsc#1239080).
- commit 58ea3d9
* Mon Mar 10 2025 mhocko@suse.com
- net_sched: sch_sfq: don't allow 1 packet limit (CVE-2024-57996
  bsc#1239076).
- commit 6b3567e
* Mon Mar 10 2025 tiwai@suse.de
- ASoC: SOF: Intel: hda-dai: Ensure DAI widget is valid during
  params (CVE-2024-58012 bsc#1239104).
- commit 642aedc
* Mon Mar 10 2025 tiwai@suse.de
- wifi: brcmfmac: fix NULL pointer dereference in
  brcmf_txfinalize() (CVE-2025-21744 bsc#1238903).
- commit 062e9bf
* Mon Mar 10 2025 tiwai@suse.de
- usb: gadget: Check bmAttributes only if configuration is valid
  (git-fixes).
- usb: gadget: Fix setting self-powered state on suspend
  (git-fixes).
- commit fb64cab
* Mon Mar 10 2025 tiwai@suse.de
- usb: typec: ucsi: Fix NULL pointer access (git-fixes).
- usb: xhci: Fix host controllers "dying" after suspend and resume
  (git-fixes).
- usb: dwc3: Set SUSPENDENABLE soon after phy init (git-fixes).
- usb: hub: lack of clearing xHC resources (git-fixes).
- usb: renesas_usbhs: Flush the notify_hotplug_work (git-fixes).
- usb: renesas_usbhs: Use devm_usb_get_phy() (git-fixes).
- usb: renesas_usbhs: Call clk_put() (git-fixes).
- usb: dwc3: gadget: Prevent irq storm when TH re-executes
  (git-fixes).
- xhci: Restrict USB4 tunnel detection for USB3 devices to Intel
  hosts (git-fixes).
- usb: typec: ucsi: increase timeout for PPM reset operations
  (git-fixes).
- acpi: typec: ucsi: Introduce a ->poll_cci method (git-fixes).
- usb: typec: tcpci_rt1711h: Unmask alert interrupts to fix
  functionality (git-fixes).
- usb: gadget: Set self-powered based on MaxPower and bmAttributes
  (git-fixes).
- usb: gadget: u_ether: Set is_suspend flag if remote wakeup fails
  (git-fixes).
- usb: atm: cxacru: fix a flaw in existing endpoint checks
  (git-fixes).
- drivers: core: fix device leak in __fw_devlink_relax_cycles()
  (git-fixes).
- Revert "drivers/card_reader/rtsx_usb: Restore interrupt based
  detection" (git-fixes).
- bus: simple-pm-bus: fix forced runtime PM use (git-fixes).
- char: misc: deallocate static minor in error path (git-fixes).
- eeprom: digsy_mtc: Make GPIO lookup table match the device
  (git-fixes).
- drivers: virt: acrn: hsm: Use kzalloc to avoid info leak in
  pmcmd_ioctl (git-fixes).
- slimbus: messaging: Free transaction ID in delayed interrupt
  scenario (git-fixes).
- cdx: Fix possible UAF error in driver_override_show()
  (git-fixes).
- bus: mhi: host: pci_generic: Use pci_try_reset_function()
  to avoid deadlock (git-fixes).
- mei: vsc: Use "wakeuphostint" when getting the host wakeup GPIO
  (git-fixes).
- iio: filter: admv8818: Force initialization of SDO (git-fixes).
- iio: dac: ad3552r: clear reset status flag (git-fixes).
- iio: adc: ad7192: fix channel select (git-fixes).
- iio: adc: at91-sama5d2_adc: fix sama7g5 realbits value
  (git-fixes).
- iio: light: apds9306: fix max_scale_nano values (git-fixes).
- commit 2fb3d9c
* Sun Mar  9 2025 tiwai@suse.de
- ALSA: hda: intel: Add Dell ALC3271 to power_save denylist
  (stable-fixes).
- ALSA: seq: Avoid module auto-load handling at event delivery
  (stable-fixes).
- commit 5548289
* Sun Mar  9 2025 tiwai@suse.de
- ALSA: hda/realtek: Add support for ASUS B5405 and B5605 Laptops
  using CS35L41 HDA (stable-fixes).
- ALSA: hda/realtek: Add support for ASUS ROG Strix GA603 Laptops
  using CS35L41 HDA (stable-fixes).
- ALSA: hda/realtek: Add support for ASUS ROG Strix G814 Laptop
  using CS35L41 HDA (stable-fixes).
- commit 5f7974b
* Sun Mar  9 2025 tiwai@suse.de
- ALSA: hda/realtek: Add support for ASUS Zenbook UM3406KA
  Laptops using CS35L41 HDA (stable-fixes).
- ALSA: hda/realtek: Add support for ASUS B3405 and B3605 Laptops
  using CS35L41 HDA (stable-fixes).
- ALSA: hda/realtek: Add support for various ASUS Laptops using
  CS35L41 HDA (stable-fixes).
- ALSA: hda/realtek: Add support for ASUS ROG Strix G614 Laptops
  using CS35L41 HDA (stable-fixes).
- ALSA: hda/realtek: update ALC222 depop optimize (stable-fixes).
- ALSA: hda: realtek: fix incorrect IS_REACHABLE() usage
  (git-fixes).
- ALSA: hda/realtek - add supported Mic Mute LED for Lenovo
  platform (stable-fixes).
- ALSA: hda: Fix speakers on ASUS EXPERTBOOK P5405CSA 1.0
  (stable-fixes).
- ALSA: hda/realtek: Fix Asus Z13 2025 audio (stable-fixes).
- commit c78c8b9
* Sun Mar  9 2025 tiwai@suse.de
- drm/xe/oa: Signal output fences (stable-fixes).
- Refresh
  patches.suse/xe-oa-Fix-query-mode-of-operation-for-OAR-OAC.patch.
- commit 9868b15
* Sun Mar  9 2025 tiwai@suse.de
- rapidio: add check for rio_add_net() in rio_scan_alloc_net()
  (git-fixes).
- rapidio: fix an API misues when rio_add_net() fails (git-fixes).
- dma: kmsan: export kmsan_handle_dma() for modules (git-fixes).
- hwmon: fix a NULL vs IS_ERR_OR_NULL() check in
  xgene_hwmon_probe() (git-fixes).
- hwmon: (ad7314) Validate leading zero bits and return error
  (git-fixes).
- hwmon: (ntc_thermistor) Fix the ncpXXxh103 sensor table
  (git-fixes).
- hwmon: (pmbus) Initialise page count in pmbus_identify()
  (git-fixes).
- hwmon: (peci/dimmtemp) Do not provide fake thresholds data
  (git-fixes).
- gpio: rcar: Fix missing of_node_put() call (git-fixes).
- gpio: aggregator: protect driver attr handlers against module
  unload (git-fixes).
- ALSA: usx2y: validate nrpacks module parameter on probe
  (git-fixes).
- ALSA: hda/realtek: Remove (revert) duplicate Ally X config
  (git-fixes).
- drm/xe/oa: Allow oa_exponent value of 0 (git-fixes).
- drm/amd/display: Fix HPD after gpu reset (stable-fixes).
- drm/amd/display: add a quirk to enable eDP0 on DP1
  (stable-fixes).
- drm/amd/display: Disable PSR-SU on eDP panels (stable-fixes).
- drm/amdkfd: Preserve cp_hqd_pq_control on update_mqd
  (stable-fixes).
- drm/xe/oa: Allow only certain property changes from config
  (stable-fixes).
- drm/xe/oa: Add syncs support to OA config ioctl (stable-fixes).
- drm/xe/oa: Move functions up so they can be reused for config
  ioctl (stable-fixes).
- commit d3f758a
* Sun Mar  9 2025 ailiop@suse.com
- sunrpc: suppress warnings for unused procfs functions
  (git-fixes).
- commit c61a5ed
* Sun Mar  9 2025 ailiop@suse.com
- SUNRPC: Handle -ETIMEDOUT return from tlshd (git-fixes).
- commit 5ae6ead
* Sun Mar  9 2025 ailiop@suse.com
- NFSv4: Fix a deadlock when recovering state on a sillyrenamed
  file (git-fixes).
- commit 68a98ff
* Sun Mar  9 2025 ailiop@suse.com
- SUNRPC: Prevent looping due to rpc_signal_task() races
  (git-fixes).
- commit efcf93f
* Sun Mar  9 2025 ailiop@suse.com
- NFSD: Fix CB_GETATTR status fix (git-fixes).
- commit bfb8cfa
* Sun Mar  9 2025 ailiop@suse.com
- nfsd: validate the nfsd_serv pointer before calling svc_wake_up
  (git-fixes).
- commit 2e52d43
* Sun Mar  9 2025 ailiop@suse.com
- nfsd: clear acl_access/acl_default after releasing them
  (git-fixes).
- commit 27010fb
* Sun Mar  9 2025 ailiop@suse.com
- pnfs/flexfiles: retry getting layout segment for reads
  (git-fixes).
- commit b6de6d7
* Sun Mar  9 2025 ailiop@suse.com
- nfs: Make NFS_FSCACHE select NETFS_SUPPORT instead of depending
  on it (git-fixes).
- commit 7c2ea4b
* Sun Mar  9 2025 ailiop@suse.com
- KMSAN: uninit-value in inode_go_dump (5) (git-fixes).
- commit 33eb119
* Sun Mar  9 2025 ailiop@suse.com
- gfs2: Fix unlinked inode cleanup (git-fixes).
- commit 34e8c14
* Sun Mar  9 2025 ailiop@suse.com
- gfs2: Allow immediate GLF_VERIFY_DELETE work (git-fixes).
- commit 85fd98d
* Sun Mar  9 2025 ailiop@suse.com
- gfs2: Rename GLF_VERIFY_EVICT to GLF_VERIFY_DELETE (git-fixes).
- commit 7b42f25
* Sun Mar  9 2025 ailiop@suse.com
- xfs: flush inodegc before swapon (git-fixes).
- commit 5c0ff3f
* Sun Mar  9 2025 ailiop@suse.com
- xfs: fix online repair probing when CONFIG_XFS_ONLINE_REPAIR=n
  (git-fixes).
- commit 188fef0
* Sun Mar  9 2025 ailiop@suse.com
- xfs: report realtime block quota limits on realtime directories
  (git-fixes).
- commit fe8bc40
* Sun Mar  9 2025 ailiop@suse.com
- exfat: short-circuit zero-byte writes in exfat_file_write_iter
  (git-fixes).
- commit e7632e9
* Sun Mar  9 2025 ailiop@suse.com
- exfat: fix soft lockup in exfat_clear_bitmap (git-fixes).
- commit 72aa500
* Sun Mar  9 2025 ailiop@suse.com
- exfat: fix just enough dentries but allocate a new cluster to
  dir (git-fixes).
- commit 9bf8f0b
* Sun Mar  9 2025 ailiop@suse.com
- NFS: Fix potential buffer overflowin nfs_sysfs_link_rpc_client()
  (bsc#1239113 CVE-2024-54456).
- commit a3a35d5
* Fri Mar  7 2025 lduncan@suse.com
- block: Remove zone write plugs when handling native zone append
  writes (git-fixes).
- md/raid*: Fix the set_queue_limits implementations (git-fixes).
- partitions: mac: fix handling of bogus partition table
  (git-fixes).
- block: cleanup and fix batch completion adding conditions
  (git-fixes).
- block: don't revert iter for -EIOCBQUEUED (git-fixes).
- commit 9fb2f84
* Fri Mar  7 2025 msuchanek@suse.de
- packaging: Patch Makefile to pre-select gcc version (jsc#PED-12251).
  When compiler different from the one which was used to configure the
  kernel is used to build modules a warning is issued and the build
  continues. This could be turned into an error but that would be too
  restrictive.
  The generated kernel-devel makefile could set the compiler but then the
  main Makefile as to be patched to assign CC with ?=
  This causes run_oldconfig failure on SUSE-2024 and kbuild config check
  failure on SUSE-2025.
  This cannot be hardcoded to one version in a regular patch because the
  value is expected to be configurable at mkspec time. Patch the Makefile
  after aplyin patches in rpm prep step instead. A check is added to
  verify that the sed command did indeed apply the change.
- commit 6031391
* Fri Mar  7 2025 mfranc@suse.cz
- tracing/osnoise: Fix resetting of tracepoints (CVE-2025-21733
  bsc#1238494).
- commit 2bff62d
* Fri Mar  7 2025 mfranc@suse.cz
- btrfs: fix assertion failure when splitting ordered extent
  after transaction abort (CVE-2025-21754 bsc#1238496).
- commit 57147c4
* Fri Mar  7 2025 mfranc@suse.cz
- tcp: correct handling of extreme memory squeeze (CVE-2025-21710
  bsc#1237888).
- commit 101929d
* Fri Mar  7 2025 msuchanek@suse.de
- x86/boot: Use '-std=gnu11' to fix build with GCC 15
  (jsc#PED-12251).
- commit bb8a87d
* Fri Mar  7 2025 tiwai@suse.de
- drm/amdkfd: Fix NULL Pointer Dereference in KFD queue
  (git-fixes).
- drm/amd/display: Fix null check for pipe_ctx->plane_state in
  resource_build_scaling_params (git-fixes).
- drm/xe/userptr: Unmap userptrs in the mmu notifier (git-fixes).
- drm/xe/hmm: Don't dereference struct page pointers without
  notifier lock (git-fixes).
- drm/xe/hmm: Style- and include fixes (git-fixes).
- drm/xe: Add staging tree for VM binds (git-fixes).
- drm/xe: Fix fault mode invalidation with unbind (git-fixes).
- drm/xe/vm: Fix a misplaced #endif (git-fixes).
- drm/xe/vm: Validate userptr during gpu vma prefetching
  (git-fixes).
- drm/xe/userptr: properly setup pfn_flags_mask (git-fixes).
- drm/sched: Fix preprocessor guard (git-fixes).
- drm/imagination: Fix timestamps in firmware traces (git-fixes).
- drm/imagination: only init job done fences once (git-fixes).
- drm/imagination: Hold drm_gem_gpuva lock for unmap (git-fixes).
- drm/imagination: avoid deadlock on fence release (git-fixes).
- wifi: cfg80211: regulatory: improve invalid hints checking
  (git-fixes).
- wifi: mac80211: fix vendor-specific inheritance (git-fixes).
- wifi: mac80211: fix MLE non-inheritance parsing (git-fixes).
- wifi: iwlwifi: Fix A-MSDU TSO preparation (git-fixes).
- wifi: iwlwifi: Free pages allocated when failing to build A-MSDU
  (git-fixes).
- wifi: iwlwifi: limit printed string from FW file (git-fixes).
- wifi: iwlwifi: mvm: don't try to talk to a dead firmware
  (git-fixes).
- wifi: iwlwifi: mvm: clean up ROC on failure (git-fixes).
- wifi: nl80211: reject cooked mode if it is set along with
  other flags (git-fixes).
- Bluetooth: Add check for mgmt_alloc_skb() in
  mgmt_device_connected() (git-fixes).
- Bluetooth: Add check for mgmt_alloc_skb() in mgmt_remote_name()
  (git-fixes).
- bluetooth: btusb: Initialize .owner field of
  force_poll_sync_fops (git-fixes).
- commit bceb443
* Fri Mar  7 2025 jlee@suse.com
- initcall_blacklist: Does not allow kernel_lockdown be
  blacklisted (bsc#1237521).
- commit 4ab5f98
* Thu Mar  6 2025 msuchanek@suse.de
- powerpc: boot: Fix build with gcc 15 (jsc#PED-12251).
- commit 177c148
* Thu Mar  6 2025 msuchanek@suse.de
- efi: libstub: Use '-std=gnu11' to fix build with GCC 15
  (jsc#PED-12251).
- commit 3a88c96
* Thu Mar  6 2025 mfranc@suse.cz
- NFSD: fix hang in nfsd4_shutdown_callback (CVE-2025-21795
  bsc#1238759).
- commit 839b02b
* Thu Mar  6 2025 mfranc@suse.cz
- vxlan: check vxlan_vnigroup_init() return value (CVE-2025-21790
  bsc#1238753).
- commit 45e6d1b
* Thu Mar  6 2025 mfranc@suse.cz
- clocksource: Use migrate_disable() to avoid calling
  get_random_u32() in atomic context (CVE-2025-21767 bsc#1238509).
- commit 1d52af5
* Thu Mar  6 2025 mfranc@suse.cz
- vxlan: Fix uninit-value in vxlan_vnifilter_dump()
  (CVE-2025-21716 bsc#1237891).
- commit e46863c
* Thu Mar  6 2025 mfranc@suse.cz
- mptcp: handle fastopen disconnect correctly (CVE-2025-21705
  bsc#1238525).
- commit 320aaa6
* Thu Mar  6 2025 mfranc@suse.cz
- smb: client: fix oops due to unset link speed (CVE-2025-21725
  bsc#1238877).
- commit 675f8ca
* Thu Mar  6 2025 mfranc@suse.cz
- ipmr: do not call mr_mfc_uses_dev() for unres entries
  (CVE-2025-21719 bsc#1238860).
- commit 32e5d0c
* Thu Mar  6 2025 mfranc@suse.cz
- net: davicom: fix UAF in dm9000_drv_remove (CVE-2025-21715
  bsc#1237889).
- commit a8a4ff6
* Thu Mar  6 2025 mfranc@suse.cz
- iommufd/iova_bitmap: Fix shift-out-of-bounds in
  iova_bitmap_offset_to_index() (CVE-2025-21724 bsc#1238863).
- commit 707e0f9
* Thu Mar  6 2025 mfranc@suse.cz
- net: ethernet: ti: am65-cpsw: fix freeing IRQ in
  am65_cpsw_nuss_remove_tx_chns() (CVE-2025-21799 bsc#1238739).
- commit 922ef51
* Thu Mar  6 2025 msuchanek@suse.de
- powerpc/ftrace: Fix ftrace bug with KASAN=y (jsc#PED-10909).
- powerpc64/bpf: Add support for bpf trampolines (jsc#PED-10909).
- samples/ftrace: Add support for ftrace direct samples on powerpc
  (jsc#PED-10909).
  - Update config files
- powerpc/ftrace: Add support for DYNAMIC_FTRACE_WITH_DIRECT_CALLS
  (jsc#PED-10909).
  - Update config files
- powerpc/ftrace: Add support for DYNAMIC_FTRACE_WITH_CALL_OPS
  (jsc#PED-10909).
  - Update config files
- powerpc64/ftrace: Support .text larger than 32MB with
  out-of-line stubs (jsc#PED-10909).
  - Update config files
- powerpc64/ftrace: Move ftrace sequence out of line
  (jsc#PED-10909).
- Update config files
- kbuild: Add generic hook for architectures to use before the
  final vmlinux link (jsc#PED-10909).
- powerpc/ftrace: Add a postlink script to validate function
  tracer (jsc#PED-10909).
- powerpc64/bpf: Fold bpf_jit_emit_func_call_hlp() into
  bpf_jit_emit_func_call_rel() (jsc#PED-10909).
- powerpc/ftrace: Move ftrace stub used for init text before
  _einittext (jsc#PED-10909).
- powerpc/ftrace: Skip instruction patching if the instructions
  are the same (jsc#PED-10909).
- powerpc/ftrace: Remove pointer to struct module from
  dyn_arch_ftrace (jsc#PED-10909).
- powerpc/module_64: Convert #ifdef to IS_ENABLED()
  (jsc#PED-10909).
- powerpc32/ftrace: Unify 32-bit and 64-bit ftrace entry code
  (jsc#PED-10909).
- powerpc64/ftrace: Nop out additional 'std' instruction emitted
  by gcc v5.x (jsc#PED-10909).
- powerpc/kprobes: Use ftrace to determine if a probe is at
  function entry (jsc#PED-10909).
- commit 52bb9ce
* Thu Mar  6 2025 tiwai@suse.de
- supported.conf: correct dependencies for optional (bsc#1238570)
  Also move some fortoggen cros modules into optional, too
- commit 1502e47
* Thu Mar  6 2025 tiwai@suse.de
- rpm/split-modules: Fix optional splitting with usrmerge (bsc#1238570)
- commit 8be63c4
* Thu Mar  6 2025 davide.benini@suse.com
- ipvs: fix UB due to uninitialized stack access in
  ip_vs_protocol_init() (CVE-2024-53680 bsc#1235715).
- commit 1f83147
* Wed Mar  5 2025 tiwai@suse.de
- udmabuf: fix vmap_udmabuf error page set (git-fixes).
- Update config files.
- commit e2e943e
* Wed Mar  5 2025 tiwai@suse.de
- acct: block access to kernel internal filesystems (git-fixes).
- acct: perform last write from workqueue (git-fixes).
- wifi: mt76: mt7921u: Add VID/PID for TP-Link TXE50UH
  (stable-fixes).
- wifi: rtw88: sdio: Fix disconnection after beacon loss
  (stable-fixes).
- wifi: rtw88: add __packed attribute to efuse layout struct
  (stable-fixes).
- wifi: iwlwifi: avoid memory leak (stable-fixes).
- wifi: brcmfmac: Check the return value of
  of_property_read_string_index() (stable-fixes).
- wifi: rtw89: add crystal_cap check to avoid setting as overflow
  value (stable-fixes).
- wifi: brcmsmac: add gain range check to
  wlc_phy_iqcal_gainparams_nphy() (stable-fixes).
- xe/oa: Fix query mode of operation for OAR/OAC (git-fixes).
- drm/amdgpu: Fix Circular Locking Dependency in AMDGPU GFX
  Isolation (git-fixes).
- drm/amd/display: Reduce accessing remote DPCD overhead
  (git-fixes).
- alloc_tag: fix set_codetag_empty() when
  !CONFIG_MEM_ALLOC_PROFILING_DEBUG (git-fixes).
- udmabuf: also check for F_SEAL_FUTURE_WRITE (git-fixes).
- EDAC/amd64: Simplify ECC check on unified memory controllers
  (git-fixes).
- ptp: kvm: x86: Return EOPNOTSUPP instead of ENODEV from
  kvm_arch_ptp_init() (git-fixes).
- ptp: Add error handling for adjfine callback in
  ptp_clock_adjtime (git-fixes).
- ubi: fastmap: Fix duplicate slab cache names while attaching
  (git-fixes).
- ubi: fastmap: wl: Schedule fm_work if wear-leveling pool is
  empty (git-fixes).
- ubi: wl: Put source PEB into correct list if trying locking
  LEB failed (git-fixes).
- verification/dot2: Improve dot parser robustness (stable-fixes).
- EDAC/{skx_common,i10nm}: Fix incorrect far-memory error source
  indicator (git-fixes).
- EDAC/skx_common: Differentiate memory error sources (git-fixes).
- commit dcf43d4
* Wed Mar  5 2025 tiwai@suse.de
- Revert "of: reserved-memory: Fix using wrong number of cells
  to get property 'alignment'" (stable-fixes).
- commit dfbe690
* Wed Mar  5 2025 shung-hsi.yu@suse.com
- net: Add rx_skb of kfree_skb to raw_tp_null_args (git-fixes).
- commit 449c6f3
* Wed Mar  5 2025 shung-hsi.yu@suse.com
- selftests/bpf: Add tests for raw_tp NULL args (git-fixes).
- bpf: Augment raw_tp arguments with PTR_MAYBE_NULL (git-fixes).
- bpf: Revert "bpf: Mark raw_tp arguments with PTR_MAYBE_NULL"
  (git-fixes).
- selftests/bpf: Add more test cases for LPM trie (git-fixes).
- selftests/bpf: Move test_lpm_map.c to map_tests (git-fixes).
- bpf: Use raw_spinlock_t for LPM trie (git-fixes).
- bpf: Switch to bpf mem allocator for LPM trie (git-fixes).
- bpf: Fix exact match conditions in trie_get_next_key()
  (git-fixes).
- bpf: Handle in-place update for full LPM trie correctly
  (git-fixes).
- bpf: Handle BPF_EXIST and BPF_NOEXIST for LPM trie (git-fixes).
- bpf: Remove unnecessary check when updating LPM trie
  (git-fixes).
- selftests/bpf: Add test for narrow spill into 64-bit spilled
  scalar (git-fixes).
- selftests/bpf: Add test for reading from STACK_INVALID slots
  (git-fixes).
- selftests/bpf: Introduce __caps_unpriv annotation for tests
  (git-fixes).
- bpf: Fix narrow scalar spill onto 64-bit spilled scalar slots
  (git-fixes).
- bpf: Don't mark STACK_INVALID as STACK_MISC in
  mark_stack_slot_misc (git-fixes).
- selftests/bpf: Add tests for raw_tp null handling (git-fixes).
- bpf: Mark raw_tp arguments with PTR_MAYBE_NULL (git-fixes).
- commit 33a0c52
* Tue Mar  4 2025 msuchanek@suse.de
- config: Set gcc version (jsc#PED-12251).
- packaging: Turn gcc version into config.sh variable
  Fixes: 51dacec21eb1 ("Use gcc-13 for build on SLE16 (jsc#PED-10028).")
- commit 2bf5321
* Tue Mar  4 2025 msuchanek@suse.de
- powerpc: Document details on H_HTM hcall (jsc#PED-10944).
- powerpc/pseries: Export hardware trace macro dump via debugfs
  (jsc#PED-10944).
- Update config files.
- powerpc/pseries: Macros and wrapper functions for H_HTM call
  (jsc#PED-10944).
- commit 5460fb0
* Tue Mar  4 2025 mkoutny@suse.com
- rpm/config.sh: Update Bugzillla product
  There is now proper product for SLE16 which is the preferred target for
  automated bug reports.
- commit 1b3f821
* Tue Mar  4 2025 dsterba@suse.com
- btrfs: check folio mapping after unlock in relocate_one_folio() (CVE-2024-56758 bsc#1235621)
- commit ba0cfe2
* Tue Mar  4 2025 iivanov@suse.de
- arm64: hugetlb: Fix flush_hugetlb_tlb_range() invalidation level (git-fixes)
- commit 8f89035
* Tue Mar  4 2025 iivanov@suse.de
- arm64: hugetlb: Fix huge_ptep_get_and_clear() for non-present ptes (git-fixes)
- commit f4826cb
* Tue Mar  4 2025 iivanov@suse.de
- mm: hugetlb: Add huge page size param to huge_ptep_get_and_clear() (git-fixes)
- commit 1fac258
* Tue Mar  4 2025 iivanov@suse.de
- arm64/mm: Fix Boot panic on Ampere Altra (git-fixes)
- commit a6faf3e
* Tue Mar  4 2025 iivanov@suse.de
- arm64: dts: rockchip: adjust SMMU interrupt type on rk3588 (git-fixes)
- commit 638ed0e
* Tue Mar  4 2025 iivanov@suse.de
- arm64: dts: rockchip: Fix lcdpwr_en pin for Cool Pi GenBook (git-fixes)
- commit dcbc592
* Tue Mar  4 2025 oneukum@suse.com
- USB: serial: option: fix Telit Cinterion FN990A name
  (git-fixes).
- commit c850a7b
* Tue Mar  4 2025 oneukum@suse.com
- USB: serial: option: add Telit Cinterion FN990B compositions
  (git-fixes).
- commit 1f5ca02
* Tue Mar  4 2025 oneukum@suse.com
- USB: serial: option: drop MeiG Smart defines (git-fixes).
- commit f6098ca
* Tue Mar  4 2025 oneukum@suse.com
- USB: serial: option: add MeiG Smart SLM828 (git-fixes).
- commit e39974a
* Tue Mar  4 2025 oneukum@suse.com
- USB: quirks: add USB_QUIRK_NO_LPM quirk for Teclast dist
  (git-fixes).
- commit c8ad9c4
* Tue Mar  4 2025 oneukum@suse.com
- USB: Add USB_QUIRK_NO_LPM quirk for sony xperia xz1 smartphone
  (git-fixes).
- commit 1cd3bfd
* Tue Mar  4 2025 oneukum@suse.com
- usb: typec: tcpm: PSSourceOffTimer timeout in PR_Swap enters
  ERROR_RECOVERY (git-fixes).
- commit d3d2cdf
* Tue Mar  4 2025 ohering@suse.de
- RDMA/mana_ib: Allocate PAGE aligned doorbell index (git-fixes).
- KVM: x86: Reject Hyper-V's SEND_IPI hypercalls if local APIC
  isn't in-kernel (git-fixes).
- commit ac8f9f3
* Tue Mar  4 2025 iivanov@suse.de
- arm64: dts: rockchip: Fix broken tsadc pinctrl names for rk3588 (git-fixes)
- commit 730f333
* Tue Mar  4 2025 tiwai@suse.de
- rpm/kernel-docs.spec.in: Workaround for reproducible builds (bsc#1238303)
- commit 1f1e842
* Tue Mar  4 2025 tbogendoerfer@suse.de
- Refresh patches.suse/0001-idpf-extend-tx-watchdog-timeout.patch.
- Refresh
  patches.suse/s390-Fix-mlx5-RoCE-throuput-degradtion.patch.
  Re-enabled needed patches.
- commit 553c7bc
* Tue Mar  4 2025 sjaeckel@suse.de
- ila: serialize calls to nf_register_net_hooks() (CVE-2024-57900
  bsc#1235973).
- commit 4159884
* Tue Mar  4 2025 sjaeckel@suse.de
- net: reenable NETIF_F_IPV6_CSUM offload for BIG TCP packets
  (CVE-2025-21629 bsc#1235968).
- commit f3eb8e0
* Mon Mar  3 2025 petr.pavlu@suse.com
- tracing: Do not allow mmap() of persistent ring buffer
  (git-fixes bsc#1237898 CVE-2025-21778).
- commit 7bd7207
* Mon Mar  3 2025 tbogendoerfer@suse.de
- Delete
  patches.suse/staging-qlge-devlink-use-retained-error-fmsg-API.patch.
  Dropped patch for no longer present driver.
- commit d78cf53
* Mon Mar  3 2025 petr.pavlu@suse.com
- bpf: Send signals asynchronously if !preemptible (git-fixes
  bsc#1237879 CVE-2025-21728).
- commit bf6a524
* Mon Mar  3 2025 dwagner@suse.de
- scsi: lpfc: Copyright updates for 14.4.0.8 patches
  (bsc#1238349).
- scsi: lpfc: Update lpfc version to 14.4.0.8 (bsc#1238349).
- scsi: lpfc: Handle duplicate D_IDs in ndlp search-by D_ID
  routine (bsc#1238349).
- scsi: lpfc: Ignore ndlp rport mismatch in dev_loss_tmo callbk
  (bsc#1238349).
- scsi: lpfc: Free phba irq in lpfc_sli4_enable_msi() when
  pci_irq_vector() fails (bsc#1238349).
- scsi: lpfc: Reduce log message generation during ELS ring
  clean up (bsc#1238349).
- commit 9c9e63e
* Mon Mar  3 2025 tbogendoerfer@suse.de
- net: ethtool: Use hwprov under rcu_read_lock (git-fixes).
- commit 9b0a090
* Mon Mar  3 2025 tbogendoerfer@suse.de
- idpf: fix checksums set in idpf_rx_rsc() (jsc#PED-10581).
- net/mlx5: IRQ, Fix null string in debug print (jsc#PED-11331).
- net/mlx5: Restore missing trace event when enabling vport QoS
  (jsc#PED-11331).
- net/mlx5: Fix vport QoS cleanup on error (jsc#PED-11331).
- ixgbe: fix media cage present detection for E610 device
  (jsc#PED-9647).
- iavf: fix circular lock dependency with netdev_lock
  (jsc#PED-10423).
- ice: Avoid setting default Rx VSI twice in switchdev setup
  (jsc#PED-10419).
- ice: Fix deinitializing VF in error path (jsc#PED-10419).
- net: ethtool: fix ioctl confusing drivers about desired HDS
  user config (git-fixes).
- RDMA/bnxt_re: Fix the page details for the srq created by
  kernel consumers (jsc#PED-10684 jsc#PED-11230).
- RDMA/bnxt_re: Fix the statistics for Gen P7 VF (jsc#PED-10684
  jsc#PED-11230).
- RDMA/bnxt_re: Fix issue in the unload path (jsc#PED-10684
  jsc#PED-11230).
- RDMA/bnxt_re: Add sanity checks on rdev validity (jsc#PED-10684
  jsc#PED-11230).
- RDMA/bnxt_re: Fix an issue in bnxt_re_async_notifier
  (jsc#PED-10684 jsc#PED-11230).
- vsock/bpf: Warn on socket without transport (jsc#PED-11028).
- ibmvnic: Don't reference skb after sending to VIOS
  (jsc#PED_10911 jsc#PED-3606).
- s390/qeth: move netif_napi_add_tx() and napi_enable() from
  under BH (git-fixes).
- vsock: Orphan socket after transport release (jsc#PED-11028).
- igc: Set buffer type for empty frames in igc_init_empty_frame
  (jsc#PED-10417).
- igc: Fix HW RX timestamp when passed by ZC XDP (jsc#PED-10417).
- ixgbe: Fix possible skb NULL pointer dereference (jsc#PED-9647).
- idpf: record rx queue in skb for RSC packets (jsc#PED-10581).
- idpf: fix handling rsc packet with a single segment
  (jsc#PED-10581).
- iavf: Fix a locking bug in an error path (jsc#PED-10423).
- neighbour: use RCU protection in __neigh_notify() (jsc#PED-10684
  jsc#PED-11230).
- net: ethtool: tsconfig: Fix netlink type of hwtstamp flags
  (git-fixes).
- net: add dev_net_rcu() helper (jsc#PED-10684 jsc#PED-11230).
- net: atlantic: fix warning during hot unplug (jsc#PED-11287).
- ice: stop storing XDP verdict within ice_rx_buf (jsc#PED-10419).
- ice: gather page_count()'s of each frag right before XDP prog
  call (jsc#PED-10419).
- ice: put Rx buffers after being done with current frame
  (jsc#PED-10419).
- tg3: Disable tg3 PCIe AER on system reboot (jsc#PED-3526
  jsc#PED-11226).
- vmxnet3: Fix tx queue race condition with XDP (jsc#PED-11024).
- ice: Add check for devm_kzalloc() (jsc#PED-10419).
- vsock: Allow retrying on connect() failure (jsc#PED-11028).
- iavf: allow changing VLAN state without calling PF
  (jsc#PED-10423).
- ice: remove invalid parameter of equalizer (jsc#PED-10419).
- ice: fix ice_parser_rt::bst_key array size (jsc#PED-10419).
- idpf: add more info during virtchnl transaction timeout/salt
  mismatch (jsc#PED-10581).
- idpf: convert workqueues to unbound (jsc#PED-10581).
- idpf: Acquire the lock before accessing the xn->salt
  (jsc#PED-10581).
- idpf: fix transaction timeouts on reset (jsc#PED-10581).
- idpf: add read memory barrier when checking descriptor done bit
  (jsc#PED-10581).
- net: page_pool: don't try to stash the napi id (jsc#PED-10423).
- netdevsim: don't assume core pre-populates HDS params on GET
  (jsc#PED-10684 jsc#PED-11230).
- wifi: mt76: move napi_enable() from under BH (git-fixes).
- eth: via-rhine: fix calling napi_enable() in atomic context
  (git-fixes).
- eth: niu: fix calling napi_enable() in atomic context
  (git-fixes).
- eth: 8139too: fix calling napi_enable() in atomic context
  (git-fixes).
- eth: forcedeth: fix calling napi_enable() in atomic context
  (git-fixes).
- eth: forcedeth: remove local wrappers for napi enable/disable
  (git-fixes).
- eth: tg3: fix calling napi_enable() in atomic context
  (jsc#PED-3526 jsc#PED-11226).
- net/mlx5e: add missing cpu_to_node to kvzalloc_node in
  mlx5e_open_xdpredirect_sq (jsc#PED-11331).
- net: mvneta: fix locking in mvneta_cpu_online() (git-fixes).
- octeontx2: don't mess with ->d_parent or ->d_parent->d_name
  (jsc#PED-11317).
- sysfs: constify bin_attribute argument of
  sysfs_bin_attr_simple_read() (jsc#PED-10421 jsc#PED-8564).
- sysfs: constify macro BIN_ATTRIBUTE_GROUPS() (jsc#PED-10421
  jsc#PED-8564).
- VMCI: remove unused ioctl definitions (jsc#PED-11026).
- RDMA/hfi1: Constify 'struct bin_attribute' (jsc#PED-10421
  jsc#PED-8564).
- RDMA/bnxt_re: Allocate dev_attr information dynamically
  (jsc#PED-10684 jsc#PED-11230).
- RDMA/bnxt_re: Pass the context for ulp_irq_stop (jsc#PED-10684
  jsc#PED-11230).
- RDMA/bnxt_re: Add support to handle DCB_CONFIG_CHANGE event
  (jsc#PED-10684 jsc#PED-11230).
- RDMA/bnxt_re: Query firmware defaults of CC params during probe
  (jsc#PED-10684 jsc#PED-11230).
- RDMA/bnxt_re: Add Async event handling support (jsc#PED-10684
  jsc#PED-11230).
- bnxt_en: Add ULP call to notify async events (jsc#PED-10684
  jsc#PED-11230).
- net: avoid race between device unregistration and ethnl ops
  (jsc#PED-10684 jsc#PED-11230).
- eth: bnxt: update header sizing defaults (jsc#PED-10684
  jsc#PED-11230).
- eth: bnxt: allocate enough buffer space to meet HDS threshold
  (jsc#PED-10684 jsc#PED-11230).
- net: ethtool: populate the default HDS params in the core
  (jsc#PED-10684 jsc#PED-11230).
- eth: bnxt: apply hds_thrs settings correctly (jsc#PED-10684
  jsc#PED-11230).
- net: provide pending ring configuration in net_device
  (jsc#PED-10684 jsc#PED-11230).
- net: ethtool: store netdev in a temp variable in
  ethnl_default_set_doit() (jsc#PED-10684 jsc#PED-11230).
- net: move HDS config from ethtool state (jsc#PED-10684
  jsc#PED-11230).
- net: destroy dev->lock later in free_netdev() (git-fixes).
- eth: bnxt: fix string truncation warning in FW version
  (jsc#PED-10684 jsc#PED-11230).
- net: ethtool: ts: add separate counter for unconfirmed one-step
  TX timestamps (jsc#PED-10684 jsc#PED-11230).
- net/mlx5: fix unintentional sign extension on shift of
  dest_attr->vport.vhca_id (jsc#PED-11331).
- ice: support FW Recovery Mode (jsc#PED-10419).
- devlink: add devl guard (jsc#PED-10419).
- pldmfw: enable selected component update (jsc#PED-10419).
- net/mlx5e: CT: Offload connections with hardware steering rules
  (jsc#PED-11331).
- net/mlx5e: CT: Make mlx5_ct_fs_smfs_ct_validate_flow_rule
  reusable (jsc#PED-11331).
- net/mlx5e: CT: Add initial support for Hardware Steering
  (jsc#PED-11331).
- net/mlx5: HWS, rework the check if matcher size can be increased
  (jsc#PED-11331).
- net: protect napi->irq with netdev_lock() (jsc#PED-3526
  jsc#PED-11226).
- net: protect NAPI enablement with netdev_lock() (jsc#PED-10423).
- net: protect netdev->napi_list with netdev_lock()
  (jsc#PED-10423).
- net: add netdev->up protected by netdev_lock() (jsc#PED-10423).
- net: make netdev_lock() protect netdev->reg_state
  (jsc#PED-10423).
- net: add netdev_lock() / netdev_unlock() helpers
  (jsc#PED-10423).
- ice: Add in/out PTP pin delays (jsc#PED-10419).
- ice: implement low latency PHY timer updates (jsc#PED-10419).
- ice: check low latency PHY timer update firmware capability
  (jsc#PED-10419).
- ice: add lock to protect low latency interface (jsc#PED-10419).
- ice: rename TS_LL_READ* macros to REG_LL_PROXY_H_*
  (jsc#PED-10419).
- ice: use read_poll_timeout_atomic in ice_read_phy_tstamp_ll_e810
  (jsc#PED-10419).
- ice: use string choice helpers (jsc#PED-10419).
- ice: add fw and port health reporters (jsc#PED-10419).
- ice: add recipe priority check in search (jsc#PED-10419).
- ice: ice_probe: init ice_adapter after HW init (jsc#PED-10419).
- ice: minor: rename goto labels from err to unroll
  (jsc#PED-10419).
- ice: split ice_init_hw() out from ice_init_dev()
  (jsc#PED-10419).
- ice: c827: move wait for FW to ice_init_hw() (jsc#PED-10419).
- netdevsim: add HDS feature (jsc#PED-10684 jsc#PED-11230).
- bnxt_en: add support for hds-thresh ethtool command
  (jsc#PED-10684 jsc#PED-11230).
- bnxt_en: add support for tcp-data-split ethtool command
  (jsc#PED-10684 jsc#PED-11230).
- bnxt_en: add support for rx-copybreak ethtool command
  (jsc#PED-10684 jsc#PED-11230).
- net: disallow setup single buffer XDP when tcp-data-split is
  enabled (jsc#PED-10684 jsc#PED-11230).
- net: devmem: add ring parameter filtering (jsc#PED-10684
  jsc#PED-11230).
- net: ethtool: add support for configuring hds-thresh
  (jsc#PED-10684 jsc#PED-11230).
- net: ethtool: add hds_config member in ethtool_netdev_state
  (jsc#PED-10684 jsc#PED-11230).
- net/mlx5: Add nic_cap_reg and vhca_icm_ctrl registers
  (jsc#PED-11331).
- net/mlx5: SHAMPO: Introduce new SHAMPO specific HCA caps
  (jsc#PED-11331).
- net/mlx5: Add support for MRTCQ register (jsc#PED-11331).
- net/mlx5: Update mlx5_ifc to support FEC for 200G per lane
  link modes (jsc#PED-11331).
- net: ethtool: add support for structured PHY statistics
  (jsc#PED-10684 jsc#PED-11230).
- net: ethtool: plumb PHY stats to PHY drivers (jsc#PED-10684
  jsc#PED-11230).
- ethtool: linkstate: migrate linkstate functions to support
  multi-PHY setups (jsc#PED-10684 jsc#PED-11230).
- net/mlx5: HWS, update flow - support through bigger action RTC
  (jsc#PED-11331).
- net/mlx5: HWS, update flow - remove the use of dual RTCs
  (jsc#PED-11331).
- net/mlx5: fs, add HWS to steering mode options (jsc#PED-11331).
- net/mlx5: fs, add HWS get capabilities (jsc#PED-11331).
- net/mlx5: fs, set create match definer to not supported by HWS
  (jsc#PED-11331).
- net/mlx5: fs, add support for dest vport HWS action
  (jsc#PED-11331).
- net/mlx5: fs, add HWS fte API functions (jsc#PED-11331).
- net/mlx5: fs, add dest table cache (jsc#PED-11331).
- net/mlx5: fs, manage flow counters HWS action sharing by
  refcount (jsc#PED-11331).
- net/mlx5: fs, add HWS modify header API function
  (jsc#PED-11331).
- net/mlx5: fs, add HWS packet reformat API function
  (jsc#PED-11331).
- net/mlx5: fs, add HWS actions pool (jsc#PED-11331).
- net/mlx5: fs, add HWS flow group API functions (jsc#PED-11331).
- net/mlx5: fs, add HWS flow table API functions (jsc#PED-11331).
- net/mlx5: fs, add HWS root namespace functions (jsc#PED-11331).
- eth: iavf: extend the netdev_lock usage (jsc#PED-10423).
- net/mlx5e: Update TX ESN context for IPSec hardware offload
  (jsc#PED-11331).
- xfrm: Support ESN context update to hardware for TX
  (jsc#PED-11331).
- net/mlx5: use do_aux_work for PHC overflow checks
  (jsc#PED-11331).
- igc: Link queues to NAPI instances (jsc#PED-10417).
- igc: Link IRQs to NAPI instances (jsc#PED-10417).
- i40e: add ability to reset VF for Tx and Rx MDD events
  (jsc#PED-10428).
- ixgbevf: Fix passing 0 to ERR_PTR in ixgbevf_run_xdp()
  (jsc#PED-9647).
- ixgbe: Fix passing 0 to ERR_PTR in ixgbe_run_xdp()
  (jsc#PED-9647).
- igb: Fix passing 0 to ERR_PTR in igb_run_xdp() (jsc#PED-10426).
- igc: Fix passing 0 to ERR_PTR in igc_xdp_run_prog()
  (jsc#PED-10417).
- igc: Allow hot-swapping XDP program (jsc#PED-10417).
- igb: Add AF_XDP zero-copy Tx support (jsc#PED-10426).
- igb: Add AF_XDP zero-copy Rx support (jsc#PED-10426).
- igb: Add XDP finalize and stats update functions
  (jsc#PED-10426).
- igb: Introduce XSK data structures and helpers (jsc#PED-10426).
- igb: Introduce igb_xdp_is_enabled() (jsc#PED-10426).
- igb: Remove static qualifiers (jsc#PED-10426).
- ixgbevf: Remove unused ixgbevf_hv_mbx_ops (jsc#PED-9647).
- octeontx2-pf: mcs: Remove dead code and semi-colon from
  rsrc_name() (jsc#PED-11317).
- net/mlx5: HWS, set timeout on polling for completion
  (jsc#PED-11331).
- net/mlx5: HWS, support flow sampler destination (jsc#PED-11331).
- net/mlx5: HWS, use the right size when writing arg data
  (jsc#PED-11331).
- net/mlx5: HWS, handle returned error value in pool alloc
  (jsc#PED-11331).
- net/mlx5: HWS, fix definer's HWS_SET32 macro for negative offset
  (jsc#PED-11331).
- net/mlx5: HWS, separate SQ that HWS uses from the usual traffic
  SQs (jsc#PED-11331).
- net/mlx5: HWS, num_of_rules counter on matcher should be atomic
  (jsc#PED-11331).
- net/mlx5: HWS, reduce memory consumption of a matcher struct
  (jsc#PED-11331).
- net/mlx5: HWS, remove wrong deletion of the miss table list
  (jsc#PED-11331).
- net/mlx5: HWS, change error flow on matcher disconnect
  (jsc#PED-11331).
- net/mlx5: HWS, add error message on failure to move rules
  (jsc#PED-11331).
- net/mlx5: HWS, simplify allocations as we support only FDB
  (jsc#PED-11331).
- net/mlx5: HWS, denote how refcounts are protected
  (jsc#PED-11331).
- net/mlx5: HWS, remove implementation of unused FW commands
  (jsc#PED-11331).
- net/mlx5: HWS, remove the use of duplicated structs
  (jsc#PED-11331).
- igc: Remove unused igc_read/write_pcie_cap_reg (jsc#PED-10417).
- igc: Remove unused igc_read/write_pci_cfg wrappers
  (jsc#PED-10417).
- igc: Remove unused igc_acquire/release_nvm (jsc#PED-10417).
- i40e: Remove unused i40e_dcb_hw_get_num_tc (jsc#PED-10428).
- i40e: Remove unused i40e_asq_send_command_v2 (jsc#PED-10428).
- i40e: Remove unused i40e_commit_partition_bw_setting
  (jsc#PED-10428).
- i40e: Remove unused i40e_del_filter (jsc#PED-10428).
- i40e: Remove unused i40e_get_cur_guaranteed_fd_count
  (jsc#PED-10428).
- i40e: Deadcode profile code (jsc#PED-10428).
- i40e: Remove unused i40e_(read|write)_phy_register
  (jsc#PED-10428).
- i40e: Remove unused i40e_blink_phy_link_led (jsc#PED-10428).
- i40e: Deadcode i40e_aq_* (jsc#PED-10428).
- devlink: Improve the port attributes description
  (jsc#PED-10419).
- ixgbevf: Add support for Intel(R) E610 device (jsc#PED-9647).
- PCI: Add PCI_VDEVICE_SUB helper macro (jsc#PED-9647).
- ixgbe: Enable link management in E610 device (jsc#PED-9647).
- ixgbe: Clean up the E610 link management related code
  (jsc#PED-9647).
- ixgbe: Add ixgbe_x540 multiple header inclusion protection
  (jsc#PED-9647).
- ixgbe: Add support for EEPROM dump in E610 device
  (jsc#PED-9647).
- ixgbe: Add support for NVM handling in E610 device
  (jsc#PED-9647).
- ixgbe: Add link management support for E610 device
  (jsc#PED-9647).
- ixgbe: Add support for E610 device capabilities detection
  (jsc#PED-9647).
- ixgbe: Add support for E610 FW Admin Command Interface
  (jsc#PED-9647).
- net: ethtool: Fix suspicious rcu_dereference usage (git-fixes).
- net/mlx5: fs, Add support for RDMA RX steering over IB link
  layer (jsc#PED-11331).
- net/mlx5: Remove PTM support log message (jsc#PED-11331).
- net/mlx5: DR, add support for ConnectX-8 steering
  (jsc#PED-11331).
- net/mlx5: DR, expand SWS STE callbacks and consolidate common
  structs (jsc#PED-11331).
- net/mlx5: HWS, do not initialize native API queues
  (jsc#PED-11331).
- net/mlx5: HWS, no need to expose mlx5hws_send_queues_open/close
  (jsc#PED-11331).
- net/mlx5: fs, retry insertion to hash table on EBUSY
  (jsc#PED-11331).
- net/mlx5: fs, add mlx5_fs_pool API (jsc#PED-11331).
- net/mlx5: fs, add counter object to flow destination
  (jsc#PED-11331).
- net/mlx5: LAG, Support LAG over Multi-Host NICs (jsc#PED-11331).
- net/mlx5: LAG, Refactor lag logic (jsc#PED-11331).
- sfc: Use netdev refcount tracking in struct
  efx_async_filter_insertion (jsc#PED-11366).
- xsk: add generic XSk &xdp_buff -> skb conversion
  (jsc#PED-10428).
- xsk: make xsk_buff_add_frag() really add the frag via
  __xdp_buff_add_frag() (jsc#PED-10428).
- xdp: add generic xdp_build_skb_from_buff() (jsc#PED-10428).
- xdp: add generic xdp_buff_add_frag() (jsc#PED-10428).
- page_pool: add page_pool_dev_alloc_netmem() (jsc#PED-10428).
- sfc: remove efx_writed_page_locked (jsc#PED-11366).
- bnxt_en: Skip reading PXP registers during ethtool -d if
  unsupported (bsc#1238145).
- bnxt_en: Skip MAC loopback selftest if it is unsupported by FW
  (bsc#1238145).
- bnxt_en: Skip PHY loopback ethtool selftest if unsupported by FW
  (bsc#1238145).
- bnxt_en: Do not allow ethtool -m on an untrusted VF
  (bsc#1238145).
- bnxt_en: Use FW defined resource limits for RoCE (bsc#1238145).
- ice: Add MDD logging via devlink health (jsc#PED-10419).
- ice: add Tx hang devlink health reporter (jsc#PED-10419).
- ice: rename devlink_port. to port.[ch] (jsc#PED-10419).
- devlink: add devlink_fmsg_dump_skb() function (jsc#PED-10419).
- devlink: add devlink_fmsg_put() macro (jsc#PED-10419).
- net/mlx5e: Report rx_discards_phy via rx_dropped
  (jsc#PED-11331).
- net: page_pool: rename page_pool_is_last_ref() (jsc#PED-10428).
- net/mlx5: Add device cap abs_native_port_num (jsc#PED-11331).
- net/mlx5: qos: Add ifc support for cross-esw scheduling
  (jsc#PED-11331).
- net/mlx5: Add support for new scheduling elements
  (jsc#PED-11331).
- net/mlx5: Add ConnectX-8 device to ifc (jsc#PED-11331).
- net/mlx5: ifc: Reorganize mlx5_ifc_flow_table_context_bits
  (jsc#PED-11331).
- net: ethtool: Add support for tsconfig command to get/set
  hwtstamp config (jsc#PED-10684 jsc#PED-11230).
- net: ethtool: tsinfo: Enhance tsinfo to support several hwtstamp
  by net topology (jsc#PED-10684 jsc#PED-11230).
- net: Add the possibility to support a selected hwtstamp in
  netdevice (jsc#PED-10684 jsc#PED-11230).
- net: Make net_hwtstamp_validate accessible (jsc#PED-10684
  jsc#PED-11230).
- net: Make dev_get_hwtstamp_phylib accessible (jsc#PED-10684
  jsc#PED-11230).
- octeontx2-af: fix build regression without CONFIG_DCB
  (jsc#PED-11317).
- ionic: remove the unused nb_work (jsc#PED-11378).
- page_pool: disable sync for cpu for dmabuf memory provider
  (jsc#PED-10428).
- page_pool: Set `dma_sync` to false for devmem memory provider
  (jsc#PED-10428).
- net: page_pool: create page_pool_alloc_netmem (jsc#PED-10428).
- net: page_pool: rename page_pool_alloc_netmem to *_netmems
  (jsc#PED-10423).
- xdp: make __xdp_return() MP-agnostic (jsc#PED-10428).
- xdp: get rid of xdp_frame::mem.id (jsc#PED-10428).
- page_pool: allow mixing PPs within one bulk (jsc#PED-10428).
- ionic: add support for QSFP_PLUS_CMIS (jsc#PED-11378).
- ionic: add speed defines for 200G and 400G (jsc#PED-11378).
- ionic: Translate IONIC_RC_ENOSUPP to EOPNOTSUPP (jsc#PED-11378).
- ionic: Use VLAN_ETH_HLEN when possible (jsc#PED-11378).
- ionic: add asic codes to firmware interface file
  (jsc#PED-11378).
- ice: cleanup Rx queue context programming functions
  (jsc#PED-10419).
- ice: move prefetch enable to ice_setup_rx_ctx (jsc#PED-10419).
- ice: reduce size of queue context fields (jsc#PED-10419).
- ice: use <linux/packing.h> for Tx and Rx queue context data
  (jsc#PED-10419).
- ice: use structures to keep track of queue context size
  (jsc#PED-10419).
- ice: remove int_q_state from ice_tlan_ctx (jsc#PED-10419).
- lib: packing: add pack_fields() and unpack_fields()
  (jsc#PED-10419).
- lib: packing: demote truncation error in pack() to a warning
  in __pack() (jsc#PED-10419).
- lib: packing: create __pack() and __unpack() variants without
  error checking (jsc#PED-10419).
- cn10k-ipsec: Fix compilation error when CONFIG_XFRM_OFFLOAD
  disabled (jsc#PED-11317).
- cn10k-ipsec: Enable outbound ipsec crypto offload
  (jsc#PED-11317).
- cn10k-ipsec: Allow ipsec crypto offload for skb with SA
  (jsc#PED-11317).
- cn10k-ipsec: Process outbound ipsec crypto offload
  (jsc#PED-11317).
- cn10k-ipsec: Add SA add/del support for outb ipsec crypto
  offload (jsc#PED-11317).
- cn10k-ipsec: Init hardware for outbound ipsec crypto offload
  (jsc#PED-11317).
- octeontx2-af: Disable backpressure between CPT and NIX
  (jsc#PED-11317).
- octeontx2-pf: Move skb fragment map/unmap to common code
  (jsc#PED-11317).
- octeontx2-pf: map skb data as device writeable (jsc#PED-11317).
- page_pool: make page_pool_put_page_bulk() handle array of
  netmems (jsc#PED-10428).
- netmem: add a couple of page helper wrappers (jsc#PED-10428).
- xdp: register system page pool as an XDP memory model
  (jsc#PED-10428).
- xsk: allow attaching XSk pool via xdp_rxq_info_reg_mem_model()
  (jsc#PED-10428).
- xdp: allow attaching already registered memory model to
  xdp_rxq_info (jsc#PED-10428).
- xdp, xsk: constify read-only arguments of some static inline
  helpers (jsc#PED-10428).
- ethtool: regenerate uapi header from the spec (jsc#PED-10684
  jsc#PED-11230).
- ethtool: remove the comments that are not gonna be generated
  (jsc#PED-10684 jsc#PED-11230).
- ethtool: separate definitions that are gonna be generated
  (jsc#PED-10684 jsc#PED-11230).
- ynl: add missing pieces to ethtool spec to better match uapi
  header (jsc#PED-10684 jsc#PED-11230).
- net/mlx5e: Always start IPsec sequence number from 1
  (jsc#PED-11331).
- net/mlx5e: Rely on reqid in IPsec tunnel mode (jsc#PED-11331).
- net/mlx5: SF, Fix add port error handling (jsc#PED-11331).
- net/mlx5: Fix a lockdep warning as part of the write combining
  test (jsc#PED-11331).
- net/mlx5: Fix RDMA TX steering prio (jsc#PED-11331).
- net: make page_pool_ref_netmem work with net iovs
  (jsc#PED-10428).
- ice: Add correct PHY lane assignment (jsc#PED-10419).
- ice: Fix ETH56G FC-FEC Rx offset value (jsc#PED-10419).
- ice: Fix quad registers read on E825 (jsc#PED-10419).
- ice: Fix E825 initialization (jsc#PED-10419).
- igc: return early when failing to read EECD register
  (jsc#PED-10417).
- ice: fix incorrect PHY settings for 100 GB/s (jsc#PED-10419).
- ice: fix max values for dpll pin phase adjust (jsc#PED-10419).
- bnxt_en: Fix DIM shutdown (jsc#PED-10684 jsc#PED-11230).
- bnxt_en: Fix possible memory leak when hwrm_req_replace fails
  (jsc#PED-10684 jsc#PED-11230).
- sysfs: attribute_group: allow registration of const
  bin_attribute (jsc#PED-10421 jsc#PED-8564).
- cdx: Fix cdx_mmap_resource() after constifying attr in ->mmap()
  (git-fixes).
- sysfs: bin_attribute: add const read/write callback variants
  (jsc#PED-10421 jsc#PED-8564).
- sysfs: implement all BIN_ATTR_* macros in terms of __BIN_ATTR()
  (jsc#PED-10421 jsc#PED-8564).
- sysfs: treewide: constify attribute callback of
  bin_attribute::llseek() (jsc#PED-10421 jsc#PED-8564).
- sysfs: treewide: constify attribute callback of
  bin_attribute::mmap() (jsc#PED-10421 jsc#PED-8564).
- sysfs: treewide: constify attribute callback of bin_is_visible()
  (jsc#PED-10421 jsc#PED-8564).
- nvmem: core: calculate bin_attribute size through bin_size()
  (jsc#PED-10421 jsc#PED-8564).
- PCI/sysfs: Calculate bin_attribute size through bin_size()
  (jsc#PED-10421 jsc#PED-8564).
- sysfs: introduce callback attribute_group::bin_size
  (jsc#PED-10421 jsc#PED-8564).
- sysfs: explicitly pass size to sysfs_add_bin_file_mode_ns()
  (jsc#PED-10421 jsc#PED-8564).
- tg3: Set coherent DMA mask bits to 31 for BCM57766 chipsets
  (jsc#PED-3526 jsc#PED-11226).
- net/neighbor: clear error in case strict check is not set
  (jsc#PED-10684 jsc#PED-11230).
- neighbour: Create netdev->neighbour association (jsc#PED-10684
  jsc#PED-11230).
- neighbour: Remove bare neighbour::next pointer (jsc#PED-10684
  jsc#PED-11230).
- neighbour: Convert iteration to use hlist+macro (jsc#PED-10684
  jsc#PED-11230).
- neighbour: Convert seq_file functions to use hlist
  (jsc#PED-10684 jsc#PED-11230).
- neighbour: Define neigh_for_each_in_bucket (jsc#PED-10684
  jsc#PED-11230).
- neighbour: Add hlist_node to struct neighbour (jsc#PED-10684
  jsc#PED-11230).
- Documentation: networking: Add missing PHY_GET command in the
  message list (jsc#PED-10684 jsc#PED-11230).
- neighbour: use kvzalloc()/kvfree() (jsc#PED-10684
  jsc#PED-11230).
- netlink: specs: Add missing phy-ntf command to ethtool spec
  (jsc#PED-10684 jsc#PED-11230).
- netlink: specs: Add missing bitset attrs to ethtool spec
  (jsc#PED-10684 jsc#PED-11230).
- ethtool: rss: prevent rss ctx deletion when in use (git-fixes).
- neighbour: Use rtnl_register_many() (jsc#PED-10684
  jsc#PED-11230).
- neighbour: Remove NEIGH_DN_TABLE (jsc#PED-10684 jsc#PED-11230).
- xsk: s/free_list_node/list_node/ (jsc#PED-10428).
- xsk: Get rid of xdp_buff_xsk::xskb_list_node (jsc#PED-10428).
- lib: packing: catch kunit_kzalloc() failure in the pack() test
  (jsc#PED-10419).
- lib: packing: use GENMASK() for box_mask (jsc#PED-10419).
- lib: packing: use BITS_PER_BYTE instead of 8 (jsc#PED-10419).
- lib: packing: fix QUIRK_MSB_ON_THE_RIGHT behavior
  (jsc#PED-10419).
- lib: packing: add additional KUnit tests (jsc#PED-10419).
- lib: packing: add KUnit tests adapted from selftests
  (jsc#PED-10419).
- lib: packing: duplicate pack() and unpack() implementations
  (jsc#PED-10419).
- lib: packing: add pack() and unpack() wrappers over packing()
  (jsc#PED-10419).
- lib: packing: remove kernel-doc from header file
  (jsc#PED-10419).
- lib: packing: adjust definitions and implementation for
  arbitrary buffer lengths (jsc#PED-10419).
- lib: packing: refuse operating on bit indices which exceed
  size of buffer (jsc#PED-10419).
- commit 6cae1c1
* Mon Mar  3 2025 dwagner@suse.de
- nvme/ioctl: add missing space in err message (git-fixes).
- nvme-tcp: fix connect failure on receiving partial ICResp PDU
  (git-fixes).
- nvme: tcp: Fix compilation warning with W=1 (git-fixes).
- nvmet: Fix crash when a namespace is disabled (git-fixes).
- nvme-fc: use ctrl state getter (git-fixes).
- nvme: make nvme_tls_attrs_group static (git-fixes).
- nvme: handle connectivity loss in nvme_set_queue_count
  (git-fixes).
- nvme-pci: Add TUXEDO IBP Gen9 to Samsung sleep quirk
  (git-fixes).
- nvme-pci: Add TUXEDO InfinityFlex to Samsung sleep quirk
  (git-fixes).
- commit 1f4a76c
* Mon Mar  3 2025 tiwai@suse.de
- docs/zh_TW+zh_CN: Make rst references unique (bsc#1238303).
- commit cc79623
* Mon Mar  3 2025 mgorman@suse.de
- sched: Compact RSEQ concurrency IDs with reduced threads and
  affinity (git fixes (sched)).
- sched_ext: Fix incorrect autogroup migration detection (git
  fixes (sched)).
- commit ff0b264
* Mon Mar  3 2025 msuchanek@suse.de
- powerpc/vdso: Flag VDSO64 entry points as functions
  (bsc#1238318).
- commit 8f0f0a0
* Mon Mar  3 2025 dsterba@suse.com
- btrfs: fix use-after-free when attempting to join an aborted transaction (CVE-2025-21753 bsc#1237875)
- commit 03161f9
* Mon Mar  3 2025 jslaby@suse.cz
- 8250: microchip: pci1xxxx: Add workaround for RTS bit toggle
  (git-fixes).
- serial: 8250_pci: Resolve WCH vendor ID ambiguity (git-fixes).
- PCI: switchtec: Add Microchip PCI100X device IDs (git-fixes).
- PCI/DPC: Quirk PIO log size for Intel Raptor Lake-P (git-fixes).
- commit 55d8dfe
* Mon Mar  3 2025 tiwai@suse.de
- phy: tegra: xusb: reset VBUS & ID OVERRIDE (git-fixes).
- phy: exynos5-usbdrd: gs101: ensure power is gated to SS phy
  in phy_exit() (git-fixes).
- phy: exynos5-usbdrd: fix MPLL_MULTIPLIER and SSC_REFCLKSEL
  masks in refclk (git-fixes).
- phy: rockchip: naneng-combphy: compatible reset with old DT
  (git-fixes).
- phy: rockchip: fix Kconfig dependency more (git-fixes).
- commit d9bc035
* Sun Mar  2 2025 tiwai@suse.de
- i2c: ls2x: Fix frequency division register access (git-fixes).
- i2c: npcm: disable interrupt enable bit before devm_request_irq
  (git-fixes).
- Revert "ata: libata-core: Add ATA_QUIRK_NOLPM for Samsung SSD
  870 QVO drives" (git-fixes).
- commit 33aa03b
* Sat Mar  1 2025 tiwai@suse.de
- thermal: gov_power_allocator: Fix incorrect calculation in
  divvy_up_power() (git-fixes).
- drm/xe: cancel pending job timer before freeing scheduler
  (git-fixes).
- drm/xe/regs: remove a duplicate definition for
  RING_CTL_SIZE(size) (git-fixes).
- drm/xe/userptr: fix EFAULT handling (git-fixes).
- drm/xe/userptr: restore invalidation list on error (git-fixes).
- drm/amdgpu: init return value in amdgpu_ttm_clear_buffer
  (git-fixes).
- drm/amdgpu: disable BAR resize on Dell G5 SE (git-fixes).
- amdgpu/pm/legacy: fix suspend/resume issues (git-fixes).
- commit 4f76ef0
* Sat Mar  1 2025 lduncan@suse.com
- scsi: core: Clear driver private data when retrying request
  (git-fixes).
- commit adaa7f6
* Fri Feb 28 2025 krisman@suse.de
- Revert "mm/page_alloc.c: don't show protection in zone's
  - >lowmem_reserve[] for empty zone" (bsc#1237124).
- commit 50e61e8
* Fri Feb 28 2025 jgross@suse.com
- KVM: nVMX: Defer SVI update to vmcs01 on EOI when L2 is active
  w/o VID (git-fixes).
- commit 0abcd2f
* Fri Feb 28 2025 jgross@suse.com
- KVM: x86: Plumb in the vCPU to kvm_x86_ops.hwapic_isr_update()
  (git-fixes).
- commit 24722f8
* Fri Feb 28 2025 jgross@suse.com
- KVM: x86: Reject disabling of MWAIT/HLT interception when not
  allowed (git-fixes).
- commit a3d8ac2
* Fri Feb 28 2025 jgross@suse.com
- KVM: x86: Break CONFIG_KVM_X86's direct dependency on KVM_INTEL
  || KVM_AMD (git-fixes).
- commit 0ad14bf
* Fri Feb 28 2025 jgross@suse.com
- KVM: x86: add back X86_LOCAL_APIC dependency (git-fixes).
- commit 32787b9
* Fri Feb 28 2025 vbabka@suse.cz
- kernel: be more careful about dup_mmap() failures and uprobe
  registering (CVE-2025-21709 bsc#1237884).
- commit 1a9b90a
* Fri Feb 28 2025 jgross@suse.com
- vsock/virtio: fix variables initialization during resuming
  (git-fixes).
- commit 2798352
* Fri Feb 28 2025 jgross@suse.com
- virtio_net: ensure netdev_tx_reset_queue is called on tx ring
  resize (git-fixes).
- commit 28a402c
* Fri Feb 28 2025 tiwai@suse.de
- ASoC: SOF: Intel: pci-ptl: Add support for PTL-H (stable-fixes).
- ALSA: hda/realtek: Fix volume adjustment issue on Lenovo
  ThinkBook 16P Gen5 (stable-fixes).
- ALSA: hda/realtek: fixup ASUS H7606W (stable-fixes).
- ALSA: hda/realtek: fixup ASUS GA605W (stable-fixes).
- ALSA: hda/realtek: Add new alc2xx-fixup-headset-mic model
  (stable-fixes).
- commit 7116445
* Fri Feb 28 2025 tiwai@suse.de
- ALSA: hda/cirrus: Reduce codec resume time (stable-fixes).
- ALSA: hda: hda-intel: add Panther Lake-H support (stable-fixes).
- ALSA: hda: intel-dsp-config: Add PTL-H support (stable-fixes).
- PCI: pci_ids: add INTEL_HDA_PTL_H (stable-fixes).
- ALSA: hda/realtek: Limit mic boost on Positivo ARN50
  (stable-fixes).
- ALSA: hda: Support for Ideapad hotkey mute LEDs (stable-fixes).
- ALSA: hda: Add AZX_DCAPS_NO_TCSEL flag for Loongson HDA devices
  (stable-fixes).
- ALSA: hda/realtek: Add support for Ayaneo System using CS35L41
  HDA (stable-fixes).
- ALSA: hda/realtek - Add support for ASUS Zen AIO 27
  Z272SD_A272SD audio (stable-fixes).
- commit 4e48fbb
* Fri Feb 28 2025 tiwai@suse.de
- sound: usb: format: don't warn that raw DSD is unsupported
  (stable-fixes).
- sound: usb: enable DSD output for ddHiFi TC44C (stable-fixes).
- commit da2e3f4
* Fri Feb 28 2025 tiwai@suse.de
- selftests/mm: fix check for running THP tests (git-fixes).
- selftests: net/{lib,openvswitch}: extend CFLAGS to keep options
  from environment (git-fixes).
- selftests: mptcp: extend CFLAGS to keep options from environment
  (git-fixes).
- commit ab48ae5
* Fri Feb 28 2025 tiwai@suse.de
- ALSA: usb-audio: Re-add sample rate quirk for Pioneer
  DJM-900NXS2 (stable-fixes).
- commit 7a3eb62
* Fri Feb 28 2025 tiwai@suse.de
- selftests: drv-net: Check if combined-count exists (git-fixes).
- usbnet: gl620a: fix endpoint checking in genelink_bind()
  (git-fixes).
- Bluetooth: L2CAP: Fix L2CAP_ECRED_CONN_RSP response (git-fixes).
- net: phy: qcom: qca807x fix condition for DAC_DSP_BIAS_CURRENT
  (git-fixes).
- ASoC: cs35l56: Prevent races when soft-resetting using SPI
  control (git-fixes).
- firmware: cs_dsp: Remove async regmap writes (git-fixes).
- ASoC: fsl: Rename stream name of SAI DAI driver (git-fixes).
- ASoC: es8328: fix route from DAC to output (git-fixes).
- ALSA: hda/realtek: Fix microphone regression on ASUS N705UD
  (git-fixes).
- ALSA: hda/realtek: Fix wrong mic setup for ASUS VivoBook 15
  (git-fixes).
- ALSA: usb-audio: Avoid dropping MIDI events at closing multiple
  ports (git-fixes).
- drm/i915/dp: Fix error handling during 128b/132b link training
  (stable-fixes).
- drm/i915: Make sure all planes in use by the joiner have their
  crtc included (stable-fixes).
- drm/amdkfd: Ensure consistent barrier state saved in gfx12
  trap handler (stable-fixes).
- drm/amdgpu: bump version for RV/PCO compute fix (stable-fixes).
- drm/amdgpu/gfx9: manually control gfxoff for CS on RV
  (stable-fixes).
- drm/amd/display: Correct register address in dcn35
  (stable-fixes).
- drm/amdkfd: Move gfx12 trap handler to separate file
  (stable-fixes).
- drm/amd/display: update dcn351 used clock offset (stable-fixes).
- drm/amd/display: Refactoring if and endif statements to enable
  DC_LOGGER (stable-fixes).
- drm/xe/oa: Add input fence dependencies (stable-fixes).
- drm/xe/oa/uapi: Define and parse OA sync properties
  (stable-fixes).
- drm/xe/oa: Separate batch submission from waiting for completion
  (stable-fixes).
- commit dbc984f
* Fri Feb 28 2025 jgross@suse.com
- virtio_ring: add a func argument 'recycle_done' to
  virtqueue_resize() (git-fixes).
- commit 9d5dc5a
* Thu Feb 27 2025 davide.benini@suse.com
- netfilter: nft_inner: incorrect percpu area handling under
  softirq (CVE-2024-56638 bsc#1235524).
- commit c4eaec2
* Thu Feb 27 2025 tbogendoerfer@suse.de
- ptr_ring: do not block hard interrupts in
  ptr_ring_resize_multiple() (CVE-2024-57994 bsc#1237901).
- commit eb91bfe
* Thu Feb 27 2025 pmladek@suse.com
- printk: Fix signed integer overflow when defining
  LOG_BUF_LEN_MAX (bsc#1237950).
- commit 2864e46
* Thu Feb 27 2025 dmueller@suse.com
- add nf_tables for iptables non-legacy network handling
  This is needed for example by docker on the Alpine Linux distribution,
  but can also be used on openSUSE.
- commit f9b0903
* Thu Feb 27 2025 sjaeckel@suse.de
- tcp: Fix use-after-free of nreq in reqsk_timer_handler()
  (CVE-2024-53206 bsc#1234960).
- commit 1d4fc49
* Thu Feb 27 2025 pmladek@suse.com
- workqueue: Put the pwq after detaching the rescuer from the pool
  (bsc#1237866).
- commit 7f68bba
* Wed Feb 26 2025 msuchanek@suse.de
- kernel-source: Also replace bin/env
- commit dc2037c
* Wed Feb 26 2025 nmorey@suse.com
- RDMA/mlx5: Fix bind QP error cleanup flow (git-fixes)
- commit 789f3e9
* Wed Feb 26 2025 nmorey@suse.com
- RDMA/mlx5: Fix AH static rate parsing (git-fixes)
- commit 9b914e2
* Wed Feb 26 2025 nmorey@suse.com
- RDMA/mlx5: Fix implicit ODP hang on parent deregistration (git-fixes)
- commit 094971b
* Wed Feb 26 2025 nmorey@suse.com
- RDMA/hns: Fix mbox timing out by adding retry mechanism (git-fixes)
- commit d95c6ee
* Wed Feb 26 2025 nmorey@suse.com
- RDMA/mlx5: Fix a WARN during dereg_mr for DM type (git-fixes)
- commit f0da614
* Wed Feb 26 2025 nmorey@suse.com
- RDMA/mlx5: Fix a race for DMABUF MR which can lead to CQE with error (git-fixes)
- commit a39ffd1
* Wed Feb 26 2025 nmorey@suse.com
- IB/mlx5: Set and get correct qp_num for a DCT QP (git-fixes)
- commit d33e08b
* Wed Feb 26 2025 nmorey@suse.com
- RDMA/mlx5: Fix the recovery flow of the UMR QP (git-fixes)
- commit 868f8b2
* Wed Feb 26 2025 nmorey@suse.com
- RDMA/efa: Reset device on probe failure (git-fixes)
- commit 6c8b3e4
* Wed Feb 26 2025 oneukum@suse.com
- media: uvcvideo: Fix deadlock during uvc_probe (git-fixes).
- commit c3f3457
* Wed Feb 26 2025 lduncan@suse.com
- md: Fix linear_set_limits() (git-fixes).
- md/md-linear: Fix a NULL vs IS_ERR() bug in linear_add()
  (git-fixes).
- commit 7025de8
* Tue Feb 25 2025 neelx@suse.com
- Refresh
  patches.suse/btrfs-provide-super_operations-get_inode_dev.
- Refresh patches.suse/vfs-add-super_operations-get_inode_dev.
  We want to keep these two patches. See bsc#1237035.
- commit b446678
* Tue Feb 25 2025 oneukum@suse.com
- media: videobuf2-core: update vb2_thread if wait_finish/prepare
  are NULL (jsc#PED-10929).
- commit 10a1fa2
* Tue Feb 25 2025 oneukum@suse.com
- media: platform: video-mux: Fix mutex locking (jsc#PED-10929
  jsc#PED-10931).
- commit dadd533
* Tue Feb 25 2025 oneukum@suse.com
- media: ipu6: fix the wrong type casting and 64-bit division
  (jsc#PED-10931).
- commit 2627941
* Tue Feb 25 2025 oneukum@suse.com
- v4l2-subdev: Return -EOPNOTSUPP for unsupported pad type in
  call_get_frame_desc() (jsc#PED-10929).
- commit 030d5b9
* Tue Feb 25 2025 oneukum@suse.com
- media: uapi: Add meta formats for PiSP FE config and stats
  (jsc#PED-10929).
- commit 802cc52
* Tue Feb 25 2025 tiwai@suse.de
- crypto: ccp - Fix check for the primary ASP device
  (bsc#1237400).
- commit 96d9d45
* Tue Feb 25 2025 pjakobsson@suse.de
- supported.conf: Mark Intel Xe DRM driver as supported (jsc#PED-10927)
- commit e99dd3a
* Tue Feb 25 2025 oneukum@suse.com
- media: tda18271: add missing result checking of
  tda18271_lookup_map() (git-fixes).
- commit 8360f5e
* Tue Feb 25 2025 oneukum@suse.com
- media: video-i2c: set lock before calling vb2_queue_init()
  (jsc#PED-10929).
- commit 76ce583
* Tue Feb 25 2025 oneukum@suse.com
- media: rcar_drif.c: set lock before calling vb2_queue_init()
  (jsc#PED-10929).
- commit 6c43c80
* Tue Feb 25 2025 oneukum@suse.com
- media: airspy: set lock before calling vb2_queue_init()
  (jsc#PED-10929).
- commit d204d85
* Tue Feb 25 2025 oneukum@suse.com
- media: hackrf: set lock before calling vb2_queue_init()
  (jsc#PED-10929).
- commit 0cf29c8
* Tue Feb 25 2025 oneukum@suse.com
- media: msi2500: set lock before calling vb2_queue_init()
  (jsc#PED-10929).
- commit 78a851d
* Tue Feb 25 2025 oneukum@suse.com
- media: pwc: set lock before calling vb2_queue_init()
  (jsc#PED-10929).
- commit 88e95f0
* Tue Feb 25 2025 oneukum@suse.com
- media: v4l2-core: add v4l2_debugfs_root() (jsc#PED-10929).
- commit cae4a2c
* Tue Feb 25 2025 oneukum@suse.com
- media: uvcvideo: Avoid race condition during unregister
  (git-fixes).
- commit f90251c
* Tue Feb 25 2025 oneukum@suse.com
- media: uvcvideo: Refactor the status irq API (git-fixes).
- commit fbb3682
* Tue Feb 25 2025 ykaukab@suse.de
- config: update with run_oldconfig.sh
- commit 6dd51d0
* Tue Feb 25 2025 ykaukab@suse.de
- Revert "stackleak: disable stack erasing by default (jsc#PED-11837)."
  References: bsc#1236639
  This reverts commit 25d95db331f571abeffc51daf9daa6219b4e2925.
- commit 84b2605
* Tue Feb 25 2025 ykaukab@suse.de
- Revert "config: enable CONFIG_GCC_PLUGIN_STACKLEAK"
  References: bsc#1236639
  This reverts commit 8cf8a171b158d71a7c9aed37d0a2ddc905d92ad3.
- commit f7b80f9
* Tue Feb 25 2025 oneukum@suse.com
- media: uvcvideo: Add support for the D3DFMT_R5G6B5 pixmap type
  (jsc#PED-10929).
- commit a17e732
* Tue Feb 25 2025 oneukum@suse.com
- media: uvcvideo: Add luma 16-bit interlaced pixel format
  (jsc#PED-10929).
- commit 1f638e3
* Tue Feb 25 2025 mgorman@suse.de
- seqlock: annotate spinning as unlikely() in
  __read_seqcount_begin (bsc#1234634 (Scheduler functional and
  performance backports)).
- commit a946846
* Tue Feb 25 2025 oneukum@suse.com
- usb: storage: fix wrong comments for struct bulk_cb_wrap
  (git-fixes).
- fs_parser: update mount_api doc to match function signature
  (git-fixes).
- media: v4l: Add luma 16-bit interlaced pixel format
  (jsc#PED-10929).
- commit 33206f5
* Tue Feb 25 2025 ykaukab@suse.de
- sysctl: remove kernel.stack_erase
  References: bsc#1236639
  Commit 25d95db331f5 ("stackleak: disable stack erasing by default (jsc#PED-11837)")
  changed the default state of kernel.stack_erase to 0. There is no need
  to do the same in the sysctl/defaults.
- commit 5dfd8de
* Tue Feb 25 2025 oneukum@suse.com
- usb: dwc3: st: Switch from CONFIG_PM_SLEEP guards to
  pm_sleep_ptr() (jsc#PED-10596).
- commit a7ea25c
* Tue Feb 25 2025 oneukum@suse.com
- usb: dwc3: gadget: Reinitiate stream for all host NoStream
  behavior (jsc#PED-10596).
- commit df9c212
* Tue Feb 25 2025 ykaukab@suse.de
- supported.conf: typec_thunderbolt: fix syntax
  Remove '+' from the start of the line as it causes kbuild failures
- commit 7b2bf44
* Mon Feb 24 2025 lduncan@suse.com
- md/md-bitmap: Synchronize bitmap_get_stats() with bitmap
  lifetime (git-fixes).
- md/md-bitmap: move bitmap_{start, end}write to md upper layer
  (git-fixes).
- md/raid5: implement pers->bitmap_sector() (git-fixes).
- md: add a new callback pers->bitmap_sector() (git-fixes).
- md/md-bitmap: remove the last parameter for
  bimtap_ops->endwrite() (git-fixes).
- md/md-bitmap: factor behind write counters out from
  bitmap_{start/end}write() (git-fixes).
- commit 4ada1e0
* Mon Feb 24 2025 lduncan@suse.com
- md: reintroduce md-linear (git-fixes).
- Update config files.
- commit f99cccf
* Mon Feb 24 2025 oneukum@suse.com
- usb: dwc3: gadget: Fix incorrect UDC state after manual
  deconfiguration (git-fixes).
- commit befc60a
* Mon Feb 24 2025 oneukum@suse.com
- usb: dwc3: core: Disable USB2 retry for DWC_usb31 1.80a and
  prior (jsc#PED-10596).
- commit 8b10560
* Mon Feb 24 2025 oneukum@suse.com
- usb: dwc3: remove unused sg struct member (jsc#PED-10596).
- commit 7e4c228
* Mon Feb 24 2025 oneukum@suse.com
- usb: dwc3: gadget: Remove dwc3_request->needs_extra_trb
  (jsc#PED-10596).
- commit afb0887
* Mon Feb 24 2025 oneukum@suse.com
- usb: dwc3: gadget: Cleanup SG handling (jsc#PED-10596).
- commit c49703b
* Mon Feb 24 2025 oneukum@suse.com
- usb: dwc3: core: Set force_gen1 bit for all applicable
  SuperSpeed ports (jsc#PED-10596).
- commit 288dd0b
* Mon Feb 24 2025 oneukum@suse.com
- usb: dwc3: gadget: Refine the logic for resizing Tx FIFOs
  (jsc#PED-10596).
- Refresh
  patches.suse/usb-dwc3-gadget-Add-missing-check-for-single-port-RA.patch.
- commit 7ccfe71
* Mon Feb 24 2025 oneukum@suse.com
- Update
  patches.suse/usb-Switch-back-to-struct-platform_driver-remove.patch
  (jsc#PED-10906 jsc#PED-10596).
- commit 467bf03
* Mon Feb 24 2025 mfranc@suse.cz
- s390/boot: Fix ESSA detection (git-fixes bsc#1237566).
- commit 1f84598
* Mon Feb 24 2025 oneukum@suse.com
- thunderbolt: debugfs: Implement Gen 4 margining eye selection
  (jsc#PED-10603).
- commit 759b7a2
* Mon Feb 24 2025 oneukum@suse.com
- thunderbolt: debugfs: Add USB4 Gen 4 margining capabilities
  (jsc#PED-10603).
- commit 29dbb78
* Mon Feb 24 2025 oneukum@suse.com
- thunderbolt: Don't hardcode margining capabilities size
  (jsc#PED-10603).
- commit 945d1a2
* Mon Feb 24 2025 mkoutny@suse.com
- cgroup: Remove steal time from usage_usec (bsc#1237560).
- cgroup: fix race between fork and cgroup.kill (bsc#1237559).
- blk-cgroup: Fix class @block_class's subsystem refcount leakage
  (bsc#1237558).
- commit 17c1245
* Mon Feb 24 2025 dwagner@suse.de
- series: enabled downstream patches for storage again
- Refresh
  patches.suse/blk-kabi-add-suse_kabi_padding-to-blk-layer-structs.patch.
- Refresh
  patches.suse/nvme-tcp-do-not-terminate-commands-when-in-resetting.patch.
- Refresh
  patches.suse/scsi-kabi-add-suse_kabi_padding-to-scsi-template-structs.patch.
- commit 152726d
* Mon Feb 24 2025 nik.borisov@suse.com
- x86/cpu/kvm: SRSO: Fix possible missing IBPB on VM-Exit (git-fixes).
- commit 37d1575
* Sun Feb 23 2025 lduncan@suse.com
- md/raid5: Wait sync io to finish before changing group cnt
  (git-fixes).
- md/md-bitmap: Add missing destroy_work_on_stack() (git-fixes).
- commit fd1221e
* Sat Feb 22 2025 tiwai@suse.de
- mtd: rawnand: cadence: fix unchecked dereference (git-fixes).
- commit f57c089
* Sat Feb 22 2025 tiwai@suse.de
- soc: loongson: loongson2_guts: Add check for devm_kstrdup()
  (git-fixes).
- firmware: arm_scmi: imx: Correct tx size of
  scmi_imx_misc_ctrl_set (git-fixes).
- platform: cznic: CZNIC_PLATFORMS should depend on ARCH_MVEBU
  (git-fixes).
- drm/msm/dsi/phy: Do not overwite PHY_CMN_CLK_CFG1 when choosing
  bitclk source (git-fixes).
- drm/msm/dsi/phy: Protect PHY_CMN_CLK_CFG1 against clock driver
  (git-fixes).
- drm/msm/dsi/phy: Protect PHY_CMN_CLK_CFG0 updated from driver
  side (git-fixes).
- drm/msm/dpu: Don't leak bits_per_component into random DSC_ENC
  fields (git-fixes).
- drm/msm/dpu: Disable dither in phys encoder cleanup (git-fixes).
- drm/msm/dpu: enable DPU_WB_INPUT_CTRL for DPU 5.x (git-fixes).
- drm/msm/dpu: skip watchdog timer programming through TOP on >=
  SM8450 (git-fixes).
- drm/msm: Avoid rounding up to one jiffy (git-fixes).
- drm/i915/ddi: Fix HDMI port width programming in DDI_BUF_CTL
  (git-fixes).
- drm/i915/gt: Use spin_lock_irqsave() in interruptible context
  (git-fixes).
- drm/nouveau/pmu: Fix gp10b firmware guard (git-fixes).
- nouveau/svm: fix missing folio unlock + put after
  make_device_exclusive_range() (git-fixes).
- drm: panel: jd9365da-h3: fix reset signal polarity (git-fixes).
- mtd: spi-nor: sst: Fix SST write failure (git-fixes).
- mtd: rawnand: cadence: fix incorrect device in dma_unmap_single
  (git-fixes).
- mtd: rawnand: cadence: use dma_map_resource for sdma address
  (git-fixes).
- mtd: rawnand: cadence: fix error code in cadence_nand_init()
  (git-fixes).
- drm/amdgpu: avoid buffer overflow attach in
  smu_sys_set_pp_table() (stable-fixes).
- fbdev: omap: use threaded IRQ for LCD DMA (stable-fixes).
- commit b47b393
* Fri Feb 21 2025 tiwai@suse.de
- Move upstreamed sound patch into sorted section
- commit 9c8581a
* Fri Feb 21 2025 mfranc@suse.cz
- s390/ism: add release function for struct device (git-fixes
  bsc#1237494).
- commit 040e6ac
* Fri Feb 21 2025 iivanov@suse.de
- supported.conf: Make pca9450 and btnxpuart drivers supported (jsc#PED-12016)
- commit 4bd4eef
* Fri Feb 21 2025 tiwai@suse.de
- power: supply: axp20x_battery: Fix fault handling for AXP717
  (git-fixes).
- power: supply: da9150-fg: fix potential overflow (git-fixes).
- commit 9a75ead
* Thu Feb 20 2025 vkarasulli@suse.de
- iommu/amd: Fix corruption when mapping large pages from 0
  (stable-fixes).
- iommu/tegra241-cmdqv: Fix unused variable warning
  (stable-fixes).
- iommu/io-pgtable-arm: Fix stage-2 map/unmap for concatenated
  tables (stable-fixes).
- commit dc2d748
* Thu Feb 20 2025 mgorman@suse.de
- sched/fair: Refactor can_migrate_task() to elimate looping
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/eevdf: Force propagating min_slice of cfs_rq when
  {en,de}queue tasks (bsc#1234634 (Scheduler functional and
  performance backports)).
- sched: Don't define sched_clock_irqtime as static key
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched: Reduce the default slice to avoid tasks getting an
  extra tick (bsc#1234634 (Scheduler functional and performance
  backports)).
- sched: Cancel the slice protection of the idle entity
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched: Clarify wake_up_q()'s write to task->wake_q.next
  (bsc#1234634 (Scheduler functional and performance backports)).
- commit 4c4449a
* Thu Feb 20 2025 oneukum@suse.com
- net: qcom/emac: Find sgmii_ops by device_for_each_child()
  (jsc#PED-10906).
- commit a0954d0
* Thu Feb 20 2025 oneukum@suse.com
- libnvdimm: Replace namespace_match() with
  device_find_child_by_name() (jsc#PED-10906).
- commit 9effb4f
* Thu Feb 20 2025 oneukum@suse.com
- driver core: Constify API device_find_child() and adapt for
  various usages (jsc#PED-10906).
- commit ce62ef8
* Thu Feb 20 2025 tiwai@suse.de
- PCI: Use downstream bridges for distributing resources
  (bsc#1237325).
- commit ac1a584
* Thu Feb 20 2025 tiwai@suse.de
- drm/i915: Drop 64bpp YUV formats from ICL+ SDR planes
  (stable-fixes).
- Revert "drm/amd/display: Use HW lock mgr for PSR1"
  (stable-fixes).
- drm/amdkfd: only flush the validate MES contex (stable-fixes).
- drm/amd/pm: Mark MM activity as unsupported (stable-fixes).
- drm/modeset: Handle tiled displays in pan_display_atomic
  (stable-fixes).
- drm/amd/display: Fix Mode Cutoff in DSC Passthrough to DP2.1
  Monitor (stable-fixes).
- drm/bridge: it6505: fix HDCP CTS KSV list wait timer
  (stable-fixes).
- drm/bridge: it6505: fix HDCP CTS compare V matching
  (stable-fixes).
- drm/bridge: it6505: fix HDCP encryption when R0 ready
  (stable-fixes).
- drm/bridge: it6505: fix HDCP Bstatus check (stable-fixes).
- drm/bridge: it6505: Change definition MAX_HDCP_DOWN_STREAM_COUNT
  (stable-fixes).
- drm/virtio: New fence for every plane update (stable-fixes).
- commit 615893a
* Thu Feb 20 2025 msuchanek@suse.de
- Fix conditional for selecting gcc-13
  Fixes: 51dacec21eb1 ("Use gcc-13 for build on SLE16 (jsc#PED-10028).")
- commit 07542ae
* Thu Feb 20 2025 tiwai@suse.de
- kasan: don't call find_vm_area() in a PREEMPT_RT kernel
  (git-fixes).
- lib/iov_iter: fix import_iovec_ubuf iovec management
  (git-fixes).
- kasan: make kasan_record_aux_stack_noalloc() the default
  behaviour (git-fixes).
- commit 0d9c641
* Thu Feb 20 2025 iivanov@suse.de
- dt-bindings: clock: sunxi: Export PLL_VIDEO_2X and PLL_MIPI (git-fixes)
- commit 0a7858b
* Thu Feb 20 2025 iivanov@suse.de
- arm64: dts: allwinner: a64: explicitly assign clock parent for TCON0 (git-fixes)
- commit 9135ee4
* Thu Feb 20 2025 iivanov@suse.de
- KVM: arm64: Unconditionally save+flush host FPSIMD/SVE/SME state (git-fixes)
- commit faef568
* Thu Feb 20 2025 iivanov@suse.de
- arm64: cacheinfo: Avoid out-of-bounds write to cacheinfo array (git-fixes)
- commit 10a9960
* Thu Feb 20 2025 iivanov@suse.de
- arm64: Handle .ARM.attributes section in linker scripts (git-fixes)
- commit f30d30c
* Thu Feb 20 2025 iivanov@suse.de
- arm64: dts: imx93: Use IMX93_CLK_SPDIF_IPG as SPDIF IPG clock (git-fixes)
- commit 45bf054
* Wed Feb 19 2025 tbogendoerfer@suse.de
- idpf: call set_real_num_queues in idpf_open (bsc#1236661
  bsc#1237316).
- commit 038664b
* Wed Feb 19 2025 oneukum@suse.com
- driver core: Introduce an device matching API
  device_match_type() (jsc#PED-10906).
- commit 9f68205
* Wed Feb 19 2025 oneukum@suse.com
- driver core: Put device attribute @wakeup_last_time_ms and
  its show() together (jsc#PED-10906).
- commit 0ab8f11
* Wed Feb 19 2025 oneukum@suse.com
- cacheinfo: Don't opencode per_cpu_cacheinfo() (jsc#PED-10906).
- commit e469790
* Wed Feb 19 2025 oneukum@suse.com
- drivers/base: Remove unused auxiliary_find_device
  (jsc#PED-10906).
- commit e7ed3d1
* Wed Feb 19 2025 oneukum@suse.com
- driver core: Add device probe log helper dev_warn_probe()
  (jsc#PED-10906).
- commit e646f4e
* Wed Feb 19 2025 oneukum@suse.com
- regmap-irq: Consistently use memset32() in regmap_irq_thread()
  (jsc#PED-10906).
- commit e64a63b
* Wed Feb 19 2025 oneukum@suse.com
- usb: typec: class: Remove both cable_match() and partner_match()
  (jsc#PED-10906).
- commit e1bfd88
* Wed Feb 19 2025 ykaukab@suse.de
- sysctl: update common tuning parameters for SAP workloads
  References: jsc#PED-11670
- commit 86d9b06
* Wed Feb 19 2025 ykaukab@suse.de
- config: set selinux as defautl lsm
  References: jsc#PED-12021
  Clear CONFIG_DEFAULT_SECURITY_APPARMOR=y
- commit ad8cf6a
* Wed Feb 19 2025 ykaukab@suse.de
- config: update configs using run_oldconfig.sh
  Mainly cleanup of TOMOYO configs after following commit:
  08c6cff34064 Update config files: disable tomoyo lsm (jsc#PED-12020)
- commit 6d8067f
* Wed Feb 19 2025 iivanov@suse.de
- supported.conf: Add more iMX93 modules to supported list (jsc#PED-12016)
- supported.conf: Make few iMX93 modules supported (jsc#PED-12016)
- commit 8472ab7
* Wed Feb 19 2025 iivanov@suse.de
- i2c: imx-lpi2c: select CONFIG_I2C_SLAVE (git-fixes)
- commit 9775c66
* Wed Feb 19 2025 osalvador@suse.de
- Update
  patches.suse/cachestat-fix-page-cache-statistics-permission-check.patch
  (CVE-2025-21691 bsc#1237026).
- commit 77a27c3
* Wed Feb 19 2025 oneukum@suse.com
- usb: typec: Print err when displayport fails to enter
  (jsc#PED-10603).
- commit ca6631e
* Wed Feb 19 2025 oneukum@suse.com
- usb: typec: Make active on port altmode writable
  (jsc#PED-10603).
- commit eeb0401
* Wed Feb 19 2025 oneukum@suse.com
- usb: typec: Add driver for Thunderbolt 3 Alternate Mode
  (jsc#PED-10603).
- commit 4279597
* Wed Feb 19 2025 jgross@suse.com
- KVM: arm64: Fix alignment of kvm_hyp_memcache allocations
  (git-fixes).
- commit cd5d95b
* Wed Feb 19 2025 jgross@suse.com
- KVM: arm64: Fix nested S2 MMU structures reallocation
  (git-fixes).
- commit b5739e1
* Wed Feb 19 2025 oneukum@suse.com
- usb: typec: tcpm: Add new AMS for Get_Revision response
  (jsc#PED-10906).
- commit 0dc07bd
* Wed Feb 19 2025 jslaby@suse.cz
- PCI: microchip: Add support for using either Root Port 1 or 2
  (git-fixes).
- Refresh
  patches.suse/PCI-microchip-Set-inbound-address-translation-for-co.patch.
- commit a34fcbd
* Wed Feb 19 2025 jgross@suse.com
- KVM: arm64: Flush hyp bss section after initialization of
  variables in bss (git-fixes).
- commit aaf5efb
* Wed Feb 19 2025 oneukum@suse.com
- usb: typec: tcpm: Add support for parsing pd-revision DT
  property (jsc#PED-10906).
- commit 3e2e05e
* Wed Feb 19 2025 oneukum@suse.com
- usb: typec: tcpm: Add support for sink-bc12-completion-time-ms
  DT property (jsc#PED-10906).
- commit fc6e26e
* Wed Feb 19 2025 jgross@suse.com
- KVM: arm64: vgic-its: Add error handling in
  vgic_its_cache_translation (git-fixes).
- commit c94c6dc
* Wed Feb 19 2025 jgross@suse.com
- KVM: arm64: Do not allow ID_AA64MMFR0_EL1.ASIDbits to be
  overridden (git-fixes).
- commit 452d1e3
* Wed Feb 19 2025 oneukum@suse.com
- usb: typec: tcpm: Add support for parsing time dt properties
  (jsc#PED-10906).
- commit 4bcea43
* Wed Feb 19 2025 jgross@suse.com
- KVM: arm64: Fix S1/S2 combination when FWB==1 and S2 has Device
  memory type (git-fixes).
- commit b033aa6
* Wed Feb 19 2025 oneukum@suse.com
- usb: typec: stusb160x: Make use of i2c_get_match_data()
  (jsc#PED-10906).
- commit bd20d7d
* Wed Feb 19 2025 oneukum@suse.com
- usb: typec: Fix typo in comment (jsc#PED-10906).
- commit 3f9d1f1
* Wed Feb 19 2025 jgross@suse.com
- KVM: arm64: Ignore PMCNTENSET_EL0 while checking for overflow
  status (git-fixes).
- commit dcc3c1a
* Wed Feb 19 2025 jgross@suse.com
- KVM: arm64: vgic-v3: Sanitise guest writes to GICR_INVLPIR
  (git-fixes).
- commit 817c4c3
* Wed Feb 19 2025 oneukum@suse.com
- usb: phy: Remove API devm_usb_put_phy() (jsc#PED-10906).
- commit a4eae2b
* Wed Feb 19 2025 oneukum@suse.com
- usb: quirks: Add NO_LPM quirk for TOSHIBA TransMemory-Mx device
  (git-fixes).
- commit eef2b55
* Wed Feb 19 2025 jgross@suse.com
- KVM: arm64: Correctly access TCR2_EL1, PIR_EL1, PIRE0_EL1 with
  VHE (git-fixes).
- commit ec41dc1
* Wed Feb 19 2025 jgross@suse.com
- KVM: x86: Load DR6 with guest value only before entering
  .vcpu_run() loop (git-fixes).
- commit 4a7679b
* Wed Feb 19 2025 jgross@suse.com
- KVM: nSVM: Enter guest mode before initializing nested NPT MMU
  (git-fixes).
- commit a57f140
* Wed Feb 19 2025 jgross@suse.com
- KVM: x86: Avoid double RDPKRU when loading host/guest PKRU
  (git-fixes).
- commit 9f1de37
* Wed Feb 19 2025 jgross@suse.com
- KVM: x86: Zero out PV features cache when the CPUID leaf is
  not present (git-fixes).
- commit e7655b9
* Wed Feb 19 2025 oneukum@suse.com
- USB: Replace own str_plural with common one (jsc#PED-10906).
- commit 78aa90a
* Wed Feb 19 2025 jgross@suse.com
- KVM: x86: Account for KVM-reserved CR4 bits when passing
  through CR4 on VMX (git-fixes).
- commit 72969c6
* Wed Feb 19 2025 tiwai@suse.de
- ALSA: hda/conexant: Add quirk for HP ProBook 450 G4 mute LED
  (stable-fixes).
- commit 70602b0
* Wed Feb 19 2025 tiwai@suse.de
- ALSA: seq: Drop UMP events when no UMP-conversion is set
  (git-fixes).
- ALSA: hda/cirrus: Correct the full scale volume set logic
  (git-fixes).
- ALSA: hda: Add error check for snd_ctl_rename_id() in
  snd_hda_create_dig_out_ctls() (git-fixes).
- ASoC: imx-audmix: remove cpu_mclk which is from cpu dai device
  (git-fixes).
- ASoC: SOF: pcm: Clear the susbstream pointer to NULL on close
  (git-fixes).
- ASoC: SOF: stream-ipc: Check for cstream nullity in
  sof_ipc_msg_data() (git-fixes).
- ASoC: SOF: ipc4-topology: Harden loops for looking up ALH
  copiers (git-fixes).
- ASoC: rockchip: i2s-tdm: fix shift config for
  SND_SOC_DAIFMT_DSP_[AB] (git-fixes).
- ASoC: fsl_micfil: Enable default case in micfil_set_quality()
  (git-fixes).
- ALSA: hda/realtek: Fixup ALC225 depop procedure (git-fixes).
- commit 5049122
* Wed Feb 19 2025 jgross@suse.com
- KVM: VMX: Fix comment of handle_vmx_instruction() (git-fixes).
- commit 34e0912
* Wed Feb 19 2025 jgross@suse.com
- KVM: VMX: Allow toggling bits in MSR_IA32_RTIT_CTL when enable
  bit is cleared (git-fixes).
- commit 8556a9f
* Wed Feb 19 2025 jgross@suse.com
- Revert "KVM: VMX: Move LOAD_IA32_PERF_GLOBAL_CTRL errata
  handling out of setup_vmcs_config()" (git-fixes).
- commit 92c9049
* Wed Feb 19 2025 jgross@suse.com
- KVM: x86: Bypass register cache when querying CPL from
  kvm_sched_out() (git-fixes).
- commit 3f985bf
* Wed Feb 19 2025 jgross@suse.com
- KVM: x86: AMD's IBPB is not equivalent to Intel's IBPB
  (git-fixes).
- commit 7344d06
* Wed Feb 19 2025 jgross@suse.com
- KVM: x86: Fix a comment inside
  __kvm_set_or_clear_apicv_inhibit() (git-fixes).
- commit c404f67
* Tue Feb 18 2025 jgross@suse.com
- vhost/net: Set num_buffers for virtio 1.0 (git-fixes).
- commit 3d87f0e
* Tue Feb 18 2025 jgross@suse.com
- s390/virtio_ccw: Fix dma_parm pointer not set up (git-fixes).
- commit 15ec5ee
* Tue Feb 18 2025 jgross@suse.com
- virtio_blk: reverse request order in virtio_queue_rqs
  (git-fixes).
- commit a91d779
* Tue Feb 18 2025 lduncan@suse.com
- zram: fix potential UAF of zram table (git-fixes).
- block: avoid to reuse `hctx` not removed from cpuhp callback
  list (git-fixes).
- block: don't verify IO lock for freeze/unfreeze in
  elevator_init_mq() (git-fixes).
- block: always verify unfreeze lock on the owner task
  (git-fixes).
- commit 16febb0
* Tue Feb 18 2025 vkarasulli@suse.de
- iommu/amd: Expicitly enable CNTRL.EPHEn bit in resume path
  (git-fixes).
- commit b2a42ed
* Tue Feb 18 2025 vkarasulli@suse.de
- iommu: Fix potential memory leak in  iopf_queue_remove_device()
  (git-fixes).
- commit 074adf0
* Tue Feb 18 2025 mfranc@suse.cz
- s390/stackleak: Use exrl instead of ex in __stackleak_poison()
  (git-fixes bsc#1237317).
- commit 4950e44
* Tue Feb 18 2025 jgross@suse.com
- x86/xen: allow larger contiguous memory regions in PV guests
  (git-fixes).
- commit 959d5ed
* Tue Feb 18 2025 jgross@suse.com
- xen/swiotlb: relax alignment requirements (git-fixes).
- commit 02c1859
* Tue Feb 18 2025 jgross@suse.com
- x86/xen: add FRAME_END to xen_hypercall_hvm() (git-fixes).
- commit f61b030
* Tue Feb 18 2025 jgross@suse.com
- x86/xen: fix xen_hypercall_hvm() to not clobber %%rbx
  (git-fixes).
- commit f11a452
* Tue Feb 18 2025 osalvador@suse.de
- Update
  patches.suse/RDMA-hns-Fix-NULL-pointer-derefernce-in-hns_roce_map.patch (CVE-2024-53226 bsc#1236576)
- Update
  patches.suse/USB-serial-quatech2-fix-null-ptr-deref-in-qt2_proces.patch (CVE-2025-21689 bsc#1237017)
- Update
  patches.suse/bpf-Call-free_htab_elem-after-htab_unlock_bucket.patch (CVE-2024-56592 bsc#1235244)
- Update
  patches.suse/bpf-Prevent-tailcall-infinite-loop-caused-by-freplac.patch (CVE-2024-47794 bsc#1235712)
- Update
  patches.suse/bpf-put-bpf_link-s-program-when-link-is-safe-to-be-d.patch (CVE-2024-56786 bsc#1235644)
- Update
  patches.suse/cachestat-fix-page-cache-statistics-permission-check.patch (CVE-2025-21691 bsc#1237026)
- Update
  patches.suse/cgroup-cpuset-remove-kernfs-active-break.patch (CVE-2025-21634 bsc#1236110)
- Update
  patches.suse/drm-amd-display-Initialize-denominator-defaults-to-1.patch (CVE-2024-57950 bsc#1237032)
- Update
  patches.suse/drm-v3d-Assign-job-pointer-to-NULL-before-signaling-.patch (CVE-2025-21688 bsc#1237007)
- Update
  patches.suse/drm-v3d-Ensure-job-pointer-is-set-to-NULL-after-job-.patch (CVE-2025-21697 bsc#1237132)
- Update
  patches.suse/gfs2-Truncate-address-space-when-flipping-GFS2_DIF_JDATA-flag.patch (CVE-2025-21699 bsc#1237139)
- Update
  patches.suse/gpio-xilinx-Convert-gpio_lock-to-raw-spinlock.patch (CVE-2025-21684 bsc#1236952)
- Update
  patches.suse/iomap-avoid-avoid-truncating-64-bit-offset-to-32-bits.patch (CVE-2025-21667 bsc#1236681)
- Update
  patches.suse/media-amphion-Set-video-drvdata-before-register-vide.patch (CVE-2024-56579 bsc#1236575)
- Update
  patches.suse/msft-hv-3155-scsi-storvsc-Ratelimit-warning-logs-to-prevent-VM-de.patch (CVE-2025-21690 bsc#1237025)
- Update
  patches.suse/pinctrl-mcp23s08-Fix-sleeping-in-atomic-context-due-.patch (CVE-2024-57889 bsc#1236573)
- Update
  patches.suse/platform-x86-dell-uart-backlight-fix-serdev-race.patch (CVE-2025-21695 bsc#1237110)
- Update
  patches.suse/platform-x86-lenovo-yoga-tab2-pro-1380-fastcharger-f.patch (CVE-2025-21685 bsc#1236953)
- Update
  patches.suse/pmdomain-imx8mp-blk-ctrl-add-missing-loop-break-cond.patch (CVE-2025-21668 bsc#1236682)
- commit 3462ac1
* Tue Feb 18 2025 davide.benini@suse.com
- bpf, sockmap: Several fixes to bpf_msg_pop_data (CVE-2024-56720
  bsc#1235592).
- commit 0185843
* Tue Feb 18 2025 davide.benini@suse.com
- net: Fix icmp host relookup triggering ip_rt_bug (CVE-2024-56647
  bsc#1235435).
- commit 49b2b74
* Tue Feb 18 2025 oneukum@suse.com
- USB: Fix the issue of task recovery failure caused by USB
  status when S4 wakes up (git-fixes).
- commit 0e001cb
* Tue Feb 18 2025 davide.benini@suse.com
- ipv6: avoid possible NULL deref in modify_prefix_route()
  (CVE-2024-56646 bsc#1235131).
- commit 5a68a13
* Tue Feb 18 2025 oneukum@suse.com
- USB: make to_usb_device_driver() use container_of_const()
  (jsc#PED-10906).
- commit 1cd52ca
* Tue Feb 18 2025 tiwai@suse.de
- drm/amd/display: Fix seamless boot sequence (stable-fixes).
- drm/amdgpu: add a BO metadata flag to disable write compression
  for Vulkan (stable-fixes).
- drm/amd/amdgpu: change the config of cgcg on gfx12
  (stable-fixes).
- drm/amdkfd: Block per-queue reset when halt_if_hws_hang=1
  (stable-fixes).
- drm/amd/display: Optimize cursor position updates
  (stable-fixes).
- drm/client: Handle tiled displays better (stable-fixes).
- ASoC: soc-pcm: don't use soc_pcm_ret() on .prepare callback
  (stable-fixes).
- clk: qcom: Make GCC_8150 depend on QCOM_GDSC (stable-fixes).
- wifi: iwlwifi: pcie: Add support for new device ids
  (stable-fixes).
- drm/amd/display: Limit Scaling Ratio on DCN3.01 (stable-fixes).
- drm/amd/display: Increase sanitizer frame larger than limit
  when compile testing with clang (stable-fixes).
- drm/amdkfd: Queue interrupt work to different CPU
  (stable-fixes).
- drm/amdgpu: Don't enable sdma 4.4.5 CTXEMPTY interrupt
  (stable-fixes).
- drm/amd/display: Overwriting dualDPP UBF values before usage
  (stable-fixes).
- drm/amd/display: Populate chroma prefetch parameters, DET
  buffer fix (stable-fixes).
- drm/vc4: hdmi: use eld_mutex to protect access to connector->eld
  (stable-fixes).
- drm/sti: hdmi: use eld_mutex to protect access to connector->eld
  (stable-fixes).
- drm/radeon: use eld_mutex to protect access to connector->eld
  (stable-fixes).
- drm/exynos: hdmi: use eld_mutex to protect access to
  connector->eld (stable-fixes).
- drm/amd/display: use eld_mutex to protect access to
  connector->eld (stable-fixes).
- drm/bridge: ite-it66121: use eld_mutex to protect access to
  connector->eld (stable-fixes).
- drm/bridge: anx7625: use eld_mutex to protect access to
  connector->eld (stable-fixes).
- drm/connector: add mutex to protect ELD from concurrent access
  (stable-fixes).
- drm/tests: hdmi: return meaningful value from
  set_connector_edid() (stable-fixes).
- drm/tests: hdmi: handle empty modes in find_preferred_mode()
  (stable-fixes).
- drm: panel-backlight-quirks: Add Framework 13 glossy and 2.8k
  panels (stable-fixes).
- drm: panel-backlight-quirks: Add Framework 13 matte panel
  (stable-fixes).
- drm: Add panel backlight quirks (stable-fixes).
- commit 88df338
* Tue Feb 18 2025 oneukum@suse.com
- USB: make to_usb_driver() use container_of_const()
  (jsc#PED-10906).
- commit 3096d5c
* Tue Feb 18 2025 oneukum@suse.com
- USB: properly lock dynamic id list when showing an id
  (jsc#PED-10906).
- commit a65f0a3
* Tue Feb 18 2025 oneukum@suse.com
- USB: core: remove dead code in do_proc_bulk() (jsc#PED-10906).
- commit f209e17
* Tue Feb 18 2025 oneukum@suse.com
- usb: core: use sysfs_emit() instead of sprintf()
  (jsc#PED-10906).
- commit 4b40393
* Tue Feb 18 2025 oneukum@suse.com
- usb: require FMODE_WRITE for usbdev_mmap() (jsc#PED-10906).
- commit 552bff1
* Tue Feb 18 2025 msuchanek@suse.de
- powerpc/code-patching: Fix KASAN hit by not flagging text
  patching area as VM_ALLOC (bsc#1215199).
- powerpc/64s: Rewrite __real_pte() and __rpte_to_hidx() as
  static inline (bsc#1215199).
- powerpc/code-patching: Disable KASAN report during patching
  via temporary mm (bsc#1215199).
- commit f5c0b81
* Mon Feb 17 2025 mgorman@suse.de
- rseq: Fix rseq unregistration regression (bsc#1234634 (Scheduler
  functional and performance backports)).
- commit d16e10a
* Mon Feb 17 2025 mgorman@suse.de
- locking/ww_mutex: Fix ww_mutex dummy lockdep map selftest
  warnings (bsc#1234634 (Scheduler functional and performance
  backports)).
- commit 7357fd9
* Mon Feb 17 2025 oneukum@suse.com
- debugfs: Fix the missing initializations in __debugfs_file_get()
  (jsc#PED-10906).
- commit a5a225f
* Mon Feb 17 2025 davide.benini@suse.com
- net: sched: Disallow replacing of child qdisc from one parent
  to another (CVE-2025-21700 bsc#1237159).
- commit 45e9f84
* Mon Feb 17 2025 oneukum@suse.com
- usb: common: expand documentation for USB functions
  (jsc#PED-10906).
- commit 5dc8ea1
* Mon Feb 17 2025 oneukum@suse.com
- USB: make single lock for all usb dynamic id lists
  (jsc#PED-10906).
- commit ca6a4cf
* Mon Feb 17 2025 davide.benini@suse.com
- pktgen: Avoid out-of-bounds access in get_imix_entries
  (CVE-2025-21680 bsc#1236700).
- commit a7a7f74
* Mon Feb 17 2025 nmorey@suse.com
- sctp: sysctl: cookie_hmac_alg: avoid using current->nsproxy (CVE-2025-21640 bsc#1236123)
- commit a4016e3
* Mon Feb 17 2025 nmorey@suse.com
- sctp: sysctl: rto_min/max: avoid using current->nsproxy (CVE-2025-21639 bsc#1236122)
- commit 3a3fa72
* Mon Feb 17 2025 nmorey@suse.com
- sctp: sysctl: auth_enable: avoid using current->nsproxy (CVE-2025-21638 bsc#1236115)
- commit 923596b
* Mon Feb 17 2025 nmorey@suse.com
- sctp: sysctl: udp_port: avoid using current->nsproxy (CVE-2025-21637 bsc#1236114)
- commit 8abdd74
* Mon Feb 17 2025 nmorey@suse.com
- sctp: sysctl: plpmtud_probe_interval: avoid using current->nsproxy (CVE-2025-21636 bsc#1236113)
- commit 19d97ab
* Mon Feb 17 2025 oneukum@suse.com
- usb: host: xhci-plat: add support compatible ID PNP0D15
  (jsc#PED-10906).
- commit e39bb0b
* Mon Feb 17 2025 oneukum@suse.com
- USB: host: Use str_enable_disable-like helpers (jsc#PED-10906).
- commit 2c7456c
* Mon Feb 17 2025 oneukum@suse.com
- xhci: don't mess with ->d_iname (jsc#PED-10906).
- commit 739b405
* Mon Feb 17 2025 oneukum@suse.com
- debugfs: allow to store an additional opaque pointer at file
  creation (jsc#PED-10906).
- commit 2324ce1
* Mon Feb 17 2025 oneukum@suse.com
- debugfs: don't mess with bits in ->d_fsdata (jsc#PED-10906).
- commit ef5509c
* Mon Feb 17 2025 oneukum@suse.com
- debugfs: get rid of dynamically allocation proxy_ops
  (jsc#PED-10906).
- commit 2205145
* Mon Feb 17 2025 oneukum@suse.com
- debugfs: move ->automount into debugfs_inode_info
  (jsc#PED-10906).
- commit 1597940
* Mon Feb 17 2025 oneukum@suse.com
- debugfs: separate cache for debugfs inodes (jsc#PED-10906).
- commit dcce65c
* Mon Feb 17 2025 oneukum@suse.com
- fs: debugfs: fix open proxy for unsafe files (jsc#PED-10906).
- commit 9dffd44
* Mon Feb 17 2025 oneukum@suse.com
- debugfs: fix missing mutex_destroy() in short_fops case
  (jsc#PED-10906).
- commit efab813
* Mon Feb 17 2025 oneukum@suse.com
- fs: debugfs: differentiate short fops with proxy ops
  (jsc#PED-10906).
- commit dae3000
* Mon Feb 17 2025 oneukum@suse.com
- debugfs: add small file operations for most files
  (jsc#PED-10906).
- commit c4f473c
* Mon Feb 17 2025 oneukum@suse.com
- xhci: Add missing capability definition bits (jsc#PED-10906).
- commit 7f85c83
* Mon Feb 17 2025 oneukum@suse.com
- xhci: Add command completion parameter support (jsc#PED-10906).
- commit 946ecb2
* Mon Feb 17 2025 oneukum@suse.com
- xhci: dbgtty: Improve performance by handling received data
  immediately (jsc#PED-10906).
- commit 61c0ac1
* Mon Feb 17 2025 oneukum@suse.com
- xhci: dbc: Improve performance by removing delay in transfer
  event polling (jsc#PED-10906).
- commit 6fb9745
* Mon Feb 17 2025 oneukum@suse.com
- usb: cdns3: Synchronise PCI IDs via common data base
  (jsc#PED-10906).
- commit d047513
* Mon Feb 17 2025 oneukum@suse.com
- usb: xhci: remove irrelevant comment (jsc#PED-10906).
- commit 3e95364
* Mon Feb 17 2025 oneukum@suse.com
- usb: xhci: add help function xhci_dequeue_td() (jsc#PED-10906).
- commit b370f56
* Mon Feb 17 2025 mfranc@suse.cz
- s390/pci: Fix handling of isolated VFs (git-fixes bsc#1237252).
- commit 09fc7a2
* Mon Feb 17 2025 mfranc@suse.cz
- s390/pci: Pull search for parent PF out of
  zpci_iov_setup_virtfn() (git-fixes bsc#1237251).
- commit 54c32f5
* Mon Feb 17 2025 msuchanek@suse.de
- Use gcc-13 for build on SLE16 (jsc#PED-10028).
- commit 51dacec
* Mon Feb 17 2025 tiwai@suse.de
- usb: xhci: Restore xhci_pci support for Renesas HCs (git-fixes).
- commit c96fec0
* Mon Feb 17 2025 tiwai@suse.de
- kbuild: userprogs: fix bitsize and target detection on clang
  (git-fixes).
- tools: fix annoying "mkdir -p ..." logs when building tools
  in parallel (git-fixes).
- serial: 8250: Fix fifo underflow on flush (git-fixes).
- serial: port: Always update ->iotype in __uart_read_properties()
  (git-fixes).
- serial: port: Assign ->iotype correctly when ->iobase is set
  (git-fixes).
- usb: roles: set switch registered flag early on (git-fixes).
- usb: gadget: core: flush gadget workqueue after device removal
  (git-fixes).
- USB: gadget: f_midi: f_midi_complete to call queue_work
  (git-fixes).
- usb: core: fix pipe creation for get_bMaxPacketSize0
  (git-fixes).
- usb: dwc3: Fix timeout issue during controller enter/exit from
  halt state (git-fixes).
- USB: cdc-acm: Fill in Renesas R-Car D3 USB Download mode quirk
  (git-fixes).
- usb: cdc-acm: Fix handling of oversized fragments (git-fixes).
- usb: cdc-acm: Check control transfer buffer size before access
  (git-fixes).
- usb: gadget: f_midi: fix MIDI Streaming descriptor lengths
  (git-fixes).
- usb: dwc2: gadget: remove of_node reference upon udc_stop
  (git-fixes).
- usb: gadget: udc: renesas_usb3: Fix compiler warning
  (git-fixes).
- usb: gadget: f_midi: Fixing wMaxPacketSize exceeded issue
  during MIDI bind retries (git-fixes).
- commit 3893a99
* Sun Feb 16 2025 lduncan@suse.com
- block: copy back bounce buffer to user-space correctly in case
  of split (git-fixes).
- partitions: ldm: remove the initial kernel-doc notation
  (git-fixes).
- block, bfq: fix waker_bfqq UAF after bfq_split_bfqq()
  (git-fixes).
- zram: fix uninitialized ZRAM not releasing backing device
  (git-fixes).
- zram: refuse to use zero sized block device as backing device
  (git-fixes).
- blk-iocost: Avoid using clamp() on inuse in
  __propagate_weights() (git-fixes).
- block: get wp_offset by bdev_offset_from_zone_start (git-fixes).
- block: Prevent potential deadlocks in zone write plug error
  recovery (git-fixes).
- commit 4b28019
* Sun Feb 16 2025 tiwai@suse.de
- objtool/rust: add one more `noreturn` Rust function (git-fixes).
- gpiolib: Fix crash on error in gpiochip_get_ngpios()
  (git-fixes).
- gpio: stmpe: Check return value of stmpe_reg_read in
  stmpe_gpio_irq_sync_unlock (git-fixes).
- gpio: bcm-kona: Add missing newline to dev_err format string
  (git-fixes).
- gpio: bcm-kona: Make sure GPIO bits are unlocked when requesting
  IRQ (git-fixes).
- gpio: bcm-kona: Fix GPIO lock/unlock for banks above bank 0
  (git-fixes).
- commit 218f1c3
* Sat Feb 15 2025 lduncan@suse.com
- block: don't update BLK_FEAT_POLL in
  __blk_mq_update_nr_hw_queues (git-fixes).
- block: check BLK_FEAT_POLL under q_usage_count (git-fixes).
- nbd: don't allow reconnect after disconnect (git-fixes).
- ps3disk: Do not use dev->bounce_size before it is set
  (git-fixes).
- block: retry call probe after request_module in
  blk_request_module (git-fixes).
- dm: Fix dm-zoned-reclaim zone write pointer alignment
  (git-fixes).
- commit 7d6f0ed
* Sat Feb 15 2025 tiwai@suse.de
- PCI: Avoid FLR for Mediatek MT7922 WiFi (git-fixes).
- mmc: mtk-sd: Fix register settings for hs400(es) mode
  (git-fixes).
- commit 7643768
* Sat Feb 15 2025 lduncan@suse.com
- block: Ignore REQ_NOWAIT for zone reset and zone finish
  operations (git-fixes).
- block: Use a zone write plug BIO work for REQ_NOWAIT BIOs
  (git-fixes).
- blk-mq: move cpuhp callback registering out of q->sysfs_lock
  (git-fixes).
- blk-mq: register cpuhp callback after hctx is added to xarray
  table (git-fixes).
- brd: decrease the number of allocated pages which discarded
  (git-fixes).
- block: Don't allow an atomic write be truncated in
  blkdev_write_iter() (git-fixes).
- block: Prevent potential deadlock in blk_revalidate_disk_zones()
  (git-fixes).
- ublk: fix error code for unsupported command (git-fixes).
- block: return unsigned int from bdev_io_min (git-fixes).
- blk-settings: round down io_opt to physical_block_size
  (git-fixes).
- zram: ZRAM_DEF_COMP should depend on ZRAM (git-fixes).
- zram: clear IDLE flag in mark_idle() (git-fixes).
- zram: clear IDLE flag after recompression (git-fixes).
- zram: do not mark idle slots that cannot be idle (git-fixes).
- block: lift bio_is_zone_append to bio.h (git-fixes).
- block: fix bio_split_rw_at to take zone_write_granularity into
  account (git-fixes).
- block: take chunk_sectors into account in bio_split_write_zeroes
  (git-fixes).
- ublk: fix ublk_ch_mmap() for 64K page size (git-fixes).
- loop: fix type of block size (git-fixes).
- block: Switch to using refcount_t for zone write plugs
  (git-fixes).
- commit df002cc
* Fri Feb 14 2025 lduncan@suse.com
- block: model freeze & enter queue as lock for supporting lockdep
  (git-fixes).
- Refresh
  patches.suse/block-fix-uaf-for-flush-rq-while-iterating-tags.patch.
- commit da1d6bf
* Fri Feb 14 2025 lduncan@suse.com
- blk-mq: add non_owner variant of start_freeze/unfreeze queue
  APIs (git-fixes).
- Refresh
  patches.suse/blk-mq-add-number-of-queue-calc-helper.patch.
- Refresh
  patches.suse/blk-mq-introduce-blk_mq_map_hw_queues.patch.
- commit 1793948
* Fri Feb 14 2025 lduncan@suse.com
- blk-mq: Make blk_mq_quiesce_tagset() hold the tag list mutex
  less long (git-fixes).
- block: fix ordering between checking BLK_MQ_S_STOPPED request
  adding (git-fixes).
- block: fix ordering between checking QUEUE_FLAG_QUIESCED
  request adding (git-fixes).
- block: fix missing dispatching request when queue is started
  or unquiesced (git-fixes).
- Revert "blk-throttle: Fix IO hang for a corner case"
  (git-fixes).
- fs/block: Check for IOCB_DIRECT in generic_atomic_write_valid()
  (git-fixes).
- block/fs: Pass an iocb to generic_atomic_write_valid()
  (git-fixes).
- commit 18a317b
* Fri Feb 14 2025 tiwai@suse.de
- drm/xe/client: bo->client does not need bos_lock (git-fixes).
- drm/i915/selftests: avoid using uninitialized context
  (git-fixes).
- drm/amdgpu: bail out when failed to load fw in
  psp_init_cap_microcode() (git-fixes).
- amdkfd: properly free gang_ctx_bo when failed to init user queue
  (git-fixes).
- drm: Fix DSC BPP increment decoding (git-fixes).
- gpu: host1x: Fix a use of uninitialized mutex (git-fixes).
- drm/tests: hdmi: Fix WW_MUTEX_SLOWPATH failures (git-fixes).
- spi: sn-f-ospi: Fix division by zero (git-fixes).
- regmap-irq: Add missing kfree() (git-fixes).
- Bluetooth: btintel_pcie: Fix a potential race condition
  (git-fixes).
- batman-adv: fix panic during interface removal (git-fixes).
- can: rockchip: rkcanfd_handle_rx_fifo_overflow_int(): bail
  out if skb cannot be allocated (git-fixes).
- can: etas_es58x: fix potential NULL pointer dereference on
  udev->serial (git-fixes).
- can: c_can: fix unbalanced runtime PM disable in error path
  (git-fixes).
- can: ctucanfd: handle skb allocation failure (git-fixes).
- can: j1939: j1939_sk_send_loop(): fix unable to send messages
  with data length zero (git-fixes).
- Documentation/networking: fix basic node example document ISO
  15765-2 (git-fixes).
- wifi: ath12k: fix handling of 6 GHz rules (git-fixes).
- ax25: Fix refcount leak caused by setting SO_BINDTODEVICE
  sockopt (git-fixes).
- commit c1eb6bd
* Fri Feb 14 2025 lduncan@suse.com
- scsi: mpt3sas: Set ioc->manu_pg11.EEDPTagMode directly to 1
  (git-fixes).
- commit 57032e5
* Fri Feb 14 2025 lduncan@suse.com
- scsi: sg: Enable runtime power management (git-fixes).
- Refresh
  patches.suse/scsi-sg-Fix-slab-use-after-free-read-in-sg_release.patch.
- commit 234612c
* Thu Feb 13 2025 lduncan@suse.com
- scsi: core: Do not retry I/Os during depopulation (git-fixes).
- scsi: mpi3mr: Fix possible crash when setting up bsg fails
  (git-fixes).
- scsi: st: Don't set pos_unknown just after device recognition
  (git-fixes).
- scsi: myrb: Remove dead code (git-fixes).
- scsi: qla2xxx: Move FCE Trace buffer allocation to user control
  (git-fixes).
- scsi: iscsi: Fix redundant response for
  ISCSI_UEVENT_GET_HOST_STATS request (git-fixes).
- scsi: core: Fix command pass through retry regression
  (git-fixes).
- scsi: scsi_debug: Fix hrtimer support for ndelay (git-fixes).
- scsi: mpi3mr: Handling of fault code for insufficient power
  (git-fixes).
- scsi: mpi3mr: Start controller indexing from 0 (git-fixes).
- scsi: mpi3mr: Synchronize access to ioctl data buffer
  (git-fixes).
- scsi: qla1280: Fix hw revision numbering for ISP1020/1040
  (git-fixes).
- scsi: st: Add MTIOCGET and MTLOAD to ioctls allowed after
  device reset (git-fixes).
- scsi: st: Don't modify unknown block number in MTIOCGET
  (git-fixes).
- scsi: hisi_sas: Enable all PHYs that are not disabled by user
  during controller reset (git-fixes).
- commit 73a1130
* Thu Feb 13 2025 mgorman@suse.de
- sched/debug: Provide slice length for fair tasks (bsc#1234634
  (Scheduler functional and performance backports)).
- sched/fair: Fix inaccurate h_nr_runnable accounting with
  delayed dequeue (bsc#1234634 (Scheduler functional and
  performance backports)).
- lazy tlb: fix hotplug exit race with MMU_LAZY_TLB_SHOOTDOWN
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched_ext: Use str_enabled_disabled() helper in
  update_selcpu_topology() (bsc#1234634 (Scheduler functional
  and performance backports)).
- sched_ext: Use sizeof_field for key_len in dsq_hash_params
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched_ext: Use the NUMA scheduling domain for NUMA optimizations
  (bsc#1234634 (Scheduler functional and performance backports)).
- torture: Add dowarn argument to torture_sched_setaffinity()
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/core: Prioritize migrating eligible tasks in
  sched_balance_rq() (bsc#1234634 (Scheduler functional and
  performance backports)).
- rseq: Validate read-only fields under DEBUG_RSEQ config
  (bsc#1234634 (Scheduler functional and performance backports)).
- lockdep: Move lockdep_assert_locked() under #ifdef
  CONFIG_PROVE_LOCKING (bsc#1234634 (Scheduler functional and
  performance backports)).
- lockdep: Mark chain_hlock_class_idx() with __maybe_unused
  (bsc#1234634 (Scheduler functional and performance backports)).
- lockdep: Document MAX_LOCKDEP_CHAIN_HLOCKS calculation
  (bsc#1234634 (Scheduler functional and performance backports)).
- locking/ww_mutex/test: Use swap() macro (bsc#1234634 (Scheduler
  functional and performance backports)).
- sched/wake_q: Add helper to call wake_up_q after unlock with
  preemption disabled (bsc#1234634 (Scheduler functional and
  performance backports)).
- exec: Make sure task->comm is always NUL-terminated (bsc#1234634
  (Scheduler functional and performance backports)).
- sched_ext: initialize kit->cursor.flags (bsc#1234634 (Scheduler
  functional and performance backports)).
- locking/rtmutex: Make sure we wake anything on the wake_q
  when we release the lock->wait_lock (bsc#1234634 (Scheduler
  functional and performance backports)).
- locking: rtmutex: Fix wake_q logic in task_blocks_on_rt_mutex
  (bsc#1234634 (Scheduler functional and performance backports)).
- posix-timers: Cure si_sys_private race (bsc#1234634 (Scheduler
  functional and performance backports)).
- locking/mutex: Expose __mutex_owner() (bsc#1234634 (Scheduler
  functional and performance backports)).
- locking/mutex: Make mutex::wait_lock irq safe (bsc#1234634
  (Scheduler functional and performance backports)).
- locking/mutex: Remove wakeups from under mutex::wait_lock
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched: remove unused __HAVE_THREAD_FUNCTIONS hook support
  (bsc#1234634 (Scheduler functional and performance backports)).
- locking/osq_lock: Use atomic_try_cmpxchg_release() in
  osq_unlock() (bsc#1234634 (Scheduler functional and performance
  backports)).
- locking/rtmutex: Fix misleading comment (bsc#1234634 (Scheduler
  functional and performance backports)).
- locking/pvqspinlock: Convert fields of 'enum vcpu_state' to
  uppercase (bsc#1234634 (Scheduler functional and performance
  backports)).
- lockdep: Use info level for lockdep initial info messages
  (bsc#1234634 (Scheduler functional and performance backports)).
- lockdep: Add lockdep_cleanup_dead_cpu() (bsc#1234634 (Scheduler
  functional and performance backports)).
- locking/ww_mutex: Adjust to lockdep nest_lock requirements
  (bsc#1234634 (Scheduler functional and performance backports)).
- commit 75dae08
* Thu Feb 13 2025 oneukum@suse.com
- usb: xhci: fix ring expansion regression in 6.13-rc1
  (jsc#PED-10906).
- commit 2b24cc0
* Thu Feb 13 2025 mfranc@suse.cz
- Update
  patches.suse/s390-debug-Pass-in-and-enforce-output-buffer-size-for-format-handlers.patch
  (git-fixes bsc#1234755 jsc#PED-11161).
- commit 5e23e2a
* Thu Feb 13 2025 mfranc@suse.cz
- s390/pci: Add pci_msg debug view to PCI report (jsc#PED-11161).
- s390/debug: Add a reverse mode for debug_dump() (jsc#PED-11161).
- s390/debug: Add debug_dump() to write debug view to a string
  buffer (jsc#PED-11161).
- s390/debug: Split private data alloc/free out of file operations
  (jsc#PED-11161).
- s390/debug: Simplify and document debug_next_entry() logic
  (jsc#PED-11161).
- s390/pci: Report PCI error recovery results via SCLP
  (jsc#PED-11161).
- commit d92d766
* Thu Feb 13 2025 mfranc@suse.cz
- s390/diag: Move diag.c to diag specific folder (jsc#PED-12044).
- s390/diag324: Retrieve power readings via diag 0x324
  (jsc#PED-12044).
- s390/diag: Create misc device /dev/diag (jsc#PED-12044).
- commit 21143cc
* Thu Feb 13 2025 oneukum@suse.com
- usb: xhci: refactor xhci_td_cleanup() to return void
  (jsc#PED-10906).
- commit 60cb49d
* Thu Feb 13 2025 oneukum@suse.com
- usb: xhci: remove unused arguments from td_to_noop()
  (jsc#PED-10906).
- commit 17866c8
* Thu Feb 13 2025 oneukum@suse.com
- usb: xhci: improve xhci_clear_command_ring() (jsc#PED-10906).
- commit 9f64dbb
* Thu Feb 13 2025 oneukum@suse.com
- usb: xhci: request MSI/-X according to requested amount
  (jsc#PED-10906).
- commit 8cf7b56
* Thu Feb 13 2025 oneukum@suse.com
- usb: xhci: move link TRB quirk to xhci_gen_setup()
  (jsc#PED-10906).
- commit 1d53caf
* Thu Feb 13 2025 oneukum@suse.com
- usb: xhci: simplify TDs start and end naming scheme in struct
  'xhci_td' (jesc#PED-10906).
- commit 5eda71a
* Thu Feb 13 2025 oneukum@suse.com
- xhci: pci: Fix indentation in the PCI device ID definitions
  (jsc#PED-10906).
- commit 9679ec8
* Thu Feb 13 2025 mfranc@suse.cz
- s390x config: enable vertical CPU polarization by default (jsc#PED-10331)
- commit 41d6235
* Thu Feb 13 2025 oneukum@suse.com
- xhci: pci: Use standard pattern for device IDs (jsc#PED-10906).
- commit 3ae969e
* Thu Feb 13 2025 oneukum@suse.com
- usb: xhci: add xhci_initialize_ring_segments() (jsc#PED-10906).
- commit 576f71b
* Thu Feb 13 2025 oneukum@suse.com
- usb: xhci: rework xhci_link_segments() (jsc#PED-10906).
- commit 13e18a0
* Thu Feb 13 2025 oneukum@suse.com
- usb: xhci: refactor xhci_link_rings() to use source and
  destination rings (jsc#PED-10906).
- commit 90c0bd4
* Thu Feb 13 2025 oneukum@suse.com
- usb: xhci: rework xhci_free_segments_for_ring() (jsc#PED-10906).
- commit 93a58c0
* Thu Feb 13 2025 oneukum@suse.com
- usb: xhci: adjust xhci_alloc_segments_for_ring() arguments
  (jsc#PED-10906).
- commit 0ce1882
* Thu Feb 13 2025 oneukum@suse.com
- usb: xhci: remove option to change a default ring's TRB cycle
  bit (jsc#PED-10906).
- commit 0379d4e
* Thu Feb 13 2025 oneukum@suse.com
- usb: xhci: introduce macro for ring segment list iteration
  (jsc#PED-10906).
- commit 2fdef8c
* Thu Feb 13 2025 oneukum@suse.com
- xhci: debugfs: Add virt endpoint state to xhci debugfs
  (jsc#PED-10906).
- commit 9e1a656
* Thu Feb 13 2025 oneukum@suse.com
- xhci: trace stream context at Set TR Deq command completion
  (jsc#PED-10906).
- Refresh
  patches.suse/usb-xhci-Fix-TD-invalidation-under-pending-Set-TR-De.patch.
- commit b9965d9
* Thu Feb 13 2025 oneukum@suse.com
- xhci: add stream context tracing (jsc#PED-10906).
- commit 2301fc5
* Thu Feb 13 2025 oneukum@suse.com
- xhci: Don't trace ring at every enqueue or dequeue increase
  (jsc#PED-10906).
- commit 2cbfb0a
* Thu Feb 13 2025 oneukum@suse.com
- xhci: show DMA address of TRB when tracing TRBs (jsc#PED-10906).
- commit e22a715
* Thu Feb 13 2025 oneukum@suse.com
- xhci: Cleanup Candence controller PCI device and vendor ID usage
  (jsc#PED-10906).
- commit fb9a885
* Thu Feb 13 2025 oneukum@suse.com
- usb: xhci: Fix sum_trb_lengths() (jsc#PED-10906).
- commit 0631220
* Thu Feb 13 2025 nmorey@suse.com
- mptcp: sysctl: sched: avoid using current->nsproxy (CVE-2025-21642 bsc#1236572)
- commit d313630
* Thu Feb 13 2025 nmorey@suse.com
- mptcp: sysctl: blackhole timeout: avoid using current->nsproxy (CVE-2025-21641 bsc#1236124)
- commit 3010ecf
* Thu Feb 13 2025 jroedel@suse.de
- Update config files.
  Set TSX_MODE to upstream default.
- commit 761f591
* Wed Feb 12 2025 krisman@suse.de
- brd: defer automatic disk creation until module initialization
  succeeds (CVE-2024-56693 bsc#1235418).
- commit 4ea5368
* Wed Feb 12 2025 oneukum@suse.com
- usb: xhci: Remove unused parameters of next_trb()
  (jsc#PED-10906).
- commit 4ce0d38
* Wed Feb 12 2025 oneukum@suse.com
- xhci: Add Isochronous TRB fields to TRB tracer (jsc#PED-10906).
- commit 62ff2a5
* Wed Feb 12 2025 oneukum@suse.com
- xhci: add helper to stop endpoint and wait for completion
  (jsc#PED-10906).
- Refresh
  patches.suse/usb-xhci-Avoid-queuing-redundant-Stop-Endpoint-comma.patch.
- commit 1863002
* Wed Feb 12 2025 oneukum@suse.com
- usb: Switch back to struct platform_driver::remove()
  (jsc#PED-10906).
- commit 5d10743
* Wed Feb 12 2025 osalvador@suse.de
- mm: zswap: move allocations during CPU init outside the lock
  (git-fixes).
- commit 6c847ee
* Wed Feb 12 2025 oneukum@suse.com
- usb: host: fix typo in the comment (jsc#PED-10906).
- commit 1243816
* Wed Feb 12 2025 osalvador@suse.de
- mm: zswap: properly synchronize freeing resources during CPU
  hotunplug (bsc#1237029 CVE-2025-21693).
- commit 91784aa
* Wed Feb 12 2025 osalvador@suse.de
- vfio/platform: check the bounds of read/write syscalls
  (bsc#1237045 CVE-2025-21687).
- commit 8ac3968
* Wed Feb 12 2025 osalvador@suse.de
- net: sched: fix ets qdisc OOB Indexing (bsc#1237028
  CVE-2025-21692).
- commit a3b6e33
* Wed Feb 12 2025 iivanov@suse.de
- ASoC: fsl_utils: Add function to constrain rates (jsc#PED-12016)
- commit d9c4732
* Wed Feb 12 2025 iivanov@suse.de
- dt-bindings: clock: imx93: Add SPDIF IPG clk (jsc#PED-12016)
- commit 1672b95
* Wed Feb 12 2025 iivanov@suse.de
- dt-bindings: clock: Add i.MX91 clock support (jsc#PED-12016)
- commit 24a24f1
* Wed Feb 12 2025 iivanov@suse.de
- dt-bindings: clock: imx93: Drop IMX93_CLK_END macro definition (jsc#PED-12016)
- commit 5c1986d
* Wed Feb 12 2025 osalvador@suse.de
- io_uring/rsrc: require cloned buffers to share accounting
  contexts (CVE-2025-21686 bsc#1237043).
- commit 864eac2
* Wed Feb 12 2025 osalvador@suse.de
- cachestat: fix page cache statistics permission checking
  (bsc#1237032 CVE-2024-57950).
- commit 751ac1a
* Wed Feb 12 2025 iivanov@suse.de
- ASoC: fsl_sai: Add sample rate constraint (jsc#PED-12016)
- commit 6510a2e
* Wed Feb 12 2025 iivanov@suse.de
- usb: typec: tcpci: set local CC to Rd only when cc1/cc2 status is Rp (jsc#PED-12016)
- commit 45143cb
* Wed Feb 12 2025 iivanov@suse.de
- tty: serial: fsl_lpuart: flush RX and TX FIFO when lpuart shutdown (jsc#PED-12016)
- commit 1e6dbc5
* Wed Feb 12 2025 iivanov@suse.de
- tty: serial: fsl_lpuart: increase maximum uart_nr to 12 (jsc#PED-12016)
- commit 33f1fe2
* Wed Feb 12 2025 iivanov@suse.de
- tty: serial: fsl_lpuart: add 7-bits format support on (jsc#PED-12016)
- commit c193367
* Wed Feb 12 2025 iivanov@suse.de
- spi: spi-fsl-lpspi: support effective_speed_hz (jsc#PED-12016)
- commit 4e04717
* Wed Feb 12 2025 iivanov@suse.de
- perf: imx9_perf: Introduce AXI filter version to refactor the driver (jsc#PED-12016)
- commit e5aa649
* Wed Feb 12 2025 iivanov@suse.de
- perf: imx_perf: add support for i.MX91 platform (jsc#PED-12016)
- commit ab04b10
* Wed Feb 12 2025 iivanov@suse.de
- nvmem: imx-ocotp-ele: set word length to 1 (jsc#PED-12016)
- commit ac25b97
* Wed Feb 12 2025 iivanov@suse.de
- nvmem: imx-ocotp-ele: fix MAC address byte order (jsc#PED-12016)
- commit 02edd36
* Wed Feb 12 2025 iivanov@suse.de
- nvmem: imx-ocotp-ele: fix reading from non zero offset (jsc#PED-12016)
- commit d166349
* Wed Feb 12 2025 iivanov@suse.de
- nvmem: imx-ocotp-ele: simplify read beyond device check (jsc#PED-12016)
- commit 764aad0
* Wed Feb 12 2025 iivanov@suse.de
- net: stmmac: imx: Use syscon_regmap_lookup_by_phandle_args (jsc#PED-12016)
- commit 618e3d7
* Wed Feb 12 2025 iivanov@suse.de
- net: dwmac-imx: add imx93 clock input support in RMII mode (jsc#PED-12016)
- commit bcac46a
* Wed Feb 12 2025 iivanov@suse.de
- net: dwmac-imx: Use helper rgmii_clock (jsc#PED-12016)
- commit 792a263
* Wed Feb 12 2025 iivanov@suse.de
- net: phy: Add helper for mapping RGMII link speed to clock rate (jsc#PED-12016)
- commit 9ebf4c7
* Wed Feb 12 2025 iivanov@suse.de
- net: stmmac: restructure the error path of stmmac_probe_config_dt() (jsc#PED-12016)
- commit f9eed74
* Wed Feb 12 2025 iivanov@suse.de
- net: stmmac: Fix clock rate variables size (jsc#PED-12016)
- commit c0ff972
* Wed Feb 12 2025 iivanov@suse.de
- net: fec: implement TSO descriptor cleanup (jsc#PED-12016)
- commit 3b9cb06
* Tue Feb 11 2025 iivanov@suse.de
- mmc: pwrseq_simple: Handle !RESET_CONTROLLER properly (jsc#PED-12016)
- commit e5cd33c
* Tue Feb 11 2025 iivanov@suse.de
- mmc: pwrseq_simple: add support for one reset control (jsc#PED-12016)
- commit 30494ea
* Tue Feb 11 2025 iivanov@suse.de
- irqchip/gic-v3: Handle CPU_PM_ENTER_FAILED correctly (jsc#PED-12016)
- commit de54886
* Tue Feb 11 2025 iivanov@suse.de
- i2c: imx-lpi2c: make controller available until the system enters (jsc#PED-12016)
- commit 588e6b2
* Tue Feb 11 2025 iivanov@suse.de
- i2c: imx-lpi2c: add target mode support (jsc#PED-12016)
- commit 9414869
* Tue Feb 11 2025 iivanov@suse.de
- i2c: imx-lpi2c: add eDMA mode support for LPI2C (jsc#PED-12016)
- commit 07d963c
* Tue Feb 11 2025 mfranc@suse.cz
- s390/fpu: Add fpc exception handler / remove fixup section again
  (git-fixes bsc#1237061).
- commit 65e32a8
* Tue Feb 11 2025 mfranc@suse.cz
- s390/pci: Fix SR-IOV for PFs initially in standby (git-fixes
  bsc#1237059).
- commit f0ee871
* Tue Feb 11 2025 mfranc@suse.cz
- s390/topology: Improve topology detection (bsc#1236996).
- commit 06dc0b0
* Tue Feb 11 2025 iivanov@suse.de
- clk: imx: Apply some clks only for i.MX93 (jsc#PED-12016)
- commit 0f650e5
* Tue Feb 11 2025 iivanov@suse.de
- clk: imx93: Add IMX93_CLK_SPDIF_IPG clock (jsc#PED-12016)
- commit 073d7ef
* Tue Feb 11 2025 iivanov@suse.de
- clk: imx: add i.MX91 clk (jsc#PED-12016)
- commit 46b8cd9
* Tue Feb 11 2025 iivanov@suse.de
- clk: imx93: Move IMX93_CLK_END macro to clk driver (jsc#PED-12016)
- commit 890578b
* Tue Feb 11 2025 mfranc@suse.cz
- s390: Add '-std=gnu11' to decompressor and purgatory CFLAGS
  (git-fixes bsc#1237054).
- commit 79eba3a
* Tue Feb 11 2025 mfranc@suse.cz
- seccomp: Stub for !CONFIG_SECCOMP (git-fixes bsc#1237053).
- commit b92853d
* Tue Feb 11 2025 mfranc@suse.cz
- KVM: s390: vsie: fix some corner-cases when grabbing vsie pages
  (git-fixes bsc#1237049).
- commit d4d35a7
* Tue Feb 11 2025 iivanov@suse.de
- soc: imx: Add SoC device register for i.MX9 (jsc#PED-12016)
- commit 6e43782
* Tue Feb 11 2025 iivanov@suse.de
- soc: imx8m: Use devm_* to simplify probe failure handling (jsc#PED-12016)
- commit e0205ec
* Tue Feb 11 2025 iivanov@suse.de
- soc: imx8m: Remove global soc_uid (jsc#PED-12016)
- commit fab4815
* Tue Feb 11 2025 iivanov@suse.de
- EDAC/fsl_ddr: Add support for i.MX9 DDR controller (jsc#PED-12016)
- commit df25446
* Tue Feb 11 2025 iivanov@suse.de
- EDAC/fsl_ddr: Fix bad bit shift operations (jsc#PED-12016)
- commit ce70346
* Tue Feb 11 2025 iivanov@suse.de
- EDAC/fsl_ddr: Move global variables into struct fsl_mc_pdata (jsc#PED-12016)
- commit baa1744
* Tue Feb 11 2025 iivanov@suse.de
- EDAC/fsl_ddr: Pass down fsl_mc_pdata in ddr_in32() and ddr_out32() (jsc#PED-12016)
- commit 4f4af2c
* Tue Feb 11 2025 mfranc@suse.cz
- net/smc: support ipv4 mapped ipv6 addr client for smc-r v2
  (bsc#1236995).
- commit a6e1ba4
* Tue Feb 11 2025 oneukum@suse.com
- x86/Documentation: Update algo in init_size description of
  boot protocol (git-fixes).
- commit 9166589
* Tue Feb 11 2025 oneukum@suse.com
- util_macros.h: fix/rework find_closest() macros (git-fixes).
- commit 7e910c6
* Tue Feb 11 2025 oneukum@suse.com
- netlink: typographical error in nlmsg_type constants definition
  (git-fixes).
- commit 0e6f2bb
* Tue Feb 11 2025 osalvador@suse.de
- irqchip/gic-v3-its: Don't enable interrupts in
  its_irq_set_vcpu_affinity() (CVE-2024-57949 bsc#1236950).
- commit 081a1c9
* Tue Feb 11 2025 oneukum@suse.com
- PM: sleep: core: Restrict power.set_active propagation
  (git-fixes).
- commit ae91759
* Tue Feb 11 2025 tiwai@suse.de
- HID: hid-steam: Don't use cancel_delayed_work_sync in IRQ
  context (git-fixes).
- HID: hid-steam: Move hidraw input (un)registering to work
  (git-fixes).
- HID: hid-thrustmaster: fix stack-out-of-bounds read in
  usb_check_int_endpoints() (git-fixes).
- HID: multitouch: Add NULL check in mt_input_configured
  (git-fixes).
- HID: winwing: Add NULL check in winwing_init_led() (git-fixes).
- pinctrl: pinconf-generic: Print unsigned value if a format is
  registered (git-fixes).
- pinctrl: cy8c95x0: Respect IRQ trigger settings from firmware
  (git-fixes).
- pinctrl: cy8c95x0: Rename PWMSEL to SELPWM (git-fixes).
- pinctrl: cy8c95x0: Enable regmap locking for debug (git-fixes).
- pinctrl: cy8c95x0: Avoid accessing reserved registers
  (git-fixes).
- jiffies: Cast to unsigned long in secs_to_jiffies() conversion
  (git-fixes).
- HID: hid-steam: Don't use cancel_delayed_work_sync in IRQ
  context (git-fixes).
- HID: hid-steam: Move hidraw input (un)registering to work
  (git-fixes).
- HID: hid-thrustmaster: fix stack-out-of-bounds read in
  usb_check_int_endpoints() (git-fixes).
- HID: multitouch: Add NULL check in mt_input_configured
  (git-fixes).
- HID: winwing: Add NULL check in winwing_init_led() (git-fixes).
- pinctrl: pinconf-generic: Print unsigned value if a format is
  registered (git-fixes).
- pinctrl: cy8c95x0: Respect IRQ trigger settings from firmware
  (git-fixes).
- pinctrl: cy8c95x0: Rename PWMSEL to SELPWM (git-fixes).
- pinctrl: cy8c95x0: Enable regmap locking for debug (git-fixes).
- pinctrl: cy8c95x0: Avoid accessing reserved registers
  (git-fixes).
- jiffies: Cast to unsigned long in secs_to_jiffies() conversion
  (git-fixes).
- commit 99e9fb4
* Tue Feb 11 2025 krisman@suse.de
- netdev: prevent accessing NAPI instances from another namespace
  (jsc#PED-12085).
- netdev-genl: Hold rcu_read_lock in napi_set (jsc#PED-12085).
- commit f11f99b
* Tue Feb 11 2025 ohering@suse.de
- scsi: storvsc: Set correct data length for sending SCSI command
  without payload (git-fixes).
- jiffies: Cast to unsigned long in secs_to_jiffies() conversion
  (git-fixes).
- scsi: storvsc: Set correct data length for sending SCSI command
  without payload (git-fixes).
- jiffies: Cast to unsigned long in secs_to_jiffies() conversion
  (git-fixes).
- commit 272f93e
* Mon Feb 10 2025 jroedel@suse.de
- iommu: Manage driver probe deferral better (bsc#1235032).
- iommu/arm-smmu-v3: Clean up more on probe failure (bsc#1235032).
- iommu/arm-smmu: Make instance lookup robust (bsc#1235032,
  CVE-2024-56568).
- commit 029e52d
* Sun Feb  9 2025 tiwai@suse.de
- seccomp: passthrough uretprobe systemcall without filtering
  (git-fixes).
- drm/amd/display: Add hubp cache reset when powergating
  (stable-fixes).
- wifi: rtw89: avoid to init mgnt_entry list twice when WoWLAN
  failed (git-fixes).
- wifi: rtw89: chan: fix soft lockup in
  rtw89_entity_recalc_mgnt_roles() (git-fixes).
- wifi: rtw89: chan: manage active interfaces (stable-fixes).
- wifi: rtw89: handle entity active flag per PHY (stable-fixes).
- commit f959305
* Sat Feb  8 2025 tiwai@suse.de
- drm/i915/dp: Iterate DSC BPP from high to low on all platforms
  (git-fixes).
- drm/i915/dp: fix the Adaptive sync Operation mode for SDP
  (git-fixes).
- drm/i915/guc: Debug print LRC state entries only if the context
  is pinned (git-fixes).
- drm/i915: Fix page cleanup on DMA remap failure (git-fixes).
- drm/i915/pmu: Fix zero delta busyness issue (git-fixes).
- drm/xe/devcoredump: Move exec queue snapshot to Contexts section
  (git-fixes).
- gpu: drm_dp_cec: fix broken CEC adapter properties check
  (git-fixes).
- accel/ivpu: Clear runtime_error after
  pm_runtime_resume_and_get() fails (git-fixes).
- drm/komeda: Add check for komeda_get_layer_fourcc_list()
  (git-fixes).
- firmware: iscsi_ibft: fix ISCSI_IBFT Kconfig entry (git-fixes).
- ACPI: property: Fix return value for nval == 0 in
  acpi_data_prop_read() (git-fixes).
- ACPI: PRM: Remove unnecessary strict handler address checks
  (git-fixes).
- gpio: pca953x: Improve interrupt support (git-fixes).
- PCI/TPH: Restore TPH Requester Enable correctly (git-fixes).
- PCI/ASPM: Fix L1SS saving (git-fixes).
- selftests: mptcp: connect: -f: no reconnect (git-fixes).
- commit 902a5b3
* Sat Feb  8 2025 tonyj@suse.de
- tools build: Remove the libunwind feature tests from the ones
  detected when test-all.o builds (git-fixes).
- commit f82da74
* Sat Feb  8 2025 tonyj@suse.de
- perf annotate: Use an array for the disassembler preference
  (git-fixes).
- perf test: Fix parallel/sequential option documentation
  (git-fixes).
- perf test stat: Avoid hybrid assumption when virtualized
  (git-fixes).
- perf symbol: Prefer non-label symbols with same address
  (git-fixes).
- perf stat: Fix trailing comma when there is no metric unit
  (git-fixes).
- tools features: Don't check for libunwind devel files by default
  (git-fixes).
- commit e8b27c5
* Fri Feb  7 2025 tonyj@suse.de
- perf probe: Fix uninitialized variable
  (perf-sle16-v6.13-userspace-update).
- libperf: evlist: Fix --cpu argument on hybrid platform
  (perf-sle16-v6.13-userspace-update).
- perf test expr: Fix system_tsc_freq for only x86
  (perf-sle16-v6.13-userspace-update).
- perf test hwmon_pmu: Fix event file location
  (perf-sle16-v6.13-userspace-update).
- perf hwmon_pmu: Use openat rather than dup to refresh directory
  (perf-sle16-v6.13-userspace-update).
- perf ftrace: Fix undefined behavior in cmp_profile_data()
  (perf-sle16-v6.13-userspace-update).
- perf tools: Fix precise_ip fallback logic
  (perf-sle16-v6.13-userspace-update).
- perf tools: Fix build error on generated/fs_at_flags_array.c
  (perf-sle16-v6.13-userspace-update).
- perf machine: Initialize machine->env to address a segfault
  (perf-sle16-v6.13-userspace-update).
- perf test: Don't signal all processes on system when
  interrupting tests (perf-sle16-v6.13-userspace-update).
- perf tools: Fix build-id event recording
  (perf-sle16-v6.13-userspace-update).
- perf tests: Fix hwmon parsing with PMU name test
  (perf-sle16-v6.13-userspace-update).
- perf hwmon_pmu: Ensure hwmon key union is zeroed before use
  (perf-sle16-v6.13-userspace-update).
- perf tests hwmon_pmu: Remove double evlist__delete()
  (perf-sle16-v6.13-userspace-update).
- perf/test: fix perf ftrace test on s390
  (perf-sle16-v6.13-userspace-update).
- perf bpf-filter: Return -ENOMEM directly when pfi allocation
  fails (perf-sle16-v6.13-userspace-update).
- perf test: Correct hwmon test PMU detection
  (perf-sle16-v6.13-userspace-update).
- perf: Remove unused del_perf_probe_events()
  (perf-sle16-v6.13-userspace-update).
- perf pmu: Move pmu_metrics_table__find and remove ARM override
  (perf-sle16-v6.13-userspace-update).
- perf jevents: Add map_for_cpu()
  (perf-sle16-v6.13-userspace-update).
- perf header: Pass a perf_cpu rather than a PMU to get_cpuid_str
  (perf-sle16-v6.13-userspace-update).
- perf header: Avoid transitive PMU includes
  (perf-sle16-v6.13-userspace-update).
- perf arm64 header: Use cpu argument in get_cpuid
  (perf-sle16-v6.13-userspace-update).
- perf header: Refactor get_cpuid to take a CPU for ARM
  (perf-sle16-v6.13-userspace-update).
- perf header: Move is_cpu_online to numa bench
  (perf-sle16-v6.13-userspace-update).
- perf jevents: fix breakage when do perf stat on system metric
  (perf-sle16-v6.13-userspace-update).
- perf test: Add missing __exit calls in tool/hwmon tests
  (perf-sle16-v6.13-userspace-update).
- perf tests: Make leader sampling test work without branch event
  (perf-sle16-v6.13-userspace-update).
- perf util: Remove kernel version deadcode
  (perf-sle16-v6.13-userspace-update).
- perf test shell trace_exit_race: Use --no-comm to avoid cases
  where COMM isn't resolved (perf-sle16-v6.13-userspace-update).
- perf test shell trace_exit_race: Show what went wrong in
  verbose mode (perf-sle16-v6.13-userspace-update).
- perf tests: Add test for trace output loss
  (perf-sle16-v6.13-userspace-update).
- perf trace: Avoid garbage when not printing a syscall's
  arguments (perf-sle16-v6.13-userspace-update).
- perf trace: Do not lose last events in a race
  (perf-sle16-v6.13-userspace-update).
- perf probe: Introduce quotation marks support
  (perf-sle16-v6.13-userspace-update).
- perf string: Add strpbrk_esq() and strdup_esq() for escape
  and quote (perf-sle16-v6.13-userspace-update).
- perf probe: Accept FUNC@* to specify function name explicitly
  (perf-sle16-v6.13-userspace-update).
- perf probe: Fix to ignore escaped characters in --lines option
  (perf-sle16-v6.13-userspace-update).
- perf probe: Fix error message for failing to find line range
  (perf-sle16-v6.13-userspace-update).
- perf trace: Fix tracing itself, creating feedback loops
  (perf-sle16-v6.13-userspace-update).
- perf timechart: Remove redundant variable assignment
  (perf-sle16-v6.13-userspace-update).
- perf list: Fix topic and pmu_name argument order
  (perf-sle16-v6.13-userspace-update).
- perf tools: Fix typos Muliplier -> Multiplier
  (perf-sle16-v6.13-userspace-update).
- perf disasm: Allow configuring what disassemblers to use
  (perf-sle16-v6.13-userspace-update).
- perf disasm: Define stubs for the LLVM and capstone
  disassemblers (perf-sle16-v6.13-userspace-update).
- perf disasm: Introduce symbol__disassemble_objdump()
  (perf-sle16-v6.13-userspace-update).
- perf build: Remove PERF_HAVE_DWARF_REGS
  (perf-sle16-v6.13-userspace-update).
- perf dwarf-regs: Remove get_arch_regstr code
  (perf-sle16-v6.13-userspace-update).
- perf xtensa: Remove dwarf-regs.c
  (perf-sle16-v6.13-userspace-update).
- perf sparc: Remove dwarf-regs.c
  (perf-sle16-v6.13-userspace-update).
- perf sh: Remove dwarf-regs.c
  (perf-sle16-v6.13-userspace-update).
- perf s390: Remove dwarf-regs.c
  (perf-sle16-v6.13-userspace-update).
- perf riscv: Remove dwarf-regs.c and add dwarf-regs-table.h
  (perf-sle16-v6.13-userspace-update).
- perf dwarf-regs: Move powerpc dwarf-regs out of arch
  (perf-sle16-v6.13-userspace-update).
- perf mips: Remove dwarf-regs.c
  (perf-sle16-v6.13-userspace-update).
- perf loongarch: Remove dwarf-regs.c
  (perf-sle16-v6.13-userspace-update).
- perf dwarf-regs: Move csky dwarf-regs out of arch
  (perf-sle16-v6.13-userspace-update).
- perf arm: Remove dwarf-regs.c
  (perf-sle16-v6.13-userspace-update).
- perf arm64: Remove dwarf-regs.c
  (perf-sle16-v6.13-userspace-update).
- perf dwarf-regs: Move x86 dwarf-regs out of arch
  (perf-sle16-v6.13-userspace-update).
- perf dwarf-regs: Pass ELF flags to get_dwarf_regstr
  (perf-sle16-v6.13-userspace-update).
- perf dwarf-regs: Pass accurate disassembly machine to
  get_dwarf_regnum (perf-sle16-v6.13-userspace-update).
- perf disasm: Add e_machine/e_flags to struct arch
  (perf-sle16-v6.13-userspace-update).
- perf dwarf-regs: Add EM_HOST and EF_HOST defines
  (perf-sle16-v6.13-userspace-update).
- perf dwarf-regs: Remove
  PERF_HAVE_ARCH_REGS_QUERY_REGISTER_OFFSET
  (perf-sle16-v6.13-userspace-update).
- perf bpf-prologue: Remove unused file
  (perf-sle16-v6.13-userspace-update).
- perf docs: Document tool and hwmon events
  (perf-sle16-v6.13-userspace-update).
- perf test: Add hwmon "PMU" test
  (perf-sle16-v6.13-userspace-update).
- perf pmu: Add calls enabling the hwmon_pmu
  (perf-sle16-v6.13-userspace-update).
- perf hwmon_pmu: Add a tool PMU exposing events from hwmon in
  sysfs (perf-sle16-v6.13-userspace-update).
- perf test: Add hwmon filename parser test
  (perf-sle16-v6.13-userspace-update).
- perf hwmon_pmu: Add hwmon filename parser
  (perf-sle16-v6.13-userspace-update).
- perf build: Include libtraceevent headers directly indicated
  by pkg-config (perf-sle16-v6.13-userspace-update).
- perf script python: Adjust objdump start/end per map pgoff
  parameter (perf-sle16-v6.13-userspace-update).
- perf script cs_etm: Add map_pgoff to python dictionary
  (perf-sle16-v6.13-userspace-update).
- perf stat: Expand metric+unit buffer size
  (perf-sle16-v6.13-userspace-update).
- perf tools: Add the empty-pmu-events build to .gitignore
  (perf-sle16-v6.13-userspace-update).
- perf: event: Remove deadcode
  (perf-sle16-v6.13-userspace-update).
- perf trace: avoid garbage when not printing a trace event's
  arguments (perf-sle16-v6.13-userspace-update).
- perf test: Fix ftrace test with regex patterns
  (perf-sle16-v6.13-userspace-update).
- perf test: Remove dangling CFLAGS for removed attr.o object
  (perf-sle16-v6.13-userspace-update).
- perf tools: Add all shellcheck_log to gitignore
  (perf-sle16-v6.13-userspace-update).
- perf build: Add missing cflags when building with custom
  libtraceevent (perf-sle16-v6.13-userspace-update).
- perf test: Remove cpu-list BPF cgroup counter test
  (perf-sle16-v6.13-userspace-update).
- perf build: Make libunwind opt-in rather than opt-out
  (perf-sle16-v6.13-userspace-update).
- perf test: Use sqrtloop workload to test bperf event
  (perf-sle16-v6.13-userspace-update).
- perf stat: Support inherit events during fork() for bperf
  (perf-sle16-v6.13-userspace-update).
- perf arm-spe: Use old behavior when opening old SPE files
  (perf-sle16-v6.13-userspace-update).
- perf ftrace latency: Fix unit on histogram first entry when
  using --use-nsec (perf-sle16-v6.13-userspace-update).
- perf, riscv: Wire up perf trace support for RISC-V
  (perf-sle16-v6.13-userspace-update).
- perf probe: Fix retrieval of source files from a debuginfod
  server (perf-sle16-v6.13-userspace-update).
- perf arm-spe: Update --itrace help text
  (perf-sle16-v6.13-userspace-update).
- perf arm-spe: Correctly set sample flags
  (perf-sle16-v6.13-userspace-update).
- perf arm-spe: Use ARM_SPE_OP_BRANCH_ERET when synthesizing
  branches (perf-sle16-v6.13-userspace-update).
- perf arm-spe: Set sample.addr to target address for instruction
  sample (perf-sle16-v6.13-userspace-update).
- perf vendor events arm64: Add i.MX91 DDR Performance Monitor
  metrics (perf-sle16-v6.13-userspace-update).
- perf test: Sort tests placing exclusive tests last
  (perf-sle16-v6.13-userspace-update).
- perf test: Add a signal handler to kill forked child processes
  (perf-sle16-v6.13-userspace-update).
- perf test: Make parallel testing the default
  (perf-sle16-v6.13-userspace-update).
- perf test: Run parallel tests in two passes
  (perf-sle16-v6.13-userspace-update).
- perf test: Add a signal handler around running a test
  (perf-sle16-v6.13-userspace-update).
- perf test: Tag parallel failing shell tests with "(exclusive)"
  (perf-sle16-v6.13-userspace-update).
- perf test: Avoid list test blocking on writing to stdout
  (perf-sle16-v6.13-userspace-update).
- perf test: Reduce scope of parallel variable
  (perf-sle16-v6.13-userspace-update).
- perf test: Display number of active running tests
  (perf-sle16-v6.13-userspace-update).
- perf disasm: Fix not cleaning up disasm_line in
  symbol__disassemble_raw() (perf-sle16-v6.13-userspace-update).
- perf disasm: Use disasm_line__free() to properly free
  disasm_line (perf-sle16-v6.13-userspace-update).
- perf test: Add precise_max subtest to the perf record shell test
  (perf-sle16-v6.13-userspace-update).
- perf record: Just use "cycles:P" as the default event
  (perf-sle16-v6.13-userspace-update).
- perf tools: Check fallback error and order
  (perf-sle16-v6.13-userspace-update).
- perf tools: Move x86__is_amd_cpu() to util/env.c
  (perf-sle16-v6.13-userspace-update).
- perf tools: Detect missing kernel features properly
  (perf-sle16-v6.13-userspace-update).
- perf tools: Do not set exclude_guest for precise_ip
  (perf-sle16-v6.13-userspace-update).
- perf tools: Simplify evsel__add_modifier()
  (perf-sle16-v6.13-userspace-update).
- perf tools: Don't set attr.exclude_guest by default
  (perf-sle16-v6.13-userspace-update).
- perf tools: Add fallback for exclude_guest
  (perf-sle16-v6.13-userspace-update).
- perf tools: sched-pipe bench: add (-n) nonblocking benchmark
  (perf-sle16-v6.13-userspace-update).
- perf test: Document the -w/--workload option
  (perf-sle16-v6.13-userspace-update).
- perf test: Introduce --list-workloads to list the available
  workloads (perf-sle16-v6.13-userspace-update).
- perf test: Introduce workloads__for_each()
  (perf-sle16-v6.13-userspace-update).
- perf vendor events amd: Update Zen 5 data cache fill events
  (perf-sle16-v6.13-userspace-update).
- perf vendor events amd: Add Zen 5 data fabric metrics
  (perf-sle16-v6.13-userspace-update).
- perf vendor events amd: Add Zen 5 data fabric events
  (perf-sle16-v6.13-userspace-update).
- perf test: Fix perf test case 84 on s390
  (perf-sle16-v6.13-userspace-update).
- perf test: Update all metrics test like metricgroups test
  (perf-sle16-v6.13-userspace-update).
- perf build: Rename CONFIG_DWARF to CONFIG_LIBDW
  (perf-sle16-v6.13-userspace-update).
- perf build: Rename HAVE_DWARF_SUPPORT to HAVE_LIBDW_SUPPORT
  (perf-sle16-v6.13-userspace-update).
- perf libdw: Remove unnecessary defines
  (perf-sle16-v6.13-userspace-update).
- perf probe: Move elfutils support check to libdw check
  (perf-sle16-v6.13-userspace-update).
- perf build: Combine test-dwarf-getcfi into test-libdw
  (perf-sle16-v6.13-userspace-update).
- perf build: Combine test-dwarf-getlocations into test-libdw
  (perf-sle16-v6.13-userspace-update).
- perf build: Combine libdw-dwarf-unwind into libdw feature tests
  (perf-sle16-v6.13-userspace-update).
- perf build: Rename test-dwarf to test-libdw
  (perf-sle16-v6.13-userspace-update).
- perf build: Remove defined but never used variable
  (perf-sle16-v6.13-userspace-update).
- perf build: Rename NO_DWARF to NO_LIBDW
  (perf-sle16-v6.13-userspace-update).
- perf build: Fix LIBDW_DIR (perf-sle16-v6.13-userspace-update).
- perf test: Move attr files into shell directory where they
  are used (perf-sle16-v6.13-userspace-update).
- perf test: Remove C test wrapper for attr.py
  (perf-sle16-v6.13-userspace-update).
- perf test: Add a shell wrapper for "Setup struct
  perf_event_attr" (perf-sle16-v6.13-userspace-update).
- perf probe: Correct demangled symbols in C++ program
  (perf-sle16-v6.13-userspace-update).
- perf stat: Disable metric thresholds for CSV and JSON
  metric-only mode (perf-sle16-v6.13-userspace-update).
- perf stat: Add metric-threshold to json output
  (perf-sle16-v6.13-userspace-update).
- perf stat: Change color to threshold in print_metric
  (perf-sle16-v6.13-userspace-update).
- perf stat: Drop metric-unit if unit is NULL
  (perf-sle16-v6.13-userspace-update).
- perf stat: Display "none" for NaN with metric only json
  (perf-sle16-v6.13-userspace-update).
- perf stat: Fix/add parameter names for print_metric
  (perf-sle16-v6.13-userspace-update).
- perf color: Add printf format checking and resolve issues
  (perf-sle16-v6.13-userspace-update).
- perf probe: Fix libdw memory leak
  (perf-sle16-v6.13-userspace-update).
- perf disasm: Fix capstone memory leak
  (perf-sle16-v6.13-userspace-update).
- tools/perf/powerpc/util: Add support to handle compatible mode
  PVR for perf json events (perf-sle16-v6.13-userspace-update).
- tools/perf/pmu-events/powerpc: Add support for compat events
  in json (perf-sle16-v6.13-userspace-update).
- perf dso: Fix symtab_type for kmod compression
  (perf-sle16-v6.13-userspace-update).
- perf probe: Improve log for long event name failure
  (perf-sle16-v6.13-userspace-update).
- perf probe: Check group string length
  (perf-sle16-v6.13-userspace-update).
- perf probe: Use the MAX_EVENT_NAME_LEN macro
  (perf-sle16-v6.13-userspace-update).
- perf test: Speed up some tests using perf list
  (perf-sle16-v6.13-userspace-update).
- perf x86/topdown: Refine helper arch_is_topdown_metrics()
  (perf-sle16-v6.13-userspace-update).
- perf x86/topdown: Make topdown metrics comparators be symmetric
  (perf-sle16-v6.13-userspace-update).
- perf tool_pmu: Remove duplicate io.h header
  (perf-sle16-v6.13-userspace-update).
- perf arm-spe: Add Cortex CPUs to common data source encoding
  list (perf-sle16-v6.13-userspace-update).
- perf arm-spe: Add Neoverse-V2 to common data source encoding
  list (perf-sle16-v6.13-userspace-update).
- perf arm-spe: Remove the unused 'midr' field
  (perf-sle16-v6.13-userspace-update).
- perf arm-spe: Use metadata to decide the data source feature
  (perf-sle16-v6.13-userspace-update).
- perf arm-spe: Introduce arm_spe__is_homogeneous()
  (perf-sle16-v6.13-userspace-update).
- perf arm-spe: Rename the common data source encoding
  (perf-sle16-v6.13-userspace-update).
- perf arm-spe: Rename arm_spe__synth_data_source_generic()
  (perf-sle16-v6.13-userspace-update).
- perf test: Delete unused Intel CQM test
  (perf-sle16-v6.13-userspace-update).
- perf evsel: Fix missing inherit + sample read check
  (perf-sle16-v6.13-userspace-update).
- perf sched timehist: Add pre-migration wait time option
  (perf-sle16-v6.13-userspace-update).
- perf tools: Remove unnecessary parentheses
  (perf-sle16-v6.13-userspace-update).
- perf tools: Fix possible compiler warnings in hashmap
  (perf-sle16-v6.13-userspace-update).
- perf tools: Fix compiler error in util/tool_pmu.c
  (perf-sle16-v6.13-userspace-update).
- tools/perf/tests: Remove duplicate evlist__delete in
  tests/tool_pmu.c (perf-sle16-v6.13-userspace-update).
- tools/perf/tests: Fix compilation error with strncpy in
  tests/tool_pmu (perf-sle16-v6.13-userspace-update).
- perf report: Display columns Predicted/Abort/Cycles in
  - -branch-history (perf-sle16-v6.13-userspace-update).
- perf tests: Add tool PMU test
  (perf-sle16-v6.13-userspace-update).
- perf tool_pmu: Switch to standard pmu functions and json
  descriptions (perf-sle16-v6.13-userspace-update).
- perf jevents: Add tool event json under a common architecture
  (perf-sle16-v6.13-userspace-update).
- perf tool_pmu: Move expr literals to tool_pmu
  (perf-sle16-v6.13-userspace-update).
- perf tool_pmu: Rename perf_tool_event__* to tool_pmu__*
  (perf-sle16-v6.13-userspace-update).
- perf tool_pmu: Rename enum perf_tool_event to tool_pmu_event
  (perf-sle16-v6.13-userspace-update).
- perf tool_pmu: Factor tool events into their own PMU
  (perf-sle16-v6.13-userspace-update).
- perf parse-events: Expose/rename config_term_name
  (perf-sle16-v6.13-userspace-update).
- perf pmu: Allow hardcoded terms to be applied to attributes
  (perf-sle16-v6.13-userspace-update).
- perf pmu: Simplify an asprintf error message
  (perf-sle16-v6.13-userspace-update).
- perf tools: Remove unused color_fwrite_lines
  (perf-sle16-v6.13-userspace-update).
- perf test x86: Fix typo in intel-pt-test
  (perf-sle16-v6.13-userspace-update).
- perf probe: Remove unused add_perf_probe_events
  (perf-sle16-v6.13-userspace-update).
- perf test attr: Add back missing topdown events
  (perf-sle16-v6.13-userspace-update).
- perf arm-spe: Dump metadata with version 2
  (perf-sle16-v6.13-userspace-update).
- perf arm-spe: Support metadata version 2
  (perf-sle16-v6.13-userspace-update).
- perf arm-spe: Save per CPU information in metadata
  (perf-sle16-v6.13-userspace-update).
- perf arm-spe: Calculate meta data size
  (perf-sle16-v6.13-userspace-update).
- perf arm-spe: Define metadata header version 2
  (perf-sle16-v6.13-userspace-update).
- perf list: update option desc in man page
  (perf-sle16-v6.13-userspace-update).
- perf test: Restore sample rate for perf_event_attr
  (perf-sle16-v6.13-userspace-update).
- perf trace: Keep exited threads for summary
  (perf-sle16-v6.13-userspace-update).
- perf/test: perf test 86 fails on s390
  (perf-sle16-v6.13-userspace-update).
- tools/perf: Allow inherit + PERF_SAMPLE_READ when opening events
  (perf-sle16-v6.13-userspace-update).
- tools/perf: Correctly calculate sample period for inherited
  SAMPLE_READ values (perf-sle16-v6.13-userspace-update).
- perf test: Skip not fail syscall tp fields test when
  insufficient permissions (perf-sle16-v6.13-userspace-update).
- perf test: Skip not fail tp fields test when insufficient
  permissions (perf-sle16-v6.13-userspace-update).
- perf test: Fix memory leaks on event-times error paths
  (perf-sle16-v6.13-userspace-update).
- perf stat: Fix affinity memory leaks on error path
  (perf-sle16-v6.13-userspace-update).
- perf jevents: Don't stop at the first matched pmu when searching
  a events table (perf-sle16-v6.13-userspace-update).
- perf tests: Add more topdown events regroup tests
  (perf-sle16-v6.13-userspace-update).
- perf tests: Add topdown events counting and sampling tests
  (perf-sle16-v6.13-userspace-update).
- perf tests: Add leader sampling test in record tests
  (perf-sle16-v6.13-userspace-update).
- perf x86/topdown: Don't move topdown metric events in group
  (perf-sle16-v6.13-userspace-update).
- perf x86/topdown: Correct leader selection with sample_read
  enabled (perf-sle16-v6.13-userspace-update).
- perf x86/topdown: Complete topdown slots/metrics events check
  (perf-sle16-v6.13-userspace-update).
- perf evsel: Reduce a variables scope
  (perf-sle16-v6.13-userspace-update).
- perf vender events arm64: Use "Topdown" as topdown metric
  group name (perf-sle16-v6.13-userspace-update).
- perf test: Use ARRAY_SIZE for array length
  (perf-sle16-v6.13-userspace-update).
- perf/test: Speed up test case perf annotate basic tests
  (perf-sle16-v6.13-userspace-update).
- perf mem: Fix printing PERF_MEM_LVLNUM_{L2_MHB|MSC}
  (perf-sle16-v6.13-userspace-update).
- perf sched replay: Remove unused parts of the code
  (perf-sle16-v6.13-userspace-update).
- libperf: Explicitly specify install-html dependencies
  (perf-sle16-v6.13-userspace-update).
- perf test: Add a test for default perf stat command
  (perf-sle16-v6.13-userspace-update).
- perf test: Make stat test work on DT devices
  (perf-sle16-v6.13-userspace-update).
- perf evsel: Remove pmu_name (perf-sle16-v6.13-userspace-update).
- perf evsel x86: Make evsel__has_perf_metrics work for legacy
  events (perf-sle16-v6.13-userspace-update).
- perf stat: Remove evlist__add_default_attrs use strings
  (perf-sle16-v6.13-userspace-update).
- perf stat: Uniquify event name improvements
  (perf-sle16-v6.13-userspace-update).
- perf evsel: Add alternate_hw_config and use in evsel__match
  (perf-sle16-v6.13-userspace-update).
- perf test: Ignore security failures in all PMU test
  (perf-sle16-v6.13-userspace-update).
- perf symbol: Do not fixup end address of labels
  (perf-sle16-v6.13-userspace-update).
- perf vendor events arm64: imx95: add
  imx95_bandwidth_usage.lpddr4x metric
  (perf-sle16-v6.13-userspace-update).
- perf stat: Stop repeating when ref_perf_stat() returns -1
  (perf-sle16-v6.13-userspace-update).
- perf stat: Close cork_fd when create_perf_stat_counter() failed
  (perf-sle16-v6.13-userspace-update).
- perf evsel: display dmesg command of showing a hardcoded path
  (perf-sle16-v6.13-userspace-update).
- perf test: cs-etm: Test Coresight disassembly script
  (perf-sle16-v6.13-userspace-update).
- perf scripts python cs-etm: Add start and stop arguments
  (perf-sle16-v6.13-userspace-update).
- perf scripts python cs-etm: Improve arguments
  (perf-sle16-v6.13-userspace-update).
- perf scripts python cs-etm: Update to use argparse
  (perf-sle16-v6.13-userspace-update).
- perf scripting python: Add function to get a config value
  (perf-sle16-v6.13-userspace-update).
- perf cs-etm: Use new OpenCSD consistency checks
  (perf-sle16-v6.13-userspace-update).
- perf cs-etm: Don't flush when packet_queue fills up
  (perf-sle16-v6.13-userspace-update).
- perf test: Be more tolerant of metricgroup failures
  (perf-sle16-v6.13-userspace-update).
- perf tools: update expected diff for lib/list_sort.c
  (perf-sle16-v6.13-userspace-update).
- commit d7ab8b5
* Fri Feb  7 2025 nmorey@suse.com
- mptcp: fix recvbuffer adjust on sleeping rcvmsg (git-fixes)
- commit d852207
* Fri Feb  7 2025 mhocko@suse.com
- smb: client: fix double free of TCP_Server_Info::hostname
  (CVE-2025-21673 bsc#1236689).
- commit 5cebe70
* Fri Feb  7 2025 mhocko@suse.com
- openvswitch: fix lockup on tx to unregistering netdev with
  carrier (CVE-2025-21681 bsc#1236702).
- commit 66a9042
* Fri Feb  7 2025 ggherdovich@suse.cz
- cpuidle: teo: Update documentation after previous changes
  (git-fixes).
- commit 2f5bf5c
* Fri Feb  7 2025 mhocko@suse.com
- mac802154: check local interfaces before deleting sdata list
  (CVE-2024-57948 bsc#1236677).
- commit 684a927
* Fri Feb  7 2025 ggherdovich@suse.cz
- cpufreq: qcom: Implement clk_ops::determine_rate() for
  qcom_cpufreq* clocks (git-fixes).
- cpufreq: qcom: Fix qcom_cpufreq_hw_recalc_rate() to query LUT
  if LMh IRQ is not available (git-fixes).
- commit 89b10dc
* Fri Feb  7 2025 ggherdovich@suse.cz
- cpufreq: fix using cpufreq-dt as module (git-fixes).
- commit a8a7426
* Fri Feb  7 2025 dwagner@suse.de
- doc: update managed_irq documentation (bsc#1236897).
- blk-mq: issue warning when offlining hctx with online isolcpus
  (bsc#1236897).
- blk-mq: use hk cpus only when isolcpus=managed_irq is enabled
  (bsc#1236897).
- lib/group_cpus: honor housekeeping config when grouping CPUs
  (bsc#1236897).
- virtio: blk/scsi: use block layer helpers to calculate num of
  queues (bsc#1236897).
- scsi: use block layer helpers to calculate num of queues
  (bsc#1236897).
- nvme-pci: use block layer helpers to calculate num of queues
  (bsc#1236897).
- blk-mq: add number of queue calc helper (bsc#1236897).
- lib/group_cpus: let group_cpu_evenly return number initialized
  masks (bsc#1236897).
- commit 489fc8c
* Fri Feb  7 2025 nmorey@suse.com
- net/l2tp: fix warning in l2tp_exit_net found by syzbot (CVE-2024-53211 bsc#1234961)
- commit 92b3970
* Fri Feb  7 2025 dwagner@suse.de
- blk-mq: create correct map for fallback case (bsc#1236896).
- blk-mq: remove unused queue mapping helpers (bsc#1236896).
- virtio: blk/scsi: replace blk_mq_virtio_map_queues with
  blk_mq_map_hw_queues (bsc#1236896).
- nvme: replace blk_mq_pci_map_queues with blk_mq_map_hw_queues
  (bsc#1236896).
- scsi: replace blk_mq_pci_map_queues with blk_mq_map_hw_queues
  (bsc#1236896).
- blk-mq: introduce blk_mq_map_hw_queues (bsc#1236896).
- virtio: hookup irq_get_affinity callback (bsc#1236896).
- PCI: hookup irq_get_affinity callback (bsc#1236896).
- driver core: bus: add irq_get_affinity callback to bus_type
  (bsc#1236896).
- commit eedefae
* Fri Feb  7 2025 shung-hsi.yu@suse.com
- selftests/bpf: Add apply_bytes test to
  test_txmsg_redir_wait_sndmem in test_sockmap (bsc#1235485
  CVE-2024-56633).
- tcp_bpf: Fix the sk_mem_uncharge logic in tcp_bpf_sendmsg
  (bsc#1235485 CVE-2024-56633).
- commit 3adbbcc
* Fri Feb  7 2025 krisman@suse.de
- selftests: net: Add busy_poll_test (jsc#PED-12085).
- eventpoll: Control irq suspension for prefer_busy_poll (jsc#PED-12085).
- eventpoll: Trigger napi_busy_loop, if prefer_busy_poll is set
  (jsc#PED-12085).
- commit 170f675
* Thu Feb  6 2025 krisman@suse.de
- net: Add control functions for irq suspension (jsc#PED-12085).
- net: Add napi_struct parameter irq_suspend_timeout (jsc#PED-12085).
- netdev-genl: Support setting per-NAPI config values (jsc#PED-12085).
- netdev-genl: Dump gro_flush_timeout (jsc#PED-12085).
- netdev-genl: Dump napi_defer_hard_irqs (jsc#PED-12085).
- commit ab1d6a3
* Thu Feb  6 2025 vkarasulli@suse.de
- iommufd: Fix struct iommu_hwpt_pgfault init and padding
  (git-fixes).
- commit c2fe2e2
* Thu Feb  6 2025 vkarasulli@suse.de
- iommufd/fault: Destroy response and mutex in
  iommufd_fault_destroy() (git-fixes).
- commit 4f00cba
* Thu Feb  6 2025 davide.benini@suse.com
- sched: sch_cake: add bounds checks to host bulk flow fairness
  counts (CVE-2025-21647 bsc#1236133).
- commit 1c89f89
* Thu Feb  6 2025 nik.borisov@suse.com
- x86/topology: Use x86_sched_itmt_flags for PKG domain unconditionally (jsc#PED-12062).
- commit 744bcec
* Thu Feb  6 2025 nik.borisov@suse.com
- x86/topology: Remove x86_smt_flags and use cpu_smt_flags directly (jsc#PED-12062).
- commit 069f91c
* Thu Feb  6 2025 nik.borisov@suse.com
- x86/itmt: Move the "sched_itmt_enabled" sysctl to debugfs (jsc#PED-12062).
- commit 9c6e214
* Thu Feb  6 2025 nik.borisov@suse.com
- x86/itmt: Use guard() for itmt_update_mutex (jsc#PED-12062).
- commit c195153
* Thu Feb  6 2025 nik.borisov@suse.com
- x86/itmt: Convert "sysctl_sched_itmt_enabled" to boolean (jsc#PED-12062).
- commit 9dfc635
* Wed Feb  5 2025 nmorey@suse.com
- RDMA/mlx5: Fix link status down event for MPV (git-fixes)
- commit 34e8f80
* Wed Feb  5 2025 msuchanek@suse.de
- Documentation/powerpc/fadump: add additional parameter feature
  details (bsc#1236743 ltc#211409).
- powerpc: increase MIN RMA size for CAS negotiation (bsc#1236743
  ltc#211409).
- powerpc/fadump: fix additional param memory reservation for
  HASH MMU (bsc#1236743 ltc#211409).
- powerpc: export MIN RMA size (bsc#1236743 ltc#211409).
- commit dbac901
* Wed Feb  5 2025 nmorey@suse.com
- vsock: Keep the binding until socket destruction (git-fixes)
- commit 5950ee8
* Wed Feb  5 2025 nmorey@suse.com
- vsock: prevent null-ptr-deref in vsock_*[has_data|has_space] (CVE-2025-21666 bsc#1236680)
- commit 55d1d4a
* Wed Feb  5 2025 nmorey@suse.com
- vsock: reset socket state when de-assigning the transport (git-fixes)
- commit 383ac2c
* Wed Feb  5 2025 nmorey@suse.com
- vsock/virtio: cancel close work in the destructor (git-fixes)
- commit 4252990
* Wed Feb  5 2025 nmorey@suse.com
- vsock/bpf: return early if transport is not assigned (CVE-2025-21670 bsc#1236685)
- commit e7946d0
* Wed Feb  5 2025 nmorey@suse.com
- vsock/virtio: discard packets if the transport changes (CVE-2025-21669 bsc#1236683)
- commit a36ac6c
* Wed Feb  5 2025 ailiop@suse.com
- Update config files: disable tomoyo lsm (jsc#PED-12020)
- commit 08c6cff
* Wed Feb  5 2025 nmorey@suse.com
- net/mlx5: Clear port select structure when fail to create (bsc#1236694 CVE-2025-21675)
- commit 7d1f9fd
* Wed Feb  5 2025 nmorey@suse.com
- mptcp: fix TCP options overflow. (bsc#1235914 CVE-2024-57882)
- commit edaa080
* Wed Feb  5 2025 sjaeckel@suse.de
- net: defer final 'struct net' free in netns dismantle
  (CVE-2024-56658 bsc#1235441).
- commit d1e2d42
* Wed Feb  5 2025 sjaeckel@suse.de
- Refresh
  patches.suse/powerpc-book3s64-hugetlb-Fix-disabling-hugetlb-when-fadump-is-active.patch.
- commit 4cd4a3a
* Tue Feb  4 2025 mgorman@suse.de
- mm/compaction: fix UBSAN shift-out-of-bounds warning (git fixes
  (mm/compaction)).
- commit 42344d4
* Tue Feb  4 2025 vbabka@suse.cz
- mm: don't try THP alignment for FS without get_unmapped_area
  (bsc#1236648).
- commit 95593b1
* Tue Feb  4 2025 vbabka@suse.cz
- mm: respect mmap hint address when aligning for THP
  (bsc#1236648).
- commit 1ea50ed
* Tue Feb  4 2025 vbabka@suse.cz
- mm: remove unnecessary page_table_lock on stack expansion
  (bsc#1236648).
- commit 6f2730b
* Tue Feb  4 2025 vbabka@suse.cz
- mm: remove misleading 'unlikely' hint in
  vms_gather_munmap_vmas() (bsc#1236648).
- commit 5eed911
* Tue Feb  4 2025 vbabka@suse.cz
- mm: correct typo in MMAP_STATE() macro (bsc#1236648).
- vma: detect infinite loop in vma tree (bsc#1236648).
- commit f1dbf1d
* Tue Feb  4 2025 dwagner@suse.de
- Update
  patches.suse/nvme-tcp-Fix-I-O-queue-cpu-spreading-for-multiple-co.patch
  (git-fixes bsc#1224049).
- commit b40b27f
* Tue Feb  4 2025 ailiop@suse.com
- xfs: Add error handling for xfs_reflink_cancel_cow_range
  (git-fixes).
- commit b508427
* Tue Feb  4 2025 ailiop@suse.com
- xfs: Propagate errors from xfs_reflink_cancel_cow_range in
  xfs_dax_write_iomap_end (git-fixes).
- commit e231dcf
* Tue Feb  4 2025 ailiop@suse.com
- xfs: don't call remap_verify_area with sb write protection held
  (git-fixes).
- commit b243b98
* Tue Feb  4 2025 tbogendoerfer@suse.de
- r8169: enable SG/TSO on selected chip versions per default
  (bsc#1235874).
- commit 2795291
* Tue Feb  4 2025 tbogendoerfer@suse.de
- tools: ynl: c: correct reverse decode of empty attrs
  (git-fixes).
- net/mlx5e: Fix inversion dependency warning while enabling
  IPsec tunnel (CVE-2025-21674 bsc#1236688).
- net: fec: handle page_pool_dev_alloc_pages error (CVE-2025-21676
  bsc#1236696).
- pfcp: Destroy device along with udp socket's netns dismantle
  (CVE-2025-21677 bsc#1236697).
- gtp: Destroy device along with udp socket's netns dismantle
  (CVE-2025-21678 bsc#1236698).
- gtp: Use for_each_netdev_rcu() in gtp_genl_dump_pdp()
  (git-fixes).
- eth: bnxt: always recalculate features after XDP clearing,
  fix null-deref (CVE-2025-21682 bsc#1236703).
- commit 7d6efad
* Tue Feb  4 2025 ptesarik@suse.com
- Update config files: Switch to CONFIG_PREEMPT_RT
- commit af14e50
* Tue Feb  4 2025 shung-hsi.yu@suse.com
- selftests/bpf: validate that tail call invalidates packet
  pointers (git-fixes).
- bpf: consider that tail calls invalidate packet pointers
  (git-fixes).
- bpf: refactor bpf_helper_changes_pkt_data to use helper number
  (git-fixes).
- bpf: Remove unnecessary kfree(im_node) in lpm_trie_update_elem
  (git-fixes).
- bpf: Zero index arg error string for dynptr and iter
  (git-fixes).
- selftests/bpf: Add tests for iter arg check (git-fixes).
- bpf: Ensure reg is PTR_TO_STACK in process_iter_arg (git-fixes).
- bpftool: fix potential NULL pointer dereferencing in prog_dump()
  (git-fixes).
- bpf: put bpf_link's program when link is safe to be deallocated
  (git-fixes).
- selftests/bpf: Add push/pop checking for msg_verify_data in
  test_sockmap (git-fixes).
- selftests/bpf: Fix total_bytes in msg_loop_rx in test_sockmap
  (git-fixes).
- selftests/bpf: Fix SENDPAGE data logic in test_sockmap
  (git-fixes).
- selftests/bpf: Add txmsg_pass to pull/push/pop in test_sockmap
  (git-fixes).
- selftests/bpf: Fix txmsg_redir of test_txmsg_pull in
  test_sockmap (git-fixes).
- selftests/bpf: Fix msg_verify_data in test_sockmap (git-fixes).
- selftests/bpf: add missing header include for htons (git-fixes).
- bpf: Add kernel symbol for struct_ops trampoline (git-fixes).
- bpf: Use function pointers count as struct_ops links count
  (git-fixes).
- selftests/bpf: skip the timer_lockup test for single-CPU nodes
  (git-fixes).
- selftests/bpf: Test the update operations for htab of maps
  (git-fixes).
- selftests/bpf: Move ENOTSUPP from bpf_util.h (git-fixes).
- bpf: Call free_htab_elem() after htab_unlock_bucket()
  (git-fixes).
- selftests/bpf: Add kprobe session verifier test for return value
  (git-fixes).
- bpf: Allow return values 0 and 1 for kprobe session (git-fixes).
- selftests/bpf: Clean up open-coded gettid syscall invocations
  (git-fixes).
- selftests/bpf: Add tests for tail calls with locks and refs
  (git-fixes).
- bpf: Unify resource leak checks (git-fixes).
- bpf: Tighten tail call checks for lingering locks, RCU,
  preempt_disable (git-fixes).
- bpf, bpftool: Fix incorrect disasm pc (git-fixes).
- libbpf: move global data mmap()'ing into bpf_object__load()
  (git-fixes).
- selftests/bpf: fix test_spin_lock_fail.c's global vars usage
  (git-fixes).
- selftests/bpf: Add test to verify tailcall and freplace
  restrictions (git-fixes).
- bpf: Prevent tailcall infinite loop caused by freplace
  (git-fixes).
- libbpf: never interpret subprogs in .text as entry programs
  (git-fixes).
- samples/bpf: Fix a resource leak (git-fixes).
- libbpf: fix sym_is_subprog() logic for weak global subprogs
  (git-fixes).
- selftests/bpf: Fix backtrace printing for selftests crashes
  (git-fixes).
- bpf: Fix the xdp_adjust_tail sample prog issue (git-fixes).
- selftests: bpf: Add missing per-arch include path (git-fixes).
- libbpf: Add missing per-arch include path (git-fixes).
- libbpf: Fix output .symtab byte-order during linking
  (git-fixes).
- selftests/bpf: Fix uprobe_multi compilation error (git-fixes).
- libbpf: Fix expected_attach_type set handling in program load
  callback (git-fixes).
- commit 9b2dc81
* Mon Feb  3 2025 ailiop@suse.com
- NFSv4.2: mark OFFLOAD_CANCEL MOVEABLE (git-fixes).
- commit 29678bd
* Mon Feb  3 2025 ailiop@suse.com
- NFSv4.2: fix COPY_NOTIFY xdr buf size calculation (git-fixes).
- commit d5313f5
* Mon Feb  3 2025 ailiop@suse.com
- nfs: fix incorrect error handling in LOCALIO (git-fixes).
- commit 9daaf72
* Mon Feb  3 2025 ailiop@suse.com
- Revert "SUNRPC: Reduce thread wake-up rate when receiving
  large RPC messages" (git-fixes).
- commit 39ec528
* Mon Feb  3 2025 ailiop@suse.com
- NFSD: Insulate nfsd4_encode_read_plus_data() from page
  boundaries in the encode buffer (git-fixes).
- commit ffa4780
* Mon Feb  3 2025 ailiop@suse.com
- NFSD: Insulate nfsd4_encode_read_plus() from page boundaries
  in the encode buffer (git-fixes).
- commit fd89a72
* Mon Feb  3 2025 ailiop@suse.com
- NFSD: Insulate nfsd4_encode_read() from page boundaries in
  the encode buffer (git-fixes).
- commit a5474b1
* Mon Feb  3 2025 ailiop@suse.com
- NFSD: fix decoding in nfs4_xdr_dec_cb_getattr (git-fixes).
- commit 744c03a
* Mon Feb  3 2025 ailiop@suse.com
- nfsd: fix legacy client tracking initialization (git-fixes).
- commit b058f86
* Mon Feb  3 2025 davide.benini@suse.com
- net: inet6: do not leave a dangling sk pointer in inet6_create()
  (CVE-2024-56600 bsc#1235217).
- commit 001ffac
* Mon Feb  3 2025 pmladek@suse.com
- printk: Defer legacy printing when holding printk_cpu_sync
  (bsc#1236733).
- commit 35fb637
* Mon Feb  3 2025 ailiop@suse.com
- iomap: avoid avoid truncating 64-bit offset to 32 bits
  (git-fixes).
- commit dcd6fd5
* Mon Feb  3 2025 ailiop@suse.com
- iomap: pass byte granular end position to iomap_add_to_ioend
  (git-fixes).
- commit 3e58ba8
* Mon Feb  3 2025 ailiop@suse.com
- cachefiles: Parse the "secctx" immediately (git-fixes).
- commit d3745ec
* Mon Feb  3 2025 ailiop@suse.com
- dlm: fix srcu_read_lock() return type to int (git-fixes).
- commit befab55
* Mon Feb  3 2025 ailiop@suse.com
- dlm: fix removal of rsb struct that is master and dir record
  (git-fixes).
- commit 0dc790e
* Mon Feb  3 2025 ailiop@suse.com
- xfs: check for dead buffers in xfs_buf_find_insert (git-fixes).
- commit 518b962
* Mon Feb  3 2025 ailiop@suse.com
- xfs: fix a double completion for buffers on in-memory targets
  (git-fixes).
- commit 230cef5
* Mon Feb  3 2025 ailiop@suse.com
- xfs/libxfs: replace kmalloc() and memcpy() with kmemdup()
  (git-fixes).
- commit e30e5c1
* Mon Feb  3 2025 jgross@suse.com
- Update config files: remove XEN PV support and kernel side PV device
  backends (jsc#PED-11779)
- commit 31e5715
* Mon Feb  3 2025 iivanov@suse.de
- arm64: dts: marvell: cn9131-cf-solidwan: fix cp1 comphy links (git-fixes)
- commit c3b3ad4
* Mon Feb  3 2025 iivanov@suse.de
- arm64: dts: rockchip: increase gmac rx_delay on rk3399-puma (git-fixes)
- commit 040d5bd
* Mon Feb  3 2025 iivanov@suse.de
- arm64: dts: rockchip: fix num-channels property of wolfvision pf5 mic (git-fixes)
- commit 80bffba
* Mon Feb  3 2025 iivanov@suse.de
- arm64: dts: rockchip: Fix PCIe3 handling for Edgeble-6TOPS Modules (git-fixes)
- commit 6eeb73e
* Mon Feb  3 2025 iivanov@suse.de
- arm64: dts: rockchip: Fix sdmmc access on rk3308-rock-s0 v1.1 boards (git-fixes)
- commit 0f4955c
* Mon Feb  3 2025 iivanov@suse.de
- arm64: tegra: Fix Tegra234 PCIe interrupt-map (git-fixes)
- commit 17b2e93
* Mon Feb  3 2025 iivanov@suse.de
- arm64: tegra: Disable Tegra234 sce-fabric node (git-fixes)
- commit 5fbc68f
* Mon Feb  3 2025 iivanov@suse.de
- arm64: tegra: Fix typo in Tegra234 dce-fabric compatible (git-fixes)
- commit b60c09f
* Mon Feb  3 2025 ailiop@suse.com
- xfs: don't shut down the filesystem for media failures beyond
  end of log (git-fixes).
- commit b3253c4
* Mon Feb  3 2025 iivanov@suse.de
- arm64: tegra: Fix DMA ID for SPI2 (git-fixes)
- commit ed27827
* Mon Feb  3 2025 ailiop@suse.com
- gfs2: Truncate address space when flipping GFS2_DIF_JDATA flag
  (git-fixes).
- commit 2bdb106
* Mon Feb  3 2025 iivanov@suse.de
- arm64: dts: rockchip: Fix Turing RK1 PCIe3 hang (git-fixes)
- commit 6545f4a
* Mon Feb  3 2025 iivanov@suse.de
- arm64: dts: rockchip: Split up RK3588's PCIe pinctrls (git-fixes)
- commit ee6c1d3
* Mon Feb  3 2025 iivanov@suse.de
- arm64/mm: Override PARange for !LPA2 and use it consistently (git-fixes)
- commit 46430f7
* Mon Feb  3 2025 iivanov@suse.de
- arm64/mm: Reduce PA space to 48 bits when LPA2 is not enabled (git-fixes)
- commit 1e5b33c
* Mon Feb  3 2025 iivanov@suse.de
- arm64: Filter out SVE hwcaps when FEAT_SVE isn't implemented (git-fixes)
- commit 6644a3b
* Mon Feb  3 2025 iivanov@suse.de
- arm64/sme: Move storage of reg_smidr to __cpuinfo_store_cpu() (git-fixes)
- commit ee0c3e4
* Mon Feb  3 2025 iivanov@suse.de
- arm64: stacktrace: Don't WARN when unwinding other tasks (git-fixes)
- commit c1b5cbf
* Mon Feb  3 2025 dwagner@suse.de
- nvme: fix bogus kzalloc() return check in
  nvme_init_effects_log() (git-fixes).
- commit d42e4b8
* Mon Feb  3 2025 oneukum@suse.com
- USB: serial: option: add Neoway N723-EA support (git-fixes).
- commit e972bca
* Mon Feb  3 2025 oneukum@suse.com
- USB: serial: option: add MeiG Smart SRM815 (git-fixes).
- commit 77f7a0f
* Mon Feb  3 2025 oneukum@suse.com
- USB: serial: cp210x: add Phoenix Contact UPS Device (git-fixes).
- commit f332140
* Mon Feb  3 2025 oneukum@suse.com
- usb-storage: Add max sectors quirk for Nokia 208 (git-fixes).
- commit 0ad9095
* Mon Feb  3 2025 dwagner@suse.de
- nvme: Add error path for xa_store in nvme_init_effects
  (git-fixes).
- nvme: Add error check for xa_store in nvme_get_effects_log
  (git-fixes).
- nvme-tcp: Fix I/O queue cpu spreading for multiple controllers
  (git-fixes).
- nvmet: propagate npwg topology (git-fixes).
- commit 7f10443
* Mon Feb  3 2025 oneukum@suse.com
- usbnet: ipheth: fix DPE OoB read (git-fixes).
- commit b2a02b8
* Mon Feb  3 2025 oneukum@suse.com
- usbnet: ipheth: break up NCM header size computation
  (git-fixes).
- commit 7a83cc0
* Mon Feb  3 2025 oneukum@suse.com
- usbnet: ipheth: refactor NCM datagram loop (git-fixes).
- commit 095ff33
* Mon Feb  3 2025 ohering@suse.de
- scsi: storvsc: Ratelimit warning logs to prevent VM denial of
  service (git-fixes).
- scsi: storvsc: Don't assume cpu_possible_mask is dense
  (git-fixes).
- hyperv: Do not overlap the hvcall IO areas in
  hv_vtl_apicid_to_vp_id() (git-fixes).
- hyperv: Do not overlap the hvcall IO areas in get_vtl()
  (git-fixes).
- hyperv: Enable the hypercall output page for the VTL mode
  (git-fixes).
- hv_balloon: Fallback to generic_online_page() for non-HV hot
  added mem (git-fixes).
- Drivers: hv: vmbus: Log on missing offers if any (git-fixes).
- Drivers: hv: vmbus: Wait for boot-time offers during boot and
  resume (git-fixes).
- uio_hv_generic: Add a check for HV_NIC for send, receive
  buffers setup (git-fixes).
- iommu/hyper-v: Don't assume cpu_possible_mask is dense
  (git-fixes).
- Drivers: hv: Don't assume cpu_possible_mask is dense
  (git-fixes).
- x86/hyperv: Don't assume cpu_possible_mask is dense (git-fixes).
- hyperv: Remove the now unused hyperv-tlfs.h files (git-fixes).
- hyperv: Switch from hyperv-tlfs.h to hyperv/hvhdk.h (git-fixes).
- hyperv: Add new Hyper-V headers in include/hyperv (git-fixes).
- hyperv: Clean up unnecessary #includes (git-fixes).
- hyperv: Move hv_connection_id to hyperv-tlfs.h (git-fixes).
- hv_netvsc: Replace one-element array with flexible array member
  (git-fixes).
- commit bf2065f
* Sun Feb  2 2025 tiwai@suse.de
- Revert "media: uvcvideo: Require entities to have a non-zero
  unique ID" (bsc#1235894).
- wifi: rtl8xxxu: add more missing rtl8192cu USB IDs
  (stable-fixes).
- drm/amd/display: Initialize denominator defaults to 1
  (stable-fixes).
- drm/amd/display: Use HW lock mgr for PSR1 (stable-fixes).
- drm/connector: hdmi: Validate supported_formats matches
  ycbcr_420_allowed (stable-fixes).
- commit 839fcdd
* Sat Feb  1 2025 tiwai@suse.de
- ASoC: acp: Support microphone from Lenovo Go S (stable-fixes).
- ALSA: pcm: use new array-copying-wrapper (stable-fixes).
- ALSA: usb-audio: Add delay quirk for iBasso DC07 Pro
  (stable-fixes).
- commit ccad405
* Sat Feb  1 2025 tiwai@suse.de
- PCI: Restore original INTX_DISABLE bit by pcim_intx()
  (git-fixes).
- kconfig: fix memory leak in sym_warn_unmet_dep() (git-fixes).
- kconfig: fix file name in warnings when loading
  KCONFIG_DEFCONFIG_LIST (git-fixes).
- genksyms: fix memory leak when the same symbol is read from
  * .symref file (git-fixes).
- genksyms: fix memory leak when the same symbol is added from
  source (git-fixes).
- ata: libata-core: Add ATA_QUIRK_NOLPM for Samsung SSD 870 QVO
  drives (git-fixes).
- ASoC: amd: acp: Fix possible deadlock (git-fixes).
- ASoC: da7213: Initialize the mutex (git-fixes).
- ASoC: rockchip: i2s_tdm: Re-add the set_sysclk callback
  (git-fixes).
- ALSA: hda: Fix headset detection failure due to unstable sort
  (git-fixes).
- ALSA: hda/realtek: Fix quirk matching for Legion Pro 7
  (git-fixes).
- commit 4daaa58
* Fri Jan 31 2025 krisman@suse.de
- io_uring/eventfd: ensure io_eventfd_signal() defers another
  RCU period (CVE-2025-21655 bsc#1236163).
- commit 8c48635
* Fri Jan 31 2025 krisman@suse.de
- io_uring/eventfd: abstract out ev_fd put helper (CVE-2025-21655
  bsc#1236163).
- commit 3ee0779
* Fri Jan 31 2025 krisman@suse.de
- io_uring/sqpoll: zero sqd->thread on tctx errors (CVE-2025-21633
  bsc#1236108).
- commit e81e97d
* Fri Jan 31 2025 mgorman@suse.de
- sched_ext: update scx_bpf_dsq_insert() doc for SCX_DSQ_LOCAL_ON
  (git fixes (sched)).
- cpufreq: schedutil: Fix superfluous updates caused by
  need_freq_update (git fixes (sched)).
- sched/fair: Fix update_cfs_group() vs DELAY_DEQUEUE (git fixes
  (sched)).
- sched/fair: Fix EEVDF entity placement bug causing scheduling
  lag (git fixes (sched)).
- sched_ext: idle: Refresh idle masks during idle-to-idle
  transitions (git fixes (sched)).
- freezer, sched: Report frozen tasks as 'D' instead of 'R'
  (git fixes (sched)).
- epoll: Add synchronous wakeup support for ep_poll_callback
  (git fixes (sched)).
- commit 3d30d97
* Fri Jan 31 2025 ptesarik@suse.com
- mm/rodata_test: use READ_ONCE() to read const variable
  (git-fixes).
- commit d31a779
* Fri Jan 31 2025 ggherdovich@suse.cz
- cpufreq/amd-pstate: Fix prefcore rankings (git-fixes).
- commit 6e54c2a
* Fri Jan 31 2025 tiwai@suse.de
- rtc: zynqmp: Fix optional clock name property (git-fixes).
- rtc: loongson: clear TOY_MATCH0_REG in loongson_rtc_isr()
  (git-fixes).
- rtc: pcf85063: fix potential OOB write in PCF85063 NVMEM read
  (git-fixes).
- rtc: tps6594: Fix integer overflow on 32bit systems (git-fixes).
- PM: sleep: core: Synchronize runtime PM status of parents and
  children (git-fixes).
- PM: hibernate: Add error handling for syscore_suspend()
  (git-fixes).
- Bluetooth: L2CAP: accept zero as a special value for MTU
  auto-selection (git-fixes).
- Bluetooth: btnxpuart: Fix glitches seen in dual A2DP streaming
  (git-fixes).
- Bluetooth: btusb: mediatek: Add locks for
  usb_driver_claim_interface() (git-fixes).
- usbnet: ipheth: use static NDP16 location in URB (git-fixes).
- usbnet: ipheth: check that DPE points past NCM header
  (git-fixes).
- usbnet: ipheth: fix possible overflow in DPE length check
  (git-fixes).
- net: usb: rtl8150: enable basic endpoint checking (git-fixes).
- net: phy: c45-tjaxx: add delay between MDIO write and read in
  soft_reset (git-fixes).
- net: rose: fix timer races against user threads (git-fixes).
- net: phy: marvell-88q2xxx: Fix temperature measurement with
  reset-gpios (git-fixes).
- NFC: nci: Add bounds checking in nci_hci_create_pipe()
  (git-fixes).
- docs: power: Fix footnote reference for Toshiba Satellite
  P10-554 (git-fixes).
- gpio: mxc: remove dead code after switch to DT-only (git-fixes).
- commit ca8e15a
* Fri Jan 31 2025 tonyj@suse.de
- docs: ABI: sysfs-bus-event_source-devices-vpa-pmu: Fix htmldocs
  errors (jsc#PED-10947, git-fixes).
- commit 84a7517
* Fri Jan 31 2025 tonyj@suse.de
- perf/x86/intel: Add PMU support for ArrowLake-H (jsc#PED-10527).
- perf/x86/intel: Support hybrid PMU with multiple atom uarchs
  (jsc#PED-10527).
- x86/cpu/intel: Define helper to get CPU core native ID
  (jsc#PED-10527).
- perf/x86: Refine hybrid_pmu_type defination (jsc#PED-10527).
- commit d4840cf
* Fri Jan 31 2025 tonyj@suse.de
- perf/x86/intel/uncore: Add Clearwater Forest support
  (jsc#PED-10657).
- commit 3b2b3d7
* Fri Jan 31 2025 tonyj@suse.de
- perf/x86/intel: Add Arrow Lake U support (jsc#PED-10525).
- commit 7de75f6
* Fri Jan 31 2025 tonyj@suse.de
- powerpc/perf: Add per-task/process monitoring to vpa_pmu driver
  (jsc#PED-10947).
- powerpc/kvm: Add vpa latency counters to kvm_vcpu_arch
  (jsc#PED-10947).
- docs: ABI: sysfs-bus-event_source-devices-vpa-pmu: Document
  sysfs event format entries for vpa_pmu (jsc#PED-10947).
- commit a4dd907
* Fri Jan 31 2025 tonyj@suse.de
- powerpc/perf: Add perf interface to expose vpa counters
  (jsc#PED-10947).
- Update config files (ppc64le/default/CONFIG_VPA_PMU)
- Update supported.conf (arch/powerpc/perf/vpa-pmu)
- commit f7b6f3e
* Fri Jan 31 2025 tonyj@suse.de
- perf/x86/rapl: Add core energy counter support for AMD CPUs
  (jsc#PED-11773).
- perf/x86/rapl: Move the cntr_mask to rapl_pmus struct
  (jsc#PED-11773).
- perf/x86/rapl: Remove the global variable rapl_msrs
  (jsc#PED-11773).
- perf/x86/rapl: Modify the generic variable names to *_pkg*
  (jsc#PED-11773).
- perf/x86/rapl: Add arguments to the init and cleanup functions
  (jsc#PED-11773).
- perf/x86/rapl: Make rapl_model struct global (jsc#PED-11773).
- perf/x86/rapl: Rename rapl_pmu variables (jsc#PED-11773).
- perf/x86/rapl: Remove the cpu_to_rapl_pmu() function
  (jsc#PED-11773).
- x86/topology: Introduce topology_logical_core_id()
  (jsc#PED-11773).
- perf/x86/rapl: Remove the unused get_rapl_pmu_cpumask() function
  (jsc#PED-11773).
- perf/x86/rapl: Clean up cpumask and hotplug (jsc#PED-11773).
- perf/x86/rapl: Move the pmu allocation out of CPU hotplug
  (jsc#PED-11773).
- x86/amd: Use heterogeneous core topology for identifying boost
  numerator (jsc#PED-11773).
- x86/cpu: Add CPU type to struct cpuinfo_topology
  (jsc#PED-11773).
- x86/cpu: Enable SD_ASYM_PACKING for PKG domain on AMD
  (jsc#PED-11773).
- x86/cpufeatures: Add X86_FEATURE_AMD_HETEROGENEOUS_CORES
  (jsc#PED-11773).
- x86/cpufeatures: Rename X86_FEATURE_FAST_CPPC to have AMD prefix
  (jsc#PED-11773).
- commit c61d138
* Thu Jan 30 2025 vbabka@suse.cz
- mm: correctly reference merged VMA (bsc#1236648).
- commit 35b5461
* Thu Jan 30 2025 vbabka@suse.cz
- mm/vma: the pgoff is correct if can_merge_right (bsc#1236648).
- commit 7e8683d
* Thu Jan 30 2025 vbabka@suse.cz
- mm: defer second attempt at merge on mmap() (bsc#1236648).
- commit b2d49c9
* Thu Jan 30 2025 vbabka@suse.cz
- mm: remove unnecessary reset state logic on merge new VMA
  (bsc#1236648).
- commit b13bccd
* Thu Jan 30 2025 vbabka@suse.cz
- mm: refactor __mmap_region() (bsc#1236648).
- commit 88a5663
* Thu Jan 30 2025 vbabka@suse.cz
- mm: isolate mmap internal logic to mm/vma.c (bsc#1236648).
- commit d29a53f
* Thu Jan 30 2025 vbabka@suse.cz
- tools: testing: add additional vma_internal.h stubs
  (bsc#1236648).
- commit db16c3e
* Thu Jan 30 2025 ggherdovich@suse.cz
- cpufreq/amd-pstate: Use boost numerator for upper bound of
  frequencies (git-fixes).
- cpufreq/amd-pstate: Store the boost numerator as highest perf
  again (git-fixes).
- commit 6f5ef23
* Thu Jan 30 2025 ggherdovich@suse.cz
- cpufreq/amd-pstate: Detect preferred core support before driver
  registration (git-fixes).
- cpufreq/amd-pstate: Move registration after static function
  call update (git-fixes).
- cpufreq/amd-pstate: Push adjust_perf vfunc init into cpu_init
  (git-fixes).
- cpufreq/amd-pstate: Align offline flow of shared memory and
  MSR based systems (git-fixes).
- cpufreq/amd-pstate: Call cppc_set_epp_perf in the reenable
  function (git-fixes).
- cpufreq/amd-pstate: Do not attempt to clear MSR_AMD_CPPC_ENABLE
  (git-fixes).
- cpufreq/amd-pstate: Rename functions that enable CPPC
  (git-fixes).
- cpufreq/amd-pstate: Remove the redundant amd_pstate_set_driver()
  call (git-fixes).
- cpufreq/amd-pstate: Remove the switch case in amd_pstate_init()
  (git-fixes).
- cpufreq/amd-pstate: Call amd_pstate_set_driver() in
  amd_pstate_register_driver() (git-fixes).
- cpufreq/amd-pstate: Call amd_pstate_register() in
  amd_pstate_init() (git-fixes).
- cpufreq/amd-pstate: Set the initial min_freq to
  lowest_nonlinear_freq (git-fixes).
- cpufreq/amd-pstate: Remove the redundant verify() function
  (git-fixes).
- cpufreq/amd-pstate: Rename MSR and shared memory specific
  functions (git-fixes).
- commit 3a64362
* Thu Jan 30 2025 ggherdovich@suse.cz
- cpufreq: ACPI: Fix max-frequency computation (git-fixes
  jsc#PED-12064).
- commit 8847124
* Thu Jan 30 2025 tiwai@suse.de
- Move upstreamed lpfc and initramfs patches into sorted section
- commit 3188ca8
* Thu Jan 30 2025 tiwai@suse.de
- Input: synaptics - fix crash when enabling pass-through port
  (bsc#1219522).
- commit 37ec4ab
* Thu Jan 30 2025 msuchanek@suse.de
- powerpc/pseries/eeh: Fix get PE state translation (bsc#1215199).
- commit 9a95d7d
* Thu Jan 30 2025 msuchanek@suse.de
- Update config files.
  Disable accidentally enabled option
  ppc64le:
  CONFIG_IRQ_TIME_ACCOUNTING=n
- commit 482ad8d
* Thu Jan 30 2025 tiwai@suse.de
- ALSA: hda/realtek: Workaround for resume on Dell Venue 11 Pro
  7130 (bsc#1235686).
- commit 9e21a47
* Thu Jan 30 2025 msuchanek@suse.de
- powerpc/pseries/iommu: Don't unset window if it was never set
  (jsc#PED-10539 git-fixes).
- commit 198b0d2
* Thu Jan 30 2025 ggherdovich@suse.cz
- cpufreq: Move endif to the end of Kconfig file (git-fixes).
- commit bff3dd1
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/efa: Align interrupt related fields to same type (jsc#PED-11323)
- commit a47f3d4
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/hns: Support fast path for link-down events dispatching (jsc#PED-11323)
- commit f1c4b07
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/mlx5: Handle link status event only for LAG device (jsc#PED-11323)
- commit 0a2c27a
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/pvrdma: Support report_port_event() ops (jsc#PED-11323)
- commit e6aa938
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/mlx4: Support report_port_event() ops (jsc#PED-11323)
- commit c56ddb4
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/usnic: Support report_port_event() ops (jsc#PED-11323)
- commit a5970c5
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/siw: Remove deliver net device event (jsc#PED-11323)
- commit 4efbd9d
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/rxe: Remove deliver net device event (jsc#PED-11323)
- commit 1346d71
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/irdma: Remove deliver net device event (jsc#PED-10421)
- commit 59a167e
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/bnxt_re: Remove deliver net device event (jsc#PED-11235)
- commit 7c9ae24
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/core: Support link status events dispatching (jsc#PED-11323)
- commit 49e4368
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/core: Add ib_query_netdev_port() to query netdev port by IB device. (jsc#PED-11323)
- commit 0534314
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/core: Remove unused ib_copy_path_rec_from_user (jsc#PED-11323)
- commit 150e860
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/core: Remove unused ibdev_printk (jsc#PED-11323)
- commit 7975ae5
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/core: Remove unused ib_find_exact_cached_pkey (jsc#PED-11323)
- commit e46a588
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/core: Remove unused ib_ud_header_unpack (jsc#PED-11323)
- commit d4c2ff6
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/irdma: Remove unused irdma_cqp_*_fpm_val_cmd functions (jsc#PED-10421)
- commit ad0bc98
* Thu Jan 30 2025 nmorey@suse.com
- IB/hfi1: Remove unused hfi1_format_hwerrors (jsc#PED-10421)
- commit 6bd5a79
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/bnxt_re: Remove unnecessary header file inclusion (jsc#PED-11235)
- commit 213b4f3
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/bnxt_re: Eliminate need for some forward declarations (jsc#PED-11235)
- commit 786aa2c
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/bnxt_re: Optimize error handling in bnxt_re_probe (jsc#PED-11235)
- commit 71f48c3
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/bnxt_re: Remove unnecessary goto in bnxt_re_netdev_event (jsc#PED-11235)
- commit 4141d4d
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/bnxt_re: Remove extra new line in bnxt_re_netdev_event (jsc#PED-11235)
- commit dc177d4
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/mlx5: Extend ODP statistics with operation count (jsc#PED-1123)
  Refresh patches.suse/RDMA-mlx5-Fix-indirect-mkey-ODP-page-count.patch
- commit e60ad0e
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/mlx4: Use DMA iterator to write MTT (jsc#PED-1123)
- commit 1a553db
* Thu Jan 30 2025 nmorey@suse.com
- RDMA/mlx4: Use ib_umem_find_best_pgsz() to calculate MTT size (jsc#PED-1123)
- commit 25cc31e
* Thu Jan 30 2025 tiwai@suse.de
- dmaengine: ti: edma: fix OF node reference leaks in edma_driver
  (git-fixes).
- regulator: core: Add missing newline character (git-fixes).
- wifi: ath12k: fix read pointer after free in
  ath12k_mac_assign_vif_to_vdev() (git-fixes).
- wifi: rtw89: fix proceeding MCC with wrong scanning state
  after sequence changes (git-fixes).
- commit 04018e2
* Wed Jan 29 2025 jgross@suse.com
- virtio-blk: don't keep queue frozen during system suspend
  (CVE-2024-57946 bsc#1236247).
- commit 7fd5c04
* Wed Jan 29 2025 mhocko@suse.com
- netfilter: x_tables: fix LED ID check in led_tg_check()
  (CVE-2024-56650 bsc#1235430).
- commit 7f5dabf
* Wed Jan 29 2025 msuchanek@suse.de
- tpm: send_data: Wait longer for the TPM to become ready
  (bsc#1235870).
- commit cf67b6d
* Wed Jan 29 2025 jslaby@suse.cz
- serial: sh-sci: Increment the runtime usage counter for the
  earlycon device (git-fixes).
- serial: sh-sci: Clean sci_ports after at earlycon exit
  (git-fixes).
- serial: sh-sci: Do not probe the serial port if its slot in
  sci_ports is in use (git-fixes).
- serial: sh-sci: Move runtime PM enable to sci_probe_single()
  (git-fixes).
- serial: sh-sci: Drop __initdata macro for port_cfg (git-fixes).
- tty: Permit some TIOCL_SETSEL modes without CAP_SYS_ADMIN
  (git-fixes).
- tty: xilinx_uartps: split sysrq handling (git-fixes).
- serial: 8250: Adjust the timeout for FIFO mode (git-fixes).
- commit d006f88
* Wed Jan 29 2025 tiwai@suse.de
- driver core: class: Fix wild pointer dereferences in API
  class_dev_iter_next() (git-fixes).
- devcoredump: cleanup some comments (git-fixes).
- tools/bootconfig: Fix the wrong format specifier (git-fixes).
- serial: sh-sci: Do not probe the serial port if its slot in
  sci_ports[] is in use (git-fixes).
- serial: sh-sci: Drop __initdata macro for port_cfg (git-fixes).
- tty: Permit some TIOCL_SETSEL modes without CAP_SYS_ADMIN
  (git-fixes).
- tty: xilinx_uartps: split sysrq handling (git-fixes).
- serial: 8250: Adjust the timeout for FIFO mode (git-fixes).
- tty: mips_ejtag_fdc: fix one more u8 warning (git-fixes).
- LoongArch: Fix warnings during S3 suspend (git-fixes).
- commit b05d21a
* Tue Jan 28 2025 cfamullaconrad@suse.com
- tools/power turbostat: Add initial support for GraniteRapids-D
  (jsc#PED-10490).
- commit 5b7dffe
* Tue Jan 28 2025 nmorey@suse.com
- Enable iSER support for s390x (jsc#PED-3319)
- commit b386466
* Tue Jan 28 2025 tiwai@suse.de
- selftests/mm: virtual_address_range: avoid reading from VM_IO
  mappings (git-fixes).
- selftests/mm: virtual_address_range: unmap chunks after
  validation (git-fixes).
- selftests/mm/cow: modify the incorrect checking parameters
  (git-fixes).
- selftests/mm: use selftests framework to print test result
  (git-fixes).
- selftests/mm: fix condition in uffd_move_test_common()
  (git-fixes).
- selftests: mm: fix conversion specifiers in transact_test()
  (git-fixes).
- clk: clk-loongson2: Fix the number count of clk provider
  (git-fixes).
- clk: sunxi-ng: a100: enable MMC clock reparenting (git-fixes).
- clk: mmp2: call pm_genpd_init() only after genpd.name is set
  (git-fixes).
- clk: thead: Fix cpu2vp_clk for TH1520 AP_SUBSYS clocks
  (git-fixes).
- clk: thead: Add CLK_IGNORE_UNUSED to fix TH1520 boot
  (git-fixes).
- clk: thead: Fix clk gate registration to pass flags (git-fixes).
- clk: qcom: gcc-sdm845: Do not use shared clk_ops for QUPs
  (git-fixes).
- clk: qcom: gcc-x1e80100: Do not turn off usb_2 controller GDSC
  (git-fixes).
- clk: qcom: gcc-mdm9607: Fix cmd_rcgr offset for blsp1_uart6 rcg
  (git-fixes).
- clk: qcom: camcc-x1e80100: Set titan_top_gdsc as the parent
  GDSC of subordinate GDSCs (git-fixes).
- clk: qcom: clk-alpha-pll: fix alpha mode configuration
  (git-fixes).
- clk: qcom: dispcc-sm6350: Add missing parent_map for a clock
  (git-fixes).
- clk: qcom: gcc-sm6350: Add missing parent_map for two clocks
  (git-fixes).
- clk: qcom: clk-rpmh: prevent integer overflow in recalc_rate
  (git-fixes).
- clk: qcom: gcc-sm8650: Do not turn off PCIe GDSCs during
  gdsc_disable() (git-fixes).
- clk: qcom: gcc-sm8550: Do not turn off PCIe GDSCs during
  gdsc_disable() (git-fixes).
- clk: imx8mp: Fix clkout1/2 support (git-fixes).
- clk: sunxi-ng: a64: stop force-selecting PLL-MIPI as TCON0
  parent (git-fixes).
- clk: ralink: mtmips: remove duplicated 'xtal' clock for Ralink
  SoC RT3883 (git-fixes).
- clk: mediatek: mt2701-img: add missing dummy clk (git-fixes).
- clk: mediatek: mt2701-mm: add missing dummy clk (git-fixes).
- clk: mediatek: mt2701-bdp: add missing dummy clk (git-fixes).
- clk: mediatek: mt2701-aud: fix conversion to
  mtk_clk_simple_probe (git-fixes).
- clk: mediatek: mt2701-vdec: fix conversion to
  mtk_clk_simple_probe (git-fixes).
- clk: renesas: cpg-mssr: Fix 'soc' node handling in
  cpg_mssr_reserved_init() (git-fixes).
- clk: analogbits: Fix incorrect calculation of vco rate delta
  (git-fixes).
- clk: fix an OF node reference leak in of_clk_get_parent_name()
  (git-fixes).
- pstore/blk: trivial typo fixes (git-fixes).
- selftests/mm: set allocated memory to non-zero content in cow
  test (git-fixes).
- clk: clk-imx8mp-audiomix: fix function signature (git-fixes).
- clk: thead: Fix TH1520 emmc and shdci clock rate (git-fixes).
- efivarfs: Fix error on non-existent file (stable-fixes).
- qca_spi: Make driver probing reliable (git-fixes).
- qca_spi: Fix clock speed for multiple QCA7000 (git-fixes).
- commit 52abd40
* Tue Jan 28 2025 jslaby@suse.cz
- PCI: rcar-ep: Fix incorrect variable used when calling
  devm_request_mem_region() (git-fixes).
- PCI: microchip: Set inbound address translation for coherent
  or non-coherent mode (git-fixes).
- PCI: imx6: Add missing reference clock disable logic
  (git-fixes).
- PCI: imx6: Deassert apps_reset in imx_pcie_deassert_core_reset()
  (git-fixes).
- PCI: imx6: Skip controller_id generation logic for i.MX7D
  (git-fixes).
- PCI: imx6: Configure PHY based on Root Complex or Endpoint mode
  (git-fixes).
- PCI: dwc: Always stop link in the dw_pcie_suspend_noirq
  (git-fixes).
- PCI: qcom: Update ICC and OPP values after Link Up event
  (git-fixes).
- PCI: endpoint: pci-epf-test: Fix check for DMA MEMCPY test
  (git-fixes).
- PCI: endpoint: pci-epf-test: Set dma_chan_rx pointer to NULL
  on error (git-fixes).
- PCI: dwc: ep: Prevent changing BAR size/flags in
  pci_epc_set_bar() (git-fixes).
- PCI: dwc: ep: Write BAR_MASK before iATU registers in
  pci_epc_set_bar() (git-fixes).
- PCI: endpoint: Finish virtual EP removal in
  pci_epf_remove_vepf() (git-fixes).
- PCI: endpoint: Destroy the EPC device in devm_pci_epc_destroy()
  (git-fixes).
- PCI/ASPM: Save parent L1SS config in pci_save_aspm_l1ss_state()
  (git-fixes).
- commit 6aedcaa
* Tue Jan 28 2025 jslaby@suse.cz
- genirq: Make handle_enforce_irqctx() unconditionally available
  (git-fixes).
- commit c47d221
* Tue Jan 28 2025 jslaby@suse.cz
- Refresh patches.suse/tpm-Map-the-ACPI-provided-event-log.patch.
  Add Alt-commit.
- commit 256dd4e
* Tue Jan 28 2025 jslaby@suse.cz
- ipmi: ssif_bmc: Fix new request loss when bmc ready for a
  response (git-fixes).
- ipmi: ipmb: Add check devm_kasprintf() returned value
  (git-fixes).
- commit 513ad80
* Tue Jan 28 2025 nik.borisov@suse.com
- x86: Fix build regression with CONFIG_KEXEC_JUMP enabled (git-fixes).
- commit e16e19e
* Tue Jan 28 2025 nik.borisov@suse.com
- clocksource: Make negative motion detection more robust (git-fixes).
- commit fca041b
* Tue Jan 28 2025 tiwai@suse.de
- drm/v3d: Assign job pointer to NULL before signaling the fence
  (git-fixes).
- drm/amd/display: Fix error pointers in
  amdgpu_dm_crtc_mem_type_changed (git-fixes).
- iio: light: as73211: fix channel handling in only-color
  triggered buffer (git-fixes).
- intel_th: core: fix kernel-doc warnings (git-fixes).
- bus: mhi: host: Free mhi_buf vector inside
  mhi_alloc_bhie_table() (git-fixes).
- iio: iio-mux: kzalloc instead of devm_kzalloc to ensure page
  alignment (git-fixes).
- iio: adc: ad_sigma_delta: Handle CS assertion as intended in
  ad_sd_read_reg_raw() (git-fixes).
- iio: adc: ad7124: Refuse invalid input specifiers (git-fixes).
- iio: adc: ad7124: Don't create more channels than the driver
  can handle (git-fixes).
- extcon: realtek: fix NULL deref check in extcon_rtk_type_c_probe
  (git-fixes).
- misc: fastrpc: Fix copy buffer page size (git-fixes).
- misc: fastrpc: Fix registered buffer page address (git-fixes).
- misc: fastrpc: Deregister device nodes properly in error
  scenarios (git-fixes).
- VMCI: fix reference to ioctl-number.rst (git-fixes).
- drivers/card_reader/rtsx_usb: Restore interrupt based detection
  (git-fixes).
- uio: uio_dmem_genirq: check the return value of devm_kasprintf()
  (git-fixes).
- uio: Fix return value of poll (git-fixes).
- misc: misc_minor_alloc to use ida for all dynamic/misc dynamic
  minors (git-fixes).
- pps: Fix a use-after-free (git-fixes).
- Revert "usb: gadget: u_serial: Disable ep before setting port to
  null to fix the crash caused by port being null" (stable-fixes).
- usb: typec: tcpci: Prevent Sink disconnection before
  vPpsShutdown in SPR PPS (git-fixes).
- usb: dwc3: core: Defer the probe until USB power supply ready
  (git-fixes).
- USB: serial: quatech2: fix null-ptr-deref in
  qt2_process_read_urb() (git-fixes).
- usb: typec: tcpm: set SRC_SEND_CAPABILITIES timeout to
  PD_T_SENDER_RESPONSE (git-fixes).
- usb: host: xhci-plat: Assign shared_hcd->rsrc_start (git-fixes).
- usb: dwc3-am62: Fix an OF node leak in phy_syscon_pll_refclk()
  (git-fixes).
- usb: dwc3: Skip resume if pm_runtime_set_active() fails
  (git-fixes).
- usb: xhci: Fix NULL pointer dereference on certain command
  aborts (git-fixes).
- usb: gadget: f_tcm: Don't prepare BOT write request twice
  (git-fixes).
- usb: gadget: f_tcm: ep_autoconfig with fullspeed endpoint
  (git-fixes).
- usb: gadget: f_tcm: Fix Get/SetInterface return value
  (git-fixes).
- usb: gadget: f_tcm: Decrement command ref count on cleanup
  (git-fixes).
- usb: gadget: f_tcm: Translate error to sense (git-fixes).
- usb: gadget: f_tcm: Don't free command immediately (git-fixes).
- usb: gadget: functionfs: fix spellos (git-fixes).
- pwm: microchip-core: fix incorrect comparison with max period
  (git-fixes).
- power: reset: as3722-poweroff: Remove unnecessary return in
  as3722_poweroff_probe (git-fixes).
- power: ip5xxx_power: Fix return value on ADC read errors
  (git-fixes).
- commit f4aee60
* Mon Jan 27 2025 mkoutny@suse.com
- padata: add pd get/put refcnt helper (git-fixes).
- commit 816d211
* Mon Jan 27 2025 nmorey@suse.com
- RDMA/hns: Clean up the legacy CONFIG_INFINIBAND_HNS (git-fixes)
- RDMA/mlx5: Fix implicit ODP use after free (git-fixes)
- RDMA/mlx5: Fix a race for an ODP MR which leads to CQE with error (git-fixes)
- RDMA/rxe: Fix the warning "__rxe_cleanup+0x12c/0x170 [rdma_rxe]" (git-fixes)
- RDMA/cxgb4: Notify rdma stack for IB_EVENT_QP_LAST_WQE_REACHED event (git-fixes)
- RDMA/mlx5: Fix indirect mkey ODP page count (git-fixes)
- RDMA/rtrs: Add missing deinit() call (git-fixes)
- RDMA/bnxt_re: Fix to drop reference to the mmap entry in case of error (git-fixes)
- RDMA/srp: Fix error handling in srp_add_port (git-fixes)
- RDMA/rxe: Fix mismatched max_msg_sz (git-fixes)
- rdma/cxgb4: Prevent potential integer overflow on 32bit (git-fixes)
- RDMA/mlx4: Avoid false error about access to uninitialized gids array (git-fixes)
- commit 8a1518e
* Mon Jan 27 2025 mkoutny@suse.com
- padata: avoid UAF for reorder_work (git-fixes).
- padata: fix UAF in padata_reorder (git-fixes).
- commit 0ccb421
* Mon Jan 27 2025 mkoutny@suse.com
- fork: avoid inappropriate uprobe access to invalid mm
  (bsc#1236477).
- commit d6bd244
* Mon Jan 27 2025 nik.borisov@suse.com
- x86/kexec: Restore GDT on return from ::preserve_context kexec (git-fixes).
- commit 394a2d2
* Mon Jan 27 2025 nik.borisov@suse.com
- timekeeping: Always check for negative motion (git-fixes).
- commit 6a6f244
* Mon Jan 27 2025 mkoutny@suse.com
- cgroup/cpuset: remove kernfs active break (bsc#1236110).
- commit 0d4d6ef
* Mon Jan 27 2025 mkoutny@suse.com
- cgroup/cpuset: Prevent leakage of isolated CPUs into sched
  domains (jsc#PED-11934).
- cgroup/cpuset: Remove stale text (jsc#PED-11934).
- cgroup/cpuset: Disable cpuset_cpumask_can_shrink() test if
  not load balancing (jsc#PED-11934).
- cgroup/cpuset: Enforce at most one
  rebuild_sched_domains_locked() call per operation
  (jsc#PED-11934).
- cgroup/cpuset: Revert "Allow suppression of sched domain
  rebuild in update_cpumasks_hier()" (jsc#PED-11934).
- commit b370227
* Mon Jan 27 2025 ptesarik@suse.com
- bug: Use RCU instead RCU-sched to protect module_bug_list
  (bsc#1234370).
- static_call: Use RCU in all users of __module_text_address()
  (bsc#1234370).
- kprobes: Use RCU in all users of __module_text_address()
  (bsc#1234370).
- bpf: Use RCU in all users of __module_text_address()
  (bsc#1234370).
- jump_label: Use RCU in all users of __module_text_address()
  (bsc#1234370).
- jump_label: Use RCU in all users of __module_address()
  (bsc#1234370).
- x86: Use RCU in all users of __module_address() (bsc#1234370).
- cfi: Use RCU while invoking __module_address() (bsc#1234370).
- arm64: module: Use RCU in all users of __module_text_address()
  (bsc#1234370).
- module: Use RCU in all users of __module_text_address()
  (bsc#1234370).
- module: Use RCU in all users of __module_address()
  (bsc#1234370).
- module: Use RCU in search_module_extables() (bsc#1234370).
- module: Allow __module_address() to be called from RCU section
  (bsc#1234370).
- module: Use RCU in __is_module_percpu_address() (bsc#1234370).
- module: Use RCU in find_symbol() (bsc#1234370).
- module: Remove module_assert_mutex_or_preempt() from
  try_add_tainted_module() (bsc#1234370).
- module: Use RCU in module_kallsyms_on_each_symbol()
  (bsc#1234370).
- module: Use RCU in __find_kallsyms_symbol_value() (bsc#1234370).
- module: Use RCU in find_module_all() (bsc#1234370).
- module: Use RCU in module_get_kallsym() (bsc#1234370).
- module: Use RCU in find_kallsyms_symbol() (bsc#1234370).
- module: Use proper RCU assignment in add_kallsyms()
  (bsc#1234370).
- module: Begin to move from RCU-sched to RCU (bsc#1234370).
- module: Extend the preempt disabled section in
  dereference_symbol_descriptor() (bsc#1234370).
- commit 9b774cd
* Mon Jan 27 2025 nik.borisov@suse.com
- x86/ioapic: Remove a stray tab in the IO-APIC type string (git-fixes).
- commit c9344f1
* Mon Jan 27 2025 tbogendoerfer@suse.de
- net: stmmac: dwmac-tegra: Read iommu stream id from device tree
  (CVE-2025-21663 bsc#1236260).
- commit f877716
* Mon Jan 27 2025 nik.borisov@suse.com
- KVM: x86: Advertise SRSO_USER_KERNEL_NO to userspace (git-fixes).
- commit 9294b74
* Mon Jan 27 2025 nik.borisov@suse.com
- x86/bugs: Add SRSO_USER_KERNEL_NO support (git-fixes).
- commit 6001f65
* Mon Jan 27 2025 tiwai@suse.de
- maple_tree: simplify split calculation (git-fixes).
- latencytop: use correct kernel-doc format for func params
  (git-fixes).
- kasan: fix typo in kasan_poison_new_object documentation
  (git-fixes).
- lib/inflate.c: remove dead code (git-fixes).
- firewire: test: Fix potential null dereference in firewire
  kunit test (git-fixes).
- maple_tree: reload mas before the second call for mas_empty_area
  (git-fixes).
- commit 7ba9d83
* Sun Jan 26 2025 tiwai@suse.de
- remoteproc: mtk_scp: Only populate devices for SCP cores
  (git-fixes).
- remoteproc: omap: Handle ARM dma_iommu_mapping (git-fixes).
- remoteproc: core: Fix ida_free call while not allocated
  (git-fixes).
- watchdog: rti_wdt: Fix an OF node leak in rti_wdt_probe()
  (git-fixes).
- mtd: rawnand: brcmnand: fix status read of brcmnand_waitfunc
  (git-fixes).
- mtd: spinand: Remove write_enable_op() in markbad() (git-fixes).
- mtd: onenand: Fix uninitialized retlen in do_otp_read()
  (git-fixes).
- PCI: rcar-ep: Fix incorrect variable used when calling
  devm_request_mem_region() (git-fixes).
- PCI: imx6: Add missing reference clock disable logic
  (git-fixes).
- PCI: imx6: Deassert apps_reset in imx_pcie_deassert_core_reset()
  (git-fixes).
- PCI: imx6: Skip controller_id generation logic for i.MX7D
  (git-fixes).
- PCI: imx6: Configure PHY based on Root Complex or Endpoint mode
  (git-fixes).
- PCI: dwc: Always stop link in the dw_pcie_suspend_noirq
  (git-fixes).
- PCI: qcom: Update ICC and OPP values after Link Up event
  (git-fixes).
- PCI: endpoint: pci-epf-test: Fix check for DMA MEMCPY test
  (git-fixes).
- PCI: endpoint: pci-epf-test: Set dma_chan_rx pointer to NULL
  on error (git-fixes).
- PCI: dwc: ep: Prevent changing BAR size/flags in
  pci_epc_set_bar() (git-fixes).
- PCI: dwc: ep: Write BAR_MASK before iATU registers in
  pci_epc_set_bar() (git-fixes).
- PCI: endpoint: Finish virtual EP removal in
  pci_epf_remove_vepf() (git-fixes).
- PCI: endpoint: Destroy the EPC device in devm_pci_epc_destroy()
  (git-fixes).
- PCI: Avoid putting some root ports into D3 on TUXEDO Sirius Gen1
  (git-fixes).
- PCI/ASPM: Save parent L1SS config in pci_save_aspm_l1ss_state()
  (git-fixes).
- media: nuvoton: Fix an error check in npcm_video_ece_init()
  (git-fixes).
- media: dvb-usb-v2: af9035: fix ISO C90 compilation error on
  af9035_i2c_master_xfer (git-fixes).
- staging: media: imx: fix OF node leak in
  imx_media_add_of_subdevs() (git-fixes).
- media: mmp: Bring back registration of the device (git-fixes).
- media: nxp: imx8-isi: fix v4l2-compliance test errors
  (git-fixes).
- media: uvcvideo: Propagate buf->error to userspace (git-fixes).
- media: uvcvideo: Remove dangling pointers (git-fixes).
- media: uvcvideo: Remove redundant NULL assignment (git-fixes).
- media: uvcvideo: Only save async fh if success (git-fixes).
- media: uvcvideo: Support partial control reads (git-fixes).
- media: uvcvideo: Fix event flags in uvc_ctrl_send_events
  (git-fixes).
- media: uvcvideo: Fix double free in error path (git-fixes).
- media: uvcvideo: Fix crash during unbind if gpio unit is in use
  (git-fixes).
- staging: media: max96712: fix kernel oops when removing module
  (git-fixes).
- media: camif-core: Add check for clk_enable() (git-fixes).
- media: mipi-csis: Add check for clk_enable() (git-fixes).
- media: ov5640: fix get_light_freq on auto (git-fixes).
- media: mc: fix endpoint iteration (git-fixes).
- media: i2c: ds90ub960: Fix UB9702 VC map (git-fixes).
- media: i2c: ds90ub960: Fix logging SP & EQ status only for
  UB9702 (git-fixes).
- media: i2c: ds90ub960: Fix use of non-existing registers on
  UB9702 (git-fixes).
- media: i2c: ds90ub960: Fix UB9702 refclk register access
  (git-fixes).
- media: i2c: ds90ub9x3: Fix extra fwnode_handle_put()
  (git-fixes).
- media: i2c: ov9282: Correct the exposure offset (git-fixes).
- media: intel/ipu6: remove cpu latency qos request on error
  (git-fixes).
- media: ccs: Fix cleanup order in ccs_probe() (git-fixes).
- media: imx296: Add standby delay during probe (git-fixes).
- media: i2c: imx412: Add missing newline to prints (git-fixes).
- media: i2c: imx290: Register 0x3011 varies between imx327 and
  imx290 (git-fixes).
- media: ccs: Clean up parsed CCS static data on parse failure
  (git-fixes).
- media: ccs: Fix CCS static data parsing for large block sizes
  (git-fixes).
- media: marvell: Add check for clk_enable() (git-fixes).
- media: stm32: dcmipp: correct dma_set_mask_and_coherent mask
  value (git-fixes).
- media: lmedm04: Handle errors for lme2510_int_read (git-fixes).
- media: rc: iguanair: handle timeouts (git-fixes).
- media: rkisp1: Fix unused value issue (git-fixes).
- media: imx-jpeg: Fix potential error pointer dereference in
  detach_pm() (git-fixes).
- commit aae4fa1
* Sat Jan 25 2025 tiwai@suse.de
- ALSA: hda/realtek: Enable Mute LED on HP Laptop 14s-fq1xxx
  (stable-fixes).
- ALSA: usb-audio: Add delay quirk for USB Audio Device
  (stable-fixes).
- ALSA: hda/realtek: Enable headset mic on Positivo C6400
  (stable-fixes).
- commit 6acf6ed
* Sat Jan 25 2025 tiwai@suse.de
- rhashtable: Fix rhashtable_try_insert test (git-fixes).
- commit f5a7305
* Sat Jan 25 2025 tiwai@suse.de
- mailbox: zynqmp: Remove invalid __percpu annotation in
  zynqmp_ipi_probe() (git-fixes).
- mailbox: tegra-hsp: Clear mailbox before using message
  (git-fixes).
- i3c: master: Fix missing 'ret' assignment in set_speed()
  (git-fixes).
- i3c: dw: Fix use-after-free in dw_i3c_master driver due to
  race condition (git-fixes).
- efi: sysfb_efi: fix W=1 warnings when EFI is not set
  (git-fixes).
- of: address: Fix empty resource handling in
  __of_address_resource_bounds() (git-fixes).
- of/fdt: Restore possibility to use both ACPI and FDT from
  bootloader (git-fixes).
- of: reserved-memory: Do not make kmemleak ignore freed address
  (git-fixes).
- of: reserved-memory: Fix using wrong number of cells to get
  property 'alignment' (git-fixes).
- of: property: Avoiding using uninitialized variable @imaplen
  in parse_interrupt_map() (git-fixes).
- of: Correct child specifier used as input of the 2nd nexus node
  (git-fixes).
- of: Fix of_find_node_opts_by_path() handling of
  alias+path+options (git-fixes).
- soc: samsung: exynos-pmu: Fix uninitialized ret in
  tensor_set_bits_atomic() (git-fixes).
- firmware: qcom: scm: Cleanup global '__scm' on probe failures
  (git-fixes).
- firmware: qcom: scm: Fix missing read barrier in
  qcom_scm_get_tzmem_pool() (git-fixes).
- firmware: qcom: scm: Fix missing read barrier in
  qcom_scm_is_available() (git-fixes).
- soc: qcom: socinfo: Avoid out of bounds read of serial number
  (git-fixes).
- soc: qcom: smem_state: fix missing of_node_put in error path
  (git-fixes).
- soc: qcom: llcc: Enable LLCC_WRCACHE at boot on X1 (git-fixes).
- soc: mediatek: mtk-devapc: Fix leaking IO map on driver remove
  (git-fixes).
- soc: mediatek: mtk-devapc: Fix leaking IO map on error paths
  (git-fixes).
- memory: tegra20-emc: fix an OF node reference bug in
  tegra_emc_find_node_by_ram_code() (git-fixes).
- soc: atmel: fix device_node release in atmel_soc_device_init()
  (git-fixes).
- fbdev: omapfb: Fix an OF node leak in
  dss_of_port_get_parent_device() (git-fixes).
- ASoC: Intel: avs: Fix init-config parsing (git-fixes).
- ASoC: Intel: avs: Fix theoretical infinite loop (git-fixes).
- ASoC: Intel: avs: Fix the minimum firmware version numbers
  (git-fixes).
- ASoC: Intel: avs: Do not readq() u32 registers (git-fixes).
- ASoC: sun4i-spdif: Add clock multiplier settings (git-fixes).
- ASoC: Intel: sof_sdw: correct mach_params->dmic_num (git-fixes).
- ASoC: wcd937x: Use *-y for Makefile (git-fixes).
- ASoC: mediatek: mt8365: Use *-y for Makefile (git-fixes).
- ASoC: cs40l50: Use *-y for Makefile (git-fixes).
- ASoC: Intel: sof_sdw: Fix DMI match for Lenovo 83JX, 83MC and
  83NM (git-fixes).
- ASoC: Intel: sof_sdw: Fix DMI match for Lenovo 83LC (git-fixes).
- ALSA: hda/realtek - Fixed headphone distorted sound on Acer
  Aspire A115-31 laptop (git-fixes).
- ALSA: hda: Fix compilation of snd_hdac_adsp_xxx() helpers
  (git-fixes).
- ALSA: seq: Make dependency on UMP clearer (git-fixes).
- padata: fix UAF in padata_reorder (git-fixes).
- padata: fix sysfs store callback check (git-fixes).
- crypto: iaa - Fix IAA disabling that occurs when sync_mode is
  set to 'async' (git-fixes).
- crypto: ixp4xx - fix OF node reference leaks in
  init_ixp_crypto() (git-fixes).
- crypto: hisilicon/sec2 - fix for aead invalid authsize
  (git-fixes).
- crypto: hisilicon/sec2 - fix for aead icv error (git-fixes).
- rhashtable: Fix potential deadlock by moving schedule_work
  outside lock (git-fixes).
- crypto: qce - fix priority to be less than ARMv8 CE (git-fixes).
- crypto: qce - unregister previously registered algos in error
  path (git-fixes).
- crypto: qce - fix goto jump in error path (git-fixes).
- crypto: caam - use JobR's space to access page 0 regs
  (git-fixes).
- crypto: api - Fix boot-up self-test race (git-fixes).
- crypto: tegra - do not transfer req when tegra init fails
  (git-fixes).
- pinctrl: renesas: rzg2l: Fix PFC_MASK for RZ/V2H and RZ/G3E
  (git-fixes).
- pinctrl: amd: Take suspend type into consideration which pins
  are non-wake (git-fixes).
- pinctrl: stm32: Add check for clk_enable() (git-fixes).
- pinctrl: samsung: fix fwnode refcount cleanup if
  platform_get_irq_optional() fails (git-fixes).
- pinctrl: samsung: Fix irq handling if an error occurs in
  exynos_irq_demux_eint16_31() (git-fixes).
- pinctrl: nomadik: Add check for clk_enable() (git-fixes).
- platform/x86: serdev_helpers: Check for serial_ctrl_uid ==
  NULL (git-fixes).
- platform/x86: x86-android-tablets: make platform data be static
  (git-fixes).
- platform/mellanox: mlxbf-pmc: incorrect type in assignment
  (git-fixes).
- commit 04804af
* Sat Jan 25 2025 tiwai@suse.de
- Move upstreamed TPM patch into sorted section
- commit a914dc3
* Fri Jan 24 2025 dsterba@suse.com
- dm thin: make get_first_thin use rcu-safe list first function (CVE-2025-21664 bsc#1236262)
- commit bce62ed
* Fri Jan 24 2025 dsterba@suse.com
- selinux: ignore unknown extended permissions (CVE-2024-57931 bsc#1236192)
- commit edbf793
* Fri Jan 24 2025 dsterba@suse.com
- net_sched: cls_flow: validate TCA_FLOW_RSHIFT attribute (CVE-2025-21653 bsc#1236161)
- commit bfe69c3
* Fri Jan 24 2025 dsterba@suse.com
- ipvlan: Fix use-after-free in ipvlan_get_iflink() (CVE-2025-21652 bsc#1236160)
- commit ed4d75b
* Fri Jan 24 2025 dsterba@suse.com
- net/sctp: Prevent autoclose integer overflow in sctp_association_init() (CVE-2024-57938 bsc#1236182)
- commit cb64cb6
* Fri Jan 24 2025 dsterba@suse.com
- fgraph: Add READ_ONCE() when accessing fgraph_array[] (CVE-2024-57934 bsc#1236179)
- commit f0f5c56
* Fri Jan 24 2025 dsterba@suse.com
- topology: Keep the cpumask unchanged when printing cpumap (CVE-2024-57917 bsc#1236127)
- commit 29e8746
* Fri Jan 24 2025 dsterba@suse.com
- mm: vmscan: account for free pages to prevent infinite Loop in throttle_direct_reclaim() (CVE-2024-57884 bsc#1235948)
- commit cd69bfc
* Fri Jan 24 2025 dsterba@suse.com
- netrom: check buffer length before accessing it (CVE-2024-57802 bsc#1235941)
- commit fecc867
* Fri Jan 24 2025 tiwai@suse.de
- wifi: ath12k: fix tx power, max reg power update to firmware
  (git-fixes).
- wifi: mt76: mt7996: fix ldpc setting (git-fixes).
- wifi: mt76: mt7996: fix definition of tx descriptor (git-fixes).
- wifi: mt76: mt7996: fix incorrect indexing of MIB FW event
  (git-fixes).
- wifi: mt76: mt7996: fix HE Phy capability (git-fixes).
- wifi: mt76: mt7996: fix the capability of reception of EHT MU
  PPDU (git-fixes).
- wifi: mt76: mt7996: add max mpdu len capability (git-fixes).
- wifi: mt76: mt7996: fix register mapping (git-fixes).
- wifi: mt76: mt7915: fix register mapping (git-fixes).
- wifi: mt76: mt7915: fix omac index assignment after hardware
  reset (git-fixes).
- wifi: mt76: mt7915: firmware restart on devices with a second
  pcie link (git-fixes).
- wifi: mt76: only enable tx worker after setting the channel
  (git-fixes).
- wifi: mt76: mt7996: fix rx filter setting for bfee functionality
  (git-fixes).
- wifi: mt76: mt7925: Properly handle responses for commands
  with events (git-fixes).
- wifi: mt76: mt7925: Cleanup MLO settings post-disconnection
  (git-fixes).
- wifi: mt76: mt7925: Update mt7925_mcu_uni_[tx,rx]_ba for MLO
  (git-fixes).
- wifi: mt76: mt7925: Init secondary link PM state (git-fixes).
- wifi: mt76: mt7925: Update secondary link PS flow (git-fixes).
- wifi: mt76: mt7925: Update mt7925_unassign_vif_chanctx for
  per-link BSS (git-fixes).
- wifi: mt76: mt7925: Update mt792x_rx_get_wcid for per-link STA
  (git-fixes).
- wifi: mt76: mt7925: Update mt7925_mcu_sta_update for BC in
  ASSOC state (git-fixes).
- wifi: mt76: Enhance mt7925_mac_link_sta_add to support MLO
  (git-fixes).
- wifi: mt76: mt7925: Enhance mt7925_mac_link_bss_add to support
  MLO (git-fixes).
- wifi: mt76: mt7925: Fix CNM Timeout with Single Active Link
  in MLO (git-fixes).
- wifi: mt76: mt7925: fix wrong parameter for related cmd of
  chan info (git-fixes).
- wifi: mt76: mt7925: Fix incorrect WCID phy_idx assignment
  (git-fixes).
- wifi: mt76: mt7925: Fix incorrect WCID assignment for MLO
  (git-fixes).
- wifi: mt76: mt7925: Fix incorrect MLD address in bss_mld_tlv
  for MLO support (git-fixes).
- wifi: mt76: connac: Extend mt76_connac_mcu_uni_add_dev for MLO
  (git-fixes).
- wifi: mt76: mt7915: fix overflows seen when writing limit
  attributes (git-fixes).
- wifi: mt76: mt7996: fix overflows seen when writing limit
  attributes (git-fixes).
- wifi: mt76: mt7925: fix the invalid ip address for arp offload
  (git-fixes).
- wifi: mt76: mt7925: fix get wrong chip cap from incorrect
  pointer (git-fixes).
- commit 0569918
* Fri Jan 24 2025 tiwai@suse.de
- wifi: mt76: mt7925: fix wrong band_idx setting when enable
  sniffer mode (git-fixes).
- wifi: mt76: mt7925: fix NULL deref check in
  mt7925_change_vif_links (git-fixes).
- wifi: mt76: mt7915: add module param to select 5 GHz or 6 GHz
  on MT7916 (git-fixes).
- wifi: mt76: mt7915: Fix an error handling path in
  mt7915_add_interface() (git-fixes).
- wifi: mt76: mt7921: fix using incorrect group cipher after
  disconnection (git-fixes).
- wifi: mt76: mt76u_vendor_request: Do not print error messages
  when -EPROTO (git-fixes).
- wifi: mt76: mt7915: Fix mesh scan on MT7916 DBDC (git-fixes).
- wifi: mt76: mt7925: fix off by one in mt7925_load_clc()
  (git-fixes).
- wifi: rtw88: 8703b: Fix RX/TX issues (git-fixes).
- wifi: rtw89: fix race between cancel_hw_scan and hw_scan
  completion (git-fixes).
- wifi: rtw89: mcc: consider time limits not divisible by 1024
  (git-fixes).
- wifi: rtlwifi: rtl8821ae: Fix media status report (git-fixes).
- wifi: cfg80211: adjust allocation of colocated AP data
  (git-fixes).
- wifi: mac80211: don't flush non-uploaded STAs (git-fixes).
- wifi: mac80211: Fix common size calculation for ML element
  (git-fixes).
- wifi: mac80211: fix tid removal during mesh forwarding
  (git-fixes).
- wifi: cfg80211: Move cfg80211_scan_req_add_chan() n_channels
  increment earlier (git-fixes).
- wifi: mac80211: prohibit deactivating all links (git-fixes).
- wifi: iwlwifi: mvm: don't count mgmt frames as MPDU (git-fixes).
- wifi: iwlwifi: mvm: avoid NULL pointer dereference (git-fixes).
- commit 98d9d6c
* Fri Jan 24 2025 tiwai@suse.de
- tools: Sync if_xdp.h uapi tooling header (git-fixes).
- wifi: iwlwifi: fw: read STEP table from correct UEFI var
  (git-fixes).
- wifi: wlcore: fix unbalanced pm_runtime calls (git-fixes).
- wifi: mt76: mt7996: fix invalid interface combinations
  (git-fixes).
- wifi: rtlwifi: pci: wait for firmware loading before releasing
  memory (git-fixes).
- wifi: rtlwifi: fix memory leaks and invalid access at probe
  error path (git-fixes).
- wifi: rtlwifi: destroy workqueue at rtl_deinit_core (git-fixes).
- wifi: rtlwifi: remove unused check_buddy_priv (git-fixes).
- wifi: rtlwifi: usb: fix workqueue leak when probe fails
  (git-fixes).
- wifi: rtlwifi: fix init_sw_vars leak when probe fails
  (git-fixes).
- wifi: rtlwifi: wait for firmware loading before releasing memory
  (git-fixes).
- wifi: rtlwifi: rtl8192se: rise completion of firmware loading
  as last step (git-fixes).
- wifi: rtlwifi: do not complete firmware loading needlessly
  (git-fixes).
- wifi: rtlwifi: rtl8821ae: phy: restore removed code to fix
  infinite loop (git-fixes).
- wifi: brcmfmac: add missing header include for brcmf_dbg
  (git-fixes).
- wifi: ath11k: cleanup struct ath11k_mon_data (git-fixes).
- wifi: ath11k: cleanup struct ath11k_reg_tpc_power_info
  (git-fixes).
- wifi: wcn36xx: fix channel survey memory allocation size
  (git-fixes).
- wifi: ath11k: Fix unexpected return buffer manager error for
  WCN6750/WCN6855 (git-fixes).
- wifi: cfg80211: tests: Fix potential NULL dereference in
  test_cfg80211_parse_colocated_ap() (git-fixes).
- commit d9471b1
* Fri Jan 24 2025 tiwai@suse.de
- keys: drop shadowing dead prototype (git-fixes).
- Refresh
  patches.suse/0002-PKCS-7-Check-codeSigning-EKU-for-kernel-module-and-k.patch.
- commit 9473efe
* Fri Jan 24 2025 tiwai@suse.de
- ktest.pl: Fix typo "accesing" (git-fixes).
- ktest.pl: Fix typo in comment (git-fixes).
- ktest.pl: Remove unused declarations in run_bisect_test function
  (git-fixes).
- ktest.pl: Check kernelrelease return in get_version (git-fixes).
- selftests: ktap_helpers: Fix uninitialized variable (git-fixes).
- selftests/landlock: Fix error message (git-fixes).
- selftests/landlock: Fix build with non-default pthread linking
  (git-fixes).
- landlock: Handle weird files (git-fixes).
- KEYS: trusted: dcp: fix improper sg use with CONFIG_VMAP_STACK=y
  (git-fixes).
- selftests/rseq: Fix handling of glibc without rseq support
  (git-fixes).
- selftests/ftrace: Fix to use remount when testing mount GID
  option (git-fixes).
- selftests: harness: fix printing of mismatch values in
  __EXPECT() (git-fixes).
- selftests: timers: clocksource-switch: Adapt progress to
  kselftest framework (git-fixes).
- selftest: media_tests: fix trivial UAF typo (git-fixes).
- Input: davinci-keyscan - remove leftover header (git-fixes).
- Input: bbnsm_pwrkey - add remove hook (git-fixes).
- HID: core: Fix assumption that Resolution Multipliers must be
  in Logical Collections (git-fixes).
- HID: fix generic desktop D-Pad controls (git-fixes).
- HID: hid-thrustmaster: Fix warning in thrustmaster_probe by
  adding endpoint check (git-fixes).
- HID: multitouch: fix support for Goodix PID 0x01e9 (git-fixes).
- Revert "HID: multitouch: Add support for lenovo Y9000P Touchpad"
  (stable-fixes).
- HID: wacom: Initialize brightness of LED trigger (git-fixes).
- ipmi: ssif_bmc: Fix new request loss when bmc ready for a
  response (git-fixes).
- ipmi: ipmb: Add check devm_kasprintf() returned value
  (git-fixes).
- pwm: stm32: Add check for clk_enable() (git-fixes).
- pwm: stm32-lp: Add check for clk_enable() (git-fixes).
- hwmon: Fix help text for aspeed-g6-pwm-tach (git-fixes).
- leds: cht-wcove: Use devm_led_classdev_register() to avoid
  memory leak (git-fixes).
- leds: netxbig: Fix an OF node reference leak in
  netxbig_leds_get_of_pdata() (git-fixes).
- leds: lp8860: Write full EEPROM, not only half of it
  (git-fixes).
- mfd: syscon: Fix race in device_node_get_regmap() (git-fixes).
- HID: hid-sensor-hub: don't use stale platform-data on remove
  (git-fixes).
- spi: zynq-qspi: Add check for clk_enable() (git-fixes).
- regulator: of: Implement the unwind path of of_regulator_match()
  (git-fixes).
- gpio: pca953x: log an error when failing to get the reset GPIO
  (git-fixes).
- net/rose: prevent integer overflows in rose_setsockopt()
  (git-fixes).
- selinux: Fix SCTP error inconsistency in selinux_socket_bind()
  (git-fixes).
- selftests/powerpc: Fix argument order to timer_sub()
  (git-fixes).
- commit df484ba
* Fri Jan 24 2025 tiwai@suse.de
- drm/connector: hdmi: Do atomic check when necessary (git-fixes).
- drm/msm/gem: prevent integer overflow in msm_ioctl_gem_submit()
  (git-fixes).
- drm/msm/mdp4: correct LCDC regulator name (git-fixes).
- drm/msm: don't clean up priv->kms prematurely (git-fixes).
- drm/msm: Check return value of of_dma_configure() (git-fixes).
- drm/msm/dpu: link DSPP_2/_3 blocks on X1E80100 (git-fixes).
- drm/msm/dpu: link DSPP_2/_3 blocks on SM8650 (git-fixes).
- drm/msm/dpu: link DSPP_2/_3 blocks on SM8550 (git-fixes).
- drm/msm/dpu: link DSPP_2/_3 blocks on SM8350 (git-fixes).
- drm/msm/dpu: link DSPP_2/_3 blocks on SM8250 (git-fixes).
- drm/msm/dpu: link DSPP_2/_3 blocks on SC8180X (git-fixes).
- drm/msm/dpu: link DSPP_2/_3 blocks on SM8150 (git-fixes).
- drm/msm/dpu: provide DSPP and correct LM config for SDM670
  (git-fixes).
- drm/msm/dpu1: don't choke on disabling the writeback connector
  (git-fixes).
- drm/msm/dpu: fix x1e80100 intf_6 underrun/vsync interrupt
  (git-fixes).
- drm/msm/hdmi: simplify code in pll_get_integloop_gain
  (git-fixes).
- drm/msm/dp: set safe_to_exit_level before printing it
  (git-fixes).
- drm/amdgpu: fix gpu recovery disable with per queue reset
  (git-fixes).
- drm/amdgpu: tear down ttm range manager for doorbell in
  amdgpu_ttm_fini() (git-fixes).
- drm/etnaviv: Fix page property being used for non writecombine
  buffers (git-fixes).
- drm/xe/tracing: Fix a potential TP_printk UAF (git-fixes).
- Revert "drm/i915/dpt: Make DPT object unshrinkable"
  (stable-fixes).
- Revert "drm/amd/display: Fix green screen issue after suspend"
  (stable-fixes).
- drm/amdgpu: simplify return statement in amdgpu_ras_eeprom_init
  (git-fixes).
- drm/amdgpu/vcn: reset fw_shared under SRIOV (git-fixes).
- drm/amdgpu: Fix potential NULL pointer dereference in
  atomctrl_get_smc_sclk_range_table (git-fixes).
- drm/amd/pm: Fix an error handling path in
  vega10_enable_se_edc_force_stall_config() (git-fixes).
- drm/bridge: it6505: Change definition of AUX_FIFO_MAX_SIZE
  (git-fixes).
- drm/rockchip: vop2: include rockchip_drm_drv.h (git-fixes).
- commit b984ce6
* Fri Jan 24 2025 tiwai@suse.de
- ACPI: fan: cleanup resources in the error path of .probe()
  (git-fixes).
- cpupower: fix TSC MHz calculation (git-fixes).
- Bluetooth: L2CAP: handle NULL sock pointer in l2cap_sock_alloc
  (git-fixes).
- Bluetooth: btrtl: check for NULL in btrtl_setup_realtek()
  (git-fixes).
- Bluetooth: btbcm: Fix NULL deref in btbcm_get_board_name()
  (git-fixes).
- ax25: rcu protect dev->ax25_ptr (git-fixes).
- Align git commit ID abbreviation guidelines and checks
  (git-fixes).
- drm/rockchip: vop2: Add check for 32 bpp format for rk3588
  (git-fixes).
- drm/rockchip: vop2: Check linear format for Cluster windows
  on rk3566/8 (git-fixes).
- drm/rockchip: vop2: Setup delay cycle for Esmart2/3 (git-fixes).
- drm/rockchip: vop2: Set AXI id for rk3588 (git-fixes).
- drm/connector: Allow clearing HDMI infoframes (git-fixes).
- drm/rcar-du: dsi: Fix PHY lock bit check (git-fixes).
- drm/rockchip: vop2: Fix the windows switch between different
  layers (git-fixes).
- drm/panthor: Preserve the result returned by panthor_fw_resume()
  (git-fixes).
- drm/rockchip: vop2: Fix the mixer alpha setup for layer 0
  (git-fixes).
- drm/rockchip: vop2: Fix cluster windows alpha ctrl regsiters
  offset (git-fixes).
- drm: renesas: rz-du: Drop DU_MCR0_DPI_OE macro (git-fixes).
- drm: renesas: rz-du: Increase supported resolutions (git-fixes).
- drm/rockchip: vop2: fix rk3588 dp+dsi maxclk verification
  (git-fixes).
- drm/tidss: Fix race condition while handling interrupt registers
  (git-fixes).
- drm/tidss: Clear the interrupt status for interrupts being
  disabled (git-fixes).
- drm/tidss: Fix issue in irq handling causing irq-flood issue
  (git-fixes).
- drm/v3d: Stop active perfmon if it is being destroyed
  (git-fixes).
- accel/ivpu: Fix Qemu crash when running in passthrough
  (git-fixes).
- drm/v3d: Fix performance counter source settings on V3D 7.x
  (git-fixes).
- drm/rockchip: cdn-dp: Use drm_connector_helper_hpd_irq_event()
  (git-fixes).
- commit ef0aef7
* Fri Jan 24 2025 jwiesner@suse.de
- net/ipv6: release expired exception dst cached in socket
  (CVE-2024-56644 bsc#1235133).
- commit a89d415
* Fri Jan 24 2025 mgorman@suse.de
- Update config files.
- commit 5e1aa47
* Fri Jan 24 2025 mgorman@suse.de
- fortify: Move FORTIFY_SOURCE under 'Kernel hardening options'
  (jsc#PED-11838).
- mm: security: Check early if HARDENED_USERCOPY is enabled
  (jsc#PED-11838).
- mm: security: Allow default HARDENED_USERCOPY to be set at
  compile time (jsc#PED-11838).
- mm: security: Move hardened usercopy under 'Kernel hardening
  options' (jsc#PED-11838).
- commit 1f3276d
* Fri Jan 24 2025 mgorman@suse.de
- Delete
  patches.suse/mm-security-Allow-default-HARDENED_USERCOPY-to-be-set-at-compile-time.patch.
- Delete
  patches.suse/mm-security-Move-hardened-usercopy-under-Kernel-hardening-options.patch.
- commit 871e2b7
* Fri Jan 24 2025 tiwai@suse.de
- drm/i915/fb: Relax clear color alignment to 64 bytes
  (stable-fixes).
- drm/amdgpu: fix fw attestation for MP0_14_0_{2/3}
  (stable-fixes).
- drm/amdgpu: always sync the GFX pipe on ctx switch
  (stable-fixes).
- drm/amdgpu: disable gfxoff with the compute workload on gfx12
  (stable-fixes).
- drm/amd/display: Disable replay and psr while VRR is enabled
  (stable-fixes).
- drm/amd/display: Fix PSR-SU not support but still call the
  amdgpu_dm_psr_enable (stable-fixes).
- drm/amdgpu/smu13: update powersave optimizations (stable-fixes).
- nouveau/fence: handle cross device fences properly
  (stable-fixes).
- commit a60ee67
* Thu Jan 23 2025 mhocko@suse.com
- Update
  patches.suse/ALSA-seq-oss-Fix-races-at-processing-SysEx-messages.patch
  (stable-fixes CVE-2024-57893 bsc#1235920).
- Update
  patches.suse/RDMA-bnxt_re-Fix-max-SGEs-for-the-Work-Request.patch
  (jsc#PED-10682 jsc#PED-11231 CVE-2024-57936 bsc#1236181).
- Update
  patches.suse/RDMA-hns-Fix-accessing-invalid-dip_ctx-during-destro.patch
  (git-fixes CVE-2024-57935 bsc#1236180).
- Update
  patches.suse/RDMA-uverbs-Prevent-integer-overflow-issue.patch
  (git-fixes CVE-2024-57890 bsc#1235919).
- Update
  patches.suse/arm64-ptrace-fix-partial-SETREGSET-for-NT_ARM_TAGGED_ADDR_CTRL.patch
  (git-fixes CVE-2024-57874 bsc#1235808).
- Update
  patches.suse/cpufreq-CPPC-Fix-possible-null-ptr-deref-for-cppc_ge.patch
  (git-fixes CVE-2024-53230 bsc#1235976).
- Update
  patches.suse/cpufreq-CPPC-Fix-possible-null-ptr-deref-for-cpufreq.patch
  (git-fixes CVE-2024-53231 bsc#1235977).
- Update
  patches.suse/drm-adv7511-Fix-use-after-free-in-adv7533_attach_dsi.patch
  (git-fixes CVE-2024-57887 bsc#1235952).
- Update
  patches.suse/drm-amd-display-Add-check-for-granularity-in-dml-cei.patch
  (stable-fixes CVE-2024-57922 bsc#1236080).
- Update
  patches.suse/drm-amd-display-fix-divide-error-in-DM-plane-scale-c.patch
  (git-fixes CVE-2024-57919 bsc#1236070).
- Update
  patches.suse/drm-amd-display-fix-page-fault-due-to-max-surface-de.patch
  (git-fixes CVE-2024-57918 bsc#1236128).
- Update
  patches.suse/drm-amdgpu-Add-a-lock-when-accessing-the-buddy-trim-.patch
  (git-fixes CVE-2024-57921 bsc#1236076).
- Update
  patches.suse/drm-amdkfd-Correct-the-migration-DMA-map-direction.patch
  (stable-fixes CVE-2024-57897 bsc#1235969).
- Update
  patches.suse/drm-amdkfd-wq_release-signals-dma_fence-only-when-av.patch
  (git-fixes CVE-2024-57920 bsc#1236072).
- Update
  patches.suse/drm-dp_mst-Ensure-mst_primary-pointer-is-valid-in-dr.patch
  (stable-fixes CVE-2024-57798 bsc#1235818).
- Update
  patches.suse/drm-dp_mst-Fix-resetting-msg-rx-state-after-topology.patch
  (git-fixes CVE-2024-57876 bsc#1235806).
- Update
  patches.suse/drm-mediatek-Set-private-all_drm_private-i-drm-to-NU.patch
  (git-fixes CVE-2024-57926 bsc#1236082).
- Update
  patches.suse/drm-xe-Fix-fault-on-fd-close-after-unbind.patch
  (git-fixes CVE-2024-57844 bsc#1235945).
- Update
  patches.suse/drm-xe-Fix-tlb-invalidation-when-wedging.patch
  (git-fixes CVE-2025-21644 bsc#1236085).
- Update
  patches.suse/exfat-fix-the-infinite-loop-in-exfat_readdir.patch
  (git-fixes CVE-2024-57940 bsc#1236227).
- Update
  patches.suse/exfat-fix-the-new-buffer-was-not-zeroed-before-writing.patch
  (git-fixes CVE-2024-57943 bsc#1236230).
- Update
  patches.suse/gpio-virtuser-fix-missing-lookup-table-cleanups.patch
  (git-fixes CVE-2025-21661 bsc#1236201).
- Update
  patches.suse/hwmon-drivetemp-Fix-driver-producing-garbage-data-wh.patch
  (git-fixes CVE-2025-21656 bsc#1236248).
- Update
  patches.suse/iio-adc-at91-call-input_free_device-on-allocated-iio.patch
  (git-fixes CVE-2024-57904 bsc#1236078).
- Update
  patches.suse/iio-adc-rockchip_saradc-fix-information-leak-in-trig.patch
  (git-fixes CVE-2024-57907 bsc#1236090).
- Update
  patches.suse/iio-adc-ti-ads1119-fix-information-leak-in-triggered.patch
  (git-fixes CVE-2024-57905 bsc#1236083).
- Update
  patches.suse/iio-adc-ti-ads1298-Add-NULL-check-in-ads1298_init.patch
  (git-fixes CVE-2024-57944 bsc#1236197).
- Update
  patches.suse/iio-adc-ti-ads8688-fix-information-leak-in-triggered.patch
  (git-fixes CVE-2024-57906 bsc#1236088).
- Update
  patches.suse/iio-dummy-iio_simply_dummy_buffer-fix-information-le.patch
  (git-fixes CVE-2024-57911 bsc#1236098).
- Update
  patches.suse/iio-imu-kmx61-fix-information-leak-in-triggered-buff.patch
  (git-fixes CVE-2024-57908 bsc#1236091).
- Update
  patches.suse/iio-light-bh1745-fix-information-leak-in-triggered-b.patch
  (git-fixes CVE-2024-57909 bsc#1236095).
- Update
  patches.suse/iio-light-vcnl4035-fix-information-leak-in-triggered.patch
  (git-fixes CVE-2024-57910 bsc#1236097).
- Update
  patches.suse/iio-pressure-zpa2326-fix-information-leak-in-trigger.patch
  (git-fixes CVE-2024-57912 bsc#1236101).
- Update
  patches.suse/misc-microchip-pci1xxxx-Resolve-kernel-panic-during-.patch
  (git-fixes CVE-2024-57916 bsc#1236125).
- Update
  patches.suse/net-mlx5e-Skip-restore-TC-rules-for-vport-rep-withou.patch
  (jsc#PED-11331 CVE-2024-57801 bsc#1235940).
- Update
  patches.suse/netfs-Fix-ceph-copy-to-cache-on-write-begin.patch
  (git-fixes CVE-2024-57942 bsc#1236229).
- Update
  patches.suse/netfs-Fix-enomem-handling-in-buffered-reads.patch
  (git-fixes CVE-2024-57928 bsc#1236092).
- Update
  patches.suse/netfs-Fix-the-non-cancellation-of-copy-when-cache-is-temporarily-disabled.patch
  (git-fixes CVE-2024-57941 bsc#1236228).
- Update
  patches.suse/nfs-Fix-oops-in-nfs_netfs_init_request-when-copying-to-cache.patch
  (git-fixes CVE-2024-57927 bsc#1236089).
- Update patches.suse/nvmet-Don-t-overflow-subsysnqn.patch
  (git-fixes CVE-2024-53681 bsc#1235904).
- Update
  patches.suse/platform-x86-amd-pmc-Only-disable-IRQ1-wakeup-where-.patch
  (git-fixes CVE-2025-21645 bsc#1236131).
- Update
  patches.suse/powerpc-pseries-vas-Add-close-callback-in-vas_vm_ops.patch
  (bsc#1234825 CVE-2024-56765 bsc#1235643).
- Update
  patches.suse/s390-cpum_sf-Handle-CPU-hotplug-remove-during-sampling.patch
  (git-fixes bsc#1234715 CVE-2024-57849 bsc#1235814).
- Update
  patches.suse/usb-gadget-f_fs-Remove-WARN_ON-in-functionfs_bind.patch
  (git-fixes CVE-2024-57913 bsc#1236102).
- Update
  patches.suse/usb-gadget-u_serial-Disable-ep-before-setting-port-t.patch
  (git-fixes CVE-2024-57915 bsc#1236120).
- Update
  patches.suse/usb-typec-tcpci-fix-NULL-pointer-issue-on-shared-irq.patch
  (git-fixes CVE-2024-57914 bsc#1236119).
- Update
  patches.suse/wifi-cfg80211-clear-link-ID-from-bitmap-during-link-.patch
  (stable-fixes CVE-2024-57898 bsc#1235966).
- Update
  patches.suse/wifi-mac80211-fix-mbss-changed-flags-corruption-on-3.patch
  (stable-fixes CVE-2024-57899 bsc#1235924).
- Update
  patches.suse/workqueue-Do-not-warn-when-cancelling-WQ_MEM_RECLAIM-work-from-WQ_MEM_RECLAIM-worker.patch
  (bsc#1235416 CVE-2024-57888 bsc#1235918).
- Update
  patches.suse/x86-fpu-Ensure-shadow-stack-is-active-before-getting-regis.patch
  (git-fixes CVE-2025-21632 bsc#1236106).
- commit 54bbd23
* Thu Jan 23 2025 davide.benini@suse.com
- net: inet: do not leave a dangling sk pointer in inet_create()
  (CVE-2024-56601 bsc#1235230).
- commit 9915dd5
* Thu Jan 23 2025 dsterba@suse.com
- bpf,perf: Fix invalid prog_array access in perf_event_detach_bpf_prog (CVE-2024-56665 bsc#1235489)
- commit c21f948
* Thu Jan 23 2025 mgorman@suse.de
- psi: Fix race when task wakes up before psi_sched_switch()
  adjusts flags (bsc#1234634 (Scheduler functional and performance
  backports)).
- sched, psi: Don't account irq time if sched_clock_irqtime is
  disabled (bsc#1234634 (Scheduler functional and performance
  backports)).
- sched: Don't account irq time if sched_clock_irqtime is disabled
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched: Define sched_clock_irqtime as static key (bsc#1234634
  (Scheduler functional and performance backports)).
- sched/fair: Do not compute overloaded status unnecessarily
  during lb (bsc#1234634 (Scheduler functional and performance
  backports)).
- sched/fair: Do not compute NUMA Balancing stats unnecessarily
  during lb (bsc#1234634 (Scheduler functional and performance
  backports)).
- sched/debug: Change need_resched warnings to pr_err (bsc#1234634
  (Scheduler functional and performance backports)).
- sched/fair: Encapsulate set custom slice in a __setparam_fair()
  function (bsc#1234634 (Scheduler functional and performance
  backports)).
- sched: Fix race between yield_to() and try_to_wake_up()
  (bsc#1234634 (Scheduler functional and performance backports)).
- docs: Update Schedstat version to 17 (bsc#1234634 (Scheduler
  functional and performance backports)).
- sched/stats: Print domain name in /proc/schedstat (bsc#1234634
  (Scheduler functional and performance backports)).
- sched: Move sched domain name out of CONFIG_SCHED_DEBUG
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched: Report the different kinds of imbalances in
  /proc/schedstat (bsc#1234634 (Scheduler functional and
  performance backports)).
- sched/fair: Cleanup in migrate_degrades_locality() to improve
  readability (bsc#1234634 (Scheduler functional and performance
  backports)).
- sched/fair: Fix value reported by hot tasks pulled in
  /proc/schedstat (bsc#1234634 (Scheduler functional and
  performance backports)).
- sched/fair: Update comments after sched_tick() rename
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/fair: Fix CPU bandwidth limit bypass during CPU hotplug
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched: deadline: Cleanup goto label in
  pick_earliest_pushable_dl_task (bsc#1234634 (Scheduler
  functional and performance backports)).
- sched/fair: Untangle NEXT_BUDDY and pick_next_task()
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/fair: Mark m*_vruntime() with __maybe_unused (bsc#1234634
  (Scheduler functional and performance backports)).
- sched/fair: Fix variable declaration position (bsc#1234634
  (Scheduler functional and performance backports)).
- sched/fair: Do not try to migrate delayed dequeue task
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/fair: Rename cfs_rq.nr_running into nr_queued (bsc#1234634
  (Scheduler functional and performance backports)).
- sched/fair: Remove unused cfs_rq.idle_nr_running (bsc#1234634
  (Scheduler functional and performance backports)).
- sched/fair: Rename cfs_rq.idle_h_nr_running into h_nr_idle
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/fair: Removed unsued cfs_rq.h_nr_delayed (bsc#1234634
  (Scheduler functional and performance backports)).
- sched/fair: Use the new cfs_rq.h_nr_runnable (bsc#1234634
  (Scheduler functional and performance backports)).
- sched/fair: Add new cfs_rq.h_nr_runnable (bsc#1234634 (Scheduler
  functional and performance backports)).
- sched/fair: Rename h_nr_running into h_nr_queued (bsc#1234634
  (Scheduler functional and performance backports)).
- sched: Unify HK_TYPE_{TIMER|TICK|MISC} to HK_TYPE_KERNEL_NOISE
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/isolation: Consolidate housekeeping cpumasks that
  are always identical (bsc#1234634 (Scheduler functional and
  performance backports)).
- sched/isolation: Make "isolcpus=nohz" equivalent to "nohz_full"
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/core: Remove HK_TYPE_SCHED (bsc#1234634 (Scheduler
  functional and performance backports)).
- sched/fair: Remove CONFIG_CFS_BANDWIDTH=n definition of
  cfs_bandwidth_used() (bsc#1234634 (Scheduler functional and
  performance backports)).
- sched/deadline: Consolidate Timer Cancellation (bsc#1234634
  (Scheduler functional and performance backports)).
- sched/deadline: Check bandwidth overflow earlier for hotplug
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/deadline: Correctly account for allocated bandwidth during
  hotplug (bsc#1234634 (Scheduler functional and performance
  backports)).
- sched/deadline: Restore dl_server bandwidth on non-destructive
  root domain changes (bsc#1234634 (Scheduler functional and
  performance backports)).
- sched: add READ_ONCE to task_on_rq_queued (bsc#1234634
  (Scheduler functional and performance backports)).
- sched: Don't try to catch up excess steal time (bsc#1234634
  (Scheduler functional and performance backports)).
- commit fa2e8c2
* Thu Jan 23 2025 petr.pavlu@suse.com
- doc/README.SUSE: Point to the updated version of LKMPG
- commit 624b259
* Thu Jan 23 2025 vbabka@suse.cz
- mm: reinstate ability to map write-sealed memfd mappings
  read-only (bsc#1236186).
- commit ded0978
* Thu Jan 23 2025 jslaby@suse.cz
- Update
  patches.suse/x86-fpu-Ensure-shadow-stack-is-active-before-getting-regis.patch
  (git-fixes CVE-2025-21632 bsc#1236106).
  Add CVE.
- commit 887d7c3
* Thu Jan 23 2025 nmorey@suse.com
- net: restrict SO_REUSEPORT to inet sockets (bsc#1235967 CVE-2024-57903)
- commit 58fab3c
* Thu Jan 23 2025 nmorey@suse.com
- net: hns3: fix kernel crash when 1588 is sent on HIP08 devices (bsc#1236143 CVE-2025-21649)
- commit 475f3b6
* Thu Jan 23 2025 nmorey@suse.com
- net/mlx5: Fix variable not being completed when function returns (bsc#1236198 CVE-2025-21662)
- commit 07f6c41
* Wed Jan 22 2025 mfranc@suse.cz
- s390/futex: Fix FUTEX_OP_ANDN implementation (git-fixes
  bsc#1236286).
- commit 0dace5e
* Wed Jan 22 2025 dsterba@suse.com
- tracing: Prevent bad count for tracing_cpumask_write (CVE-2024-56763 bsc#1235638)
- commit ddb87c7
* Wed Jan 22 2025 dsterba@suse.com
- dccp: Fix memory leak in dccp_feat_change_recv (CVE-2024-56643 bsc#1235132)
- commit a463e51
* Wed Jan 22 2025 dsterba@suse.com
- net: stmmac: fix TSO DMA API usage causing oops (CVE-2024-56719 bsc#1235591)
- commit 303cb71
* Wed Jan 22 2025 dsterba@suse.com
- net: mscc: ocelot: fix incorrect IFH SRC_PORT field in ocelot_ifh_set_basic() (CVE-2024-56717 bsc#1235588)
- commit 9d81d98
* Wed Jan 22 2025 dsterba@suse.com
- EDAC/igen6: Avoid segmentation fault on module unload (CVE-2024-56708 bsc#1235564)
- commit b104d19
* Wed Jan 22 2025 dsterba@suse.com
- net/smc: initialize close_work early to avoid warning (CVE-2024-56641 bsc#1235526)
- commit 004c5ba
* Wed Jan 22 2025 dsterba@suse.com
- net: hsr: must allocate more bytes for RedBox support (CVE-2024-56639 bsc#1235525)
- commit 5287ee6
* Wed Jan 22 2025 fdmanana@suse.com
- btrfs: fix transaction atomicity bug when enabling simple quotas
  (bsc#1235792 CVE-2024-57806).
- btrfs: flush delalloc workers queue before stopping cleaner
  kthread during unmount (bsc#1235965 CVE-2024-57896).
- commit c277493
* Wed Jan 22 2025 tbogendoerfer@suse.de
- net: hns3: fixed hclge_fetch_pf_reg accesses bar space out of
  bounds issue (CVE-2025-21650 bsc#1236144).
- net: hns3: don't auto enable misc vector (CVE-2025-21651
  bsc#1236145).
- gve: guard XSK operations on the existence of queues
  (CVE-2024-57933 bsc#1236178).
- gve: guard XDP xmit NDO on existence of xdp queues
  (CVE-2024-57932 bsc#1236190).
- commit 234dcb0
* Wed Jan 22 2025 vbabka@suse.cz
- Update config files. Make zsmalloc the default for zswap (bsc#1235938)
- commit 5f343bc
* Wed Jan 22 2025 vbabka@suse.cz
- Update config files. Enable CONFIG_READ_ONLY_THP_FOR_FS (bsc#1235939)
- commit afec79a
* Wed Jan 22 2025 msuchanek@suse.de
- powerpc/pseries/iommu: IOMMU incorrectly marks MMIO range in
  DDW (bsc#1218470 ltc#204531).
- commit 0e16ef6
* Wed Jan 22 2025 oneukum@suse.com
- Delete
  patches.suse/0001-kvm-Reintroduce-nopvspin-kernel-parameter.patch.
  This patch was required for a performance issue with specific kernels
- commit 77171c1
* Tue Jan 21 2025 rgoldwyn@suse.com
- netfs: Fix kernel async DIO (CVE-2025-21643 bsc#1236129).
- commit 5091c6e
* Tue Jan 21 2025 vkarasulli@suse.de
- KVM: x86: Play nice with protected guests in
  complete_hypercall_exit() (CVE-2024-55881 bsc#1235745).
- commit 1b22d6c
* Tue Jan 21 2025 dsterba@suse.com
- netfilter: ipset: Hold module reference while requesting a module (CVE-2024-56637 bsc#1235523)
- commit 690c0e7
* Tue Jan 21 2025 neelx@suse.com
- btrfs: zlib: fix avail_in bytes for s390 zlib HW compression
  path (CVE-2024-57923 bsc#1236081).
- commit 8a7a4cd
* Tue Jan 21 2025 dsterba@suse.com
- geneve: do not assume mac header is set in geneve_xmit_skb() (CVE-2024-56636 bsc#1235520)
- commit 952c736
* Tue Jan 21 2025 colyli@suse.de
- dm array: fix releasing a faulty array block twice in
  dm_array_cursor_end (bsc#1236096, CVE-2024-57929).
- commit 39a2cb0
* Tue Jan 21 2025 dsterba@suse.com
- net: avoid potential UAF in default_operstate() (CVE-2024-56635 bsc#1235519)
- commit 3ce7665
* Tue Jan 21 2025 dsterba@suse.com
- net: lapb: increase LAPB_HEADER_LEN (CVE-2024-56659 bsc#1235439)
- commit f8467db
* Tue Jan 21 2025 dsterba@suse.com
- net: enetc: Do not configure preemptible TCs if SIs do not support (CVE-2024-56649 bsc#1235449)
- commit 72c14cf
* Tue Jan 21 2025 dsterba@suse.com
- smb: Initialize cfid->tcon before performing network ops (CVE-2024-56729 bsc#1235503)
- commit 01281af
* Tue Jan 21 2025 oneukum@suse.com
- usb: typec: ucsi: Fix connector status writing past buffer size
  (git-fixes).
- commit cef7f7d
* Tue Jan 21 2025 oneukum@suse.com
- reenabled kABI padding for rfkill subsystem
- commit 6ada0c1
* Tue Jan 21 2025 oneukum@suse.com
- reenabled kABI padding for fpga subsystem
- commit 2829876
* Tue Jan 21 2025 oneukum@suse.com
- reenabled kABI paddings for atheros wifi
- commit e1e449a
* Tue Jan 21 2025 oneukum@suse.com
- reenable kABI paddings for mediatek wifi
- commit 3acd857
* Tue Jan 21 2025 oneukum@suse.com
- reenable kABI padding for realtek wifi
- commit f74657e
* Tue Jan 21 2025 vbabka@suse.cz
- selftests/mm: add self tests for guard page feature
  (jsc#PED-11997).
- commit 60e0640
* Tue Jan 21 2025 vbabka@suse.cz
- tools: testing: update tools UAPI header for mman-common.h
  (jsc#PED-11997).
- commit 8363626
* Tue Jan 21 2025 vbabka@suse.cz
- mm: madvise: implement lightweight guard page mechanism
  (jsc#PED-11997).
- commit ef64fd4
* Tue Jan 21 2025 vbabka@suse.cz
- mm: add PTE_MARKER_GUARD PTE marker (jsc#PED-11997).
- commit 8bdd1e7
* Tue Jan 21 2025 vbabka@suse.cz
- mm: pagewalk: add the ability to install PTEs (jsc#PED-11997).
- commit 05dd309
* Tue Jan 21 2025 vbabka@suse.cz
- mm/madvise: unrestrict process_madvise() for current process
  (jsc#PED-11997).
- commit 520a012
* Tue Jan 21 2025 vbabka@suse.cz
- mm: refactor mm_access() to not return NULL (jsc#PED-11997).
- commit f4b336b
* Tue Jan 21 2025 nik.borisov@suse.com
- x86/cpu/topology: Remove limit of CPUs due to disabled IO/APIC (git-fixes).
- commit 62783ca
* Tue Jan 21 2025 nik.borisov@suse.com
- x86/microcode/intel: Remove unnecessary cache writeback and invalidation (git-fixes).
- commit dc8791d
* Tue Jan 21 2025 nik.borisov@suse.com
- x86/tdx: Dynamically disable SEPT violations from causing #VEs (git-fixes).
- commit 496a9c3
* Tue Jan 21 2025 nik.borisov@suse.com
- x86/tdx: Rename tdx_parse_tdinfo() to tdx_setup() (git-fixes).
- commit 5e1ffad
* Tue Jan 21 2025 nik.borisov@suse.com
- x86/tdx: Introduce wrappers to read and write TD metadata (git-fixes).
- commit 755075a
* Tue Jan 21 2025 nik.borisov@suse.com
- x86/pkeys: Ensure updated PKRU value is XRSTOR'd (git-fixes).
- commit 51df86b
* Tue Jan 21 2025 nik.borisov@suse.com
- x86/pkeys: Change caller of update_pkru_in_sigframe() (git-fixes).
- commit 978efb4
* Tue Jan 21 2025 nik.borisov@suse.com
- x86/fpu: Ensure shadow stack is active before "getting" registers (git-fixes).
- commit 46e75e2
* Tue Jan 21 2025 nik.borisov@suse.com
- x86/mm: Carve out INVLPG inline asm for use by others (git-fixes).
- commit e895153
* Tue Jan 21 2025 nik.borisov@suse.com
- x86: fix off-by-one in access_ok() (git-fixes).
- commit 4b269aa
* Tue Jan 21 2025 nik.borisov@suse.com
- x86/asm: Make serialize() always_inline (git-fixes).
- commit f957994
* Tue Jan 21 2025 nik.borisov@suse.com
- x86/CPU/AMD: WARN when setting EFER.AUTOIBRS if and only if the WRMSR  fails (git-fixes).
- commit c5e60f6
* Tue Jan 21 2025 nik.borisov@suse.com
- x86/microcode/AMD: Flush patch buffer mapping after application (git-fixes).
- commit d8e2f7c
* Tue Jan 21 2025 nik.borisov@suse.com
- x86/fred: Fix the FRED RSP0 MSR out of sync with its per-CPU cache (git-fixes).
- commit bb3c863
* Tue Jan 21 2025 jlee@suse.com
- Reviewed
  patches.suse/0004-MODSIGN-checking-the-blacklisted-hash-before-loading.patch
- commit 0e6968e
* Tue Jan 21 2025 jlee@suse.com
- Reviewed
  patches.suse/0003-Add-external-no-support-as-bad-taint-module.patch
- commit 86de2cb
* Mon Jan 20 2025 msuchanek@suse.de
- tpm: ibmvtpm: Set TPM_OPS_AUTO_STARTUP flag on driver
  (git-fixes).
- commit 6f0e558
* Mon Jan 20 2025 ohering@suse.de
- net: mana: Cleanup "mana" debugfs dir after cleanup of all children (git-fixes).
- commit 7180a8a
* Mon Jan 20 2025 nmorey@suse.com
- RDMA/hns: Fix missing flush CQE for DWQE (git-fixes)
- commit 87b30f5
* Mon Jan 20 2025 nmorey@suse.com
- RDMA/hns: Fix warning storm caused by invalid input in IO path (git-fixes)
- commit e09ea24
* Mon Jan 20 2025 nmorey@suse.com
- RDMA/hns: Fix accessing invalid dip_ctx during destroying QP (git-fixes)
- commit d0ac89c
* Mon Jan 20 2025 nmorey@suse.com
- RDMA/hns: Fix mapping error of zero-hop WQE buffer (git-fixes)
- commit 87de660
* Mon Jan 20 2025 nmorey@suse.com
- RDMA/nldev: Set error code in rdma_nl_notify_event (git-fixes)
- commit c4562bf
* Mon Jan 20 2025 nmorey@suse.com
- RDMA/core: Fix ENODEV error for iWARP test over vlan (git-fixes)
- commit a0b253d
* Mon Jan 20 2025 nmorey@suse.com
- RDMA/uverbs: Prevent integer overflow issue (git-fixes)
- commit aeb3e97
* Mon Jan 20 2025 jlee@suse.com
- Reviewed
  patches.suse/0001-PKCS-7-Check-codeSigning-EKU-of-certificates-in-PKCS.patch
- commit c96f4a3
* Mon Jan 20 2025 jlee@suse.com
- Reviewed
  patches.suse/0001-X.509-Fix-the-parser-of-extended-key-usage-for-lengt.patch
- commit b4da5d5
* Mon Jan 20 2025 jlee@suse.com
- Reviewed
  patches.suse/0004-Documentation-admin-guide-module-signing.rst-add-ope.patch
- commit 4076611
* Mon Jan 20 2025 jlee@suse.com
- Reviewed
  patches.suse/0003-modsign-Add-codeSigning-EKU-when-generating-X.509-ke.patch
- commit 3ca6e63
* Mon Jan 20 2025 jlee@suse.com
- Refresh
  patches.suse/0002-PKCS-7-Check-codeSigning-EKU-for-kernel-module-and-k.patch.
  Update config files.
  CONFIG_CHECK_CODESIGN_EKU
- commit 3293035
* Mon Jan 20 2025 jlee@suse.com
- Refresh
  patches.suse/0001-X.509-Add-CodeSigning-extended-key-usage-parsing.patch.
- commit af592d7
* Mon Jan 20 2025 heming.zhao@suse.com
- ocfs2: fix slab-use-after-free due to dangling pointer dqi_priv
  (bsc#1235964 CVE-2024-57892).
- commit c39636c
* Mon Jan 20 2025 jlee@suse.com
- efi: remove EFI secret key when booting with secure boot
  disabled (jsc#PED-1444).
- commit b444d73
* Sat Jan 18 2025 lduncan@suse.com
- scsi: mpi3mr: Fix corrupt config pages PHY state is switched
  in sysfs (CVE-2024-57804 bsc#1235779).
- commit aa77f1e
* Sat Jan 18 2025 tiwai@suse.de
- soc: ti: pruss: Fix pruss APIs (git-fixes).
- reset: rzg2l-usbphy-ctrl: Assign proper of node to the allocated
  device (git-fixes).
- platform/x86: lenovo-yoga-tab2-pro-1380-fastcharger: fix serdev
  race (git-fixes).
- platform/x86: dell-uart-backlight: fix serdev race (git-fixes).
- Revert "mtd: spi-nor: core: replace dummy buswidth from addr
  to data" (git-fixes).
- hwmon: (ltc2991) Fix mixed signed/unsigned in DIV_ROUND_CLOSEST
  (git-fixes).
- hwmon: (tmp513) Fix division of negative numbers (git-fixes).
- gpio: xilinx: Convert gpio_lock to raw spinlock (git-fixes).
- i2c: testunit: on errors, repeat NACK until STOP (git-fixes).
- i2c: rcar: fix NACK handling when being a target (git-fixes).
- i2c: mux: demux-pinctrl: check initial mux selection, too
  (git-fixes).
- i2c: atr: Fix client detach (git-fixes).
- i2c: core: fix reference leak in i2c_register_adapter()
  (git-fixes).
- pmdomain: imx8mp-blk-ctrl: add missing loop break condition
  (git-fixes).
- selftests: mptcp: avoid spurious errors on disconnect
  (git-fixes).
- drm/amd/pm:  fix BUG: scheduling while atomic (stable-fixes).
- drm/amdkfd: wq_release signals dma_fence only when available
  (git-fixes).
- drm/amd/display: Add check for granularity in dml ceil/floor
  helpers (stable-fixes).
- drm/amd/display: increase MAX_SURFACES to the value supported
  by hw (stable-fixes).
- pmdomain: imx: gpcv2: fix an OF node reference leak in
  imx_gpcv2_probe() (git-fixes).
- commit edae5a9
* Sat Jan 18 2025 colyli@suse.de
- block: RCU protect disk->conv_zones_bitmap (bsc#1235820,
  CVE-2024-57875).
- commit 76c266d
* Sat Jan 18 2025 colyli@suse.de
- ublk: detach gendisk from ublk device if add_disk() fails
  (bsc#1235634, CVE-2024-56764).
- commit 3688e07
* Fri Jan 17 2025 jgross@suse.com
- KVM: arm64: Get rid of userspace_irqchip_in_use (CVE-2024-53195
  bsc#1234957).
- commit 4e1a286
* Fri Jan 17 2025 jgross@suse.com
- KVM: arm64: Don't retire aborted MMIO instruction
  (CVE-2024-53196 bsc#1234906).
- commit c7394cd
* Fri Jan 17 2025 jgross@suse.com
- xen: Fix the issue of resource not being properly released in
  xenbus_dev_probe() (CVE-2024-53198 bsc#1234923).
- commit a0f3f9e
* Fri Jan 17 2025 jgross@suse.com
- x86/static-call: Remove early_boot_irqs_disabled check to fix
  Xen PVH dom0 (git-fixes).
- commit 8264638
* Fri Jan 17 2025 vbabka@suse.cz
- mm: hugetlb: independent PMD page table shared count
  (CVE-2024-57883 bsc#1235947).
- commit 454014f
* Fri Jan 17 2025 tiwai@suse.de
- ASoC: tas2781: Fix occasional calibration failture (git-fixes).
- commit 9c36ea2
* Fri Jan 17 2025 tiwai@suse.de
- drm/xe: Mark ComputeCS read mode as UC on iGPU (git-fixes).
- drm/xe/oa: Add missing VISACTL mux registers (git-fixes).
- drm/xe: make change ccs_mode a synchronous action (git-fixes).
- drm/xe: introduce xe_gt_reset and xe_gt_wait_for_reset
  (git-fixes).
- drm/amd/display: Do not elevate mem_type change to full update
  (git-fixes).
- drm/amd/display: Do not wait for PSR disable on vbl enable
  (git-fixes).
- Revert "drm/amd/display: Enable urgent latency adjustments
  for DCN35" (git-fixes).
- drm/amd/display: Validate mdoe under MST LCT=1 case as well
  (git-fixes).
- drm/v3d: Ensure job pointer is set to NULL after job completion
  (git-fixes).
- drm/vmwgfx: Add new keep_resv BO param (git-fixes).
- drm/vmwgfx: Unreserve BO on error (git-fixes).
- drm/tests: helpers: Fix compiler warning (git-fixes).
- commit 0fe40cd
* Fri Jan 17 2025 vkarasulli@suse.de
- config: enable
  CONFIG_INTEL_IOMMU_SCALABLE_MODE_DEFAULT_ON
- commit 7266c28
* Fri Jan 17 2025 ptesarik@suse.com
- ftrace: Fix regression with module command in stack_trace_filter
  (CVE-2024-56569 bsc#1235031).
- commit edf09c4
* Fri Jan 17 2025 tiwai@suse.de
- Move upstreamed DRM patch into sorted section
- commit efd17c1
* Thu Jan 16 2025 nmorey@suse.com
- RDMA/siw: Remove direct link to net_device (bsc#1235946 CVE-2024-57857)
- commit a26645d
* Thu Jan 16 2025 tbogendoerfer@suse.de
- af_packet: fix vlan_get_protocol_dgram() vs MSG_PEEK
  (CVE-2024-57901 bsc#1235900).
- net: wwan: t7xx: Fix FSM command timeout issue (CVE-2024-39282
  bsc#1235903).
- commit f820992
* Thu Jan 16 2025 tiwai@suse.de
- tpm: Map the ACPI provided event log (bsc#1233260 bsc#1233259
  bsc#1232421).
- commit 9c4f937
* Thu Jan 16 2025 nmorey@suse.com
- RDMA/rtrs: Ensure 'ib_sge list' is accessible (bsc#1235902 CVE-2024-36476)
- commit 5e76f66
* Thu Jan 16 2025 nmorey@suse.com
- RDMA/rxe: Remove the direct link to net_device (bsc#1235906 CVE-2024-57795)
- commit 09cd979
* Thu Jan 16 2025 vkarasulli@suse.de
- iommu/vt-d: Remove cache tags before disabling ATS
  (CVE-2024-56669 bsc#1235245).
- commit f02f36b
* Thu Jan 16 2025 vkarasulli@suse.de
- iommu/vt-d: Fix qi_batch NULL pointer with nested parent  domain
  (CVE-2024-56668 bsc#1235017).
- commit 1757163
* Thu Jan 16 2025 osalvador@suse.de
- mm: use aligned address in copy_user_gigantic_page()
  (CVE-2024-51729 bsc#1235741).
- commit 3c62d9b
* Thu Jan 16 2025 dsterba@suse.com
- bpf: fix recursive lock when verdict program return SK_PASS (CVE-2024-56694 bsc#1235412)
- commit dfde0f5
* Thu Jan 16 2025 dsterba@suse.com
- bpf: fix OOB devmap writes when deleting elements (CVE-2024-56615 bsc#1235426)
- commit 997fa6c
* Thu Jan 16 2025 dsterba@suse.com
- xsk: fix OOB map writes when deleting elements (CVE-2024-56614 bsc#1235424)
- commit 4dda137
* Thu Jan 16 2025 dsterba@suse.com
- mm/mempolicy: fix migrate_to_node() assuming there is at least one VMA in a MM (CVE-2024-56611 bsc#1235391)
- commit 3a11b51
* Wed Jan 15 2025 dsterba@suse.com
- iommu/tegra241-cmdqv: Fix alignment failure at max_n_shift (CVE-2024-53225 bsc#1235006)
- commit d17bd9f
* Wed Jan 15 2025 ailiop@suse.com
- ring-buffer: Fix overflow in __rb_map_vma (bsc#1235752
  CVE-2024-56368).
- commit 887043f
* Wed Jan 15 2025 ailiop@suse.com
- mm: use aligned address in clear_gigantic_page() (bsc#1235742
  CVE-2024-52319).
- commit cf2082f
* Wed Jan 15 2025 ailiop@suse.com
- netdevsim: prevent bad user input in
  nsim_dev_health_break_write() (bsc#1235587 CVE-2024-56716).
- commit 64a78e2
* Wed Jan 15 2025 ailiop@suse.com
- bpf: Fix UAF via mismatching bpf_prog/attachment RCU flavors
  (bsc#1235555 CVE-2024-56675).
- commit 9dd9586
* Wed Jan 15 2025 ailiop@suse.com
- net: netdevsim: fix nsim_pp_hold_write() (bsc#1235554
  CVE-2024-56713).
- commit 9b9335e
* Wed Jan 15 2025 ailiop@suse.com
- mm/gup: handle NULL pages in unpin_user_pages() (bsc#1235388
  CVE-2024-56612).
- commit 58f5e58
* Wed Jan 15 2025 ailiop@suse.com
- xsk: Free skb when TX metadata options are invalid (bsc#1235000
  CVE-2024-53236).
- commit 488293a
* Wed Jan 15 2025 ailiop@suse.com
- ipc: fix memleak if msg_init_ns failed in create_ipc_ns
  (bsc#1234893 CVE-2024-53175).
- commit ee73306
* Wed Jan 15 2025 dsterba@suse.com
- ocfs2: fix uninitialized value in ocfs2_file_read_iter() (CVE-2024-53155 bsc#1234855)
- commit 29d10db
* Wed Jan 15 2025 neelx@suse.com
- btrfs: add a sanity check for btrfs root in btrfs_search_slot()
  (CVE-2024-56774 bsc#1235653).
- commit 7fe00e3
* Wed Jan 15 2025 dsterba@suse.com
- ocfs2: free inode when ocfs2_get_init_inode() fails (CVE-2024-56630 bsc#1235479)
- commit 892fcc7
* Wed Jan 15 2025 dsterba@suse.com
- ceph: give up on paths longer than PATH_MAX (CVE-2024-53685 bsc#1235720)
- commit 96cf2d2
* Wed Jan 15 2025 dsterba@suse.com
- bcache: revert replacing IS_ERR_OR_NULL with IS_ERR again (CVE-2024-48881 bsc#1235727)
- commit 7611048
* Wed Jan 15 2025 dsterba@suse.com
- vfio/mlx5: Fix an unwind issue in mlx5vf_add_migration_pages() (CVE-2024-56742 bsc#1235613)
- commit 561ef4c
* Wed Jan 15 2025 mhocko@suse.com
- net/smc: check return value of sock_recvmsg when draining clc
  data (CVE-2024-57791 bsc#1235759).
- commit 3137fae
* Wed Jan 15 2025 dsterba@suse.com
- udmabuf: change folios array from kmalloc to kvmalloc (CVE-2024-56544 bsc#1235067)
- commit e18704f
* Wed Jan 15 2025 dsterba@suse.com
- scsi: qedf: Fix a possible memory leak in qedf_alloc_and_init_sb() (CVE-2024-56748 bsc#1235627)
- commit bf1507f
* Wed Jan 15 2025 dsterba@suse.com
- scsi: ufs: core: sysfs: Prevent div by zero (CVE-2024-56622 bsc#1235251)
- commit e1723b2
* Wed Jan 15 2025 dsterba@suse.com
- scsi: ufs: core: Cancel RTC work during ufshcd_remove() (CVE-2024-56621 bsc#1235228)
- commit dcbc4ba
* Wed Jan 15 2025 dsterba@suse.com
- scsi: ufs: qcom: Only free platform MSIs when ESI is enabled (CVE-2024-56620 bsc#1235227)
- commit a4f3898
* Wed Jan 15 2025 vkarasulli@suse.de
- virt: tdx-guest: Just leak decrypted memory on unrecoverable
  errors (CVE-2024-57793 bsc#1235768).
- commit 5a20f80
* Wed Jan 15 2025 osalvador@suse.de
- stackdepot: fix stack_depot_save_flags() in NMI context
  (CVE-2024-48876 bsc#1235726).
- commit 21d9f52
* Wed Jan 15 2025 jslaby@suse.cz
- x86/fred: Clear WFE in missing-ENDBRANCH #CPs (CVE-2024-56761
  bsc#1235633).
- commit d326277
* Wed Jan 15 2025 tbogendoerfer@suse.de
- net: ethernet: oa_tc6: fix tx skb race condition between
  reference pointers (CVE-2024-56788 bsc#1235754).
- tools/net/ynl: fix sub-message key lookup for nested attributes
  (git-fixes).
- net: tun: fix tun_napi_alloc_frags() (CVE-2024-56372
  bsc#1235753).
- net: renesas: rswitch: avoid use-after-put for a device tree
  node (CVE-2024-55639 bsc#1235737).
- commit ab1ee58
* Wed Jan 15 2025 vkarasulli@suse.de
- KVM: SVM: Allow guest writes to set MSR_AMD64_DE_CFG bits
  (bsc#1234635).
- commit ad88ff2
* Wed Jan 15 2025 vbabka@suse.cz
- mm/page_alloc: don't call pfn_to_page() on possibly non-existent
  PFN in split_large_buddy() (CVE-2024-57881 bsc#1235843).
- commit 47fc212
* Wed Jan 15 2025 jlee@suse.com
- Reviewed
  patches.suse/0001-efi-do-not-automatically-generate-secret-key.patch
- commit 64be71e
* Wed Jan 15 2025 jlee@suse.com
- Reviewed
  patches.suse/0011-PM-hibernate-require-hibernate-snapshot-image-to-be-.patch
- commit fac3c3b
* Wed Jan 15 2025 jlee@suse.com
- Refresh
  patches.suse/0010-PM-hibernate-a-option-to-request-that-snapshot-image.patch.
  Update config files.
  CONFIG_HIBERNATE_VERIFICATION_FORCE is not set
- commit d0b09b5
* Wed Jan 15 2025 jlee@suse.com
- Refresh
  patches.suse/0009-PM-hibernate-prevent-EFI-secret-key-to-be-regenerate.patch.
- commit 38aa2b2
* Tue Jan 14 2025 lduncan@suse.com
- Revert "block, bfq: merge bfq_release_process_ref() into
  bfq_put_cooperator()" (CVE-2024-53182 bsc#1234946).
- block: fix uaf for flush rq while iterating tags (CVE-2024-53170
  bsc#1234888).
- scsi: qedi: Fix a possible memory leak in
  qedi_alloc_and_init_sb() (CVE-2024-56747 bsc#1234934).
- scsi: bfa: Fix use-after-free in bfad_im_module_exit()
  (CVE-2024-53227 bsc#1235011).
- scsi: hisi_sas: Create all dump files during debugfs
  initialization (CVE-2024-56588 bsc#1235123).
- commit d7ec03b
* Tue Jan 14 2025 ematsumiya@suse.de
- smb: client: fix TCP timers deadlock after rmmod (bsc#1235723,
  CVE-2024-54680).
- commit 067db58
* Tue Jan 14 2025 nik.borisov@suse.com
- x86/cpu: Add Lunar Lake to list of CPUs with a broken MONITOR implementation (jsc#PED-11963).
- commit 40fc24b
* Tue Jan 14 2025 dsterba@suse.com
- scsi: hisi_sas: Add cond_resched() for no forced preemption model (CVE-2024-56589 bsc#1235241)
- commit 5616a9a
* Tue Jan 14 2025 jack@suse.cz
- Enable CONFIG_BUG_ON_DATA_CORRUPTION (jsc#PED-11849)
- commit ad832d9
* Tue Jan 14 2025 andrea.porta@suse.com
- arm64: dts: rockchip: add hevc power domain clock to rk3328
  (git-fixes).
- commit 4ced1a7
* Tue Jan 14 2025 andrea.porta@suse.com
- arm64: dts: rockchip: rename rfkill label for Radxa ROCK 5B
  (git-fixes).
- commit 1aa0c5f
* Tue Jan 14 2025 andrea.porta@suse.com
- arm64: dts: imx95: correct the address length of
  netcmix_blk_ctrl (git-fixes).
- commit 261c0be
* Tue Jan 14 2025 mfranc@suse.cz
- Remove superflous References tags.
- Refresh
  patches.suse/0001-Lock-down-x86_64-kernel-in-secure-boot-mode-in-subsy.patch.
- Refresh
  patches.suse/0002-security-Add-a-kernel-lockdown-flag-for-early-boot-s.patch.
- commit 53733e1
* Tue Jan 14 2025 andrea.porta@suse.com
- arm64: dts: broadcom: Fix L2 linesize for Raspberry Pi 5
  (git-fixes).
- commit 34dcb38
* Tue Jan 14 2025 oneukum@suse.com
- reinstating kABI paddings for crypto
- commit dcd0a1e
* Tue Jan 14 2025 oneukum@suse.com
- Refresh patches.suse/crypto-add-suse_kabi_padding.patch.
- commit 7e643ee
* Tue Jan 14 2025 oneukum@suse.com
- reinstate PCI kABI paddings
- commit d5bb436
* Tue Jan 14 2025 oneukum@suse.com
- Reinstating kABI padding for Thunderbolt
- commit 13936cf
* Tue Jan 14 2025 oneukum@suse.com
- usb: typec: Add attribute file showing the USB Modes of the
  partner (git-fixes).
- Refresh patches.suse/paddings-add-for-type-C-new-in-SP5.patch.
- commit 1aae08b
* Tue Jan 14 2025 dsterba@suse.com
- Delete patches.suse/btrfs-fix-use-after-free-waiting-for-encoded-read-en.patch (bsc#1235128)
- commit 6ac27ed
* Tue Jan 14 2025 mgorman@suse.de
- Update config files.
  Disable HARDENED_USERCOPY by default but can be re-enabled via the kernel
  command line.
- commit b89f0e3
* Tue Jan 14 2025 oneukum@suse.com
- usb: typec: Add attribute file showing the supported USB modes
  of the port (git-fixes).
- Refresh patches.suse/paddings-add-for-type-C-new-in-SP5.patch.
- commit 2fd6860
* Tue Jan 14 2025 mgorman@suse.de
- mm: security: Allow default HARDENED_USERCOPY to be set at
  compile time (jsc#PED-11838).
- mm: security: Move hardened usercopy under 'Kernel hardening
  options' (jsc#PED-11838).
- commit 6f73ffe
* Tue Jan 14 2025 oneukum@suse.com
- usb: typec: ucsi: Fix a missing bits to bytes conversion in
  ucsi_init() (git-fixes).
- commit 7a60998
* Tue Jan 14 2025 oneukum@suse.com
- usb: typec: ucsi: Convert connector specific commands to bitmaps
  (git-fixes).
- commit 1060e28
* Tue Jan 14 2025 oneukum@suse.com
- usb: typec: ucsi: Helper for Get Connector Status command
  (git-fixes).
- commit 7530947
* Tue Jan 14 2025 oneukum@suse.com
- usb: typec: ucsi: Add support for the partner USB Modes
  (git-fixes).
- commit bb31d21
* Tue Jan 14 2025 oneukum@suse.com
- usb: typec: ucsi: Supply the USB capabilities to the ports
  (git-fixes).
- commit a77d656
* Tue Jan 14 2025 oneukum@suse.com
- usb: typec: ucsi: UCSI2.0 Set Sink Path command support
  (git-fixes).
- commit 0376245
* Tue Jan 14 2025 oneukum@suse.com
- usb: typec: ucsi: glink: use device_for_each_child_node_scoped()
  (git-fixes).
- commit 3691738
* Tue Jan 14 2025 jlee@suse.com
- Refresh
  patches.suse/0008-PM-hibernate-Generate-and-verify-signature-for-snaps.patch.
  Update config files.
  CONFIG_HIBERNATE_VERIFICATION
  CONFIG_EFI_SECRET_KEY
  CONFIG_HIDDEN_AREA
- commit 4b57a00
* Tue Jan 14 2025 jlee@suse.com
- Refresh
  patches.suse/0007-PM-hibernate-encrypt-hidden-area.patch.
- commit a1cdd8d
* Tue Jan 14 2025 jlee@suse.com
- Refresh
  patches.suse/0006-efi-allow-user-to-regenerate-secret-key.patch.
- commit 498aa9e
* Mon Jan 13 2025 krisman@suse.de
- Update
  patches.suse/ACPI-x86-Add-adev-NULL-check-to-acpi_quirk_skip_serd.patch
  (stable-fixes CVE-2024-56782 bsc#1235629).
- Update
  patches.suse/ALSA-6fire-Release-resources-at-card-release.patch
  (git-fixes CVE-2024-53239 bsc#1235054).
- Update
  patches.suse/ALSA-caiaq-Use-snd_card_free_when_closed-at-disconne.patch
  (git-fixes CVE-2024-56531 bsc#1235057).
- Update
  patches.suse/ALSA-control-Avoid-WARN-for-symlink-errors.patch
  (git-fixes CVE-2024-56657 bsc#1235432).
- Update
  patches.suse/ALSA-core-Fix-possible-NULL-dereference-caused-by-ku.patch
  (git-fixes CVE-2024-56696 bsc#1235539).
- Update
  patches.suse/ALSA-memalloc-prefer-dma_mapping_error-over-explicit.patch
  (git-fixes CVE-2024-57800 bsc#1235772).
- Update
  patches.suse/ALSA-pcm-Add-sanity-NULL-check-for-the-default-mmap-.patch
  (stable-fixes CVE-2024-53180 bsc#1234929).
- Update
  patches.suse/ALSA-us122l-Use-snd_card_free_when_closed-at-disconn.patch
  (git-fixes CVE-2024-56532 bsc#1235059).
- Update
  patches.suse/ALSA-usb-audio-Fix-out-of-bounds-reads-when-finding-.patch
  (stable-fixes CVE-2024-53150 bsc#1234834).
- Update
  patches.suse/ALSA-usb-audio-Fix-potential-out-of-bound-accesses-f.patch
  (git-fixes CVE-2024-53197 bsc#1235464).
- Update
  patches.suse/ALSA-usx2y-Use-snd_card_free_when_closed-at-disconne.patch
  (git-fixes CVE-2024-56533 bsc#1235053).
- Update
  patches.suse/ASoC-Intel-sof_sdw-Add-space-for-a-terminator-into-D.patch
  (git-fixes CVE-2024-57880 bsc#1235800).
- Update
  patches.suse/ASoC-SOF-Intel-hda-dai-Do-not-release-the-link-DMA-o.patch
  (git-fixes CVE-2024-57805 bsc#1235790).
- Update
  patches.suse/ASoC-imx-audmix-Add-NULL-check-in-imx_audmix_probe.patch
  (git-fixes CVE-2024-53199 bsc#1234967).
- Update
  patches.suse/ASoC-mediatek-Check-num_codecs-is-not-zero-to-avoid-.patch
  (git-fixes CVE-2024-56685 bsc#1235561).
- Update
  patches.suse/Bluetooth-L2CAP-do-not-leave-dangling-sk-pointer-on-.patch
  (stable-fixes CVE-2024-56605 bsc#1235061).
- Update patches.suse/Bluetooth-MGMT-Fix-possible-deadlocks.patch
  (git-fixes CVE-2024-53207 bsc#1234907).
- Update
  patches.suse/Bluetooth-MGMT-Fix-slab-use-after-free-Read-in-set_p.patch
  (git-fixes CVE-2024-53208 bsc#1234909).
- Update
  patches.suse/Bluetooth-RFCOMM-avoid-leaving-dangling-sk-pointer-i.patch
  (stable-fixes CVE-2024-56604 bsc#1235056).
- Update
  patches.suse/Bluetooth-btmtk-adjust-the-position-to-init-iso-data.patch
  (git-fixes CVE-2024-53238 bsc#1234910).
- Update
  patches.suse/Bluetooth-btmtk-avoid-UAF-in-btmtk_process_coredump.patch
  (git-fixes CVE-2024-56653 bsc#1235531).
- Update
  patches.suse/Bluetooth-btusb-mediatek-add-intf-release-flow-when-.patch
  (stable-fixes CVE-2024-56757 bsc#1235619).
- Update
  patches.suse/Bluetooth-fix-use-after-free-in-device_for_each_chil.patch
  (git-fixes CVE-2024-53237 bsc#1235007).
- Update
  patches.suse/Bluetooth-hci_conn-Use-disable_delayed_work_sync.patch
  (stable-fixes CVE-2024-56591 bsc#1235052).
- Update
  patches.suse/Bluetooth-hci_core-Fix-not-checking-skb-length-on-hc.patch
  (stable-fixes CVE-2024-56590 bsc#1235038).
- Update
  patches.suse/Bluetooth-hci_event-Fix-using-rcu_read_-un-lock-whil.patch
  (git-fixes CVE-2024-56654 bsc#1235532).
- Update
  patches.suse/Bluetooth-iso-Always-release-hdev-at-the-end-of-iso_.patch
  (git-fixes CVE-2024-57879 bsc#1235802).
- Update
  patches.suse/Bluetooth-iso-Fix-circular-lock-in-iso_conn_big_sync.patch
  (git-fixes CVE-2024-54191 bsc#1235717).
- Update
  patches.suse/Bluetooth-iso-Fix-circular-lock-in-iso_listen_bis.patch
  (git-fixes CVE-2024-54460 bsc#1235722).
- Update
  patches.suse/HID-wacom-fix-when-get-product-name-maybe-null-point.patch
  (git-fixes CVE-2024-56629 bsc#1235473).
- Update
  patches.suse/NFSD-Prevent-NULL-dereference-in-nfsd4_process_cb_update.patch
  (git-fixes CVE-2024-53217 bsc#1234999).
- Update
  patches.suse/NFSD-Prevent-a-potential-integer-overflow.patch
  (git-fixes CVE-2024-53146 bsc#1234853).
- Update
  patches.suse/NFSv4.0-Fix-a-use-after-free-problem-in-the-asynchronous-open.patch
  (git-fixes CVE-2024-53173 bsc#1234891).
- Update patches.suse/PCI-Fix-reset_method_store-memory-leak.patch
  (git-fixes CVE-2024-56745 bsc#1235563).
- Update
  patches.suse/PCI-Fix-use-after-free-of-slot-bus-on-hot-remove.patch
  (stable-fixes CVE-2024-53194 bsc#1235459).
- Update
  patches.suse/PCI-MSI-Handle-lack-of-irqdomain-gracefully.patch
  (git-fixes CVE-2024-56760 bsc#1235616).
- Update
  patches.suse/PCI-endpoint-Fix-PCI-domain-ID-release-in-pci_epc_de.patch
  (git-fixes CVE-2024-56561 bsc#1235105).
- Update
  patches.suse/PCI-endpoint-epf-mhi-Avoid-NULL-dereference-if-DT-la.patch
  (git-fixes CVE-2024-56689 bsc#1235543).
- Update
  patches.suse/PCI-imx6-Fix-suspend-resume-support-on-i.MX6QDL.patch
  (stable-fixes CVE-2024-57809 bsc#1235793).
- Update
  patches.suse/PCI-qcom-ep-Move-controller-cleanups-to-qcom_pcie_pe.patch
  (git-fixes CVE-2024-53153 bsc#1234830).
- Update
  patches.suse/PCI-tegra194-Move-controller-cleanups-to-pex_ep_even.patch
  (git-fixes CVE-2024-53152 bsc#1234841).
- Update
  patches.suse/RDMA-hns-Fix-cpu-stuck-caused-by-printings-during-re.patch
  (jsc#PED-11250 CVE-2024-56722 bsc#1235570).
- Update
  patches.suse/RDMA-mlx5-Move-events-notifier-registration-to-be-af.patch
  (git-fixes CVE-2024-53224 bsc#1235009).
- Update
  patches.suse/RDMA-rxe-Fix-the-qp-flush-warnings-in-req.patch
  (jsc#PED-11323 CVE-2024-53229 bsc#1234905).
- Update
  patches.suse/SUNRPC-make-sure-cache-entry-active-before-cache_show.patch
  (git-fixes CVE-2024-53174 bsc#1234899).
- Update
  patches.suse/accel-ivpu-Fix-WARN-in-ivpu_ipc_send_receive_interna.patch
  (git-fixes CVE-2024-54193 bsc#1235713).
- Update
  patches.suse/accel-ivpu-Fix-general-protection-fault-in-ivpu_bo_l.patch
  (git-fixes CVE-2024-54455 bsc#1235719).
- Update
  patches.suse/accel-ivpu-Prevent-recovery-invocation-during-probe-.patch
  (git-fixes CVE-2024-56540 bsc#1235063).
- Update
  patches.suse/acpi-nfit-vmalloc-out-of-bounds-Read-in-acpi_nfit_ct.patch
  (git-fixes CVE-2024-56662 bsc#1235533).
- Update
  patches.suse/ad7780-fix-division-by-zero-in-ad7780_write_raw.patch
  (git-fixes CVE-2024-56567 bsc#1234916).
- Update
  patches.suse/af_packet-avoid-erroring-out-after-sock_init_data-in.patch
  (CVE-2024-56606 bsc#123541 bsc#1235417).
- Update
  patches.suse/apparmor-test-Fix-memory-leak-for-aa_unpack_strdup.patch
  (git-fixes CVE-2024-56741 bsc#1235502).
- Update
  patches.suse/arm64-ptrace-fix-partial-SETREGSET-for-NT_ARM_FPMR.patch
  (git-fixes CVE-2024-57878 bsc#1235803).
- Update
  patches.suse/arm64-ptrace-fix-partial-SETREGSET-for-NT_ARM_POE.patch
  (git-fixes CVE-2024-57877 bsc#1235804).
- Update
  patches.suse/blk-cgroup-Fix-UAF-in-blkcg_unpin_online.patch
  (bsc#1234726 CVE-2024-56672 bsc#1235534).
- Update
  patches.suse/bnxt_en-Fix-aggregation-ID-mask-to-prevent-oops-on-5.patch
  (jsc#PED-10684 jsc#PED-11230 CVE-2024-56656 bsc#1235444).
- Update
  patches.suse/cacheinfo-Allocate-memory-during-CPU-hotplug-if-not-done-f.patch
  (jsc#PED-10467 CVE-2024-56617 bsc#1235429).
- Update
  patches.suse/can-dev-can_set_termination-allow-sleeping-GPIOs.patch
  (git-fixes CVE-2024-56625 bsc#1235223).
- Update
  patches.suse/can-hi311x-hi3110_can_ist-fix-potential-use-after-fr.patch
  (git-fixes CVE-2024-56651 bsc#1235528).
- Update
  patches.suse/can-j1939-j1939_session_new-fix-skb-reference-counti.patch
  (git-fixes CVE-2024-56645 bsc#1235134).
- Update
  patches.suse/clk-clk-apple-nco-Add-NULL-check-in-applnco_probe.patch
  (git-fixes CVE-2024-53154 bsc#1234826).
- Update
  patches.suse/clk-clk-loongson2-Fix-memory-corruption-bug-in-struc.patch
  (git-fixes CVE-2024-53193 bsc#1234902).
- Update
  patches.suse/clk-clk-loongson2-Fix-potential-buffer-overflow-in-f.patch
  (git-fixes CVE-2024-53192 bsc#1234956).
- Update
  patches.suse/clk-ralink-mtmips-fix-clocks-probe-order-in-oldest-r.patch
  (git-fixes CVE-2024-53223 bsc#1234976).
- Update
  patches.suse/crypto-bcm-add-error-check-in-the-ahash_hmac_init-fu.patch
  (git-fixes CVE-2024-56681 bsc#1235557).
- Update
  patches.suse/crypto-caam-Fix-the-pointer-passed-to-caam_qi_shutdo.patch
  (git-fixes CVE-2024-56754 bsc#1234918).
- Update
  patches.suse/crypto-pcrypt-Call-crypto-layer-directly-when-padata.patch
  (git-fixes CVE-2024-56690 bsc#1235428).
- Update
  patches.suse/crypto-qat-qat_420xx-fix-off-by-one-in-uof_get_name.patch
  (git-fixes CVE-2024-53163 bsc#1234828).
- Update
  patches.suse/crypto-qat-qat_4xxx-fix-off-by-one-in-uof_get_name.patch
  (git-fixes CVE-2024-53162 bsc#1234843).
- Update
  patches.suse/dlm-fix-dlm_recover_members-refcount-on-error.patch
  (git-fixes CVE-2024-56749 bsc#1235628).
- Update
  patches.suse/dlm-fix-possible-lkb_resource-null-dereference.patch
  (git-fixes CVE-2024-47809 bsc#1235714).
- Update
  patches.suse/dma-debug-fix-a-possible-deadlock-on-radix_lock.patch
  (stable-fixes CVE-2024-47143 bsc#1235710).
- Update
  patches.suse/dmaengine-at_xdmac-avoid-null_prt_deref-in-at_xdmac_.patch
  (git-fixes CVE-2024-56767 bsc#1235160).
- Update
  patches.suse/drivers-soc-xilinx-add-the-missing-kfree-in-xlnx_add.patch
  (git-fixes CVE-2024-56546 bsc#1235070).
- Update
  patches.suse/drm-amd-display-Adding-array-index-check-to-prevent-.patch
  (stable-fixes CVE-2024-56784 bsc#1235654).
- Update
  patches.suse/drm-amd-display-Fix-handling-of-plane-refcount.patch
  (stable-fixes CVE-2024-56775 bsc#1235657).
- Update
  patches.suse/drm-amd-display-Fix-null-check-for-pipe_ctx-plane_st-2bc96c9.patch
  (git-fixes CVE-2024-53200 bsc#1234968).
- Update
  patches.suse/drm-amd-display-Fix-null-check-for-pipe_ctx-plane_st.patch
  (git-fixes CVE-2024-53201 bsc#1234969).
- Update
  patches.suse/drm-amd-display-Fix-out-of-bounds-access-in-dcn21_li.patch
  (stable-fixes CVE-2024-56608 bsc#1235487).
- Update
  patches.suse/drm-amd-display-fix-a-memleak-issue-when-driver-is-r.patch
  (git-fixes CVE-2024-56542 bsc#1234908).
- Update
  patches.suse/drm-amdgpu-Fix-the-memory-allocation-issue-in-amdgpu.patch
  (git-fixes CVE-2024-56697 bsc#1235544).
- Update patches.suse/drm-amdgpu-don-t-access-invalid-sched.patch
  (git-fixes CVE-2024-46896 bsc#1235707).
- Update patches.suse/drm-amdgpu-fix-usage-slab-after-free.patch
  (stable-fixes CVE-2024-56551 bsc#1235075).
- Update
  patches.suse/drm-amdgpu-gfx9-Add-Cleaner-Shader-Deinitialization-.patch
  (git-fixes CVE-2024-56753 bsc#1235631).
- Update
  patches.suse/drm-amdgpu-set-the-right-AMDGPU-sg-segment-limitatio.patch
  (stable-fixes CVE-2024-56594 bsc#1235413).
- Update
  patches.suse/drm-amdkfd-Dereference-null-return-value.patch
  (git-fixes CVE-2024-56666 bsc#1235242).
- Update
  patches.suse/drm-amdkfd-Use-dynamic-allocation-for-CU-occupancy-a.patch
  (git-fixes CVE-2024-56695 bsc#1235541).
- Update
  patches.suse/drm-dp_mst-Fix-MST-sideband-message-body-length-chec.patch
  (stable-fixes CVE-2024-56616 bsc#1235427).
- Update
  patches.suse/drm-i915-Fix-NULL-pointer-dereference-in-capture_eng.patch
  (git-fixes CVE-2024-56667 bsc#1235016).
- Update
  patches.suse/drm-modes-Avoid-divide-by-zero-harder-in-drm_mode_vr.patch
  (stable-fixes CVE-2024-56369 bsc#1235750).
- Update
  patches.suse/drm-nouveau-gr-gf100-Fix-missing-unlock-in-gf100_gr_.patch
  (git-fixes CVE-2024-56752 bsc#1234937).
- Update
  patches.suse/drm-panel-himax-hx83102-Add-a-check-to-prevent-NULL-.patch
  (git-fixes CVE-2024-56711 bsc#1235562).
- Update
  patches.suse/drm-sti-avoid-potential-dereference-of-error-pointer-831214f.patch
  (git-fixes CVE-2024-56776 bsc#1235647).
- Update
  patches.suse/drm-sti-avoid-potential-dereference-of-error-pointer-e965e77.patch
  (git-fixes CVE-2024-56777 bsc#1235641).
- Update
  patches.suse/drm-sti-avoid-potential-dereference-of-error-pointer.patch
  (git-fixes CVE-2024-56778 bsc#1235635).
- Update
  patches.suse/drm-vc4-hdmi-Avoid-hang-with-debug-registers-when-su.patch
  (git-fixes CVE-2024-56683 bsc#1235497).
- Update
  patches.suse/drm-xe-guc_submit-fix-race-around-suspend_pending.patch
  (git-fixes CVE-2024-56552 bsc#1235071).
- Update patches.suse/drm-xe-reg_sr-Remove-register-pool.patch
  (git-fixes CVE-2024-56652 bsc#1235529).
- Update
  patches.suse/drm-xlnx-zynqmp_disp-layer-may-be-null-while-releasi.patch
  (git-fixes CVE-2024-56537 bsc#1235049).
- Update
  patches.suse/drm-zynqmp_kms-Unplug-DRM-device-before-removal.patch
  (git-fixes CVE-2024-56538 bsc#1235051).
- Update
  patches.suse/efi-libstub-Free-correct-pointer-on-failure.patch
  (git-fixes CVE-2024-56573 bsc#1235042).
- Update
  patches.suse/erofs-fix-blksize-PAGE_SIZE-for-file-backed-mounts.patch
  (git-fixes CVE-2024-56750 bsc#1235630).
- Update patches.suse/erofs-fix-file-backed-mounts-over-FUSE.patch
  (git-fixes CVE-2024-53235 bsc#1234998).
- Update
  patches.suse/erofs-handle-NONHEAD-delta-1-lclusters-gracefully.patch
  (git-fixes CVE-2024-53234 bsc#1235045).
- Update
  patches.suse/exfat-fix-out-of-bounds-access-of-directory-entries.patch
  (git-fixes CVE-2024-53147 bsc#1234857).
- Update
  patches.suse/fbdev-sh7760fb-Fix-a-possible-memory-leak-in-sh7760f.patch
  (git-fixes CVE-2024-56746 bsc#1235622).
- Update
  patches.suse/firmware-arm_scpi-Check-the-DVFS-OPP-count-returned-.patch
  (git-fixes CVE-2024-53157 bsc#1234827).
- Update
  patches.suse/firmware_loader-Fix-possible-resource-leak-in-fw_log.patch
  (git-fixes CVE-2024-53202 bsc#1234970).
- Update
  patches.suse/gpio-graniterapids-Fix-vGPIO-driver-crash.patch
  (stable-fixes CVE-2024-56671 bsc#1235018).
- Update
  patches.suse/gpio-grgpio-Add-NULL-check-in-grgpio_probe.patch
  (git-fixes CVE-2024-56634 bsc#1235486).
- Update
  patches.suse/i3c-Use-i3cdev-desc-info-instead-of-calling-i3c_devi.patch
  (stable-fixes CVE-2024-43098 bsc#1235703).
- Update
  patches.suse/i3c-master-Fix-miss-free-init_dyn_addr-at-i3c_master.patch
  (git-fixes CVE-2024-56562 bsc#1234930).
- Update
  patches.suse/i3c-mipi-i3c-hci-Mask-ring-interrupts-before-ring-st.patch
  (stable-fixes CVE-2024-45828 bsc#1235705).
- Update
  patches.suse/igb-Fix-potential-invalid-memory-access-in-igb_init_.patch
  (jsc#PED-10426 jsc#PED-10425 CVE-2024-52332 bsc#1235700).
- Update
  patches.suse/iio-adc-ad7923-Fix-buffer-overflow-for-tx_buf-and-ri.patch
  (git-fixes CVE-2024-56557 bsc#1235122).
- Update
  patches.suse/io_uring-check-for-overflows-in-io_pin_pages.patch
  (git-fixes CVE-2024-53187 bsc#1234947).
- Update
  patches.suse/io_uring-check-if-iowq-is-killed-before-queuing.patch
  (git-fixes CVE-2024-56709 bsc#1235552).
- Update
  patches.suse/io_uring-tctx-work-around-xa_store-allocation-error-.patch
  (git-fixes CVE-2024-56584 bsc#1235117).
- Update patches.suse/iommu-s390-Implement-blocking-domain.patch
  (git-fixes bsc#1234350 CVE-2024-53232 bsc#1235050).
- Update
  patches.suse/iommufd-Fix-out_fput-in-iommufd_fault_alloc.patch
  (git-fixes CVE-2024-56624 bsc#1235469).
- Update
  patches.suse/ionic-Fix-netdev-notifier-unregister-on-failure.patch
  (jsc#PED-11378 CVE-2024-56715 bsc#1235612).
- Update patches.suse/ionic-no-double-destroy-workqueue.patch
  (jsc#PED-11378 CVE-2024-56714 bsc#1235558).
- Update
  patches.suse/irqchip-riscv-aplic-Prevent-crash-when-MSI-domain-is.patch
  (git-fixes CVE-2024-56682 bsc#1235559).
- Update
  patches.suse/kcsan-Turn-report_filterlist_lock-into-a-raw_spinloc.patch
  (stable-fixes CVE-2024-56610 bsc#1235390).
- Update
  patches.suse/kunit-Fix-potential-null-dereference-in-kunit_device.patch
  (git-fixes CVE-2024-56773 bsc#1235594).
- Update
  patches.suse/kunit-string-stream-Fix-a-UAF-bug-in-kunit_init_suit.patch
  (git-fixes CVE-2024-56772 bsc#1235651).
- Update
  patches.suse/leds-class-Protect-brightness_show-with-led_cdev-led.patch
  (stable-fixes CVE-2024-56587 bsc#1235125).
- Update
  patches.suse/mailbox-mtk-cmdq-fix-wrong-use-of-sizeof-in-cmdq_get.patch
  (git-fixes CVE-2024-56684 bsc#1235560).
- Update
  patches.suse/media-atomisp-Add-check-for-rgby_data-memory-allocat.patch
  (git-fixes CVE-2024-56705 bsc#1235568).
- Update
  patches.suse/media-dvb-frontends-dib3000mb-fix-uninit-value-in-di.patch
  (git-fixes CVE-2024-56769 bsc#1235155).
- Update
  patches.suse/media-i2c-tc358743-Fix-crash-in-the-probe-error-path.patch
  (git-fixes CVE-2024-56576 bsc#1235019).
- Update
  patches.suse/media-imx-jpeg-Ensure-power-suppliers-be-suspended-b.patch
  (git-fixes CVE-2024-56575 bsc#1235039).
- Update
  patches.suse/media-imx-jpeg-Set-video-drvdata-before-register-vid.patch
  (git-fixes CVE-2024-56578 bsc#1235115).
- Update
  patches.suse/media-intel-ipu6-do-not-handle-interrupts-when-devic.patch
  (git-fixes CVE-2024-56680 bsc#1235556).
- Update
  patches.suse/media-mtk-jpeg-Fix-null-ptr-deref-during-unload-modu.patch
  (git-fixes CVE-2024-56577 bsc#1235112).
- Update
  patches.suse/media-platform-allegro-dvt-Fix-possible-memory-leak-.patch
  (git-fixes CVE-2024-56572 bsc#1235043).
- Update
  patches.suse/media-qcom-camss-fix-error-path-on-configuration-of-.patch
  (git-fixes CVE-2024-56580 bsc#1235114).
- Update
  patches.suse/media-ts2020-fix-null-ptr-deref-in-ts2020_probe.patch
  (git-fixes CVE-2024-56574 bsc#1235040).
- Update
  patches.suse/media-uvcvideo-Require-entities-to-have-a-non-zero-u.patch
  (git-fixes CVE-2024-56571 bsc#1235037).
- Update
  patches.suse/media-wl128x-Fix-atomicity-violation-in-fmc_send_cmd.patch
  (git-fixes CVE-2024-56700 bsc#1235500).
- Update
  patches.suse/mfd-intel_soc_pmic_bxtwc-Use-IRQ-domain-for-PMIC-dev.patch
  (git-fixes CVE-2024-56723 bsc#1235571).
- Update
  patches.suse/mfd-intel_soc_pmic_bxtwc-Use-IRQ-domain-for-TMU-devi.patch
  (git-fixes CVE-2024-56724 bsc#1235577).
- Update
  patches.suse/mfd-intel_soc_pmic_bxtwc-Use-IRQ-domain-for-USB-Type.patch
  (git-fixes CVE-2024-56691 bsc#1235425).
- Update
  patches.suse/msft-hv-3081-hv_sock-Initializing-vsk-trans-to-NULL-to-prevent-a-.patch
  (git-fixes CVE-2024-53103 bsc#1234024).
- Update
  patches.suse/msft-hv-3082-HID-hyperv-streamline-driver-probe-to-avoid-devres-i.patch
  (git-fixes CVE-2024-56545 bsc#1235069).
- Update
  patches.suse/msft-hv-3095-Drivers-hv-util-Avoid-accessing-a-ringbuffer-not-ini.patch
  (git-fixes CVE-2024-55916 bsc#1235747).
- Update
  patches.suse/mtd-rawnand-fix-double-free-in-atmel_pmecc_create_us.patch
  (git-fixes CVE-2024-56766 bsc#1235219).
- Update
  patches.suse/mtd-spinand-winbond-Fix-512GW-01GW-01JW-and-02JW-ECC.patch
  (git-fixes CVE-2024-56771 bsc#1235649).
- Update
  patches.suse/net-mlx5-DR-prevent-potential-error-pointer-derefere.patch
  (jsc#PED-11331 CVE-2024-56660 bsc#1235437).
- Update
  patches.suse/net-usb-lan78xx-Fix-double-free-issue-with-interrupt.patch
  (git-fixes CVE-2024-53213 bsc#1234973).
- Update
  patches.suse/nfs-blocklayout-Don-t-attempt-unregister-for-invalid-block-device.patch
  (git-fixes CVE-2024-53167 bsc#1234886).
- Update
  patches.suse/nfs-localio-must-clear-res.replen-in-nfs_local_read_done.patch
  (git-fixes CVE-2024-56740 bsc#1234932).
- Update
  patches.suse/nfs_common-must-not-hold-RCU-while-calling-nfsd_file_put_local.patch
  (git-fixes CVE-2024-56743 bsc#1235614).
- Update
  patches.suse/nfsd-fix-nfs4_openowner-leak-when-concurrent-nfsd4_open-occur.patch
  (git-fixes CVE-2024-56779 bsc#1235632).
- Update
  patches.suse/nfsd-make-sure-exp-active-before-svc_export_show.patch
  (git-fixes CVE-2024-56558 bsc#1235100).
- Update
  patches.suse/nvme-fabrics-fix-kernel-crash-while-shutting-down-co.patch
  (git-fixes CVE-2024-53169 bsc#1234900).
- Update
  patches.suse/nvme-pci-fix-freeing-of-the-HMB-descriptor-table.patch
  (git-fixes CVE-2024-56756 bsc#1234922).
- Update
  patches.suse/nvme-rdma-unquiesce-admin_q-before-destroy-it.patch
  (git-fixes CVE-2024-49569 bsc#1235730).
- Update
  patches.suse/nvme-tcp-fix-the-memleak-while-create-new-ctrl-faile.patch
  (git-fixes CVE-2024-56632 bsc#1235483).
- Update
  patches.suse/octeontx2-pf-handle-otx2_mbox_get_rsp-errors-in-cn10.patch
  (jsc#PED-11317 CVE-2024-56726 bsc#1235582).
- Update
  patches.suse/octeontx2-pf-handle-otx2_mbox_get_rsp-errors-in-otx2-69297b0d.patch
  (jsc#PED-11317 CVE-2024-56725 bsc#1235578).
- Update
  patches.suse/octeontx2-pf-handle-otx2_mbox_get_rsp-errors-in-otx2-bd3110bc.patch
  (jsc#PED-11317 CVE-2024-56727 bsc#1235583).
- Update
  patches.suse/octeontx2-pf-handle-otx2_mbox_get_rsp-errors-in-otx2-e26f8eac.patch
  (jsc#PED-11317 CVE-2024-56728 bsc#1235656).
- Update
  patches.suse/octeontx2-pf-handle-otx2_mbox_get_rsp-errors-in-otx2-f5b942e6.patch
  (jsc#PED-11317 CVE-2024-56707 bsc#1235545).
- Update
  patches.suse/octeontx2-pf-handle-otx2_mbox_get_rsp-errors-in-otx2.patch
  (jsc#PED-11317 CVE-2024-56679 bsc#1235498).
- Update
  patches.suse/phy-realtek-usb-fix-NULL-deref-in-rtk_usb2phy_probe.patch
  (git-fixes CVE-2024-53205 bsc#1234954).
- Update
  patches.suse/phy-realtek-usb-fix-NULL-deref-in-rtk_usb3phy_probe.patch
  (git-fixes CVE-2024-53204 bsc#1234955).
- Update
  patches.suse/phy-rockchip-samsung-hdptx-Set-drvdata-before-enabli.patch
  (git-fixes CVE-2024-57799 bsc#1235770).
- Update
  patches.suse/pinmux-Use-sequential-access-to-access-desc-pinmux-d.patch
  (stable-fixes CVE-2024-47141 bsc#1235708).
- Update
  patches.suse/pmdomain-imx-gpcv2-Adjust-delay-after-power-up-hands.patch
  (git-fixes CVE-2024-56618 bsc#1235465).
- Update
  patches.suse/power-supply-gpio-charger-Fix-set-charge-current-lim.patch
  (git-fixes CVE-2024-57792 bsc#1235764).
- Update
  patches.suse/powerpc-fadump-Move-fadump_cma_init-to-setup_arch-af.patch
  (bsc#1215199 CVE-2024-56677 bsc#1235494).
- Update
  patches.suse/powerpc-mm-fault-Fix-kfence-page-fault-reporting.patch
  (bsc#1194869 CVE-2024-56678 bsc#1235495).
- Update
  patches.suse/powerpc-pseries-Fix-dtl_access_lock-to-be-a-rw_semap.patch
  (bsc#1194869 CVE-2024-56701 bsc#1235496).
- Update patches.suse/regulator-axp20x-AXP717-set-ramp_delay.patch
  (git-fixes CVE-2024-53682 bsc#1235718).
- Update
  patches.suse/rtc-check-if-__rtc_read_time-was-successful-in-rtc_t.patch
  (git-fixes CVE-2024-56739 bsc#1235611).
- Update
  patches.suse/s390-cpum_sf-Fix-and-protect-memory-allocation-of-SDBs-with-mutex.patch
  (git-fixes bsc#1234348 CVE-2024-56706 bsc#1235586).
- Update
  patches.suse/s390-entry-Mark-IRQ-entries-to-fix-stack-depot-warnings.patch
  (git-fixes bsc#1234356 CVE-2024-57838 bsc#1235798).
- Update
  patches.suse/s390-iucv-MSG_PEEK-causes-memory-leak-in-iucv_sock_destruct.patch
  (git-fixes bsc#1234351 CVE-2024-53210 bsc#1234971).
- Update
  patches.suse/s390-pci-Fix-potential-double-remove-of-hotplug-slot.patch
  (git-fixes bsc#1234354 CVE-2024-56699 bsc#1235490).
- Update
  patches.suse/sched-deadline-Fix-warning-in-migrate_enable-for-boosted-tasks.patch
  (bsc#1234634 (Scheduler functional and performance backports)
  CVE-2024-56583 bsc#1235118).
- Update patches.suse/sched-fair-Fix-NEXT_BUDDY.patch (bsc#1234634
  (Scheduler functional and performance backports) CVE-2024-49573
  bsc#1235743).
- Update patches.suse/sched-fix-warning-in-sched_setaffinity.patch
  (bsc#1234634 (Scheduler functional and performance backports)
  CVE-2024-41932 bsc#1235699).
- Update
  patches.suse/scsi-megaraid_sas-Fix-for-a-potential-deadlock.patch
  (jsc#PED-11259 CVE-2024-57807 bsc#1235761).
- Update
  patches.suse/scsi-qla2xxx-Fix-use-after-free-on-unload.patch
  (bsc#1235406 CVE-2024-56623 bsc#1235466).
- Update
  patches.suse/soc-imx8m-Probe-the-SoC-driver-as-platform-driver.patch
  (stable-fixes CVE-2024-56787 bsc#1235663).
- Update
  patches.suse/soc-qcom-geni-se-fix-array-underflow-in-geni_se_clk_.patch
  (git-fixes CVE-2024-53158 bsc#1234811).
- Update
  patches.suse/spi-mpc52xx-Add-cancel_work_sync-before-module-remov.patch
  (git-fixes CVE-2024-50051 bsc#1235739).
- Update
  patches.suse/sunrpc-clear-XPRT_SOCK_UPD_TIMEOUT-when-reset-transport.patch
  (git-fixes CVE-2024-56688 bsc#1235538).
- Update
  patches.suse/sunrpc-fix-one-UAF-issue-caused-by-sunrpc-kernel-tcp-socket.patch
  (git-fixes CVE-2024-53168 bsc#1234887).
- Update patches.suse/svcrdma-Address-an-integer-overflow.patch
  (git-fixes CVE-2024-53151 bsc#1234829).
- Update
  patches.suse/svcrdma-fix-miss-destroy-percpu_counter-in-svc_rdma_proc_init.patch
  (git-fixes CVE-2024-53215 bsc#1234962).
- Update
  patches.suse/thermal-testing-Initialize-some-variables-annoteded-.patch
  (git-fixes CVE-2024-56676 bsc#1235493).
- Update patches.suse/tipc-fix-NULL-deref-in-cleanup_bearer.patch
  (bsc#1235433 CVE-2024-56661 bsc#1234931).
- Update patches.suse/unicode-Fix-utf8_load-error-path.patch
  (git-fixes CVE-2024-53233 bsc#1235046).
- Update
  patches.suse/usb-dwc3-gadget-Fix-looping-of-queued-SG-entries.patch
  (git-fixes CVE-2024-56698 bsc#1235491).
- Update
  patches.suse/usb-gadget-u_serial-Fix-the-issue-that-gs_start_io-c.patch
  (git-fixes CVE-2024-56670 bsc#1235488).
- Update
  patches.suse/usb-musb-Fix-hardware-lockup-on-first-Rx-endpoint-re.patch
  (git-fixes CVE-2024-56687 bsc#1235537).
- Update
  patches.suse/usb-typec-fix-potential-array-underflow-in-ucsi_ccg_.patch
  (git-fixes CVE-2024-53203 bsc#1235001).
- Update
  patches.suse/usb-typec-ucsi-glink-fix-off-by-one-in-connector_sta.patch
  (git-fixes CVE-2024-53149 bsc#1234842).
- Update
  patches.suse/wifi-ath10k-avoid-NULL-pointer-error-during-sdio-rem.patch
  (stable-fixes CVE-2024-56599 bsc#1235138).
- Update
  patches.suse/wifi-ath12k-Skip-Rx-TID-cleanup-for-self-peer.patch
  (git-fixes CVE-2024-56543 bsc#1235065).
- Update
  patches.suse/wifi-ath12k-fix-atomic-calls-in-ath12k_mac_op_set_bi.patch
  (stable-fixes CVE-2024-56607 bsc#1235423).
- Update patches.suse/wifi-ath12k-fix-crash-when-unbinding.patch
  (git-fixes CVE-2024-53188 bsc#1234948).
- Update
  patches.suse/wifi-ath12k-fix-use-after-free-in-ath12k_dp_cc_clean.patch
  (git-fixes CVE-2024-56541 bsc#1235064).
- Update patches.suse/wifi-ath12k-fix-warning-when-unbinding.patch
  (git-fixes CVE-2024-53191 bsc#1234952).
- Update
  patches.suse/wifi-ath9k-add-range-check-for-conn_rsp_epid-in-htc_.patch
  (git-fixes CVE-2024-53156 bsc#1234846).
- Update
  patches.suse/wifi-brcmfmac-Fix-oops-due-to-NULL-pointer-dereferen.patch
  (stable-fixes CVE-2024-56593 bsc#1235252).
- Update
  patches.suse/wifi-cw1200-Fix-potential-NULL-dereference.patch
  (git-fixes CVE-2024-56536 bsc#1234911).
- Update
  patches.suse/wifi-mwifiex-Fix-memcpy-field-spanning-write-warning.patch
  (git-fixes CVE-2024-56539 bsc#1234963).
- Update
  patches.suse/wifi-nl80211-fix-NL80211_ATTR_MLO_LINK_ID-off-by-one.patch
  (git-fixes CVE-2024-56663 bsc#1235454).
- Update
  patches.suse/wifi-nl80211-fix-bounds-checker-error-in-nl80211_par.patch
  (git-fixes CVE-2024-53189 bsc#1234949).
- Update
  patches.suse/wifi-rtlwifi-Drastically-reduce-the-attempts-to-read.patch
  (stable-fixes CVE-2024-53190 bsc#1234950).
- Update
  patches.suse/wifi-rtw88-use-ieee80211_purge_tx_queue-to-purge-TX-.patch
  (stable-fixes CVE-2024-56609 bsc#1235389).
- Update
  patches.suse/wifi-rtw89-check-return-value-of-ieee80211_probereq_.patch
  (stable-fixes CVE-2024-48873 bsc#1235716).
- Update
  patches.suse/wifi-rtw89-coex-check-NULL-return-of-kmalloc-in-btc_.patch
  (git-fixes CVE-2024-56535 bsc#1235044).
- Update
  patches.suse/xfs-unlock-inodes-when-erroring-out-of-xfs_trans_alloc_dir.patch
  (git-fixes CVE-2024-55641 bsc#1235740).
- commit b21bae3
* Mon Jan 13 2025 mkoutny@suse.com
- padding for extending cgroup controllers (bsc#1207439).
- commit 7b2e72c
* Mon Jan 13 2025 mkoutny@suse.com
- padding for more cgroup controllers (jsc#PED-8461).
- commit 417e2c0
* Mon Jan 13 2025 mfranc@suse.cz
- KVM: s390: Reject KVM_SET_GSI_ROUTING on ucontrol VMs (git-fixes
  bsc#1235755).
- KVM: s390: Reject setting flic pfault attributes on ucontrol
  VMs (git-fixes bsc#1235756).
- KVM: s390: vsie: fix virtual/physical address in unpin_scb()
  (git-fixes bsc#1235757).
- commit 25f73de
* Mon Jan 13 2025 mfranc@suse.cz
- s390x config: IOMMU_DEFAULT_DMA_LAZY=y (bsc#1235646)
- commit 2199130
* Mon Jan 13 2025 oneukum@suse.com
- net: usb: qmi_wwan: add Telit FE910C04 compositions (git-fixes).
- commit a8a3e1b
* Mon Jan 13 2025 tiwai@suse.de
- misc: microchip: pci1xxxx: Resolve return code mismatch during
  GPIO set config (git-fixes).
- misc: microchip: pci1xxxx: Resolve kernel panic during GPIO
  IRQ handling (git-fixes).
- interconnect: icc-clk: check return values of devm_kasprintf()
  (git-fixes).
- interconnect: qcom: icc-rpm: Set the count member before
  accessing the flex array (git-fixes).
- iio: adc: ti-ads1119: fix sample size in scan struct for
  triggered buffer (git-fixes).
- iio: inkern: call iio_device_put() only on mapped devices
  (git-fixes).
- iio: adc: ad9467: Fix the "don't allow reading vref if not
  available" case (git-fixes).
- iio: adc: at91: call input_free_device() on allocated iio_dev
  (git-fixes).
- iio: adc: ad7173: fix using shared static info struct
  (git-fixes).
- iio: adc: ti-ads124s08: Use gpiod_set_value_cansleep()
  (git-fixes).
- iio: adc: ti-ads1119: fix information leak in triggered buffer
  (git-fixes).
- iio: pressure: zpa2326: fix information leak in triggered buffer
  (git-fixes).
- iio: adc: rockchip_saradc: fix information leak in triggered
  buffer (git-fixes).
- iio: imu: kmx61: fix information leak in triggered buffer
  (git-fixes).
- iio: light: vcnl4035: fix information leak in triggered buffer
  (git-fixes).
- iio: light: bh1745: fix information leak in triggered buffer
  (git-fixes).
- iio: adc: ti-ads8688: fix information leak in triggered buffer
  (git-fixes).
- iio: dummy: iio_simply_dummy_buffer: fix information leak in
  triggered buffer (git-fixes).
- iio: test: Fix GTS test config (git-fixes).
- iio: adc: ti-ads1298: Add NULL check in ads1298_init
  (git-fixes).
- iio: adc: stm32-dfsdm: handle label as an optional property
  (git-fixes).
- iio: adc: ad4695: fix buffered read, single sample timings
  (git-fixes).
- iio: imu: inv_icm42600: fix timestamps after suspend if sensor
  is on (git-fixes).
- iio: gyro: fxas21002c: Fix missing data update in trigger
  handler (git-fixes).
- iio: test : check null return of kunit_kmalloc in
  iio_rescale_test_scale (git-fixes).
- iio: adc: ad7124: Disable all channels at probe time
  (git-fixes).
- staging: iio: ad9832: Correct phase range check (git-fixes).
- staging: iio: ad9834: Correct phase range check (git-fixes).
- usb: typec: fix pm usage counter imbalance in
  ucsi_ccg_sync_control() (git-fixes).
- usb: gadget: midi2: Reverse-select at the right place
  (git-fixes).
- usb: gadget: f_fs: Remove WARN_ON in functionfs_bind
  (git-fixes).
- USB: core: Disable LPM only for non-suspended ports (git-fixes).
- usb: fix reference leak in usb_new_device() (git-fixes).
- usb: typec: tcpci: fix NULL pointer issue on shared irq case
  (git-fixes).
- usb: gadget: u_serial: Disable ep before setting port to null
  to fix the crash caused by port being null (git-fixes).
- usb: chipidea: ci_hdrc_imx: decrement device's refcount in
  .remove() and in the error path of .probe() (git-fixes).
- usb: gadget: configfs: Ignore trailing LF for user strings to
  cdev (git-fixes).
- USB: usblp: return error when setting unsupported protocol
  (git-fixes).
- usb: gadget: f_uac2: Fix incorrect setting of bNumEndpoints
  (git-fixes).
- usb: typec: tcpm/tcpci_maxim: fix error code in
  max_contaminant_read_resistance_kohm() (git-fixes).
- usb: host: xhci-plat: set skip_phy_initialization if software
  node has XHCI_SKIP_PHY_INIT property (git-fixes).
- usb: dwc3-am62: Disable autosuspend during remove (git-fixes).
- usb: dwc3: gadget: fix writing NYET threshold (git-fixes).
- commit 708e579
* Mon Jan 13 2025 jslaby@suse.cz
- serial: stm32: use port lock wrappers for break control
  (git-fixes).
- tty: serial: 8250: Fix another runtime PM usage counter
  underflow (git-fixes).
- commit 2e58518
* Sun Jan 12 2025 tiwai@suse.de
- hwmon: (drivetemp) Fix driver producing garbage data when SCSI
  errors occur (git-fixes).
- modpost: fix the missed iteration for the max bit in do_input()
  (git-fixes).
- commit 5559cd4
* Sun Jan 12 2025 jlee@suse.com
- Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch.
  Update config files.
  CONFIG_EFI_SECRET_KEY is not set
- commit f3e53e1
* Sun Jan 12 2025 jlee@suse.com
- Refresh
  patches.suse/0002-hibernate-avoid-the-data-in-hidden-area-to-be-snapsh.patch.
- commit 81704e7
* Sun Jan 12 2025 jlee@suse.com
- Refresh
  patches.suse/0001-security-create-hidden-area-to-keep-sensitive-data.patch.
  Update config files.
  CONFIG_HIDDEN_AREA is not set
- commit 53e4009
* Sun Jan 12 2025 jlee@suse.com
- Refresh
  patches.suse/acpi-Disable-APEI-error-injection-if-the-kernel-is-lockeddown.patch.
- commit 1526952
* Sat Jan 11 2025 tiwai@suse.de
- thermal: of: fix OF node leak in of_thermal_zone_find()
  (git-fixes).
- drm/mediatek: Add return value check when reading DPCD
  (git-fixes).
- drm/mediatek: mtk_dsi: Add registers to pdata to fix
  MT8186/MT8188 (git-fixes).
- drm/mediatek: Fix mode valid issue for dp (git-fixes).
- drm/mediatek: Fix YCbCr422 color format issue for DP
  (git-fixes).
- drm/mediatek: stop selecting foreign drivers (git-fixes).
- drm/mediatek: Add support for 180-degree rotation in the
  display driver (git-fixes).
- drm/mediatek: Only touch DISP_REG_OVL_PITCH_MSB if AFBC is
  supported (git-fixes).
- drm/mediatek: Move mtk_crtc_finish_page_flip() to ddp_cmdq_cb()
  (git-fixes).
- drm/mediatek: Set private->all_drm_private[i]->drm to NULL if
  mtk_drm_bind returns err (git-fixes).
- Revert "drm/mediatek: dsi: Correct calculation formula of PHY
  Timing" (git-fixes).
- drm/xe: Fix tlb invalidation when wedging (git-fixes).
- drm/amdgpu: Add a lock when accessing the buddy trim function
  (git-fixes).
- drm/amdkfd: fixed page fault when enable MES shader debugger
  (git-fixes).
- drm/amd/display: fix divide error in DM plane scale calcs
  (git-fixes).
- drm/amd/display: fix page fault due to max surface definition
  mismatch (git-fixes).
- drm/amd/display: Remove unnecessary amdgpu_irq_get/put
  (git-fixes).
- platform/x86: intel/pmc: Fix ioremap() of bad address
  (git-fixes).
- platform/x86/amd/pmc: Only disable IRQ1 wakeup where i8042
  actually enabled it (git-fixes).
- gpio: loongson: Fix Loongson-2K2000 ACPI GPIO register offset
  (git-fixes).
- gpio: virtuser: fix handling of multiple conn_ids in lookup
  table (git-fixes).
- gpio: virtuser: fix missing lookup table cleanups (git-fixes).
- commit 993f2e5
* Sat Jan 11 2025 jlee@suse.com
- kgdb: Check early kernel lockdown flag before using kgdb
  (bsc#1234646).
- commit 8566b22
* Sat Jan 11 2025 jlee@suse.com
- ACPI: Check early kernel lockdown flag before overlaying tables
  (bsc#1234646).
- commit f711c7c
* Sat Jan 11 2025 jlee@suse.com
- efi: Set early kernel lock down flag if booted in secure boot
  mode (bsc#1234646).
- commit 00a355d
* Sat Jan 11 2025 jlee@suse.com
- security: Add a kernel lockdown flag for early boot stage
  (bsc#1234646).
  Update config files.
  CONFIG_LOCK_DOWN_KERNEL_EARLY
- commit d7ebed1
* Sat Jan 11 2025 jlee@suse.com
- Lock down x86_64 kernel in secure boot mode in subsys_initcall
  stage (bsc#1234646).
- commit 206dec9
* Fri Jan 10 2025 lduncan@suse.com
- block, bfq: fix bfqq uaf in bfq_limit_depth() (CVE-2024-53166
  bsc#1234884).
- commit 2d6266b
* Fri Jan 10 2025 mhocko@suse.com
- bpf, sockmap: Fix race between element replace and close()
  (CVE-2024-56664 bsc#1235249).
- commit c6238ec
* Fri Jan 10 2025 rgoldwyn@suse.com
- Disable ceph (jsc#PED-7242)
- commit c5f8eec
* Fri Jan 10 2025 jlee@suse.com
- Refresh
  patches.suse/0001-security-lockdown-expose-a-hook-to-lock-the-kernel-down.patch.
- commit fe21847
* Fri Jan 10 2025 mhocko@suse.com
- tipc: fix NULL deref in cleanup_bearer() (bsc#1235433).
- commit e901a2d
* Fri Jan 10 2025 jack@suse.cz
- Enable CONFIG_LIST_HARDENED (jsc#PED-11842)
- commit a16f97b
* Fri Jan 10 2025 farosas@suse.de
- virtio_net: correct netdev_tx_reset_queue() invocation point
  (CVE-2024-56674 bsc#1235549).
- commit d01521b
* Fri Jan 10 2025 ykaukab@suse.de
- stackleak: disable stack erasing by default (jsc#PED-11837).
- commit 25d95db
* Fri Jan 10 2025 ykaukab@suse.de
- config: enable CONFIG_GCC_PLUGIN_STACKLEAK
  Keep it disabled via stack_erasing syscall to avoid overhead
- commit 8cf8a17
* Fri Jan 10 2025 vbabka@suse.cz
- Update config files. Enable CONFIG_RANDOM_KMALLOC_CACHES (jsc#PED-11846)
  except on zfcpdump, disable CONFIG_SLAB_BUCKETS on zfcpdump.
- commit 23291c7
* Fri Jan 10 2025 jlee@suse.com
- Reviewed
  patches.suse/s390-lock-down-kernel-in-secure-boot-mode.patch
- commit 75d9cc5
* Fri Jan 10 2025 jlee@suse.com
- Reviewed
  patches.suse/arm64-lock-down-kernel-in-secure-boot-mode.patch
- commit a397f81
* Fri Jan 10 2025 jlee@suse.com
- Refresh
  patches.suse/powerpc-lock-down-kernel-in-secure-boot-mode.patch.
- commit 6f37879
* Fri Jan 10 2025 jlee@suse.com
- Refresh
  patches.suse/0004-efi-Lock-down-the-kernel-at-the-integrity-level-if-b.patch.
- commit c848190
* Fri Jan 10 2025 jlee@suse.com
- Reviewed
  patches.suse/KEYS-Make-use-of-platform-keyring-for-module-signatu.patch
- commit 5b00a1a
* Fri Jan 10 2025 jlee@suse.com
- Refresh
  patches.suse/0003-efi-Lock-down-the-kernel-if-booted-in-secure-boot-mode.patch.
  Update config files.
  CONFIG_LOCK_DOWN_IN_EFI_SECURE_BOOT
- commit 509a86d
* Fri Jan 10 2025 jlee@suse.com
- Reviewed
  patches.suse/0002-efi-Add-an-EFI_SECURE_BOOT-flag-to-indicate-secure-boot-mode.patch
- commit 6ffabc3
* Fri Jan 10 2025 mhocko@suse.com
- scsi: sg: Fix slab-use-after-free read in sg_release()
  (CVE-2024-56631 bsc#1235480).
- commit 76de829
* Fri Jan 10 2025 jlee@suse.com
- Refresh
  patches.suse/0001-security-lockdown-expose-a-hook-to-lock-the-kernel-down.patch.
- commit 2157c81
* Fri Jan 10 2025 tiwai@suse.de
- Bluetooth: btmtk: Fix failed to send func ctrl for MediaTek
  devices (git-fixes).
- Bluetooth: btnxpuart: Fix driver sending truncated data
  (git-fixes).
- Bluetooth: MGMT: Fix Add Device to responding before completing
  (git-fixes).
- Bluetooth: hci_sync: Fix not setting Random Address when
  required (git-fixes).
- ieee802154: ca8210: Add missing check for kfifo_alloc() in
  ca8210_probe() (git-fixes).
- drm/amdkfd: Correct the migration DMA map direction
  (stable-fixes).
- drm/amdgpu: use sjt mec fw on gfx943 for sriov (stable-fixes).
- wifi: mac80211: wake the queues in case of failure in resume
  (stable-fixes).
- wifi: cfg80211: clear link ID from bitmap during link delete
  after clean up (stable-fixes).
- wifi: mac80211: fix mbss changed flags corruption on 32 bit
  systems (stable-fixes).
- Bluetooth: btmtk: Fix failed to send func ctrl for MediaTek
  devices (git-fixes).
- Bluetooth: btnxpuart: Fix driver sending truncated data
  (git-fixes).
- Bluetooth: MGMT: Fix Add Device to responding before completing
  (git-fixes).
- Bluetooth: hci_sync: Fix not setting Random Address when
  required (git-fixes).
- ieee802154: ca8210: Add missing check for kfifo_alloc() in
  ca8210_probe() (git-fixes).
- drm/amdkfd: Correct the migration DMA map direction
  (stable-fixes).
- drm/amdgpu: use sjt mec fw on gfx943 for sriov (stable-fixes).
- wifi: mac80211: wake the queues in case of failure in resume
  (stable-fixes).
- wifi: cfg80211: clear link ID from bitmap during link delete
  after clean up (stable-fixes).
- wifi: mac80211: fix mbss changed flags corruption on 32 bit
  systems (stable-fixes).
- commit d04ce72
* Fri Jan 10 2025 mhocko@suse.com
- 9p/xen: fix release of IRQ (CVE-2024-56704 bsc#1235584).
- commit bf1ccfc
* Fri Jan 10 2025 mhocko@suse.com
- net: ieee802154: do not leave a dangling sk pointer in
  ieee802154_create() (CVE-2024-56602 bsc#1235521).
- commit 8b46faa
* Fri Jan 10 2025 tiwai@suse.de
- udmabuf: fix memory leak on last export_udmabuf() error path
  (CVE-2024-56712 bsc#1235565).
- commit 3d88b1a
* Fri Jan 10 2025 jslaby@suse.cz
- x86/CPU/AMD: Terminate the erratum_1386_microcode array
  (CVE-2024-56721 bsc#1235566).
- commit 09a03bf
* Fri Jan 10 2025 mhocko@suse.com
- net: hsr: avoid potential out-of-bound access in
  fill_frame_info() (CVE-2024-56648 bsc#1235451).
- commit 333d1e7
* Thu Jan  9 2025 ggherdovich@suse.cz
- supported.conf: All modules related to the Intel TPMI are supported (jsc#PED-4901 jsc#PED-4961 jsc#PED-4647)
- commit 782043f
* Thu Jan  9 2025 ggherdovich@suse.cz
- Update
  patches.suse/cpufreq-amd-pstate-Default-to-powersave-governor-whe.patch
  (jsc#PED-11639).
- commit f371154
* Thu Jan  9 2025 ggherdovich@suse.cz
- cpufreq: intel_pstate: Update Balance-performance EPP for
  Granite Rapids (jsc#PED-11771).
- commit 907dba9
* Thu Jan  9 2025 ggherdovich@suse.cz
- intel_idle: add Granite Rapids Xeon D support (jsc#PED-10589).
- commit 3305026
* Thu Jan  9 2025 nmorey@suse.com
- af_packet: avoid erroring out after sock_init_data() in packet_create() (CVE-2024-56606 bsc#123541)
- commit 4c171b7
* Thu Jan  9 2025 dsterba@suse.com
- smb: client: fix NULL ptr deref in crypto_aead_setkey() (CVE-2024-53185 bsc#1234901)
- commit 16fd7dd
* Thu Jan  9 2025 dsterba@suse.com
- net: af_can: do not leave a dangling sk pointer in can_create() (CVE-2024-56603 bsc#1235415)
- commit 358efec
* Thu Jan  9 2025 ddiss@suse.de
- ovl: Filter invalid inodes with missing lookup function
  (bsc#1235035 CVE-2024-56570).
- commit 707d8d7
* Thu Jan  9 2025 dsterba@suse.com
- ceph: fix cred leak in ceph_mds_check_access() (CVE-2024-56563 bsc#1235107)
- commit 2378163
* Thu Jan  9 2025 jdelvare@suse.de
- Update
  patches.suse/comedi-Flush-partial-mappings-in-error-case.patch
  (git-fixes CVE-2024-53148 bsc#1234832).
  Add CVE reference.
- commit 04ca6f4
* Thu Jan  9 2025 mhocko@suse.com
- tipc: Fix use-after-free of kernel socket in cleanup_bearer()
  (CVE-2024-56642 bsc#1235433).
- commit 9a3730d
* Thu Jan  9 2025 henrique.carvalho@suse.com
- smb: client: fix use-after-free of signing key (CVE-2024-53179
  bsc#1234921).
- commit 2e9abfc
* Wed Jan  8 2025 jbohac@suse.cz
- powerpc/book3s64/hugetlb: Fix disabling hugetlb when fadump
  is active (bsc#1235108).
- commit 8c55a2a
* Wed Jan  8 2025 dwagner@suse.de
- nvmet-loop: avoid using mutex in IO hotpath (git-fixes).
- nvmet: Don't overflow subsysnqn (git-fixes).
- nvme-pci: 512 byte aligned dma pool segment quirk (git-fixes).
- nvme-rdma: unquiesce admin_q before destroy it (git-fixes).
- nvme-tcp: fix the memleak while create new ctrl failed
  (git-fixes).
- nvme-fabrics: handle zero MAXCMD without closing the connection
  (git-fixes).
- nvme: don't apply NVME_QUIRK_DEALLOCATE_ZEROES when DSM is
  not supported (git-fixes).
- nvmet-loop: avoid using mutex in IO hotpath (git-fixes).
- nvmet: Don't overflow subsysnqn (git-fixes).
- nvme-pci: 512 byte aligned dma pool segment quirk (git-fixes).
- nvme-rdma: unquiesce admin_q before destroy it (git-fixes).
- nvme-tcp: fix the memleak while create new ctrl failed
  (git-fixes).
- nvme-fabrics: handle zero MAXCMD without closing the connection
  (git-fixes).
- nvme: don't apply NVME_QUIRK_DEALLOCATE_ZEROES when DSM is
  not supported (git-fixes).
- commit 64d03b4
* Wed Jan  8 2025 pmladek@suse.com
- workqueue: Do not warn when cancelling WQ_MEM_RECLAIM work
  from !WQ_MEM_RECLAIM worker (bsc#1235416).
- commit d1a20d8
* Wed Jan  8 2025 dsterba@suse.com
- btrfs: fix use-after-free waiting for encoded read endios (bsc#1235128)
- commit faccece
* Wed Jan  8 2025 dwagner@suse.de
- scsi: lpfc: Copyright updates for 14.4.0.7 patches
  (bsc#1235409).
- scsi: lpfc: Update lpfc version to 14.4.0.7 (bsc#1235409).
- scsi: lpfc: Add support for large fw object application layer
  reads (bsc#1235409).
- scsi: lpfc: Update definition of firmware configuration mbox
  cmds (bsc#1235409).
- scsi: lpfc: Change lpfc_nodelist save_flags member into a
  bitmask (bsc#1235409).
- scsi: lpfc: Add handling for LS_RJT reason explanation
  authentication required (bsc#1235409).
- scsi: lpfc: Modify handling of ADISC based on ndlp state and
  RPI registration (bsc#1235409).
- scsi: lpfc: Delete NLP_TARGET_REMOVE flag due to obsolete usage
  (bsc#1235409).
- scsi: lpfc: Restrict the REG_FCFI MAM field to FCoE adapters
  only (bsc#1235409).
- scsi: lpfc: Redefine incorrect type in lpfc_create_device_data()
  (bsc#1235409).
- scsi: lpfc: Copyright updates for 14.4.0.7 patches
  (bsc#1235409).
- scsi: lpfc: Update lpfc version to 14.4.0.7 (bsc#1235409).
- scsi: lpfc: Add support for large fw object application layer
  reads (bsc#1235409).
- scsi: lpfc: Update definition of firmware configuration mbox
  cmds (bsc#1235409).
- scsi: lpfc: Change lpfc_nodelist save_flags member into a
  bitmask (bsc#1235409).
- scsi: lpfc: Add handling for LS_RJT reason explanation
  authentication required (bsc#1235409).
- scsi: lpfc: Modify handling of ADISC based on ndlp state and
  RPI registration (bsc#1235409).
- scsi: lpfc: Delete NLP_TARGET_REMOVE flag due to obsolete usage
  (bsc#1235409).
- scsi: lpfc: Restrict the REG_FCFI MAM field to FCoE adapters
  only (bsc#1235409).
- scsi: lpfc: Redefine incorrect type in lpfc_create_device_data()
  (bsc#1235409).
- commit a46e8c0
* Wed Jan  8 2025 dsterba@suse.com
- btrfs: fix use-after-free in btrfs_encoded_read_endio() (CVE-2024-56582 bsc#1235128)
- commit c77e8af
* Wed Jan  8 2025 jslaby@suse.cz
- PCI/TPH: Add TPH documentation (jsc#PED-11562).
- PCI/TPH: Add Steering Tag support (jsc#PED-11562).
- PCI: Add TLP Processing Hints (TPH) support (jsc#PED-11562).
- Update config files (CONFIG_PCIE_TPH=y).
- commit bd308e1
* Wed Jan  8 2025 dwagner@suse.de
- scsi: qla2xxx: Update version to 10.02.09.400-k (bsc#1235406).
- scsi: qla2xxx: Supported speed displayed incorrectly for VPorts
  (bsc#1235406).
- scsi: qla2xxx: Fix NVMe and NPIV connect issue (bsc#1235406).
- scsi: qla2xxx: Remove check req_sg_cnt should be equal to
  rsp_sg_cnt (bsc#1235406).
- scsi: qla2xxx: Fix use after free on unload (bsc#1235406).
- scsi: qla2xxx: Fix abort in bsg timeout (bsc#1235406).
- scsi: qla2xxx: Update version to 10.02.09.400-k (bsc#1235406).
- scsi: qla2xxx: Supported speed displayed incorrectly for VPorts
  (bsc#1235406).
- scsi: qla2xxx: Fix NVMe and NPIV connect issue (bsc#1235406).
- scsi: qla2xxx: Remove check req_sg_cnt should be equal to
  rsp_sg_cnt (bsc#1235406).
- scsi: qla2xxx: Fix use after free on unload (bsc#1235406).
- scsi: qla2xxx: Fix abort in bsg timeout (bsc#1235406).
- commit e644331
* Wed Jan  8 2025 jlee@suse.com
- vfio/pci: Properly hide first-in-list PCIe extended capability
  (bsc#1235004 CVE-2024-53214).
- commit 989377b
* Wed Jan  8 2025 ailiop@suse.com
- fs: fix is_mnt_ns_file() (git-fixes).
- commit f76cd98
* Wed Jan  8 2025 ailiop@suse.com
- erofs: use buffered I/O for file-backed mounts by default
  (git-fixes).
- commit 699c7cc
* Wed Jan  8 2025 ailiop@suse.com
- erofs: reference `struct erofs_device_info` for erofs_map_dev
  (git-fixes).
- commit c6ac991
* Wed Jan  8 2025 ailiop@suse.com
- erofs: use `struct erofs_device_info` for the primary device
  (git-fixes).
- commit 426336f
* Wed Jan  8 2025 ailiop@suse.com
- erofs: add erofs_sb_free() helper (git-fixes).
- commit 468b714
* Wed Jan  8 2025 ailiop@suse.com
- nfs: Fix oops in nfs_netfs_init_request() when copying to cache
  (git-fixes).
- commit d2c36d1
* Wed Jan  8 2025 ailiop@suse.com
- netfs: Fix is-caching check in read-retry (git-fixes).
- commit d3ca9e7
* Wed Jan  8 2025 ailiop@suse.com
- netfs: Fix the (non-)cancellation of copy when cache is
  temporarily disabled (git-fixes).
- commit b8f5973
* Wed Jan  8 2025 ailiop@suse.com
- netfs: Fix ceph copy to cache on write-begin (git-fixes).
- commit 4931632
* Wed Jan  8 2025 ailiop@suse.com
- netfs: Fix missing barriers by using clear_and_wake_up_bit()
  (git-fixes).
- commit 59b3732
* Wed Jan  8 2025 ailiop@suse.com
- netfs: Fix enomem handling in buffered reads (git-fixes).
- commit d3c3d24
* Wed Jan  8 2025 ailiop@suse.com
- exfat: fix the infinite loop in __exfat_free_cluster()
  (git-fixes).
- commit 32d6d4e
* Wed Jan  8 2025 ailiop@suse.com
- exfat: fix the new buffer was not zeroed before writing
  (git-fixes).
- commit faf023a
* Wed Jan  8 2025 ailiop@suse.com
- exfat: fix the infinite loop in exfat_readdir() (git-fixes).
- commit 5136005
* Wed Jan  8 2025 ailiop@suse.com
- dlm: fix possible lkb_resource null dereference (git-fixes).
- commit 490216a
* Tue Jan  7 2025 mbrugger@suse.com
- powerpc/pseries/vas: Add close() callback in vas_vm_ops struct
  (bsc#1234825).
- commit 2674760
* Tue Jan  7 2025 tbogendoerfer@suse.de
- ethtool: Fix access to uninitialized fields in set RXNFC command
  (git-fixes).
- net: Make napi_hash_lock irq safe (git-fixes).
- commit 9fa4e00
* Tue Jan  7 2025 tbogendoerfer@suse.de
- octeontx2-pf: RVU representor driver (jsc#PED-11317).
- Update config files.
- supported.conf: mark new OcteonTx2 submodule rvu_rep supported.
- commit c4b0aa9
* Tue Jan  7 2025 tbogendoerfer@suse.de
- testing: net-drv: add basic shaper test (jsc#PED-10419).
- Update config files.
- commit 04716f4
* Tue Jan  7 2025 tbogendoerfer@suse.de
- net: sfc: Correct key_len for efx_tc_ct_zone_ht_params
  (jsc#PED-11366).
- net/mlx5e: Keep netdev when leave switchdev for devlink set
  legacy only (jsc#PED-11331).
- net/mlx5e: Skip restore TC rules for vport rep without loaded
  flag (jsc#PED-11331).
- net/mlx5e: macsec: Maintain TX SA from encoding_sa
  (jsc#PED-11331).
- net/mlx5: DR, select MSIX vector 0 for completion queue creation
  (jsc#PED-11331).
- RDMA/mlx5: Enable multiplane mode only when it is supported
  (jsc#PED-11325).
- RDMA/bnxt_re: Fix error recovery sequence (jsc#PED-10682
  jsc#PED-11231).
- RDMA/bnxt_re: Fix the locking while accessing the QP table
  (jsc#PED-10682 jsc#PED-11231).
- RDMA/bnxt_re: Fix MSN table size for variable wqe mode
  (jsc#PED-10682 jsc#PED-11231).
- RDMA/bnxt_re: Add send queue size check for variable wqe
  (jsc#PED-10682 jsc#PED-11231).
- RDMA/bnxt_re: Disable use of reserved wqes (jsc#PED-10682
  jsc#PED-11231).
- RDMA/bnxt_re: Fix max_qp_wrs reported (jsc#PED-10682
  jsc#PED-11231).
- RDMA/bnxt_re: Fix reporting hw_ver in query_device
  (jsc#PED-10682 jsc#PED-11231).
- RDMA/bnxt_re: Fix to export port num to ib_query_qp
  (jsc#PED-10682 jsc#PED-11231).
- RDMA/bnxt_re: Fix setting mandatory attributes for modify_qp
  (jsc#PED-10682 jsc#PED-11231).
- RDMA/bnxt_re: Add check for path mtu in modify_qp (jsc#PED-10682
  jsc#PED-11231).
- RDMA/bnxt_re: Fix the check for 9060 condition (jsc#PED-10682
  jsc#PED-11231).
- RDMA/bnxt_re: Don't fail destroy QP and cleanup debugfs earlier
  (jsc#PED-10682 jsc#PED-11231).
- RDMA/bnxt_re: Avoid sending the modify QP workaround for latest
  adapters (jsc#PED-10682 jsc#PED-11231).
- RDMA/bnxt_re: Avoid initializing the software queue for user
  queues (jsc#PED-10682 jsc#PED-11231).
- RDMA/bnxt_re: Fix max SGEs for the Work Request (jsc#PED-10682
  jsc#PED-11231).
- RDMA/mlx5: Enforce same type port association for multiport RoCE
  (jsc#PED-11325).
- RDMA/bnxt_re: Remove always true dattr validity check
  (jsc#PED-10682 jsc#PED-11231).
- octeontx2-pf: fix error handling of devlink port in
  rvu_rep_create() (jsc#PED-11317).
- octeontx2-pf: fix netdev memory leak in rvu_rep_create()
  (jsc#PED-11317).
- idpf: trigger SW interrupt when exiting wb_on_itr mode
  (jsc#PED-10581).
- idpf: add support for SW triggered interrupts (jsc#PED-10581).
- qed: fix possible uninit pointer read in
  qed_mcp_nvm_info_populate() (jsc#PED-9648 jsc#PED-11293).
- chelsio/chtls: prevent potential integer overflow on 32bit
  (git-fixes).
- ionic: use ee->offset when returning sprom data (jsc#PED-11378).
- ionic: no double destroy workqueue (jsc#PED-11378).
- ionic: Fix netdev notifier unregister on failure
  (jsc#PED-11378).
- bnxt_en: Fix aggregation ID mask to prevent oops on 5760X chips
  (jsc#PED-10684 jsc#PED-11230).
- octeontx2-af: Fix installation of PF multicast rule
  (jsc#PED-11317).
- cxgb4: use port number to set mac addr (git-fixes).
- bnxt_en: Fix potential crash when dumping FW log coredump
  (jsc#PED-10684 jsc#PED-11230).
- bnxt_en: Fix GSO type for HW GRO packets on 5750X chips
  (jsc#PED-10684 jsc#PED-11230).
- net/mlx5: DR, prevent potential error pointer dereference
  (jsc#PED-11331).
- bpf, vsock: Invoke proto::close on close() (jsc#PED-11028).
- bpf, vsock: Fix poll() missing a queue (jsc#PED-11028).
- igb: Fix potential invalid memory access in igb_init_module()
  (jsc#PED-10426 jsc#PED-10425).
- ixgbe: Correct BASE-BX10 compliance code (jsc#PED-9647
  jsc#PED-9646).
- ixgbe: downgrade logging of unsupported VF API version to debug
  (jsc#PED-9647 jsc#PED-9646).
- ixgbevf: stop attempting IPSEC offload on Mailbox API 1.5
  (jsc#PED-9647 jsc#PED-9646).
- idpf: set completion tag for "empty" bufs associated with a
  packet (jsc#PED-10581).
- ice: Fix VLAN pruning in switchdev mode (jsc#PED-10419).
- ice: Fix NULL pointer dereference in switchdev (jsc#PED-10419).
- ice: fix PHY timestamp extraction for ETH56G (jsc#PED-10419).
- ice: fix PHY Clock Recovery availability check (jsc#PED-10419).
- net/mlx5e: Remove workaround to avoid syndrome for internal port
  (jsc#PED-11331).
- net/mlx5e: SD, Use correct mdev to build channel param
  (jsc#PED-11331).
- net/mlx5: E-Switch, Fix switching to switchdev mode in MPV
  (jsc#PED-11331).
- net/mlx5: E-Switch, Fix switching to switchdev mode with IB
  device disabled (jsc#PED-11331).
- net/mlx5: HWS: Properly set bwc queue locks lock classes
  (jsc#PED-11331).
- net/mlx5: HWS: Fix memory leak in mlx5hws_definer_calc_layout
  (jsc#PED-11331).
- bnxt_en: handle tpa_info in queue API implementation
  (jsc#PED-10684 jsc#PED-11230).
- bnxt_en: refactor bnxt_alloc_rx_rings() to call
  bnxt_alloc_rx_agg_bmap() (jsc#PED-10684 jsc#PED-11230).
- bnxt_en: refactor tpa_info alloc/free into helpers
  (jsc#PED-10684 jsc#PED-11230).
- net/qed: allow old cards not supporting "num_images" to work
  (jsc#PED-9648 jsc#PED-11293).
- octeontx2-af: Fix SDP MAC link credits configuration
  (jsc#PED-11317).
- bnxt_en: ethtool: Supply ntuple rss context action
  (jsc#PED-10684 jsc#PED-11230).
- bnxt_en: Unregister PTP during PCI shutdown and suspend
  (jsc#PED-10684 jsc#PED-11230).
- bnxt_en: Refactor bnxt_ptp_init() (jsc#PED-10684 jsc#PED-11230).
- bnxt_en: Fix receive ring space parameters when XDP is active
  (jsc#PED-10684 jsc#PED-11230 CVE-2024-53209 bsc#1235002).
- bnxt_en: Fix queue start to update vnic RSS table (jsc#PED-10684
  jsc#PED-11230).
- bnxt_en: Set backplane link modes correctly for ethtool
  (jsc#PED-10684 jsc#PED-11230).
- bnxt_en: Reserve rings after PCIe AER recovery if NIC interface
  is down (jsc#PED-10684 jsc#PED-11230).
- octeontx2-af: Quiesce traffic before NIX block reset
  (jsc#PED-11317).
- octeontx2-af: RPM: fix stale FCFEC counters (jsc#PED-11317).
- octeontx2-af: RPM: fix stale RSFEC counters (jsc#PED-11317).
- octeontx2-af: RPM: Fix low network performance (jsc#PED-11317).
- octeontx2-af: RPM: Fix mismatch in lmac type (jsc#PED-11317).
- vdpa/mlx5: Fix suboptimal range on iotlb iteration
  (jsc#PED-11331).
- RDMA/mlx5: Add implementation for ufile_hw_cleanup device
  operation (jsc#PED-11325).
- RDMA/mlx5: Ensure active slave attachment to the bond IB device
  (jsc#PED-11325).
- RDMA/mlx5: Call dev_put() after the blocking notifier
  (jsc#PED-11325).
- RDMA/mlx5: Support querying per-plane IB PortCounters
  (jsc#PED-11325).
- RDMA/mlx5: Support OOO RX WQE consumption (jsc#PED-11325).
- net/mlx5: Introduce data placement ordering bits
  (jsc#PED-11331).
- i40e: Fix handling changed priv flags (jsc#PED-10428).
- bnxt_en: Add FW trace coredump segments to the coredump
  (jsc#PED-10684 jsc#PED-11230).
- bnxt_en: Add a new ethtool -W dump flag (jsc#PED-10684
  jsc#PED-11230).
- bnxt_en: Add 2 parameters to bnxt_fill_coredump_seg_hdr()
  (jsc#PED-10684 jsc#PED-11230).
- bnxt_en: Add functions to copy host context memory
  (jsc#PED-10684 jsc#PED-11230).
- bnxt_en: Do not free FW log context memory (jsc#PED-10684
  jsc#PED-11230).
- bnxt_en: Manage the FW trace context memory (jsc#PED-10684
  jsc#PED-11230).
- bnxt_en: Allocate backing store memory for FW trace logs
  (jsc#PED-10684 jsc#PED-11230).
- bnxt_en: Add a 'force' parameter to bnxt_free_ctx_mem()
  (jsc#PED-10684 jsc#PED-11230).
- bnxt_en: Refactor bnxt_free_ctx_mem() (jsc#PED-10684
  jsc#PED-11230).
- bnxt_en: Add mem_valid bit to struct bnxt_ctx_mem_type
  (jsc#PED-10684 jsc#PED-11230).
- bnxt_en: Update firmware interface spec to 1.10.3.85
  (jsc#PED-10684 jsc#PED-11230).
- e1000: Hold RTNL when e1000_down can be called (jsc#PED-10422).
- igbvf: remove unused spinlock (jsc#PED-10426 jsc#PED-10425).
- igb: Fix 2 typos in comments in igb_main.c (jsc#PED-10426
  jsc#PED-10425).
- igc: remove autoneg parameter from igc_mac_info (jsc#PED-10417).
- ixgbe: Break include dependency cycle (jsc#PED-9647
  jsc#PED-9646).
- ice: Unbind the workqueue (jsc#PED-10419).
- ice: use stack variable for virtchnl_supported_rxdids
  (jsc#PED-10419).
- ice: initialize pf->supported_rxdids immediately after loading
  DDP (jsc#PED-10419).
- ice: only allow Tx promiscuous for multicast (jsc#PED-10419).
- ice: Add support for persistent NAPI config (jsc#PED-10419).
- ice: support optional flags in signature segment header
  (jsc#PED-10419).
- ice: refactor "last" segment of DDP pkg (jsc#PED-10419).
- ice: extend dump serdes equalizer values feature
  (jsc#PED-10419).
- ice: rework of dump serdes equalizer values feature
  (jsc#PED-10419).
- ndo_fdb_del: Add a parameter to report whether notification
  was sent (jsc#PED-10419).
- ndo_fdb_add: Add a parameter to report whether notification
  was sent (jsc#PED-10428).
- octeontx2-pf: Fix spelling mistake "reprentator" ->
  "representor" (jsc#PED-11317).
- bnxt_en: optimize gettimex64 (jsc#PED-10684 jsc#PED-11230).
- net: ethtool: only allow set_rxnfc with rss + ring_cookie if
  driver opts in (jsc#PED-11366).
- octeontx2-pf: Adds TC offload support (jsc#PED-11317).
- octeontx2-pf: Implement offload stats ndo for representors
  (jsc#PED-11317).
- octeontx2-pf: Add devlink port support (jsc#PED-11317).
- octeontx2-pf: Add representors for sdp MAC (jsc#PED-11317).
- octeontx2-pf: Configure VF mtu via representor (jsc#PED-11317).
- octeontx2-pf: Add support to sync link state between representor
  and VFs (jsc#PED-11317).
- octeontx2-pf: Get VF stats via representor (jsc#PED-11317).
- octeontx2-af: Add packet path between representor and VF
  (jsc#PED-11317).
- octeontx2-pf: Add basic net_device_ops (jsc#PED-11317).
- octeontx2-pf: Create representor netdev (jsc#PED-11317).
- eth: bnxt: use page pool for head frags (jsc#PED-10684
  jsc#PED-11230).
- net/mlx5e: SHAMPO, Rework header allocation loop
  (jsc#PED-11331).
- net/mlx5e: SHAMPO, Drop info array (jsc#PED-11331).
- net/mlx5e: SHAMPO, Change frag page setup order during
  allocation (jsc#PED-11331).
- net/mlx5e: SHAMPO, Fix page_index calculation inconsistency
  (jsc#PED-11331).
- net/mlx5e: SHAMPO, Simplify UMR allocation for headers
  (jsc#PED-11331).
- net/mlx5: Make vport QoS enablement more flexible for future
  extensions (jsc#PED-11331).
- net/mlx5: Integrate esw_qos_vport_enable logic into rate
  operations (jsc#PED-11331).
- net/mlx5: Generalize scheduling element operations
  (jsc#PED-11331).
- net/mlx5: Refactor scheduling element configuration bitmasks
  (jsc#PED-11331).
- net/mlx5: Generalize max_rate and min_rate setting for nodes
  (jsc#PED-11331).
- net/mlx5: Simplify QoS normalization by removing error handling
  (jsc#PED-11331).
- net/mlx5: E-switch, refactor eswitch mode change
  (jsc#PED-11331).
- bnxt_en: add unlocked version of bnxt_refclk_read (jsc#PED-10684
  jsc#PED-11230).
- net: atlantic: use irq_update_affinity_hint() (jsc#PED-11287).
- bnxt_en: use irq_update_affinity_hint() (jsc#PED-10684
  jsc#PED-11230).
- octeontx2-af: Knobs for NPC default rule counters
  (jsc#PED-11317).
- octeontx2-af: Refactor few NPC mcam APIs (jsc#PED-11317).
- mlx5/core: deduplicate {mlx5_,}eq_update_ci() (jsc#PED-11331).
- mlx5/core: relax memory barrier in eq_update_ci()
  (jsc#PED-11331).
- bridge: Allow deleting FDB entries with non-existent VLAN
  (jsc#PED-10419).
- mlx5/core: Schedule EQ comp tasklet only if necessary
  (jsc#PED-11331).
- net: sfc: use ethtool string helpers (jsc#PED-11366).
- net: bnx2x: use ethtool string helpers (jsc#PED-10901
  jsc#PED-11308).
- bnxt_en: ethtool: Support unset l4proto on ip4/ip6 ntuple rules
  (jsc#PED-10684 jsc#PED-11230).
- bnxt_en: ethtool: Remove ip4/ip6 ntuple support for IPPROTO_RAW
  (jsc#PED-10684 jsc#PED-11230).
- sfc: Remove more unused functions (jsc#PED-11366).
- sfc: Remove unused mcdi functions (jsc#PED-11366).
- sfc: Remove unused efx_mae_mport_vf (jsc#PED-11366).
- sfc: Remove falcon deadcode (jsc#PED-11366).
- bnxt_en: replace PTP spinlock with seqlock (jsc#PED-10684
  jsc#PED-11230).
- bnxt_en: cache only 24 bits of hw counter (jsc#PED-10684
  jsc#PED-11230).
- mlx5_en: use read sequence for gettimex64 (jsc#PED-11331).
- net/mlx5e: do not create xdp_redirect for non-uplink rep
  (jsc#PED-11331).
- net/mlx5e: move XDP_REDIRECT sq to dynamic allocation
  (jsc#PED-11331).
- net/mlx5: HWS, renamed the files in accordance with naming
  convention (jsc#PED-11331).
- net/mlx5: DR, moved all the SWS code into a separate directory
  (jsc#PED-11331).
- net/mlx5: Rework esw qos domain init and cleanup
  (jsc#PED-11331).
- dim: pass dim_sample to net_dim() by reference (jsc#PED-10581).
- dim: make dim_calc_stats() inputs const pointers
  (jsc#PED-11331).
- net: bnxt: use ethtool string helpers (jsc#PED-10684
  jsc#PED-11230).
- net/mlx5: DPLL, Add clock quality level op implementation
  (jsc#PED-11331).
- dpll: add clock quality level attribute and op (jsc#PED-11331).
- octeontx2-pf: Move shared APIs to header file (jsc#PED-11317).
- octeontx2-pf: Reuse PF max mtu value (jsc#PED-11317).
- octeontx2-pf: Add new APIs for queue memory alloc/free
  (jsc#PED-11317).
- octeontx2-pf: Define common API for HW resources configuration
  (jsc#PED-11317).
- net: qlogic: use ethtool string helpers (jsc#PED-9648
  jsc#PED-11293).
- net: marvell: use ethtool string helpers (jsc#PED-11317).
- mlx5: simplify EQ interrupt polling logic (jsc#PED-11331).
- mlx5: fix typo in "mlx5_cqwq_get_cqe_enahnced_comp"
  (jsc#PED-11331).
- ibmvnic: use ethtool string helpers (jsc#PED_10911
  jsc#PED-3606).
- net/mlx5e: Update features on ring size change (jsc#PED-11331).
- net/mlx5e: Update features on MTU change (jsc#PED-11331).
- vsock: do not leave dangling sk pointer in vsock_create()
  (jsc#PED-11028).
- net/mlx5: unique names for per device caches (jsc#PED-11331).
- net: atlantic: support reading SFP module info (jsc#PED-11287).
- octeontx2-pf: handle otx2_mbox_get_rsp errors in otx2_dcbnl.c
  (jsc#PED-11317).
- octeontx2-pf: handle otx2_mbox_get_rsp errors in otx2_dmac_flt.c
  (jsc#PED-11317).
- octeontx2-pf: handle otx2_mbox_get_rsp errors in cn10k.c
  (jsc#PED-11317).
- octeontx2-pf: handle otx2_mbox_get_rsp errors in otx2_flows.c
  (jsc#PED-11317).
- octeontx2-pf: handle otx2_mbox_get_rsp errors in otx2_ethtool.c
  (jsc#PED-11317).
- octeontx2-pf: handle otx2_mbox_get_rsp errors in otx2_common.c
  (jsc#PED-11317).
- virtchnl: fix m68k build (jsc#PED-10423).
- net/mlx5: fs, rename modify header struct member action
  (jsc#PED-11331).
- net/mlx5: fs, rename packet reformat struct member action
  (jsc#PED-11331).
- net/mlx5: Only create VEPA flow table when in VEPA mode
  (jsc#PED-11331).
- net/mlx5: Add sync reset drop mode support (jsc#PED-11331).
- net/mlx5: Generalize QoS operations for nodes and vports
  (jsc#PED-11331).
- net/mlx5: Simplify QoS scheduling element configuration
  (jsc#PED-11331).
- net/mlx5: Remove vport QoS enabled flag (jsc#PED-11331).
- net/mlx5: Refactor vport QoS to use scheduling node structure
  (jsc#PED-11331).
- net/mlx5: Refactor vport scheduling element creation function
  (jsc#PED-11331).
- net/mlx5: Introduce node struct and rename group terminology
  to node (jsc#PED-11331).
- net/mlx5: Rename vport QoS group reference to parent
  (jsc#PED-11331).
- net/mlx5: Restrict domain list insertion to root TSAR ancestors
  (jsc#PED-11331).
- net/mlx5: Add parent group support in rate group structure
  (jsc#PED-11331).
- net/mlx5: Introduce node type to rate group structure
  (jsc#PED-11331).
- net/mlx5: Refactor QoS group scheduling element creation
  (jsc#PED-11331).
- eth: Fix typo 'accelaration'. 'exprienced' and 'rewritting'
  (jsc#PED-3526 jsc#PED-11226).
- tg3: Increase buffer size for IRQ label (jsc#PED-3526
  jsc#PED-11226).
- mlx4: Add support for persistent NAPI config to RX CQs
  (jsc#PED-10418 jsc#PED11336).
- mlx5: Add support for persistent NAPI config (jsc#PED-11331).
- bnxt: Add support for persistent NAPI config (jsc#PED-10684
  jsc#PED-11230).
- net: napi: Add napi_config (jsc#PED-10419).
- net: napi: Make gro_flush_timeout per-NAPI (jsc#PED-10419).
- net: napi: Make napi_defer_hard_irqs per-NAPI (jsc#PED-10419).
- tg3: Address byte-order miss-matches (jsc#PED-3526
  jsc#PED-11226).
- tg3: Link queues to NAPIs (jsc#PED-3526 jsc#PED-11226).
- tg3: Link IRQs to NAPI instances (jsc#PED-3526 jsc#PED-11226).
- iavf: add support to exchange qos capabilities (jsc#PED-10423).
- iavf: Add net_shaper_ops support (jsc#PED-10423).
- ice: Support VF queue rate limit and quanta size configuration
  (jsc#PED-10419).
- virtchnl: support queue rate limit and quanta size configuration
  (jsc#PED-10419).
- net-shapers: implement cap validation in the core
  (jsc#PED-10419).
- net: shaper: implement introspection support (jsc#PED-10419).
- netlink: spec: add shaper introspection support (jsc#PED-10419).
- net-shapers: implement shaper cleanup on queue deletion
  (jsc#PED-10419).
- net-shapers: implement delete support for NODE scope shaper
  (jsc#PED-10419).
- net-shapers: implement NL group operation (jsc#PED-10419).
- net-shapers: implement NL set and delete operations
  (jsc#PED-10419).
- net-shapers: implement NL get operation (jsc#PED-10419).
- netlink: spec: add shaper YAML spec (jsc#PED-10419).
- genetlink: extend info user-storage to match NL cb ctx
  (jsc#PED-10419).
- net/mlx5: Add support check for TSAR types in QoS scheduling
  (jsc#PED-11331).
- net/mlx5: Unify QoS element type checks across NIC and E-Switch
  (jsc#PED-11331).
- net/mlx5: qos: Refactor locking to a qos domain mutex
  (jsc#PED-11331).
- net/mlx5: qos: Store rate groups in a qos domain
  (jsc#PED-11331).
- net/mlx5: qos: Rename rate group 'list' as 'parent_entry'
  (jsc#PED-11331).
- net/mlx5: qos: Add an explicit 'dev' to vport trace calls
  (jsc#PED-11331).
- net/mlx5: qos: Store the eswitch in a mlx5_esw_rate_group
  (jsc#PED-11331).
- net/mlx5: qos: Drop 'esw' param from vport qos functions
  (jsc#PED-11331).
- net/mlx5: qos: Always create group0 (jsc#PED-11331).
- net/mlx5: qos: Maintain rate group vport members in a list
  (jsc#PED-11331).
- net/mlx5: qos: Refactor and document bw_share calculation
  (jsc#PED-11331).
- net/mlx5: qos: Consistently name vport vars as 'vport'
  (jsc#PED-11331).
- net/mlx5: qos: Rename vport 'tsar' into 'sched_elem'
  (jsc#PED-11331).
- net/mlx5: qos: Flesh out element_attributes in mlx5_ifc.h
  (jsc#PED-11331).
- e1000: Link NAPI instances to queues and IRQs (jsc#PED-10422).
- e1000e: Link NAPI instances to queues and IRQs (jsc#PED-10420).
- e1000e: Remove duplicated writel() in e1000_configure_tx/rx()
  (jsc#PED-10420).
- igb: Cleanup unused declarations (jsc#PED-10426 jsc#PED-10425).
- iavf: Remove unused declarations (jsc#PED-10423).
- ice: Cleanup unused declarations (jsc#PED-10419).
- ice: Use common error handling code in two functions
  (jsc#PED-10419).
- ice: Make use of assign_bit() API (jsc#PED-10419).
- ice: store max_frame and rx_buf_len only in ice_rx_ring
  (jsc#PED-10419).
- ice: consistently use q_idx in ice_vc_cfg_qs_msg()
  (jsc#PED-10419).
- ice: add E830 HW VF mailbox message limit support
  (jsc#PED-10419).
- ice: Implement ethtool reset support (jsc#PED-10419).
- doc: net: Fix .rst rendering of net_cachelines pages
  (jsc#PED-10419).
- idpf: Don't hard code napi_struct size (jsc#PED-10581).
- vmxnet3: support higher link speeds from vmxnet3 v9
  (jsc#PED-11024).
- ipv4: remove fib_info_devhash (jsc#PED-10419).
- ipv4: remove fib_info_lock (jsc#PED-10419).
- ipv4: use rcu in ip_fib_check_default() (jsc#PED-10419).
- ipv4: remove fib_devindex_hashfn() (jsc#PED-10419).
- sfc: add per-queue RX bytes stats (jsc#PED-11366).
- sfc: implement per-queue TSO (hw_gso) stats (jsc#PED-11366).
- sfc: implement per-queue rx drop and overrun stats
  (jsc#PED-11366).
- sfc: account XDP TXes in netdev base stats (jsc#PED-11366).
- sfc: add n_rx_overlength to ethtool stats (jsc#PED-11366).
- sfc: implement basic per-queue stats (jsc#PED-11366).
- sfc: remove obsolete counters from struct efx_channel
  (jsc#PED-11366).
- net: add IFLA_MAX_PACING_OFFLOAD_HORIZON device attribute
  (jsc#PED-10419).
- ice: Drop auxbus use for PTP to finalize ice_adapter move
  (jsc#PED-10419).
- ice: Use ice_adapter for PTP shared data instead of auxdev
  (jsc#PED-10419).
- ice: Initial support for E825C hardware in ice_adapter
  (jsc#PED-10419).
- ice: Add ice_get_ctrl_ptp() wrapper to simplify the code
  (jsc#PED-10419).
- ice: Introduce ice_get_phy_model() wrapper (jsc#PED-10419).
- ice: Enable 1PPS out from CGU for E825C products
  (jsc#PED-10419).
- ice: Read SDP section from NVM for pin definitions
  (jsc#PED-10419).
- ice: Disable shared pin on E810 on setfunc (jsc#PED-10419).
- ice: Cache perout/extts requests and check flags
  (jsc#PED-10419).
- ice: Align E810T GPIO to other products (jsc#PED-10419).
- ice: Add SDPs support for E825C (jsc#PED-10419).
- ice: Implement ice_ptp_pin_desc (jsc#PED-10419).
- net/mlx5: hw counters: Remove mlx5_fc_create_ex (jsc#PED-11331).
- net/mlx5: hw counters: Don't maintain a counter count
  (jsc#PED-11331).
- net/mlx5: hw counters: Drop unneeded cacheline alignment
  (jsc#PED-11331).
- net/mlx5: hw counters: Replace IDR+lists with xarray
  (jsc#PED-11331).
- net/mlx5: hw counters: Use kvmalloc for bulk query buffer
  (jsc#PED-11331).
- net/mlx5: hw counters: Make fc_stats & fc_pool private
  (jsc#PED-11331).
- octeontx2-af: Change block parameter to const pointer in
  get_lf_str_list (jsc#PED-11317).
- qed: put cond_resched() in qed_dmae_operation_wait()
  (jsc#PED-9648 jsc#PED-11293).
- qed: allow the callee of qed_mcp_nvm_read() to sleep
  (jsc#PED-9648 jsc#PED-11293).
- qed: put cond_resched() in qed_grc_dump_ctx_data() (jsc#PED-9648
  jsc#PED-11293).
- qed: make 'ethtool -d' 10 times faster (jsc#PED-9648
  jsc#PED-11293).
- ibmvnic: Add stat for tx direct vs tx batched (jsc#PED_10911
  jsc#PED-3606).
- ipv4: avoid quadratic behavior in FIB insertion of common
  address (jsc#PED-10419).
- commit affc8ea
* Tue Jan  7 2025 tiwai@suse.de
- pmdomain: core: add dummy release function to genpd device
  (git-fixes).
- commit a551144
* Tue Jan  7 2025 tiwai@suse.de
- drm/amdgpu: rework resume handling for display (v2)
  (stable-fixes).
- commit b4013fc
* Tue Jan  7 2025 tiwai@suse.de
- dmaengine: loongson2-apb: Change GENMASK to GENMASK_ULL
  (git-fixes).
- commit 6fbbd7d
* Tue Jan  7 2025 tiwai@suse.de
- drm/xe: Move the coredump registration to the worker thread
  (git-fixes).
- commit 2b22b2b
* Tue Jan  7 2025 tiwai@suse.de
- drm/xe: Take PM ref in delayed snapshot capture worker
  (git-fixes).
- commit e6eb1c2
* Tue Jan  7 2025 tiwai@suse.de
- wifi: iwlwifi: be less noisy if the NIC is dead in S3
  (bsc#1012628).
- commit 636dbb8
* Tue Jan  7 2025 tiwai@suse.de
- ASoC: dt-bindings: realtek,rt5645: Fix CPVDD voltage comment
  (git-fixes).
- commit 08e9225
* Tue Jan  7 2025 tiwai@suse.de
- media: ipu6: use the IPU6 DMA mapping APIs to do mapping
  (stable-fixes).
- commit 43b4f15
* Tue Jan  7 2025 tiwai@suse.de
- drm/amd/display: Add option to retrieve detile buffer size
  (stable-fixes).
- commit acb618b
* Tue Jan  7 2025 tiwai@suse.de
- pinctrl: freescale: fix COMPILE_TEST error with PINCTRL_IMX_SCU
  (stable-fixes).
- commit e5efdb1
* Tue Jan  7 2025 tiwai@suse.de
- drm/xe/guc/ct: Flush g2h worker in case of g2h response timeout
  (stable-fixes).
- commit f607e51
* Tue Jan  7 2025 tiwai@suse.de
- pmdomain: imx: gpcv2: Adjust delay after power up handshake
  (git-fixes).
- commit ef0da9b
* Tue Jan  7 2025 tiwai@suse.de
- pmdomain: core: Fix error path in pm_genpd_init() when ida
  alloc fails (git-fixes).
- pmdomain: core: Add missing put_device() (git-fixes).
- commit cd9a63e
* Tue Jan  7 2025 tiwai@suse.de
- spmi: pmic-arb: fix return path in
  for_each_available_child_of_node() (git-fixes).
- commit 550e3b3
* Tue Jan  7 2025 tiwai@suse.de
- usb: xhci: Avoid queuing redundant Stop Endpoint commands
  (git-fixes).
- commit cabee38
* Tue Jan  7 2025 tiwai@suse.de
- MAINTAINERS: update location of media main tree (stable-fixes).
- commit 6ee41d4
* Tue Jan  7 2025 tiwai@suse.de
- net: rfkill: gpio: Add check for clk_enable() (git-fixes).
- commit 5bd30ef
* Tue Jan  7 2025 tiwai@suse.de
- drm: fsl-dcu: enable PIXCLK on LS1021A (git-fixes).
- commit 4a514d1
* Tue Jan  7 2025 tiwai@suse.de
- drm/vc4: Introduce generation number enum (stable-fixes).
- Refresh
  patches.suse/drm-vc4-Match-drm_dev_enter-and-exit-calls-in-vc4_hv-cf1c87d.patch.
- commit afddd1c
* Tue Jan  7 2025 tiwai@suse.de
- drm/vc4: Correct generation check in vc4_hvs_lut_load
  (git-fixes).
- commit ce18613
* Tue Jan  7 2025 tiwai@suse.de
- ASoC: dt-bindings: mt6359: Update generic node name and
  dmic-mode (git-fixes).
- commit d641daf
* Tue Jan  7 2025 tiwai@suse.de
- thermal/lib: Fix memory leak on error in thermal_genl_auto()
  (git-fixes).
- tools/lib/thermal: Make more generic the command encoding
  function (stable-fixes).
- commit d312e68
* Tue Jan  7 2025 mgorman@suse.de
- configs: Enable CONFIG_PAGE_POISONING (jsc#PED-11843)
  Page poisoning must still be enabled by kernel command line
  page_poison=on.
- commit 0bc6079
* Tue Jan  7 2025 jgross@suse.com
- x86/static-call: fix 32-bit build (git-fixes).
- commit 05b1f89
* Tue Jan  7 2025 ddiss@suse.de
- zram: fix NULL pointer in comp_algorithm_show() (bsc#1234974
  CVE-2024-53222).
- commit d85c3b1
* Mon Jan  6 2025 vbabka@suse.cz
- mm/slub: Avoid list corruption when removing a slab from the
  full list (CVE-2024-56566 bsc#1235033).
- commit ab1309f
* Mon Jan  6 2025 nik.borisov@suse.com
- x86/cacheinfo: Delete global num_cache_leaves (jsc#PED-10467).
- commit b0f961c
* Mon Jan  6 2025 nik.borisov@suse.com
- cacheinfo: Allocate memory during CPU hotplug if not done from the primary CPU (jsc#PED-10467).
- commit 948fe91
* Mon Jan  6 2025 neilb@suse.de
- nfsd: fix UAF when access ex_uuid or ex_stats (CVE-2024-53216
  bsc#1235003).
- SUNRPC: no need get cache ref when protected by rcu
  (CVE-2024-53216 bsc#1235003).
- nfsd: no need get cache ref when protected by rcu
  (CVE-2024-53216 bsc#1235003).
- SUNRPC: introduce cache_check_rcu to help check in rcu context
  (CVE-2024-53216 bsc#1235003).
- commit 1400ad6
* Mon Jan  6 2025 neilb@suse.de
- blacklist.conf:
- Delete
  patches.suse/nfsd-release-svc_expkey-svc_export-with-rcu_work.patch.
  This was reverted upstream.  There is a better fix.
- commit 3a96ba3
* Sat Jan  4 2025 tiwai@suse.de
- ALSA hda/realtek: Add quirk for Framework F111:000C
  (stable-fixes).
- ALSA: seq: oss: Fix races at processing SysEx messages
  (stable-fixes).
- commit c470d47
* Sat Jan  4 2025 tiwai@suse.de
- selftests: net: local_termination: require mausezahn
  (git-fixes).
- wifi: cw1200: Fix potential NULL dereference (git-fixes).
- wifi: iwlwifi: mvm: Fix __counted_by usage in
  cfg80211_wowlan_nd_* (git-fixes).
- wifi: iwlwifi: fix CRF name for Bz (git-fixes).
- net: phy: micrel: Dynamically control external clock of KSZ PHY
  (git-fixes).
- pinctrl: mcp23s08: Fix sleeping in atomic context due to regmap
  locking (git-fixes).
- ALSA: seq: Check UMP support for midi_version change
  (git-fixes).
- Revert "ALSA: ump: Don't enumeration invalid groups for legacy
  rawmidi" (stable-fixes).
- ALSA: hda/tas2781: Ignore SUBSYS_ID not found for tas2563
  projects (git-fixes).
- ALSA: usb-audio: US16x08: Initialize array before use
  (git-fixes).
- drm: adv7511: Drop dsi single lane support (git-fixes).
- drm: adv7511: Fix use-after-free in adv7533_attach_dsi()
  (git-fixes).
- drm/bridge: adv7511_audio: Update Audio InfoFrame properly
  (git-fixes).
- drm/i915/dg1: Fix power gate sequence (git-fixes).
- drm/i915/cx0_phy: Fix C10 pll programming sequence (git-fixes).
- drm/xe: Fix fault on fd close after unbind (git-fixes).
- drm/xe/pf: Use correct function to check LMEM provisioning
  (git-fixes).
- drm/xe: Wait for migration job before unmapping pages
  (git-fixes).
- drm/xe: Use non-interruptible wait when moving BO to system
  (git-fixes).
- drm/xe: Revert some changes that break a mesa debug tool
  (git-fixes).
- drm/dp_mst: Ensure mst_primary pointer is valid in
  drm_dp_mst_handle_up_req() (stable-fixes).
- commit 40c61fe
* Fri Jan  3 2025 rgoldwyn@suse.com
- virtiofs: use pages instead of pointer for kernel direct IO
  (CVE-2024-53219 bsc#1235010).
- netfs/fscache: Add a memory barrier for FSCACHE_VOLUME_CREATING
  (CVE-2024-56755 bsc#1234920).
- cachefiles: Fix NULL pointer dereference in object->file
  (CVE-2024-56549 bsc#1234912).
- commit 6497a18
* Fri Jan  3 2025 ptesarik@suse.com
- sysfs: Add /sys/kernel/realtime entry (bsc#1234370).
- commit 67c8a0e
* Fri Jan  3 2025 ptesarik@suse.com
- Revert "drm/i915: Depend on !PREEMPT_RT." (bsc#1234370).
- drm/i915/guc: Consider also RCU depth in busy loop
  (bsc#1234370).
- drm/i915: Drop the irqs_disabled() check (bsc#1234370).
- drm/i915/gt: Use spin_lock_irq() instead of local_irq_disable()
  + spin_lock() (bsc#1234370).
- drm/i915: Disable tracing points on PREEMPT_RT (bsc#1234370).
- drm/i915: Don't check for atomic context on PREEMPT_RT
  (bsc#1234370).
- drm/i915: Don't disable interrupts on PREEMPT_RT during atomic
  updates (bsc#1234370).
- drm/i915: Use preempt_disable/enable_rt() where recommended
  (bsc#1234370).
- commit d7bae3c
* Fri Jan  3 2025 ptesarik@suse.com
- preempt: Add a generic function to return the preemption string
  (bsc#1234370).
- commit 240e711
* Fri Jan  3 2025 ptesarik@suse.com
- serial: 8250: Revert "drop lockdep annotation from
  serial8250_clear_IER()" (bsc#1234370).
- serial: 8250: Switch to nbcon console (bsc#1234370).
- commit 6ed51c3
* Fri Jan  3 2025 ptesarik@suse.com
- Add SLERT-specific patches (bsc#1234370):
- patches.suse/rt-Add-documentation-describing-what-RT-kernel-config-changes-to-default.patch
- patches.suse/rt-Add-documentation-describing-what-kernel-debug-options-to-add-for-testing.patch
- patches.suse/rt-Add-helper-script-to-refresh-RT-configs-based-on-the-parent.patch
- commit a177908
* Fri Jan  3 2025 tiwai@suse.de
- Bluetooth: btusb: mediatek: add intf release flow when usb
  disconnect (stable-fixes).
- Refresh
  patches.suse/Bluetooth-btmtk-adjust-the-position-to-init-iso-data.patch.
- commit 53f7776
* Fri Jan  3 2025 tiwai@suse.de
- mmc: sdhci-msm: fix crypto key eviction (git-fixes).
- ACPI/IORT: Add PMCG platform information for HiSilicon HIP09A
  (stable-fixes).
- regmap: Use correct format specifier for logging range errors
  (stable-fixes).
- spi: omap2-mcspi: Fix the IS_ERR() bug for
  devm_clk_get_optional_enabled() (stable-fixes).
- spi: intel: Add Panther Lake SPI controller support
  (stable-fixes).
- watchdog: mediatek: Add support for MT6735 TOPRGU/WDT
  (stable-fixes).
- watchdog: rzg2l_wdt: Power on the watchdog domain in the
  restart handler (stable-fixes).
- watchdog: it87_wdt: add PWRGD enable quirk for Qotom QCML04
  (stable-fixes).
- platform/x86: asus-nb-wmi: Ignore unknown event 0xCF
  (stable-fixes).
- Bluetooth: btusb: mediatek: change the conditions for ISO
  interface (stable-fixes).
- Bluetooth: btusb: mediatek: add callback function in
  btusb_disconnect (stable-fixes).
- Bluetooth: btusb: mediatek: move Bluetooth power off command
  position (stable-fixes).
- commit ae01e54
* Thu Jan  2 2025 mfranc@suse.cz
- slab: Fix too strict alignment check in create_cache()
  (CVE-2024-56560 bsc#1234925).
- commit 13fdc6a
* Thu Jan  2 2025 mfranc@suse.cz
- EDAC/bluefield: Fix potential integer overflow (CVE-2024-53161
  bsc#1234856).
- commit 9d9eb76
* Thu Jan  2 2025 mfranc@suse.cz
- supported.conf: externally supported drivers/s390/crypto/pkey_* (jsc#PED-11872)
- commit 4f63bae
* Thu Jan  2 2025 mfranc@suse.cz
- s390/pci: Expose FIDPARM attribute in sysfs (jsc#PED-11868).
- commit 11fe795
* Tue Dec 31 2024 tiwai@suse.de
- ASoC: Intel: sof_sdw: Fix DMI match for Lenovo 21QA and 21QB
  (git-fixes).
- ASoC: Intel: sof_sdw: Fix DMI match for Lenovo 21Q6 and 21Q7
  (git-fixes).
- riscv: Fix wrong usage of __pa() on a fixmap address
  (git-fixes).
- commit 70097d1
* Tue Dec 31 2024 tiwai@suse.de
- stddef: make __struct_group() UAPI C++-friendly (git-fixes).
- thunderbolt: Improve redrive mode handling (git-fixes).
- thunderbolt: Don't display nvm_version unless upgrade supported
  (git-fixes).
- thunderbolt: Add support for Intel Panther Lake-M/P
  (stable-fixes).
- xhci: Turn NEC specific quirk for handling Stop Endpoint errors
  generic (stable-fixes).
- USB: serial: option: add Telit FE910C04 rmnet compositions
  (stable-fixes).
- USB: serial: option: add MediaTek T7XX compositions
  (stable-fixes).
- USB: serial: option: add Netprisma LCUK54 modules for WWAN Ready
  (stable-fixes).
- USB: serial: option: add MeiG Smart SLM770A (stable-fixes).
- USB: serial: option: add TCL IK512 MBIM & ECM (stable-fixes).
- usb: typec: ucsi: Fix completion notifications (git-fixes).
- usb: dwc2: Fix HCD port connection race (git-fixes).
- usb: dwc2: hcd: Fix GetPortStatus & SetPortFeature (git-fixes).
- usb: dwc2: Fix HCD resume (git-fixes).
- usb: gadget: u_serial: Fix the issue that gs_start_io crashed
  due to accessing null pointer (git-fixes).
- usb: misc: onboard_usb_dev: skip suspend/resume sequence for
  USB5744 SMBus support (git-fixes).
- usb: dwc3: xilinx: make sure pipe clock is deselected in usb2
  only mode (git-fixes).
- usb: core: hcd: only check primary hcd skip_phy_initialization
  (git-fixes).
- usb: gadget: midi2: Fix interpretation of is_midi1 bits
  (git-fixes).
- usb: dwc3: imx8mp: fix software node kernel dump (git-fixes).
- usb: typec: anx7411: fix OF node reference leaks in
  anx7411_typec_switch_probe() (git-fixes).
- usb: typec: anx7411: fix fwnode_handle reference leak
  (git-fixes).
- usb: host: max3421-hcd: Correctly abort a USB request
  (git-fixes).
- usb: ehci-hcd: fix call balance of clocks handling routines
  (git-fixes).
- spi: rockchip: Fix PM runtime count on no-op cs (git-fixes).
- spi: aspeed: Fix an error handling path in
  aspeed_spi_[read|write]_user() (git-fixes).
- Revert "unicode: Don't special case ignorable code points"
  (stable-fixes).
- usb: typec: ucsi: glink: be more precise on orientation-aware
  ports (stable-fixes).
- usb: typec: ucsi: Do not call ACPI _DSM method for UCSI read
  operations (stable-fixes).
- usb: chipidea: udc: handle USB Error Interrupt if IOC not set
  (stable-fixes).
- usb: chipidea: udc: create bounce buffer for problem sglist
  entries if possible (stable-fixes).
- usb: chipidea: udc: limit usb request length to max 16KB
  (stable-fixes).
- usb: chipidea: add CI_HDRC_HAS_SHORT_PKT_LIMIT flag
  (stable-fixes).
- thermal/drivers/qcom/tsens-v1: Add support for MSM8937 tsens
  (stable-fixes).
- wifi: brcmfmac: Fix oops due to NULL pointer dereference in
  brcmf_sdiod_sglist_rw() (stable-fixes).
- wifi: ipw2x00: libipw_rx_any(): fix bad alignment
  (stable-fixes).
- wifi: ath5k: add PCI ID for Arcadyan devices (stable-fixes).
- wifi: ath5k: add PCI ID for SX76X (stable-fixes).
- wifi: ath10k: avoid NULL pointer error during sdio remove
  (stable-fixes).
- wifi: ath12k: fix atomic calls in
  ath12k_mac_op_set_bitrate_mask() (stable-fixes).
- wifi: rtw89: check return value of ieee80211_probereq_get()
  for RNR (stable-fixes).
- wifi: rtw88: use ieee80211_purge_tx_queue() to purge TX skb
  (stable-fixes).
- spi: spi-fsl-lpspi: Adjust type of scldiv (stable-fixes).
- commit e030fc8
* Tue Dec 31 2024 tiwai@suse.de
- power: supply: bq24190: Fix BQ24296 Vbus regulator support
  (git-fixes).
- power: supply: cros_charge-control: hide start threshold on
  v2 cmd (git-fixes).
- power: supply: cros_charge-control: allow start_threshold ==
  end_threshold (git-fixes).
- power: supply: cros_charge-control: add mutex for driver data
  (git-fixes).
- power: supply: gpio-charger: Fix set charge current limits
  (git-fixes).
- selftests/memfd: run sysctl tests when PID namespace support
  is enabled (git-fixes).
- selftests: openvswitch: fix tcpdump execution (git-fixes).
- regulator: axp20x: AXP717: set ramp_delay (git-fixes).
- kselftest/arm64: abi: fix SVCR detection (git-fixes).
- selftests: netfilter: Stabilize rpath.sh (git-fixes).
- selftests: mlxsw: sharedbuffer: Ensure no extra packets are
  counted (git-fixes).
- selftests: mlxsw: sharedbuffer: Remove duplicate test cases
  (git-fixes).
- selftests: mlxsw: sharedbuffer: Remove h1 ingress test case
  (git-fixes).
- selftests/ftrace: adjust offset for kprobe syntax error test
  (git-fixes).
- selftests/damon: add _damon_sysfs.py to TEST_FILES (git-fixes).
- selftest: hugetlb_dio: fix test naming (git-fixes).
- selftests: hid: fix typo and exit code (git-fixes).
- setlocalversion: work around "git describe" performance
  (stable-fixes).
- rtc: cmos: avoid taking rtc_lock for extended period of time
  (stable-fixes).
- serial: 8250_dw: Add Sophgo SG2044 quirk (stable-fixes).
- selftests: rds: move test.py to TEST_FILES (git-fixes).
- regulator: qcom-rpmh: Update ranges for FTSMPS525
  (stable-fixes).
- selftests/mount_setattr: Fix failures on 64K PAGE_SIZE kernels
  (git-fixes).
- remoteproc: qcom: pas: enable SAR2130P audio DSP support
  (stable-fixes).
- selftests/damon/debugfs_duplicate_context_creation: hide errors
  from expected file write failures (git-fixes).
- selftests/damon/_debugfs_common: hide expected error message
  from test_write_result() (git-fixes).
- selftests/damon/huge_count_read_write: remove unnecessary
  debugging message (git-fixes).
- selftests/damon/huge_count_read_write: provide sufficiently
  large buffer for DEPRECATED file read (git-fixes).
- selftests: netfilter: Fix missing return values in
  conntrack_dump_flush (git-fixes).
- selftests: net: really check for bg process completion
  (git-fixes).
- soc: imx8m: Probe the SoC driver as platform driver
  (stable-fixes).
- soc: qcom: pd-mapper: Add QCM6490 PD maps (stable-fixes).
- soc: qcom: llcc: Use designated initializers for LLC settings
  (stable-fixes).
- regmap: maple: Provide lockdep (sub)class for maple tree's
  internal lock (stable-fixes).
- selftests/resctrl: Protect against array overflow when reading
  strings (stable-fixes).
- selftests/resctrl: Protect against array overrun during iMC
  config parsing (git-fixes).
- selftests/resctrl: Fix memory overflow due to unhandled
  wraparound (git-fixes).
- selftests/resctrl: Print accurate buffer size as part of MBM
  results (git-fixes).
- selftests/mm: Fix unused function warning for
  aarch64_write_signal_pkey() (git-fixes).
- kselftest/arm64: Don't leak pipe fds in pac.exec_sign_all()
  (stable-fixes).
- kselftest/arm64: Fix encoding for SVE B16B16 test (git-fixes).
- kselftest/arm64: Log fp-stress child startup errors to stdout
  (stable-fixes).
- kselftest/arm64: mte: fix printf type warnings about longs
  (git-fixes).
- kselftest/arm64: mte: fix printf type warnings about __u64
  (git-fixes).
- kselftest/arm64: hwcap: fix f8dp2 cpuinfo name (git-fixes).
- kselftest/arm64: signal: drop now redundant GNU_SOURCE
  definition (git-fixes).
- commit 5e98b23
* Tue Dec 31 2024 tiwai@suse.de
- platform/x86: mlx-platform: call pci_dev_put() to balance the
  refcount (git-fixes).
- PCI/MSI: Handle lack of irqdomain gracefully (git-fixes).
- phy: core: Fix an OF node refcount leakage in
  of_phy_provider_lookup() (git-fixes).
- phy: core: Fix an OF node refcount leakage in _of_phy_get()
  (git-fixes).
- phy: core: Fix that API devm_phy_destroy() fails to destroy
  the phy (git-fixes).
- phy: core: Fix that API devm_of_phy_provider_unregister()
  fails to unregister the phy provider (git-fixes).
- phy: core: Fix that API devm_phy_put() fails to release the phy
  (git-fixes).
- phy: rockchip: samsung-hdptx: Set drvdata before enabling
  runtime PM (git-fixes).
- phy: qcom-qmp: Fix register name in RX Lane config of SC8280XP
  (git-fixes).
- phy: rockchip: naneng-combphy: fix phy reset (git-fixes).
- phy: usb: Toggle the PHY power during init (git-fixes).
- platform/chrome: cros_ec_lpc: fix product identity for early
  Framework Laptops (git-fixes).
- mtd: rawnand: arasan: Fix missing de-registration of NAND
  (git-fixes).
- mtd: rawnand: arasan: Fix double assertion of chip-select
  (git-fixes).
- mtd: diskonchip: Cast an operand to prevent potential overflow
  (git-fixes).
- mtd: rawnand: fix double free in atmel_pmecc_create_user()
  (git-fixes).
- of/irq: Fix using uninitialized variable @addr_len in API
  of_irq_parse_one() (git-fixes).
- of/irq: Fix interrupt-map cell length check in
  of_irq_parse_imap_parent() (git-fixes).
- of: Fix refcount leakage for OF node returned by
  __of_get_dma_parent() (git-fixes).
- of: Fix error path in of_parse_phandle_with_args_map()
  (git-fixes).
- of: address: Preserve the flags portion on 1:1 dma-ranges
  mapping (git-fixes).
- of: property: fw_devlink: Do not use interrupt-parent directly
  (git-fixes).
- objtool/x86: allow syscall instruction (stable-fixes).
- p2sb: Do not scan and remove the P2SB device when it is unhidden
  (git-fixes).
- p2sb: Move P2SB hide and unhide code to p2sb_scan_and_cache()
  (stable-fixes).
- p2sb: Introduce the global flag p2sb_hidden_by_bios
  (stable-fixes).
- p2sb: Factor out p2sb_read_from_cache() (stable-fixes).
- PCI: vmd: Add DID 8086:B06F and 8086:B60B for Intel client SKUs
  (stable-fixes).
- PCI: qcom: Add support for IPQ9574 (stable-fixes).
- PCI: Add ACS quirk for Wangxun FF5xxx NICs (stable-fixes).
- PCI: Detect and trust built-in Thunderbolt chips (stable-fixes).
- PCI: Add 'reset_subordinate' to reset hierarchy below bridge
  (stable-fixes).
- PCI: starfive: Enable controller runtime PM before probing
  host bridge (stable-fixes).
- PCI: vmd: Set devices to D0 before enabling PM L1 Substates
  (stable-fixes).
- pinctrl: qcom: spmi-mpp: Add PM8937 compatible (stable-fixes).
- pinctrl: qcom-pmic-gpio: add support for PM8937 (stable-fixes).
- pinmux: Use sequential access to access desc->pinmux data
  (stable-fixes).
- of: Allow overlay kunit tests to run CONFIG_OF_OVERLAY=n
  (git-fixes).
- of/fdt: add dt_phys arg to early_init_dt_scan and
  early_init_dt_verify (git-fixes).
- commit 52557e8
* Tue Dec 31 2024 tiwai@suse.de
- media: dvb-frontends: dib3000mb: fix uninit-value in
  dib3000_write_reg (git-fixes).
- mmc: mtk-sd: disable wakeup in .remove() and in the error path
  of .probe() (git-fixes).
- mmc: sdhci-tegra: Remove SDHCI_QUIRK_BROKEN_ADMA_ZEROLEN_DESC
  quirk (git-fixes).
- modpost: Add .irqentry.text to OTHER_SECTIONS (stable-fixes).
- mmc: sdhci-pci: Add DMI quirk for missing CD GPIO on Vexia
  Edu Atla 10 tablet (stable-fixes).
- misc: eeprom: eeprom_93cx6: Add quirk for extra read clock cycle
  (stable-fixes).
- media: cx231xx: Add support for Dexatek USB Video Grabber
  1d19:6108 (stable-fixes).
- media: uvcvideo: Force UVC version to 1.0a for 0408:4033
  (stable-fixes).
- media: uvcvideo: Add a quirk for the Kaiweets KTI-W02 infrared
  camera (stable-fixes).
- media: uvcvideo: RealSense D421 Depth module metadata
  (stable-fixes).
- mmc: mtk-sd: Fix MMC_CAP2_CRYPTO flag setting (git-fixes).
- mmc: mtk-sd: Fix error handle of probe function (git-fixes).
- mmc: core: Use GFP_NOIO in ACMD22 (git-fixes).
- mmc: mtk-sd: fix devm_clk_get_optional usage (stable-fixes).
- mmc: mtk-sd: use devm_mmc_alloc_host (stable-fixes).
- mmc: core: Adjust ACMD22 to SDUC (stable-fixes).
- mmc: sd: SDUC Support Recognition (stable-fixes).
- mmc: sdhci-esdhc-imx: enable quirks SDHCI_QUIRK_NO_LED
  (stable-fixes).
- mmc: core: Add SD card quirk for broken poweroff notification
  (stable-fixes).
- commit ba13df0
* Tue Dec 31 2024 tiwai@suse.de
- Update config files: CONFIG_HISILICON_ERRATUM_162100801=y
- commit ff7aefc
* Tue Dec 31 2024 tiwai@suse.de
- linux/dmaengine.h: fix a few kernel-doc warnings (git-fixes).
- irqchip/gic-v3: Work around insecure GIC integrations
  (git-fixes).
- lib: stackinit: hide never-taken branch from compiler
  (stable-fixes).
- irqchip/gicv3-its: Add workaround for hip09 ITS erratum
  162100801 (stable-fixes).
- iio: light: ltr501: Add LTER0303 to the supported devices
  (stable-fixes).
- iio: adc: ad7192: properly check spi_get_device_match_data()
  (stable-fixes).
- mailbox: pcc: Check before sending MCTP PCC response ACK
  (stable-fixes).
- leds: class: Protect brightness_show() with led_cdev->led_access
  mutex (stable-fixes).
- kcsan: Turn report_filterlist_lock into a raw_spinlock
  (stable-fixes).
- commit d2834e2
* Tue Dec 31 2024 tiwai@suse.de
- i2c: microchip-core: fix "ghost" detections (git-fixes).
- i2c: microchip-core: actually use repeated sends (git-fixes).
- i2c: imx: add imx7d compatible string for applying erratum
  ERR007805 (git-fixes).
- hwmon: (tmp513) Fix interpretation of values of Temperature
  Result and Limit Registers (git-fixes).
- hwmon: (tmp513) Fix Current Register value interpretation
  (git-fixes).
- hwmon: (tmp513) Fix interpretation of values of Shunt Voltage
  and Limit Registers (git-fixes).
- i915/guc: Accumulate active runtime on gt reset (git-fixes).
- i915/guc: Ensure busyness counter increases motonically
  (git-fixes).
- i915/guc: Reset engine utilization buffer before registration
  (git-fixes).
- i2c: riic: Always round-up when calculating bus period
  (git-fixes).
- i2c: pnx: Fix timeout in wait functions (git-fixes).
- gpio: graniterapids: Fix GPIO Ack functionality (stable-fixes).
- gpio: graniterapids: Check if GPIO line can be used for IRQs
  (stable-fixes).
- gpio: graniterapids: Determine if GPIO pad can be used by driver
  (stable-fixes).
- gpio: graniterapids: Fix invalid RXEVCFG register bitmask
  (stable-fixes).
- gpio: graniterapids: Fix invalid GPI_IS register offset
  (stable-fixes).
- gpio: graniterapids: Fix incorrect BAR assignment
  (stable-fixes).
- gpio: graniterapids: Fix vGPIO driver crash (stable-fixes).
- gpio: ljca: Initialize num before accessing item in
  ljca_gpio_config (git-fixes).
- i3c: Use i3cdev->desc->info instead of calling
  i3c_device_get_info() to avoid deadlock (stable-fixes).
- i3c: mipi-i3c-hci: Mask ring interrupts before ring stop request
  (stable-fixes).
- i3c: master: Fix dynamic address leak when 'assigned-address'
  is present (git-fixes).
- i3c: master: Extend address status bit to 4 and add
  I3C_ADDR_SLOT_EXT_DESIRED (stable-fixes).
- i3c: master: Replace hard code 2 with macro
  I3C_ADDR_SLOT_STATUS_BITS (stable-fixes).
- i2c: i801: Add support for Intel Panther Lake (stable-fixes).
- HID: add per device quirk to force bind to hid-generic
  (stable-fixes).
- HID: magicmouse: Apple Magic Trackpad 2 USB-C driver support
  (stable-fixes).
- gpio: grgpio: Add NULL check in grgpio_probe (git-fixes).
- iio: magnetometer: fix if () scoped_guard() formatting
  (git-fixes).
- hwmon: (nct6775) Add 665-ACE/600M-CL to ASUS WMI monitoring list
  (stable-fixes).
- commit 0ebc937
* Tue Dec 31 2024 tiwai@suse.de
- drm/amdgpu/nbio7.0: fix IP version check (stable-fixes).
- drm/amd: Update strapping for NBIO 2.5.0 (stable-fixes).
- drm/amdgpu: Handle NULL bo->tbo.resource (again) in
  amdgpu_vm_bo_update (git-fixes).
- drm/amdgpu: fix amdgpu_coredump (stable-fixes).
- drm/amdgpu/smu14.0.2: fix IP version check (stable-fixes).
- drm/amdgpu/gfx12: fix IP version check (stable-fixes).
- drm/amdgpu/mmhub4.1: fix IP version check (stable-fixes).
- drm/amdgpu/nbio7.11: fix IP version check (stable-fixes).
- drm/amdgpu/nbio7.7: fix IP version check (stable-fixes).
- drm/amdgpu: don't access invalid sched (git-fixes).
- drm/modes: Avoid divide by zero harder in drm_mode_vrefresh()
  (stable-fixes).
- drm/display: use ERR_PTR on DP tunnel manager creation fail
  (git-fixes).
- drm/panel: synaptics-r63353: Fix regulator unbalance
  (git-fixes).
- drm/panel: st7701: Add prepare_prev_first flag to drm_panel
  (git-fixes).
- drm/panel: novatek-nt35950: fix return value check in
  nt35950_probe() (git-fixes).
- drm/panel: himax-hx83102: Add a check to prevent NULL pointer
  dereference (git-fixes).
- firmware: arm_ffa: Fix the race around setting
  ffa_dev->properties (git-fixes).
- drm/panic: remove spurious empty line to clean warning
  (git-fixes).
- drm/amdkfd: pause autosuspend when creating pdd (stable-fixes).
- drm/amdgpu: fix when the cleaner shader is emitted (git-fixes).
- drm/amdkfd: hard-code MALL cacheline size for gfx11, gfx12
  (stable-fixes).
- drm/amdkfd: hard-code cacheline size for gfx11 (stable-fixes).
- drm/amdkfd: Dereference null return value (git-fixes).
- drm/amd/pm: Set SMU v13.0.7 default workload type
  (stable-fixes).
- drm/amdgpu: fix UVD contiguous CS mapping problem
  (stable-fixes).
- drm/xe/reg_sr: Remove register pool (git-fixes).
- drm/xe: Call invalidation_fence_fini for PT inval fences in
  error state (git-fixes).
- drm/xe: fix the ERR_PTR() returned on failure to allocate tiny
  pt (git-fixes).
- drm/i915: Fix memory leak by correcting cache object name in
  error handler (git-fixes).
- drm/i915: Fix NULL pointer dereference in capture_engine
  (git-fixes).
- drm/i915/color: Stop using non-posted DSB writes for legacy LUT
  (git-fixes).
- drm/amd/pm: fix and simplify workload handling (stable-fixes).
- drm/amd/display: Limit VTotal range to max hw cap minus fp
  (stable-fixes).
- drm/amd/display: Correct prefetch calculation (stable-fixes).
- drm/amd/display: Add a left edge pixel if in YCbCr422 or
  YCbCr420 and odm (stable-fixes).
- drm/amdkfd: hard-code cacheline for gc943,gc944 (stable-fixes).
- drm/amdkfd: add MEC version that supports no PCIe atomics for
  GFX12 (stable-fixes).
- drm/amdgpu/hdp7.0: do a posting read when flushing HDP
  (stable-fixes).
- drm/amdgpu/hdp6.0: do a posting read when flushing HDP
  (stable-fixes).
- drm/amdgpu/hdp5.2: do a posting read when flushing HDP
  (stable-fixes).
- drm/amdgpu/hdp5.0: do a posting read when flushing HDP
  (stable-fixes).
- drm/amdgpu/hdp4.0: do a posting read when flushing HDP
  (stable-fixes).
- drm/dp_mst: Verify request type in the corresponding down
  message reply (stable-fixes).
- drm/dp_mst: Fix MST sideband message body length check
  (stable-fixes).
- drm/amdgpu/vcn: reset fw_shared when VCPU buffers corrupted
  on vcn v4.0.3 (stable-fixes).
- drm/amd/display: Ignore scalar validation failure if pipe is
  phantom (stable-fixes).
- Revert "drm/amd/display: parse umc_info or vram_info based on
  ASIC" (stable-fixes).
- drm/panic: Add ABGR2101010 support (stable-fixes).
- drm/amdgpu: set the right AMDGPU sg segment limitation
  (stable-fixes).
- drm/amdgpu: skip amdgpu_device_cache_pci_state under sriov
  (stable-fixes).
- drm/amd/display: Prune Invalid Modes For HDMI Output
  (stable-fixes).
- drm/amd/display: parse umc_info or vram_info based on ASIC
  (stable-fixes).
- drm/amd/display: Remove hw w/a toggle if on DP2/HPO
  (stable-fixes).
- drm/amd/display: Fix underflow when playing 8K video in full
  screen mode (stable-fixes).
- drm/xe/devcoredump: Update handling of xe_force_wake_get return
  (stable-fixes).
- drm/xe/forcewake: Add a helper xe_force_wake_ref_has_domain()
  (stable-fixes).
- drm/sched: memset() 'job' in drm_sched_job_init()
  (stable-fixes).
- drm/panel: simple: Add Microchip AC69T88A LVDS Display panel
  (stable-fixes).
- drm/amdgpu: refine error handling in amdgpu_ttm_tt_pin_userptr
  (stable-fixes).
- drm/amdgpu: Dereference the ATCS ACPI buffer (stable-fixes).
- drm/amdgpu: clear RB_OVERFLOW bit when enabling interrupts
  for vega20_ih (stable-fixes).
- drm/amdgpu/gfx9: Add cleaner shader for GFX9.4.2 (stable-fixes).
- drm/amd/display: Adding array index check to prevent memory
  corruption (stable-fixes).
- drm/amd/display: Full exit out of IPS2 when all allow signals
  have been cleared (stable-fixes).
- drm/amd/display: disable SG displays on cyan skillfish
  (stable-fixes).
- drm/amd/display: calculate final viewport before TAP
  optimization (stable-fixes).
- drm/amd/display: Fix garbage or black screen when resetting otg
  (stable-fixes).
- drm/amd/display: skip disable CRTC in seemless bootup case
  (stable-fixes).
- drm/radeon/r600_cs: Fix possible int overflow in
  r600_packet3_check() (stable-fixes).
- drm/amd/display: Fix out-of-bounds access in
  'dcn21_link_encoder_create' (stable-fixes).
- drm/display: Fix building with GCC 15 (stable-fixes).
- drm/xe/xe3: Add initial set of workarounds (stable-fixes).
- drm/xe/ptl: L3bank mask is not available on the media GT
  (stable-fixes).
- drm/xe/guc: Copy GuC log prior to dumping (stable-fixes).
- drm/xe/devcoredump: Add ASCII85 dump helper function
  (stable-fixes).
- drm/xe/devcoredump: Improve section headings and add tile info
  (stable-fixes).
- drm/xe/devcoredump: Use drm_puts and already cached local
  variables (stable-fixes).
- drm/xe/pciid: Add new PCI id for ARL (stable-fixes).
- drm/xe/pciids: Add PVC's PCI device ID macros (stable-fixes).
- drm/xe/pciids: separate ARL and MTL PCI IDs (stable-fixes).
- drm/xe/pciids: separate RPL-U and RPL-P PCI IDs (stable-fixes).
- drm/mcde: Enable module autoloading (stable-fixes).
- firmware: qcom: scm: Allow QSEECOM on Dell XPS 13 9345
  (stable-fixes).
- firmware: qcom: scm:  Allow QSEECOM on Lenovo Yoga Slim 7x
  (stable-fixes).
- gpio: grgpio: use a helper variable to store the address of
  ofdev->dev (stable-fixes).
- gpio: free irqs that are still requested when the chip is
  being removed (stable-fixes).
- commit d415f2b
* Tue Dec 31 2024 tiwai@suse.de
- dmaengine: tegra: Return correct DMA status when paused
  (git-fixes).
- dmaengine: mv_xor: fix child node refcount handling in early
  exit (git-fixes).
- dmaengine: fsl-edma: implement the cleanup path of
  fsl_edma3_attach_pd() (git-fixes).
- dmaengine: amd: qdma: Remove using the private get and set
  dma_ops APIs (git-fixes).
- dmaengine: apple-admac: Avoid accessing registers in probe
  (git-fixes).
- dmaengine: dw: Select only supported masters for ACPI devices
  (git-fixes).
- dmaengine: at_xdmac: avoid null_prt_deref in
  at_xdmac_prep_dma_memset (git-fixes).
- dma-buf: Fix __dma_buf_debugfs_list_del argument for
  !CONFIG_DEBUG_FS (git-fixes).
- can: m_can: fix missed interrupts with m_can_pci (git-fixes).
- can: m_can: set init flag earlier in probe (git-fixes).
- cxl/region: Fix region creation for greater than x2 switches
  (git-fixes).
- cxl/pci: Fix potential bogus return value upon successful
  probing (git-fixes).
- crypto: hisilicon/debugfs - fix the struct pointer incorrectly
  offset problem (git-fixes).
- Documentation: PM: Clarify pm_runtime_resume_and_get() return
  value (git-fixes).
- Documentation: networking: Add a caveat to nexthop_compat_mode
  sysctl (git-fixes).
- clk: en7523: Initialize num before accessing hws in
  en7523_register_clocks() (git-fixes).
- clk: en7523: Fix wrong BUS clock for EN7581 (git-fixes).
- dma-buf: fix dma_fence_array_signaled v4 (stable-fixes).
- clk: qcom: clk-alpha-pll: Add NSS HUAYRA ALPHA PLL support
  for ipq9574 (stable-fixes).
- clk: qcom: dispcc-sm8550: enable support for SAR2130P
  (stable-fixes).
- clk: qcom: tcsrcc-sm8550: add SAR2130P support (stable-fixes).
- clk: qcom: rpmh: add support for SAR2130P (stable-fixes).
- clk: qcom: rcg2: add clk_rcg2_shared_floor_ops (stable-fixes).
- drm/bridge: it6505: Enable module autoloading (stable-fixes).
- drm: panel-orientation-quirks: Add quirk for AYA NEO GEEK
  (stable-fixes).
- drm: panel-orientation-quirks: Add quirk for AYA NEO Founder
  edition (stable-fixes).
- drm: panel-orientation-quirks: Add quirk for AYA NEO 2 model
  (stable-fixes).
- drm/vc4: hvs: Set AXI panic modes for the HVS (stable-fixes).
- drm/vc4: hdmi: Avoid log spam for audio start failure
  (stable-fixes).
- dma-debug: fix a possible deadlock on radix_lock (stable-fixes).
- Documentation: tipc: fix formatting issue in tipc.rst
  (git-fixes).
- cleanup: Adjust scoped_guard() macros to avoid potential warning
  (stable-fixes).
- crypto: ecdsa - Avoid signed integer overflow on signature
  decoding (stable-fixes).
- commit 8e66607
* Tue Dec 31 2024 tiwai@suse.de
- ASoC: SOF: Intel: hda-dai: Do not release the link DMA on STOP
  (git-fixes).
- ASoC: amd: ps: Fix for enabling DMIC on acp63 platform via
  _DSD entry (git-fixes).
- ALSA: sh: Fix wrong argument order for copy_from_iter()
  (git-fixes).
- ALSA: memalloc: prefer dma_mapping_error() over explicit
  address checking (git-fixes).
- accel/ivpu: Fix WARN in ivpu_ipc_send_receive_internal()
  (git-fixes).
- accel/ivpu: Fix general protection fault in ivpu_bo_list()
  (git-fixes).
- ata: sata_highbank: fix OF node reference leak in
  highbank_initialize_phys() (git-fixes).
- amdgpu/uvd: get ring reference from rq scheduler (git-fixes).
- ACPICA: events/evxfregn: don't release the ContextMutex that
  was never acquired (git-fixes).
- ACPI: resource: Fix memory resource type union access
  (git-fixes).
- acpi: nfit: vmalloc-out-of-bounds Read in acpi_nfit_ctl
  (git-fixes).
- ASoC: Intel: sof_sdw: Add space for a terminator into DAIs array
  (git-fixes).
- ASoC: fsl_spdif: change IFACE_PCM to IFACE_MIXER (git-fixes).
- ASoC: fsl_xcvr: change IFACE_PCM to IFACE_MIXER (git-fixes).
- ASoC: tas2781: Fix calibration issue in stress test (git-fixes).
- ASoC: amd: yc: Fix the wrong return value (git-fixes).
- ALSA: control: Avoid WARN() for symlink errors (git-fixes).
- ALSA: usb-audio: Add implicit feedback quirk for Yamaha THR5
  (stable-fixes).
- ALSA: hda/realtek: Fix headset mic on Acer Nitro 5
  (stable-fixes).
- ASoC: amd: yc: Add quirk for microphone on Lenovo Thinkpad
  T14s Gen 6 21M1CTO1WW (stable-fixes).
- ASoC: amd: yc: fix internal mic on Redmi G 2022 (stable-fixes).
- ACPI: x86: Clean up Asus entries in acpi_quirk_skip_dmi_ids[]
  (stable-fixes).
- ACPI: x86: Add skip i2c clients quirk for Acer Iconia One 8
  A1-840 (stable-fixes).
- accel/qaic: Add AIC080 support (stable-fixes).
- ASoC: hdmi-codec: reorder channel allocation list
  (stable-fixes).
- ASoC: Intel: soc-acpi-intel-arl-match: Add rt722 and rt1320
  support (stable-fixes).
- ASoC: sdw_utils: Add quirk to exclude amplifier function
  (stable-fixes).
- ASoC: Intel: sof_sdw: Add quirks for some new Lenovo laptops
  (stable-fixes).
- ASoC: Intel: sof_sdw: Add quirk for cs42l43 system using host
  DMICs (stable-fixes).
- ASoC: sdw_utils: Add a quirk to allow the cs42l43 mic DAI to
  be ignored (stable-fixes).
- ASoC: sdw_utils: Add support for exclusion DAI quirks
  (stable-fixes).
- ASoC: Intel: avs: Fix return status of
  avs_pcm_hw_constraints_init() (stable-fixes).
- ASoC: Intel: sof_rt5682: Add HDMI-In capture with rt5682
  support for MTL (stable-fixes).
- Bluetooth: btusb: Add 3 HWIDs for MT7925 (stable-fixes).
- Bluetooth: btusb: Add new VID/PID 0489/e124 for MT7925
  (stable-fixes).
- Bluetooth: btusb: Add new VID/PID 0489/e111 for MT7925
  (stable-fixes).
- Bluetooth: Set quirks for ATS2851 (stable-fixes).
- Bluetooth: Support new quirks for ATS2851 (stable-fixes).
- Bluetooth: Add new quirks for ATS2851 (stable-fixes).
- Bluetooth: hci_core: Fix not checking skb length on
  hci_acldata_packet (stable-fixes).
- Bluetooth: hci_conn: Use disable_delayed_work_sync
  (stable-fixes).
- Bluetooth: btusb: Add USB HW IDs for MT7920/MT7925
  (stable-fixes).
- Bluetooth: btusb: Add RTL8852BE device 0489:e123 to device
  tables (stable-fixes).
- Bluetooth: hci_conn: Reduce hci_conn_drop() calls in two
  functions (stable-fixes).
- Bluetooth: RFCOMM: avoid leaving dangling sk pointer in
  rfcomm_sock_alloc() (stable-fixes).
- Bluetooth: L2CAP: do not leave dangling sk pointer on error
  in l2cap_sock_create() (stable-fixes).
- ACPI: video: force native for Apple MacbookPro11,2 and Air7,2
  (stable-fixes).
- ACPI: x86: Add adev NULL check to
  acpi_quirk_skip_serdev_enumeration() (stable-fixes).
- ACPI: x86: Make UART skip quirks work on PCI UARTs without an
  UID (stable-fixes).
- commit f768efe
* Tue Dec 31 2024 krisman@suse.de
- io_uring: check if iowq is killed before queuing (git-fixes).
- commit d272417
* Mon Dec 30 2024 krisman@suse.de
- io_uring: Fix registered ring file refcount leak (git-fixes).
- io_uring: Change res2 parameter type in io_uring_cmd_done
  (git-fixes).
- io_uring/tctx: work around xa_store() allocation error issue
  (git-fixes).
- io_uring: fix corner case forgetting to vunmap (git-fixes).
- io_uring: check for overflows in io_pin_pages (git-fixes).
- commit bbcd0cb
* Mon Dec 30 2024 mfranc@suse.cz
- Update
  patches.suse/s390-stacktrace-Use-break-instead-of-return-statement.patch
  (git-fixes bsc#1234352 CVE-2024-56550 bsc#1234915).
- commit fb93bc1
* Mon Dec 30 2024 ptesarik@suse.com
- preempt: Move PREEMPT_RT before PREEMPT in vermagic (git-fixes).
- commit bd70ce5
* Wed Dec 25 2024 ohering@suse.de
- tools/hv: reduce resource usage in hv_kvp_daemon (git-fixes).
- tools/hv: add a .gitignore file (git-fixes).
- tools/hv: reduce resouce usage in hv_get_dns_info helper
  (git-fixes).
- hv/hv_kvp_daemon: Pass NIC name to hv_get_dns_info as well
  (git-fixes).
- Drivers: hv: util: Avoid accessing a ringbuffer not initialized
  yet (git-fixes).
- Drivers: hv: util: Don't force error code to ENODEV in
  util_probe() (git-fixes).
- tools/hv: terminate fcopy daemon if read from uio fails
  (git-fixes).
- drivers: hv: Convert open-coded timeouts to secs_to_jiffies()
  (git-fixes).
- tools: hv: change permissions of NetworkManager configuration
  file (git-fixes).
- x86/hyperv: Fix hv tsc page based sched_clock for hibernation
  (git-fixes).
- tools: hv: Fix a complier warning in the fcopy uio daemon
  (git-fixes).
- jiffies: Define secs_to_jiffies() (git-fixes).
- commit 9c8b4b3
* Tue Dec 24 2024 ailiop@suse.com
- nfsd: restore callback functionality for NFSv4.0 (git-fixes).
- commit bf279e8
* Mon Dec 23 2024 ailiop@suse.com
- xfs: return from xfs_symlink_verify early on V4 filesystems
  (git-fixes).
- commit 6019ea4
* Mon Dec 23 2024 ailiop@suse.com
- xfs: fix sb_spino_align checks for large fsblock sizes
  (git-fixes).
- commit 98c6cb3
* Mon Dec 23 2024 ailiop@suse.com
- xfs: only run precommits once per transaction object
  (git-fixes).
- commit 574f714
* Mon Dec 23 2024 ailiop@suse.com
- xfs: unlock inodes when erroring out of xfs_trans_alloc_dir
  (git-fixes).
- commit 49dd5e2
* Mon Dec 23 2024 ailiop@suse.com
- xfs: fix scrub tracepoints when inode-rooted btrees are involved
  (git-fixes).
- commit 9d264ae
* Mon Dec 23 2024 ailiop@suse.com
- xfs: update btree keys correctly when _insrec splits an inode
  root block (git-fixes).
- commit 16300ea
* Mon Dec 23 2024 ailiop@suse.com
- xfs: fix null bno_hint handling in xfs_rtallocate_rtg
  (git-fixes).
- commit 64c1638
* Mon Dec 23 2024 ailiop@suse.com
- xfs: set XFS_SICK_INO_SYMLINK_ZAPPED explicitly when zapping
  a symlink (git-fixes).
- commit 9828305
* Mon Dec 23 2024 ailiop@suse.com
- xfs: don't drop errno values when we fail to ficlone the entire
  range (git-fixes).
- commit 701e2f2
* Mon Dec 23 2024 ailiop@suse.com
- xfs: return a 64-bit block count from xfs_btree_count_blocks
  (git-fixes).
- commit 2c2d3e0
* Mon Dec 23 2024 ailiop@suse.com
- NFS/pnfs: Fix a live lock between recalled layouts and layoutget
  (git-fixes).
- commit 4b27d0f
* Mon Dec 23 2024 ailiop@suse.com
- nfsd: fix nfs4_openowner leak when concurrent nfsd4_open occur
  (git-fixes).
- commit 866861d
* Mon Dec 23 2024 ailiop@suse.com
- SUNRPC: make sure cache entry active before cache_show
  (git-fixes).
- commit 46da6e3
* Mon Dec 23 2024 ailiop@suse.com
- NFSD: Prevent a potential integer overflow (git-fixes).
- commit afa1145
* Mon Dec 23 2024 ailiop@suse.com
- erofs: fix PSI memstall accounting (git-fixes).
- commit 33a3df5
* Mon Dec 23 2024 ailiop@suse.com
- epoll: annotate racy check (git-fixes).
- commit 94df11a
* Mon Dec 23 2024 ailiop@suse.com
- exfat: fix uninit-value in __exfat_get_dentry_set (git-fixes).
- commit 092c2f6
* Mon Dec 23 2024 ailiop@suse.com
- exfat: fix out-of-bounds access of directory entries
  (git-fixes).
- commit bca1b1b
* Fri Dec 20 2024 ykaukab@suse.de
- config: enable CONFIG_DEBUG_WX
  References: jsc#PED-11834
- commit 1b5f22c
* Fri Dec 20 2024 mfranc@suse.cz
- s390/debug: Pass in and enforce output buffer size for format
  handlers (git-fixes bsc#1234755).
- commit 430b82f
* Fri Dec 20 2024 iivanov@suse.de
- arm64: ptrace: fix partial SETREGSET for NT_ARM_POE (git-fixes)
- commit be5e333
* Fri Dec 20 2024 iivanov@suse.de
- arm64: ptrace: fix partial SETREGSET for NT_ARM_FPMR (git-fixes)
- commit a39fa97
* Fri Dec 20 2024 iivanov@suse.de
- arm64: ptrace: fix partial SETREGSET for NT_ARM_TAGGED_ADDR_CTRL (git-fixes)
- commit ac2dfa2
* Fri Dec 20 2024 iivanov@suse.de
- arm64: mm: Fix zone_dma_limit calculation (git-fixes)
- commit 8778362
* Fri Dec 20 2024 jslaby@suse.cz
- serial: sh-sci: Check if TX data was written to device in
  .tx_empty() (git-fixes).
- commit 3191962
* Fri Dec 20 2024 ptesarik@suse.com
- sched/core: Update kernel boot parameters for LAZY preempt
  (bsc#1234370).
- sched: No PREEMPT_RT=y for all{yes,mod}config (bsc#1234370).
- commit 7d6dbbf
* Fri Dec 20 2024 ptesarik@suse.com
- sched, x86: Enable Lazy preemption (bsc#1234370).
- Update config files.
- commit c439fcd
* Fri Dec 20 2024 ptesarik@suse.com
- tracing: Record task flag NEED_RESCHED_LAZY (bsc#1234370).
- tracing: Remove TRACE_FLAG_IRQS_NOSUPPORT (bsc#1234370).
- sched, x86: Update the comment for TIF_NEED_RESCHED_LAZY
  (bsc#1234370).
- riscv: add PREEMPT_LAZY support (bsc#1234370).
- sched: Enable PREEMPT_DYNAMIC for PREEMPT_RT (bsc#1234370).
- sched: Add Lazy preemption model (bsc#1234370).
- sched: Add TIF_NEED_RESCHED_LAZY infrastructure (bsc#1234370).
- commit 32e8d26
* Thu Dec 19 2024 mkoutny@suse.com
- blk-cgroup: Fix UAF in blkcg_unpin_online() (bsc#1234726).
- commit 991b744
* Thu Dec 19 2024 mfranc@suse.cz
- s390/cpum_sf: Handle CPU hotplug remove during sampling
  (git-fixes bsc#1234715).
- commit 6c44c98
* Wed Dec 18 2024 jgross@suse.com
- x86/xen: remove hypercall page (XSA-466 CVE-2024-53241
  bsc#1234282).
- commit cc077cb
* Wed Dec 18 2024 jgross@suse.com
- x86/xen: use new hypercall functions instead of hypercall page
  (XSA-466 CVE-2024-53241 bsc#1234282).
- commit cf705e2
* Wed Dec 18 2024 jgross@suse.com
- x86/xen: add central hypercall functions (XSA-466 CVE-2024-53241
  bsc#1234282).
- commit 8d7a3d3
* Wed Dec 18 2024 jgross@suse.com
- x86/xen: don't do PV iret hypercall through hypercall page
  (XSA-466 CVE-2024-53241 bsc#1234282).
- commit 1847ea1
* Wed Dec 18 2024 jgross@suse.com
- x86/static-call: provide a way to do very early static-call
  updates (XSA-466 CVE-2024-53241 bsc#1234282).
- commit 518b891
* Wed Dec 18 2024 jgross@suse.com
- objtool/x86: allow syscall instruction (XSA-466 CVE-2024-53241
  bsc#1234282).
- commit c82a684
* Wed Dec 18 2024 jgross@suse.com
- x86: make get_cpu_vendor() accessible from Xen code (XSA-466
  CVE-2024-53241 bsc#1234282).
- commit 827db39
* Wed Dec 18 2024 jgross@suse.com
- xen/netfront: fix crash when removing device (XSA-465
  CVE-2024-53240 bsc#1234281).
- commit 683acf2
* Wed Dec 18 2024 mfranc@suse.cz
- s390/mm: Consider KMSAN modules metadata for paging levels
  (git-fixes bsc#1234686).
- s390/ipl: Fix never less than zero warning (git-fixes
  bsc#1234685).
- s390/mm: Fix DirectMap accounting (git-fixes bsc#1234687).
- commit 4ad9925
* Wed Dec 18 2024 nmorey@suse.com
- RDMA/mlx5: Move events notifier registration to be after device registration (git-fixes)
- commit 38f5ec4
* Tue Dec 17 2024 mfranc@suse.cz
- s390x config: drop netiucv and lcs drivers (jsc#PED-11160)
- commit 160e70b
* Tue Dec 17 2024 mfranc@suse.cz
- supported.conf: drop netiucv and lcs drivers (jsc#PED-11160)
- commit b6e4c33
* Mon Dec 16 2024 mgorman@suse.de
- sched/dlserver: Fix dlserver time accounting (bsc#1234634
  (Scheduler functional and performance backports)).
- sched/dlserver: Fix dlserver double enqueue (bsc#1234634
  (Scheduler functional and performance backports)).
- sched/eevdf: More PELT vs DELAYED_DEQUEUE (bsc#1234634
  (Scheduler functional and performance backports)).
- sched/fair: Fix sched_can_stop_tick() for fair tasks
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/fair: Fix NEXT_BUDDY (bsc#1234634 (Scheduler functional
  and performance backports)).
- sched/deadline: Fix warning in migrate_enable for boosted tasks
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/core: Update kernel boot parameters for LAZY preempt
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/core: Prevent wakeup of ksoftirqd during idle load balance
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/fair: Check idle_cpu() before need_resched() to detect
  ilb CPU turning busy (bsc#1234634 (Scheduler functional and
  performance backports)).
- sched/core: Remove the unnecessary need_resched() check
  in nohz_csd_func() (bsc#1234634 (Scheduler functional and
  performance backports)).
- softirq: Allow raising SCHED_SOFTIRQ from SMP-call-function on
  RT kernel (bsc#1234634 (Scheduler functional and performance
  backports)).
- sched: fix warning in sched_setaffinity (bsc#1234634 (Scheduler
  functional and performance backports)).
- sched/deadline: Fix replenish_dl_new_period dl_server condition
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched_ext: Replace scx_next_task_picked() with switch_class()
  in comment (bsc#1234634 (Scheduler functional and performance
  backports)).
- sched_ext: Rename scx_bpf_dispatch[_vtime]_from_dsq*() ->
  scx_bpf_dsq_move[_vtime]*() (bsc#1234634 (Scheduler functional
  and performance backports)).
- sched_ext: Rename scx_bpf_consume() to
  scx_bpf_dsq_move_to_local() (bsc#1234634 (Scheduler functional
  and performance backports)).
- sched_ext: Rename scx_bpf_dispatch[_vtime]() to
  scx_bpf_dsq_insert[_vtime]() (bsc#1234634 (Scheduler functional
  and performance backports)).
- sched_ext: scx_bpf_dispatch_from_dsq_set_*() are allowed
  from unlocked context (bsc#1234634 (Scheduler functional and
  performance backports)).
- sched_ext: add a missing rcu_read_lock/unlock pair at
  scx_select_cpu_dfl() (bsc#1234634 (Scheduler functional and
  performance backports)).
- sched_ext: Clarify sched_ext_ops table for userland scheduler
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched_ext: Enable the ops breather and eject BPF scheduler on
  softlockup (bsc#1234634 (Scheduler functional and performance
  backports)).
- sched_ext: Avoid live-locking bypass mode switching (bsc#1234634
  (Scheduler functional and performance backports)).
- sched_ext: Fix incorrect use of bitwise AND (bsc#1234634
  (Scheduler functional and performance backports)).
- sched_ext: Do not enable LLC/NUMA optimizations when domains
  overlap (bsc#1234634 (Scheduler functional and performance
  backports)).
- sched_ext: Introduce NUMA awareness to the default idle
  selection policy (bsc#1234634 (Scheduler functional and
  performance backports)).
- sched_ext: Replace set_arg_maybe_null() with __nullable CFI
  stub tags (bsc#1234634 (Scheduler functional and performance
  backports)).
- sched_ext: Rename CFI stubs to names that are recognized by BPF
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched_ext: Introduce LLC awareness to the default idle
  selection policy (bsc#1234634 (Scheduler functional and
  performance backports)).
- sched_ext: Clarify ops.select_cpu() for single-CPU tasks
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched_ext: improve WAKE_SYNC behavior for default idle CPU
  selection (bsc#1234634 (Scheduler functional and performance
  backports)).
- sched_ext: Use btf_ids to resolve task_struct (bsc#1234634
  (Scheduler functional and performance backports)).
- sched/ext: Use tg_cgroup() to elieminate duplicate code
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/ext: Fix unmatch trailing comment of
  CONFIG_EXT_GROUP_SCHED (bsc#1234634 (Scheduler functional and
  performance backports)).
- sched_ext: Factor out move_task_between_dsqs() from
  scx_dispatch_from_dsq() (bsc#1234634 (Scheduler functional
  and performance backports)).
- sched/idle: Switch to use hrtimer_setup_on_stack() (bsc#1234634
  (Scheduler functional and performance backports)).
- hrtimers: Delete hrtimer_init_sleeper_on_stack() (bsc#1234634
  (Scheduler functional and performance backports)).
- wait: Switch to use hrtimer_setup_sleeper_on_stack()
  (bsc#1234634 (Scheduler functional and performance backports)).
- timers: Switch to use hrtimer_setup_sleeper_on_stack()
  (bsc#1234634 (Scheduler functional and performance backports)).
- net: pktgen: Switch to use hrtimer_setup_sleeper_on_stack()
  (bsc#1234634 (Scheduler functional and performance backports)).
- futex: Switch to use hrtimer_setup_sleeper_on_stack()
  (bsc#1234634 (Scheduler functional and performance backports)).
- fs/aio: Switch to use hrtimer_setup_sleeper_on_stack()
  (bsc#1234634 (Scheduler functional and performance backports)).
- hrtimers: Introduce hrtimer_update_function() (bsc#1234634
  (Scheduler functional and performance backports)).
- hrtimers: Introduce hrtimer_setup_sleeper_on_stack()
  (bsc#1234634 (Scheduler functional and performance backports)).
- hrtimers: Introduce hrtimer_setup_on_stack() (bsc#1234634
  (Scheduler functional and performance backports)).
- hrtimers: Introduce hrtimer_setup() to replace hrtimer_init()
  (bsc#1234634 (Scheduler functional and performance backports)).
- hrtimers: Add missing hrtimer_init() trace points (bsc#1234634
  (Scheduler functional and performance backports)).
- timers: Move *sleep*() and timeout functions into a separate
  file (bsc#1234634 (Scheduler functional and performance
  backports)).
- sched, x86: Enable Lazy preemption (bsc#1234634 (Scheduler
  functional and performance backports)).
- Refresh configs
- sched: Add Lazy preemption model (bsc#1234634 (Scheduler
  functional and performance backports)).
- sched: Add TIF_NEED_RESCHED_LAZY infrastructure (bsc#1234634
  (Scheduler functional and performance backports)).
- sched/ext: Remove sched_fork() hack (bsc#1234634 (Scheduler
  functional and performance backports)).
- sched: Initialize idle tasks only once (bsc#1234634 (Scheduler
  functional and performance backports)).
- sched: psi: pass enqueue/dequeue flags to psi callbacks directly
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/uclamp: Fix unnused variable warning (bsc#1234634
  (Scheduler functional and performance backports)).
- sched: Split scheduler and execution contexts (bsc#1234634
  (Scheduler functional and performance backports)).
- sched: Split out __schedule() deactivate task logic into a
  helper (bsc#1234634 (Scheduler functional and performance
  backports)).
- sched: Consolidate pick_*_task to task_is_pushable helper
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched: Add move_queued_task_locked helper (bsc#1234634
  (Scheduler functional and performance backports)).
- sched: Improve cache locality of RSEQ concurrency IDs for
  intermittent workloads (bsc#1234634 (Scheduler functional and
  performance backports)).
- sched: idle: Optimize the generic idle loop by removing
  needless memory barrier (bsc#1234634 (Scheduler functional
  and performance backports)).
- sched/wait: Remove unused bit_wait_io_timeout (bsc#1234634
  (Scheduler functional and performance backports)).
- sched/fair: fix the comment for PREEMPT_SHORT (bsc#1234634
  (Scheduler functional and performance backports)).
- sched/fair: optimize the PLACE_LAG when se->vlag is zero
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched/fair: remove the DOUBLE_TICK feature (bsc#1234634
  (Scheduler functional and performance backports)).
- softirq: use bit waits instead of var waits (bsc#1234634
  (Scheduler functional and performance backports)).
- sched: add wait_var_event_io() (bsc#1234634 (Scheduler
  functional and performance backports)).
- sched: Add wait/wake interface for variable updated under a lock
  (bsc#1234634 (Scheduler functional and performance backports)).
- sched: Add test_and_clear_wake_up_bit() and
  atomic_dec_and_wake_up() (bsc#1234634 (Scheduler functional
  and performance backports)).
- sched: Document wait_var_event() family of functions and
  wake_up_var() (bsc#1234634 (Scheduler functional and performance
  backports)).
- sched: Improve documentation for wake_up_bit/wait_on_bit
  family of functions (bsc#1234634 (Scheduler functional and
  performance backports)).
- sched: change wake_up_bit() and related function to expect
  unsigned long * (bsc#1234634 (Scheduler functional and
  performance backports)).
- sched/cpufreq: Ensure sd is rebuilt for EAS check (bsc#1234634
  (Scheduler functional and performance backports)).
- sched_getattr: port to copy_struct_to_user (bsc#1234634
  (Scheduler functional and performance backports)).
- uaccess: add copy_struct_to_user helper (bsc#1234634 (Scheduler
  functional and performance backports)).
- commit 23379e3
* Mon Dec 16 2024 mfranc@suse.cz
- s390/sclp: Allow user-space to provide PCI reports for optical
  modules (jsc#PED-11804).
- commit 645b84a
* Mon Dec 16 2024 ohering@suse.de
- net: mana: Fix irq_contexts memory leak in mana_gd_setup_irqs
  (git-fixes).
- net: mana: Fix memory leak in mana_gd_setup_irqs (git-fixes).
- commit e0ecd16
* Mon Dec 16 2024 iivanov@suse.de
- arm64: Ensure bits ASID[15:8] are masked out when the kernel uses (bsc#1234605)
- commit b4e6c18
* Fri Dec 13 2024 mfranc@suse.cz
- KVM: s390: add gen17 facilities to CPU model (jsc#PED-10311).
- KVM: s390: add msa11 to cpu model (jsc#PED-10311).
- KVM: s390: add concurrent-function facility to cpu model
  (jsc#PED-10311).
- commit 61222cd
* Fri Dec 13 2024 mfranc@suse.cz
- s390/crypto: Add hardware acceleration for full AES-XTS mode
  (jsc#PED-10314).
- s390/crypto: Postpone the key split to key conversion
  (jsc#PED-10314).
- s390/crypto: Introduce function for tokenize clearkeys
  (jsc#PED-10314).
- s390/crypto: Generalize parameters for key conversion
  (jsc#PED-10314).
- s390/crypto: Use module-local structures for protected keys
  (jsc#PED-10314).
- s390/crypto: Convert to reverse x-mas tree, rename ret to rc
  (jsc#PED-10314).
- s390/pkey: Tolerate larger key blobs (jsc#PED-10314).
- commit 0dd8187
* Fri Dec 13 2024 mfranc@suse.cz
- supported.conf: mark arch/s390/crypto/hmac_s390 as externally supported (jsc#PED-10324)
- commit c4fa325
* Fri Dec 13 2024 mfranc@suse.cz
- supported.conf: mark drivers/s390/crypto/pkey_uv as externally supported (jsc#PED-10318)
- commit 50163dc
* Fri Dec 13 2024 mfranc@suse.cz
- s390x config: enable PKEY_UV (jsc#PED-10318)
- commit 1fa7668
* Fri Dec 13 2024 mfranc@suse.cz
- s390/pkey: Add new pkey handler module pkey-uv (jsc#PED-10318).
- s390/pkey: Build module name array selectively based on kernel
  config options (jsc#PED-10318).
- s390/pkey: Rework pkey verify for protected keys
  (jsc#PED-10318).
- s390/pkey: Simplify protected key length calculation code
  (jsc#PED-10318).
- s390/zcrypt: Cleanup include zcrypt_api.h (jsc#PED-10318).
- commit fa68c6e
* Fri Dec 13 2024 mfranc@suse.cz
- s390/uvdevice: Support longer secret lists (jsc#PED-11785).
- s390/uv: Retrieve UV secrets sysfs support (jsc#PED-11785).
- s390/uvdevice: Increase indent in IOCTL definitions
  (jsc#PED-11785).
- s390/uvdevice: Add Retrieve Secret IOCTL (jsc#PED-11785).
- s390/uv: Retrieve UV secrets support (jsc#PED-11785).
- s390/uv: Use a constant for more-data rc (jsc#PED-11785).
- commit 0151068
* Fri Dec 13 2024 mfranc@suse.cz
- s390/uv: Provide host-key hashes in sysfs (jsc#PED-11158).
- s390/uv: Refactor uv-sysfs creation (jsc#PED-11158).
- commit edbf800
* Fri Dec 13 2024 mfranc@suse.cz
- s390/cio: Externalize full CMG characteristics (jsc#PED-11162).
- commit 5d24d1b
* Fri Dec 13 2024 mfranc@suse.cz
- s390x config: disable CONFIG_COMPAT (jsc#PED-7854)
- commit d25f099
* Fri Dec 13 2024 jslaby@suse.cz
- rpm/kernel-binary.spec.in: fix KMPs build on 6.13+ (bsc#1234454)
  Upstream commit 822b11a74ba2 (kbuild: use absolute path in the generated
  wrapper Makefile) sets also KBUILD_OUTPUT in objdir's Makefile before
  including srcdir's Makefile.
  So emulate this too, otherwise KMPs fail to build:
  /usr/src/linux-6.13.0-rc2-1.gf92fc5d/Makefile:782: /usr/src/linux-6.13.0-rc2-1.gf92fc5d/include/config/auto.conf: No such file or directory
- commit 46168e5
* Fri Dec 13 2024 mfranc@suse.cz
- s390/pci: Fix leak of struct zpci_dev when zpci_add_device()
  fails (jsc#PED-10325).
- s390/pci: Ignore RID for isolated VFs (jsc#PED-10325).
- s390/pci: Use topology ID for multi-function devices
  (jsc#PED-10325).
- s390/pci: Sort PCI functions prior to creating virtual busses
  (jsc#PED-10325).
- commit 30c6861
* Fri Dec 13 2024 tiwai@suse.de
- Bluetooth: btmtk: avoid UAF in btmtk_process_coredump
  (git-fixes).
- Bluetooth: iso: Fix circular lock in iso_conn_big_sync
  (git-fixes).
- Bluetooth: iso: Fix circular lock in iso_listen_bis (git-fixes).
- Bluetooth: SCO: Add support for 16 bits transparent voice
  setting (git-fixes).
- Bluetooth: iso: Fix recursive locking warning (git-fixes).
- Bluetooth: iso: Always release hdev at the end of iso_listen_bis
  (git-fixes).
- Bluetooth: hci_event: Fix using rcu_read_(un)lock while
  iterating (git-fixes).
- Bluetooth: Improve setsockopt() handling of malformed user input
  (git-fixes).
- batman-adv: Do not let TT changes list grows indefinitely
  (git-fixes).
- batman-adv: Remove uninitialized data in full table TT response
  (git-fixes).
- batman-adv: Do not send uninitialized TT changes (git-fixes).
- wifi: cfg80211: sme: init n_channels before channels[] access
  (git-fixes).
- wifi: mac80211: fix station NSS capability initialization order
  (git-fixes).
- wifi: mac80211: fix a queue stall in certain cases of CSA
  (git-fixes).
- wifi: mac80211: init cnt before accessing elem in
  ieee80211_copy_mbssid_beacon (git-fixes).
- wifi: nl80211: fix NL80211_ATTR_MLO_LINK_ID off-by-one
  (git-fixes).
- commit 87acd7b
* Thu Dec 12 2024 mwilck@suse.com
- scsi: megaraid_sas: Fix for a potential deadlock
  (jsc#PED-11259).
- commit 73f8b3c
* Thu Dec 12 2024 mwilck@suse.com
- Update config files: drop bfa driver (jsc#PED-6925)
- commit 6eb9687
* Thu Dec 12 2024 mwilck@suse.com
- scsi: mpt3sas: Update driver version to 51.100.00.00
  (jsc#PED-11252).
- commit a77a0f7
* Thu Dec 12 2024 mwilck@suse.com
- scsi: mpt3sas: Diag-Reset when Doorbell-In-Use bit is set
  during driver load time (jsc#PED-11252).
- commit ab220b1
* Thu Dec 12 2024 vkarasulli@suse.de
- iommufd: Fix out_fput in iommufd_fault_alloc() (git-fixes).
- commit b516daa
* Thu Dec 12 2024 vkarasulli@suse.de
- iommu/amd/pgtbl_v2: Take protection domain lock before
  invalidating TLB (git-fixes).
- commit bfae336
* Thu Dec 12 2024 ohering@suse.de
- scsi: storvsc: Do not flag MAINTENANCE_IN return of
  SRB_STATUS_DATA_OVERRUN as an error (git-fixes).
- net :mana :Request a V2 response version for MANA_QUERY_GF_STAT
  (git-fixes).
- net: mana: use ethtool string helpers (git-fixes).
- net: mana: Enable debugfs files for MANA device (git-fixes).
- hv_netvsc: Don't assume cpu_possible_mask is dense (git-fixes).
- net: mana: Add get_link and get_link_ksettings in ethtool
  (git-fixes).
- net: mana: Increase the DEF_RX_BUFFERS_PER_QUEUE to 1024
  (git-fixes).
- commit a3a0c1e
* Wed Dec 11 2024 nmorey@suse.com
- bnxt_en: Add support for RoCE sriov configuration (jsc#PED-11250)
- commit a177146
* Wed Dec 11 2024 nmorey@suse.com
- Re-enable patches.suse/mlx5-add-parameter-to-disable-enhanced-IPoIB.patch (bsc#1142095, jsc#SLE-15175)
- commit 7a74a29
* Wed Dec 11 2024 ptesarik@suse.com
- locking/rt: Annotate unlock followed by lock for sparse
  (bsc#1234370).
- locking/rt: Add sparse annotation for RCU (bsc#1234370).
- locking/rt: Remove one __cond_lock() in RT's
  spin_trylock_irqsave() (bsc#1234370).
- locking/rt: Add sparse annotation PREEMPT_RT's sleeping locks
  (bsc#1234370).
- commit 79348e2
* Wed Dec 11 2024 nmorey@suse.com
- IB/cm: Rework sending DREQ when destroying a cm_id (jsc#PED-11323)
- commit 5f6d0d2
* Wed Dec 11 2024 nmorey@suse.com
- IB/cm: Do not hold reference on cm_id unless needed (jsc#PED-11323)
- commit aaede19
* Wed Dec 11 2024 nmorey@suse.com
- IB/cm: Explicitly mark if a response MAD is a retransmission (jsc#PED-11323)
- commit 2d5950b
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/nldev: Add IB device and net device rename events (jsc#PED-11323)
- commit 3146d03
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/core: Move ib_uverbs_file struct to uverbs_types.h (jsc#PED-11323)
- commit dda2a0e
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/core: Add device ufile cleanup operation (jsc#PED-11323)
- commit b241858
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/core: Implement RoCE GID port rescan and export delete function (jsc#PED-11323)
- commit 9487e55
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/rxe: Set queue pair cur_qp_state when being queried (jsc#PED-11323)
- commit 1fda28e
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/efa: Report link speed according to device attributes (jsc#PED-11323)
- commit 96e5da5
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/rxe: Fix the qp flush warnings in req (jsc#PED-11323)
- commit df95324
* Wed Dec 11 2024 oneukum@suse.com
- This is very hard to fix upstream as it goes deeply into NFC core
- commit 668fe23
* Wed Dec 11 2024 nmorey@suse.com
- RDMA: Use ethtool string helpers (jsc#PED-11323)
- commit 486ec2b
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/ipoib: Use the networking stack default for txqueuelen (jsc#PED-11323)
- commit b26dae5
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/efa: Add option to set QP service level on create (jsc#PED-11323)
- commit d641492
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/efa: Update device interface (jsc#PED-11323)
- commit a356642
* Wed Dec 11 2024 nmorey@suse.com
- IB/hfi1: make clear_all_interrupts static (jsc#PED-8564)
- commit 69cf48c
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/hns: Fix different dgids mapping to the same dip_idx (jsc#PED-11250)
- commit a935952
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/hns: Fix NULL pointer derefernce in hns_roce_map_mr_sg() (jsc#PED-11250)
- commit 914d5d2
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/hns: Fix out-of-order issue of requester when setting FENCE (jsc#PED-11250)
- commit f34c3c1
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/hns: Fix cpu stuck caused by printings during reset (jsc#PED-11250)
- commit 6408c43
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/hns: Use dev_* printings in hem code instead of ibdev_* (jsc#PED-11250)
- commit 99377a7
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/hns: Modify debugfs name (jsc#PED-11250)
- commit 3839b8a
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/hns: Fix flush cqe error when racing with destroy qp (jsc#PED-11250)
- commit 39e568b
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/hns: Fix an AEQE overflow error caused by untimely update of eq_db_ci (jsc#PED-11250)
- commit 56699b7
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/hns: Disassociate mmap pages for all uctx when HW is being reset (jsc#PED-11250)
- commit 6230f20
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/bnxt_re: Correct the sequence of device suspend (jsc#PED-11250)
- commit 2ef4645
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/bnxt_re: Use the default mode of congestion control (jsc#PED-11250)
- commit 65235d2
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/bnxt_re: Support different traffic class (jsc#PED-11250)
- commit 1942a7b
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/bnxt_re: Cache MSIx info to a local structure (jsc#PED-11250)
- commit 1e3b642
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/bnxt_re: Refurbish CQ to NQ hash calculation (jsc#PED-11250)
- commit 69d4b35
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/bnxt_re: Refactor NQ allocation (jsc#PED-11250)
- commit 72bfe4d
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/bnxt_re: Fail probe early when not enough MSI-x vectors are reserved (jsc#PED-11250)
- commit 2d18123
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/bnxt_re: Add set_func_resources support for P5/P7 adapters (jsc#PED-11250)
- commit cbb163e
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/bnxt_re: Enhance RoCE SRIOV resource configuration design (jsc#PED-11250)
- commit 8e2b0d1
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/bnxt_re: Add debugfs hook in the driver (jsc#PED-11250)
- commit 7df4e4c
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/bnxt_re: Support raw data query for each resources (jsc#PED-11250)
- commit b35c9fe
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/bnxt_re: Add support for querying HW contexts (jsc#PED-11250)
- commit 03d0ac2
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/bnxt_re: Support driver specific data collection using rdma tool (jsc#PED-11250)
- commit 301d4c8
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/bnxt_re: Check cqe flags to know imm_data vs inv_irkey (jsc#PED-11250)
- commit db78d83
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix access flags for MR and QP modify (jsc#PED-11250)
- commit 103dfc7
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/bnxt_re: Add support for modify_device hook (jsc#PED-11250)
- commit 2b5ef62
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/bnxt_re: Add support for CQ rx coalescing (jsc#PED-11250)
- commit 24d2ba3
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/bnxt_re: Add support for optimized modify QP (jsc#PED-11250)
- commit b0961e5
* Wed Dec 11 2024 nmorey@suse.com
- RDMA/core: Provide rdma_user_mmap_disassociate() to disassociate mmap pages (jsc#PED-11250)
- commit 9dfd1ae
* Wed Dec 11 2024 mfranc@suse.cz
- s390/dasd: fix redundant /proc/dasd* entries removal
  (bsc#1227694).
- commit 3fe3c9b
* Wed Dec 11 2024 ptesarik@suse.com
- softirq: Use a dedicated thread for timer wakeups on PREEMPT_RT
  (bsc#1234370).
- timers: Use __raise_softirq_irqoff() to raise the softirq
  (bsc#1234370).
- hrtimer: Use __raise_softirq_irqoff() to raise the softirq
  (bsc#1234370).
- commit 648ddcf
* Tue Dec 10 2024 ptesarik@suse.com
- config: remove unsupported configs
- commit 1752d05
* Tue Dec 10 2024 mfranc@suse.cz
- s390/entry: Mark IRQ entries to fix stack depot warnings
  (git-fixes bsc#1234356).
- commit c8209d6
* Tue Dec 10 2024 ptesarik@suse.com
- config: rename x86_64 and arm64 default and debug config files
  Move default to rt and debug to rt_debug, adjusting CONFIG_LOCALVERSION
  accordingly. No other changes.
- commit 5e72780
* Tue Dec 10 2024 ptesarik@suse.com
- rpm/config.sh: Specify RT variant and livepatching
- commit daf200f
* Tue Dec 10 2024 mfranc@suse.cz
- s390/pci: Fix potential double remove of hotplug slot (git-fixes
  bsc#1234354).
- commit 7049f18
* Tue Dec 10 2024 mfranc@suse.cz
- s390/vfio-ap: Remove gmap_convert_to_secure() from vfio_ap_ops
  (git-fixes bsc#1234353).
- commit 474fbfd
* Tue Dec 10 2024 mfranc@suse.cz
- s390/stacktrace: Use break instead of return statement
  (git-fixes bsc#1234352).
- commit dae6da4
* Tue Dec 10 2024 mfranc@suse.cz
- s390/iucv: MSG_PEEK causes memory leak in iucv_sock_destruct()
  (git-fixes bsc#1234351).
- commit ac7d642
* Tue Dec 10 2024 mfranc@suse.cz
- iommu/s390: Implement blocking domain (git-fixes bsc#1234350).
- commit 6b9a77b
* Tue Dec 10 2024 mfranc@suse.cz
- s390/syscalls: Avoid creation of arch/arch/ directory (git-fixes
  bsc#1234349).
- commit 1f0d2c0
* Tue Dec 10 2024 mfranc@suse.cz
- s390/cpum_sf: Fix and protect memory allocation of SDBs with
  mutex (git-fixes bsc#1234348).
- commit 444f041
* Tue Dec 10 2024 mfranc@suse.cz
- s390/pageattr: Implement missing kernel_page_present()
  (git-fixes bsc#1234347).
- commit 3d52939
* Tue Dec 10 2024 mfranc@suse.cz
- s390/cio: Do not unregister the subchannel based on DNV
  (git-fixes bsc#1234346).
- commit 4347702
* Tue Dec 10 2024 mfranc@suse.cz
- s390/facilities: Fix warning about shadow of global variable
  (git-fixes bsc#1234345).
- commit 02f0405
* Tue Dec 10 2024 tiwai@suse.de
- drm/amdgpu: fix usage slab after free (stable-fixes).
- drm/amd/pm: Remove arcturus min power limit (stable-fixes).
- drm/amd/pm: skip setting the power source on smu v14.0.2/3
  (stable-fixes).
- drm/amd/pm: disable pcie speed switching on Intel platform
  for smu v14.0.2/3 (stable-fixes).
- drm/amdkfd: Use the correct wptr size (stable-fixes).
- drm/amdgpu/pm: add gen5 display to the user on smu v14.0.2/3
  (stable-fixes).
- drm/amd: Fix initialization mistake for NBIO 7.11 devices
  (stable-fixes).
- drm/amd/display: Remove PIPE_DTO_SRC_SEL programming from
  set_dtbclk_dto (stable-fixes).
- drm/amd/display: Fix handling of plane refcount (stable-fixes).
- drm/amd/display: update pipe selection policy to check head pipe
  (stable-fixes).
- drm/amd/pm: update current_socclk and current_uclk in
  gpu_metrics on smu v13.0.7 (stable-fixes).
- PCI: imx6: Fix suspend/resume support on i.MX6QDL
  (stable-fixes).
- drm/etnaviv: flush shader L1 cache after user commandstream
  (stable-fixes).
- Revert "drm/xe/xe_guc_ads: save/restore OA registers and
  allowlist regs" (git-fixes).
- drm/xe/xe_guc_ads: save/restore OA registers and allowlist regs
  (git-fixes).
- commit fd87388
* Tue Dec 10 2024 ailiop@suse.com
- fcntl: make F_DUPFD_QUERY associative (git-fixes).
- commit be385fd
* Tue Dec 10 2024 ailiop@suse.com
- fs: support relative paths with FSCONFIG_SET_STRING (git-fixes).
- commit ef5bd8a
* Tue Dec 10 2024 ailiop@suse.com
- hostfs: Fix the NULL vs IS_ERR() bug for __filemap_get_folio()
  (git-fixes).
- commit 5fd3bb3
* Tue Dec 10 2024 ailiop@suse.com
- erofs: handle NONHEAD !delta[1] lclusters gracefully
  (git-fixes).
- commit 813ea9e
* Tue Dec 10 2024 ailiop@suse.com
- erofs: fix blksize < PAGE_SIZE for file-backed mounts
  (git-fixes).
- commit b284b3f
* Tue Dec 10 2024 ailiop@suse.com
- erofs: fix file-backed mounts over FUSE (git-fixes).
- commit 7bf2dba
* Tue Dec 10 2024 ailiop@suse.com
- nfs/blocklayout: Limit repeat device registration on failure
  (git-fixes).
- commit 5b1e7a2
* Tue Dec 10 2024 ailiop@suse.com
- nfs/blocklayout: Don't attempt unregister for invalid block
  device (git-fixes).
- commit 8ad811d
* Tue Dec 10 2024 ailiop@suse.com
- sunrpc: fix one UAF issue caused by sunrpc kernel tcp socket
  (git-fixes).
- commit bd7fa6f
* Tue Dec 10 2024 ailiop@suse.com
- SUNRPC: timeout and cancel TLS handshake with -ETIMEDOUT
  (git-fixes).
- commit ee8bee6
* Tue Dec 10 2024 ailiop@suse.com
- sunrpc: clear XPRT_SOCK_UPD_TIMEOUT when reset transport
  (git-fixes).
- commit 897270b
* Tue Dec 10 2024 ailiop@suse.com
- nfs: ignore SB_RDONLY when mounting nfs (git-fixes).
- commit 99730eb
* Tue Dec 10 2024 ailiop@suse.com
- Revert "nfs: don't reuse partially completed requests in
  nfs_lock_and_join_requests" (git-fixes).
- commit 890cbd2
* Tue Dec 10 2024 ailiop@suse.com
- Revert "fs: nfs: fix missing refcnt by replacing
  folio_set_private by folio_attach_private" (git-fixes).
- commit e370dcb
* Tue Dec 10 2024 ailiop@suse.com
- nfs/localio: must clear res.replen in nfs_local_read_done
  (git-fixes).
- commit cad5bd8
* Tue Dec 10 2024 ailiop@suse.com
- NFSv4.0: Fix a use-after-free problem in the asynchronous open()
  (git-fixes).
- commit d12d418
* Tue Dec 10 2024 ailiop@suse.com
- nfs_common: must not hold RCU while calling nfsd_file_put_local
  (git-fixes).
- commit 5734a19
* Tue Dec 10 2024 ailiop@suse.com
- NFSD: Fix nfsd4_shutdown_copy() (git-fixes).
- commit ebfeeee
* Tue Dec 10 2024 ailiop@suse.com
- svcrdma: fix miss destroy percpu_counter in svc_rdma_proc_init()
  (git-fixes).
- commit 329fe63
* Tue Dec 10 2024 ailiop@suse.com
- nfsd: release svc_expkey/svc_export with rcu_work (git-fixes).
- commit 97e3dac
* Tue Dec 10 2024 ailiop@suse.com
- nfsd: make sure exp active before svc_export_show (git-fixes).
- commit a104268
* Tue Dec 10 2024 ailiop@suse.com
- NFSD: Cap the number of bytes copied by nfs4_reset_recoverydir()
  (git-fixes).
- commit 7f91920
* Tue Dec 10 2024 ailiop@suse.com
- NFSD: Prevent NULL dereference in nfsd4_process_cb_update()
  (git-fixes).
- commit aaee8d9
* Tue Dec 10 2024 ailiop@suse.com
- NFSD: Remove a never-true comparison (git-fixes).
- commit c224daa
* Tue Dec 10 2024 ailiop@suse.com
- nfsd: drop inode parameter from nfsd4_change_attribute()
  (git-fixes).
- commit dddb56b
* Tue Dec 10 2024 ailiop@suse.com
- svcrdma: Address an integer overflow (git-fixes).
- commit a27962f
* Mon Dec  9 2024 ailiop@suse.com
- xfs: remove unknown compat feature check in superblock write
  validation (git-fixes).
- commit 03498b6
* Mon Dec  9 2024 ailiop@suse.com
- xfs: fix chown with rt quota (git-fixes).
- commit df1beba
* Mon Dec  9 2024 ailiop@suse.com
- xfs: fix simplify extent lookup in xfs_can_free_eofblocks
  (git-fixes).
- commit 83617d6
* Mon Dec  9 2024 ailiop@suse.com
- xfs: sb_spino_align is not verified (git-fixes).
- commit 1d6b422
* Mon Dec  9 2024 ailiop@suse.com
- dlm: fix dlm_recover_members refcount on error (git-fixes).
- commit 32f05df
* Mon Dec  9 2024 ailiop@suse.com
- dlm: fix swapped args sb_flags vs sb_status (git-fixes).
- commit 8a26d75
* Mon Dec  9 2024 ailiop@suse.com
- exfat: fix file being changed by unaligned direct write
  (git-fixes).
- commit 5ecc480
* Mon Dec  9 2024 ailiop@suse.com
- config: remove all unsupported filesystems (jsc#PED-3637)
- supported.conf:
- Update config files.
- commit ef4af57
* Mon Dec  9 2024 ddiss@suse.de
- Update
  patches.suse/initramfs-avoid-filename-buffer-overrun.patch
  (CVE-2024-53142 bsc#1232436).
- commit b2d6f7d
* Mon Dec  9 2024 mgorman@suse.de
- sched/numa: fix memory leak due to the overwritten
  vma->numab_state (git fixes (sched/numa)).
- commit ebb11c8
* Mon Dec  9 2024 tiwai@suse.de
- irqchip/stm32mp-exti: CONFIG_STM32MP_EXTI should not default
  to y when compile-testing (git-fixes).
- iio: magnetometer: yas530: use signed integer type for clamp
  limits (git-fixes).
- scatterlist: fix incorrect func name in kernel-doc (git-fixes).
- kasan: make report_lock a raw spinlock (git-fixes).
- commit 5b25167
* Sat Dec  7 2024 tiwai@suse.de
- ASoC: Intel: avs: da7219: Remove suspend_pre() and resume_post()
  (stable-fixes).
- ALSA: hda/realtek: Fix spelling mistake "Firelfy" -> "Firefly"
  (git-fixes).
- ALSA: hda/realtek: fix micmute LEDs don't work on HP Laptops
  (stable-fixes).
- ALSA: usb-audio: Add extra PID for RME Digiface USB
  (stable-fixes).
- ALSA: hda/realtek: Add support for Samsung Galaxy Book3 360
  (NP730QFG) (stable-fixes).
- ALSA: hda/realtek: Enable mute and micmute LED on HP ProBook
  430 G8 (stable-fixes).
- ALSA: usb-audio: add mixer mapping for Corsair HS80
  (stable-fixes).
- ALSA: ump: Shut up truncated string warning (git-fixes).
- ALSA: sh: Use standard helper for buffer accesses
  (stable-fixes).
- ALSA: hda/conexant: fix Z60MR100 startup pop issue
  (stable-fixes).
- ALSA: ump: Update legacy substream names upon FB info update
  (stable-fixes).
- ALSA: ump: Indicate the inactive group in legacy substream names
  (stable-fixes).
- ALSA: ump: Don't open legacy substream for an inactive group
  (stable-fixes).
- commit 9157c44
* Sat Dec  7 2024 tiwai@suse.de
- drm/v3d: Enable Performance Counters before clearing them
  (git-fixes).
- drm/dp_mst: Fix resetting msg rx state after topology removal
  (git-fixes).
- drm/sti: Add __iomem for mixer_dbg_mxn's parameter (git-fixes).
- dma-fence: Use kernel's sort for merging fences (git-fixes).
- dma-fence: Fix reference leak on fence merge failure path
  (git-fixes).
- ASoC: mediatek: mt8188-mt6359: Remove hardcoded dmic codec
  (git-fixes).
- ASoC: SOF: ipc3-topology: fix resource leaks in
  sof_ipc3_widget_setup_comp_dai() (git-fixes).
- ALSA: usb-audio: Fix a DMA to stack memory bug (git-fixes).
- ALSA: hda/tas2781: Fix error code tas2781_read_acpi()
  (git-fixes).
- ALSA: usb-audio: Notify xrun for low-latency mode (git-fixes).
- ALSA: seq: ump: Fix seq port updates per FB info notify
  (git-fixes).
- regmap: detach regmap from dev on regmap_exit (git-fixes).
- spi: mpc52xx: Add cancel_work_sync before module remove
  (git-fixes).
- mmc: core: Further prevent card detect during shutdown
  (git-fixes).
- commit 9884b2e
* Fri Dec  6 2024 jbohac@suse.cz
- enable the disabled kdump-cma patchset
- Refresh patches.suse/kdump-add-crashkernel-cma-suffix.patch.
- Refresh
  patches.suse/kdump-crashkernel-cma-update-Documentation.patch.
- Refresh
  patches.suse/kdump-implement-reserve_crashkernel_cma.patch.
- Refresh
  patches.suse/kdump-wait-for-dma-to-time-out-when-using-cma.patch.
- Refresh
  patches.suse/kdump-x86-implement-crashkernel-cma-reservation.patch.
- commit c48df50
* Fri Dec  6 2024 tiwai@suse.de
- net: phy: microchip: Reset LAN88xx PHY to ensure clean link
  state on LAN7800/7850 (git-fixes).
- can: j1939: j1939_session_new(): fix skb reference counting
  (git-fixes).
- can: mcp251xfd: mcp251xfd_get_tef_len(): work around erratum
  DS80000789E 6 (git-fixes).
- can: f81604: f81604_handle_can_bus_errors(): fix {rx,tx}_errors
  statistics (git-fixes).
- can: ems_usb: ems_usb_rx_err(): fix {rx,tx}_errors statistics
  (git-fixes).
- can: sun4i_can: sun4i_can_err(): fix {rx,tx}_errors statistics
  (git-fixes).
- can: sja1000: sja1000_err(): fix {rx,tx}_errors statistics
  (git-fixes).
- can: hi311x: hi3110_can_ist(): fix {rx,tx}_errors statistics
  (git-fixes).
- can: ifi_canfd: ifi_canfd_handle_lec_err(): fix {rx,tx}_errors
  statistics (git-fixes).
- can: m_can: m_can_handle_lec_err(): fix {rx,tx}_errors
  statistics (git-fixes).
- can: hi311x: hi3110_can_ist(): fix potential use-after-free
  (git-fixes).
- can: sun4i_can: sun4i_can_err(): call can_change_state()
  even if cf is NULL (git-fixes).
- can: c_can: c_can_handle_bus_err(): update statistics if skb
  allocation fails (git-fixes).
- can: gs_usb: add usb endpoint address detection at driver
  probe step (git-fixes).
- can: dev: can_set_termination(): allow sleeping GPIOs
  (git-fixes).
- HID: wacom: fix when get product name maybe null pointer
  (git-fixes).
- HID: i2c-hid: Revert to using power commands to wake on resume
  (git-fixes).
- watchdog: rti: of: honor timeout-sec property (git-fixes).
- watchdog: mediatek: Make sure system reset gets asserted in
  mtk_wdt_restart() (git-fixes).
- Revert "watchdog: s3c2410_wdt: use
  exynos_get_pmu_regmap_by_phandle() for PMU regs" (stable-fixes).
- watchdog: apple: Actually flush writes after requesting watchdog
  restart (git-fixes).
- watchdog: xilinx_wwdt: Calculate max_hw_heartbeat_ms using
  clock frequency (git-fixes).
- iTCO_wdt: mask NMI_NOW bit for update_no_reboot_bit() call
  (git-fixes).
- platform/x86: asus-wmi: Ignore return value when writing
  thermal policy (git-fixes).
- irqchip/irq-mvebu-sei: Move misplaced select() callback to
  SEI CP domain (git-fixes).
- kbuild: deb-pkg: Don't fail if modules.order is missing
  (git-fixes).
- Revert "serial: sh-sci: Clean sci_ports[0] after at earlycon
  exit" (git-fixes).
- serial: 8250_fintek: Add support for F81216E (stable-fixes).
- serial: sh-sci: Clean sci_ports[0] after at earlycon exit
  (git-fixes).
- kfifo: don't include dma-mapping.h in kfifo.h (git-fixes).
- ASoC: amd: yc: Add a quirk for microfone on Lenovo ThinkPad
  P14s Gen 5 21MES00B00 (stable-fixes).
- counter: ti-ecap-capture: Add check for clk_enable()
  (git-fixes).
- counter: stm32-timer-cnt: Add check for clk_enable()
  (git-fixes).
- counter: stm32-timer-cnt: fix device_node handling in
  probe_encoder() (git-fixes).
- phy: airoha: Fix REG_CSR_2L_RX{0,1}_REV0 definitions
  (git-fixes).
- phy: airoha: Fix REG_CSR_2L_JCPLL_SDM_HREN config in
  airoha_pcie_phy_init_ssc_jcpll() (git-fixes).
- phy: airoha: Fix REG_PCIE_PMA_TX_RESET config in
  airoha_pcie_phy_init_csr_2l() (git-fixes).
- phy: airoha: Fix REG_CSR_2L_PLL_CMN_RESERVE0 config in
  airoha_pcie_phy_init_clk_out() (git-fixes).
- PCI: Fix use-after-free of slot->bus on hot remove
  (stable-fixes).
- clk: en7523: fix estimation of fixed rate for EN7581
  (git-fixes).
- clk: en7523: introduce chip_scu regmap (stable-fixes).
- clk: en7523: move clock_register in hw_init callback
  (stable-fixes).
- clk: en7523: remove REG_PCIE*_{MEM,MEM_MASK} configuration
  (stable-fixes).
- drm/panthor: Fix OPP refcnt leaks in devfreq initialisation
  (git-fixes).
- drm/amd/display: Reduce HPD Detection Interval for IPS
  (git-fixes).
- drm/amd/display: Increase idle worker HPD detection time
  (stable-fixes).
- drm/amd/display: Skip Invalid Streams from DSC Policy
  (stable-fixes).
- drm/amd/display: Fix incorrect DSC recompute trigger
  (stable-fixes).
- drm/panthor: record current and maximum device clock frequencies
  (stable-fixes).
- drm/panthor: introduce job cycle and timestamp accounting
  (stable-fixes).
- drm/vc4: hdmi: Increase audio MAI fifo dreq threshold
  (stable-fixes).
- Bluetooth: ISO: Send BIG Create Sync via hci_sync (git-fixes).
- Bluetooth: ISO: Do not emit LE BIG Create Sync if previous is
  pending (stable-fixes).
- Bluetooth: ISO: Do not emit LE PA Create Sync if previous is
  pending (stable-fixes).
- Bluetooth: Fix type of len in rfcomm_sock_getsockopt{,_old}()
  (stable-fixes).
- Bluetooth: btintel: Do no pass vendor events to stack
  (git-fixes).
- Bluetooth: btintel_pcie: Add handshake between driver and
  firmware (stable-fixes).
- wifi: rtlwifi: Drastically reduce the attempts to read efuse
  in case of failures (stable-fixes).
- wifi: rtw89: unlock on error path in
  rtw89_ops_unassign_vif_chanctx() (git-fixes).
- wifi: rtw89: Fix TX fail with A2DP after scanning (git-fixes).
- wifi: iwlwifi: mvm: tell iwlmei when we finished suspending
  (git-fixes).
- wifi: iwlwifi: allow fast resume on ax200 (stable-fixes).
- wifi: rtw89: tweak driver architecture for impending MLO support
  (stable-fixes).
- wifi: rtw89: refactor STA related func ahead for MLO
  (stable-fixes).
- wifi: rtw89: refactor VIF related func ahead for MLO
  (stable-fixes).
- wifi: rtw89: read link_sta corresponding to the link
  (stable-fixes).
- wifi: rtw89: read bss_conf corresponding to the link
  (stable-fixes).
- wifi: rtw89: rename rtw89_sta to rtw89_sta_link ahead for MLO
  (stable-fixes).
- wifi: rtw89: rename rtw89_vif to rtw89_vif_link ahead for MLO
  (stable-fixes).
- netdevsim: copy addresses for both in and out paths (git-fixes).
- docs: media: update location of the media patches
  (stable-fixes).
- media: ipu6: not override the dma_ops of device in driver
  (git-fixes).
- media: ipu6: Fix DMA and physical address debugging messages
  for 32-bit (stable-fixes).
- clocksource/drivers/timer-ti-dm: Fix child node refcount
  handling (git-fixes).
- clocksource/drivers:sp804: Make user selectable (git-fixes).
- irqchip/riscv-aplic: Prevent crash when MSI domain is missing
  (git-fixes).
- thermal: testing: Initialize some variables annoteded with
  _free() (git-fixes).
- thermal: testing: Use DEFINE_FREE() and __free() to simplify
  code (stable-fixes).
- thermal: core: Fix race between zone registration and system
  suspend (git-fixes).
- thermal: core: Mark thermal zones as initializing to start with
  (git-fixes).
- thermal: core: Represent suspend-related thermal zone flags
  as bits (stable-fixes).
- thermal: core: Rearrange PM notification code (stable-fixes).
- commit 5990dcc
* Thu Dec  5 2024 msuchanek@suse.de
- powerpc/fadump: Move fadump_cma_init to setup_arch() after
  initmem_init() (bsc#1215199).
- powerpc/fadump: Refactor and prepare fadump_cma_init for late
  init (bsc#1215199).
- commit 1188346
* Thu Dec  5 2024 msuchanek@suse.de
- powerpc/kexec: Fix return of uninitialized variable
  (bsc#1194869).
- powerpc/sstep: make emulate_vsx_load and emulate_vsx_store
  static (bsc#1194869).
- powerpc/pseries: Fix KVM guest detection for disabling
  hardlockup detector (bsc#1194869).
- powerpc/pseries: Fix dtl_access_lock to be a rw_semaphore
  (bsc#1194869).
- powerpc/mm/fault: Fix kfence page fault reporting (bsc#1194869).
- commit b6fdd1f
* Thu Dec  5 2024 oneukum@suse.com
- Refresh patches.suse/0001-typeC-add-kABI-padding.patch.
- Refresh
  patches.suse/0002-Add-a-void-suse_kabi_padding-placeholder-to-some-USB.patch.
- Refresh
  patches.suse/new-paddings-for-the-new-features-of-TB.patch.
- Refresh patches.suse/padding-XHCI-additional-padding.patch.
- Refresh patches.suse/padding-ehci-core-structures.patch.
- Refresh patches.suse/padding-ohci-core-structure-padding.patch.
- Refresh patches.suse/paddings-add-paddings-to-TypeC-stuff.patch.
- Refresh patches.suse/paddings-for-gadgets.patch.
- commit 1d5b9ca
* Thu Dec  5 2024 iivanov@suse.de
- bpf, arm64: Remove garbage frame for struct_ops trampoline (git-fixes)
- commit f62ac09
* Thu Dec  5 2024 iivanov@suse.de
- arm64: dts: rockchip: correct analog audio name on Indiedroid Nova (git-fixes)
- commit f3d03a2
* Thu Dec  5 2024 iivanov@suse.de
- arm64: dts: allwinner: pinephone: Add mount matrix to accelerometer (git-fixes)
- commit 8c31355
* Thu Dec  5 2024 iivanov@suse.de
- arm64: dts: freescale: imx8mp-verdin: Fix SD regulator startup delay (git-fixes)
- commit 39fac3d
* Thu Dec  5 2024 iivanov@suse.de
- arm64: dts: freescale: imx8mm-verdin: Fix SD regulator startup delay (git-fixes)
- commit e7350ce
* Thu Dec  5 2024 iivanov@suse.de
- arm64: dts: imx8mn-tqma8mqnl-mba8mx-usbot: fix coexistence of (git-fixes)
- commit bf28c10
* Thu Dec  5 2024 iivanov@suse.de
- arm64: dts: rockchip: Remove 'enable-active-low' from two boards (git-fixes)
- commit a573b02
* Thu Dec  5 2024 iivanov@suse.de
- arm64: dts: rockchip: pwm-leds for Orange Pi 5 (git-fixes)
- commit 7d2d085
* Thu Dec  5 2024 iivanov@suse.de
- arm64: tegra: p2180: Add mandatory compatible for WiFi node (git-fixes)
- commit d9c39de
* Thu Dec  5 2024 iivanov@suse.de
- arm64: probes: Disable kprobes/uprobes on MOPS instructions (git-fixes)
- commit 1d64594
* Thu Dec  5 2024 iivanov@suse.de
- arm64: tls: Fix context-switching of tpidrro_el0 when kpti is enabled (git-fixes)
- commit 8da52a4
* Thu Dec  5 2024 iivanov@suse.de
- arm64: fix .data.rel.ro size assertion when CONFIG_LTO_CLANG (git-fixes)
- commit bacb7d4
* Thu Dec  5 2024 iivanov@suse.de
- arm64: Expose ID_AA64ISAR1_EL1.XS to sanitised feature consumers (git-fixes)
- commit 43f6bc3
* Wed Dec  4 2024 ohering@suse.de
- hv_sock: Initializing vsk->trans to NULL to prevent a dangling
  pointer (git-fixes).
- HID: hyperv: streamline driver probe to avoid devres issues
  (git-fixes).
- commit ee23739
* Wed Dec  4 2024 ohering@suse.de
- hyperv: keep generate_guest_id (bsc#1189965).
- commit ec2fbf8
* Tue Dec  3 2024 mhocko@suse.com
- Update
  patches.suse/media-uvcvideo-Skip-parsing-frames-of-type-UVC_VS_UN.patch
  (git-fixes CVE-2024-53104 bsc#1234025).
- commit 381f9fa
* Tue Dec  3 2024 mkoutny@suse.com
- config.sh: Update Bugzilla product
- commit 5d4ad4d
* Tue Dec  3 2024 mkoutny@suse.com
- cgroup/bpf: only cgroup v2 can be attached by bpf programs
  (bsc#1234108).
- Revert "cgroup: Fix memory leak caused by missing
  cgroup_bpf_offline" (bsc#1234108).
- commit 440fba7
* Tue Dec  3 2024 tiwai@suse.de
- kernel-doc: allow object-like macros in ReST output (git-fixes).
- commit 58f47a6
* Tue Dec  3 2024 tiwai@suse.de
- checkpatch: always parse orig_commit in fixes tag (git-fixes).
- accel/ivpu: Prevent recovery invocation during probe and resume
  (git-fixes).
- cleanup: Remove address space of returned pointer (git-fixes).
- commit 9e46c4d
* Mon Dec  2 2024 jack@suse.cz
- fs/file.c: add fast path in find_next_fd() (jsc#PED-10666).
- commit 408b57f
* Mon Dec  2 2024 jack@suse.cz
- fs/file.c: conditionally clear full_fds (jsc#PED-10666).
- commit 26a9b57
* Mon Dec  2 2024 jack@suse.cz
- fs/file.c: remove sanity_check and add likely/unlikely in
  alloc_fd() (jsc#PED-10666).
- commit 5da9b0b
* Mon Dec  2 2024 dwagner@suse.de
- nvme-fabrics: fix kernel crash while shutting down controller
  (git-fixes).
- Revert "nvme: make keep-alive synchronous operation"
  (git-fixes).
- nvme/multipath: Fix RCU list traversal to use SRCU primitive
  (git-fixes).
- nvme-pci: reverse request order in nvme_queue_rqs (git-fixes).
- nvme-pci: fix freeing of the HMB descriptor table (git-fixes).
- commit 534c003
* Mon Dec  2 2024 dwagner@suse.de
- scsi: lpfc: Copyright updates for 14.4.0.6 patches (bsc#1233241
  jsc#PED-10904).
- scsi: lpfc: Update lpfc version to 14.4.0.6 (bsc#1233241
  jsc#PED-10904).
- scsi: lpfc: Change lpfc_nodelist nlp_flag member into a bitmask
  (bsc#1233241 jsc#PED-10904).
- scsi: lpfc: Remove NLP_RELEASE_RPI flag from nodelist structure
  (bsc#1233241 jsc#PED-10904).
- scsi: lpfc: Prevent NDLP reference count underflow in
  dev_loss_tmo callback (bsc#1233241 jsc#PED-10904).
- scsi: lpfc: Add cleanup of nvmels_wq after HBA reset
  (bsc#1233241 jsc#PED-10904).
- scsi: lpfc: Check SLI_ACTIVE flag in FDMI cmpl before submitting
  follow up FDMI (bsc#1233241 jsc#PED-10904).
- scsi: lpfc: Update lpfc_els_flush_cmd() to check for SLI_ACTIVE
  before BSG flag (bsc#1233241 jsc#PED-10904).
- scsi: lpfc: Call lpfc_sli4_queue_unset() in restart and rmmod
  paths (bsc#1233241 jsc#PED-10904).
- scsi: lpfc: Check devloss callbk done flag for potential stale
  NDLP ptrs (bsc#1233241 jsc#PED-10904).
- scsi: lpfc: Modify CGN warning signal calculation based on
  EDC response (bsc#1233241 jsc#PED-10904).
- commit 954c8fe
* Mon Dec  2 2024 mkoutny@suse.com
- Refresh patches.suse/kabi-Add-placeholders-to-a-couple-of-important-struc.patch
- refreshed contexts
- mm_struct: taken out of randomized substruct
- sock: moved from middle to the end
- commit 12002b5
* Mon Dec  2 2024 jslaby@suse.cz
- PCI/pwrctl: Ensure that pwrctl drivers are probed before PCI
  client drivers (git-fixes).
- PCI/pwrctl: Create pwrctl device only if at least one power
  supply is present (git-fixes).
- PCI/pwrctl: Use of_platform_device_create() to create pwrctl
  devices (git-fixes).
- commit 5ac4fb1
* Sun Dec  1 2024 tiwai@suse.de
- serial: amba-pl011: fix build regression (git-fixes).
- commit e7439f2
* Sun Dec  1 2024 tiwai@suse.de
- tools/power turbostat: Fix child's argument forwarding
  (git-fixes).
- tools/power turbostat: Fix trailing '\n' parsing (git-fixes).
- modpost: remove incorrect code in do_eisa_entry() (git-fixes).
- Rename .data.once to .data..once to fix resetting WARN*_ONCE
  (git-fixes).
- Rename .data.unlikely to .data..unlikely (git-fixes).
- rtc: ab-eoz9: don't fail temperature reads on undervoltage
  notification (git-fixes).
- rtc: rzn1: fix BCD to rtc_time conversion errors (git-fixes).
- rtc: check if __rtc_read_time was successful in
  rtc_timer_do_work() (git-fixes).
- rtc: abx80x: Fix WDT bit position of the status register
  (git-fixes).
- rtc: bbnsm: add remove hook (git-fixes).
- rtc: st-lpc: Use IRQF_NO_AUTOEN flag in request_irq()
  (git-fixes).
- mtd: ubi: fix unreleased fwnode_handle in find_volume_fwnode()
  (git-fixes).
- serial: amba-pl011: Fix RX stall when DMA is used (git-fixes).
- tty: ldsic: fix tty_ldisc_autoload sysctl's proc_handler
  (git-fixes).
- serial: 8250: omap: Move pm_runtime_get_sync (git-fixes).
- commit c7930d4
* Sat Nov 30 2024 tiwai@suse.de
- USB: chaoskey: Fix possible deadlock chaoskey_list_lock
  (git-fixes).
- commit 3c5d214
* Sat Nov 30 2024 tiwai@suse.de
- ALSA: hda: improve bass speaker support for ASUS Zenbook
  UM5606WA (stable-fixes).
- ALSA: hda/realtek: Apply quirk for Medion E15433 (stable-fixes).
- ALSA: hda: Show the codec quirk info at probing (stable-fixes).
- ALSA: hda/realtek: Set PCBeep to default value for ALC274
  (stable-fixes).
- ALSA: hda/tas2781: Add speaker id check for ASUS projects
  (stable-fixes).
- ALSA: hda/realtek: Enable speaker pins for Medion E15443
  platform (stable-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs don't work for
  EliteBook X G1i (stable-fixes).
- ALSA: usb-audio: Fix out of bounds reads when finding clock
  sources (stable-fixes).
- ALSA: hda/realtek: Fix Internal Speaker and Mic boost of
  Infinix Y4 Max (stable-fixes).
- ALSA: pcm: Add sanity NULL check for the default mmap fault
  handler (stable-fixes).
- ALSA: hda: Poll jack events for LS7A HD-Audio (stable-fixes).
- ALSA: usb-audio: Make mic volume workarounds globally applicable
  (stable-fixes).
- ALSA: usb-audio: Add Pioneer DJ/AlphaTheta DJM-A9 Mixer
  (stable-fixes).
- ALSA: hda: Fix build error without CONFIG_SND_DEBUG (git-fixes).
- ALSA: usb-audio: Use snprintf instead of sprintf in
  build_mixer_unit_ctl (stable-fixes).
- ALSA: hda/realtek: Use codec SSID matching for Lenovo devices
  (stable-fixes).
- ALSA: hda/conexant: Use the new codec SSID matching
  (stable-fixes).
- ALSA: hda: Use own quirk lookup helper (stable-fixes).
- commit 0775b0e
* Sat Nov 30 2024 tiwai@suse.de
- interconnect: qcom: icc-rpmh: probe defer incase of missing
  QoS clock dependency (git-fixes).
- iio: adc: pac1921: Check for error code from devm_mutex_init()
  call (git-fixes).
- iio: adc: ad4000: Check for error code from devm_mutex_init()
  call (git-fixes).
- iio: accel: kxcjk-1013: Revert "Add support for KX022-1020"
  (git-fixes).
- =?UTF-8?q?iio:=20accel:=20kxcjk-1013:=20Remove=20redundan?=
  =?UTF-8?q?t=20I=C2=B2C=20ID?= (git-fixes).
- iio: Fix fwnode_handle in __fwnode_iio_channel_get_by_name()
  (git-fixes).
- iio: accel: adxl380: fix raw sample read (git-fixes).
- iio: accel: kx022a: Fix raw read format (git-fixes).
- iio: gts: fix infinite loop for gain_to_scaletables()
  (git-fixes).
- iio: gts: Fix uninitialized symbol 'ret' (git-fixes).
- iio: adc: ad4000: fix reading unsigned data (git-fixes).
- iio: adc: ad7923: Fix buffer overflow for tx_buf and ring_xfer
  (git-fixes).
- iio: backend: fix wrong pointer passed to IS_ERR() (git-fixes).
- iio: invensense: fix multiple odr switch when FIFO is off
  (git-fixes).
- goldfish: Fix unused const variable 'goldfish_pipe_acpi_match'
  (git-fixes).
- misc: rtsx: Cleanup on DRV_NAME cardreader variables
  (git-fixes).
- iio: dac: adi-axi-dac: fix wrong register bitfield (git-fixes).
- iio: adc: ad7606: Fix typo in the driver name (git-fixes).
- iio: light: al3010: Fix an error handling path in al3010_probe()
  (git-fixes).
- misc: apds990x: Fix missing pm_runtime_disable() (git-fixes).
- staging: vchiq_arm: Fix missing refcount decrement in error
  path for fw_node (git-fixes).
- usb: dwc3: gadget: Fix looping of queued SG entries (git-fixes).
- usb: dwc3: gadget: Fix checking for number of TRBs left
  (git-fixes).
- usb: dwc3: ep0: Don't clear ep0 DWC3_EP_TRANSFER_STARTED
  (git-fixes).
- Revert "usb: gadget: composite: fix OS descriptors w_value
  logic" (git-fixes).
- usb: ehci-spear: fix call balance of sehci clk handling routines
  (git-fixes).
- USB: serial: ftdi_sio: Fix atomicity violation in
  get_serial_info() (git-fixes).
- usb: dwc3: gadget: Add missing check for single port RAM in
  TxFIFO resizing logic (git-fixes).
- usb: typec: fix potential array underflow in
  ucsi_ccg_sync_control() (git-fixes).
- usb: misc: ljca: set small runtime autosuspend delay
  (git-fixes).
- usb: misc: ljca: move usb_autopm_put_interface() after wait
  for response (git-fixes).
- usb: musb: Fix hardware lockup on first Rx endpoint request
  (git-fixes).
- usb: typec: ucsi: glink: fix off-by-one in connector_status
  (git-fixes).
- usb: xhci: Fix TD invalidation under pending Set TR Dequeue
  (git-fixes).
- usb: xhci: Limit Stop Endpoint retries (git-fixes).
- xhci: Don't perform Soft Retry for Etron xHCI host (git-fixes).
- xhci: Fix control transfer error on Etron xHCI host (git-fixes).
- xhci: Don't issue Reset Device command to Etron xHCI host
  (git-fixes).
- xhci: Combine two if statements for Etron xHCI host (git-fixes).
- phy: realtek: usb: fix NULL deref in rtk_usb3phy_probe
  (git-fixes).
- phy: realtek: usb: fix NULL deref in rtk_usb2phy_probe
  (git-fixes).
- usb: gadget: uvc: wake pump everytime we update the free list
  (git-fixes).
- USB: chaoskey: fail open after removal (git-fixes).
- usb: yurex: make waiting on yurex_write interruptible
  (git-fixes).
- usb: using mutex lock and supporting O_NONBLOCK flag in
  iowarrior_read() (git-fixes).
- net: mdio-ipq4019: add missing error check (git-fixes).
- commit 251ecb2
* Sat Nov 30 2024 tiwai@suse.de
- drm/xe/migrate: use XE_BO_FLAG_PAGETABLE (git-fixes).
- drm/xe/migrate: fix pat index usage (git-fixes).
- drm/xe/guc_submit: fix race around suspend_pending (git-fixes).
- Revert "drm/radeon: Delay Connector detecting when HPD singals
  is unstable" (stable-fixes).
- drm/amd/display: Fix null check for pipe_ctx->plane_state in
  hwss_setup_dpp (git-fixes).
- drm/amd/display: Fix null check for pipe_ctx->plane_state in
  dcn20_program_pipe (git-fixes).
- drm/radeon: Fix spurious unplug event on radeon HDMI
  (git-fixes).
- drm/amd: Add some missing straps from NBIO 7.11.0 (git-fixes).
- drm/xe: Mark preempt fence workqueue as reclaim (git-fixes).
- drm/xe/ufence: Wake up waiters after setting ufence->signalled
  (git-fixes).
- ASoC: SOF: ipc3-topology: Convert the topology pin index to
  ALH dai index (git-fixes).
- ASoC: mediatek: Check num_codecs is not zero to avoid panic
  during probe (git-fixes).
- ASoC: amd: yc: Fix for enabling DMIC on acp6x via _DSD entry
  (git-fixes).
- ASoC: imx-audmix: Add NULL check in imx_audmix_probe
  (git-fixes).
- ALSA: ump: Fix evaluation of MIDI 1.0 FB info (git-fixes).
- ALSA: core: Fix possible NULL dereference caused by
  kunit_kzalloc() (git-fixes).
- ALSA: hda/realtek: Update ALC225 depop procedure (git-fixes).
- ALSA: rawmidi: Fix kvfree() call in spinlock (git-fixes).
- ALSA: usb-audio: Fix potential out-of-bound accesses for Extigy
  and Mbox devices (git-fixes).
- ALSA: hda/realtek: Update ALC256 depop procedure (git-fixes).
- ALSA: ac97: bus: Fix the mistake in the comment (git-fixes).
- bus: mhi: host: Switch trace_mhi_gen_tre fields to native endian
  (git-fixes).
- ad7780: fix division by zero in ad7780_write_raw() (git-fixes).
- comedi: Flush partial mappings in error case (git-fixes).
- firmware_loader: Fix possible resource leak in
  fw_log_firmware_info() (git-fixes).
- driver core: fw_devlink: Stop trying to optimize cycle detection
  logic (git-fixes).
- devres: Fix page faults when tracing devres from unloaded
  modules (git-fixes).
- apparmor: fix 'Do simple duplicate message elimination'
  (git-fixes).
- apparmor: test: Fix memory leak for aa_unpack_strdup()
  (git-fixes).
- commit 62cfe63
* Fri Nov 29 2024 ykaukab@suse.de
- SLE16: supported.conf: arm64: fix more split-modules errors
  Following errors are fixed:
  [ 6207s] The following optional modules are used by extra modules:
  [ 6207s] industrialio_hw_consumer needed by stm32_adfsdm
  [ 6207s] industrialio_hw_consumer needed by stm32_dfsdm_adc
  [ 6207s] stm32_dfsdm_adc needed by stm32_adfsdm
  [ 6207s] stm32_dfsdm_core needed by stm32_adfsdm
  [ 6207s] stm32_dfsdm_core needed by stm32_dfsdm_adc
  [ 6207s] stm32_lptimer_trigger needed by stm32_adfsdm
  [ 6207s] stm32_lptimer_trigger needed by stm32_dfsdm_adc
  [ 6207s] stm32_timer_trigger needed by stm32_adfsdm
  [ 6207s] stm32_timer_trigger needed by stm32_dfsdm_adc
- commit 1bedf5a
* Fri Nov 29 2024 tiwai@suse.de
- cpufreq: CPPC: Fix wrong return value in cppc_get_cpu_power()
  (git-fixes).
- cpufreq: CPPC: Fix wrong return value in cppc_get_cpu_cost()
  (git-fixes).
- drm/vc4: Match drm_dev_enter and exit calls in vc4_hvs_lut_load
  (git-fixes).
- commit a70686d
* Fri Nov 29 2024 ykaukab@suse.de
- SLE16: supported.conf: arm64: fix split-modules errors
  Fix following errors:
  [ 6849s] The following optional modules are used by extra modules:
  [ 6849s] ad_sigma_delta needed by ad7173
  [ 6849s] bmi088_accel_core needed by bmi088_accel_i2c
  [ 6849s] clk_qcom needed by camcc_sc8280xp
  [ 6849s] clk_qcom needed by camcc_sm4450
  [ 6849s] clk_qcom needed by camcc_sm7150
  [ 6849s] clk_qcom needed by camcc_sm8150
  [ 6849s] clk_qcom needed by camcc_sm8650
  [ 6849s] clk_qcom needed by camcc_x1e80100
  [ 6849s] clk_qcom needed by dispcc_sm4450
  [ 6849s] clk_qcom needed by dispcc_sm7150
  [ 6849s] clk_qcom needed by dispcc_x1e80100
  [ 6849s] clk_qcom needed by ecpricc_qdu1000
  [ 6849s] clk_qcom needed by gcc_ipq5018
  [ 6849s] clk_qcom needed by gcc_sdx75
  [ 6849s] clk_qcom needed by gcc_sm4450
  [ 6849s] clk_qcom needed by gcc_sm8650
  [ 6849s] clk_qcom needed by gcc_x1e80100
  [ 6849s] clk_qcom needed by gpucc_qcm2290
  [ 6849s] clk_qcom needed by gpucc_sm4450
  [ 6849s] clk_qcom needed by gpucc_sm8450
  [ 6849s] clk_qcom needed by gpucc_sm8550
  [ 6849s] clk_qcom needed by gpucc_sm8650
  [ 6849s] clk_qcom needed by gpucc_x1e80100
  [ 6849s] clk_qcom needed by lpasscc_sc8280xp
  [ 6849s] clk_qcom needed by nsscc_qca8k
  [ 6849s] clk_qcom needed by tcsrcc_sm8650
  [ 6849s] clk_qcom needed by tcsrcc_x1e80100
  [ 6849s] clk_qcom needed by videocc_sm7150
  [ 6849s] clk_qcom needed by videocc_sm8350
  [ 6849s] clk_qcom needed by videocc_sm8450
  [ 6849s] clk_qcom needed by videocc_sm8550
  [ 6849s] ecc_mtk needed by spi_mtk_snfi
  [ 6849s] industrialio_buffer_dma needed by adi_axi_dac
  [ 6849s] industrialio_buffer_dma needed by industrialio_buffer_dmaengine
  [ 6849s] industrialio_buffer_dmaengine needed by adi_axi_dac
  [ 6849s] industrialio_hw_consumer needed by stm32_adfsdm
  [ 6849s] industrialio_hw_consumer needed by stm32_dfsdm_adc
  [ 6849s] pinctrl_lpass_lpi needed by pinctrl_sm4250_lpass_lpi
  [ 6849s] pinctrl_lpass_lpi needed by pinctrl_sm6115_lpass_lpi
  [ 6849s] pinctrl_lpass_lpi needed by pinctrl_sm8350_lpass_lpi
  [ 6849s] pinctrl_lpass_lpi needed by pinctrl_sm8650_lpass_lpi
  [ 6849s] rcar_fcp needed by rcar_du_drm
  [ 6849s] rcar_fcp needed by rzg2l_du_drm
  [ 6849s] rcar_fcp needed by vsp1
  [ 6849s] v4l2_mem2mem needed by stm32_dma2d
  [ 6849s] vsp1 needed by rcar_du_drm
  [ 6849s] vsp1 needed by rzg2l_du_drm
  Mark all new iio modules as optional
- commit d15d3ea
* Fri Nov 29 2024 tiwai@suse.de
- clk: mediatek: drop two dead config options (git-fixes).
- Update config files.
- commit 720e07f
* Fri Nov 29 2024 tiwai@suse.de
- power: sequencing: make the QCom PMU pwrseq driver depend on
  CONFIG_OF (git-fixes).
- Update config files.
- commit 3044556
* Fri Nov 29 2024 tiwai@suse.de
- drm/fbdev-dma: Select FB_DEFERRED_IO (git-fixes).
- Update config files.
- commit 9b9fb95
* Fri Nov 29 2024 tiwai@suse.de
- drm/panic: allow verbose version check (git-fixes).
- drm/panic: allow verbose boolean for clarity (git-fixes).
- drm/panic: correctly indent continuation of line in list item
  (git-fixes).
- drm/panic: remove redundant field when assigning value
  (git-fixes).
- drm/panic: prefer eliding lifetimes (git-fixes).
- drm/panic: remove unnecessary borrow in alignment_pattern
  (git-fixes).
- drm/panic: avoid reimplementing Iterator::find (git-fixes).
- fbdev: sh7760fb: Fix a possible memory leak in
  sh7760fb_alloc_mem() (git-fixes).
- drm/amdkfd: Fix wrong usage of INIT_WORK() (git-fixes).
- drm/amdgpu: Fix map/unmap queue logic (git-fixes).
- drm/amdgpu: fix ACA bank count boundary check error (git-fixes).
- drm/panfrost: Add missing OPP table refcnt decremental
  (git-fixes).
- drm: use ATOMIC64_INIT() for atomic64_t (git-fixes).
- drm/bridge: it6505: Fix inverted reset polarity (git-fixes).
- drm/vkms: Drop unnecessary call to drm_crtc_cleanup()
  (git-fixes).
- drm/etnaviv: hold GPU lock across perfmon sampling (git-fixes).
- drm/etnaviv: Request pages from DMA32 zone on addressing_limited
  (git-fixes).
- drm/amdkfd: Use dynamic allocation for CU occupancy array in
  'kfd_get_cu_occupancy()' (git-fixes).
- drm/amdgpu: fix comment about amdgpu.abmlevel defaults
  (git-fixes).
- drm/amdgpu: Fix the memory allocation issue in
  amdgpu_discovery_get_nps_info() (git-fixes).
- drm/msm/dpu: cast crtc_clk calculation to u64 in
  _dpu_core_perf_calc_clk() (git-fixes).
- drm/xe/hdcp: Fix gsc structure check in fw check status
  (git-fixes).
- drm/mediatek: Fix child node refcount handling in early exit
  (git-fixes).
- drm/msm/gpu: Check the status of registration to PM QoS
  (git-fixes).
- drm/msm/adreno: Use IRQF_NO_AUTOEN flag in request_irq()
  (git-fixes).
- drm/msm: Fix some typos in comment (git-fixes).
- drm/msm/dpu: drop LM_3 / LM_4 on MSM8998 (git-fixes).
- drm/msm/dpu: drop LM_3 / LM_4 on SDM845 (git-fixes).
- drm/msm/dpu: on SDM845 move DSPP_3 to LM_5 block (git-fixes).
- drm: xlnx: zynqmp_dpsub: fix hotplug detection (git-fixes).
- drm: xlnx: zynqmp_disp: layer may be null while releasing
  (git-fixes).
- drm: zynqmp_kms: Unplug DRM device before removal (git-fixes).
- drm/nouveau/gr/gf100: Fix missing unlock in gf100_gr_chan_new()
  (git-fixes).
- drm/panfrost: Remove unused id_mask from struct panfrost_model
  (git-fixes).
- drm: panel: nv3052c: correct spi_device_id for RG35XX panel
  (git-fixes).
- Revert "drm/amdgpu/gfx9: put queue resets behind a debug option"
  (stable-fixes).
- drm/amd/display: fix a memleak issue when driver is removed
  (git-fixes).
- drm/amdgpu/gfx9: Add Cleaner Shader Deinitialization in gfx_v9_0
  Module (git-fixes).
- drm/amdgpu: Fix JPEG v4.0.3 register write (git-fixes).
- drm/panic: Select ZLIB_DEFLATE for DRM_PANIC_SCREEN_QR_CODE
  (git-fixes).
- drm/bridge: tc358767: Fix link properties discovery (git-fixes).
- drm/vc4: Match drm_dev_enter and exit calls in
  vc4_hvs_atomic_flush (git-fixes).
- drm: panel: jd9365da-h3: Remove unused num_init_cmds structure
  member (git-fixes).
- drm/bridge: it6505: Drop EDID cache on bridge power off
  (git-fixes).
- drm/bridge: anx7625: Drop EDID cache on bridge power off
  (git-fixes).
- drm/v3d: Flush the MMU before we supply more memory to the
  binner (git-fixes).
- drm/v3d: Address race-condition in MMU flush (git-fixes).
- drm/sti: avoid potential dereference of error pointers
  (git-fixes).
- drm/sti: avoid potential dereference of error pointers in
  sti_gdp_atomic_check (git-fixes).
- drm/sti: avoid potential dereference of error pointers in
  sti_hqvdp_atomic_check (git-fixes).
- drm/panel: nt35510: Make new commands optional (git-fixes).
- drm/imx/ipuv3: Use IRQF_NO_AUTOEN flag in request_irq()
  (git-fixes).
- drm/imx/dcss: Use IRQF_NO_AUTOEN flag in request_irq()
  (git-fixes).
- drm/panic: Fix uninitialized spinlock acquisition with
  CONFIG_DRM_PANIC=n (git-fixes).
- drm/v3d: Appease lockdep while updating GPU stats (git-fixes).
- drm/omap: Fix locking in omap_gem_new_dmabuf() (git-fixes).
- drm/omap: Fix possible NULL dereference (git-fixes).
- drm/vc4: hvs: Correct logic on stopping an HVS channel
  (git-fixes).
- drm/vc4: hvs: Remove incorrect limit from hvs_dlist debugfs
  function (git-fixes).
- drm/vc4: hvs: Fix dlist debug not resetting the next entry
  pointer (git-fixes).
- drm/vc4: hdmi: Avoid hang with debug registers when suspended
  (git-fixes).
- drm/vc4: hvs: Don't write gamma luts on 2711 (git-fixes).
- drm/mm: Mark drm_mm_interval_tree*() functions with
  __maybe_unused (git-fixes).
- drm/imagination: Use pvr_vm_context_get() (git-fixes).
- drm/imagination: Convert to use time_before macro (git-fixes).
- commit febdd50
* Fri Nov 29 2024 tiwai@suse.de
- spi: Fix acpi deferred irq probe (git-fixes).
- spi: atmel-quadspi: Fix register name in verbose logging
  function (git-fixes).
- thermal: int3400: Fix reading of current_uuid for active policy
  (git-fixes).
- remoteproc: qcom_q6v5_mss: Re-order writes to the IMEM region
  (git-fixes).
- remoteproc: qcom_q6v5_pas: disable auto boot for wpss
  (git-fixes).
- remoteproc: qcom: pas: add minidump_id to SM8350 resources
  (git-fixes).
- remoteproc: qcom: adsp: Remove subdevs on the error path of
  adsp_probe() (git-fixes).
- remoteproc: qcom: pas: Remove subdevs on the error path of
  adsp_probe() (git-fixes).
- scatterlist: fix a typo (git-fixes).
- unicode: Fix utf8_load() error path (git-fixes).
- Revert "wifi: iwlegacy: do not skip frames with bad FCS"
  (git-fixes).
- wifi: brcmfmac: release 'root' node in all execution paths
  (git-fixes).
- wifi: rtw89: coex: check NULL return of kmalloc in
  btc_fw_set_monreg() (git-fixes).
- wifi: nl80211: fix bounds checker error in
  nl80211_parse_sched_scan (git-fixes).
- wifi: cfg80211: Remove the Medium Synchronization Delay validity
  check (git-fixes).
- wifi: cw1200: Fix potential NULL dereference (git-fixes).
- wifi: wfx: Fix error handling in wfx_core_init() (git-fixes).
- wifi: ath12k: fix warning when unbinding (git-fixes).
- wifi: ath12k: fix crash when unbinding (git-fixes).
- wifi: ath12k: remove msdu_end structure for WCN7850 (git-fixes).
- wifi: ath11k: Fix CE offset address calculation for WCN6750
  in SSR (git-fixes).
- wifi: ath12k: fix one more memcpy size error (git-fixes).
- wifi: ath12k: fix use-after-free in ath12k_dp_cc_cleanup()
  (git-fixes).
- wifi: ath12k: Skip Rx TID cleanup for self peer (git-fixes).
- wifi: ath10k: fix invalid VHT parameters in
  supported_vht_mcs_rate_nss2 (git-fixes).
- wifi: ath10k: fix invalid VHT parameters in
  supported_vht_mcs_rate_nss1 (git-fixes).
- wifi: ath9k: add range check for conn_rsp_epid in
  htc_connect_service() (git-fixes).
- wifi: rtl8xxxu: Perform update_beacon_work when beaconing is
  enabled (git-fixes).
- wifi: mwifiex: Fix memcpy() field-spanning write warning in
  mwifiex_config_scan() (git-fixes).
- wifi: wilc1000: Set MAC after operation mode (git-fixes).
- wifi: mwifiex: add missing locking for cfg80211 calls
  (git-fixes).
- wifi: cfg80211: check radio iface combination for multi radio
  per wiphy (git-fixes).
- wifi: mwifiex: Use IRQF_NO_AUTOEN flag in request_irq()
  (git-fixes).
- wifi: p54: Use IRQF_NO_AUTOEN flag in request_irq() (git-fixes).
- soc: fsl: cpm1: qmc: Set the ret error code on
  platform_get_irq() failure (git-fixes).
- soc: fsl: rcpm: fix missing of_node_put() in
  copy_ippdexpcr1_setting() (git-fixes).
- soc: ti: smartreflex: Use IRQF_NO_AUTOEN flag in request_irq()
  (git-fixes).
- soc: qcom: geni-se: fix array underflow in geni_se_clk_tbl_get()
  (git-fixes).
- drivers: soc: xilinx: add the missing kfree in
  xlnx_add_cb_for_suspend() (git-fixes).
- watchdog: Add HAS_IOPORT dependency for SBC8360 and SBC7240
  (git-fixes).
- tpm: fix signed/unsigned bug when checking event logs
  (git-fixes).
- =?UTF-8?q?spi:=20zynqmp-gqspi:=20Undo=20runtime=20PM=20ch?=
  =?UTF-8?q?anges=20at=20driver=20exit=20time=E2=80=8B?=
  (git-fixes).
- spi: tegra210-quad: Avoid shift-out-of-bounds (git-fixes).
- spi: spi-fsl-lpspi: Use IRQF_NO_AUTOEN flag in request_irq()
  (git-fixes).
- regulator: rk808: Restrict DVS GPIOs to the RK808 variant only
  (git-fixes).
- regulator: qcom-smd: make smd_vreg_rpm static (git-fixes).
- scripts/kernel-doc: Do not track section counter across
  processed files (git-fixes).
- Revert "scripts/faddr2line: Check only two symbols when
  calculating symbol size" (git-fixes).
- thermal: core: Initialize thermal zones before registering them
  (git-fixes).
- commit 96ef6e8
* Fri Nov 29 2024 tiwai@suse.de
- power: reset: ep93xx: add AUXILIARY_BUS dependency (git-fixes).
- power: supply: rt9471: Use IC status regfield to report real
  charger status (git-fixes).
- power: supply: rt9471: Fix wrong WDT function regfield
  declaration (git-fixes).
- power: supply: bq27xxx: Fix registers of bq27426 (git-fixes).
- power: supply: core: Remove might_sleep() from
  power_supply_put() (git-fixes).
- PCI: Fix reset_method_store() memory leak (git-fixes).
- PCI: tegra194: Move controller cleanups to
  pex_ep_event_pex_rst_deassert() (git-fixes).
- PCI: rockchip-ep: Fix address translation unit programming
  (git-fixes).
- PCI: qcom: Disable ASPM L0s for X1E80100 (git-fixes).
- PCI: qcom-ep: Move controller cleanups to
  qcom_pcie_perst_deassert() (git-fixes).
- PCI: qcom: Enable MSI interrupts together with Link up if
  'Global IRQ' is supported (git-fixes).
- PCI: keystone: Add link up check to ks_pcie_other_map_bus()
  (git-fixes).
- PCI: keystone: Set mode as Root Complex for "ti,keystone-pcie"
  compatible (git-fixes).
- PCI: j721e: Deassert PERST# after a delay of PCIE_T_PVPERL_MS
  milliseconds (git-fixes).
- PCI: dwc: ep: Fix advertised resizable BAR size regression
  (git-fixes).
- pinctrl: k210: Undef K210_PC_DEFAULT (git-fixes).
- pinctrl: qcom: spmi: fix debugfs drive strength (git-fixes).
- pinctrl: renesas: Select PINCTRL_RZG2L for RZ/V2H(P) SoC
  (git-fixes).
- pinctrl: renesas: rzg2l: Fix missing return in
  rzg2l_pinctrl_register() (git-fixes).
- pinctrl: zynqmp: drop excess struct member description
  (git-fixes).
- platform/x86: panasonic-laptop: Return errno correctly in show
  callback (git-fixes).
- platform/x86/intel/pmt: allow user offset for PMT callbacks
  (git-fixes).
- platform/x86: asus-wmi: Fix inconsistent use of thermal policies
  (git-fixes).
- pmdomain: ti-sci: Add missing of_node_put() for args.np
  (git-fixes).
- pwm: Assume a disabled PWM to emit a constant inactive output
  (git-fixes).
- pwm: imx27: Workaround of the pwm output bug when decrease
  the duty cycle (git-fixes).
- regmap: irq: Set lockdep class for hierarchical IRQ domains
  (git-fixes).
- platform/chrome: cros_ec_typec: fix missing fwnode reference
  decrement (git-fixes).
- commit fc6407d
* Fri Nov 29 2024 tiwai@suse.de
- net: phy: fix phy_ethtool_set_eee() incorrectly enabling LPI
  (git-fixes).
- net: usb: lan78xx: Fix refcounting and autosuspend on invalid
  WoL configuration (git-fixes).
- net: usb: lan78xx: Fix memory leak on device unplug by freeing
  PHY device (git-fixes).
- net: usb: lan78xx: Fix double free issue with interrupt buffer
  allocation (git-fixes).
- net: phy: ensure that genphy_c45_an_config_eee_aneg() sees
  new value of phydev->eee_cfg.eee_enabled (git-fixes).
- PCI: endpoint: Clear secondary (not primary) EPC in
  pci_epc_remove_epf() (git-fixes).
- PCI: endpoint: Fix PCI domain ID release in pci_epc_destroy()
  (git-fixes).
- PCI: endpoint: epf-mhi: Avoid NULL dereference if DT lacks
  'mmio' (git-fixes).
- PCI: of_property: Assign PCI instead of CPU bus address to
  dynamic PCI nodes (git-fixes).
- PCI: cpqphp: Fix PCIBIOS_* return value confusion (git-fixes).
- mtd: spinand: winbond: Fix 512GW, 01GW, 01JW and 02JW ECC
  information (git-fixes).
- mtd: spinand: winbond: Fix 512GW and 02JW OOB layout
  (git-fixes).
- mtd: rawnand: atmel: Fix possible memory leak (git-fixes).
- mtd: spi-nor: core: replace dummy buswidth from addr to data
  (git-fixes).
- mtd: spi-nor: spansion: Use nor->addr_nbytes in octal DTR mode
  in RD_ANY_REG_OP (git-fixes).
- mtd: hyperbus: rpc-if: Add missing MODULE_DEVICE_TABLE
  (git-fixes).
- mfd: rt5033: Fix missing regmap_del_irq_chip() (git-fixes).
- mfd: intel_soc_pmic_bxtwc: Fix IRQ domain names duplication
  (git-fixes).
- mfd: intel_soc_pmic_bxtwc: Use IRQ domain for PMIC devices
  (git-fixes).
- mfd: intel_soc_pmic_bxtwc: Use IRQ domain for TMU device
  (git-fixes).
- mfd: intel_soc_pmic_bxtwc: Use IRQ domain for USB Type-C device
  (git-fixes).
- mfd: da9052-spi: Change read-mask to write-mask (git-fixes).
- mfd: tps65010: Use IRQF_NO_AUTOEN flag in request_irq() to
  fix race (git-fixes).
- net: phy: fix phylib's dual eee_enabled (git-fixes).
- net: phy: dp83869: fix status reporting for 1000base-x
  autonegotiation (git-fixes).
- media: uvcvideo: Skip parsing frames of type UVC_VS_UNDEFINED
  in uvc_parse_format (git-fixes).
- media: platform: exynos4-is: Fix an OF node reference leak in
  fimc_md_is_isp_available (git-fixes).
- media: atomisp: Add check for rgby_data memory allocation
  failure (git-fixes).
- media: venus: sync with threaded IRQ during inst destruction
  (git-fixes).
- media: venus: fix enc/dec destruction order (git-fixes).
- media: intel/ipu6: do not handle interrupts when device is
  disabled (git-fixes).
- media: ov08x40: Fix burst write sequence (git-fixes).
- media: gspca: ov534-ov772x: Fix off-by-one error in
  set_frame_rate() (git-fixes).
- media: venus: Fix pm_runtime_set_suspended() with runtime pm
  enabled (git-fixes).
- media: amphion: Fix pm_runtime_set_suspended() with runtime
  pm enabled (git-fixes).
- media: i2c: dw9768: Fix pm_runtime_set_suspended() with runtime
  pm enabled (git-fixes).
- media: ipu6: remove architecture DMA ops dependency in Kconfig
  (git-fixes).
- media: mantis: remove orphan mantis_core.h (git-fixes).
- media: vb2: Fix comment (git-fixes).
- mmc: mmc_spi: drop buggy snprintf() (git-fixes).
- commit 1b8353d
* Fri Nov 29 2024 tiwai@suse.de
- mailbox, remoteproc: k3-m4+: fix compile testing (git-fixes).
- mailbox: arm_mhuv2: clean up loop in get_irq_chan_comb()
  (git-fixes).
- mailbox: mtk-cmdq: fix wrong use of sizeof in cmdq_get_clocks()
  (git-fixes).
- lib/Kconfig.debug: move int_pow test option to runtime testing
  section (git-fixes).
- lib: string_helpers: silence snprintf() output truncation
  warning (git-fixes).
- maple_tree: refine mas_store_root() on storing NULL (git-fixes).
- maple_tree: fix alloc node fail issue (git-fixes).
- leds: ktd2692: Set missing timing properties (git-fixes).
- leds: max5970: Fix unreleased fwnode_handle in probe function
  (git-fixes).
- leds: lp55xx: Remove redundant test for invalid channel number
  (git-fixes).
- leds: flash: mt6360: Fix device_for_each_child_node()
  refcounting in error paths (git-fixes).
- media: v4l2-core: v4l2-dv-timings: check cvt/gtf result
  (git-fixes).
- media: uvcvideo: Stop stream during unregister (git-fixes).
- media: ipu6: remove redundant dependency in Kconfig (git-fixes).
- media: i2c: ds90ub960: Fix missing return check on
  ub960_rxport_read call (git-fixes).
- media: i2c: vgxy61: Fix an error handling path in
  vgxy61_detect() (git-fixes).
- media: ti: j721e-csi2rx: Convert comma to semicolon (git-fixes).
- media: i2c: max96717: clean up on error in
  max96717_subdev_init() (git-fixes).
- media: qcom: camss: fix error path on configuration of power
  domains (git-fixes).
- media: ts2020: fix null-ptr-deref in ts2020_probe() (git-fixes).
- media: platform: allegro-dvt: Fix possible memory leak in
  allocate_buffers_internal() (git-fixes).
- media: i2c: tc358743: Fix crash in the probe error path when
  using polling (git-fixes).
- media: wl128x: Fix atomicity violation in fmc_send_cmd()
  (git-fixes).
- media: imx-jpeg: Ensure power suppliers be suspended before
  detach them (git-fixes).
- media: amphion: Set video drvdata before register video device
  (git-fixes).
- media: imx-jpeg: Set video drvdata before register video device
  (git-fixes).
- media: mtk-jpeg: Fix null-ptr-deref during unload module
  (git-fixes).
- media: verisilicon: av1: Fix reference video buffer pointer
  assignment (git-fixes).
- media: platform: rga: fix 32-bit DMA limitation (git-fixes).
- media: uvcvideo: Require entities to have a non-zero unique ID
  (git-fixes).
- commit dbf2447
* Fri Nov 29 2024 tiwai@suse.de
- gpio: exar: set value when external pull-up or pull-down is
  present (git-fixes).
- gpio: zevio: Add missed label initialisation (git-fixes).
- hwmon: (aquacomputer_d5next) Fix length of speed_input array
  (git-fixes).
- hwmon: (tps23861) Fix reporting of negative temperatures
  (git-fixes).
- i3c: master: svc: Modify enabled_events bit 7:0 to act as IBI
  enable counter (git-fixes).
- i3c: master: svc: Fix pm_runtime_set_suspended() with runtime
  pm enabled (git-fixes).
- i3c: master: Fix miss free init_dyn_addr at
  i3c_master_put_i3c_addrs() (git-fixes).
- i3c: master: Remove i3c_dev_disable_ibi_locked(olddev) on
  device hotjoin (git-fixes).
- i3c: master: svc: fix possible assignment of the same address
  to two devices (git-fixes).
- Input: imagis - fix warning regarding 'imagis_3038_data'
  being unused (git-fixes).
- Input: hycon-hy46xx - add missing dependency on REGMAP_I2C
  (git-fixes).
- Input: hideep - add missing dependency on REGMAP_I2C
  (git-fixes).
- Input: cs40l50 - fix wrong usage of INIT_WORK() (git-fixes).
- kasan: move checks to do_strncpy_from_user (git-fixes).
- kunit: Fix potential null dereference in
  kunit_device_driver_test() (git-fixes).
- kunit: string-stream: Fix a UAF bug in kunit_init_suite()
  (git-fixes).
- kunit: skb: use "gfp" variable instead of hardcoding GFP_KERNEL
  (git-fixes).
- i2c: dev: Fix memory leak when underlying adapter does not
  support I2C (git-fixes).
- dma-mapping: remove an outdated comment from dma-map-ops.h
  (git-fixes).
- firmware: arm_scpi: Check the DVFS OPP count returned by the
  firmware (git-fixes).
- efi/libstub: Free correct pointer on failure (git-fixes).
- efi/libstub: fix efi_parse_options() ignoring the default
  command line (git-fixes).
- HID: wacom: Interpret tilt data from Intuos Pro BT as signed
  values (git-fixes).
- gpio: sloppy-logic-analyzer remove reference to
  rcu_momentary_dyntick_idle() (git-fixes).
- Documentation: kgdb: Correct parameter error (git-fixes).
- kcsan, seqlock: Fix incorrect assumption in read_seqbegin()
  (git-fixes).
- kcsan, seqlock: Support seqcount_latch_t (git-fixes).
- doc: rcu: update printed dynticks counter bits (git-fixes).
- hwmon: (nct6775-core) Fix overflows seen when writing limit
  attributes (git-fixes).
- hwmon: (pmbus/core) clear faults after setting smbalert mask
  (git-fixes).
- crypto: cavium - Fix an error handling path in
  cpt_ucode_load_fw() (git-fixes).
- crypto: bcm - add error check in the ahash_hmac_init function
  (git-fixes).
- crypto: caam - add error check to caam_rsa_set_priv_key_form
  (git-fixes).
- crypto: inside-secure - Fix the return value of
  safexcel_xcbcmac_cra_init() (git-fixes).
- crypto: qat - Fix missing destroy_workqueue in adf_init_aer()
  (git-fixes).
- crypto: hisilicon/qm - disable same error report before
  resetting (git-fixes).
- crypto: cavium - Fix the if condition to exit loop after timeout
  (git-fixes).
- crypto: x86/aegis128 - access 32-bit arguments as 32-bit
  (git-fixes).
- firmware: google: Unregister driver_info on failure (git-fixes).
- commit ba10c07
* Fri Nov 29 2024 tiwai@suse.de
- Bluetooth: MGMT: Fix possible deadlocks (git-fixes).
- Bluetooth: MGMT: Fix slab-use-after-free Read in
  set_powered_sync (git-fixes).
- cpufreq: mediatek-hw: Fix wrong return value in
  mtk_cpufreq_get_cpu_power() (git-fixes).
- cpufreq: loongson3: Check for error code from devm_mutex_init()
  call (git-fixes).
- cpufreq: scmi: Fix cleanup path when boost enablement fails
  (git-fixes).
- cpufreq: CPPC: Fix possible null-ptr-deref for
  cppc_get_cpu_cost() (git-fixes).
- cpufreq: CPPC: Fix possible null-ptr-deref for
  cpufreq_cpu_get_raw() (git-fixes).
- Revert "cpufreq: brcmstb-avs-cpufreq: Fix initial command check"
  (stable-fixes).
- cpufreq: loongson2: Unregister platform_driver on failure
  (git-fixes).
- cppc_cpufreq: Use desired perf if feedback ctrs are 0 or
  unchanged (git-fixes).
- clk: qcom: clk-alpha-pll: fix lucid 5lpe pll enabled check
  (git-fixes).
- clk: qcom: clk-alpha-pll: drop lucid-evo pll enabled warning
  (git-fixes).
- clk: qcom: gcc-qcs404: fix initial rate of GPLL3 (git-fixes).
- clk: qcom: videocc-sm8550: depend on either gcc-sm8550 or
  gcc-sm8650 (git-fixes).
- clk: clk-axi-clkgen: make sure to enable the AXI bus clock
  (git-fixes).
- clk: sunxi-ng: d1: Fix PLL_AUDIO0 preset (git-fixes).
- clk: imx: imx8-acm: Fix return value check in
  clk_imx_acm_attach_pm_domains() (git-fixes).
- clk: imx: clk-scu: fix clk enable state save and restore
  (git-fixes).
- clk: imx: fracn-gppll: fix pll power up (git-fixes).
- clk: imx: fracn-gppll: correct PLL initialization flow
  (git-fixes).
- clk: imx: lpcg-scu: SW workaround for errata (e10858)
  (git-fixes).
- clk: renesas: rzg2l: Fix FOUTPOSTDIV clk (git-fixes).
- clk: Allow kunit tests to run without OF_OVERLAY enabled
  (git-fixes).
- clk: ralink: mtmips: fix clocks probe order in oldest ralink
  SoCs (git-fixes).
- clk: ralink: mtmips: fix clock plan for Ralink SoC RT3883
  (git-fixes).
- clk: clk-loongson2: Fix potential buffer overflow in
  flexible-array member access (git-fixes).
- clk: clk-loongson2: Fix memory corruption bug in struct
  loongson2_clk_provider (git-fixes).
- clk: clk-apple-nco: Add NULL check in applnco_probe (git-fixes).
- clk: sophgo: avoid integer overflow in sg2042_pll_recalc_rate()
  (git-fixes).
- ASoC: da7213: Populate max_register to regmap_config
  (git-fixes).
- ASoC: codecs: Fix atomicity violation in
  snd_soc_component_get_drvdata() (git-fixes).
- ASoC: rt722-sdca: Remove logically deadcode in rt722-sdca.c
  (git-fixes).
- ASoC: amd: acp: fix for cpu dai index logic (git-fixes).
- ASoC: amd: acp: fix for inconsistent indenting (git-fixes).
- ASoC: fsl-asoc-card: Add missing handling of {hp,mic}-dt-gpios
  (git-fixes).
- ASoC: fsl_micfil: fix regmap_write_bits usage (git-fixes).
- ALSA: 6fire: Release resources at card release (git-fixes).
- ALSA: caiaq: Use snd_card_free_when_closed() at disconnection
  (git-fixes).
- ALSA: us122l: Use snd_card_free_when_closed() at disconnection
  (git-fixes).
- ALSA: usx2y: Use snd_card_free_when_closed() at disconnection
  (git-fixes).
- Bluetooth: fix use-after-free in device_for_each_child()
  (git-fixes).
- Bluetooth: ISO: Use kref to track lifetime of iso_conn
  (git-fixes).
- Bluetooth: btbcm: fix missing of_node_put() in
  btbcm_get_board_name() (git-fixes).
- Bluetooth: btmtk: adjust the position to init iso data anchor
  (git-fixes).
- ACPI: CPPC: Fix _CPC register setting issue (git-fixes).
- cpufreq/amd-pstate: Don't update CPPC request in
  amd_pstate_cpu_boost_update() (git-fixes).
- cpufreq/amd-pstate: Fix non kerneldoc comment (git-fixes).
- crypto: pcrypt - Call crypto layer directly when
  padata_do_parallel() return -EBUSY (git-fixes).
- crypto: ecdsa - Update Kconfig help text for NIST P521
  (git-fixes).
- crypto: qat - remove faulty arbiter config reset (git-fixes).
- crypto: qat/qat_4xxx - fix off by one in uof_get_name()
  (git-fixes).
- crypto: qat/qat_420xx - fix off by one in uof_get_name()
  (git-fixes).
- crypto: qat - remove check after debugfs_create_dir()
  (git-fixes).
- crypto: caam - Fix the pointer passed to caam_qi_shutdown()
  (git-fixes).
- crypto: mxs-dcp - Fix AES-CBC with hardware-bound keys
  (git-fixes).
- acpi/arm64: Adjust error handling procedure in
  gtdt_parse_timer_block() (git-fixes).
- commit 9685db9
* Fri Nov 29 2024 tzimmermann@suse.com
- Revert "config: Update config for DRM graphics drivers (jsc#11186)"
  This reverts commit f8bed7719a0fa09b55bbc650f404bfd3a570f203.
  The reference to the Jira ticket is incorrect.
- commit c7da338
* Fri Nov 29 2024 ykaukab@suse.de
- SLE16: supported.conf: fix more errors reported by split-modules
  arm64:
  [ 6326s] The following unsupported modules are used by supported modules:
  [ 6326s] wire needed by w1_gpio
  [ 6326s] wire needed by w1_therm
  x86_64:
  [ 1616s] The following optional modules are used by extra modules:
  [ 1616s] cros_ec needed by cros_ec_lpcs
  [ 1616s] cros_ec needed by rtc_wilco_ec
  [ 1616s] cros_ec needed by wilco_ec
  [ 1616s] cros_ec_lpcs needed by rtc_wilco_ec
  [ 1616s] cros_ec_lpcs needed by wilco_ec
  [ 1616s] wilco_ec needed by rtc_wilco_ec
- commit 9198e30
* Fri Nov 29 2024 tzimmermann@suse.com
- config: Fallout from running ./run_oldconfig.sh
- commit 84c0ddd
* Fri Nov 29 2024 tzimmermann@suse.com
- config: x86_64: Enable HiSilicon BMC graphics driver (jsc#PED-11182)
- commit a69a48e
* Fri Nov 29 2024 tzimmermann@suse.com
- drm/hibmc: Drop dependency on ARM64 (jsc#PED-11182).
- commit ca797cd
* Fri Nov 29 2024 ggherdovich@suse.cz
- cpufreq/amd-pstate: Default to "powersave" governor when in
  "active mode" on servers (bsc#1233975).
- commit 454ab2e
* Thu Nov 28 2024 ggherdovich@suse.cz
- amd-pstate: Switch to amd-pstate by default on some Server
  platforms (bsc#1233975).
- commit 9c67ff1
* Thu Nov 28 2024 ggherdovich@suse.cz
- amd-pstate: Set min_perf to nominal_perf for active mode
  performance gov (bsc#1233975).
- commit 28d6ce6
* Thu Nov 28 2024 ykaukab@suse.de
- SLE16: supported.conf: fix errors reported by split-modules
  Workaround false positives for implicitly declared modules
  by adding them explicitly.
- commit 11a0cf1
* Thu Nov 28 2024 msuchanek@suse.de
- Refresh patches.suse/powerpc-kexec_file-Add-KEXEC_SIG-support.patch.
  Avoid compiler warning
- commit e0b7746
* Thu Nov 28 2024 pmladek@suse.com
- Refresh
  patches.suse/livepatch-mark-the-kernel-unsupported-when-disabling.patch.
- commit b021387
* Wed Nov 27 2024 tiwai@suse.de
- Drop obsoleted patches and refresh/enable kabi padding patches
  Dropped:
  patches.suse/Input-elan_i2c-Add-deny-list-for-Lenovo-Yoga-Slim-7.patch
  patches.suse/Input-synaptics-retry-query-upon-error.patch
  patches.suse/drm-i915-lspcon-Separate-function-to-set-expected-mo.patch
  patches.suse/drm-i915-lspcon-Separate-lspcon-probe-and-lspcon-ini.patch
  patches.suse/drm-nouveau-blacklist-Turing-and-Ampere-models-as-default.patch
  patches.suse/firmware-qemu_fw_cfg-Do-not-hard-depend-on-CONFIG_HA.patch
  Refreshed:
  patches.suse/asoc-suse-kabi-padding.patch
  patches.suse/media-suse-kabi-padding.patch.
  patches.suse/soundwire-suse-kabi-padding.patch
  patches.suse/wireless-suse-kabi-padding.patch
- commit 51775ca
* Wed Nov 27 2024 pmladek@suse.com
- Refresh: patches.suse/prepare-arm64-klp.
- commit 477d95e
* Wed Nov 27 2024 pmladek@suse.com
- Refresh
  patches.suse/Revert-kallsyms-unexport-kallsyms_lookup_name-and-kallsyms_on_each_symbol.patch.
- commit 6f8810b
* Wed Nov 27 2024 pmladek@suse.com
- Refresh
  patches.suse/Revert-Revert-kbuild-use-flive-patching-when-CONFIG_LIVEPATCH-is-enabled.patch.
- commit 6ba47ba
* Wed Nov 27 2024 pmladek@suse.com
- Refresh
  patches.suse/livepatch-dump-ipa-clones.patch
  Update config files.
- commit c9d0459
* Wed Nov 27 2024 jbohac@suse.cz
- fadump: reserve param area if below boot_mem_top (jsc#PED-9891).
- powerpc/fadump: allocate memory for additional parameters early
  (jsc#PED-9891).
- commit 93c8306
* Wed Nov 27 2024 pmladek@suse.com
- Refresh
  patches.suse/livepatch-Add-sample-livepatch-module.patch.
- commit cff40b1
* Wed Nov 27 2024 pmladek@suse.com
- Refresh patches.suse/kbuild-modpost-integrate-klp-convert.patch.
- commit 5bfefc6
* Wed Nov 27 2024 tzimmermann@suse.com
- config: s390: Disable XE driver (jsc#PED-11187)
- commit 9589455
* Wed Nov 27 2024 ykaukab@suse.de
- config: x86_64: change HZ to upstream default
  References: jsc#PED-11606
- commit 80f3e03
* Wed Nov 27 2024 pmladek@suse.com
- Refresh patches.suse/livepatch-Add-klp-convert-tool.patch.
- commit e46c3e4
* Wed Nov 27 2024 tzimmermann@suse.com
- config: Update config for DRM graphics drivers (jsc#PED-11186)
  Also list additional modules as unsupported.
  Same as commit f8bed7719a0fa09b55bbc650f404bfd3a570f203, but with
  the correct reference to the Jira ticket.
- config: Update config for DRM graphics drivers (jsc#11186)
  Also list additional modules as unsupported.
- commit 26a7b09
* Wed Nov 27 2024 pmladek@suse.com
- Refresh
  patches.suse/livepatch-Create-and-include-UAPI-headers.patch.
- commit 4e85f17
* Wed Nov 27 2024 pmladek@suse.com
- Refresh
  patches.suse/vsprintf-kallsyms-Prevent-invalid-data-when-printing.patch.
- commit fd35952
* Wed Nov 27 2024 petr.pavlu@suse.com
- Reenable patches.suse/tracing-Add-kabi-placeholders.patch.
  The added placeholders are useful for 6.12-based branches too.
- commit 3f5f9a3
* Wed Nov 27 2024 petr.pavlu@suse.com
- Delete
  patches.suse/kprobes-Fix-double-free-of-kretprobe_holder.patch.
  The patch is not needed for 6.12-based branches as they include upstream
  commit 4bbd93455659 ("kprobes: kretprobe scalability improvement") which
  reworked the affected area and also fixed the issue.
- commit 988bf28
* Wed Nov 27 2024 tzimmermann@suse.com
- config: Disable obsolete fbdev drivers (jsc#PED-11183)
- commit a294eeb
* Wed Nov 27 2024 tzimmermann@suse.com
- config: Fallout fom run_oldconfig.sh
- commit 526ac06
* Wed Nov 27 2024 jack@suse.cz
- Enable patches.suse/unsupported-features.patch: Support for tainting
  kernel when unsupported filesystem features are used.
- commit 70a4d99
* Wed Nov 27 2024 jack@suse.cz
- Delete patches.suse/readahead-request-tunables.patch: Now handled in
  udev rule
- commit 6ef5420
* Wed Nov 27 2024 jack@suse.cz
- Delete
  patches.suse/blk-wbt-Fix-detection-of-dirty-throttled-tasks.patch: Now
  upstream.
- Delete
  patches.suse/nfs-Bump-default-write-congestion-size.patch: Upstream
  has a proper fix.
- commit 5bb4f43
* Wed Nov 27 2024 jack@suse.cz
- Enable patches.suse/ext4-unsupported-features.patch. There was no
  request to make these features (bigalloc) supported on ext4.
- commit 636b72e
* Tue Nov 26 2024 ggherdovich@suse.cz
- Re-enable fixup to the acpi_pad driver
- commit 0dc7926
* Tue Nov 26 2024 ggherdovich@suse.cz
- Re-enable prerequisite patch to set CONFIG_CPU_FREQ_DEFAULT_GOV_ONDEMAND=y
- commit d5e1336
* Tue Nov 26 2024 ggherdovich@suse.cz
- Re-enable defaulting to intel_pstate/powersave on non-HWP machines
- commit b22515b
* Tue Nov 26 2024 ggherdovich@suse.cz
- Re-enable idle-boost optimization for intel_pstate on non-HWP machines
- commit 795714e
* Tue Nov 26 2024 ggherdovich@suse.cz
- Re-enable intel_pstate optimization for low-utilization workloads on non-HWP machines
- commit ce7c38f
* Tue Nov 26 2024 ggherdovich@suse.cz
- Re-enable aggressive iowait boost for intel_pstate for non-HWP machines
- commit 5b65f5b
* Tue Nov 26 2024 msuchanek@suse.de
- Reenable broken cdrom quirk.
- commit 6b9f78a
* Tue Nov 26 2024 msuchanek@suse.de
- Reenable downstream powerpc patches.
- commit 799a7a7
* Tue Nov 26 2024 msuchanek@suse.de
- Reenable ppc KEXEC_SIG
  KEXEC option rework is now merged so this can be revisited but it's not
  upstream yet.
- Update config files.
- commit 933b828
* Tue Nov 26 2024 msuchanek@suse.de
- Refresh sorted patches.
- commit 0916037
* Tue Nov 26 2024 msuchanek@suse.de
- Reenable crypto fix
- commit 7f7a3e3
* Tue Nov 26 2024 msuchanek@suse.de
- Lockdown patches need to be handled together.
- commit a64f237
* Tue Nov 26 2024 msuchanek@suse.de
- Reenable kABI placeholder
- commit 6e585f9
* Tue Nov 26 2024 msuchanek@suse.de
- Delete patches.rpmify/Revert-kbuild-Hack-for-depmod-not-handling-X.Y-versi.patch.
  Upstreamed
- commit de5f3c4
* Tue Nov 26 2024 msuchanek@suse.de
- Update config
  product version SLFO 1.2
  build project SLFO:Main:Build
  bugzilla product Micro 6.2
  build optional KMP
- commit c86a93a
* Tue Nov 26 2024 msuchanek@suse.de
- KVM: PPC: Book3S HV: Avoid returning to nested hypervisor on
  pending doorbells (bsc#1215199).
- KVM: PPC: Book3S HV: Stop using vc->dpdes for nested KVM guests
  (bsc#1215199).
- Revert "KVM: PPC: Book3S HV Nested: Stop forwarding all HFUs
  to L1" (bsc#1215199).
- commit 78cb129
* Tue Nov 26 2024 msuchanek@suse.de
- KVM: PPC: Book3S HV: Add Power11 capability support for Nested
  PAPR guests (jsc#PED-7970 jsc#PED-11016).
- commit 1731e24
* Tue Nov 26 2024 ailiop@suse.com
- Delete
  patches.suse/reiserfs-mark-read-write-mode-unsupported.patch.
  We do not compile reiserfs at all for SLE16, so we can drop this patch
  completely.
- commit 6f524a6
* Tue Nov 26 2024 iivanov@suse.de
- series.conf: Keep reserving space in cpu_hwcaps and cpu_hwcap_keys arrays
- commit 5af8e9d
* Tue Nov 26 2024 ailiop@suse.com
- Refresh patches.suse/xfs-allow-mount-remount-when-stripe-width-alignment-.patch.
  We can retain this patch to make sure that customers that may be
  upgrading to SLE16 with previously formatted xfs filesystems susceptible
  to the issue mentioned in the patch will not face any upgrade issues.
- commit 07642be
* Tue Nov 26 2024 ailiop@suse.com
- Delete patches.suse/xfs-remove-experimental-tag-for-dax-support.patch.
  Drop the patch as upstream [1] has removed the warning in v6.8 so we do
  not need to carry this any more.
  [1] commit 27c86d43bcdb ("xfs: drop experimental warning for FSDAX")
- commit ad7a543
* Tue Nov 26 2024 msuchanek@suse.de
- KVM: PPC: Book3S HV: Fix kmv -> kvm typo (jsc#PED-11016
  git-fixes).
- commit 6002aff
* Tue Nov 26 2024 ykaukab@suse.de
- SLE16: supported.conf: further fixups
  Fix remaining warnings from kbuild
- commit 5454218
* Mon Nov 25 2024 ykaukab@suse.de
- SLE16: supported.conf: fix build errors
  Fix following errors in supported.conf
  x86_64:
  [ 1581s] warning: intel_skl_int3472_common not listed in supported.conf
  [ 1583s] warning: mlx90635 not listed in supported.conf
  [ 1584s] warning: nxp_c45_tja not listed in supported.conf
  [ 1584s] warning: processor_thermal_power_floor not listed in supported.conf
  [ 1584s] warning: processor_thermal_wt_hint not listed in supported.conf
  [ 1584s] warning: processor_thermal_wt_req not listed in supported.conf
  [ 1586s] warning: skx_edac_common not listed in supported.conf
  [ 1586s] warning: spi_pxa2xx_core not listed in supported.conf
  [ 1587s] warning: tipc_diag not listed in supported.conf
  [ 1589s] The following unsupported modules are used by supported modules:
  [ 1589s] libeth needed by iavf
  [ 1589s] libeth needed by idpf
  [ 1589s] libie needed by i40e
  [ 1589s] libie needed by iavf
  [ 1589s] libie needed by ice
  [ 1589s] libie needed by irdma
  [ 1589s] liquidio_core needed by liquidio
  [ 1589s] liquidio_core needed by liquidio_vf
  [ 1589s] nls_ucs2_utils needed by cifs
  [ 1589s] processor_thermal_power_floor needed by int3401_thermal
  [ 1589s] processor_thermal_power_floor needed by processor_thermal_device
  [ 1589s] processor_thermal_power_floor needed by processor_thermal_device_pci
  [ 1589s] processor_thermal_wt_hint needed by int3401_thermal
  [ 1589s] processor_thermal_wt_hint needed by processor_thermal_device
  [ 1589s] processor_thermal_wt_hint needed by processor_thermal_device_pci
  [ 1589s] processor_thermal_wt_req needed by int3401_thermal
  [ 1589s] processor_thermal_wt_req needed by processor_thermal_device
  [ 1589s] processor_thermal_wt_req needed by processor_thermal_device_pci
  [ 1589s] ptp_mock needed by netdevsim
  [ 1589s] pwrseq_core needed by hci_nokia
  [ 1589s] pwrseq_core needed by hci_uart
  [ 1589s] qcom_phy_lib needed by at803x
  [ 1589s] rpmb_core needed by mmc_block
  [ 1589s] rtw88_8723x needed by rtw88_8723d
  [ 1589s] rtw88_8723x needed by rtw88_8723de
  [ 1589s] skx_edac_common needed by i10nm_edac
  [ 1589s] skx_edac_common needed by skx_edac
  [ 1589s] snd_amd_sdw_acpi needed by snd_pci_ps
  [ 1589s] snd_amd_sdw_acpi needed by snd_sof_amd_acp
  [ 1589s] snd_amd_sdw_acpi needed by snd_sof_amd_rembrandt
  [ 1589s] snd_amd_sdw_acpi needed by snd_sof_amd_renoir
  [ 1589s] snd_amd_sdw_acpi needed by snd_sof_amd_vangogh
  [ 1589s] snd_hda_scodec_component needed by snd_hda_codec_realtek
  [ 1589s] snd_soc_cs_amp_lib needed by snd_hda_scodec_cs35l41
  [ 1589s] snd_soc_cs_amp_lib needed by snd_hda_scodec_cs35l41_i2c
  [ 1589s] snd_soc_cs_amp_lib needed by snd_hda_scodec_cs35l41_spi
  [ 1589s] snd_soc_cs_amp_lib needed by snd_hda_scodec_cs35l56
  [ 1589s] snd_soc_cs_amp_lib needed by snd_hda_scodec_cs35l56_i2c
  [ 1589s] snd_soc_cs_amp_lib needed by snd_hda_scodec_cs35l56_spi
  [ 1589s] snd_soc_cs_amp_lib needed by snd_soc_cs35l56
  [ 1589s] snd_soc_cs_amp_lib needed by snd_soc_cs35l56_i2c
  [ 1589s] snd_soc_cs_amp_lib needed by snd_soc_cs35l56_sdw
  [ 1589s] snd_soc_cs_amp_lib needed by snd_soc_cs35l56_shared
  [ 1589s] snd_soc_cs_amp_lib needed by snd_soc_cs35l56_spi
  [ 1589s] snd_soc_es83xx_dsm_common needed by snd_soc_sst_byt_cht_es8316
  [ 1589s] snd_soc_intel_sof_board_helpers needed by snd_soc_skl_hda_dsp
  [ 1589s] snd_soc_intel_sof_board_helpers needed by snd_soc_sof_cs42l42
  [ 1589s] snd_soc_intel_sof_board_helpers needed by snd_soc_sof_nau8825
  [ 1589s] snd_soc_intel_sof_board_helpers needed by snd_soc_sof_rt5682
  [ 1589s] snd_soc_intel_sof_board_helpers needed by snd_soc_sof_ssp_amp
  [ 1589s] snd_soc_intel_sof_nuvoton_common needed by snd_soc_sof_nau8825
  [ 1589s] snd_soc_sdw_utils needed by snd_soc_sof_sdw
  [ 1589s] snd_sof_intel_hda_generic needed by snd_sof_pci_intel_apl
  [ 1589s] snd_sof_intel_hda_generic needed by snd_sof_pci_intel_cnl
  [ 1589s] snd_sof_intel_hda_generic needed by snd_sof_pci_intel_icl
  [ 1589s] snd_sof_intel_hda_generic needed by snd_sof_pci_intel_lnl
  [ 1589s] snd_sof_intel_hda_generic needed by snd_sof_pci_intel_mtl
  [ 1589s] snd_sof_intel_hda_generic needed by snd_sof_pci_intel_skl
  [ 1589s] snd_sof_intel_hda_generic needed by snd_sof_pci_intel_tgl
  [ 1589s] soundwire_amd needed by snd_pci_ps
  [ 1589s] soundwire_amd needed by snd_sof_amd_acp
  [ 1589s] soundwire_amd needed by snd_sof_amd_rembrandt
  [ 1589s] soundwire_amd needed by snd_sof_amd_renoir
  [ 1589s] soundwire_amd needed by snd_sof_amd_vangogh
  [ 1589s] spi_pxa2xx_core needed by spi_pxa2xx_platform
  arm64:
  [ 6509s] warning: cpr not listed in supported.conf
  [ 6510s] warning: ffa_core not listed in supported.conf
  [ 6511s] warning: hclge_common not listed in supported.conf
  [ 6512s] warning: i2c_pasemi_core not listed in supported.conf
  [ 6512s] warning: i2c_pasemi_platform not listed in supported.conf
  [ 6512s] warning: imx_common not listed in supported.conf
  [ 6514s] warning: mlx90635 not listed in supported.conf
  [ 6515s] warning: mtk_adsp_common not listed in supported.conf
  [ 6516s] warning: nxp_c45_tja not listed in supported.conf
  [ 6516s] warning: phy_qcom_qmp_usbc not listed in supported.conf
  [ 6517s] warning: qcom_pmic_tcpm not listed in supported.conf
  [ 6518s] warning: rpmpd not listed in supported.conf
  [ 6518s] warning: rswitch not listed in supported.conf
  [ 6520s] warning: snd_soc_fsi not listed in supported.conf
  [ 6520s] warning: snd_soc_rcar not listed in supported.conf
  [ 6520s] warning: snd_soc_rz_ssi not listed in supported.conf
  [ 6520s] warning: snd_soc_stm32_sai_sub not listed in supported.conf
  [ 6520s] warning: snd_sof_imx8 not listed in supported.conf
  [ 6520s] warning: snd_sof_imx8m not listed in supported.conf
  [ 6520s] warning: snd_sof_imx8ulp not listed in supported.conf
  [ 6520s] warning: snd_sof_mt8186 not listed in supported.conf
  [ 6520s] warning: snd_sof_mt8195 not listed in supported.conf
  [ 6520s] warning: snd_sof_of not listed in supported.conf
  [ 6522s] warning: tipc_diag not listed in supported.conf
  [ 6525s] The following unsupported modules are used by supported modules:
  [ 6525s] apple_mailbox needed by apple_rtkit
  [ 6525s] apple_mailbox needed by nvme_apple
  [ 6525s] apple_rtkit needed by nvme_apple
  [ 6525s] apple_sart needed by nvme_apple
  [ 6525s] aux_hpd_bridge needed by pmic_glink_altmode
  [ 6525s] ffa_core needed by ffa_module
  [ 6525s] ffa_core needed by optee
  [ 6525s] hclge_common needed by hclge
  [ 6525s] hclge_common needed by hclgevf
  [ 6525s] k3_cppi_desc_pool needed by ti_am65_cpsw_nuss
  [ 6525s] libeth needed by iavf
  [ 6525s] libie needed by i40e
  [ 6525s] libie needed by iavf
  [ 6525s] libie needed by ice
  [ 6525s] libie needed by irdma
  [ 6525s] liquidio_core needed by liquidio
  [ 6525s] liquidio_core needed by liquidio_vf
  [ 6525s] mdio_regmap needed by dwmac_altr_socfpga
  [ 6525s] nls_ucs2_utils needed by cifs
  [ 6525s] ptp_mock needed by netdevsim
  [ 6525s] pwrseq_core needed by hci_nokia
  [ 6525s] pwrseq_core needed by hci_uart
  [ 6525s] qcom_ice needed by sdhci_msm
  [ 6525s] qcom_ice needed by ufs_qcom
  [ 6525s] qcom_pdr_msg needed by apr
  [ 6525s] qcom_pdr_msg needed by pdr_interface
  [ 6525s] qcom_pdr_msg needed by pmic_glink
  [ 6525s] qcom_pdr_msg needed by pmic_glink_altmode
  [ 6525s] qcom_pdr_msg needed by q6adm
  [ 6525s] qcom_pdr_msg needed by q6afe
  [ 6525s] qcom_pdr_msg needed by q6afe_clocks
  [ 6525s] qcom_pdr_msg needed by q6afe_dai
  [ 6525s] qcom_pdr_msg needed by q6apm_dai
  [ 6525s] qcom_pdr_msg needed by q6apm_lpass_dais
  [ 6525s] qcom_pdr_msg needed by q6asm
  [ 6525s] qcom_pdr_msg needed by q6asm_dai
  [ 6525s] qcom_pdr_msg needed by q6core
  [ 6525s] qcom_pdr_msg needed by q6prm
  [ 6525s] qcom_pdr_msg needed by q6prm_clocks
  [ 6525s] qcom_pdr_msg needed by q6routing
  [ 6525s] qcom_pdr_msg needed by snd_q6apm
  [ 6525s] qcom_phy_lib needed by at803x
  [ 6525s] rpmb_core needed by mmc_block
  [ 6525s] rpmb_core needed by optee
  [ 6525s] rtw88_8723x needed by rtw88_8723d
  [ 6525s] rtw88_8723x needed by rtw88_8723de
  [ 6525s] snd_hda_scodec_component needed by snd_hda_codec_realtek
  [ 6525s] snd_soc_cs_amp_lib needed by snd_hda_scodec_cs35l41
  [ 6525s] snd_soc_cs_amp_lib needed by snd_hda_scodec_cs35l41_i2c
  [ 6525s] snd_soc_cs_amp_lib needed by snd_hda_scodec_cs35l41_spi
  [ 6525s] snd_soc_cs_amp_lib needed by snd_hda_scodec_cs35l56
  [ 6525s] snd_soc_cs_amp_lib needed by snd_hda_scodec_cs35l56_i2c
  [ 6525s] snd_soc_cs_amp_lib needed by snd_hda_scodec_cs35l56_spi
  [ 6525s] snd_soc_cs_amp_lib needed by snd_soc_cs35l56
  [ 6525s] snd_soc_cs_amp_lib needed by snd_soc_cs35l56_i2c
  [ 6525s] snd_soc_cs_amp_lib needed by snd_soc_cs35l56_sdw
  [ 6525s] snd_soc_cs_amp_lib needed by snd_soc_cs35l56_shared
  [ 6525s] snd_soc_cs_amp_lib needed by snd_soc_cs35l56_spi
  [ 6525s] snd_soc_wcd_classh needed by snd_soc_wcd9335
  [ 6525s] snd_soc_wcd_classh needed by snd_soc_wcd934x
  [ 6525s] snd_soc_wcd_classh needed by snd_soc_wcd938x
  [ 6525s] xilinx_core needed by xilinx_spi
  ppc64le:
  [ 2708s] warning: nxp_c45_tja not listed in supported.conf
  [ 2709s] warning: tipc_diag not listed in supported.conf
  [ 2712s] The following unsupported modules are used by supported modules:
  [ 2712s] aux_hpd_bridge needed by pmic_glink_altmode
  [ 2712s] curve25519_ppc64le needed by libcurve25519
  [ 2712s] curve25519_ppc64le needed by wireguard
  [ 2712s] libeth needed by iavf
  [ 2712s] libie needed by i40e
  [ 2712s] libie needed by iavf
  [ 2712s] libie needed by ice
  [ 2712s] libie needed by irdma
  [ 2712s] nls_ucs2_utils needed by cifs
  [ 2712s] ptp_mock needed by netdevsim
  [ 2712s] qcom_pdr_msg needed by pdr_interface
  [ 2712s] qcom_pdr_msg needed by pmic_glink
  [ 2712s] qcom_pdr_msg needed by pmic_glink_altmode
  [ 2712s] qcom_phy_lib needed by at803x
  [ 2712s] rtw88_8723x needed by rtw88_8723d
  [ 2712s] rtw88_8723x needed by rtw88_8723de
  [ 2712s] xilinx_core needed by xilinx_spi
  s390:
  [ 1303s] warning: nxp_c45_tja not listed in supported.conf
  [ 1304s] warning: serial_base not listed in supported.conf
  [ 1304s] warning: tipc_diag not listed in supported.conf
  [ 1305s] The following unsupported modules are used by supported modules:
  [ 1305s] nls_ucs2_utils needed by cifs
  [ 1305s] ptp_mock needed by netdevsim
  [ 1305s] qcom_phy_lib needed by at803x
- commit 078fa22
* Fri Nov 22 2024 ykaukab@suse.de
- SLE16: supported.conf: mark all new modules as unsupported
- commit 56358e9
* Fri Nov 22 2024 ykaukab@suse.de
- SLE16: supported.conf: fix tabs using sort_supported.rb
  No content change
- commit c2a9039
* Wed Nov 20 2024 ykaukab@suse.de
- SLE16: Update to v6.12
  Previous base was v6.12-rc7
- commit 6f63baf
* Wed Nov 20 2024 ykaukab@suse.de
- SLE16: s390x: update configs
- commit 179d85e
* Tue Nov 19 2024 ykaukab@suse.de
- SLE16: arm64: update configs
- commit e27a64b
* Tue Nov 19 2024 ykaukab@suse.de
- SLE16: ppc64le: update configs
- commit ac2a2eb
* Mon Nov 18 2024 ykaukab@suse.de
- SLE16: x86_64: update configs
- commit d3cf7cc
* Mon Nov 18 2024 msuchanek@suse.de
- kernel-binary: Enable livepatch package only when livepatch is enabled
  Otherwise the filelist may be empty failing the build (bsc#1218644).
- commit f730eec
* Fri Nov 15 2024 ykaukab@suse.de
- SLE16: fix conflicts in the existing patches
- commit d49a172
* Fri Nov 15 2024 ykaukab@suse.de
- SLE16: set v6.12-rc7 as the base kernel
- commit bebe581
* Fri Nov 15 2024 ykaukab@suse.de
- SLE16: Add branch maintainers
- commit 953623a
* Fri Nov 15 2024 ykaukab@suse.de
- SLE16: delete old kABI values
- commit ae7da2f
* Fri Nov 15 2024 ykaukab@suse.de
- SLE16: Remove patches not needed in v6.12
  Disable all out-of-tree and kABI padding patches
  Remove all kABI consistency patches
  Base SUSE-2024 commit: 211ffe41382b ("Merge branch 'SLE15-SP6' into SUSE-2024")
- commit cd4d89d
* Fri Nov 15 2024 msuchanek@suse.de
- crypto: aes-gcm-p10 - Use the correct bit to test for P10
  (bsc#1232704).
- commit b7937ab
* Thu Nov 14 2024 shung-hsi.yu@suse.com
- Refresh patches.kabi/bpf-verifier-kABI-workarounds.patch (bsc#1233350)
  Correctly workaround kABI breakage that was introduced with fixes
  backported for bsc#1225903.
- commit 52684a5
* Thu Nov 14 2024 tiwai@suse.de
- ASoC: SOF: ipc4-topology: Only handle dai_config with HW_PARAMS
  for ChainDMA (bsc#1233305).
- commit 1b06409
* Wed Nov 13 2024 krisman@suse.de
- io_uring/rw: fix missing NOWAIT check for O_DIRECT start write
  (git-fixes).
- io_uring/sqpoll: close race on waiting for sqring entries
  (git-fixes).
- commit 83eaece
* Wed Nov 13 2024 mgorman@suse.de
- mm: shmem: fix data-race in shmem_getattr() (CVE-2024-50228,
  bsc#1233204, git fixes (mm/shmem)).
- commit 89c94b7
* Wed Nov 13 2024 jslaby@suse.cz
- irqchip/gic-v4: Correctly deal with set_affinity on
  lazily-mapped VPEs (CVE-2024-50192 bsc#1233106).
- commit 4258dbe
* Wed Nov 13 2024 jslaby@suse.cz
- irqchip/gic-v4: Don't allow a VMOVP on a dying VPE
  (CVE-2024-50192 bsc#1233106).
- kABI: Don't allow a VMOVP on a dying VPE (kabi CVE-2024-50192
  bsc#1233106).
- irqchip/gic-v3-its: Avoid explicit cpumask allocation on stack
  (git-fixes).
- commit 9bd7834
* Wed Nov 13 2024 sjaeckel@suse.de
- kABI fix for - Bluetooth: L2CAP: Fix
  div-by-zero in l2cap_le_flowctl_init()
  (CVE-2024-36968 bsc#1226130). - Refresh
  patches.suse/Bluetooth-Ignore-too-large-handle-values-in-BIG.patch.
- Refresh
  patches.suse/Bluetooth-L2CAP-Fix-deadlock.patch. - Refresh
  patches.suse/Bluetooth-btnxpuart-Enable-Power-Save-feature-on-sta.patch.
- Refresh
  patches.suse/bluetooth-hci-disallow-setting-handle-bigger-than-HC.patch.
- Refresh
  patches.suse/bluetooth-l2cap-sync-sock-recv-cb-and-release.patch.
- commit d93ac77
* Wed Nov 13 2024 tbogendoerfer@suse.de
- macsec: Fix use-after-free while sending the offloading packet
  (CVE-2024-50261 bsc#1233253).
- commit 493a21e
* Wed Nov 13 2024 tiwai@suse.de
- kABI workaround for ASoC SOF (bsc#1233305).
- commit d8b041e
* Wed Nov 13 2024 tiwai@suse.de
- ASoC: SOF: ipc4-topology: Add definition for generic switch/enum
  control (bsc#1233305).
- Refresh
  patches.suse/ASoC-SOF-ipc4-topology-Correct-data-structures-for-t-e238b68.patch.
- commit 6d4ee28
* Wed Nov 13 2024 tiwai@suse.de
- ASoC: SOF: topology: Parse DAI type token for dspless mode
  (bsc#1233305).
- ASoC: SOF: topology: dynamically allocate and store DAI
  widget->private (bsc#1233305).
- ASoC: SOF: ipc4-topology: change chain_dma handling in
  dai_config (bsc#1233305).
- ASoC: SOF: ipc4-topology: set config_length based on
  device_count (bsc#1233305).
- ASoC: SOF: Rename amd_bt sof_dai_type (bsc#1233305).
- ASoC: SOF: Add i2s bt dai configuration support for AMD
  platforms (bsc#1233305).
- ASoC: SOF: Refactor sof_i2s_tokens reading to update acpbt dai
  (bsc#1233305).
- ASoC: SOF: IPC4: synchronize fw_config_params with fw
  definitions (bsc#1233305).
- ASoC: SOF: Wire up buffer flags (bsc#1233305).
- ASoC: SOF: add alignment for topology header file struct
  definition (bsc#1233305).
- ASoC: SOF: align topology header file with sof topology header
  (bsc#1233305).
- ASoC: SOF: ipc4-topology: Add module ID print during module
  set up (bsc#1233305).
- ASoC: SOF: ipc4: Add data struct for module notification
  message from firmware (bsc#1233305).
- ASoC: SOF: ipc4-topology: Helper to find an swidget by
  module/instance id (bsc#1233305).
- ASoC: SOF: Add support for configuring PDM interface from
  topology (bsc#1233305).
- ASoC: SOF: IPC4: get pipeline priority from topology
  (bsc#1233305).
- ASoC: SOF: ipc4-mtrace: move debug slot related definitions
  to header.h (bsc#1233305).
- ASoC: SOF: ipc4-control: Add support for ALSA enum control
  (bsc#1233305).
- ASoC: SOF: ipc4-control: Add support for ALSA switch control
  (bsc#1233305).
- ASoC: SOF: ipc4-topology: export
  sof_ipc4_copier_is_single_format (bsc#1233305).
- ASoC: SOF: ipc4: Add new message type:
  SOF_IPC4_GLB_LOAD_LIBRARY_PREPARE (bsc#1233305).
- ASoC: SOF: ipc4-topology: Add deep buffer size to debug prints
  (bsc#1233305).
- ASoC: SOF: Deprecate invalid enums in IPC3 (bsc#1233305).
- commit ccbfc43
* Wed Nov 13 2024 tiwai@suse.de
- ima: fix buffer overrun in ima_eventdigest_init_common
  (git-fixes).
- commit 200c852
* Tue Nov 12 2024 vkarasulli@suse.de
- KVM: arm64: Fix shift-out-of-bounds bug (CVE-2024-50139
  bsc#1233062).
- commit dc4add6
* Tue Nov 12 2024 vkarasulli@suse.de
- KVM: nSVM: Ignore nCR3[4:0] when loading PDPTEs from memory
  (CVE-2024-50115 bsc#1232919).
- commit b8f7c4d
* Tue Nov 12 2024 sjaeckel@suse.de
- Bluetooth: L2CAP: Fix div-by-zero in l2cap_le_flowctl_init()
  (CVE-2024-36968 bsc#1226130).
- Refresh
  patches.suse/Bluetooth-Ignore-too-large-handle-values-in-BIG.patch.
- Refresh patches.suse/Bluetooth-L2CAP-Fix-deadlock.patch.
- Refresh
  patches.suse/Bluetooth-btnxpuart-Enable-Power-Save-feature-on-sta.patch.
- Refresh
  patches.suse/bluetooth-hci-disallow-setting-handle-bigger-than-HC.patch.
- Refresh
  patches.suse/bluetooth-l2cap-sync-sock-recv-cb-and-release.patch.
- commit c95a285
* Tue Nov 12 2024 sjaeckel@suse.de
- net: sched: fix use-after-free in taprio_change()
  (CVE-2024-50127 bsc#1232907).
- commit 8d80c7f
* Tue Nov 12 2024 rgoldwyn@suse.com
- fsdax: dax_unshare_iter needs to copy entire blocks
  (bsc#1233226, CVE-2024-50250).
- fsdax: remove zeroing code from dax_unshare_iter  (bsc#1233226,
  CVE-2024-50250).
- commit 94457ab
* Tue Nov 12 2024 ailiop@suse.com
- nilfs2: fix kernel bug due to missing clearing of checked flag
  (bsc#1233206 CVE-2024-50230).
- commit ba9ac5c
* Tue Nov 12 2024 tzimmermann@suse.com
- drm/amd/display: Check null pointers before used (bsc#1232371 CVE-2024-49921)
- commit 3bf6629
* Mon Nov 11 2024 tbogendoerfer@suse.de
- net/ncsi: Disable the ncsi work before freeing the associated
  structure (CVE-2024-49945 bsc#1232165).
- commit 75d875c
* Mon Nov 11 2024 tbogendoerfer@suse.de
- e1000e: Remove Meteor Lake SMBUS workarounds (git-fixes).
- i40e: fix race condition by adding filter's intermediate sync
  state (git-fixes).
- commit f4e661d
* Mon Nov 11 2024 jack@suse.cz
- Revert "mm/writeback: fix possible divide-by-zero in
  wb_dirty_limits(), again" (CVE-2024-42102 bsc#1233132).
- commit 696592c
* Mon Nov 11 2024 tiwai@suse.de
- i2c: designware: do not hold SCL low when I2C_DYNAMIC_TAR_UPDATE
  is not set (git-fixes).
- USB: serial: io_edgeport: fix use after free in debug printk
  (git-fixes).
- usb: typec: fix potential out of bounds in
  ucsi_ccg_update_set_new_cam_cmd() (git-fixes).
- usb: musb: sunxi: Fix accessing an released usb phy (git-fixes).
- commit d16f490
* Sat Nov  9 2024 tiwai@suse.de
- ASoC: stm: Prevent potential division by zero in
  stm32_sai_get_clk_div() (stable-fixes).
- ASoC: stm: Prevent potential division by zero in
  stm32_sai_mclk_round_rate() (stable-fixes).
- ASoC: amd: yc: Support dmic on another model of Lenovo Thinkpad
  E14 Gen 6 (stable-fixes).
- ASoC: amd: yc: fix internal mic on Xiaomi Book Pro 14 2022
  (stable-fixes).
- ASoC: tas2781: Add new driver version for tas2563 & tas2781
  qfn chip (stable-fixes).
- commit 1f9992e
* Sat Nov  9 2024 tiwai@suse.de
- drm/amdgpu: Fix DPX valid mode check on GC 9.4.3 (git-fixes).
- ASoC: SOF: sof-client-probes-ipc4: Set param_size extension bits
  (git-fixes).
- ASoC: stm32: spdifrx: fix dma channel release in
  stm32_spdifrx_remove (git-fixes).
- ALSA: firewire-lib: fix return value on fail in
  amdtp_tscm_init() (git-fixes).
- media: pulse8-cec: fix data timestamp at pulse8_setup()
  (git-fixes).
- media: stb0899_algo: initialize cfr before using it (git-fixes).
- media: adv7604: prevent underflow condition when reporting
  colorspace (git-fixes).
- media: cx24116: prevent overflows on SNR calculus (git-fixes).
- media: ar0521: don't overflow when checking PLL values
  (git-fixes).
- media: s5p-jpeg: prevent buffer overflows (git-fixes).
- media: dvb_frontend: don't play tricks with underflow values
  (git-fixes).
- media: dvbdev: prevent the risk of out of memory access
  (git-fixes).
- media: v4l2-tpg: prevent the risk of a division by zero
  (git-fixes).
- media: v4l2-ctrls-api: fix error handling for v4l2_g_ctrl()
  (git-fixes).
- thunderbolt: Honor TMU requirements in the domain when setting
  TMU mode (stable-fixes).
- wifi: iwlegacy: Clear stale interrupts before resuming device
  (stable-fixes).
- USB: gadget: dummy-hcd: Fix "task hung" problem (git-fixes).
- usb: gadget: dummy_hcd: execute hrtimer callback in softirq
  context (git-fixes).
- usb: gadget: dummy_hcd: Set transfer interval to 1 microframe
  (stable-fixes).
- usb: gadget: dummy_hcd: Switch to hrtimer transfer scheduler
  (stable-fixes).
- commit c5281d0
* Sat Nov  9 2024 ailiop@suse.com
- nfs: avoid i_lock contention in nfs_clear_invalid_mapping
  (git-fixes).
- commit e6016a1
* Sat Nov  9 2024 ailiop@suse.com
- nfs: Fix KMSAN warning in decode_getfattr_attrs() (git-fixes).
- commit 9358249
* Sat Nov  9 2024 ailiop@suse.com
- NFS: remove revoked delegation from server's delegation list
  (git-fixes).
- commit 6feb8eb
* Sat Nov  9 2024 ailiop@suse.com
- SUNRPC: Remove BUG_ON call sites (git-fixes).
- commit 5969339
* Sat Nov  9 2024 ailiop@suse.com
- nilfs2: fix potential deadlock with newly created symlinks
  (git-fixes).
- commit 002996c
* Fri Nov  8 2024 ggherdovich@suse.cz
- cpufreq: amd-pstate: add check for cpufreq_cpu_get's return
  value (CVE-2024-50009 bsc#1232318).
- commit 15f7e86
* Fri Nov  8 2024 jack@suse.cz
- ext4: fix error message when rejecting the default hash
  (bsc#1232264 CVE-2024-49968).
- commit 5d137c7
* Fri Nov  8 2024 ggherdovich@suse.cz
- sched/deadline: Fix task_struct reference leak (CVE-2024-41023
  bsc#1228430).
- commit 3a83981
* Fri Nov  8 2024 tbogendoerfer@suse.de
- be2net: fix potential memory leak in be_xmit() (CVE-2024-50167
  bsc#1233049).
- commit 376f8c7
* Fri Nov  8 2024 tiwai@suse.de
- can: mcp251xfd: mcp251xfd_get_tef_len(): fix length calculation
  (git-fixes).
- can: mcp251xfd: mcp251xfd_ring_alloc(): fix coalescing
  configuration when switching CAN modes (git-fixes).
- can: c_can: fix {rx,tx}_errors statistics (git-fixes).
- pwm: imx-tpm: Use correct MODULO value for EPWM mode
  (git-fixes).
- commit c5fa961
* Thu Nov  7 2024 dsterba@suse.com
- blk-rq-qos: fix crash on rq_qos_wait vs. rq_qos_wake_function race (CVE-2024-50082 bsc#1232500)
- commit 6a67bac
* Thu Nov  7 2024 dsterba@suse.com
- btrfs: fix uninitialized pointer free on read_alloc_one_name() error (CVE-2024-50087 bsc#1232499)
- commit a3c097a
* Thu Nov  7 2024 dsterba@suse.com
- btrfs: fix uninitialized pointer free in add_inode_ref() (CVE-2024-50088 bsc#1232498)
- commit 75b1127
* Thu Nov  7 2024 dsterba@suse.com
- net: microchip: vcap api: Fix memory leaks in vcap_api_encode_rule_test() (CVE-2024-50084 bsc#1232494)
- commit e53e21a
* Thu Nov  7 2024 dsterba@suse.com
- drm/amd/display: fix double free issue during amdgpu module unload (CVE-2024-49989 bsc#1232483)
- commit 6511376
* Thu Nov  7 2024 dsterba@suse.com
- drm/amd/display: update DML2 policy EnhancedPrefetchScheduleAccelerationFinal DCN35 (CVE-2024-50004 bsc#1232396)
- commit d5739f8
* Thu Nov  7 2024 dsterba@suse.com
- drm/amd/display: Fix system hang while resume with TBT monitor (CVE-2024-50003 bsc#1232385)
- commit 24ceb7a
* Thu Nov  7 2024 tiwai@suse.de
- thermal: intel: int340x: processor: Fix warning during module
  unload (git-fixes).
- commit 2c3d870
* Thu Nov  7 2024 sjaeckel@suse.de
- mptcp: fix double-free on socket dismantle (CVE-2024-26782
  bsc#1222590).
- mptcp: deal with large GSO size (CVE-2023-52778 bsc#1224948).
- commit 86ee052
* Thu Nov  7 2024 jack@suse.cz
- ext4: ext4_search_dir should return a proper error (bsc#1231920
  CVE-2024-47701).
- commit 7c02130
* Thu Nov  7 2024 jack@suse.cz
- ext4: explicitly exit when ext4_find_inline_entry returns an
  error (bsc#1231920 CVE-2024-47701).
- commit e600961
* Thu Nov  7 2024 jack@suse.cz
- ext4: return error on ext4_find_inline_entry (bsc#1231920
  CVE-2024-47701).
- commit 39b6acc
* Thu Nov  7 2024 tbogendoerfer@suse.de
- igb: Disable threaded IRQ for igb_msix_other (git-fixes).
- commit b8afad1
* Thu Nov  7 2024 jack@suse.cz
- fs/inode: Prevent dump_mapping() accessing invalid
  dentry.d_name.name (bsc#1232387 CVE-2024-49934).
- commit cf2a806
* Thu Nov  7 2024 jack@suse.cz
- ext4: filesystems without casefold feature cannot be mounted
  with siphash (bsc#1232264 CVE-2024-49968).
- commit 1907014
* Thu Nov  7 2024 jack@suse.cz
- ext4: drop ppath from ext4_ext_replay_update_ex() to avoid
  double-free (bsc#1232096 CVE-2024-49983).
- commit 4a6ac53
* Thu Nov  7 2024 jack@suse.cz
- vfs: fix race between evice_inodes() and find_inode()&iput()
  (bsc#1231930 CVE-2024-47679).
- commit dcf9f6e
* Thu Nov  7 2024 jack@suse.cz
- ext4: avoid OOB when system.data xattr changes underneath the
  filesystem (bsc#1231920 CVE-2024-47701).
- commit f292cb3
* Thu Nov  7 2024 tiwai@suse.de
- security/keys: fix slab-out-of-bounds in key_task_permission
  (git-fixes).
- platform/x86/amd/pmc: Detect when STB is not available
  (git-fixes).
- HID: core: zero-initialize the report buffer (git-fixes).
- commit 277fa5f
* Thu Nov  7 2024 tbogendoerfer@suse.de
- mlxbf_gige: disable RX filters until RX path initialized
  (git-fixes).
- commit f2b07e9
* Thu Nov  7 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add tests for sdiv/smod overflow cases
  (CVE-2024-49888 bsc#1232208).
- commit b193d4f
* Thu Nov  7 2024 ddiss@suse.de
- initramfs: avoid filename buffer overrun (bsc#1232436).
- commit 4918398
* Thu Nov  7 2024 shung-hsi.yu@suse.com
- netfilter: bpf: must hold reference on net namespace
  (bsc#1232894 CVE-2024-50130).
- commit 7d292ad
* Thu Nov  7 2024 shung-hsi.yu@suse.com
- bpftool: Fix undefined behavior in qsort(NULL, 0,
  ...) (bsc#1232258 CVE-2024-49987).
- commit 80f8e64
* Wed Nov  6 2024 mhocko@suse.com
- Update
  patches.suse/mm-mmap-no-need-to-call-khugepaged_enter_vma-for-sta.patch
  (jsc#PED-11442).
- commit d087a3b
* Wed Nov  6 2024 jlee@suse.com
- fbdev: efifb: Register sysfs groups through driver core
  (bsc#1232224 CVE-2024-49925).
- commit 4fd0365
* Wed Nov  6 2024 msuchanek@suse.de
- aes-gcm-p10: Use the correct bit to test for P10 (bsc#1232704).
- commit f0dea0e
* Tue Nov  5 2024 krisman@suse.de
- ublk: don't allow user copy for unprivileged device
  (CVE-2024-50080 bsc#1232502).
- commit 267c92f
* Tue Nov  5 2024 krisman@suse.de
- blk-mq: setup queue ->tag_set before initializing hctx
  (CVE-2024-50081 bsc#1232501).
- commit 87d4a82
* Tue Nov  5 2024 oneukum@suse.com
- media: core: v4l2-ioctl: check if ioctl is known to avoid NULL
  name (git-fixes).
- commit c862b93
* Tue Nov  5 2024 oneukum@suse.com
- media: videobuf2: fix typo: vb2_dbuf -> vb2_qbuf (git-fixes).
- commit 92209c4
* Tue Nov  5 2024 oneukum@suse.com
- media: bttv: use audio defaults for winfast2000 (git-fixes).
- commit 6e1da70
* Tue Nov  5 2024 mfranc@suse.cz
- scsi: elx: libefc: Fix potential use after free in
  efc_nport_vport_del() (CVE-2024-49852 bsc#1232819).
- commit 51395e6
* Tue Nov  5 2024 jwiesner@suse.de
- Update config files.
  c37e85c135ce ("clocksource: Loosen clocksource watchdog constraints")
  introduced a new default for the time skew measured by the clocksource
  watchdog. The value was raised from 100 to 125 microseconds. Reflect this
  change in the kernel config. This is an x86_64 option only.
- commit 14c1b2d
* Tue Nov  5 2024 tiwai@suse.de
- ALSA: usb-audio: Add quirk for HP 320 FHD Webcam (bsc#1232768).
- commit 7c39137
* Tue Nov  5 2024 shung-hsi.yu@suse.com
- kABI: bpf: struct bpf_func_state kABI workaround (CVE-2024-47703
  bsc#1231946).
- commit fd45833
* Tue Nov  5 2024 shung-hsi.yu@suse.com
- selftests/bpf: Workaround strict bpf_lsm return value check
  (CVE-2024-47703 bsc#1231946).
- selftests/bpf: Add verifier tests for bpf lsm (CVE-2024-47703
  bsc#1231946).
- selftests/bpf: Add return value checks for failed tests
  (CVE-2024-47703 bsc#1231946).
- bpf: Fix compare error in function retval_range_within
  (CVE-2024-47703 bsc#1231946).
- bpf, lsm: Add check for BPF LSM return value (CVE-2024-47703
  bsc#1231946).
- Refresh patches.suse/bpf-Fail-verification-for-sign-extension-of-packet-d.patch
- Refresh patches.kabi/bpf-struct-bpf_insn_access_aux-workaround.patch
- selftests/bpf: fix timer/test_bad_ret subtest on
  test_progs-cpuv4 flavor (CVE-2024-47703 bsc#1231946).
- commit a0c7d4f
* Tue Nov  5 2024 tiwai@suse.de
- rpmsg: glink: Handle rejected intent request better (git-fixes).
- firmware: arm_scmi: Fix slab-use-after-free in
  scmi_bus_notifier() (git-fixes).
- commit 01fe6bf
* Mon Nov  4 2024 dsterba@suse.com
- Update references for patches.suse/tracing-timerlat-Fix-a-race-during-cpuhp-processing.patch (CVE-2024-49866 bsc#1232259 git-fixes)
- commit d9311d0
* Mon Nov  4 2024 tiwai@suse.de
- Move out-of-tree patch into a proper section
- commit c581359
* Mon Nov  4 2024 tiwai@suse.de
- Revert "ALSA: hda/conexant: Mute speakers at suspend / shutdown"
  (bsc#1228269).
- commit 13ce240
* Mon Nov  4 2024 dwagner@suse.de
- scsi: lpfc: Update lpfc version to 14.4.0.5 (bsc#1232757).
- scsi: lpfc: Support loopback tests with VMID enabled
  (bsc#1232757).
- scsi: lpfc: Revise TRACE_EVENT log flag severities from KERN_ERR
  to KERN_WARNING (bsc#1232757).
- scsi: lpfc: Ensure DA_ID handling completion before deleting
  an NPIV instance (bsc#1232757).
- scsi: lpfc: Fix kref imbalance on fabric ndlps from dev_loss_tmo
  handler (bsc#1232757).
- scsi: lpfc: Restrict support for 32 byte CDBs to specific HBAs
  (bsc#1232757 bsc#1228119).
- scsi: lpfc: Update phba link state conditional before sending
  CMF_SYNC_WQE (bsc#1232757).
- scsi: lpfc: Add ELS_RSP cmd to the list of WQEs to flush in
  lpfc_els_flush_cmd() (bsc#1232757).
- scsi: lpfc: Remove trailing space after \n newline
  (bsc#1232757).
- commit 3cf27b4
* Mon Nov  4 2024 vkarasulli@suse.de
- ext4: fix timer use-after-free on failed mount (CVE-2024-49960
  bsc#1232395).
- commit bd6997d
* Mon Nov  4 2024 mfranc@suse.cz
- net/xen-netback: prevent UAF in xenvif_flush_hash()
  (CVE-2024-49936 bsc#1232424).
- commit ae05dab
* Mon Nov  4 2024 vkarasulli@suse.de
- tipc: guard against string buffer overrun (CVE-2024-49995
  bsc#1232432).
- commit ada263e
* Mon Nov  4 2024 tiwai@suse.de
- drm/amdkfd: amdkfd_free_gtt_mem clear the correct pointer
  (CVE-2024-49991 bsc#1232282).
- commit 1b15839
* Mon Nov  4 2024 dwagner@suse.de
- nvme: re-fix error-handling for io_uring nvme-passthrough
  (git-fixes).
- nvmet-auth: assign dh_key to NULL after kfree_sensitive
  (git-fixes).
- nvme-pci: fix race condition between reset and
  nvme_dev_disable() (git-fixes).
- nvme: null terminate nvme_tls_attrs (git-fixes).
- nvme-pci: set doorbell config before unquiescing (git-fixes).
- commit d7598b1
* Mon Nov  4 2024 vbabka@suse.cz
- mm: split critical region in remap_file_pages() and invoke
  LSMs in between (CVE-2024-47745 bsc#1232135 git-fix).
- commit 8228ecb
* Mon Nov  4 2024 tiwai@suse.de
- Add alt-commit to AMDGPU patch
- commit 9e50980
* Mon Nov  4 2024 tiwai@suse.de
- phy: tegra: xusb: Add error pointer check in xusb.c (git-fixes).
- phy: freescale: imx8m-pcie: Do CMN_RST just before PHY PLL
  lock check (git-fixes).
- phy: ti: phy-j721e-wiz: fix usxgmii configuration (git-fixes).
- phy: qcom: qmp-combo: move driver data initialisation earlier
  (git-fixes).
- phy: qcom: qmp-usb: fix NULL-deref on runtime suspend
  (git-fixes).
- dmaengine: ti: k3-udma: Set EOP for all TRs in cyclic BCDMA
  transfer (git-fixes).
- dmaengine: sh: rz-dmac: handle configs where one address is zero
  (git-fixes).
- Revert "driver core: Fix uevent_show() vs driver detach race"
  (git-fixes).
- usb: phy: Fix API devm_usb_put_phy() can not release the phy
  (git-fixes).
- usb: typec: fix unreleased fwnode_handle in
  typec_port_register_altmodes() (git-fixes).
- xhci: Fix Link TRB DMA in command ring stopped completion event
  (git-fixes).
- xhci: Use pm_runtime_get to prevent RPM on unsupported systems
  (git-fixes).
- usbip: tools: Fix detach_port() invalid port error path
  (git-fixes).
- iio: adc: ad7124: fix division by zero in
  ad7124_set_channel_odr() (git-fixes).
- staging: iio: frequency: ad9832: fix division by zero in
  ad9832_calc_freqreg() (git-fixes).
- iio: light: veml6030: fix microlux value calculation
  (git-fixes).
- iio: gts-helper: Fix memory leaks for the error path of
  iio_gts_build_avail_scale_table() (git-fixes).
- iio: gts-helper: Fix memory leaks in
  iio_gts_build_avail_scale_table() (git-fixes).
- mei: use kvmalloc for read buffer (git-fixes).
- Input: edt-ft5x06 - fix regmap leak when probe fails
  (git-fixes).
- modpost: fix input MODULE_DEVICE_TABLE() built for 64-bit on
  32-bit host (git-fixes).
- modpost: fix acpi MODULE_DEVICE_TABLE built with mismatched
  endianness (git-fixes).
- sumversion: Fix a memory leak in get_src_version() (git-fixes).
- genirq/msi: Fix off-by-one error in msi_domain_alloc()
  (git-fixes).
- commit df7fb9d
* Mon Nov  4 2024 jslaby@suse.cz
- Refresh
  patches.suse/PCI-Fix-pci_enable_acs-support-for-the-ACS-quirks.patch.
  Update upstream status.
- commit f283868
* Mon Nov  4 2024 neilb@suse.de
- nfsd: cancel nfsd_shrinker_work using sync mode in
  nfs4_state_shutdown_net (git-fixes).
- commit ed2b339
* Mon Nov  4 2024 neilb@suse.de
- NFSv3: only use NFS timeout for MOUNT when protocols are
  compatible (bsc#1231016).
- commit ddbeb4f
* Mon Nov  4 2024 jlee@suse.com
- Update
  patches.suse/0002-x86-mm-ident_map-Use-gbpages-only-where-full-GB-page.patch
  (bsc#1220382 CVE-2024-50017 bsc#1232312).
- Update patches.suse/ACPI-PAD-fix-crash-in-exit_round_robin.patch
  (stable-fixes CVE-2024-49935 bsc#1232370).
- Update
  patches.suse/ACPI-battery-Fix-possible-crash-when-unregistering-a.patch
  (git-fixes CVE-2024-49955 bsc#1232154).
- Update
  patches.suse/ACPI-sysfs-validate-return-type-of-_STR-method.patch
  (git-fixes CVE-2024-49860 bsc#1231861).
- Update
  patches.suse/ACPICA-check-null-return-of-ACPI_ALLOCATE_ZEROED-in-.patch
  (stable-fixes CVE-2024-49962 bsc#1232314).
- Update
  patches.suse/ALSA-asihpi-Fix-potential-OOB-array-access.patch
  (stable-fixes CVE-2024-50007 bsc#1232394).
- Update
  patches.suse/Bluetooth-Call-iso_exit-on-module-unload.patch
  (git-fixes CVE-2024-50078 bsc#1232503).
- Update
  patches.suse/Bluetooth-ISO-Fix-multiple-init-when-debugfs-is-disa.patch
  (git-fixes CVE-2024-50077 bsc#1232504).
- Update
  patches.suse/Bluetooth-RFCOMM-FIX-possible-deadlock-in-rfcomm_sk_.patch
  (git-fixes CVE-2024-50044 bsc#1231904).
- Update
  patches.suse/IB-core-Fix-ib_cache_setup_one-error-flow-cleanup.patch
  (git-fixes CVE-2024-47693 bsc#1232013).
- Update
  patches.suse/IB-core-Implement-a-limit-on-UMAD-receive-List.patch
  (bsc#1228743 CVE-2024-42145 bsc#1223384).
- Update
  patches.suse/Input-adp5589-keys-fix-NULL-pointer-dereference.patch
  (git-fixes CVE-2024-49871 bsc#1232287).
- Update
  patches.suse/KEYS-prevent-NULL-pointer-dereference-in-find_asymme.patch
  (git-fixes CVE-2024-47743 bsc#1232129).
- Update
  patches.suse/KVM-Use-dedicated-mutex-to-protect-kvm_usage_count-t.patch
  (git-fixes CVE-2024-47744 bsc#1232132).
- Update
  patches.suse/PCI-keystone-Fix-if-statement-expression-in-ks_pcie_.patch
  (git-fixes CVE-2024-47756 bsc#1232185).
- Update
  patches.suse/PCI-kirin-Fix-buffer-overflow-in-kirin_pcie_parse_po.patch
  (git-fixes CVE-2024-47751 bsc#1232127).
- Update
  patches.suse/RDMA-cxgb4-Added-NULL-check-for-lookup_atid.patch
  (git-fixes CVE-2024-47749 bsc#1232180).
- Update
  patches.suse/RDMA-hns-Fix-Use-After-Free-of-rsv_qp-on-HIP08.patch
  (git-fixes CVE-2024-47750 bsc#1232182).
- Update
  patches.suse/RDMA-hns-Fix-spin_unlock_irqrestore-called-with-IRQs.patch
  (git-fixes CVE-2024-47735 bsc#1232111).
- Update
  patches.suse/RDMA-iwcm-Fix-WARNING-at_kernel-workqueue.c-check_fl.patch
  (git-fixes CVE-2024-47696 bsc#1231864).
- Update
  patches.suse/RDMA-rtrs-clt-Reset-cid-to-con_num-1-to-stay-in-boun.patch
  (git-fixes CVE-2024-47695 bsc#1231931).
- Update
  patches.suse/RDMA-rtrs-srv-Avoid-null-pointer-deref-during-path-e.patch
  (git-fixes CVE-2024-50062 bsc#1232232).
- Update
  patches.suse/aoe-fix-the-potential-use-after-free-problem-in-more.patch
  (bsc#1218562 CVE-2023-6270 CVE-2024-49982 bsc#1232097).
- Update
  patches.suse/bpf-Fail-verification-for-sign-extension-of-packet-d.patch
  (git-fixes CVE-2024-47702 bsc#1231924).
- Update
  patches.suse/bpf-Fix-helper-writes-to-read-only-maps.patch
  (git-fixes CVE-2024-49861 bsc#1232254).
- Update
  patches.suse/bpf-Fix-use-after-free-in-bpf_uprobe_multi_link_attach.patch
  (git-fixes CVE-2024-47675 bsc#1231926).
- Update
  patches.suse/bpf-Zero-former-ARG_PTR_TO_-LONG-INT-args-in-case-of.patch
  (git-fixes CVE-2024-47728 bsc#1232076).
- Update
  patches.suse/bpf-correctly-handle-malformed-BPF_CORE_TYPE_ID_LOCA.patch
  (git-fixes CVE-2024-49850 bsc#1232189).
- Update
  patches.suse/cachefiles-fix-dentry-leak-in-cachefiles_open_file.patch
  (bsc#1231183 CVE-2024-49870 bsc#1232279).
- Update
  patches.suse/can-bcm-Clear-bo-bcm_proc_read-after-remove_proc_ent.patch
  (git-fixes CVE-2024-47709 bsc#1232048).
- Update
  patches.suse/crypto-iaa-Fix-potential-use-after-free-bug.patch
  (git-fixes CVE-2024-47732 bsc#1232109).
- Update
  patches.suse/cxl-pci-Fix-disabling-memory-if-DVSEC-CXL-Range-does.patch
  (git-fixes CVE-2024-26761 bsc#1230375).
- Update
  patches.suse/driver-core-Fix-a-potential-null-ptr-deref-in-module.patch
  (git-fixes CVE-2024-47688 bsc#1232009).
- Update
  patches.suse/driver-core-bus-Fix-double-free-in-driver-API-bus_re.patch
  (stable-fixes CVE-2024-50055 bsc#1232329).
- Update
  patches.suse/drivers-media-dvb-frontends-rtl2830-fix-an-out-of-bo.patch
  (git-fixes CVE-2024-47697 bsc#1231858).
- Update
  patches.suse/drivers-media-dvb-frontends-rtl2832-fix-an-out-of-bo.patch
  (git-fixes CVE-2024-47698 bsc#1231859).
- Update
  patches.suse/drm-amd-display-Add-null-check-for-set_output_gamma-.patch
  (git-fixes CVE-2024-47720 bsc#1232043).
- Update
  patches.suse/drm-amd-display-Check-null-pointer-before-dereferenc.patch
  (stable-fixes CVE-2024-50049 bsc#1232309).
- Update
  patches.suse/drm-amd-display-fixed-integer-types-and-null-check-l.patch
  (git-fixes CVE-2024-26767 bsc#1230339).
- Update
  patches.suse/drm-omapdrm-Add-missing-check-for-alloc_ordered_work.patch
  (git-fixes CVE-2024-49879 bsc#1232349).
- Update
  patches.suse/drm-v3d-Stop-the-active-perfmon-before-being-destroy.patch
  (git-fixes CVE-2024-50031 bsc#1231947).
- Update
  patches.suse/efistub-tpm-Use-ACPI-reclaim-memory-for-event-log-to.patch
  (stable-fixes CVE-2024-49858 bsc#1232251).
- Update
  patches.suse/ep93xx-clock-Fix-off-by-one-in-ep93xx_div_recalc_rat.patch
  (git-fixes CVE-2024-47686 bsc#1232000).
- Update
  patches.suse/exfat-fix-memory-leak-in-exfat_load_bitmap.patch
  (git-fixes CVE-2024-50013 bsc#1232080).
- Update
  patches.suse/fbcon-Fix-a-NULL-pointer-dereference-issue-in-fbcon_.patch
  (stable-fixes CVE-2024-50048 bsc#1232310).
- Update
  patches.suse/firmware-arm_scmi-Fix-double-free-in-OPTEE-transport.patch
  (git-fixes CVE-2024-49853 bsc#1232192).
- Update patches.suse/firmware_loader-Block-path-traversal.patch
  (git-fixes CVE-2024-47742 bsc#1232126).
- Update
  patches.suse/i2c-stm32f7-Do-not-prepare-unprepare-clock-during-ru.patch
  (git-fixes CVE-2024-49985 bsc#1232094).
- Update
  patches.suse/i3c-master-cdns-Fix-use-after-free-vulnerability-in-.patch
  (stable-fixes CVE-2024-50061 bsc#1232263).
- Update
  patches.suse/i3c-master-svc-Fix-use-after-free-vulnerability-in-s.patch
  (git-fixes CVE-2024-49874 bsc#1232295).
- Update
  patches.suse/i40e-Fix-XDP-program-unloading-while-removing-the-dr.patch
  (git-fixes CVE-2024-41047 bsc#1228537).
- Update
  patches.suse/idpf-fix-UAFs-when-destroying-the-queues.patch
  (git-fixes CVE-2024-44932 bsc#1229808).
- Update
  patches.suse/idpf-fix-memory-leaks-and-crashes-while-performing-a.patch
  (git-fixes CVE-2024-44964 bsc#1230220).
- Update
  patches.suse/iommufd-Protect-against-overflow-of-ALIGN-during-iov.patch
  (git-fixes CVE-2024-47719 bsc#1231865).
- Update
  patches.suse/jffs2-prevent-xattr-node-from-overflowing-the-eraseblock.patch
  (git-fixes CVE-2024-38599 bsc#1226848 bsc#1223384).
- Update patches.suse/jfs-Fix-uaf-in-dbFreeBits.patch (git-fixes
  CVE-2024-49903 bsc#1232362).
- Update
  patches.suse/jfs-Fix-uninit-value-access-of-new_ea-in-ea_buffer.patch
  (git-fixes CVE-2024-49900 bsc#1232359).
- Update
  patches.suse/jfs-check-if-leafidx-greater-than-num-leaves-per-dmap-tree.patch
  (git-fixes CVE-2024-49902 bsc#1232378).
- Update
  patches.suse/jfs-fix-out-of-bounds-in-dbNextAG-and-diAlloc.patch
  (git-fixes CVE-2024-47723 bsc#1232050).
- Update
  patches.suse/mailbox-bcm2835-Fix-timeout-during-suspend-mode.patch
  (git-fixes CVE-2024-49963 bsc#1232147).
- Update
  patches.suse/md-Don-t-ignore-suspended-array-in-md_check_recovery-1baa.patch
  (bsc#1219596 CVE-2024-26758 bsc#1230341).
- Update patches.suse/media-edia-dvbdev-fix-a-use-after-free.patch
  (git-fixes CVE-2024-27043 bsc#1223824 bsc#1218562).
- Update
  patches.suse/media-i2c-ar0521-Use-cansleep-version-of-gpiod_set_v.patch
  (git-fixes CVE-2024-49961 bsc#1232148).
- Update
  patches.suse/media-venus-fix-use-after-free-bug-in-venus_remove-d.patch
  (git-fixes CVE-2024-49981 bsc#1232098).
- Update
  patches.suse/nbd-fix-race-between-timeout-and-normal-completion.patch
  (bsc#1230918 CVE-2024-49855 bsc#1232195).
- Update
  patches.suse/net-phy-Remove-LED-entry-from-LEDs-list-on-unregiste.patch
  (git-fixes CVE-2024-50023 bsc#1231955).
- Update
  patches.suse/net-test-for-not-too-small-csum_start-in-virtio_net_.patch
  (git-fixes CVE-2024-49947 bsc#1232162).
- Update
  patches.suse/nfsd-call-cache_put-if-xdr_reserve_space-returns-NULL.patch
  (git-fixes CVE-2024-47737 bsc#1232056).
- Update
  patches.suse/nfsd-map-the-EBADMSG-to-nfserr_io-to-avoid-warning.patch
  (git-fixes CVE-2024-49875 bsc#1232333).
- Update
  patches.suse/nilfs2-fix-potential-null-ptr-deref-in-nilfs_btree_insert.patch
  (git-fixes CVE-2024-47699 bsc#1231916).
- Update
  patches.suse/nilfs2-fix-potential-oob-read-in-nilfs_btree_check_delete.patch
  (git-fixes CVE-2024-47757 bsc#1232187).
- Update
  patches.suse/nouveau-dmem-handle-kcalloc-allocation-failure.patch
  (git-fixes CVE-2024-26943 bsc#1230527).
- Update
  patches.suse/ocfs2-cancel-dqi_sync_work-before-freeing-oinfo.patch
  (git-fixes CVE-2024-49966 bsc#1232141).
- Update
  patches.suse/ocfs2-fix-null-ptr-deref-when-journal-load-failed.patch
  (git-fixes CVE-2024-49957 bsc#1232152).
- Update
  patches.suse/ocfs2-fix-possible-null-ptr-deref-in-ocfs2_set_buffer_uptodate.patch
  (git-fixes CVE-2024-49877 bsc#1232339).
- Update
  patches.suse/ocfs2-remove-unreasonable-unlock-in-ocfs2_read_blocks.patch
  (git-fixes CVE-2024-49965 bsc#1232142).
- Update
  patches.suse/parport-Proper-fix-for-array-out-of-bounds-access.patch
  (git-fixes CVE-2024-50074 bsc#1232507).
- Update
  patches.suse/pinctrl-apple-check-devm_kasprintf-returned-value.patch
  (git-fixes CVE-2024-50069 bsc#1232511).
- Update
  patches.suse/platform-x86-ISST-Fix-the-KASAN-report-slab-out-of-b.patch
  (git-fixes CVE-2024-49886 bsc#1232196).
- Update
  patches.suse/powercap-intel_rapl-Fix-off-by-one-in-get_rpi.patch
  (git-fixes CVE-2024-49862 bsc#1231871).
- Update
  patches.suse/resource-fix-region_intersects-vs-add_memory_driver_.patch
  (git-fixes CVE-2024-49878 bsc#1232340).
- Update
  patches.suse/scsi-fnic-Move-flush_work-initialization-out-of-if-b.patch
  (bsc#1230055 CVE-2024-50025 bsc#1231953).
- Update
  patches.suse/scsi-lpfc-validate-hdwq-pointers-before-dereferencing-in.patch
  (bsc#1229429 jsc#PED-9899 CVE-2024-49891 bsc#1232218).
- Update
  patches.suse/scsi-sd-Fix-off-by-one-error-in-sd_read_block_charac.patch
  (bsc#1223848 CVE-2024-47682 bsc#1231856).
- Update
  patches.suse/serial-protect-uart_port_dtr_rts-in-uart_shutdown-to.patch
  (stable-fixes CVE-2024-50058 bsc#1232285).
- Update
  patches.suse/tpm-Clean-up-TPM-space-after-command-failure.patch
  (git-fixes CVE-2024-49851 bsc#1232134).
- Update
  patches.suse/tty-n_gsm-Fix-use-after-free-in-gsm_cleanup_mux.patch
  (stable-fixes CVE-2024-50073 bsc#1232520).
- Update
  patches.suse/vhost-scsi-null-ptr-dereference-in-vhost_scsi_get_re.patch
  (git-fixes CVE-2024-49863 bsc#1232255).
- Update
  patches.suse/vhost_vdpa-assign-irq-bypass-producer-token-correctl.patch
  (git-fixes CVE-2024-47748 bsc#1232174).
- Update patches.suse/vmxnet3-Fix-missing-reserved-tailroom.patch
  (bsc#1226498 CVE-2024-27026 bsc#1223700).
- Update
  patches.suse/vt-prevent-kernel-infoleak-in-con_font_get.patch
  (git-fixes CVE-2024-50076 bsc#1232505).
- Update
  patches.suse/wifi-ath11k-fix-array-out-of-bound-access-in-SoC-sta.patch
  (stable-fixes CVE-2024-49930 bsc#1232260).
- Update
  patches.suse/wifi-ath12k-fix-array-out-of-bound-access-in-SoC-sta.patch
  (stable-fixes CVE-2024-49931 bsc#1232275).
- Update
  patches.suse/wifi-ath9k_htc-Use-__skb_set_length-for-resetting-ur.patch
  (stable-fixes CVE-2024-49938 bsc#1232552).
- Update
  patches.suse/wifi-cfg80211-Set-correct-chandef-when-starting-CAC.patch
  (stable-fixes CVE-2024-49937 bsc#1232427).
- Update
  patches.suse/wifi-iwlwifi-mvm-avoid-NULL-pointer-dereference.patch
  (stable-fixes CVE-2024-49929 bsc#1232253).
- Update
  patches.suse/wifi-mac80211-don-t-use-rate-mask-for-offchannel-TX-.patch
  (git-fixes CVE-2024-47738 bsc#1232114).
- Update
  patches.suse/wifi-mac80211-use-two-phase-skb-reclamation-in-ieee8.patch
  (git-fixes CVE-2024-47713 bsc#1232016).
- Update
  patches.suse/wifi-mt76-mt7915-fix-oops-on-non-dbdc-mt7986.patch
  (git-fixes CVE-2024-47715 bsc#1231860).
- Update
  patches.suse/wifi-mt76-mt7996-fix-NULL-pointer-dereference-in-mt7.patch
  (git-fixes CVE-2024-47681 bsc#1231855).
- Update
  patches.suse/wifi-mt76-mt7996-use-hweight16-to-get-correct-tx-ant.patch
  (git-fixes CVE-2024-47714 bsc#1232018).
- Update
  patches.suse/wifi-mwifiex-Fix-memcpy-field-spanning-write-warning.patch
  (stable-fixes CVE-2024-50008 bsc#1232317).
- Update
  patches.suse/wifi-rtw88-always-wait-for-both-firmware-loading-att.patch
  (git-fixes CVE-2024-47718 bsc#1232015).
- Update
  patches.suse/wifi-rtw89-avoid-reading-out-of-bounds-when-loading-.patch
  (stable-fixes CVE-2024-49928 bsc#1232250).
- Update
  patches.suse/wifi-rtw89-avoid-to-add-interface-to-list-twice-when.patch
  (stable-fixes CVE-2024-49939 bsc#1232381).
- Update
  patches.suse/wifi-wilc1000-fix-potential-RCU-dereference-issue-in.patch
  (git-fixes CVE-2024-47712 bsc#1232017).
- Update
  patches.suse/xhci-tegra-fix-checked-USB2-port-number.patch
  (git-fixes CVE-2024-50075 bsc#1232506).
- commit a270265
* Mon Nov  4 2024 jlee@suse.com
- Update
  patches.suse/i3c-mipi-i3c-hci-Fix-out-of-bounds-access-in-hci_dma.patch
  (git-fixes CVE-2023-52766 bsc#1230620).
- Update
  patches.suse/media-pci-cx23885-check-cx23885_vdev_init-return.patch
  (stable-fixes CVE-2023-52918 bsc#1232047).
- Update
  patches.suse/nfc-nci-fix-possible-NULL-pointer-dereference-in-sen.patch
  (git-fixes CVE-2023-52919 bsc#1231988).
- Update
  patches.suse/ntb-intel-Fix-the-NULL-vs-IS_ERR-bug-for-debugfs_cre.patch
  (git-fixes CVE-2023-52917 bsc#1231849).
- Update
  patches.suse/tcp-do-not-accept-ACK-of-bytes-we-never-sent.patch
  (CVE-2023-52881 bsc#1225611 bsc#1223384).
- Update patches.suse/wifi-ath11k-fix-htt-pktlog-locking.patch
  (git-fixes CVE-2023-52800 bsc#1230600).
- commit 9859953
* Mon Nov  4 2024 neilb@suse.de
- NFSD: Force all NFSv4.2 COPY requests to be synchronous
  (CVE-2024-49974 bsc#1232383).
- commit 16045fc
* Sun Nov  3 2024 petr.pavlu@suse.com
- fgraph: Change the name of cpuhp state to "fgraph:online"
  (git-fixes).
- commit 59421b3
* Sun Nov  3 2024 petr.pavlu@suse.com
- fgraph: Fix missing unlock in register_ftrace_graph()
  (git-fixes).
- commit 60d91ed
* Sun Nov  3 2024 ailiop@suse.com
- fs/9p: drop inodes immediately on non-.L too (git-fixes).
- commit 5fa5f19
* Sun Nov  3 2024 ailiop@suse.com
- 9p: explicitly deny setlease attempts (git-fixes).
- commit 474852b
* Sun Nov  3 2024 ailiop@suse.com
- fs/9p: fix the cache always being enabled on files with qid
  flags (git-fixes).
- commit 362152c
* Sun Nov  3 2024 ailiop@suse.com
- zonefs: Improve error handling (git-fixes).
- commit cb63c4c
* Sun Nov  3 2024 ailiop@suse.com
- debugfs: fix automount d_fsdata usage (git-fixes).
- commit 5f78a06
* Sun Nov  3 2024 ailiop@suse.com
- splice: fsnotify_access(in), fsnotify_modify(out) on success
  in tee (git-fixes).
- commit d518e6d
* Sun Nov  3 2024 ailiop@suse.com
- splice: fsnotify_access(fd)/fsnotify_modify(fd) in vmsplice
  (git-fixes).
- commit d630f18
* Sun Nov  3 2024 ailiop@suse.com
- splice: always fsnotify_access(in), fsnotify_modify(out)
  on success (git-fixes).
- commit e7f8947
* Sun Nov  3 2024 ailiop@suse.com
- keys: Fix overwrite of key expiration on instantiation
  (git-fixes).
- commit 323181d
* Sun Nov  3 2024 ailiop@suse.com
- audit: don't WARN_ON_ONCE(!current->mm) in audit_exe_compare()
  (git-fixes).
- commit e2db423
* Sun Nov  3 2024 ailiop@suse.com
- ocfs2: fix uninit-value in ocfs2_get_block() (git-fixes).
- commit 426a4b1
* Sun Nov  3 2024 ailiop@suse.com
- keys, dns: Allow key types (eg. DNS) to be reclaimed immediately
  on expiry (git-fixes).
- commit ce262a7
* Sun Nov  3 2024 ailiop@suse.com
- Revert "KEYS: encrypted: Add check for strsep" (git-fixes).
- commit 7aa308c
* Sun Nov  3 2024 ailiop@suse.com
- ubifs: add check for crypto_shash_tfm_digest (git-fixes).
- commit ea9ba15
* Sun Nov  3 2024 ailiop@suse.com
- ubifs: dbg_orphan_check: Fix missed key type checking
  (git-fixes).
- commit 465ad1a
* Sun Nov  3 2024 ailiop@suse.com
- ubifs: Fix adding orphan entry twice for the same inode
  (git-fixes).
- commit 93096ab
* Sun Nov  3 2024 ailiop@suse.com
- Revert "ubifs: ubifs_symlink: Fix memleak of inode->i_link in
  error path" (git-fixes).
- commit 0a7c17d
* Sun Nov  3 2024 ailiop@suse.com
- ubifs: Fix unattached xattr inode if powercut happens after
  deleting (git-fixes).
- commit 6c90268
* Sun Nov  3 2024 ailiop@suse.com
- audit: don't take task_lock() in audit_exe_compare() code path
  (git-fixes).
- Refresh patches.suse/vfs-add-super_operations-get_inode_dev.
- commit d4e23ef
* Sun Nov  3 2024 petr.pavlu@suse.com
- uprobes: fix kernel info leak via "[uprobes]" vma (bsc#1231114
  CVE-2024-46828).
- uprobes: turn xol_area->pages into xol_area->page (bsc#1231114).
- uprobes: introduce the global struct vm_special_mapping
  xol_mapping (bsc#1231114).
- commit 4f9954c
* Sun Nov  3 2024 petr.pavlu@suse.com
- sched: sch_cake: fix bulk flow accounting logic for host
  fairness (bsc#1231114 CVE-2024-46828).
- commit ad42d5f
* Sun Nov  3 2024 ailiop@suse.com
- xfs: fix finding a last resort AG in xfs_filestream_pick_ag
  (git-fixes).
- commit a10af4c
* Sat Nov  2 2024 petr.pavlu@suse.com
- static_call: Handle module init failure correctly in
  static_call_del_module() (bsc#1232083 CVE-2024-50002).
- commit af953b9
* Sat Nov  2 2024 tiwai@suse.de
- ALSA: hda/realtek: Refactor and simplify Samsung Galaxy Book
  init (stable-fixes).
- Refresh
  patches.suse/ALSA-hda-realtek-Add-quirk-for-Huawei-MateBook-13-KL.patch.
- commit 98d4026
* Sat Nov  2 2024 tiwai@suse.de
- ALSA: hda/realtek: Enable mic on Vaio VJFH52 (stable-fixes).
- commit 7075c22
* Sat Nov  2 2024 tiwai@suse.de
- ALSA: hda/realtek: tas2781: Fix ROG ALLY X audio (stable-fixes).
- commit e26a542
* Sat Nov  2 2024 tiwai@suse.de
- ALSA: hda/realtek: Fix headset mic on TUXEDO Stellaris 16 Gen6
  mb1 (stable-fixes).
- ALSA: hda/realtek: Fix headset mic on TUXEDO Gemini 17 Gen3
  (stable-fixes).
- ALSA: usb-audio: Add quirks for Dell WD19 dock (stable-fixes).
- ASoC: dapm: fix bounds checker error in dapm_widget_list_create
  (git-fixes).
- ASoC: Intel: sst: Fix used of uninitialized ctx to log an error
  (git-fixes).
- ASoC: Intel: sst: Support LPE0F28 ACPI HID (stable-fixes).
- ASoC: Intel: bytcr_rt5640: Add DMI quirk for Vexia Edu Atla
  10 tablet (stable-fixes).
- ASoC: Intel: bytcr_rt5640: Add support for non ACPI instantiated
  codec (stable-fixes).
- ASoC: codecs: rt5640: Always disable IRQs from
  rt5640_cancel_work() (stable-fixes).
- ALSA: hda/realtek: Add subwoofer quirk for Infinix ZERO BOOK 13
  (stable-fixes).
- ALSA: hda/realtek: Limit internal Mic boost on Dell platform
  (stable-fixes).
- commit 0d350ca
* Sat Nov  2 2024 tiwai@suse.de
- drm/mediatek: Fix get efuse issue for MT8188 DPTX (git-fixes).
- drm/amd/pm: Vangogh: Fix kernel memory out of bounds write
  (git-fixes).
- ACPI: CPPC: Make rmw_lock a raw_spin_lock (git-fixes).
- firmware: arm_sdei: Fix the input parameter of
  cpuhp_remove_state() (git-fixes).
- kasan: Fix Software Tag-Based KASAN with GCC (git-fixes).
- commit 2a07e04
* Sat Nov  2 2024 tiwai@suse.de
- Bluetooth: hci: fix null-ptr-deref in hci_read_supported_codecs
  (git-fixes).
- wifi: cfg80211: clear wdev->cqm_config pointer on free
  (git-fixes).
- Revert "wifi: iwlwifi: remove retry loops in start" (git-fixes).
- wifi: iwlwifi: mvm: don't add default link in fw restart flow
  (git-fixes).
- wifi: iwlwifi: mvm: Fix response handling in
  iwl_mvm_send_recovery_cmd() (git-fixes).
- wifi: iwlwifi: mvm: don't leak a link on AP removal (git-fixes).
- wifi: ath11k: Fix invalid ring usage in full monitor mode
  (git-fixes).
- wifi: ath10k: Fix memory leak in management tx (git-fixes).
- wifi: brcm80211: BRCM_TRACING should depend on TRACING
  (git-fixes).
- wifi: mac80211: skip non-uploaded keys in ieee80211_iter_keys
  (git-fixes).
- wifi: mac80211: do not pass a stopped vif to the driver in
  .get_txpower (git-fixes).
- mac80211: MAC80211_MESSAGE_TRACING should depend on TRACING
  (git-fixes).
- wifi: iwlegacy: Fix "field-spanning write" warning in
  il_enqueue_hcmd() (git-fixes).
- ASoC: cs42l51: Fix some error handling paths in cs42l51_probe()
  (git-fixes).
- platform/x86: dell-wmi: Ignore suspend notifications
  (stable-fixes).
- ACPI: button: Add DMI quirk for Samsung Galaxy Book2 to fix
  initial lid detection issue (stable-fixes).
- ACPI: resource: Add LG 16T90SP to irq1_level_low_skip_override[]
  (stable-fixes).
- drm/amd/display: Disable PSR-SU on Parade 08-01 TCON too
  (stable-fixes).
- drm/amd: Guard against bad data for ATIF ACPI method
  (git-fixes).
- usb: gadget: f_uac2: fix return value for UAC2_ATTRIBUTE_STRING
  store (git-fixes).
- accel/qaic: Fix the for loop used to walk SG table (git-fixes).
- drm/amd/amdgpu: Fix double unlock in amdgpu_mes_add_ring
  (git-fixes).
- drm/msm/dpu: don't always program merge_3d block (git-fixes).
- drm/msm: Allocate memory for disp snapshot with kvzalloc()
  (git-fixes).
- drm/msm: Avoid NULL dereference in msm_disp_state_print_regs()
  (git-fixes).
- drm/msm/dsi: fix 32-bit signed integer extension in pclk_rate
  calculation (git-fixes).
- drm/msm/dsi: improve/fix dsc pclk calculation (git-fixes).
- drm/msm/dpu: check for overflow in _dpu_crtc_setup_lm_bounds()
  (git-fixes).
- drm/msm/dpu: move CRTC resource assignment to
  dpu_encoder_virt_atomic_check (git-fixes).
- drm/msm/dpu: make sure phys resources are properly initialized
  (git-fixes).
- platform/x86: dell-sysman: add support for alienware products
  (stable-fixes).
- drm/vboxvideo: Replace fake VLA at end of
  vbva_mouse_pointer_shape with real VLA (stable-fixes).
- usb: gadget: f_uac2: fix non-newline-terminated function name
  (stable-fixes).
- usb: gadget: f_uac2: Replace snprintf() with the safer
  scnprintf() variant (stable-fixes).
- commit 09f40f7
* Fri Nov  1 2024 dsterba@suse.com
- drm/amd/display: Check null pointers before using them (CVE-2024-49922 bsc#1232374)
- commit 342005c
* Fri Nov  1 2024 dsterba@suse.com
- drm/amd/display: Handle null 'stream_status' in 'planes_changed_for_existing_stream' (CVE-2024-49912 bsc#1232367)
- commit 2394db2
* Fri Nov  1 2024 dsterba@suse.com
- drm/amd/display: Add NULL check for function pointer in dcn20_set_output_transfer_func (CVE-2024-49911 bsc#1232366)
- commit 6c83ea7
* Fri Nov  1 2024 dsterba@suse.com
- drm/amd/display: Pass non-null to dcn20_validate_apply_pipe_split_flags (CVE-2024-49923 bsc#1232361)
- commit 3759560
* Fri Nov  1 2024 dsterba@suse.com
- drm/amd/display: Fix index out of bounds in DCN30 degamma hardware format translation (CVE-2024-49895 bsc#1232352)
- commit f36c162
* Fri Nov  1 2024 dsterba@suse.com
- drm/amd/display: Initialize denominators' default to 1 (CVE-2024-49899 bsc#1232358)
- commit 282fa51
* Fri Nov  1 2024 dsterba@suse.com
- drm/amd/display: Check phantom_stream before it is used (CVE-2024-49897 bsc#1232355)
- commit d3fcaed
* Fri Nov  1 2024 dsterba@suse.com
- drm/amd/display: Fix index out of bounds in degamma hardware format translation (CVE-2024-49894 bsc#1232354)
- commit db76ccb
* Fri Nov  1 2024 dsterba@suse.com
- drm/amd/display: Add NULL check for function pointer in dcn32_set_output_transfer_func (CVE-2024-49909 bsc#1232337)
- commit 11facc9
* Fri Nov  1 2024 dsterba@suse.com
- drm/amd/display: Add null check for top_pipe_to_program in commit_planes_for_stream (CVE-2024-49913 bsc#1232307)
- commit 60f7853
* Fri Nov  1 2024 dsterba@suse.com
- drm/msm/adreno: Assign msm_gpu->pdev earlier to avoid nullptrs (CVE-2024-49901 bsc#1232305)
- commit 69be7bb
* Fri Nov  1 2024 nik.borisov@suse.com
- RAS/AMD/ATL: Implement DF 4.5 NP2 denormalization (jsc#PED-10559).
- commit 52d40f4
* Fri Nov  1 2024 nik.borisov@suse.com
- RAS/AMD/ATL: Validate address map when information is gathered (jsc#PED-10559).
- commit 94e412f
* Fri Nov  1 2024 nik.borisov@suse.com
- RAS/AMD/ATL: Expand helpers for adding and removing base and hole (jsc#PED-10559).
- commit 2b18348
* Fri Nov  1 2024 nik.borisov@suse.com
- RAS/AMD/ATL: Read DRAM hole base early (jsc#PED-10559).
- commit e1cf5b5
* Fri Nov  1 2024 nik.borisov@suse.com
- RAS/AMD/ATL: Add amd_atl pr_fmt() prefix (jsc#PED-10559).
- commit 17f78f9
* Fri Nov  1 2024 tzimmermann@suse.com
- drm/amd/display: Check null pointer before try to access it (bsc#1232332 CVE-2024-49906)
- commit f2b2892
* Fri Nov  1 2024 tzimmermann@suse.com
- drm/amd/display: Add null check for pipe_ctx->plane_state in (bsc#1232369 CVE-2024-49914)
- commit c236474
* Fri Nov  1 2024 tzimmermann@suse.com
- drm/amd/display: Add null check for 'afb' in amdgpu_dm_update_cursor (bsc#1232335 CVE-2024-49908)
- commit 64a943f
* Fri Nov  1 2024 tzimmermann@suse.com
- drm/amd/display: Check null pointers before using dc->clk_mgr (bsc#1232334 CVE-2024-49907)
- commit 366c63a
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/bnxt_re: synchronize the qp-handle table array (git-fixes)
- commit 866dbc5
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix the usage of control path spin locks (git-fixes)
- commit c834f25
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/mlx5: Round max_rd_atomic/max_dest_rd_atomic up instead of down (git-fixes)
- commit 3c270f2
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/cxgb4: Dump vendor specific QP details (git-fixes)
- commit 587d3b0
* Fri Nov  1 2024 dsterba@suse.com
- ext4: fix access to uninitialised lock in fc replay path (CVE-2024-50014 bsc#1232446)
- commit 1b2ba45
* Thu Oct 31 2024 dsterba@suse.com
- ext4: fix i_data_sem unlock order in ext4_ind_migrate() (CVE-2024-50006 bsc#1232442)
- commit de0e62b
* Thu Oct 31 2024 krisman@suse.de
- scsi: ufs: core: Remove SCSI host only if added (CVE-2024-46843
  bsc#1231100).
- commit b455bee
* Thu Oct 31 2024 krisman@suse.de
- io_uring: check if we need to reschedule during overflow flush
  (bsc#1232417 CVE-2024-50060).
- commit 695bc5f
* Thu Oct 31 2024 vkarasulli@suse.de
- iommu/vt-d: Fix potential lockup if qi_submit_sync called
  with 0 count (bsc#1232316 CVE-2024-49993).
- commit f1e5ce7
* Thu Oct 31 2024 dsterba@suse.com
- ext4: dax: fix overflowing extents beyond inode size when partially writing (CVE-2024-50015 bsc#1232079)
- commit 9768b7c
* Thu Oct 31 2024 dsterba@suse.com
- jbd2: stop waiting for space when jbd2_cleanup_journal_tail() returns error (CVE-2024-49959 bsc#1232149)
- commit 8307a3a
* Thu Oct 31 2024 dsterba@suse.com
- of: Add cleanup.h based auto release via __free(device_node) markings (bsc#1232386)
- commit 794e5ba
* Thu Oct 31 2024 svarbanov@suse.de
- net: stmmac: dwmac-tegra: Fix link bring-up sequence (git-fixes)
- commit 277d940
* Thu Oct 31 2024 dsterba@suse.com
- cpufreq: Avoid a bad reference count on CPU node (CVE-2024-50012 bsc#1232386)
- commit 283b9a0
* Thu Oct 31 2024 dsterba@suse.com
- ext4: update orig_path in ext4_find_extent() (CVE-2024-49881 bsc#1232201)
- commit 2ed2a04
* Thu Oct 31 2024 dsterba@suse.com
- ext4: fix slab-use-after-free in ext4_split_extent_at() (bsc#1232201)
- commit c78e4be
* Wed Oct 30 2024 krisman@suse.de
- btrfs: don't BUG_ON on ENOMEM from btrfs_lookup_extent_info()
  in walk_down_proc() (CVE-2024-46841 bsc#1231094).
- commit fb4a0c7
* Wed Oct 30 2024 dsterba@suse.com
- ext4: aovid use-after-free in ext4_ext_insert_extent() (CVE-2024-49883 bsc#1232199)
- commit 2db9cb5
* Wed Oct 30 2024 dsterba@suse.com
- blk_iocost: fix more out of bound shifts (CVE-2024-49933 bsc#1232368)
- commit df53397
* Wed Oct 30 2024 vkarasulli@suse.de
- drm/amd/display: Fix index out of bounds in DCN30 color
  transformation (CVE-2024-49969 bsc#1232519).
- commit 7d6c264
* Wed Oct 30 2024 petr.pavlu@suse.com
- static_call: Replace pointless WARN_ON() in
  static_call_module_notify() (bsc#1232155 CVE-2024-49954).
- commit 03b6c35
* Wed Oct 30 2024 petr.pavlu@suse.com
- module: abort module loading when sysfs setup suffer errors
  (git-fixes).
- Refresh patches.suse/add-suse-supported-flag.patch.
- commit db27509
* Wed Oct 30 2024 petr.pavlu@suse.com
- bpf,perf: Fix perf_event_detach_bpf_prog error handling
  (git-fixes).
- commit 5b6b2d4
* Wed Oct 30 2024 petr.pavlu@suse.com
- tracing: Consider the NULL character when validating the event
  length (git-fixes).
- commit 6b1d97f
* Wed Oct 30 2024 petr.pavlu@suse.com
- uprobe: avoid out-of-bounds memory access of fetching args
  (git-fixes).
- uprobes: encapsulate preparation of uprobe args buffer
  (git-fixes).
- commit ead6cfe
* Wed Oct 30 2024 mfranc@suse.cz
- s390/pci: Handle PCI error codes other than 0x3a (git-fixes
  bsc#1232629).
- commit e4948be
* Wed Oct 30 2024 mfranc@suse.cz
- s390/sclp: Deactivate sclp after all its users (git-fixes
  bsc#1232628).
- commit 9e889e7
* Wed Oct 30 2024 mfranc@suse.cz
- s390/sclp_vt220: Convert newlines to CRLF instead of LFCR
  (git-fixes bsc#1232627).
- commit 5725ee0
* Wed Oct 30 2024 mfranc@suse.cz
- KVM: s390: Change virtual to physical address access in diag
  0x258 handler (git-fixes bsc#1232626).
- commit 2b0b1e9
* Wed Oct 30 2024 mfranc@suse.cz
- KVM: s390: gaccess: Check if guest address is in memslot
  (git-fixes bsc#1232623).
- commit b583687
* Wed Oct 30 2024 petr.pavlu@suse.com
- fgraph: Use CPU hotplug mechanism to initialize idle shadow
  stacks (git-fixes).
- commit 4265ef9
* Wed Oct 30 2024 petr.pavlu@suse.com
- mm: khugepaged: fix the arguments order in
  khugepaged_collapse_file trace point (git-fixes).
- commit 43546b6
* Wed Oct 30 2024 petr.pavlu@suse.com
- tracing/hwlat: Fix a race during cpuhp processing (git-fixes).
- tracing/timerlat: Fix a race during cpuhp processing
  (git-fixes).
- tracing/timerlat: Drop interface_lock in stop_kthread()
  (git-fixes).
- tracing/timerlat: Fix duplicated kthread creation due to CPU
  online/offline (git-fixes).
- tracing/osnoise: Fix build when timerlat is not enabled
  (git-fixes).
- tracing/timerlat: Add interface_lock around clearing of kthread
  in stop_kthread() (git-fixes).
- tracing/timerlat: Only clear timer if a kthread exists
  (git-fixes).
- tracing/osnoise: Use a cpumask to know what threads are kthreads
  (git-fixes).
- tracing/timerlat: Move hrtimer_init to timerlat_fd open()
  (git-fixes).
- tracing/timerlat: Add user-space interface (git-fixes).
- tracing/osnoise: Skip running osnoise if all instances are off
  (git-fixes).
- tracing/osnoise: Switch from PF_NO_SETAFFINITY to
  migrate_disable (git-fixes).
- commit 8482ad0
* Wed Oct 30 2024 ailiop@suse.com
- ocfs2: pass u64 to ocfs2_truncate_inline maybe overflow
  (git-fixes).
- commit 24fea60
* Wed Oct 30 2024 nik.borisov@suse.com
- Refresh patches.suse/x86-fix-user-address-masking-non-canonical-speculation-iss.patch. (bsc#1232529)
  Give check_range a unique label. Otherwise the macro's 1b label
  conflicts with __get_user_1's 1 label and this causes the exception fixup
  entry, installed at the end of the file to match the wrong thing.
  Instead of matching __get_user_1's 1b label it will match check_range's 1b
  label when this macro is expanded for the last time in __get_user_8.
  This fixes intermittent random crashes when copying data from userspace.
- commit 3a35fd0
* Wed Oct 30 2024 petr.pavlu@suse.com
- jump_label: Fix static_key_slow_dec() yet again (git-fixes).
- commit ab363f5
* Wed Oct 30 2024 petr.pavlu@suse.com
- SUNRPC: Fixup gss_status tracepoint error output (git-fixes).
- commit 84cc417
* Tue Oct 29 2024 dsterba@suse.com
- drm/amd/display: Deallocate DML memory if allocation fails (CVE-2024-49972 bsc#1232315)
- commit dd5ab13
* Tue Oct 29 2024 dsterba@suse.com
- drm/amd/display: Check stream before comparing them (CVE-2024-49896 bsc#1232221)
- commit 930546b
* Tue Oct 29 2024 dsterba@suse.com
- drm/amd/pm: ensure the fw_info is not null before using it (CVE-2024-49890 bsc#1232217)
- commit a0e8b9f
* Tue Oct 29 2024 dsterba@suse.com
- drm/amd/display: Initialize get_bytes_per_element's default to 1 (CVE-2024-49892 bsc#1232220)
- commit e1539d0
* Tue Oct 29 2024 dsterba@suse.com
- drivers/perf: Fix ali_drw_pmu driver interrupt status clearing (CVE-2024-47731 bsc#1232117)
- commit 774dc33
* Tue Oct 29 2024 dsterba@suse.com
- padata: use integer wrap around to prevent deadlock on seq_nr overflow (CVE-2024-47739 bsc#1232124)
- commit 7e58560
* Tue Oct 29 2024 dsterba@suse.com
- media: mediatek: vcodec: Fix H264 stateless decoder smatch warning (CVE-2024-47752 bsc#1232130)
- commit 086cd43
* Tue Oct 29 2024 dsterba@suse.com
- media: mediatek: vcodec: Fix H264 multi stateless decoder smatch warning (CVE-2024-47754 bsc#1232131)
- commit dacb1c6
* Tue Oct 29 2024 dsterba@suse.com
- media: mediatek: vcodec: Fix VP8 stateless decoder smatch warning (CVE-2024-47753 bsc#1231868)
- commit fed66a9
* Tue Oct 29 2024 vkarasulli@suse.de
- iommu/vt-d: Always reserve a domain ID for identity setup
  (git-fixes).
- commit f7ecad0
* Tue Oct 29 2024 dsterba@suse.com
- btrfs: clean up our handling of refs == 0 in snapshot delete (CVE-2024-46840 bsc#1231105)
- commit 788d396
* Tue Oct 29 2024 shung-hsi.yu@suse.com
- kABI: bpf: struct bpf_map kABI workaround (CVE-2024-50063
  bsc#1232435).
- selftests/bpf: Add test for lsm tail call (CVE-2024-50063
  bsc#1232435).
- bpf: Prevent tail call between progs attached to different hooks
  (CVE-2024-50063 bsc#1232435).
- commit 666246a
* Tue Oct 29 2024 vkarasulli@suse.de
- iommu/vt-d: Fix incorrect pci_for_each_dma_alias() for non-PCI
  devices (git-fixes).
- commit 28951a9
* Tue Oct 29 2024 tzimmermann@suse.com
- drm/amd/display: Check null pointers before multiple uses (bsc#1232313 CVE-2024-49920)
- commit 5447aa1
* Tue Oct 29 2024 tzimmermann@suse.com
- drm/amd/display: Check link_res->hpo_dp_link_enc before using it (bsc#1231944)
- commit bf57b96
* Tue Oct 29 2024 tzimmermann@suse.com
- drm/amd/display: Check null-initialized variables (bsc#1232222 CVE-2024-49898)
- commit a00bfda
* Tue Oct 29 2024 tzimmermann@suse.com
- drm/amd/display: Check link_res->hpo_dp_link_enc before using it (bsc#1231944 CVE-2024-47704)
- commit 931c899
* Tue Oct 29 2024 tiwai@suse.de
- spi: spi-fsl-dspi: Fix crash when not using GPIO chip select
  (git-fixes).
- spi: mtk-snfi: fix kerneldoc for mtk_snand_is_page_ops()
  (git-fixes).
- spi: atmel-quadspi: Fix wrong register value written to MR
  (git-fixes).
- commit fd0b348
* Tue Oct 29 2024 krisman@suse.de
- crypto: stm32/cryp - call finalize with bh disabled
  (CVE-2024-47658 bsc#1231436).
- commit 2854148
* Mon Oct 28 2024 henrique.carvalho@suse.com
- smb: client: fix UAF in async decryption (bsc#1232418
  CVE-2024-50047).
- commit 381863e
* Mon Oct 28 2024 tbogendoerfer@suse.de
- e1000e: fix force smbus during suspend flow (git-fixes).
- commit f9cbf12
* Mon Oct 28 2024 fdmanana@suse.com
- btrfs: wait for fixup workers before stopping cleaner kthread
  during umount (bsc#1232262 CVE-2024-49867).
- btrfs: fix race setting file private on concurrent lseek using
  same fd (bsc#1231869 CVE-2024-47741).
- commit af36a3e
* Mon Oct 28 2024 tbogendoerfer@suse.de
- ppp: fix ppp_async_encode() illegal access (CVE-2024-50035
  bsc#1232392).
- net: avoid potential underflow in qdisc_pkt_len_init() with UFO
  (CVE-2024-49949 bsc#1232160).
- commit f4bcea0
* Mon Oct 28 2024 tbogendoerfer@suse.de
- ice: map XDP queues to vectors in ice_vsi_map_rings_to_vectors()
  (git-fixes).
- Refresh
  patches.suse/ice-move-netif_queue_set_napi-to-rtnl-protected-sect.patch.
- commit 7b44c3c
* Mon Oct 28 2024 tbogendoerfer@suse.de
- net/mlx5: Check capability for fw_reset (git-fixes).
- Refresh
  patches.suse/net-mlx5-Fix-MTMP-register-capability-offset-in-MCAM.patch.
- commit 480249d
* Mon Oct 28 2024 tbogendoerfer@suse.de
- net/mlx5e: Don't call cleanup on profile rollback failure
  (git-fixes).
- net/mlx5: Unregister notifier on eswitch init failure
  (git-fixes).
- net/mlx5: Fix command bitmask initialization (git-fixes).
- net/mlx5: Check for invalid vector index on EQ creation
  (git-fixes).
- e1000e: change I219 (19) devices to ADP (git-fixes).
- ice: Flush FDB entries before reset (git-fixes).
- ice: Fix netif_is_ice() in Safe Mode (git-fixes).
- ice: fix VLAN replay after reset (git-fixes).
- ice: disallow DPLL_PIN_STATE_SELECTABLE for dpll output pins
  (git-fixes).
- ice: clear port vlan config during reset (git-fixes).
- ice: set correct dst VSI in only LAN filters (git-fixes).
- net/mlx5: Added cond_resched() to crdump collection (git-fixes).
- vduse: avoid using __GFP_NOFAIL (git-fixes).
- igb: Always call igb_xdp_ring_update_tail() under Tx lock
  (git-fixes).
- ice: fix VSI lists confusion when adding VLANs (git-fixes).
- ice: fix accounting for filters shared by multiple VSIs
  (git-fixes).
- ice: Fix lldp packets dropping after changing the number of
  channels (git-fixes).
- net/mlx5: Add missing masks and QoS bit masks for scheduling
  elements (git-fixes).
- net/mlx5: Explicitly set scheduling element and TSAR type
  (git-fixes).
- net/mlx5e: Add missing link mode to ptys2ext_ethtool_map
  (git-fixes).
- net/mlx5e: Add missing link modes to ptys2ethtool_map
  (git-fixes).
- net/mlx5: Update the list of the PCI supported devices
  (git-fixes).
- ice: do not bring the VSI up, if it was down before the XDP
  setup (git-fixes).
- igc: Unlock on error in igc_io_resume() (git-fixes).
- igb: Fix not clearing TimeSync interrupts for 82580 (git-fixes).
- ice: fix truesize operations for PAGE_SIZE >= 8192 (git-fixes).
- ice: fix ICE_LAST_OFFSET formula (git-fixes).
- ice: fix page reuse when PAGE_SIZE is over 8k (git-fixes).
- cxgb4: add forgotten u64 ivlan cast before shift (git-fixes).
- igc: Fix qbv tx latency by setting gtxoffset (git-fixes).
- igc: Fix reset adapter logics when tx mode change (git-fixes).
- igc: Fix qbv_config_change_errors logics (git-fixes).
- igc: Fix packet still tx after gate close by reducing i226
  MAC retry buffer (git-fixes).
- net/mlx5e: Correctly report errors for ethtool rx flows
  (git-fixes).
- ice: Fix reset handler (git-fixes).
- idpf: fix UAFs when destroying the queues (git-fixes).
- idpf: fix memleak in vport interrupt configuration (git-fixes).
- idpf: fix memory leaks and crashes while performing a soft reset
  (git-fixes).
- igc: Fix double reset adapter triggered from a single taprio
  cmd (git-fixes).
- net/mlx5e: Add a check for the return value from
  mlx5_port_set_eth_ptys (git-fixes).
- net/mlx5e: Require mlx5 tc classifier action support for IPsec
  prio capability (git-fixes).
- net/mlx5: Lag, don't use the hardcoded value of the first port
  (git-fixes).
- net/mlx5: Fix error handling in irq_pool_request_irq
  (git-fixes).
- ice: add missing WRITE_ONCE when clearing ice_rx_ring::xdp_prog
  (git-fixes).
- ice: replace synchronize_rcu with synchronize_net (git-fixes).
- ice: don't busy wait for Rx queue disable in ice_qp_dis()
  (git-fixes).
- ice: respect netif readiness in AF_XDP ZC related ndo's
  (git-fixes).
- gve: Fix an edge case for TSO skb validity check (git-fixes).
- ice: Fix recipe read procedure (git-fixes).
- gve: Fix XDP TX completion handling when counters overflow
  (git-fixes).
- RDMA/mlx5: Use sq timestamp as QP timestamp when RoCE is
  disabled (git-fixes).
- idpf: avoid bloating &idpf_q_vector with big %%NR_CPUS
  (git-fixes).
- i40e: Fix XDP program unloading while removing the driver
  (git-fixes).
- ice: use proper macro for testing bit (git-fixes).
- ice: Reject pin requests with unsupported flags (git-fixes).
- e1000e: Fix S0ix residency on corporate systems (git-fixes).
- net/mlx5e: Add mqprio_rl cleanup and free in
  mlx5e_priv_cleanup() (git-fixes).
- ice: Rebuild TC queues on VSI queue reconfiguration (git-fixes).
- bnxt_en: Restore PTP tx_avail count in case of skb_pad() error
  (git-fixes).
- ice: Fix VSI list rule with ICE_SW_LKUP_LAST type (git-fixes).
- ice: implement AQ download pkg retry (git-fixes).
- ice: fix 200G link speed message log (git-fixes).
- ice: avoid IRQ collision to fix init failure on ACPI S3 resume
  (git-fixes).
- bnxt_en: Cap the size of HWRM_PORT_PHY_QCFG forwarded response
  (git-fixes).
- gve: ignore nonrelevant GSO type bits when processing TSO
  headers (git-fixes).
- net/mlx5e: Fix features validation check for tunneled UDP
  (non-VXLAN) packets (git-fixes).
- ice: add flag to distinguish reset from .ndo_bpf in XDP rings
  config (git-fixes).
- ice: remove af_xdp_zc_qps bitmap (git-fixes).
- ice: fix reads from NVM Shadow RAM on E830 and E825-C devices
  (git-fixes).
- ice: fix iteration of TLVs in Preserved Fields Area (git-fixes).
- net/mlx5: Stop waiting for PCI if pci channel is offline
  (git-fixes).
- ice: fix 200G PHY types to link speed mapping (git-fixes).
- e1000e: move force SMBUS near the end of enable_ulp function
  (git-fixes).
- ice: fix accounting if a VLAN already exists (git-fixes).
- idpf: don't enable NAPI and interrupts prior to allocating Rx
  buffers (git-fixes).
- net/mlx5e: Fix UDP GSO for encapsulated packets (git-fixes).
- net/mlx5e: Use rx_missed_errors instead of rx_dropped for
  reporting buffer exhaustion (git-fixes).
- net/mlx5e: Fix IPsec tunnel mode offload feature check
  (git-fixes).
- net/mlx5: Lag, do bond only if slaves agree on roce state
  (git-fixes).
- idpf: Interpret .set_channels() input differently (git-fixes).
- ice: Interpret .set_channels() input differently (git-fixes).
- idpf: don't skip over ethtool tcp-data-split setting
  (git-fixes).
- ice: Fix package download algorithm (git-fixes).
- mlx5: stop warning for 64KB pages (git-fixes).
- mlx5: avoid truncating error message (git-fixes).
- qed: avoid truncating work queue length (git-fixes).
- cxgb4: unnecessary check for 0 in the free_sge_txq_uld()
  function (git-fixes).
- cxgb4: Properly lock TX queue for the selftest (git-fixes).
- net: qede: use return from qede_parse_actions() (git-fixes).
- net: qede: use return from qede_parse_flow_attr() for flow_spec
  (git-fixes).
- net: qede: use return from qede_parse_flow_attr() for flower
  (git-fixes).
- net: qede: sanitize 'rc' in qede_add_tc_flower_fltr()
  (git-fixes).
- iavf: Fix TC config comparison with existing adapter TC config
  (git-fixes).
- i40e: Report MFS in decimal base instead of hex (git-fixes).
- eth: bnxt: fix counting packets discarded due to OOM and netpoll
  (git-fixes).
- bnxt_en: Fix error recovery for 5760X (P7) chips (git-fixes).
- bnxt_en: Fix the PCI-AER routines (git-fixes).
- bnxt_en: refactor reset close code (git-fixes).
- ice: Fix checking for unsupported keys on non-tunnel device
  (git-fixes).
- ice: tc: allow zero flags in parsing tc flower (git-fixes).
- ice: tc: check src_vsi in case of traffic from VF (git-fixes).
- vdpa: Fix an error handling path in eni_vdpa_probe()
  (git-fixes).
- vdpa_sim_blk: allocate the buffer zeroed (git-fixes).
- vdpa_sim_blk: Fix the potential leak of mgmt_dev (git-fixes).
- commit 58c03fe
* Mon Oct 28 2024 nik.borisov@suse.com
- dcache: keep dentry_hashtable or d_hash_shift even when not used (git-fixes).
- commit d6ce9b3
* Mon Oct 28 2024 nik.borisov@suse.com
- x86: fix user address masking non-canonical speculation issue (git-fixes).
- commit 561e50e
* Mon Oct 28 2024 nik.borisov@suse.com
- x86: make the masked_user_access_begin() macro use its argument only  once (git-fixes).
- commit aa2495e
* Mon Oct 28 2024 nik.borisov@suse.com
- x86: do the user address masking outside the user access area (git-fixes).
- commit a4b9c7b
* Mon Oct 28 2024 nik.borisov@suse.com
- x86: support user address masking instead of non-speculative conditional (git-fixes).
- commit 6536d1f
* Mon Oct 28 2024 nik.borisov@suse.com
- runtime constants: add x86 architecture support (git-fixes).
- commit 32e2def
* Mon Oct 28 2024 nik.borisov@suse.com
- runtime constants: add default dummy infrastructure (git-fixes).
- commit dd17ee6
* Mon Oct 28 2024 nik.borisov@suse.com
- vfs: dcache: move hashlen_hash() from callers into d_hash() (git-fixes).
- commit c440ebe
* Mon Oct 28 2024 ohering@suse.de
- hv_netvsc: Fix VF namespace also in synthetic NIC NETDEV_REGISTER event (git-fixes).
- commit 3dc5225
* Sat Oct 26 2024 tiwai@suse.de
- Drop USB dwc2 patch that caused a regression on RPi3 (bsc#1232342)
- commit c84227d
* Sat Oct 26 2024 tiwai@suse.de
- ACPI: PRM: Clean up guid type in struct prm_handler_info
  (git-fixes).
- commit 8c8a801
* Sat Oct 26 2024 tiwai@suse.de
- ALSA: hda/realtek: Add subwoofer quirk for Acer Predator G9-593
  (stable-fixes).
- commit 595e400
* Sat Oct 26 2024 tiwai@suse.de
- ACPI: PRM: Find EFI_MEMORY_RUNTIME block for PRM handler and
  context (git-fixes).
- ata: libata: Set DID_TIME_OUT for commands that actually timed
  out (git-fixes).
- ASoC: max98388: Fix missing increment of variable slot_found
  (git-fixes).
- ASoC: qcom: Fix NULL Dereference in
  asoc_qcom_lpass_cpu_platform_probe() (git-fixes).
- ALSA: hda/realtek: Update default depop procedure (git-fixes).
- ALSA: hda/tas2781: select CRC32 instead of CRC32_SARWATE
  (git-fixes).
- ALSA: firewire-lib: Avoid division by zero in
  apply_constraint_to_size() (git-fixes).
- cpufreq/amd-pstate: Fix amd_pstate mode switch on shared memory
  systems (git-fixes).
- ntb: intel: Fix the NULL vs IS_ERR() bug for
  debugfs_create_dir() (git-fixes).
- commit 33d7ff7
* Fri Oct 25 2024 vkarasulli@suse.de
- platform/x86: x86-android-tablets: Fix use after free on
  platform_device_register() errors (bsc#1232093 CVE-2024-49986).
- commit a5650bf
* Fri Oct 25 2024 vkarasulli@suse.de
- thermal: core: Free tzp copy along with the thermal zone
  (bsc#1231951 CVE-2024-50027).
- commit 5199a1f
* Fri Oct 25 2024 vkarasulli@suse.de
- device-dax: correct pgoff align in dax_set_mapping()
  (bsc#1231956 CVE-2024-50022).
- commit 527a95e
* Fri Oct 25 2024 tiwai@suse.de
- ntb: ntb_hw_switchtec: Fix use after free vulnerability in
  switchtec_ntb_remove due to race condition (CVE-2024-50059
  bsc#1232345).
- commit 4d86c47
* Fri Oct 25 2024 vbabka@suse.cz
- mm: call the security_mmap_file() LSM hook in remap_file_pages()
  (CVE-2024-47745 bsc#1232135).
- commit 18a36ea
* Fri Oct 25 2024 sjaeckel@suse.de
- Bluetooth: L2CAP: Fix uaf in l2cap_connect (CVE-2024-49950
  bsc#1232159).
- commit c906740
* Fri Oct 25 2024 sjaeckel@suse.de
- rxrpc: Fix a race between socket set up and I/O thread creation
  (CVE-2024-49864 bsc#1232256).
- commit 9a8fa8a
* Fri Oct 25 2024 ailiop@suse.com
- jfs: Fix sanity check in dbMount (git-fixes).
- commit 82a9085
* Fri Oct 25 2024 tbogendoerfer@suse.de
- net/mlx5e: Fix NULL deref in mlx5e_tir_builder_alloc()
  (CVE-2024-50000 bsc#1232085).
- commit fe8d0fb
* Fri Oct 25 2024 lhenriques@suse.de
- ext4: fix double brelse() the buffer of the extents path
  (bsc#1232200 CVE-2024-49882).
- ext4: no need to continue when the number of entries is 1
  (bsc#1232140 CVE-2024-49967).
- commit 4a7f79c
* Fri Oct 25 2024 dwagner@suse.de
- nvme: disable CC.CRIME (NVME_CC_CRIME) (jsc#PED-9901).
- commit e02c81e
* Fri Oct 25 2024 tbogendoerfer@suse.de
- ice: Fix improper handling of refcount in
  ice_sriov_set_msix_vec_count() (CVE-2024-50020 bsc#1231989).
- Refresh patches.suse/ice-Fix-increasing-MSI-X-on-VF.patch.
- commit 879bb19
* Fri Oct 25 2024 tbogendoerfer@suse.de
- igb: Do not bring the device up after non-fatal error
  (CVE-2024-50040 bsc#1231908).
- ice: Fix improper handling of refcount in
  ice_dpll_init_rclk_pins() (CVE-2024-50021 bsc#1231957).
- ppp: do not assume bh is held in ppp_channel_bridge_input()
  (CVE-2024-49946 bsc#1232164).
- net/mlx5e: Fix crash caused by calling __xfrm_state_delete()
  twice (CVE-2024-49953 bsc#1232156).
- net/mlx5: Fix error path in multi-packet WQE transmit
  (CVE-2024-50001 bsc#1232084).
- net: seeq: Fix use after free vulnerability in ether3 Driver
  Due to Race Condition (CVE-2024-47747 bsc#1232145).
- vdpa/mlx5: Fix invalid mr resource destroy (CVE-2024-47687
  bsc#1232003).
- Revert "ixgbe: Manual AN-37 for troublesome link partners for
  X550 SFI" (git-fixes).
- commit bf0d04c
* Fri Oct 25 2024 oneukum@suse.com
- net: usb: usbnet: fix name regression (get-fixes).
- commit 05e3778
* Fri Oct 25 2024 dsterba@suse.com
- r8169: add tally counter fields added with RTL8125 (CVE-2024-49973 bsc#1232105)
- commit bda1225
* Fri Oct 25 2024 dsterba@suse.com
- crypto: hisilicon/qm - flush all work before driver removed (bsc#1232075)
- commit fe52020
* Fri Oct 25 2024 dsterba@suse.com
- crypto: hisilicon/qm - inject error before stopping queue (CVE-2024-47730 bsc#1232075)
- commit 2ca1dd9
* Thu Oct 24 2024 dsterba@suse.com
- sock_map: Add a cond_resched() in sock_hash_free() (CVE-2024-47710 bsc#1232049)
- commit 0ac9917
* Thu Oct 24 2024 ematsumiya@suse.de
- cifs: Fix buffer overflow when parsing NFS reparse points
  (bsc#1232089, CVE-2024-49996).
- commit f42a100
* Thu Oct 24 2024 dsterba@suse.com
- netfilter: nf_reject_ipv6: fix nf_reject_ip6_tcphdr_put() (CVE-2024-47685 bsc#1231998)
- commit 8da2621
* Thu Oct 24 2024 dsterba@suse.com
- net: Fix an unsafe loop on the list (CVE-2024-50024 bsc#1231954)
- commit 89e6925
* Thu Oct 24 2024 dsterba@suse.com
- ipv6: avoid possible NULL deref in rt6_uncached_list_flush_dev() (CVE-2024-47707 bsc#1231935)
- commit cc8f915
* Thu Oct 24 2024 dsterba@suse.com
- netfilter: br_netfilter: fix panic with metadata_dst skb (CVE-2024-50045 bsc#1231903)
- commit e6591d1
* Thu Oct 24 2024 dsterba@suse.com
- block, bfq: fix possible UAF for bfqq->bic with merge chain (CVE-2024-47706 bsc#1231942)
- commit 5c1066e
* Thu Oct 24 2024 dsterba@suse.com
- tcp: check skb is non-NULL in tcp_rto_delta_us() (CVE-2024-47684 bsc#1231987)
- commit e27a5c2
* Thu Oct 24 2024 ohering@suse.de
- add bug references to existing mana changes (bsc#1232033, bsc#1232034, bsc#1232036).
- commit e93ce92
* Thu Oct 24 2024 rgoldwyn@suse.com
- filemap: remove use of wait bookmarks  (bsc#1224088).
- commit 323bb54
* Thu Oct 24 2024 nik.borisov@suse.com
- config: Disable LAM on x86 (bsc#1217845)
  LAM is affected by speculative execution vulnerabilities so until LASS
  lands it's advisable to be disabled.
- commit 405fa97
* Thu Oct 24 2024 shung-hsi.yu@suse.com
- selftests/bpf: adjust global_func15 test to validate prog exit
  precision (CVE-2024-47703 bsc#1231946).
- selftests/bpf: validate async callback return value check
  correctness (CVE-2024-47703 bsc#1231946).
- bpf: enforce precision of R0 on program/async callback return
  (CVE-2024-47703 bsc#1231946).
- bpf: unify async callback and program retval checks
  (CVE-2024-47703 bsc#1231946).
- commit d5ff894
* Thu Oct 24 2024 shung-hsi.yu@suse.com
- bpf: enforce precise retval range on program exit
  (CVE-2024-47703 bsc#1231946).
- selftests/bpf: add selftest validating callback result is
  enforced (CVE-2024-47703 bsc#1231946).
- bpf: enforce exact retval range on subprog/callback exit
  (CVE-2024-47703 bsc#1231946).
- Refresh patches.kabi/bpf-verifier-kABI-workarounds.patch
- bpf: provide correct register name for exception callback
  retval check (CVE-2024-47703 bsc#1231946).
- bpf: rearrange bpf_func_state fields to save a bit of memory
  (CVE-2024-47703 bsc#1231946).
- Refresh patches.suse/bpf-Add-some-comments-to-stack-representation.patch
- Refresh patches.kabi/bpf-verifier-kABI-workarounds.patch
- bpf: Treat first argument as return value for bpf_throw
  (CVE-2024-47703 bsc#1231946).
- commit 5efe683
* Thu Oct 24 2024 osalvador@suse.de
- drm/amd/display: Add null check for head_pipe in
  dcn32_acquire_idle_pipe_for_head_pipe_in_layer (CVE-2024-49918
  bsc#1231967).
- commit 0e6515f
* Thu Oct 24 2024 osalvador@suse.de
- drm/amd/display: Add NULL check for clk_mgr and clk_mgr->funcs
  in dcn30_init_hw (bsc#1231965 CVE-2024-49917).
- commit 0859f94
* Wed Oct 23 2024 ailiop@suse.com
- ocfs2: reserve space for inline xattr before attaching reflink
  tree (bsc#1232151 CVE-2024-49958).
- commit 9d01096
* Wed Oct 23 2024 iivanov@suse.de
- arm64: probes: Fix uprobes for big-endian kernels (git-fixes)
- commit 5114e0b
* Wed Oct 23 2024 iivanov@suse.de
- arm64: probes: Fix simulate_ldr*_literal() (git-fixes)
- commit 2795830
* Wed Oct 23 2024 iivanov@suse.de
- arm64: probes: Remove broken LDR (literal) uprobe support (git-fixes)
- commit 83d2001
* Wed Oct 23 2024 dsterba@suse.com
- spi: hisi-kunpeng: Add verification for the max_frequency provided by the firmware (CVE-2024-47664 bsc#1231442)
- commit 89945c9
* Wed Oct 23 2024 iivanov@suse.de
- arm64: Subscribe Microsoft Azure Cobalt 100 to erratum 3194386 (git-fixes)
- commit ad9716f
* Wed Oct 23 2024 iivanov@suse.de
- arm64: errata: Expand speculative SSBS workaround once more (git-fixes)
- commit f66e878
* Wed Oct 23 2024 iivanov@suse.de
- arm64: cputype: Add Neoverse-N3 definitions (git-fixes)
- commit 6a20007
* Wed Oct 23 2024 iivanov@suse.de
- arm64: esr: Define ESR_ELx_EC_* constants as UL (git-fixes)
- commit 28e8491
* Wed Oct 23 2024 pmladek@suse.com
- printk: Add notation to console_srcu locking (bsc#1232183).
- commit b5edcce
* Wed Oct 23 2024 pmladek@suse.com
- Update patches.suse/kthread-unpark-only-parked-kthread.patch
  (git-fixes, bsc#1231990, CVE-2024-50019).
- commit 1ac001a
* Wed Oct 23 2024 nik.borisov@suse.com
- x86/bugs: Do not use UNTRAIN_RET with IBPB on entry (git-fixes).
- commit 9059d40
* Wed Oct 23 2024 nik.borisov@suse.com
- x86/bugs: Skip RSB fill at VMEXIT (git-fixes).
- commit 1c2e2e9
* Wed Oct 23 2024 mfranc@suse.cz
- supported.conf: mark ultravisor userspace access as supported (bsc#1232090)
  This is needed for secure execution attestations feature.
- commit 9d4c7ad
* Wed Oct 23 2024 nik.borisov@suse.com
- x86/entry: Have entry_ibpb() invalidate return predictions (git-fixes).
- commit 8e4a09c
* Wed Oct 23 2024 nik.borisov@suse.com
- x86/cpufeatures: Add a IBPB_NO_RET BUG flag (git-fixes).
- commit 4411a53
* Wed Oct 23 2024 mfranc@suse.cz
- config s390x: build ultravisor userspace access into the kernel (bsc#1232090)
  The new s390-tools attestation-related tools depends on this.  It's
  better to have this built into the kernel just like in all other
  branches.
- commit 25c0449
* Wed Oct 23 2024 nik.borisov@suse.com
- x86/cpufeatures: Define X86_FEATURE_AMD_IBPB_RET (git-fixes).
- commit 589671a
* Wed Oct 23 2024 nik.borisov@suse.com
- x86/tdx: Fix "in-kernel MMIO" check (bsc#1232116 CVE-2024-47727).
- commit 9b65946
* Wed Oct 23 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add test for sign extension in
  coerce_subreg_to_size_sx() (git-fixes).
- selftests/bpf: Add test for truncation after sign extension
  in coerce_reg_to_size_sx() (git-fixes).
- bpf: Fix truncation bug in coerce_reg_to_size_sx() (git-fixes).
- selftests/bpf: Add test for sign extension in
  coerce_subreg_to_size_sx() (git-fixes).
- selftests/bpf: Add test for truncation after sign extension
  in coerce_reg_to_size_sx() (git-fixes).
- bpf: Fix truncation bug in coerce_reg_to_size_sx() (git-fixes).
- commit 34bee66
* Wed Oct 23 2024 ailiop@suse.com
- xfs: fix freeing speculative preallocations for preallocated
  files (git-fixes).
- commit 80e4f70
* Wed Oct 23 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add test for lsm tail call (CVE-2024-50063).
- commit 810e00e
* Wed Oct 23 2024 ailiop@suse.com
- xfs: make sure sb_fdblocks is non-negative (git-fixes).
- commit 258a678
* Wed Oct 23 2024 ailiop@suse.com
- xfs: remove a racy if_bytes check in xfs_reflink_end_cow_extent
  (git-fixes).
- commit 4ab4091
* Wed Oct 23 2024 ailiop@suse.com
- xfs: convert delayed extents to unwritten when zeroing post
  eof blocks (git-fixes).
- commit 6f12db2
* Wed Oct 23 2024 ailiop@suse.com
- xfs: make xfs_bmapi_convert_delalloc() to allocate the target
  offset (git-fixes).
- commit 9f0f731
* Wed Oct 23 2024 ailiop@suse.com
- xfs: make the seq argument to xfs_bmapi_convert_delalloc()
  optional (git-fixes).
- commit 504e0bc
* Wed Oct 23 2024 ailiop@suse.com
- xfs: validate recovered name buffers when recovering xattr items
  (git-fixes).
- commit a53fc5e
* Wed Oct 23 2024 ailiop@suse.com
- xfs: check shortform attr entry flags specifically (git-fixes).
- commit 621ec11
* Wed Oct 23 2024 shung-hsi.yu@suse.com
- kABI: bpf: struct bpf_map kABI workaround (CVE-2024-50063).
- bpf: Prevent tail call between progs attached to different hooks
  (CVE-2024-50063).
- commit cef79ef
* Wed Oct 23 2024 ailiop@suse.com
- xfs: check opcode and iovec count match in
  xlog_recover_attri_commit_pass2 (git-fixes).
- commit 2398ba4
* Wed Oct 23 2024 ailiop@suse.com
- fat: fix uninitialized variable (git-fixes).
- commit 77f5dad
* Wed Oct 23 2024 osalvador@suse.de
- drm/amd/display: Add null check for head_pipe in
  dcn201_acquire_free_pipe_for_layer (CVE-2024-49919 bsc#1231968).
- commit ff31b31
* Wed Oct 23 2024 tbogendoerfer@suse.de
- slip: make slhc_remember() more robust against malicious packets
  (CVE-2024-50033 bsc#1231914).
- i40e: Fix macvlan leak by synchronizing access to
  mac_filter_hash (CVE-2024-50041 bsc#1231907).
- ice: Fix increasing MSI-X on VF (CVE-2024-50042 bsc#1231906).
- commit a1fb8a8
* Wed Oct 23 2024 tiwai@suse.de
- pinctrl: ocelot: fix system hang on level based interrupts
  (stable-fixes).
- tty: n_gsm: Fix use-after-free in gsm_cleanup_mux
  (stable-fixes).
- USB: serial: option: add Telit FN920C04 MBIM compositions
  (stable-fixes).
- USB: serial: option: add support for Quectel EG916Q-GL
  (stable-fixes).
- drm/vmwgfx: Handle surface check failure correctly (git-fixes).
- drm/amdgpu/swsmu: Only force workload setup on init (git-fixes).
- drm/radeon: Fix encoder->possible_clones (git-fixes).
- commit 4fdf5d1
* Wed Oct 23 2024 tiwai@suse.de
- thermal: core: Reference count the zone in
  thermal_zone_get_by_id() (CVE-2024-50028 bsc#1231950).
- commit a5813a1
* Wed Oct 23 2024 shung-hsi.yu@suse.com
- bpf: Fix a sdiv overflow issue (CVE-2024-49888 bsc#1232208).
- commit ce8f994
* Tue Oct 22 2024 ailiop@suse.com
- kabi fix for NFSv4: Prevent NULL-pointer dereference in
  nfs42_complete_copies() (bsc#1231902 CVE-2024-50046).
- NFSv4: Prevent NULL-pointer dereference in
  nfs42_complete_copies() (bsc#1231902 CVE-2024-50046).
- commit e5e1a89
* Tue Oct 22 2024 vbabka@suse.cz
- zram: don't free statically defined names (CVE-2024-50064
  bsc#1231901).
- commit 645eb93
* Tue Oct 22 2024 vbabka@suse.cz
- zram: free secondary algorithms names (CVE-2024-50064
  bsc#1231901).
- commit 293822f
* Tue Oct 22 2024 lhenriques@suse.de
- block: fix potential invalid pointer dereference in
  blk_add_partition (bsc#1231872 CVE-2024-47705).
- block: print symbolic error name instead of error code
  (bsc#1231872).
- commit fcde2ed
* Tue Oct 22 2024 ddiss@suse.de
- nfsd: return -EINVAL when namelen is 0 (CVE-2024-47692
  bsc#1231857).
- commit 9ee6831
* Tue Oct 22 2024 jslaby@suse.cz
- PCI: Fix pci_enable_acs() support for the ACS quirks (bsc#1229019).
- commit 1bd1860
* Tue Oct 22 2024 ailiop@suse.com
- nilfs2: fix kernel bug due to missing clearing of buffer delay
  flag (git-fixes).
- commit 472d949
* Mon Oct 21 2024 jgross@suse.com
- Update
  patches.suse/xen-move-max_pfn-in-xen_memory_setup-out-of-function.patch
  (bsc#1226003 bsc#1231828).
- commit ec3e6a6
* Mon Oct 21 2024 nik.borisov@suse.com
- x86/sev: Check for MWAITX and MONITORX opcodes in the #VC handler (git-fixes).
- commit 23789e3
* Mon Oct 21 2024 nik.borisov@suse.com
- x86/apic: Make x2apic_disable() work correctly (git-fixes).
- commit 546101e
* Mon Oct 21 2024 nik.borisov@suse.com
- x86/entry: Remove unwanted instrumentation in common_interrupt() (git-fixes).
- commit 846156b
* Mon Oct 21 2024 nik.borisov@suse.com
- x86/mm: Use IPIs to synchronize LAM enablement (git-fixes).
- commit 8a7a0be
* Mon Oct 21 2024 nik.borisov@suse.com
- x86/amd_nb: Add new PCI IDs for AMD family 1Ah model 60h (git-fixes).
- commit 60a5f34
* Mon Oct 21 2024 nik.borisov@suse.com
- x86/PCI: Check pcie_find_root_port() return for NULL (git-fixes).
- commit 7c1cc11
* Mon Oct 21 2024 vbabka@suse.cz
- maple_tree: correct tree corruption on spanning store
  (git-fixes).
- commit 2b034f1
* Mon Oct 21 2024 nik.borisov@suse.com
- x86/resctrl: Avoid overflow in MB settings in bw_validate() (git-fixes).
- commit b2f0d6d
* Mon Oct 21 2024 nik.borisov@suse.com
- x86/resctrl: Annotate get_mem_config() functions as __init (git-fixes).
- commit 7e80f38
* Mon Oct 21 2024 nik.borisov@suse.com
- x86/apic: Always explicitly disarm TSC-deadline timer (git-fixes).
- commit 312d3e7
* Mon Oct 21 2024 nik.borisov@suse.com
- x86/CPU/AMD: Only apply Zenbleed fix for Zen2 during late microcode  load (git-fixes).
- commit 0cb125d
* Mon Oct 21 2024 davide.benini@suse.com
- ethtool: fail closed if we can't get max channel used in
  indirection tables (CVE-2024-46834 bsc#1231096).
- commit 5cacc93
* Mon Oct 21 2024 tiwai@suse.de
- Bluetooth: btusb: Fix regression with fake CSR controllers
  0a12:0001 (git-fixes).
- Bluetooth: bnep: fix wild-memory-access in proto_unregister
  (git-fixes).
- Bluetooth: Remove debugfs directory on module init failure
  (git-fixes).
- Bluetooth: Call iso_exit() on module unload (git-fixes).
- Bluetooth: ISO: Fix multiple init when debugfs is disabled
  (git-fixes).
- pinctrl: apple: check devm_kasprintf() returned value
  (git-fixes).
- parport: Proper fix for array out-of-bounds access (git-fixes).
- iio: frequency: admv4420: fix missing select REMAP_SPI in
  Kconfig (git-fixes).
- iio: adc: ti-ads8688: add missing select IIO_(TRIGGERED_)BUFFER
  in Kconfig (git-fixes).
- iio: hid-sensors: Fix an error handling path in
  _hid_sensor_set_report_latency() (git-fixes).
- iio: dac: stm32-dac-core: add missing select REGMAP_MMIO in
  Kconfig (git-fixes).
- iio: dac: ltc1660: add missing select REGMAP_SPI in Kconfig
  (git-fixes).
- iio: dac: ad5770r: add missing select REGMAP_SPI in Kconfig
  (git-fixes).
- iio: amplifiers: ada4250: add missing select REGMAP_SPI in
  Kconfig (git-fixes).
- iio: frequency: adf4377: add missing select REMAP_SPI in Kconfig
  (git-fixes).
- iio: proximity: mb1232: add missing select
  IIO_(TRIGGERED_)BUFFER in Kconfig (git-fixes).
- iio: dac: ad5766: add missing select IIO_(TRIGGERED_)BUFFER
  in Kconfig (git-fixes).
- iio: dac: ad3552r: add missing select IIO_(TRIGGERED_)BUFFER
  in Kconfig (git-fixes).
- iio: adc: ti-lmp92064: add missing select REGMAP_SPI in Kconfig
  (git-fixes).
- iio: adc: ti-ads124s08: add missing select
  IIO_(TRIGGERED_)BUFFER in Kconfig (git-fixes).
- iio: accel: kx022a: add missing select IIO_(TRIGGERED_)BUFFER
  in Kconfig (git-fixes).
- iio: light: veml6030: fix ALS sensor resolution (git-fixes).
- iio: light: opt3001: add missing full-scale range value
  (git-fixes).
- iio: light: veml6030: fix IIO device retrieval from embedded
  device (git-fixes).
- iio: accel: bma400: Fix uninitialized variable field_value in
  tap event handling (git-fixes).
- serial: imx: Update mctrl old_status on RTSD interrupt
  (git-fixes).
- vt: prevent kernel-infoleak in con_font_get() (git-fixes).
- xhci: Mitigate failed set dequeue pointer commands (git-fixes).
- xhci: Fix incorrect stream context type macro (git-fixes).
- xhci: tegra: fix checked USB2 port number (git-fixes).
- usb: dwc3: Wait for EndXfer completion before restoring
  GUSB2PHYCFG (git-fixes).
- usb: typec: altmode should keep reference to parent (git-fixes).
- commit 5e08e81
* Sat Oct 19 2024 mfranc@suse.cz
- supported.conf: mark nhpoly1305 module as supported (bsc#1231035)
  In 59d03d7c990c, we marked adiantum as a supported module, I'm afraid
  we need to mark nhpoly1305 as supported too (as a dependecy) if we
  want adiantum to work.
  This makes tcrypt test case 219 (adiantum) pass on SLE15-SP6 (tested
  on z15 VM).
- commit 01d2906
* Fri Oct 18 2024 tbogendoerfer@suse.de
- vmxnet3: Fix packet corruption in vmxnet3_xdp_xmit_frame
  (bsc#1226498).
- vmxnet3: Fix missing reserved tailroom (bsc#1226498).
- commit 1bd55aa
* Fri Oct 18 2024 tbogendoerfer@suse.de
- vmxnet3: update to version 9 (bsc#1226498).
- vmxnet3: add command to allow disabling of offloads
  (bsc#1226498).
- vmxnet3: add latency measurement support in vmxnet3
  (bsc#1226498).
- vmxnet3: prepare for version 9 changes (bsc#1226498).
- vmxnet3: Add XDP support (bsc#1226498).
- commit 3fdc8e3
* Fri Oct 18 2024 ailiop@suse.com
- SUNRPC: Fix integer overflow in decode_rc_list() (git-fixes).
- commit 15be003
* Fri Oct 18 2024 ailiop@suse.com
- NFSD: Mark filecache "down" if init fails (git-fixes).
- commit ceca4b8
* Fri Oct 18 2024 ailiop@suse.com
- SUNRPC: clnt.c: Remove misleading comment (git-fixes).
- commit 2e12710
* Fri Oct 18 2024 ailiop@suse.com
- nfs: fix memory leak in error path of nfs4_do_reclaim
  (git-fixes).
- commit 1994ef6
* Fri Oct 18 2024 ailiop@suse.com
- nfsd: fix delegation_blocked() to block correctly for at least
  30 seconds (git-fixes).
- commit f66078d
* Fri Oct 18 2024 ailiop@suse.com
- nfsd: return -EINVAL when namelen is 0 (git-fixes).
- commit 1bc1c36
* Fri Oct 18 2024 ailiop@suse.com
- nfsd: call cache_put if xdr_reserve_space returns NULL
  (git-fixes).
- commit 003f784
* Fri Oct 18 2024 ailiop@suse.com
- nfsd: map the EBADMSG to nfserr_io to avoid warning (git-fixes).
- commit 5b8020a
* Fri Oct 18 2024 ailiop@suse.com
- NFSD: Fix NFSv4's PUTPUBFH operation (git-fixes).
- commit 88290fb
* Fri Oct 18 2024 ailiop@suse.com
- nfsd: fix refcount leak when file is unhashed after being found
  (git-fixes).
- commit 5a551a1
* Fri Oct 18 2024 ailiop@suse.com
- nfsd: remove unneeded EEXIST error check in nfsd_do_file_acquire
  (git-fixes).
- commit 6d18e0e
* Fri Oct 18 2024 ailiop@suse.com
- NFS: Avoid unnecessary rescanning of the per-server delegation
  list (git-fixes).
- commit e5841ef
* Fri Oct 18 2024 ailiop@suse.com
- NFSv4: Fix clearing of layout segments in layoutreturn
  (git-fixes).
- commit ec4c812
* Fri Oct 18 2024 tiwai@suse.de
- ALSA: hda/conexant - Use cached pin control for Node 0x1d on
  HP EliteOne 1000 G2 (git-fixes).
- ALSA/hda: intel-sdw-acpi: simplify sdw-master-count property
  read (stable-fixes).
- ALSA/hda: intel-sdw-acpi: fetch fwnode once in
  sdw_intel_scan_controller() (stable-fixes).
- ALSA/hda: intel-sdw-acpi: cleanup sdw_intel_scan_controller
  (stable-fixes).
- ALSA: hda/tas2781: Add new quirk for Lenovo, ASUS, Dell projects
  (stable-fixes).
- ALSA: line6: update contact information (stable-fixes).
- ALSA: hda/conexant - Fix audio routing for HP EliteOne 1000 G2
  (stable-fixes).
- ALSA: hda: Sound support for HP Spectre x360 16 inch model 2024
  (stable-fixes).
- commit fb6c2ec
* Fri Oct 18 2024 tiwai@suse.de
- firmware: arm_scmi: Fix the double free in
  scmi_debugfs_common_setup() (git-fixes).
- ALSA: hda/cs8409: Fix possible NULL dereference (git-fixes).
- netdevsim: use cond_resched() in nsim_dev_trap_report_work()
  (git-fixes).
- macsec: don't increment counters for an unrelated SA
  (git-fixes).
- net: usb: usbnet: fix race in probe failure (git-fixes).
- HID: plantronics: Workaround for an unexcepted opposite volume
  key (stable-fixes).
- usb: xhci: Fix problem with xhci resume from suspend
  (stable-fixes).
- usb: storage: ignore bogus device raised by JieLi BR21 USB
  sound chip (stable-fixes).
- net: phy: Remove LED entry from LEDs list on unregister
  (git-fixes).
- net: phy: bcm84881: Fix some error handling paths (git-fixes).
- net: phy: dp83869: fix memory corruption when enabling fiber
  (git-fixes).
- kthread: unpark only parked kthread (git-fixes).
- unicode: Don't special case ignorable code points
  (stable-fixes).
- fbdev: sisfb: Fix strbuf array overflow (stable-fixes).
- fbcon: Fix a NULL pointer dereference issue in fbcon_putcs
  (stable-fixes).
- drm/amd/display: Check null pointer before dereferencing se
  (stable-fixes).
- driver core: bus: Fix double free in driver API bus_register()
  (stable-fixes).
- driver core: bus: Return -EIO instead of 0 when show/store
  invalid bus attribute (stable-fixes).
- comedi: ni_routing: tools: Check when the file could not be
  opened (stable-fixes).
- serial: protect uart_port_dtr_rts() in uart_shutdown() too
  (stable-fixes).
- usb: dwc2: Adjust the timing of USB Driver Interrupt
  Registration in the Crashkernel Scenario (stable-fixes).
- usb: chipidea: udc: enable suspend interrupt after usb reset
  (stable-fixes).
- i3c: master: cdns: Fix use after free vulnerability in
  cdns_i3c_master Driver Due to Race Condition (stable-fixes).
- media: videobuf2-core: clear memory related fields in
  __vb2_plane_dmabuf_put() (stable-fixes).
- clk: imx: Remove CLK_SET_PARENT_GATE for DRAM mux for i.MX7D
  (stable-fixes).
- clk: bcm: bcm53573: fix OF node leak in init (stable-fixes).
- i2c: i801: Use a different adapter-name for IDF adapters
  (stable-fixes).
- mfd: intel_soc_pmic_chtwc: Make Lenovo Yoga Tab 3 X90F DMI
  match less strict (stable-fixes).
- soundwire: intel_bus_common: enable interrupts before exiting
  reset (stable-fixes).
- PCI: Mark Creative Labs EMU20k2 INTx masking as broken
  (stable-fixes).
- PCI: Add ACS quirk for Qualcomm SA8775P (stable-fixes).
- PCI: Add function 0 DMA alias quirk for Glenfly Arise chip
  (stable-fixes).
- drm/amd/display: Revert "Check HDCP returned status"
  (stable-fixes).
- HID: multitouch: Add support for lenovo Y9000P Touchpad
  (stable-fixes).
- drm/amd/display: Remove a redundant check in authenticated_dp
  (stable-fixes).
- HID: i2c-hid: Remove I2C_HID_QUIRK_SET_PWR_WAKEUP_DEV quirk
  (stable-fixes).
- commit f829d20
* Fri Oct 18 2024 nmorey@suse.com
- RDMA/mlx5: Enforce umem boundaries for explicit ODP page faults (git-fixes)
- commit b9b835e
* Fri Oct 18 2024 nmorey@suse.com
- RDMA/rtrs-srv: Avoid null pointer deref during path establishment (git-fixes)
- commit cf9eccb
* Fri Oct 18 2024 nmorey@suse.com
- RDMA/mad: Improve handling of timed out WRs of mad agent (git-fixes)
- commit 72bef76
* Thu Oct 17 2024 krisman@suse.de
- io_uring/sqpoll: do not put cpumask on stack (git-fixes).
- io_uring/sqpoll: retain test for whether the CPU is valid
  (git-fixes).
- commit ff84c2d
* Thu Oct 17 2024 vbabka@suse.cz
- mm: avoid leaving partial pfn mappings around in error case
  (CVE-2024-47674 bsc#1231673).
- commit 83d1625
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Avoid CPU lockups due fifo occupancy check loop (git-fixes)
- commit 21fb93d
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix the GID table length (git-fixes)
- commit 6a0779e
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix a bug while setting up Level-2 PBL pages (git-fixes)
- commit d91ede3
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Change the sequence of updating the CQ toggle value (git-fixes)
- commit 414cbde
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Return more meaningful error (git-fixes)
- commit 6755798
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix incorrect dereference of srq in async event (git-fixes)
- commit 4e1ef61
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix out of bound check (git-fixes)
- commit d8d1339
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix the max CQ WQEs for older adapters (git-fixes)
- commit 598626b
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/srpt: Make slab cache names unique (git-fixes)
- commit 29c0fcb
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/irdma: Fix misspelling of "accept*" (git-fixes)
- commit 2566da7
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/cxgb4: Fix RDMA_CM_EVENT_UNREACHABLE error for iWARP (git-fixes)
- commit 89fa27f
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/core: Fix ENODEV error for iWARP test over vlan (git-fixes)
- commit 4c15511
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Add a check for memory allocation (git-fixes)
- commit abea295
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix incorrect AVID type in WQE structure (git-fixes)
- commit ae91db1
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix a possible memory leak (git-fixes)
- commit 77c3f34
* Wed Oct 16 2024 krisman@suse.de
- io_uring/rw: fix cflags posting for single issue multishot read
  (git-fixes).
- commit 320c7ee
* Wed Oct 16 2024 krisman@suse.de
- io_uring/net: harden multishot termination case for recv
  (git-fixes).
- commit 6529e65
* Wed Oct 16 2024 krisman@suse.de
- io_uring: check for presence of task_work rather than
  TIF_NOTIFY_SIGNAL (git-fixes).
- commit 5b92400
* Wed Oct 16 2024 krisman@suse.de
- io_uring/io-wq: inherit cpuset of cgroup in io worker
  (git-fixes).
- commit 474a07e
* Wed Oct 16 2024 krisman@suse.de
- io_uring/io-wq: do not allow pinning outside of cpuset
  (git-fixes).
- commit e99d8a8
* Wed Oct 16 2024 krisman@suse.de
- io_uring/rw: treat -EOPNOTSUPP for IOCB_NOWAIT like -EAGAIN
  (git-fixes).
- io_uring/sqpoll: do not allow pinning outside of cpuset
  (git-fixes).
- commit 37d0dce
* Wed Oct 16 2024 krisman@suse.de
- io_uring/eventfd: move to more idiomatic RCU free usage
  (git-fixes).
- commit 4e262c3
* Wed Oct 16 2024 jack@suse.cz
- udf: Avoid excessive partition lengths (bsc#1230773
  CVE-2024-46777).
- commit ec61258
* Wed Oct 16 2024 jack@suse.cz
- fsnotify: clear PARENT_WATCHED flags lazily (bsc#1231439
  CVE-2024-47660).
- commit 133a7e9
* Wed Oct 16 2024 davide.benini@suse.com
- netem: fix return value if duplicate enqueue fails
  (CVE-2024-45016 bsc#1230429).
- commit 8c9c269
* Wed Oct 16 2024 oneukum@suse.com
- media: pci: ipu3-cio2: Initialise timing struct to avoid a
  compiler warning (git-fixes).
- commit c21df3e
* Wed Oct 16 2024 oneukum@suse.com
- wifi: rtw88: Fix USB/SDIO devices not transmitting beacons
  (git-fixes).
- commit d46bb93
* Wed Oct 16 2024 msuchanek@suse.de
- crypto: powerpc/p10-aes-gcm - Add dependency on CRYPTO_SIMD and
  re-enable CRYPTO_AES_GCM_P10 (bsc#1230501 ltc#208632).
  - Update config files.
- crypto: powerpc/p10-aes-gcm - Register modules as SIMD
  (bsc#1230501 ltc#208632).
- crypto: powerpc/p10-aes-gcm - Re-write AES/GCM stitched
  implementation (bsc#1230501 ltc#208632).
- crypto: powerpc/p10-aes-gcm - Disable CRYPTO_AES_GCM_P10
  (bsc#1230501 ltc#208632).
- powerpc/crypto: don't build aes-gcm-p10 by default (bsc#1230501
  ltc#208632).
- powerpc/crypto: fix missing skcipher dependency for aes-gcm-p10
  (bsc#1230501 ltc#208632).
- commit a579f42
* Tue Oct 15 2024 oneukum@suse.com
- powercap: intel_rapl: Fix off by one in get_rpi() (git-fixes).
- commit 6c73c0c
* Tue Oct 15 2024 tzimmermann@suse.com
- drm/amd/display: Disable DMCUB timeout for DCN35 (bsc#1231435 CVE-2024-46870)
- commit 0a39326
* Tue Oct 15 2024 tzimmermann@suse.com
- drm/amd/display: Add disable timeout option (bsc#1231435)
- commit cb303b5
* Tue Oct 15 2024 tiwai@suse.de
- Refresh patches.suse/paddings-add-paddings-to-TypeC-stuff.patch
  Drop superfluous file mode modifications in the patch that broke the
  patch expansion recently
- commit e7ac9e1
* Tue Oct 15 2024 tiwai@suse.de
- Move upstreamed scsi patch into sorted section
- commit 5db43b0
* Mon Oct 14 2024 mkubecek@suse.cz
- nbd: fix race between timeout and normal completion
  (bsc#1230918).
- commit 57c54c8
* Mon Oct 14 2024 lhenriques@suse.de
- ext4: mark fc as ineligible using an handle in ext4_xattr_set()
  (bsc#1231640).
- ext4: use handle to mark fc as ineligible in
  __track_dentry_update() (bsc#1231639).
- jbd2: correctly compare tids with tid_geq function in
  jbd2_fc_begin_commit (bsc#1231638).
- ext4: fix incorrect tid assumption in ext4_fc_mark_ineligible()
  (bsc#1231637).
- ext4: fix fast commit inode enqueueing during a full journal
  commit (bsc#1231636).
- ext4: don't track ranges in fast_commit if inode has inlined
  data (bsc#1231635).
- ext4: fix possible tid_t sequence overflows (bsc#1231634).
- commit 6951914
* Mon Oct 14 2024 oneukum@suse.com
- net: sysfs: Fix /sys/class/net/<iface> path for statistics
  (git-fixes).
- commit 54925d7
* Mon Oct 14 2024 oneukum@suse.com
- devlink: Fix command annotation documentation (git-fixes).
- commit 2b95827
* Mon Oct 14 2024 oneukum@suse.com
- x86/Documentation: Indent 'note::' directive for protocol
  version number note (git-fixes).
- commit ec31602
* Mon Oct 14 2024 ddiss@suse.de
- mm/filemap: optimize filemap folio adding (bsc#1231617).
- lib/xarray: introduce a new helper xas_get_order (bsc#1231617).
- mm/filemap: return early if failed to allocate memory for split
  (bsc#1231617).
- commit c3c5888
* Mon Oct 14 2024 oneukum@suse.com
- srcu: Fix callbacks acceleration mishandling (git-fixes).
- task_work: add kerneldoc annotation for 'data' argument
  (git-fixes).
- commit a4661ee
* Mon Oct 14 2024 tiwai@suse.de
- HID: amd_sfh: Switch to device-managed dmam_alloc_coherent()
  (git-fixes).
- hid: intel-ish-hid: Fix uninitialized variable 'rv' in
  ish_fw_xfer_direct_dma (git-fixes).
- usb: dwc3: core: Stop processing of pending events if controller
  is halted (git-fixes).
- usb: gadget: core: force synchronous registration (git-fixes).
- commit 2bb6fd5
* Sun Oct 13 2024 tiwai@suse.de
- hwmon: (adt7470) Add missing dependency on REGMAP_I2C
  (git-fixes).
- hwmon: (adm9240) Add missing dependency on REGMAP_I2C
  (git-fixes).
- hwmon: (mc34vr500) Add missing dependency on REGMAP_I2C
  (git-fixes).
- hwmon: (tmp513) Add missing dependency on REGMAP_I2C
  (git-fixes).
- hwmon: intel-m10-bmc-hwmon: relabel Columbiaville to CVL Die
  Temperature (git-fixes).
- commit 07e1f67
* Sat Oct 12 2024 tiwai@suse.de
- gpio: aspeed: Use devm_clk api to manage clock source
  (git-fixes).
- gpio: aspeed: Add the flush write to ensure the write complete
  (git-fixes).
- ata: libata: avoid superfluous disk spin down + spin up during
  hibernation (git-fixes).
- nouveau/dmem: Fix vulnerability in migrate_to_ram upon copy
  error (git-fixes).
- nouveau/dmem: Fix privileged error in copy engine channel
  (git-fixes).
- drm/vc4: Stop the active perfmon before being destroyed
  (git-fixes).
- drm/v3d: Stop the active perfmon before being destroyed
  (git-fixes).
- drm/i915/hdcp: fix connector refcounting (git-fixes).
- commit 8534efe
* Sat Oct 12 2024 shung-hsi.yu@suse.com
- kABI: bpf: struct bpf_insn_acces_aux kABI workaround (git-fixes).
- commit c2cff36
* Fri Oct 11 2024 vkarasulli@suse.de
- Update patches.suse/ASoC-meson-axg-card-fix-use-after-free.patch
  (git-fixes CVE-2024-46849 bsc#1231073).
- Update
  patches.suse/KVM-x86-Acquire-kvm-srcu-when-handling-KVM_SET_VCPU_.patch
  (git-fixes CVE-2024-46830 bsc#1231116).
- Update
  patches.suse/PCI-keystone-Add-workaround-for-Errata-i2037-AM65x-S.patch
  (stable-fixes CVE-2024-47667 bsc#1231481).
- Update patches.suse/USB-usbtmc-prevent-kernel-usb-infoleak.patch
  (git-fixes CVE-2024-47671 bsc#1231541).
- Update patches.suse/arm64-tlb-Fix-TLBI-RANGE-operand.patch
  (bsc#1229585 CVE-2024-35980 bsc#1224574).
- Update
  patches.suse/dma-buf-heaps-Fix-off-by-one-in-CMA-heap-fault-handl.patch
  (git-fixes CVE-2024-46852 bsc#1231082).
- Update
  patches.suse/drm-amd-amdgpu-Check-tbo-resource-pointer.patch
  (stable-fixes CVE-2024-46807 bsc#1231138).
- Update
  patches.suse/drm-amd-display-Add-array-index-check-for-hdcp-ddc-a.patch
  (stable-fixes CVE-2024-46804 bsc#1231132).
- Update
  patches.suse/drm-amd-display-Avoid-overflow-from-uint32_t-to-uint.patch
  (stable-fixes CVE-2024-47661 bsc#1231496).
- Update
  patches.suse/drm-amd-display-Avoid-race-between-dcn10_set_drr-and.patch
  (git-fixes CVE-2024-46851 bsc#1231081).
- Update
  patches.suse/drm-amd-display-Check-BIOS-images-before-it-is-used.patch
  (stable-fixes CVE-2024-46809 bsc#1231148).
- Update
  patches.suse/drm-amd-display-Check-gpio_id-before-used-as-array-i.patch
  (stable-fixes CVE-2024-46818 bsc#1231203).
- Update
  patches.suse/drm-amd-display-Check-msg_id-before-processing-trans.patch
  (stable-fixes CVE-2024-46814 bsc#1231193).
- Update
  patches.suse/drm-amd-display-Check-num_valid_sets-before-accessin.patch
  (stable-fixes CVE-2024-46815 bsc#1231195).
- Update
  patches.suse/drm-amd-display-Correct-the-defined-value-for-AMDGPU.patch
  (stable-fixes CVE-2024-46871 bsc#1231434).
- Update
  patches.suse/drm-amd-display-Fix-index-may-exceed-array-range-wit.patch
  (stable-fixes CVE-2024-46811 bsc#1231179).
- Update
  patches.suse/drm-amd-display-Remove-register-from-DCN35-DMCUB-dia.patch
  (stable-fixes CVE-2024-47662 bsc#1231440).
- Update
  patches.suse/drm-amd-display-Skip-inactive-planes-within-ModeSupp.patch
  (stable-fixes CVE-2024-46812 bsc#1231187).
- Update
  patches.suse/drm-amd-display-Stop-amdgpu_dm-initialize-when-strea.patch
  (stable-fixes CVE-2024-46817 bsc#1231200).
- Update
  patches.suse/drm-amd-display-added-NULL-check-at-start-of-dc_vali.patch
  (stable-fixes CVE-2024-46802 bsc#1231111).
- Update
  patches.suse/drm-amd-pm-Fix-negative-array-index-read.patch
  (stable-fixes CVE-2024-46821 bsc#1231169).
- Update
  patches.suse/drm-amdgpu-Fix-smatch-static-checker-warning.patch
  (stable-fixes CVE-2024-46835 bsc#1231098).
- Update
  patches.suse/drm-amdgpu-Fix-the-warning-division-or-modulo-by-zer.patch
  (stable-fixes CVE-2024-46806 bsc#1231136).
- Update
  patches.suse/drm-amdgpu-fix-the-waring-dereferencing-hive.patch
  (stable-fixes CVE-2024-46805 bsc#1231135).
- Update
  patches.suse/drm-amdgpu-the-warning-dereferencing-obj-for-nbio_v7.patch
  (stable-fixes CVE-2024-46819 bsc#1231202).
- Update
  patches.suse/drm-amdkfd-Check-debug-trap-enable-before-write-dbg_.patch
  (stable-fixes CVE-2024-46803 bsc#1231131).
- Update
  patches.suse/drm-bridge-tc358767-Check-if-fully-initialized-befor.patch
  (stable-fixes CVE-2024-46810 bsc#1231178).
- Update
  patches.suse/i3c-mipi-i3c-hci-Error-out-instead-on-BUG_ON-in-IBI-.patch
  (stable-fixes CVE-2024-47665 bsc#1231452).
- Update
  patches.suse/lib-generic-radix-tree.c-Fix-rare-race-in-__genradix.patch
  (stable-fixes CVE-2024-47668 bsc#1231502).
- Update
  patches.suse/msft-hv-3054-x86-hyperv-fix-kexec-crash-due-to-VP-assist-page-cor.patch
  (git-fixes CVE-2024-46864 bsc#1231108).
- Update
  patches.suse/nilfs2-fix-state-management-in-error-path-of-log-writing-function.patch
  (git-fixes CVE-2024-47669 bsc#1231474).
- Update
  patches.suse/ocfs2-add-bounds-checking-to-ocfs2_xattr_find_entry.patch
  (bsc#1228410 CVE-2024-41016 CVE-2024-47670 bsc#1231537).
- Update
  patches.suse/perf-x86-intel-Limit-the-period-on-Haswell.patch
  (git-fixes CVE-2024-46848 bsc#1231072).
- Update
  patches.suse/platform-x86-panasonic-laptop-Fix-SINF-array-out-of-.patch
  (git-fixes CVE-2024-46859 bsc#1231089).
- Update
  patches.suse/rcu-Fix-buffer-overflow-in-print_cpu_stall_info.patch
  (bsc#1226623 CVE-2024-38576).
- Update
  patches.suse/rcu-tasks-Fix-show_rcu_tasks_trace_gp_kthread-buffer-overflow.patch
  (bsc#1226631 CVE-2024-38577).
- Update
  patches.suse/scsi-lpfc-Handle-mailbox-timeouts-in-lpfc_get_sfp_in.patch
  (bsc#1228857 CVE-2024-46842 bsc#1231101).
- Update
  patches.suse/spi-nxp-fspi-fix-the-KASAN-report-out-of-bounds-bug.patch
  (git-fixes CVE-2024-46853 bsc#1231083).
- Update
  patches.suse/spi-rockchip-Resolve-unbalanced-runtime-PM-system-PM.patch
  (git-fixes CVE-2024-46846 bsc#1231075).
- Update
  patches.suse/staging-iio-frequency-ad9834-Validate-frequency-para.patch
  (git-fixes CVE-2024-47663 bsc#1231441).
- Update
  patches.suse/usb-gadget-aspeed_udc-validate-endpoint-index-for-as.patch
  (stable-fixes CVE-2024-46836 bsc#1231092).
- Update
  patches.suse/usbnet-ipheth-do-not-stop-RX-on-failing-RX-callback.patch
  (git-fixes CVE-2024-46861 bsc#1231102).
- Update
  patches.suse/wifi-ath12k-fix-firmware-crash-due-to-invalid-peer-n.patch
  (stable-fixes CVE-2024-46827 bsc#1231171).
- Update
  patches.suse/wifi-iwlwifi-mvm-don-t-wait-for-tx-queues-if-firmwar.patch
  (stable-fixes CVE-2024-47672 bsc#1231540).
- Update
  patches.suse/wifi-iwlwifi-mvm-pause-TCM-when-the-firmware-is-stop.patch
  (stable-fixes CVE-2024-47673 bsc#1231539).
- Update
  patches.suse/wifi-iwlwifi-mvm-use-IWL_FW_CHECK-for-link-ID-check.patch
  (stable-fixes CVE-2024-46825 bsc#1231170).
- Update
  patches.suse/wifi-mt76-mt7921-fix-NULL-pointer-access-in-mt7921_i.patch
  (stable-fixes CVE-2024-46860 bsc#1231093).
- commit 1ed6329
* Fri Oct 11 2024 mgorman@suse.de
- sched/smt: Fix unbalance sched_smt_present dec/inc
  (CVE-2024-44958 bsc#1230179).
- sched/smt: Introduce sched_smt_present_inc/dec() helper
  (CVE-2024-44958 bsc#1230179).
- commit b09820b
* Fri Oct 11 2024 tiwai@suse.de
- crypto: octeontx* - Select CRYPTO_AUTHENC (git-fixes).
- commit 155c418
* Fri Oct 11 2024 tiwai@suse.de
- spi: spi-imx: Fix pm_runtime_set_suspended() with runtime pm
  enabled (git-fixes).
- spi: s3c64xx: fix timeout counters in flush_fifo (git-fixes).
- i2c: synquacer: Deal with optional PCLK correctly (git-fixes).
- media: imx335: Fix reset-gpio handling (git-fixes).
- i2c: xiic: Try re-initialization on bus busy timeout
  (git-fixes).
- platform/x86: touchscreen_dmi: add nanote-next quirk
  (stable-fixes).
- platform/x86: lenovo-ymc: Ignore the 0x0 state (stable-fixes).
- hwmon: (nct6775) add G15CF to ASUS WMI monitoring list
  (stable-fixes).
- power: reset: brcmstb: Do not go into infinite loop if reset
  fails (stable-fixes).
- wifi: ath9k_htc: Use __skb_set_length() for resetting urb
  before resubmit (stable-fixes).
- wifi: mt76: mt7915: hold dev->mt76.mutex while disabling tx
  worker (stable-fixes).
- wifi: mt76: mt7915: add dummy HW offload of IEEE 802.11
  fragmentation (stable-fixes).
- wifi: mt76: mt7915: disable tx worker during tx BA session
  enable/disable (stable-fixes).
- wifi: rtw89: avoid reading out of bounds when loading TX power
  FW elements (stable-fixes).
- wifi: rtw89: correct base HT rate mask for firmware
  (stable-fixes).
- wifi: mwifiex: Fix memcpy() field-spanning write warning in
  mwifiex_cmd_802_11_scan_ext() (stable-fixes).
- wifi: cfg80211: Set correct chandef when starting CAC
  (stable-fixes).
- wifi: mac80211: fix RCU list iterations (stable-fixes).
- wifi: iwlwifi: mvm: avoid NULL pointer dereference
  (stable-fixes).
- wifi: iwlwifi: allow only CN mcc from WRDD (stable-fixes).
- wifi: iwlwifi: mvm: drop wrong STA selection in TX
  (stable-fixes).
- wifi: iwlwifi: mvm: Fix a race in scan abort flow
  (stable-fixes).
- wifi: iwlwifi: mvm: use correct key iteration (stable-fixes).
- wifi: ath9k: fix possible integer overflow in
  ath9k_get_et_stats() (stable-fixes).
- wifi: ath11k: fix array out-of-bound access in SoC stats
  (stable-fixes).
- wifi: ath12k: fix array out-of-bound access in SoC stats
  (stable-fixes).
- wifi: rtw89: avoid to add interface to list twice when SER
  (stable-fixes).
- wifi: rtw88: select WANT_DEV_COREDUMP (stable-fixes).
- i2c: xiic: improve error message when transfer fails to start
  (stable-fixes).
- i2c: synquacer: Remove a clk reference from struct synquacer_i2c
  (stable-fixes).
- media: i2c: imx335: Enable regulator supplies (stable-fixes).
- commit 490fb1f
* Fri Oct 11 2024 tiwai@suse.de
- ALSA: usb-audio: Replace complex quirk lines with macros
  (stable-fixes).
- commit 6f67136
* Fri Oct 11 2024 tiwai@suse.de
- Bluetooth: RFCOMM: FIX possible deadlock in
  rfcomm_sk_state_change (git-fixes).
- ACPI: battery: Fix possible crash when unregistering a battery
  hook (git-fixes).
- ACPI: battery: Simplify battery hook locking (stable-fixes).
- ACPI: resource: Add Asus ExpertBook B2502CVA to
  irq1_level_low_skip_override[] (stable-fixes).
- ACPI: resource: Add Asus Vivobook X1704VAP to
  irq1_level_low_skip_override[] (stable-fixes).
- HID: Ignore battery for all ELAN I2C-HID devices (stable-fixes).
- HID: multitouch: Add support for Thinkpad X12 Gen 2 Kbd
  Portfolio (stable-fixes).
- ASoC: codecs: wsa883x: Handle reading version failure
  (stable-fixes).
- ALSA: usb-audio: Add logitech Audio profile quirk
  (stable-fixes).
- ALSA: usb-audio: Define macros for quirk table entries
  (stable-fixes).
- ALSA: hdsp: Break infinite MIDI input flush loop (stable-fixes).
- ALSA: asihpi: Fix potential OOB array access (stable-fixes).
- ALSA: usb-audio: Add input value sanity checks for standard
  types (stable-fixes).
- ACPI: PAD: fix crash in exit_round_robin() (stable-fixes).
- ACPI: video: Add force_vendor quirk for Panasonic Toughbook
  CF-18 (stable-fixes).
- ACPI: CPPC: Add support for setting EPP register in FFH
  (stable-fixes).
- ACPI: EC: Do not release locks during operation region accesses
  (stable-fixes).
- ACPICA: iasl: handle empty connection_node (stable-fixes).
- ACPICA: Fix memory leak if acpi_ps_get_next_field() fails
  (stable-fixes).
- ACPICA: Fix memory leak if acpi_ps_get_next_namepath() fails
  (stable-fixes).
- ACPICA: check null return of ACPI_ALLOCATE_ZEROED() in
  acpi_db_convert_to_package() (stable-fixes).
- crypto: octeontx2 - Fix authenc setkey (stable-fixes).
- crypto: octeontx - Fix authenc setkey (stable-fixes).
- Bluetooth: btusb: Add Realtek RTL8852C support ID 0x0489:0xe122
  (stable-fixes).
- can: netlink: avoid call to do_set_data_bittiming callback
  with stale can_priv::ctrlmode (stable-fixes).
- commit 650f32e
* Fri Oct 11 2024 ailiop@suse.com
- ocfs2: fix the la space leak when unmounting an ocfs2 volume
  (git-fixes).
- commit 92d1b30
* Fri Oct 11 2024 ailiop@suse.com
- jfs: Fix uninit-value access of new_ea in ea_buffer (git-fixes).
- commit b1e0ef1
* Fri Oct 11 2024 ailiop@suse.com
- jfs: check if leafidx greater than num leaves per dmap tree
  (git-fixes).
- commit 4cb79e7
* Fri Oct 11 2024 ailiop@suse.com
- jfs: Fix uaf in dbFreeBits (git-fixes).
- commit da4aab1
* Fri Oct 11 2024 ailiop@suse.com
- jfs: UBSAN: shift-out-of-bounds in dbFindBits (git-fixes).
- commit fee8a70
* Fri Oct 11 2024 shung-hsi.yu@suse.com
- kABI: bpf: enum bpf_{type_flag,arg_type} kABI workaround (git-fixes).
- commit 93e6047
* Thu Oct 10 2024 vkarasulli@suse.de
- iommu/amd: Allocate the page table root using GFP_KERNEL
  (git-fixes).
- commit cdbbb3f
* Thu Oct 10 2024 vkarasulli@suse.de
- iommu/amd: Fix typo of , instead of ; (git-fixes).
- commit baf85d0
* Thu Oct 10 2024 dwagner@suse.de
- block: sed-opal: add ioctl IOC_OPAL_SET_SID_PW (bsc#1229677).
- commit 5ca02dc
* Thu Oct 10 2024 hare@suse.de
- nvme-multipath: suppress partition scan until the disk is ready
  (bsc#1228244).
- commit 5accc60
* Wed Oct  9 2024 krisman@suse.de
- fix bitmap corruption on close_range() with CLOSE_RANGE_UNSHARE
  (CVE-2024-45025 bsc#1230456).
- commit c3824ef
* Wed Oct  9 2024 oneukum@suse.com
- i2c: core: Setup i2c_adapter runtime-pm before calling
  device_add() (git-fixes).
- commit 5095dfb
* Wed Oct  9 2024 oneukum@suse.com
- i2c: ismt: kill transaction in hardware on timeout (git-fixes).
- commit f6029bb
* Wed Oct  9 2024 vkarasulli@suse.de
- iommufd: Check the domain owner of the parent before creating
  a nesting domain (git-fixes).
- commit 3ff7340
* Wed Oct  9 2024 vkarasulli@suse.de
- iommufd: Protect against overflow of ALIGN() during iova
  allocation (git-fixes).
- commit fffeb67
* Wed Oct  9 2024 vkarasulli@suse.de
- iommu/amd: Do not set the D bit on AMD v2 table entries
  (git-fixes).
- commit e3053a9
* Wed Oct  9 2024 oneukum@suse.com
- i2c: omap: wakeup the controller during suspend() callback
  (git-fixes).
- commit 52f3dad
* Wed Oct  9 2024 oneukum@suse.com
- i2c: omap: switch to NOIRQ_SYSTEM_SLEEP_PM_OPS() and
  RUNTIME_PM_OPS() (git-fixes).
- commit 3fe2f94
* Wed Oct  9 2024 tiwai@suse.de
- Drop the previous HD-audio TAS2781 fix (bsc#1230132)
  The proposed fix turned out to be incorrect
- commit b3a4c29
* Wed Oct  9 2024 rgoldwyn@suse.com
- Update config files: Enable NFSD_V2 (bsc#1230914)
  NFSv2 was disabled because of the upstream kernel commit 2f3a4b2ac2f2
  ("nfsd: allow disabling NFSv2 at compile time").
  Enable it for the few users who cannot upgrade to NFSv3.
  https://bugzilla.suse.com/show_bug.cgi?id=1230914#c5
- commit 9e3254d
* Wed Oct  9 2024 oneukum@suse.com
- i2c: stm32f7: perform most of irq job in threaded handler
  (git-fixes).
- commit 4a35980
* Wed Oct  9 2024 oneukum@suse.com
- i2c: i801: Add lis3lv02d for Dell XPS 15 7590 (git-fixes).
- commit 38f58af
* Wed Oct  9 2024 oneukum@suse.com
- i2c: i801: Add lis3lv02d for Dell Precision 3540 (git-fixes).
- commit 036aff9
* Wed Oct  9 2024 oneukum@suse.com
- i2c: cpm: Remove linux,i2c-index conversion from be32
  (git-fixes).
- commit 5d04b4e
* Wed Oct  9 2024 oneukum@suse.com
- i2c: ocores: Move system PM hooks to the NOIRQ phase
  (git-fixes).
- commit 0df7a53
* Wed Oct  9 2024 oneukum@suse.com
- i2c: ocores: Remove #ifdef guards for PM related functions
  (git-fixes).
- commit ead06ad
* Wed Oct  9 2024 tiwai@suse.de
- wifi: iwlwifi: config: label 'gl' devices as discrete
  (git-fixes).
- commit 6321867
* Wed Oct  9 2024 tiwai@suse.de
- kconfig: qconf: fix buffer overflow in debug links (git-fixes).
- platform/x86: ISST: Fix the KASAN report slab-out-of-bounds bug
  (git-fixes).
- i2c: stm32f7: Do not prepare/unprepare clock during runtime
  suspend/resume (git-fixes).
- gpio: davinci: fix lazy disable (git-fixes).
- drm/i915/gem: fix bitwise and logical AND mixup (git-fixes).
- drm/sched: Always wake up correct scheduler in
  drm_sched_entity_push_job (git-fixes).
- drm/sched: Add locking to drm_sched_entity_modify_sched
  (git-fixes).
- drm: Consistently use struct drm_mode_rect for FB_DAMAGE_CLIPS
  (git-fixes).
- Bluetooth: hci_event: Align BR/EDR JUST_WORKS paring with LE
  (git-fixes).
- Bluetooth: btmrvl: Use IRQF_NO_AUTOEN flag in request_irq()
  (git-fixes).
- ieee802154: Fix build error (git-fixes).
- Input: adp5589-keys - fix adp5589_gpio_get_value() (git-fixes).
- Input: adp5589-keys - fix NULL pointer dereference (git-fixes).
- drm/amdgpu/vcn: enable AV1 on both instances (stable-fixes).
- drm/amd/display: Validate backlight caps are sane
  (stable-fixes).
- drm/amd/display: Skip to enable dsc if it has been off
  (stable-fixes).
- drm/amd/display: Add HDMI DSC native YCbCr422 support
  (stable-fixes).
- drm/amd/display: Clean up dsc blocks in accelerated mode
  (stable-fixes).
- drm/amd/display: Round calculated vtotal (stable-fixes).
- efistub/tpm: Use ACPI reclaim memory for event log to avoid
  corruption (stable-fixes).
- iio: magnetometer: ak8975: drop incorrect AK09116 compatible
  (git-fixes).
- Input: i8042 - add TUXEDO Stellaris 15 Slim Gen6 AMD to i8042
  quirk table (stable-fixes).
- Input: i8042 - add another board name for TUXEDO Stellaris
  Gen5 AMD line (stable-fixes).
- Input: i8042 - add TUXEDO Stellaris 16 Gen5 AMD to i8042 quirk
  table (stable-fixes).
- hwmon: (max16065) Fix alarm attributes (git-fixes).
- ACPI: resource: Add another DMI match for the TongFang GMxXGxx
  (stable-fixes).
- wifi: rtw88: 8821cu: Remove VID/PID 0bda:c82c (stable-fixes).
- ASoC: tas2781: Use of_property_read_reg() (stable-fixes).
- wifi: iwlwifi: remove AX101, AX201 and AX203 support from LNL
  (stable-fixes).
- hwmon: (max16065) Remove use of i2c_match_id() (stable-fixes).
- nouveau/gsp: Avoid addressing beyond end of rpc->entries
  (stable-fixes).
- thunderbolt: Improve DisplayPort tunnel setup process to be
  more robust (stable-fixes).
- iio: magnetometer: ak8975: Fix 'Unexpected device' error
  (git-fixes).
- iio: magnetometer: ak8975: Convert enum->pointer for data in
  the match tables (stable-fixes).
- commit 85984c8
* Wed Oct  9 2024 oneukum@suse.com
- i2c: core: fix lockdep warning for sparsely nested adapter chain
  (git-fixes).
- commit 691570d
* Wed Oct  9 2024 oneukum@suse.com
- i2c: exynos5: Calculate t_scl_l, t_scl_h according to i2c spec
  (git-fixes).
- commit cbbb120
* Wed Oct  9 2024 oneukum@suse.com
- i2c: i801: add helper i801_restore_regs (git-fixes).
- commit 3839f86
* Wed Oct  9 2024 oneukum@suse.com
- i2c: rcar: properly format a debug output (git-fixes).
- commit e7085c8
* Wed Oct  9 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add a test case to write mtu result into .rodata
  (git-fixes).
- selftests/bpf: Add a test case to write strtol result into
  .rodata (git-fixes).
- commit 805bbba
* Wed Oct  9 2024 shung-hsi.yu@suse.com
- selftests/bpf: Rename ARG_PTR_TO_LONG test description
  (git-fixes).
- selftests/bpf: Fix ARG_PTR_TO_LONG {half-,}uninitialized test
  (git-fixes).
- bpf: Zero former ARG_PTR_TO_{LONG,INT} args in case of error
  (git-fixes).
- bpf: Improve check_raw_mode_ok test for MEM_UNINIT-tagged types
  (git-fixes).
- commit 4580630
* Wed Oct  9 2024 shung-hsi.yu@suse.com
- bpf: Fix helper writes to read-only maps (git-fixes).
- bpf: Remove truncation test in bpf_strtol and bpf_strtoul
  helpers (git-fixes).
- bpf: Fix bpf_strtol and bpf_strtoul helpers for 32bit
  (git-fixes).
- commit 5fc2ffd
* Wed Oct  9 2024 vkarasulli@suse.de
- bpf: Remove tst_run from lwt_seg6local_prog_ops (bsc#1230801
  CVE-2024-46754).
- commit a7335b8
* Wed Oct  9 2024 shung-hsi.yu@suse.com
- bpf: Fix error message on kfunc arg type mismatch (git-fixes).
- commit 04ed437
* Wed Oct  9 2024 shung-hsi.yu@suse.com
- selftests/bpf: test for malformed BPF_CORE_TYPE_ID_LOCAL
  relocation (git-fixes).
- bpf: correctly handle malformed BPF_CORE_TYPE_ID_LOCAL relos
  (git-fixes).
- commit 67ebe66
* Wed Oct  9 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add tests for ldsx of pkt data/data_end/data_meta
  accesses (git-fixes).
- bpf: Fail verification for sign-extension of packet
  data/data_end/data_meta (git-fixes).
- bpf, lsm: Add disabled BPF LSM hook list (git-fixes).
- commit df1486e
* Wed Oct  9 2024 shung-hsi.yu@suse.com
- bpf, net: Fix a potential race in do_sock_getsockopt()
  (git-fixes).
- bpf: Fix tailcall cases in test_bpf (git-fixes).
- bpf, x64: Remove tail call detection (git-fixes).
- bpf, verifier: Correct tail_call_reachable for bpf prog
  (git-fixes).
- commit e072387
* Tue Oct  8 2024 ohering@suse.de
- add bug reference for a mana change (bsc#1229769).
- commit 64c619e
* Tue Oct  8 2024 dsterba@suse.com
- net/sched: taprio: extend minimum interval restriction to entire cycle too (CVE-2024-36244 bsc#1226797)
- commit 5ade9d6
* Tue Oct  8 2024 andrea.porta@suse.com
- arm64: fix selection of HAVE_DYNAMIC_FTRACE_WITH_ARGS
  (git-fixes).
- commit 7e90455
* Tue Oct  8 2024 andrea.porta@suse.com
- arm64: errata: Enable the AC03_CPU_38 workaround for ampere1a
  (git-fixes).
- commit 994f16f
* Tue Oct  8 2024 jlee@suse.com
- aoe: fix the potential use-after-free problem in more places
  (bsc#1218562 CVE-2023-6270).
- commit 1a991ba
* Tue Oct  8 2024 tiwai@suse.de
- ALSA: hda: tas2781: Fix missing setup at runtime PM
  (bsc#1230132).
- commit 3dc7842
* Tue Oct  8 2024 tiwai@suse.de
- Move upstreamed sound patch into sorted section
- commit b11079c
* Tue Oct  8 2024 msuchanek@suse.de
- kbuild,bpf: Add module-specific pahole flags for distilled
  base BTF (bsc#1230414 bsc#1229450).
- kbuild: bpf: Tell pahole to DECL_TAG kfuncs (bsc#1230414
  bsc#1229450).
- kbuild, bpf: Use test-ge check for v1.25-only pahole
  (bsc#1230414 bsc#1229450).
- kbuild,bpf: Switch to using --btf_features for pahole v1.26
  and later (bsc#1230414 bsc#1229450).
- kbuild: avoid too many execution of scripts/pahole-flags.sh
  (bsc#1230414 bsc#1229450).
- btf, scripts: rust: drop is_rust_module.sh (bsc#1230414
  bsc#1229450).
- commit e2cacce
* Tue Oct  8 2024 tiwai@suse.de
- Use pahole -j1 option for reproducible builds (bsc#1230414
  bsc#1229450).
- commit 340585e
* Tue Oct  8 2024 lhenriques@suse.de
- ceph: fix cap ref leak via netfs init_request (bsc#1231384).
- commit ca24d43
* Tue Oct  8 2024 jgross@suse.com
- vhost/scsi: null-ptr-dereference in vhost_scsi_get_req()
  (git-fixes).
- commit 267df6b
* Tue Oct  8 2024 jgross@suse.com
- virtio_console: fix misc probe bugs (git-fixes).
- commit f7d3065
* Tue Oct  8 2024 ohering@suse.de
- RDMA/mana_ib: use the correct page size for mapping user-mode
  doorbell page (git-fixes).
- RDMA/mana_ib: use the correct page table index based on hardware
  page size (git-fixes).
- tools: hv: rm .*.cmd when make clean (git-fixes).
- x86/hyperv: Set X86_FEATURE_TSC_KNOWN_FREQ when Hyper-V provides
  frequency (git-fixes).
- commit 059fd95
* Tue Oct  8 2024 jgross@suse.com
- KVM: VMX: Set PFERR_GUEST_{FINAL,PAGE}_MASK if and only if
  the GVA is valid (git-fixes).
- commit bb6f3d3
* Tue Oct  8 2024 jgross@suse.com
- KVM: x86/mmu: Skip emulation on page fault iff 1+ SPs were
  unprotected (git-fixes).
- commit bcfafe2
* Tue Oct  8 2024 jgross@suse.com
- KVM: x86/mmu: Trigger unprotect logic only on write-protection
  page faults (git-fixes).
- commit 322cf36
* Mon Oct  7 2024 jgross@suse.com
- KVM: VMX: Also clear SGX EDECCSSA in KVM CPU caps when SGX is
  disabled (git-fixes).
- commit d7b7771
* Mon Oct  7 2024 fdmanana@suse.com
- btrfs: send: fix invalid clone operation for file that got
  its size decreased (git-fixes).
- commit 26ee3ac
* Mon Oct  7 2024 jgross@suse.com
- KVM: x86: Exit to userspace if fastpath triggers one on
  instruction skip (git-fixes).
- commit 1621f7b
* Mon Oct  7 2024 jgross@suse.com
- KVM: x86: Dedup fastpath MSR post-handling logic (git-fixes).
- commit c20ff7c
* Mon Oct  7 2024 jgross@suse.com
- KVM: x86: Re-enter guest if WRMSR(X2APIC_ICR) fastpath is
  successful (git-fixes).
- commit 0dc4c78
* Mon Oct  7 2024 jgross@suse.com
- kABI fix of VM: x86: Re-split x2APIC ICR into ICR+ICR2 for AMD
  (x2AVIC) (git-fixes).
- commit 0a6716e
* Mon Oct  7 2024 jgross@suse.com
- KVM: x86: Re-split x2APIC ICR into ICR+ICR2 for AMD (x2AVIC)
  (git-fixes).
- commit 6a07b23
* Mon Oct  7 2024 jgross@suse.com
- KVM: x86: Move x2APIC ICR helper above kvm_apic_write_nodecode()
  (git-fixes).
- commit 4f194f7
* Mon Oct  7 2024 oneukum@suse.com
- USB: misc: yurex: fix race between read and write (git-fixes).
- commit 7f6ab55
* Mon Oct  7 2024 oneukum@suse.com
- USB: misc: cypress_cy7c63: check for short transfer (git-fixes).
- commit 3dcfad1
* Mon Oct  7 2024 oneukum@suse.com
- USB: appledisplay: close race between probe and completion
  handler (git-fixes).
- commit 888718f
* Mon Oct  7 2024 jgross@suse.com
- KVM: x86: Enforce x2APIC's must-be-zero reserved ICR bits
  (git-fixes).
- commit 891c3ef
* Mon Oct  7 2024 oneukum@suse.com
- usb: xhci: fix loss of data on Cadence xHC (git-fixes).
- commit 9e9d585
* Mon Oct  7 2024 jgross@suse.com
- KVM: Write the per-page "segment" when clearing (part of)
  a guest page (git-fixes).
- commit dae8f10
* Mon Oct  7 2024 oneukum@suse.com
- xhci: Add a quirk for writing ERST in high-low order
  (git-fixes).
- commit d0eccfc
* Mon Oct  7 2024 tzimmermann@suse.com
- drm/amd/display: Validate function returns (bsc#1230774 CVE-2024-46775)
- commit fc9ad2b
* Mon Oct  7 2024 jgross@suse.com
- KVM: Fix coalesced_mmio_has_room() to avoid premature userspace
  exit (git-fixes).
- commit 93dbc58
* Mon Oct  7 2024 jgross@suse.com
- KVM: Use dedicated mutex to protect kvm_usage_count to avoid
  deadlock (git-fixes).
- commit 2ff88a8
* Mon Oct  7 2024 msuchanek@suse.de
- Delete some more obsolete scripts
- commit 9bb77f8
* Mon Oct  7 2024 jgross@suse.com
- KVM: SVM: Disallow guest from changing userspace's
  MSR_AMD64_DE_CFG value (git-fixes).
- commit c8fa16d
* Mon Oct  7 2024 pjakobsson@suse.de
- drm/amd/display: Stop amdgpu_dm initialize when link nums greater than max_links (CVE-2024-46816 bsc#1231197).
- commit c05e7e2
* Mon Oct  7 2024 jgross@suse.com
- net: test for not too small csum_start in
  virtio_net_hdr_to_skb() (git-fixes).
- commit ed78dff
* Mon Oct  7 2024 jgross@suse.com
- vhost_vdpa: assign irq bypass producer token correctly
  (git-fixes).
- commit 1a9cba6
* Mon Oct  7 2024 pjakobsson@suse.de
- drm/amd/display: Check link_index before accessing dc->links (CVE-2024-46813 bsc#1231191).
- commit eb31596
* Mon Oct  7 2024 jgross@suse.com
- minmax: avoid overly complex min()/max() macro arguments in xen
  (git-fixes).
- Refresh
  patches.suse/xen-move-max_pfn-in-xen_memory_setup-out-of-function.patch.
- commit 754808b
* Sat Oct  5 2024 tiwai@suse.de
- ALSA: hda/conexant: Fix conflicting quirk for System76 Pangolin
  (git-fixes).
- ALSA: line6: add hw monitor volume control to POD HD500X
  (stable-fixes).
- ALSA: usb-audio: Add native DSD support for Luxman D-08u
  (stable-fixes).
- ALSA: core: add isascii() check to card ID generator
  (stable-fixes).
- ASoC: qcom: sm8250: add qrb4210-rb2-sndcard compatible string
  (stable-fixes).
- ASoC: imx-card: Set card.owner to avoid a warning calltrace
  if SND=m (git-fixes).
- ASoC: fsl_sai: Enable 'FIFO continue on error' FCONT bit
  (stable-fixes).
- ASoC: codecs: lpass-rx-macro: add missing
  CDC_RX_BCL_VBAT_RF_PROC2 to default regs values (stable-fixes).
- ASoC: atmel: mchp-pdmc: Skip ALSA restoration if substream
  runtime is uninitialized (git-fixes).
- ASoC: amd: yc: Add quirk for HP Dragonfly pro one
  (stable-fixes).
- Revert "ALSA: hda: Conditionally use snooping for AMD HDMI"
  (stable-fixes).
- ALSA: hda/realtek: Add a quirk for HP Pavilion 15z-ec200
  (stable-fixes).
- ALSA: silence integer wrapping warning (stable-fixes).
- ALSA: Reorganize kerneldoc parameter names (stable-fixes).
- ALSA: hda/realtek: Fix the push button function for the ALC257
  (git-fixes).
- ALSA: hda/conexant: fix some typos (stable-fixes).
- ALSA: mixer_oss: Remove some incorrect kfree_const() usages
  (git-fixes).
- ALSA: hda/realtek: Add quirk for Huawei MateBook 13 KLV-WX9
  (stable-fixes).
- ALSA: usb-audio: Add delay quirk for VIVO USB-C HEADSET
  (stable-fixes).
- ALSA: hda/tas2781: Add new quirk for Lenovo Y990 Laptop
  (stable-fixes).
- ALSA: hda/realtek: fix mute/micmute LED for HP mt645 G8
  (stable-fixes).
- commit 1cdc743
* Fri Oct  4 2024 mkoutny@suse.com
- rcu-tasks: Fix show_rcu_tasks_trace_gp_kthread buffer overflow
  (bsc#1226631).
- commit 36faf07
* Fri Oct  4 2024 mwilck@suse.com
- scsi: fnic: Move flush_work initialization out of if block
  (bsc#1230055).
- commit 9b5b899
* Fri Oct  4 2024 mkoutny@suse.com
- rcu: Fix buffer overflow in print_cpu_stall_info()
  (bsc#1226623).
- commit b695829
* Fri Oct  4 2024 msuchanek@suse.de
- Replace ALP with SLFO
- Refresh patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
- Update config files.
- commit 267a9d3
* Fri Oct  4 2024 msuchanek@suse.de
- Update config files.
  Update SUSE_VERSION to match SLFO project version
- commit 0d531e8
* Fri Oct  4 2024 msuchanek@suse.de
- config.sh: Remove Arm build project, we do not build armv7 configs
- commit 359f219
* Fri Oct  4 2024 msuchanek@suse.de
- config.sh: Update bugzilla product
- commit 0688dde
* Fri Oct  4 2024 msuchanek@suse.de
- rpm/release-projects: Add SLFO projects (bsc#1231293).
- commit 9f2c584
* Thu Oct  3 2024 msuchanek@suse.de
- Update patches.suse/powerpc-qspinlock-Fix-deadlock-in-MCS-queue.patch
  (bsc#1230295 ltc#206656 CVE-2024-46797 bsc#1230831).
- commit af09bb2
* Thu Oct  3 2024 mfranc@suse.cz
- KVM: s390: Fix SORTL and DFLTCC instruction format error in
  __insn32_query (git-fixes bsc#1231276).
- commit 39bab2d
* Thu Oct  3 2024 tabraham@suse.com
- s390/mm: Add cond_resched() to cmm_alloc/free_pages()
  (bsc#1228747).
- commit d0c79ab
* Thu Oct  3 2024 dsterba@suse.com
- ELF: fix kernel.randomize_va_space double read (CVE-2024-46826 bsc#1231115)
- commit 0519fb0
* Wed Oct  2 2024 dsterba@suse.com
- net/mlx5: Fix bridge mode operations when there are no VFs (CVE-2024-46857 bsc#1231087)
- commit b20fc2c
* Wed Oct  2 2024 dsterba@suse.com
- netfilter: nft_socket: fix sk refcount leaks (CVE-2024-46855 bsc#1231085)
- commit 6c66212
* Wed Oct  2 2024 tbogendoerfer@suse.de
- net: microchip: vcap: Fix use-after-free error in kunit test
  (CVE-2024-46831 bsc#1231117).
- commit 630e2e8
* Wed Oct  2 2024 mhocko@suse.com
- vmalloc: modify the alloc_vmap_area() error message for better
  diagnostics (jsc#PED-10978).
- mm: mmap: no need to call khugepaged_enter_vma() for stack
  (jsc#PED-10978).
- commit 41e1775
* Wed Oct  2 2024 dwagner@suse.de
- nvme-pci: qdepth 1 quirk (git-fixes).
- commit ee2b909
* Wed Oct  2 2024 tiwai@suse.de
- ALSA: hda/generic: Unconditionally prefer preferred_dacs pairs
  (bsc#1219803).
- commit 020b49a
* Tue Oct  1 2024 msuchanek@suse.de
- powerpc/code-patching: Add generic memory patching
  (bsc#1194869).
- powerpc/code-patching: Perform hwsync in __patch_instruction()
  in case of failure (bsc#1194869).
- commit 33b01a6
* Tue Oct  1 2024 oneukum@suse.com
- usbnet: fix cyclical race on disconnect with work queue
  (git-fixes).
- Refresh
  patches.suse/0002-Add-a-void-suse_kabi_padding-placeholder-to-some-USB.patch.
- commit 8272f2d
* Tue Oct  1 2024 dsterba@suse.com
- apparmor: fix possible NULL pointer dereference (CVE-2024-46721 bsc#1230710)
- commit 2d35a7c
* Tue Oct  1 2024 msuchanek@suse.de
- powerpc/64: Convert patch_instruction() to patch_u32()
  (bsc#1194869).
- powerpc/boot: Only free if realloc() succeeds (bsc#1194869).
- powerpc/boot: Handle allocation failure in simple_realloc()
  (bsc#1194869).
- powerpc/xics: Check return value of kasprintf in
  icp_native_map_one_cpu (bsc#1194869).
- powerpc/vdso: Fix VDSO data access when running in a non-root
  time namespace (bsc#1194869).
- commit 0dec2e8
* Tue Oct  1 2024 tbogendoerfer@suse.de
- net: mana: Improve mana_set_channels() in low mem conditions
  (bsc#1230289).
- net: mana: Implement get_ringparam/set_ringparam for mana
  (bsc#1229891).
- net: dpaa: Pad packets to ETH_ZLEN (CVE-2024-46854 bsc#1231084).
- ice: move netif_queue_set_napi to rtnl-protected sections
  (CVE-2024-46766 bsc#1230762).
- ice: Add netif_device_attach/detach into PF reset flow
  (CVE-2024-46770 bsc#1230763).
- bonding: change ipsec_lock from spin lock to mutex
  (CVE-2024-46678 bsc#1230550).
- bonding: extract the use of real_device into local variable
  (CVE-2024-46678 bsc#1230550).
- bonding: implement xdo_dev_state_free and call it after deletion
  (CVE-2024-46678 bsc#1230550).
- commit 9ee67ad
* Tue Oct  1 2024 msuchanek@suse.de
- powerpc/xmon: Fix disassembly CPU feature checks (bsc#1065729).
- commit c675509
* Tue Oct  1 2024 tiwai@suse.de
- ACPICA: executer/exsystem: Don't nag user about every Stall()
  violating the spec (git-fixes).
- ACPICA: Implement ACPI_WARNING_ONCE and ACPI_ERROR_ONCE
  (stable-fixes).
- commit f94e799
* Tue Oct  1 2024 lhenriques@suse.de
- cachefiles: fix dentry leak in cachefiles_open_file()
  (bsc#1231183).
- ceph: remove the incorrect Fw reference check when dirtying
  pages (bsc#1231182).
- commit ba82da7
* Tue Oct  1 2024 schwab@suse.de
- rpm/check-for-config-changes: add HAVE_RUST and RUSTC_SUPPORTS_ to IGNORED_CONFIGS_RE
  They depend on SHADOW_CALL_STACK.
- commit 65fa52b
* Tue Oct  1 2024 tiwai@suse.de
- can: mcp251xfd: move mcp251xfd_timestamp_start()/stop() into
  mcp251xfd_chip_start/stop() (stable-fixes).
- Refresh
  patches.suse/can-mcp251xfd-clarify-the-meaning-of-timestamp.patch.
- commit 6779985
* Tue Oct  1 2024 tiwai@suse.de
- USB: serial: pl2303: add device id for Macrosilicon MS3020
  (stable-fixes).
- powercap/intel_rapl: Add support for AMD family 1Ah
  (stable-fixes).
- ASoC: amd: yc: Add a quirk for MSI Bravo 17 (D7VEK)
  (stable-fixes).
- ASoC: tda7419: fix module autoloading (stable-fixes).
- ASoC: intel: fix module autoloading (stable-fixes).
- ASoC: Intel: soc-acpi-cht: Make Lenovo Yoga Tab 3 X90F DMI
  match less strict (stable-fixes).
- ALSA: hda: add HDMI codec ID for Intel PTL (stable-fixes).
- drm: komeda: Fix an issue related to normalized zpos
  (stable-fixes).
- can: mcp251xfd: mcp251xfd_ring_init(): check TX-coalescing
  configuration (stable-fixes).
- spi: spidev: Add missing spi_device_id for jg10309-01
  (git-fixes).
- spi: bcm63xx: Enable module autoloading (stable-fixes).
- spi: spidev: Add an entry for elgin,jg10309-01 (stable-fixes).
- hwmon: (asus-ec-sensors) remove VRM temp X570-E GAMING
  (stable-fixes).
- wifi: iwlwifi: clear trans->state earlier upon error
  (stable-fixes).
- wifi: mac80211: free skb on error path in
  ieee80211_beacon_get_ap() (stable-fixes).
- wifi: iwlwifi: mvm: don't wait for tx queues if firmware is dead
  (stable-fixes).
- wifi: iwlwifi: mvm: pause TCM when the firmware is stopped
  (stable-fixes).
- wifi: iwlwifi: mvm: fix iwl_mvm_max_scan_ie_fw_cmd_room()
  (stable-fixes).
- wifi: iwlwifi: mvm: fix iwl_mvm_scan_fits() calculation
  (stable-fixes).
- wifi: iwlwifi: lower message level for FW buffer destination
  (stable-fixes).
- platform/x86: x86-android-tablets: Make Lenovo Yoga Tab 3 X90F
  DMI match less strict (stable-fixes).
- pinctrl: at91: make it work with current gpiolib (stable-fixes).
- can: mcp251xfd: properly indent labels (stable-fixes).
- commit a530f31
* Mon Sep 30 2024 krisman@suse.de
- mm/filemap: skip to create PMD-sized page cache if needed
  (bsc#1228454 CVE-2024-41031).
- commit 03907fa
* Mon Sep 30 2024 dwagner@suse.de
- nvme-fabrics: use reserved tag for reg read/write command
  (bsc#1228620 CVE-2024-41082).
- commit 239456c
* Mon Sep 30 2024 pmladek@suse.com
- kthread: Fix task state in kthread worker if being frozen
  (bsc#1231146).
- commit fe88a62
* Mon Sep 30 2024 tiwai@suse.de
- supported.conf: mark adiantum and xctr crypto modules as supported (bsc#1231035)
- commit 59d03d7
* Mon Sep 30 2024 petr.pavlu@suse.com
- Refresh
  patches.suse/bpf-kprobe-remove-unused-declaring-of-bpf_kprobe_override.patch.
- commit 5a0b269
* Mon Sep 30 2024 petr.pavlu@suse.com
- bpf: Fix use-after-free in bpf_uprobe_multi_link_attach()
  (git-fixes).
- commit 1884922
* Mon Sep 30 2024 petr.pavlu@suse.com
- tracing: Avoid possible softlockup in tracing_iter_reset()
  (git-fixes).
- commit d5df75c
* Mon Sep 30 2024 petr.pavlu@suse.com
- tracing: Fix overflow in get_free_elt() (git-fixes
  CVE-2024-43890 bsc#1229764).
- commit ceb524e
* Mon Sep 30 2024 iivanov@suse.de
- arm64: acpi: Harden get_cpu_for_acpi_id() against missing CPU entry (bsc#1231120 CVE-2024-46822)
- commit cc6d7b5
* Mon Sep 30 2024 tiwai@suse.de
- mailbox: bcm2835: Fix timeout during suspend mode (git-fixes).
- mailbox: rockchip: fix a typo in module autoloading (git-fixes).
- i2c: designware: fix controller is holding SCL low while ENABLE
  bit is disabled (git-fixes).
- drm/amd/display: handle nulled pipe context in DCE110's
  set_drr() (git-fixes).
- drm/amdgpu: Fix get each xcp macro (git-fixes).
- tomoyo: fallback to realpath if symlink's pathname does not
  exist (git-fixes).
- cxl/pci: Fix to record only non-zero ranges (git-fixes).
- ata: libata-scsi: Fix ata_msense_control() CDL page reporting
  (git-fixes).
- firmware_loader: Block path traversal (git-fixes).
- driver core: Fix a potential null-ptr-deref in
  module_add_driver() (git-fixes).
- driver core: Fix error handling in driver API device_rename()
  (git-fixes).
- ep93xx: clock: Fix off by one in ep93xx_div_recalc_rate()
  (git-fixes).
- iio: magnetometer: ak8975: Fix reading for ak099xx sensors
  (git-fixes).
- iio: chemical: bme680: Fix read/write ops to device by adding
  mutexes (git-fixes).
- ABI: testing: fix admv8818 attr description (git-fixes).
- iio: adc: ad7606: fix standby gpio state to match the
  documentation (git-fixes).
- iio: adc: ad7606: fix oversampling gpio array (git-fixes).
- tty: rp2: Fix reset with non forgiving PCIe host bridges
  (git-fixes).
- USB: class: CDC-ACM: fix race between get_serial and set_serial
  (git-fixes).
- usb: dwc2: drd: fix clock gating on USB role switch (git-fixes).
- usb: cdnsp: Fix incorrect usb_request status (git-fixes).
- USB: usbtmc: prevent kernel-usb-infoleak (git-fixes).
- USB: serial: kobil_sct: restore initial terminal settings
  (git-fixes).
- xhci: Set quirky xHC PCI hosts to D3 _after_ stopping and
  freeing them (git-fixes).
- usb: dwc2: Skip clock gating on Broadcom SoCs (git-fixes).
- spi: atmel-quadspi: Avoid overwriting delay register settings
  (git-fixes).
- spi: spi-fsl-lpspi: Undo runtime PM changes at driver exit time
  (git-fixes).
- spi: atmel-quadspi: Undo runtime PM changes at driver exit time
  (git-fixes).
- rtc: at91sam9: fix OF node leak in probe() error path
  (git-fixes).
- i3c: master: svc: Fix use after free vulnerability in
  svc_i3c_master Driver Due to Race Condition (git-fixes).
- remoteproc: k3-r5: Fix error handling when power-up failed
  (git-fixes).
- remoteproc: imx_rproc: Initialize workqueue earlier (git-fixes).
- remoteproc: imx_rproc: Correct ddr alias for i.MX8M (git-fixes).
- KEYS: prevent NULL pointer dereference in find_asymmetric_key()
  (git-fixes).
- media: i2c: ar0521: Use cansleep version of gpiod_set_value()
  (git-fixes).
- media: ov5675: Fix power on/off delay timings (git-fixes).
- media: sun4i_csi: Implement link validate for sun4i_csi subdev
  (git-fixes).
- media: platform: rzg2l-cru: rzg2l-csi2: Add missing
  MODULE_DEVICE_TABLE (git-fixes).
- media: venus: fix use after free bug in venus_remove due to
  race condition (git-fixes).
- media: uapi/linux/cec.h: cec_msg_set_reply_to: zero flags
  (git-fixes).
- clk: ti: dra7-atl: Fix leak of of_nodes (git-fixes).
- watchdog: imx_sc_wdt: Don't disable WDT in suspend (git-fixes).
- pinctrl: single: fix missing error code in pcs_probe()
  (git-fixes).
- xz: cleanup CRC32 edits from 2018 (git-fixes).
- ata: pata_macio: Use WARN instead of BUG (stable-fixes).
- commit c5ab3ca
* Mon Sep 30 2024 tiwai@suse.de
- Drop mm patches that caused regressions (bsc#1230413)
  Those should have been already dropped via SLE15-SP6 merge, but slipped
  due to incorrect merge conflict resolutions
- commit 09dbc92
* Mon Sep 30 2024 tiwai@suse.de
- Move upstreamed SCSI patches into sorted section
- commit aba5747
* Mon Sep 30 2024 hare@suse.de
- kcm: Serialise kcm_sendmsg() for the same socket (CVE-2024-44946
  bsc#1230015).
- commit 4310760
* Mon Sep 30 2024 hare@suse.de
- nvme-multipath: avoid hang on inaccessible namespaces
  (bsc#1228244).
- kcm: Serialise kcm_sendmsg() for the same socket
  (CVE-2024-44946,bsc#1230015).
- commit a84ca87
* Mon Sep 30 2024 hare@suse.de
- nvme-multipath: system fails to create generic nvme device
  (bsc#1228244).
- commit 4fc57d2
* Mon Sep 30 2024 ailiop@suse.com
- erofs: fix incorrect symlink detection in fast symlink
  (git-fixes).
- commit 2e1ae75
* Mon Sep 30 2024 ailiop@suse.com
- afs: Don't cross .backup mountpoint from backup volume
  (git-fixes).
- commit f35dae1
* Mon Sep 30 2024 ailiop@suse.com
- afs: Revert "afs: Hide silly-rename files from userspace"
  (git-fixes).
- commit 11353bb
* Fri Sep 27 2024 mwilck@suse.com
- scsi: sd: Fix off-by-one error in
  sd_read_block_characteristics() (bsc#1223848).
- commit 621f2fb
* Fri Sep 27 2024 mwilck@suse.com
- scsi: ibmvfc: Add max_sectors module parameter (bsc#1216223).
- commit af0ff0f
* Fri Sep 27 2024 dsterba@suse.com
- drm/amd/display: Check denominator crb_pipes before used (CVE-2024-46772 bsc#1230772)
- commit 322be4a
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: allwinner: h616: Add r_i2c pinctrl nodes
  (git-fixes).
- commit 642d7e6
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: imx8-ss-dma: Fix adc0 closing brace location
  (git-fixes).
- commit 970cc49
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: rockchip: Correct vendor prefix for Hardkernel
  ODROID-M1 (git-fixes).
- commit 87f0ae6
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: rockchip: Raise Pinebook Pro's panel backlight
  PWM frequency (git-fixes).
- commit 1582b94
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: rockchip: Correct the Pinebook Pro battery design
  capacity (git-fixes).
- commit 3b2ebbf
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: exynos: exynos7885-jackpotlte: Correct RAM amount
  to 4GB (git-fixes).
- commit 1059c29
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: signal: Fix some under-bracketed UAPI macros (git-fixes).
- commit 9704ff3
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: rockchip: override BIOS_DISABLE signal via GPIO
  hog on RK3399 Puma (git-fixes).
- commit 6052a8c
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: rockchip: fix eMMC/SPI corruption when audio has
  been used on RK3399 Puma (git-fixes).
- commit 8b3743b
* Fri Sep 27 2024 msuchanek@suse.de
- Update
  patches.suse/powerpc-pseries-make-max-polling-consistent-for-long.patch
  (bsc#1215199 jsc#PED-10954).
- Update
  patches.suse/security-integrity-fix-pointer-to-ESL-data-and-.patch
  (bsc#1012628 jsc#PED-5085 jsc#PED-10954).
- commit ec9be2c
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: rockchip: fix PMIC interrupt pin in pinctrl for
  ROCK Pi E (git-fixes).
- commit 7527015
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: acpi: Move get_cpu_for_acpi_id() to a header (git-fixes).
- commit 42389f0
* Fri Sep 27 2024 iivanov@suse.de
- ipmi:ssif: Improve detecting during probing (bsc#1228771)
  Move patch into the sorted section.
- commit 77cf6fc
* Fri Sep 27 2024 jslaby@suse.cz
- Update patches.suse/ALSA-line6-Fix-racy-access-to-midibuf.patch
  (stable-fixes CVE-2024-44954 bsc#1230176).
- Update
  patches.suse/ASoC-dapm-Fix-UAF-for-snd_soc_pcm_runtime-object.patch
  (git-fixes CVE-2024-46798 bsc#1230830).
- Update
  patches.suse/Bluetooth-btnxpuart-Fix-Null-pointer-dereference-in-.patch
  (stable-fixes CVE-2024-46749 bsc#1230780).
- Update
  patches.suse/Bluetooth-btnxpuart-Shutdown-timer-and-prevent-rearm.patch
  (stable-fixes CVE-2024-44962 bsc#1230213).
- Update
  patches.suse/HID-amd_sfh-free-driver_data-after-destroying-hid-de.patch
  (stable-fixes CVE-2024-46746 bsc#1230751).
- Update
  patches.suse/HID-cougar-fix-slab-out-of-bounds-Read-in-cougar_rep.patch
  (stable-fixes CVE-2024-46747 bsc#1230752).
- Update patches.suse/Input-MT-limit-max-slots.patch (stable-fixes
  CVE-2024-45008 bsc#1230248).
- Update
  patches.suse/Input-uinput-reject-requests-with-unreasonable-numbe.patch
  (stable-fixes CVE-2024-46745 bsc#1230748).
- Update
  patches.suse/KVM-arm64-Make-ICC_-SGI-_EL1-undef-in-the-absence-of.patch
  (git-fixes CVE-2024-46707 bsc#1230582).
- Update
  patches.suse/KVM-s390-fix-validity-interception-issue-when-gisa-is-switched-off.patch
  (git-fixes bsc#1229167 CVE-2024-45005 bsc#1230173).
- Update
  patches.suse/PCI-Add-missing-bridge-lock-to-pci_bus_lock.patch
  (stable-fixes CVE-2024-46750 bsc#1230783).
- Update
  patches.suse/Squashfs-sanity-check-symbolic-link-size.patch
  (git-fixes CVE-2024-46744 bsc#1230747).
- Update
  patches.suse/VMCI-Fix-use-after-free-when-removing-resource-in-vm.patch
  (git-fixes CVE-2024-46738 bsc#1230731).
- Update
  patches.suse/bpf-Fix-a-kernel-verifier-crash-in-stacksafe.patch
  (bsc#1225903 CVE-2024-45020 bsc#1230433).
- Update
  patches.suse/btrfs-fix-race-between-direct-IO-write-and-fsync-whe.patch
  (git-fixes CVE-2024-46734 bsc#1230726).
- Update
  patches.suse/can-bcm-Remove-proc-entry-when-dev-is-unregistered.patch
  (git-fixes CVE-2024-46771 bsc#1230766).
- Update
  patches.suse/can-mcp251x-fix-deadlock-if-an-interrupt-occurs-duri.patch
  (git-fixes CVE-2024-46791 bsc#1230821).
- Update
  patches.suse/char-xillybus-Check-USB-endpoints-when-probing-devic.patch
  (git-fixes CVE-2024-45011 bsc#1230440).
- Update
  patches.suse/char-xillybus-Don-t-destroy-workqueue-from-work-item.patch
  (stable-fixes CVE-2024-45007 bsc#1230175).
- Update
  patches.suse/dmaengine-altera-msgdma-properly-free-descriptor-in-.patch
  (stable-fixes CVE-2024-46716 bsc#1230715).
- Update
  patches.suse/driver-core-Fix-uevent_show-vs-driver-detach-race.patch
  (git-fixes CVE-2024-44952 bsc#1230178).
- Update
  patches.suse/driver-iio-add-missing-checks-on-iio_info-s-callback.patch
  (stable-fixes CVE-2024-46715 bsc#1230700).
- Update
  patches.suse/drm-amd-display-Assign-linear_pitch_alignment-even-f.patch
  (stable-fixes CVE-2024-46732 bsc#1230711).
- Update
  patches.suse/drm-amd-display-Check-UnboundedRequestEnabled-s-valu.patch
  (stable-fixes CVE-2024-46778 bsc#1230776).
- Update
  patches.suse/drm-amd-display-Check-denominator-pbn_div-before-use.patch
  (stable-fixes CVE-2024-46773 bsc#1230791).
- Update
  patches.suse/drm-amd-display-Check-index-for-aux_rd_interval-befo.patch
  (stable-fixes CVE-2024-46728 bsc#1230703).
- Update
  patches.suse/drm-amd-display-Ensure-array-index-tg_inst-won-t-be-.patch
  (stable-fixes CVE-2024-46730 bsc#1230701).
- Update
  patches.suse/drm-amd-display-Ensure-index-calculation-will-not-ov.patch
  (stable-fixes CVE-2024-46726 bsc#1230706).
- Update
  patches.suse/drm-amd-display-Run-DC_LOG_DC-after-checking-link-li.patch
  (stable-fixes CVE-2024-46776 bsc#1230775).
- Update
  patches.suse/drm-amd-display-Skip-wbscl_set_scaler_filter-if-filt.patch
  (stable-fixes CVE-2024-46714 bsc#1230699).
- Update
  patches.suse/drm-amd-display-avoid-using-null-object-of-framebuff.patch
  (git-fixes CVE-2024-46694 bsc#1230511).
- Update
  patches.suse/drm-amd-pm-fix-the-Out-of-bounds-read-warning.patch
  (stable-fixes CVE-2024-46731 bsc#1230709).
- Update
  patches.suse/drm-amdgpu-Fix-out-of-bounds-read-of-df_v1_7_channel.patch
  (stable-fixes CVE-2024-46724 bsc#1230725).
- Update
  patches.suse/drm-amdgpu-Fix-out-of-bounds-write-warning.patch
  (stable-fixes CVE-2024-46725 bsc#1230705).
- Update
  patches.suse/drm-amdgpu-Forward-soft-recovery-errors-to-userspace.patch
  (stable-fixes CVE-2024-44961 bsc#1230207).
- Update patches.suse/drm-amdgpu-Validate-TA-binary-size.patch
  (stable-fixes CVE-2024-44977 bsc#1230217).
- Update
  patches.suse/drm-amdgpu-fix-dereference-after-null-check.patch
  (stable-fixes CVE-2024-46720 bsc#1230724).
- Update
  patches.suse/drm-amdgpu-fix-mc_data-out-of-bounds-read-warning.patch
  (stable-fixes CVE-2024-46722 bsc#1230712).
- Update
  patches.suse/drm-amdgpu-fix-ucode-out-of-bounds-read-warning.patch
  (stable-fixes CVE-2024-46723 bsc#1230702).
- Update
  patches.suse/drm-mgag200-Bind-I2C-lifetime-to-DRM-device.patch
  (git-fixes CVE-2024-44967 bsc#1230224).
- Update
  patches.suse/drm-msm-dpu-cleanup-FB-if-dpu_format_populate_layout.patch
  (git-fixes CVE-2024-44982 bsc#1230204).
- Update
  patches.suse/drm-msm-dpu-move-dpu_encoder-s-connector-assignment-.patch
  (git-fixes CVE-2024-45015 bsc#1230444).
- Update
  patches.suse/drm-vmwgfx-Fix-prime-with-external-buffers.patch
  (git-fixes CVE-2024-46709 bsc#1230539).
- Update
  patches.suse/fs-netfs-fscache_cookie-add-missing-n_accesses-check.patch
  (bsc#1229455 CVE-2024-45000 bsc#1230170).
- Update
  patches.suse/fscache-delete-fscache_cookie_lru_timer-when-fscache-.patch
  (bsc#1230602 CVE-2024-46786 bsc#1230813).
- Update
  patches.suse/fuse-Initialize-beyond-EOF-page-contents-before-setti.patch
  (bsc#1229456 CVE-2024-44947).
- Update
  patches.suse/hwmon-adc128d818-Fix-underflows-seen-when-writing-li.patch
  (stable-fixes CVE-2024-46759 bsc#1230814).
- Update
  patches.suse/hwmon-lm95234-Fix-underflows-seen-when-writing-limit.patch
  (stable-fixes CVE-2024-46758 bsc#1230812).
- Update
  patches.suse/hwmon-nct6775-core-Fix-underflows-seen-when-writing-.patch
  (stable-fixes CVE-2024-46757 bsc#1230809).
- Update
  patches.suse/hwmon-w83627ehf-Fix-underflows-seen-when-writing-lim.patch
  (stable-fixes CVE-2024-46756 bsc#1230806).
- Update
  patches.suse/media-dvb-usb-v2-af9035-Fix-null-ptr-deref-in-af9035.patch
  (git-fixes CVE-2023-52915 bsc#1230270).
- Update
  patches.suse/misc-fastrpc-Fix-double-free-of-buf-in-error-path.patch
  (git-fixes CVE-2024-46741 bsc#1230749).
- Update
  patches.suse/mmc-mmc_test-Fix-NULL-dereference-on-allocation-fail.patch
  (git-fixes CVE-2024-45028 bsc#1230450).
- Update
  patches.suse/msft-hv-3046-uio_hv_generic-Fix-kernel-NULL-pointer-dereference-i.patch
  (git-fixes CVE-2024-46739 bsc#1230732).
- Update
  patches.suse/msft-hv-3048-net-mana-Fix-error-handling-in-mana_create_txq-rxq-s.patch
  (git-fixes CVE-2024-46784 bsc#1230771).
- Update
  patches.suse/net-ethernet-mtk_wed-fix-use-after-free-panic-in-mtk.patch
  (git-fixes CVE-2024-44997 bsc#1230232).
- Update
  patches.suse/net-mana-Fix-RX-buf-alloc_size-alignment-and-atomic-.patch
  (bsc#1229086 CVE-2024-45001 bsc#1230244).
- Update
  patches.suse/net-phy-Fix-missing-of_node_put-for-leds.patch
  (git-fixes CVE-2024-46767 bsc#1230787).
- Update
  patches.suse/nfc-pn533-Add-poll-mod-list-filling-check.patch
  (git-fixes CVE-2024-46676 bsc#1230535).
- Update
  patches.suse/nilfs2-fix-missing-cleanup-on-rollforward-recovery-error.patch
  (git-fixes CVE-2024-46781 bsc#1230768).
- Update
  patches.suse/nilfs2-protect-references-to-superblock-parameters-exposed-in-sysfs.patch
  (git-fixes CVE-2024-46780 bsc#1230808).
- Update
  patches.suse/nouveau-firmware-use-dma-non-coherent-allocator.patch
  (git-fixes CVE-2024-45012 bsc#1230441).
- Update
  patches.suse/nvmet-tcp-fix-kernel-crash-if-commands-allocation-fa.patch
  (git-fixes CVE-2024-46737 bsc#1230730).
- Update
  patches.suse/pci-hotplug-pnv_php-Fix-hotplug-driver-crash-on-Powe.patch
  (stable-fixes CVE-2024-46761 bsc#1230761).
- Update patches.suse/perf-Fix-event-leak-upon-exit.patch
  (git-fixes CVE-2024-43870 bsc#1229494).
- Update
  patches.suse/pinctrl-single-fix-potential-NULL-dereference-in-pcs.patch
  (git-fixes CVE-2024-46685 bsc#1230515).
- Update
  patches.suse/powerpc-qspinlock-Fix-deadlock-in-MCS-queue.patch
  (bac#1230295 ltc#206656 CVE-2024-46797 bsc#1230831).
- Update
  patches.suse/powerpc-rtas-Prevent-Spectre-v1-gadget-construction-.patch
  (bsc#1227487 CVE-2024-46774 bsc#1230767).
- Update
  patches.suse/s390-dasd-fix-error-recovery-leading-to-data-corruption-on-ESE-devices.patch
  (git-fixes bsc#1229452 CVE-2024-45026 bsc#1230454).
- Update
  patches.suse/s390-sclp-Prevent-release-of-buffer-in-I-O.patch
  (git-fixes bsc#1229169 CVE-2024-44969 bsc#1230200).
- Update
  patches.suse/soc-qcom-cmd-db-Map-shared-memory-as-WC-not-WB.patch
  (git-fixes CVE-2024-46689 bsc#1230524).
- Update
  patches.suse/thunderbolt-Mark-XDomain-as-unplugged-when-router-is.patch
  (stable-fixes CVE-2024-46702 bsc#1230589).
- Update
  patches.suse/tty-serial-fsl_lpuart-mark-last-busy-before-uart_add.patch
  (git-fixes CVE-2024-46706 bsc#1230580).
- Update
  patches.suse/usb-dwc3-core-Prevent-USB-core-invalid-event-buffer-.patch
  (stable-fixes CVE-2024-46675 bsc#1230533).
- Update
  patches.suse/usb-dwc3-st-fix-probed-platform-device-ref-count-on-.patch
  (git-fixes CVE-2024-46674 bsc#1230507).
- Update
  patches.suse/usb-gadget-core-Check-for-unset-descriptor.patch
  (git-fixes CVE-2024-44960 bsc#1230191).
- Update
  patches.suse/usb-typec-ucsi-Fix-null-pointer-dereference-in-trace.patch
  (stable-fixes CVE-2024-46719 bsc#1230722).
- Update
  patches.suse/wifi-brcmfmac-cfg80211-Handle-SSID-based-pmksa-delet.patch
  (git-fixes CVE-2024-46672 bsc#1230459).
- Update
  patches.suse/wifi-mwifiex-Do-not-return-unused-priv-in-mwifiex_ge.patch
  (stable-fixes CVE-2024-46755 bsc#1230802).
- Update
  patches.suse/wifi-rtw88-usb-schedule-rx-work-after-everything-is-.patch
  (stable-fixes CVE-2024-46760 bsc#1230753).
- Update
  patches.suse/x86-mm-Fix-pti_clone_pgtable-alignment-assumption.patch
  (git-fixes CVE-2024-44965 bsc#1230221).
- Update
  patches.suse/x86-mtrr-Check-if-fixed-MTRRs-exist-before-saving-them.patch
  (git-fixes CVE-2024-44948 bsc#1230174).
- Update
  patches.suse/xhci-Fix-Panther-point-NULL-pointer-deref-at-full-sp.patch
  (git-fixes CVE-2024-45006 bsc#1230247).
- commit 6da06c4
* Fri Sep 27 2024 glass.su@suse.com
- Update patches.suse/gfs2-Fix-NULL-pointer-dereference-in-gfs2_log_flush.patch (bsc#1230948)
- commit 90a5b1b
* Thu Sep 26 2024 vbabka@suse.cz
- userfaultfd: fix checks for huge PMDs (CVE-2024-46787
  bsc#1230815).
- commit a236c90
* Thu Sep 26 2024 lhenriques@suse.de
- cachefiles: Fix non-taking of sb_writers around set/removexattr
  (bsc#1231008).
- commit 1b01b3e
* Thu Sep 26 2024 nmorey@suse.com
- RDMA/rtrs-clt: Reset cid to con_num - 1 to stay in bounds (git-fixes)
- commit a6683f0
* Thu Sep 26 2024 jslaby@suse.cz
- PCI: dwc: Expose dw_pcie_ep_exit() to module (git-fixes).
- Refresh
  patches.suse/PCI-dwc-endpoint-Introduce-.pre_init-and-.deinit.patch.
- commit 34c9950
* Thu Sep 26 2024 jslaby@suse.cz
- PCI: xilinx-nwl: Clean up clock on probe failure/removal
  (git-fixes).
- PCI: xilinx-nwl: Fix off-by-one in INTx IRQ handler (git-fixes).
- PCI: qcom-ep: Enable controller resources like PHY only after
  refclk is available (git-fixes).
- PCI: kirin: Fix buffer overflow in kirin_pcie_parse_port()
  (git-fixes).
- PCI: keystone: Fix if-statement expression in ks_pcie_quirk()
  (git-fixes).
- PCI: imx6: Fix missing call to phy_power_off() in error handling
  (git-fixes).
- PCI: dra7xx: Fix error handling when IRQ request fails in probe
  (git-fixes).
- PCI: dra7xx: Fix threaded IRQ request for "dra7xx-pcie-main"
  IRQ (git-fixes).
- PCI: Wait for Link before restoring Downstream Buses
  (git-fixes).
- commit 1528eee
* Wed Sep 25 2024 dsterba@suse.com
- WIP DO NOT PUSH btrfs: fix a use-after-free when hitting errors inside btrfs_submit_chunk() (CVE-2024-46687 bsc#1230518)
- commit 17b4a47
* Wed Sep 25 2024 ailiop@suse.com
- exfat: fix memory leak in exfat_load_bitmap() (git-fixes).
- commit 9f477b0
* Wed Sep 25 2024 sjaeckel@suse.de
- net: ip_tunnel: prevent perpetual headroom growth
  (CVE-2024-26804 bsc#1222629).
- commit 0ca3b23
* Wed Sep 25 2024 oneukum@suse.com
- Input: ps2-gpio - use IRQF_NO_AUTOEN flag in request_irq()
  (git-fixes).
- commit 45cee3b
* Wed Sep 25 2024 oneukum@suse.com
- Input: ilitek_ts_i2c - avoid wrong input subsystem sync
  (git-fixes).
- commit e5e587b
* Wed Sep 25 2024 oneukum@suse.com
- Input: tsc2004/5 - fix reset handling on probe (git-fixes).
- commit 1366de4
* Wed Sep 25 2024 oneukum@suse.com
- Input: tsc2004/5 - do not hard code interrupt trigger
  (git-fixes).
- commit 110dbdb
* Wed Sep 25 2024 oneukum@suse.com
- Input: tsc2004/5 - use device core to create driver-specific
  device attributes (git-fixes).
- commit 958966c
* Wed Sep 25 2024 oneukum@suse.com
- Input: adp5588-keys - fix check on return code (git-fixes).
- commit d15133c
* Wed Sep 25 2024 tzimmermann@suse.com
- drm/amd/display: Fix incorrect size calculation for loop (bsc#1230704 CVE-2024-46729)
- commit 55d78a7
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Fix ah error counter in sw stat not increasing (git-fixes)
- commit d7bebcf
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/mlx5: Fix MR cache temp entries cleanup (git-fixes)
- commit b0aa848
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/mlx5: Drop redundant work canceling from clean_keys() (git-fixes)
- commit 6800d7e
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/irdma: fix error message in irdma_modify_qp_roce() (git-fixes)
- commit dcf63e1
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/cxgb4: Added NULL check for lookup_atid (git-fixes)
- commit 23d3195
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/mlx5: Obtain upper net device only when needed (git-fixes)
- commit ca2d8dc
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Fix restricted __le16 degrades to integer issue (git-fixes)
- commit 4481358
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Optimize hem allocation performance (git-fixes)
- commit 7afe440
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Fix 1bit-ECC recovery address in non-4K OS (git-fixes)
- commit 25e36c2
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Fix VF triggering PF reset in abnormal interrupt handler (git-fixes)
- commit a18704a
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Fix spin_unlock_irqrestore() called with IRQs enabled (git-fixes)
- commit 7b15e64
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Fix the overflow risk of hem_list_calc_ba_range() (git-fixes)
- commit 60eb35c
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Fix Use-After-Free of rsv_qp on HIP08 (git-fixes)
- commit 3ab1ca2
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Don't modify rq next block addr in HIP09 QPC (git-fixes)
- commit 7100eb8
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/mlx5: Limit usage of over-sized mkeys from the MR cache (git-fixes)
- commit 914ed66
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/mlx5: Fix counter update on MR cache mkey creation (git-fixes)
- commit 60e75bb
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/erdma: Return QP state in erdma_query_qp (git-fixes)
- commit 09a59c3
* Wed Sep 25 2024 nmorey@suse.com
- IB/core: Fix ib_cache_setup_one error flow cleanup (git-fixes)
- commit 38bf526
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/rtrs: Reset hb_missed_cnt after receiving other traffic from peer (git-fixes)
- commit c4f28a8
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/iwcm: Fix WARNING:at_kernel/workqueue.c:#check_flush_dependency (git-fixes)
- commit 0456b72
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/core: Remove unused declaration rdma_resolve_ip_route() (git-fixes)
- commit 4cb7201
* Wed Sep 25 2024 jslaby@suse.cz
- Revert "PCI: Extend ACS configurability (bsc#1228090)." (bsc#1229019)
  This reverts commit 571e4310e81312c847a5caee7e45e66aeea2a169. It breaks
  ACS on certain platforms. Even 6.11 is affected. So drop for now and
  investigate.
- commit 3b92a44
* Tue Sep 24 2024 dsterba@suse.com
- btrfs: handle errors from btrfs_dec_ref() properly (CVE-2024-46753 bsc#1230796)
- commit 3e3b2cb
* Tue Sep 24 2024 oneukum@suse.com
- media: vicodec: allow en/decoder cmd w/o CAPTURE (git-fixes).
- commit 62ef4d1
* Tue Sep 24 2024 oneukum@suse.com
- media: qcom: camss: Remove use_count guard in stop_streaming
  (git-fixes).
- commit ef85228
* Tue Sep 24 2024 oneukum@suse.com
- Revert "media: tuners: fix error return code of
  hybrid_tuner_request_state()" (git-fixes).
- drivers: media: dvb-frontends/rtl2830: fix an out-of-bounds
  write error (git-fixes).
- drivers: media: dvb-frontends/rtl2832: fix an out-of-bounds
  write error (git-fixes).
- commit 48dc3a9
* Tue Sep 24 2024 sjaeckel@suse.de
- net: bridge: xmit: make sure we have at least eth header len
  bytes (CVE-2024-38538 bsc#1226606).
- commit 2548071
* Tue Sep 24 2024 jlee@suse.com
- PKCS#7: Check codeSigning EKU of certificates in PKCS#7
  (bsc#1226666).
- commit dbae63e
* Mon Sep 23 2024 jgross@suse.com
- xen/swiotlb: fix allocated size (git-fixes).
- commit 199871d
* Mon Sep 23 2024 jgross@suse.com
- xen/swiotlb: add alignment check for dma buffers (bsc#1229928).
- commit 0ffbc04
* Mon Sep 23 2024 jgross@suse.com
- xen: tolerate ACPI NVS memory overlapping with Xen allocated
  memory (bsc#1226003).
- commit 3dc14d8
* Mon Sep 23 2024 jgross@suse.com
- xen: allow mapping ACPI data using a different physical address
  (bsc#1226003).
- commit 0928eec
* Mon Sep 23 2024 dsterba@suse.com
- x86/tdx: Fix data leak in mmio_read() (CVE-2024-46794 bsc#1230825)
- commit 9a2a1c2
* Mon Sep 23 2024 dsterba@suse.com
- tcp_bpf: fix return value of tcp_bpf_sendmsg() (CVE-2024-46783 bsc#1230810)
- commit eb9d143
* Mon Sep 23 2024 dwagner@suse.de
- nvme: fix namespace removal list (git-fixes).
- commit b45d192
* Mon Sep 23 2024 dsterba@suse.com
- ublk_drv: fix NULL pointer dereference in ublk_ctrl_start_recovery() (CVE-2024-46735 bsc#1230727)
- commit 23e039f
* Mon Sep 23 2024 dsterba@suse.com
- Update references for patches.suse/nvmet-tcp-fix-kernel-crash-if-commands-allocation-fa.patch (CVE-2024-46737 bsc#1230730)
- commit 8ce7f58
* Mon Sep 23 2024 jgross@suse.com
- xen: add capability to remap non-RAM pages to different PFNs
  (bsc#1226003).
- commit 47109fd
* Mon Sep 23 2024 dsterba@suse.com
- net/mlx5e: SHAMPO, Fix incorrect page release (CVE-2024-46717 bsc#1230719)
- commit d6a30a9
* Mon Sep 23 2024 jgross@suse.com
- xen: move max_pfn in xen_memory_setup() out of function scope
  (bsc#1226003).
- commit 2750357
* Mon Sep 23 2024 jgross@suse.com
- xen: move checks for e820 conflicts further up (bsc#1226003).
- commit 191a602
* Mon Sep 23 2024 jgross@suse.com
- xen: introduce generic helper checking for memory map conflicts
  (bsc#1226003).
- commit eb57cec
* Mon Sep 23 2024 jgross@suse.com
- xen: use correct end address of kernel for conflict checking
  (bsc#1226003).
- commit c40fc6b
* Mon Sep 23 2024 dwagner@suse.de
- scsi: lpfc: Copyright updates for 14.4.0.4 patches (bsc#1229429
  jsc#PED-9899).
- scsi: lpfc: Update lpfc version to 14.4.0.4 (bsc#1229429
  jsc#PED-9899).
- scsi: lpfc: Update PRLO handling in direct attached topology
  (bsc#1229429 jsc#PED-9899).
- scsi: lpfc: Fix unsolicited FLOGI kref imbalance when in direct
  attached topology (bsc#1229429 jsc#PED-9899).
- scsi: lpfc: Fix unintentional double clearing of vmid_flag
  (bsc#1229429 jsc#PED-9899).
- scsi: lpfc: Validate hdwq pointers before dereferencing in
  reset/errata paths (bsc#1229429 jsc#PED-9899).
- scsi: lpfc: Remove redundant vport assignment when building
  an abort request (bsc#1229429 jsc#PED-9899).
- scsi: lpfc: Change diagnostic log flag during receipt of
  unknown ELS cmds (bsc#1229429 jsc#PED-9899).
- scsi: lpfc: Fix overflow build issue (bsc#1229429 jsc#PED-9899).
- commit 18ec475
* Mon Sep 23 2024 tzimmermann@suse.com
- drm/vmwgfx: Prevent unmapping active read buffers (bsc#1230540 CVE-2024-46710)
- commit 84f019d
* Mon Sep 23 2024 dwagner@suse.de
- nvme-tcp: fix link failure for TCP auth (git-fixes).
- nvmet: Identify-Active Namespace ID List command should reject
  invalid nsid (git-fixes).
- nvme-pci: Add sleep quirk for Samsung 990 Evo (git-fixes).
- nvme-pci: allocate tagset on reset if necessary (git-fixes).
- nvmet-tcp: fix kernel crash if commands allocation fails
  (git-fixes).
- nvme/pci: Add APST quirk for Lenovo N60z laptop (git-fixes).
- nvme: use srcu for iterating namespace list (git-fixes).
  Refresh:
  - patches.suse/nvme-tcp-sanitize-tls-key-handling.patch
- nvmet-rdma: fix possible bad dereference when freeing rsps
  (git-fixes).
- nvmet-tcp: do not continue for invalid icreq (git-fixes).
- nvme: clear caller pointer on identify failure (git-fixes).
- nvmet-trace: avoid dereferencing pointer too early (git-fixes).
- commit 7382ad4
* Mon Sep 23 2024 jslaby@suse.cz
- Update
  patches.suse/KVM-arm64-vgic-v2-Check-for-non-NULL-vCPU-in-vgic_v2.patch
  (git-fixes CVE-2024-36953 bsc#1225812).
- Update
  patches.suse/vfio-pci-fix-potential-memory-leak-in-vfio_intx_enab.patch
  (git-fixes CVE-2024-38632 bsc#1226860).
  Add CVE references.
- commit c9c3b6f
* Sun Sep 22 2024 ailiop@suse.com
- nilfs2: fix potential oob read in nilfs_btree_check_delete()
  (git-fixes).
- commit cc0f59d
* Sun Sep 22 2024 ailiop@suse.com
- nilfs2: determine empty node blocks as corrupted (git-fixes).
- commit 3244e52
* Sun Sep 22 2024 ailiop@suse.com
- nilfs2: fix potential null-ptr-deref in nilfs_btree_insert()
  (git-fixes).
- commit 90f4e49
* Fri Sep 20 2024 dsterba@suse.com
- media: mtk-vcodec: potential null pointer deference in SCP (CVE-2024-40973 bsc#1227890)
- commit ce5074d
* Fri Sep 20 2024 fdmanana@suse.com
- btrfs: don't BUG_ON() when 0 reference count at
  btrfs_lookup_extent_info() (bsc#1230786 CVE-2024-46751).
- btrfs: reduce nesting for extent processing at
  btrfs_lookup_extent_info() (bsc#1230794 CVE-2024-46752).
- btrfs: remove superfluous metadata check at
  btrfs_lookup_extent_info() (bsc#1230794 CVE-2024-46752).
- btrfs: replace BUG_ON() with error handling at
  update_ref_for_cow() (bsc#1230794 CVE-2024-46752).
- btrfs: simplify setting the full backref flag at
  update_ref_for_cow() (bsc#1230794 CVE-2024-46752).
- btrfs: remove NULL transaction support for
  btrfs_lookup_extent_info() (bsc#1230794 CVE-2024-46752).
- btrfs: remove level argument from btrfs_set_block_flags
  (bsc#1230794 CVE-2024-46752).
- commit a1c1176
* Fri Sep 20 2024 fdmanana@suse.com
- btrfs: send: allow cloning non-aligned extent if it ends at
  i_size (bsc#1230854).
- commit e9cad4b
* Fri Sep 20 2024 ailiop@suse.com
- ocfs2: cancel dqi_sync_work before freeing oinfo (git-fixes).
- commit 1f37ac4
* Fri Sep 20 2024 ailiop@suse.com
- ocfs2: fix possible null-ptr-deref in ocfs2_set_buffer_uptodate
  (git-fixes).
- commit b7bf7eb
* Fri Sep 20 2024 ailiop@suse.com
- ocfs2: remove unreasonable unlock in ocfs2_read_blocks
  (git-fixes).
- commit e2cb129
* Fri Sep 20 2024 ailiop@suse.com
- ocfs2: fix null-ptr-deref when journal load failed (git-fixes).
- commit b463b02
* Fri Sep 20 2024 ailiop@suse.com
- jfs: fix out-of-bounds in dbNextAG() and diAlloc() (git-fixes).
- commit d948d87
* Fri Sep 20 2024 tiwai@suse.de
- of/irq: Prevent device address out-of-bounds read in interrupt
  map walk (CVE-2024-46743 bsc#1230756).
- commit 300f40a
* Fri Sep 20 2024 tiwai@suse.de
- i2c: qcom-geni: Use IRQF_NO_AUTOEN flag in request_irq()
  (git-fixes).
- i2c: isch: Add missed 'else' (git-fixes).
- i2c: xiic: Wait for TX empty to avoid missed TX NAKs
  (git-fixes).
- i2c: aspeed: Update the stop sw state when the bus recovery
  occurs (git-fixes).
- resource: fix region_intersects() vs add_memory_driver_managed()
  (git-fixes).
- drivers:drm:exynos_drm_gsc:Fix wrong assignment in gsc_bind()
  (git-fixes).
- drm/msm: fix %%s null argument error (git-fixes).
- drm/msm/dsi: correct programming sequence for SM8350 / SM8450
  (git-fixes).
- drm/msm/a5xx: workaround early ring-buffer emptiness check
  (git-fixes).
- drm/msm/a5xx: fix races in preemption evaluation stage
  (git-fixes).
- drm/msm/a5xx: properly clear preemption records on resume
  (git-fixes).
- drm/msm/a5xx: disable preemption in submits by default
  (git-fixes).
- drm/msm: Fix incorrect file name output in adreno_request_fw()
  (git-fixes).
- drm/mediatek: ovl_adaptor: Add missing of_node_put()
  (git-fixes).
- drm: omapdrm: Add missing check for alloc_ordered_workqueue
  (git-fixes).
- drm/radeon/evergreen_cs: fix int overflow errors in cs track
  offsets (git-fixes).
- drm/amd/amdgpu: Properly tune the size of struct (git-fixes).
- drm/radeon: properly handle vbios fake edid sizing (git-fixes).
- drm/amdgpu: properly handle vbios fake edid sizing (git-fixes).
- drm/amd/display: Add null check for set_output_gamma in
  dcn30_set_output_transfer_func (git-fixes).
- drm/amdgpu: fix a possible null pointer dereference (git-fixes).
- drm/radeon: fix null pointer dereference in
  radeon_add_common_modes (git-fixes).
- drm/vc4: hdmi: Handle error case of pm_runtime_resume_and_get
  (git-fixes).
- drm/bridge: lontium-lt8912b: Validate mode in
  drm_bridge_funcs::mode_valid() (git-fixes).
- drm/rockchip: dw_hdmi: Fix reading EDID when using a forced mode
  (git-fixes).
- drm/rockchip: vop: Allow 4096px width scaling (git-fixes).
- drm/rockchip: vop: enable VOP_FEATURE_INTERNAL_RGB on RK3066
  (git-fixes).
- drm/rockchip: vop: clear DMA stop bit on RK3066 (git-fixes).
- drm/stm: ltdc: check memory returned by devm_kzalloc()
  (git-fixes).
- drm/stm: Fix an error handling path in stm_drm_platform_probe()
  (git-fixes).
- ata: libata: Clear DID_TIME_OUT for ATA PT commands with sense
  data (git-fixes).
- HID: wacom: Do not warn about dropped packets for first packet
  (git-fixes).
- HID: wacom: Support sequence numbers smaller than 16-bit
  (git-fixes).
- tpm: Clean up TPM space after command failure (git-fixes).
- ipmi: docs: don't advertise deprecated sysfs entries
  (git-fixes).
- commit b4e4911
* Thu Sep 19 2024 dsterba@suse.com
- smb/client: avoid dereferencing rdata=NULL in smb2_new_read_req() (CVE-2024-46686 bsc#1230517)
- commit a155846
* Thu Sep 19 2024 dsterba@suse.com
- firmware: qcom: scm: Mark get_wq_ctx() as atomic call (CVE-2024-46692 bsc#1230520)
- commit ee65da0
* Thu Sep 19 2024 dsterba@suse.com
- scsi: aacraid: Fix double-free on probe failure (CVE-2024-46673 bsc#1230506)
- commit 49aab2b
* Thu Sep 19 2024 dsterba@suse.com
- gtp: fix a potential NULL pointer dereference (CVE-2024-46677 bsc#1230549)
- commit 9cdd14b
* Thu Sep 19 2024 dsterba@suse.com
- ethtool: check device is present when getting link settings (CVE-2024-46679 bsc#1230556)
- commit 68643d1
* Thu Sep 19 2024 colyli@suse.de
- md/raid5: avoid BUG_ON() while continue reshape after
  reassembling (bsc#1229790, CVE-2024-43914).
- commit bfb799a
* Thu Sep 19 2024 ailiop@suse.com
- xfs: restrict when we try to align cow fork delalloc to cowextsz
  hints (git-fixes).
- commit 96ac1b7
* Thu Sep 19 2024 jdelvare@suse.de
- clk: Provide !COMMON_CLK dummy for devm_clk_rate_exclusive_get()
  (bsc#1227885).
- commit bf3362b
* Thu Sep 19 2024 colyli@suse.de
- Replace git-fixes tag by bsc#1226507,
  patches.suse/md-Don-t-wait-for-MD_RECOVERY_NEEDED-for-HOT_REMOVE_DISK-ioctl-a1fd.patch
  (bsc#1226507).
- commit b04e0cb
* Thu Sep 19 2024 colyli@suse.de
- closures: Change BUG_ON() to WARN_ON() (bsc#1229004,
  CVE-2024-42252).
- commit 84b7984
* Thu Sep 19 2024 jdelvare@suse.de
- clk: Add a devm variant of clk_rate_exclusive_get()
  (bsc#1227885).
- commit b6fb747
* Thu Sep 19 2024 oneukum@suse.com
- r8152: add vendor/device ID pair for D-Link DUB-E250
  (git-fixes).
- Refresh
  patches.suse/r8152-add-vendor-device-ID-pair-for-ASUS-USB-C2500.patch.
- commit 0c077ab
* Thu Sep 19 2024 oneukum@suse.com
- usbnet: ipheth: fix carrier detection in modes 1 and 4
  (git-fixes).
- commit 591cebb
* Thu Sep 19 2024 oneukum@suse.com
- usbnet: ipheth: do not stop RX on failing RX callback
  (git-fixes).
- commit c58c483
* Thu Sep 19 2024 oneukum@suse.com
- usbnet: ipheth: drop RX URBs with no payload (git-fixes).
- commit 73a78e2
* Thu Sep 19 2024 jgross@suse.com
- KVM: arm64: Disallow copying MTE to guest memory while KVM is
  dirty logging (git-fixes).
- commit 3cf4c02
* Thu Sep 19 2024 oneukum@suse.com
- usbnet: ipheth: remove extraneous rx URB length check
  (git-fixes).
- commit 507443a
* Thu Sep 19 2024 oneukum@suse.com
- usbnet: ipheth: add CDC NCM support (git-fixes).
- commit 1bf1d1e
* Thu Sep 19 2024 jgross@suse.com
- KVM: arm64: Release pfn, i.e. put page, if copying MTE tags
  hits ZONE_DEVICE (git-fixes).
- commit 64bccd6
* Thu Sep 19 2024 oneukum@suse.com
- usbnet: ipheth: transmit URBs without trailing padding
  (git-fixes).
- usbnet: ipheth: fix risk of NULL pointer deallocation
  (git-fixes).
- commit d804072
* Thu Sep 19 2024 jgross@suse.com
- KVM: arm64: Invalidate EL1&0 TLB entries for all VMIDs in nvhe
  hyp init (git-fixes).
- commit 30df9d2
* Thu Sep 19 2024 tiwai@suse.de
- drm/amd/display: Solve mst monitors blank out problem after
  resume (git-fixes).
- commit cd94b30
* Thu Sep 19 2024 jgross@suse.com
- virtio-net: synchronize probe with ndo_set_features (git-fixes).
- commit 1a471dd
* Thu Sep 19 2024 tiwai@suse.de
- fbdev: hpfb: Fix an error handling path in hpfb_dio_probe()
  (git-fixes).
- hwmon: (ntc_thermistor) fix module autoloading (git-fixes).
- hwmon: (max16065) Fix overflows seen when writing limits
  (git-fixes).
- mtd: powernv: Add check devm_kasprintf() returned value
  (git-fixes).
- mtd: slram: insert break after errors in parsing the map
  (git-fixes).
- power: supply: hwmon: Fix missing temp1_max_alarm attribute
  (git-fixes).
- power: supply: Drop use_cnt check from
  power_supply_property_is_writeable() (git-fixes).
- power: supply: max17042_battery: Fix SOC threshold calc w/
  no current sense (git-fixes).
- power: supply: axp20x_battery: Remove design from min and max
  voltage (git-fixes).
- pinctrl: meteorlake: Add Arrow Lake-H/U ACPI ID (stable-fixes).
- drm/amdgpu/atomfirmware: Silence UBSAN warning (stable-fixes).
- drm/amd/display: Avoid race between dcn10_set_drr() and
  dc_state_destruct() (git-fixes).
- Input: synaptics - enable SMBus for HP Elitebook 840 G2
  (stable-fixes).
- Input: ads7846 - ratelimit the spi_sync error message
  (stable-fixes).
- drm/msm/adreno: Fix error return if missing firmware-name
  (stable-fixes).
- scripts: kconfig: merge_config: config files: add a trailing
  newline (stable-fixes).
- platform/surface: aggregator_registry: Add support for Surface
  Laptop Go 3 (stable-fixes).
- platform/surface: aggregator_registry: Add Support for Surface
  Pro 10 (stable-fixes).
- HID: multitouch: Add support for GT7868Q (stable-fixes).
- drm/mediatek: Set sensible cursor width/height values to fix
  crash (stable-fixes).
- drm: panel-orientation-quirks: Add quirk for Ayn Loki Max
  (stable-fixes).
- drm: panel-orientation-quirks: Add quirk for Ayn Loki Zero
  (stable-fixes).
- wifi: mt76: mt7921: fix NULL pointer access in
  mt7921_ipv6_addr_change (stable-fixes).
- net: phy: vitesse: repair vsc73xx autonegotiation
  (stable-fixes).
- cxl/core: Fix incorrect vendor debug UUID define (git-fixes).
- drm/amd/display: Fix FEC_READY write on DP LT (stable-fixes).
- drm/amd/display: Defer handling mst up request in resume
  (stable-fixes).
- drm/amd/display: Disable error correction if it's not supported
  (stable-fixes).
- commit 040b0ea
* Thu Sep 19 2024 neilb@suse.de
- Update patches.suse/NFS-never-reuse-a-NFSv4-0-lock-owner.patch
  (bsc#1227726 bsc#1230733 bsc#1230971)
- commit 1f8ff5f
* Wed Sep 18 2024 jdelvare@suse.de
- i2c: lpi2c: Avoid calling clk_get_rate during transfer
  (bsc#1227885 CVE-2024-40965).
- commit abb755c
* Wed Sep 18 2024 mhocko@suse.com
- x86/mm/ident_map: Use gbpages only where full GB page should
  be mapped (bsc#1220382).
- x86/kexec: Add EFI config table identity mapping for kexec
  kernel (bsc#1220382).
- commit 26eab5b
* Wed Sep 18 2024 tiwai@suse.de
- Move upstreamed nvme patches into sorted section
- commit 1e42d2f
* Wed Sep 18 2024 tiwai@suse.de
- spi: ppc4xx: Avoid returning 0 when failed to parse and map IRQ
  (git-fixes).
- commit 1cec71a
* Wed Sep 18 2024 tiwai@suse.de
- ASoC: meson: Remove unused declartion in header file
  (git-fixes).
- ASoC: soc-ac97: Fix the incorrect description (git-fixes).
- ASoC: rt5682: Return devm_of_clk_add_hw_provider to transfer
  the error (git-fixes).
- ASoC: tas2781-i2c: Get the right GPIO line (git-fixes).
- ASoC: cs42l42: Convert comma to semicolon (git-fixes).
- ASoC: rt5682s: Return devm_of_clk_add_hw_provider to transfer
  the error (git-fixes).
- ALSA: hda: cs35l41: fix module autoloading (git-fixes).
- selftests: lib: remove strscpy test (git-fixes).
- scripts: sphinx-pre-install: remove unnecessary double check
  for $cur_version (git-fixes).
- Documentation: ioctl: document 0x07 ioctl code (git-fixes).
- module: Fix KCOV-ignored file name (git-fixes).
- reset: k210: fix OF node leak in probe() error path (git-fixes).
- reset: berlin: fix OF node leak in probe() error path
  (git-fixes).
- bus: integrator-lm: fix OF node leak in probe() (git-fixes).
- soc: fsl: cpm1: tsa: Fix tsa_write8() (git-fixes).
- firmware: tegra: bpmp: Drop unused mbox_client_to_bpmp()
  (git-fixes).
- firmware: arm_scmi: Fix double free in OPTEE transport
  (git-fixes).
- soc: versatile: integrator: fix OF node leak in probe() error
  path (git-fixes).
- memory: mtk-smi: Use devm_clk_get_enabled() (git-fixes).
- memory: tegra186-emc: drop unused to_tegra186_emc() (git-fixes).
- spi: bcm63xx: Fix module autoloading (git-fixes).
- spi: rpc-if: Add missing MODULE_DEVICE_TABLE (git-fixes).
- spi: meson-spicc: convert comma to semicolon (git-fixes).
- spi: ppc4xx: handle irq_of_parse_and_map() errors (git-fixes).
- regulator: core: Fix regulator_is_supported_voltage() kerneldoc
  return value (git-fixes).
- regulator: core: Fix short description for
  _regulator_check_status_enabled() (git-fixes).
- regulator: Return actual error in of_regulator_bulk_get_all()
  (git-fixes).
- regulator: rt5120: Convert comma to semicolon (git-fixes).
- regulator: wm831x-isink: Convert comma to semicolon (git-fixes).
- clocksource/drivers/qcom: Add missing iounmap() on errors in
  msm_dt_timer_init() (git-fixes).
- commit 994b020
* Tue Sep 17 2024 tiwai@suse.de
- cpufreq: ti-cpufreq: Introduce quirks to handle syscon fails
  appropriately (git-fixes).
- ACPI: CPPC: Fix MASK_VAL() usage (git-fixes).
- ACPI: PMIC: Remove unneeded check in
  tps68470_pmic_opregion_probe() (git-fixes).
- ACPI: sysfs: validate return type of _STR method (git-fixes).
- crypto: ccp - do not request interrupt on cmd completion when
  irqs disabled (git-fixes).
- hwrng: mtk - Use devm_pm_runtime_enable (git-fixes).
- crypto: ccp - Properly unregister /dev/sev on sev
  PLATFORM_STATUS failure (git-fixes).
- hwrng: cctrng - Add missing clk_disable_unprepare in
  cctrng_resume (git-fixes).
- hwrng: bcm2835 - Add missing clk_disable_unprepare in
  bcm2835_rng_init (git-fixes).
- crypto: iaa - Fix potential use after free bug (git-fixes).
- crypto: xor - fix template benchmarking (git-fixes).
- can: m_can: m_can_close(): stop clocks after device has been
  shut down (git-fixes).
- can: m_can: enable NAPI before enabling interrupts (git-fixes).
- can: bcm: Clear bo->bcm_proc_read after remove_proc_entry()
  (git-fixes).
- Bluetooth: btusb: Fix not handling ZPL/short-transfer
  (git-fixes).
- Bluetooth: hci_sync: Ignore errors from
  HCI_OP_REMOTE_NAME_REQ_CANCEL (git-fixes).
- Bluetooth: hci_core: Fix sending MGMT_EV_CONNECT_FAILED
  (git-fixes).
- wifi: mt76: mt7925: fix a potential array-index-out-of-bounds
  issue for clc (git-fixes).
- wifi: mt76: mt7615: check devm_kasprintf() returned value
  (git-fixes).
- wifi: mt76: mt7921: Check devm_kasprintf() returned value
  (git-fixes).
- wifi: mt76: mt7915: check devm_kasprintf() returned value
  (git-fixes).
- wifi: mt76: mt7996: fix uninitialized TLV data (git-fixes).
- wifi: mt76: mt7915: fix rx filter setting for bfee functionality
  (git-fixes).
- wifi: mt76: mt7603: fix mixed declarations and code (git-fixes).
- wifi: mt76: connac: fix checksum offload fields of connac3 RXD
  (git-fixes).
- wifi: mt76: mt7996: fix NULL pointer dereference in
  mt7996_mcu_sta_bfer_he (git-fixes).
- wifi: mt76: mt7996: fix EHT beamforming capability check
  (git-fixes).
- wifi: mt76: mt7996: fix HE and EHT beamforming capabilities
  (git-fixes).
- wifi: mt76: mt7996: fix wmm set of station interface to 3
  (git-fixes).
- wifi: mt76: mt7996: fix traffic delay when switching back to
  working channel (git-fixes).
- wifi: mt76: mt7996: use hweight16 to get correct tx antenna
  (git-fixes).
- wifi: mt76: mt7921: fix wrong UNII-4 freq range check for the
  channel usage (git-fixes).
- wifi: mt76: mt7915: fix oops on non-dbdc mt7986 (git-fixes).
- wifi: rtw88: remove CPT execution branch never used (git-fixes).
- wifi: wilc1000: fix potential RCU dereference issue in
  wilc_parse_join_bss_param (git-fixes).
- wifi: mac80211: use two-phase skb reclamation in
  ieee80211_do_stop() (git-fixes).
- wifi: cfg80211: fix two more possible UBSAN-detected off-by-one
  errors (git-fixes).
- wifi: cfg80211: fix UBSAN noise in cfg80211_wext_siwscan()
  (git-fixes).
- wifi: mac80211: fix the comeback long retry times (git-fixes).
- wifi: cfg80211: fix bug of mapping AF3x to incorrect User
  Priority (git-fixes).
- wifi: iwlwifi: mvm: increase the time between ranging
  measurements (git-fixes).
- wifi: mac80211: don't use rate mask for offchannel TX either
  (git-fixes).
- wifi: ath12k: fix invalid AMPDU factor calculation in
  ath12k_peer_assoc_h_he() (git-fixes).
- wifi: ath12k: match WMI BSS chan info structure with firmware
  definition (git-fixes).
- wifi: ath12k: fix BSS chan info request WMI command (git-fixes).
- wifi: ath9k: Remove error checks when creating debugfs entries
  (git-fixes).
- wifi: rtw88: always wait for both firmware loading attempts
  (git-fixes).
- wifi: rtw88: 8822c: Fix reported RX band width (git-fixes).
- wifi: brcmfmac: introducing fwil query functions (git-fixes).
- can: j1939: use correct function name in comment (git-fixes).
- commit ffce0ad
* Mon Sep 16 2024 jgross@suse.com
- net: tighten bad gso csum offset check in virtio_net_hdr
  (git-fixes).
- commit 6b94c45
* Mon Sep 16 2024 jgross@suse.com
- KVM: SVM: fix emulation of msr reads/writes of MSR_FS_BASE
  and MSR_GS_BASE (git-fixes).
- commit aeba695
* Mon Sep 16 2024 lhenriques@suse.de
- fscache: delete fscache_cookie_lru_timer when fscache exits
  to avoid  UAF (bsc#1230602).
- commit d2c95a5
* Mon Sep 16 2024 sjaeckel@suse.de
- Update
  patches.suse/virtio_net-Fix-napi_skb_cache_put-warning.patch
  (git-fixes CVE-2024-43835 bsc#1229289).
- commit b9542fb
* Mon Sep 16 2024 ohering@suse.de
- x86/hyperv: fix kexec crash due to VP assist page corruption
  (git-fixes).
- Drivers: hv: vmbus: Fix the misplaced function description
  (git-fixes).
- commit c60d936
* Mon Sep 16 2024 ddiss@suse.de
- Update references
  patches.suse/selinux-smack-don-t-bypass-permissions-check-in-inod.patch
  (stable-fixes CVE-2024-46695 bsc#1230519).
- commit 2a7bb57
* Mon Sep 16 2024 neilb@suse.de
- NFSv4: Add missing rescheduling points in
  nfs_client_return_marked_delegations (git-fixes).
- commit a563f31
* Mon Sep 16 2024 neilb@suse.de
- nfsd: Don't leave work of closing files to a work queue
  (bsc#1228140).
- Refresh
  patches.suse/nfsd-use-__fput_sync-to-avoid-delayed-closing-of-fil.patch.
- commit 83ce74a
* Sun Sep 15 2024 tiwai@suse.de
- ASoC: meson: axg-card: fix 'use-after-free' (git-fixes).
- ASoC: codecs: avoid possible garbage value in peb2466_reg_read()
  (git-fixes).
- commit 5a67afd
* Sat Sep 14 2024 tiwai@suse.de
- kABI workaround for soc-qcom pmic_glink changes (CVE-2024-46693
  bsc#1230521).
- commit 9a06e25
* Sat Sep 14 2024 tiwai@suse.de
- usb: typec: ucsi: Move unregister out of atomic section
  (CVE-2024-46691 bsc#1230526).
- soc: qcom: pmic_glink: Fix race during initialization
  (CVE-2024-46693 bsc#1230521).
- commit 26dd9b4
* Sat Sep 14 2024 tiwai@suse.de
- spi: nxp-fspi: fix the KASAN report out-of-bounds bug
  (git-fixes).
- drm/syncobj: Fix syncobj leak in drm_syncobj_eventfd_ioctl
  (git-fixes).
- drm/nouveau/fb: restore init() for ramgp102 (git-fixes).
- dma-buf: heaps: Fix off-by-one in CMA heap fault handler
  (git-fixes).
- drm/i915/guc: prevent a possible int overflow in wq offsets
  (git-fixes).
- usbnet: ipheth: race between ipheth_close and error handling
  (stable-fixes).
- commit 8d8bf2f
* Sat Sep 14 2024 colyli@suse.de
- md/raid1: Fix data corruption for degraded array with slow disk
  (bsc#1230455, CVE-2024-45023).
- commit 34cd7b5
* Fri Sep 13 2024 tonyj@suse.de
- perf/x86/intel: Limit the period on Haswell (git-fixes).
- perf/x86: Fix smp_processor_id()-in-preemptible warnings
  (git-fixes).
- perf/x86/intel/cstate: Add pkg C2 residency counter for Sierra
  Forest (git-fixes).
- ARM: 9406/1: Fix callchain_trace() return value (git-fixes).
- bpf, events: Use prog to emit ksymbol event for main program
  (git-fixes).
- perf/x86/intel: Add a distinct name for Granite Rapids
  (git-fixes).
- perf/x86/intel/ds: Fix non 0 retire latency on Raptorlake
  (git-fixes).
- perf/x86/intel/uncore: Fix the bits of the CHA extended umask
  for SPR (git-fixes).
- perf: Fix event leak upon exit (git-fixes).
- perf/x86/intel/cstate: Fix Alderlake/Raptorlake/Meteorlake
  (git-fixes).
- perf: Fix default aux_watermark calculation (git-fixes).
- perf: Prevent passing zero nr_pages to rb_alloc_aux()
  (git-fixes).
- perf: Fix perf_aux_size() for greater-than 32-bit size
  (git-fixes).
- perf/x86/intel/pt: Fix pt_topa_entry_for_page() address
  calculation (git-fixes).
- perf/x86/intel/pt: Fix a topa_entry base address calculation
  (git-fixes).
- perf/x86/intel/pt: Fix topa_entry base length (git-fixes).
- perf/x86: Serialize set_attr_rdpmc() (git-fixes).
- perf/core: Fix missing wakeup when waiting for context reference
  (git-fixes).
- perf/x86/intel: Factor out the initialization code for SPR
  (git fixes).
- perf/x86/intel: Use the common uarch name for the shared
  functions (git fixes).
- commit bb48e43
* Fri Sep 13 2024 dsterba@suse.com
- nvme: move stopping keep-alive into nvme_uninit_ctrl() (CVE-2024-45013 bsc#1230442)
- commit ce739c4
* Fri Sep 13 2024 dsterba@suse.com
- i2c: tegra: Do not mark ACPI devices as irq safe (CVE-2024-45029 bsc#1230451)
- commit 2870112
* Fri Sep 13 2024 dsterba@suse.com
- netfilter: flowtable: initialise extack before use (CVE-2024-45018 bsc#1230431)
- commit 8b44b15
* Fri Sep 13 2024 dsterba@suse.com
- net/mlx5e: Take state lock during tx timeout reporter (CVE-2024-45019 bsc#1230432)
- commit 2552371
* Fri Sep 13 2024 dsterba@suse.com
- net/mlx5: Fix IPsec RoCE MPV trace call (CVE-2024-45017 bsc#1230430)
- commit 60aac02
* Fri Sep 13 2024 dsterba@suse.com
- igb: cope with large MAX_SKB_FRAGS (CVE-2024-45030 bsc#1230457)
- commit d2d3c69
* Fri Sep 13 2024 tiwai@suse.de
- Move s390 kabi patch into the kabi section
- commit 4ab5d36
* Fri Sep 13 2024 mfranc@suse.cz
- s390/uv: Don't call folio_wait_writeback() without a folio
  reference (git-fixes bsc#1229380 CVE-2024-43832).
- s390/mm: Convert gmap_make_secure to use a folio (git-fixes
  bsc#1230562).
- s390/mm: Convert make_page_secure to use a folio (git-fixes
  bsc#1230563).
- s390: allow pte_offset_map_lock() to fail (git-fixes
  bsc#1230564).
- commit 7069eb7
* Fri Sep 13 2024 mhocko@suse.com
- mm/vmalloc: fix page mapping if vm_area_alloc_pages() with
  high order fallback to order 0 (CVE-2024-45022 bsc#1230435).
- commit cc8880a
* Fri Sep 13 2024 osalvador@suse.de
- Revert "mm/sparsemem: fix race in accessing memory_section->usage"
  This reverts commit 6aa8957889611fbe7f06353f917cfb3d9620a680 to fix a regression (bsc#1230413)
- commit 720e36b
* Fri Sep 13 2024 osalvador@suse.de
- Revert "mm, kmsan: fix infinite recursion due to RCU critical section"
  This reverts commit 16ad73a9f4c2888f3bc28513f5e9a88d753f8741 to fix a regression (bsc#1230413)
- commit 2fd5290
* Fri Sep 13 2024 osalvador@suse.de
- Revert "mm: prevent derefencing NULL ptr in pfn_section_valid()"
  This reverts commit 35f619d3c421219e07bc89d2d6a37fbff25519fe to fix a refression
  (bsc#1230413)
- commit 7e5afd7
* Fri Sep 13 2024 mhocko@suse.com
- memcg_write_event_control(): fix a user-triggerable oops
  (CVE-2024-45021 bsc#1230434).
- commit 99a85a8
* Fri Sep 13 2024 tiwai@suse.de
- platform/x86: panasonic-laptop: Allocate 1 entry extra in the
  sinf array (git-fixes).
- platform/x86: panasonic-laptop: Fix SINF array out of bounds
  accesses (git-fixes).
- usb: dwc3: core: update LC timer as per USB Spec V3.2
  (stable-fixes).
- lib/generic-radix-tree.c: Fix rare race in
  __genradix_ptr_alloc() (stable-fixes).
- kselftests: dmabuf-heaps: Ensure the driver name is
  null-terminated (stable-fixes).
- regmap: maple: work around gcc-14.1 false-positive warning
  (stable-fixes).
- phy: zynqmp: Take the phy mutex in xlate (stable-fixes).
- pcmcia: Use resource_size function on resource object
  (stable-fixes).
- pci/hotplug/pnv_php: Fix hotplug driver crash on Powernv
  (stable-fixes).
- PCI: keystone: Add workaround for Errata #i2037 (AM65x SR 1.0)
  (stable-fixes).
- PCI: Add missing bridge lock to pci_bus_lock() (stable-fixes).
- usb: gadget: aspeed_udc: validate endpoint index for ast udc
  (stable-fixes).
- usb: uas: set host status byte on data completion error
  (stable-fixes).
- media: qcom: camss: Add check for v4l2_fwnode_endpoint_parse
  (stable-fixes).
- media: vivid: don't set HDMI TX controls if there are no HDMI
  outputs (stable-fixes).
- media: vivid: fix wrong sizeimage value for mplane
  (stable-fixes).
- leds: spi-byte: Call of_node_put() on error path (stable-fixes).
- wifi: rtw88: usb: schedule rx work after everything is set up
  (stable-fixes).
- wifi: rtw89: wow: prevent to send unexpected H2C during download
  Firmware (stable-fixes).
- wifi: mwifiex: Do not return unused priv in
  mwifiex_get_priv_by_id() (stable-fixes).
- wifi: ath12k: fix firmware crash due to invalid peer nss
  (stable-fixes).
- wifi: ath12k: fix uninitialize symbol error on
  ath12k_peer_assoc_h_he() (stable-fixes).
- wifi: brcmsmac: advertise MFP_CAPABLE to enable WPA3
  (stable-fixes).
- wifi: iwlwifi: mvm: use IWL_FW_CHECK for link ID check
  (stable-fixes).
- commit 3b57fa8
* Fri Sep 13 2024 ailiop@suse.com
- Squashfs: sanity check symbolic link size (git-fixes).
- commit fa6af4a
* Fri Sep 13 2024 tiwai@suse.de
- hwmon: (pmbus) Conditionally clear individual status bits for
  pmbus rev >= 1.2 (git-fixes).
- Input: uinput - reject requests with unreasonable number of
  slots (stable-fixes).
- HID: amd_sfh: free driver_data after destroying hid device
  (stable-fixes).
- HID: cougar: fix slab-out-of-bounds Read in cougar_report_fixup
  (stable-fixes).
- i3c: mipi-i3c-hci: Error out instead on BUG_ON() in IBI DMA
  setup (stable-fixes).
- Input: ili210x - use kvmalloc() to allocate buffer for firmware
  update (stable-fixes).
- drm/amdgpu: reject gang submit on reserved VMIDs (stable-fixes).
- drm/amdgpu: Set no_hw_access when VF request full GPU fails
  (stable-fixes).
- drm/amdgpu/display: handle gfx12 in
  amdgpu_dm_plane_format_mod_supported (stable-fixes).
- drm/amdgpu: handle gfx12 in amdgpu_display_verify_sizes
  (stable-fixes).
- drm/amdgpu: check for LINEAR_ALIGNED correctly in
  check_tiling_flags_gfx6 (stable-fixes).
- drm/amd/display: Check denominator pbn_div before used
  (stable-fixes).
- drm/amdgpu: clear RB_OVERFLOW bit when enabling interrupts
  (stable-fixes).
- drm/amdgpu: Fix smatch static checker warning (stable-fixes).
- drm/amdgpu: add missing error handling in function
  amdgpu_gmc_flush_gpu_tlb_pasid (stable-fixes).
- drm/amd/display: Check HDCP returned status (stable-fixes).
- hwmon: (w83627ehf) Fix underflows seen when writing limit
  attributes (stable-fixes).
- hwmon: (nct6775-core) Fix underflows seen when writing limit
  attributes (stable-fixes).
- hwmon: (lm95234) Fix underflows seen when writing limit
  attributes (stable-fixes).
- hwmon: (adc128d818) Fix underflows seen when writing limit
  attributes (stable-fixes).
- commit 2fa929e
* Fri Sep 13 2024 osalvador@suse.de
- Revert "mm/sparsemem: fix race in accessing memory_section->usage"
  This reverts commit 6aa8957889611fbe7f06353f917cfb3d9620a680.
- commit 5376e5a
* Fri Sep 13 2024 osalvador@suse.de
- Revert "mm, kmsan: fix infinite recursion due to RCU critical section"
  This reverts commit 16ad73a9f4c2888f3bc28513f5e9a88d753f8741.
- commit 505329c
* Fri Sep 13 2024 osalvador@suse.de
- Revert "mm: prevent derefencing NULL ptr in pfn_section_valid()"
  This reverts commit 35f619d3c421219e07bc89d2d6a37fbff25519fe.
- commit 937414d
* Fri Sep 13 2024 tiwai@suse.de
- ata: libata: Fix memory leak for error path in ata_host_alloc()
  (git-fixes).
- devres: Initialize an uninitialized struct member
  (stable-fixes).
- ASoc: TAS2781: replace beXX_to_cpup with get_unaligned_beXX
  for potentially broken alignment (stable-fixes).
- ASoC: topology: Properly initialize soc_enum values
  (stable-fixes).
- ALSA: hda: Add input value sanity checks to HDMI channel map
  controls (stable-fixes).
- ALSA: control: Apply sanity check of input values for user
  elements (stable-fixes).
- crypto: qat - fix unintentional re-enabling of error interrupts
  (stable-fixes).
- drm/amd/display: Run DC_LOG_DC after checking link->link_enc
  (stable-fixes).
- drm/amd/display: Check UnboundedRequestEnabled's value
  (stable-fixes).
- drm/amd: Add gfx12 swizzle mode defs (stable-fixes).
- Bluetooth: btnxpuart: Fix Null pointer dereference in
  btnxpuart_flush() (stable-fixes).
- can: mcp251xfd: rx: add workaround for erratum DS80000789E 6
  of mcp2518fd (stable-fixes).
- can: mcp251xfd: rx: prepare to workaround broken RX FIFO head
  index erratum (stable-fixes).
- can: mcp251xfd: mcp251xfd_handle_rxif_ring_uinc(): factor out
  in separate function (stable-fixes).
- can: mcp251xfd: clarify the meaning of timestamp (stable-fixes).
- can: kvaser_pciefd: Skip redundant NULL pointer check in ISR
  (stable-fixes).
- ACPI: processor: Fix memory leaks in error paths of
  processor_add() (stable-fixes).
- ACPI: processor: Return an error if acpi_processor_get_info()
  fails in processor_add() (stable-fixes).
- cpufreq: amd-pstate: fix the highest frequency issue which
  limits performance (git-fixes).
- cpufreq: amd-pstate: Enable amd-pstate preferred core support
  (stable-fixes).
- ACPI: CPPC: Add helper to get the highest performance value
  (stable-fixes).
- Bluetooth: hci_sync: Add helper functions to manipulate cmd_sync
  queue (stable-fixes).
- Bluetooth: hci_event: Use HCI error defines instead of magic
  values (stable-fixes).
- commit 96be389
* Thu Sep 12 2024 jgross@suse.com
- virtio_net: Fix napi_skb_cache_put warning (git-fixes).
- commit 860ef0a
* Thu Sep 12 2024 jgross@suse.com
- virtio_net: fixing XDP for fully checksummed packets handling
  (git-fixes).
- commit 77fb9e7
* Thu Sep 12 2024 mfranc@suse.cz
- s390/dasd: Fix redundant /proc/dasd* entries removal
  (bsc#1227694).
- commit b66530a
* Thu Sep 12 2024 tiwai@suse.de
- Move upstreamed input patch into sorted section
- commit e197a51
* Thu Sep 12 2024 jgross@suse.com
- KVM: SVM: Don't advertise Bus Lock Detect to guest if SVM
  support is missing (git-fixes).
- commit 42f7b0c
* Thu Sep 12 2024 jgross@suse.com
- KVM: x86: Acquire kvm->srcu when handling KVM_SET_VCPU_EVENTS
  (git-fixes).
- commit 610cfdd
* Thu Sep 12 2024 jgross@suse.com
- KVM: arm64: Make ICC_*SGI*_EL1 undef in the absence of a vGICv3
  (git-fixes).
- commit bae7627
* Thu Sep 12 2024 jroedel@suse.de
- kABI: Workaround kABI change in
  patches.suse/iommu-dma-Trace-bounce-buffer-usage-when-mapping-buf.patch
  (git-fixes).
- Refresh
  patches.suse/iommu-dma-Trace-bounce-buffer-usage-when-mapping-buf.patch.
- commit d37ca1f
* Thu Sep 12 2024 jgross@suse.com
- KVM: arm64: Do not re-initialize the KVM lock (git-fixes).
- commit b05c6c8
* Thu Sep 12 2024 mfranc@suse.cz
- s390/dasd: Remove DMA alignment (LTC#208933 bsc#1230426
  git-fixes).
- commit 5b1f3c2
* Thu Sep 12 2024 jgross@suse.com
- KVM: arm64: vgic-v2: Check for non-NULL vCPU in
  vgic_v2_parse_attr() (git-fixes).
- commit 4ccaaf2
* Thu Sep 12 2024 jgross@suse.com
- KVM: arm64: Don't pass a TLBI level hint when zapping table
  entries (git-fixes).
- commit e3cb3e5
* Thu Sep 12 2024 jgross@suse.com
- KVM: arm64: nvhe: Ignore SVE hint in SMCCC function ID
  (git-fixes).
- commit 9d7939a
* Thu Sep 12 2024 jgross@suse.com
- KVM: arm64: Block unsafe FF-A calls from the host (git-fixes).
- commit 6327e50
* Thu Sep 12 2024 tiwai@suse.de
- minmax: reduce min/max macro expansion in atomisp driver
  (git-fixes).
- commit 6d37707
* Thu Sep 12 2024 dsterba@suse.com
- net: dsa: bcm_sf2: Fix a possible memory leak in bcm_sf2_mdio_register() (CVE-2024-44971 bsc#1230211)
- commit f262d95
* Thu Sep 12 2024 dsterba@suse.com
- tcp: prevent concurrent execution of tcp_sk_exit_batch (CVE-2024-44991 bsc#1230195)
- commit 179b01d
* Wed Sep 11 2024 dsterba@suse.com
- bonding: fix xfrm real_dev null pointer dereference (CVE-2024-44989 bsc#1230193)
- commit 5caf0d2
* Wed Sep 11 2024 tonyj@suse.de
- perf arch events: Fix duplicate RISC-V SBI firmware event name
  (git-fixes).
- commit 4570763
* Wed Sep 11 2024 tonyj@suse.de
- perf tool: fix dereferencing NULL al->maps (git-fixes).
- commit 5e4751b
* Wed Sep 11 2024 tonyj@suse.de
- perf intel-pt: Fix exclude_guest setting (git-fixes).
- commit e69b63b
* Wed Sep 11 2024 tonyj@suse.de
- perf intel-pt: Fix aux_watermark calculation for 64-bit size
  (git-fixes).
- commit e3b3bca
* Wed Sep 11 2024 tonyj@suse.de
- perf report: Fix condition in sort__sym_cmp() (git-fixes).
- commit c3e65ee
* Wed Sep 11 2024 tonyj@suse.de
- perf pmus: Fixes always false when compare duplicates aliases
  (git-fixes).
- commit 8eeac69
* Wed Sep 11 2024 tonyj@suse.de
- tools/perf: Fix the string match for "/tmp/perf-$PID.map"
  files in dso__load (git-fixes).
- commit 9a7d0fb
* Wed Sep 11 2024 krisman@suse.de
- bonding: fix null pointer deref in bond_ipsec_offload_ok
  (CVE-2024-44990 bsc#1230194).
- media: aspeed: Fix memory overwrite if timing is 1600x900
  (CVE-2023-52916 bsc#1230269).
- commit 7cce3c7
* Wed Sep 11 2024 tonyj@suse.de
- perf test: Make test_arm_callgraph_fp.sh more robust
  (git-fixes).
- commit 8d430e5
* Wed Sep 11 2024 tonyj@suse.de
- perf stat: Fix the hard-coded metrics calculation on the hybrid
  (git-fixes).
- commit 0fe6062
* Wed Sep 11 2024 tonyj@suse.de
- perf pmu: Assume sysfs events are always the same case
  (git-fixes).
- Refresh
  patches.suse/perf-pmu-Count-sys-and-cpuid-JSON-events-separately.patch.
- commit 0eb9b05
* Wed Sep 11 2024 krisman@suse.de
- rtla/osnoise: Prevent NULL dereference in error handling
  (CVE-2024-45002 bsc#1230169).
- net/mlx5e: SHAMPO, Fix invalid WQ linked list unlink
  (CVE-2024-44970 bsc#1230209).
- commit 33e2b5d
* Wed Sep 11 2024 oneukum@suse.com
- lirc: rc_dev_get_from_fd(): fix file leak (git-fixes).
- commit b3b20de
* Wed Sep 11 2024 oneukum@suse.com
- thunderbolt: Fix calculation of consumed USB3 bandwidth on a
  path (git-fixes).
- commit c3642e6
* Wed Sep 11 2024 marco.crivellari@suse.com
- Move fixes into sorted section (bsc#1230119)
- commit c8d5e3a
* Wed Sep 11 2024 tiwai@suse.de
- Refresh patches.suse/ipmi-ssif-Improve-detecting-during-probing.patch
  Add commit id and move away from out-of-tree section
- commit ceb6869
* Wed Sep 11 2024 tiwai@suse.de
- Move upstreamed kaslr patch into sorted section
- commit 554594b
* Wed Sep 11 2024 dsterba@suse.com
- net: dsa: mv88e6xxx: Fix out-of-bound access (CVE-2024-44988 bsc#1230192)
- commit 5ca3065
* Wed Sep 11 2024 dsterba@suse.com
- ipv6: prevent UAF in ip6_send_skb() (CVE-2024-44987 bsc#1230185)
- commit 075c292
* Wed Sep 11 2024 tonyj@suse.de
- perf tools: Add/use PMU reverse lookup from config to name
  (git-fixes).
- commit 62632fc
* Wed Sep 11 2024 tonyj@suse.de
- perf tools: Use pmus to describe type from attribute
  (git-fixes).
- commit 3dc616b
* Wed Sep 11 2024 tonyj@suse.de
- perf: script: add raw|disasm arguments to --insn-trace option
  (git-fixes).
- Refresh
  patches.suse/perf-script-Show-also-errors-for-insn-trace-option.patch.
- commit f716aa4
* Wed Sep 11 2024 tonyj@suse.de
- perf annotate: Use global annotation_options (git-fixes).
- Refresh
  patches.suse/perf-annotate-Fix-annotation_calc_lines-to-pass-correct-address-to-get_srcline.patch.
- commit b70a6bc
* Wed Sep 11 2024 tonyj@suse.de
- perf top: Convert to the global annotation_options (git-fixes).
- commit c12ae1d
* Wed Sep 11 2024 tonyj@suse.de
- perf report: Convert to the global annotation_options
  (git-fixes).
- commit e5bcc3a
* Wed Sep 11 2024 tonyj@suse.de
- perf annotate: Introduce global annotation_options (git-fixes).
- commit b458961
* Wed Sep 11 2024 tonyj@suse.de
- perf maps: Move symbol maps functions to maps.c (git-fixes).
- Refresh
  patches.suse/perf-symbols-Fix-ownership-of-string-in-dso__load_vmlinux.patch.
- commit 93caf35
* Wed Sep 11 2024 tonyj@suse.de
- perf annotate: Split branch stack cycles information out of
  'struct annotation_line' (git-fixes).
- commit 733d4c0
* Wed Sep 11 2024 tonyj@suse.de
- perf machine thread: Remove exited threads by default
  (git-fixes).
- commit 3c4b077
* Wed Sep 11 2024 dsterba@suse.com
- Update references for patches.suse/ipv6-fix-possible-UAF-in-ip6_finish_output2.patch (CVE-2024-44986 bsc#1230230 bsc#1230206)
- commit 814e7ee
* Wed Sep 11 2024 dsterba@suse.com
- bnxt_en: Fix double DMA unmapping for XDP_REDIRECT (CVE-2024-44984 bsc#1230240)
- commit 43e2e07
* Wed Sep 11 2024 dsterba@suse.com
- gtp: pull network headers in gtp_dev_xmit() (CVE-2024-44999 bsc#1230233)
- commit 057aaf8
* Tue Sep 10 2024 tonyj@suse.de
- perf record: Lazy load kernel symbols (git-fixes).
- commit 84efd43
* Tue Sep 10 2024 tonyj@suse.de
- Detect memory allocation failure in
  annotated_source__alloc_histograms (bsc#1227962).
- commit 6424d7a
* Tue Sep 10 2024 tonyj@suse.de
- Add alternate commit id for git-fixes.
  Refresh
  patches.suse/perf-evlist-Fix-evlist__new_default-for-1-core-PMU.patch.
- commit 3b7c481
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: There are only 5 basic router registers in pre-USB4
  routers (git-fixes).
- commit 065ac58
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Fix rollback in tb_port_lane_bonding_enable()
  for lane 1 (git-fixes).
- commit 108e81e
* Tue Sep 10 2024 iivanov@suse.de
- ipmi:ssif: Improve detecting during probing (bsc#1228771)
- commit db0a09e
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Fix XDomain rx_lanes_show and tx_lanes_show
  (git-fixes).
- commit b11c099
* Tue Sep 10 2024 tiwai@suse.de
- Drop soundwire patch that caused a regression (bsc#1230350)
  Deleted:
  patches.suse/soundwire-stream-fix-programming-slave-ports-for-non.patch
- commit 5c05eeb
* Tue Sep 10 2024 fdmanana@suse.com
- btrfs: fix race between direct IO write and fsync when using
  same fd (git-fixes).
- commit dc59ebc
* Tue Sep 10 2024 vbabka@suse.cz
- mm/swap: fix race when skipping swapcache (CVE-2024-26759
  bsc#1230340).
- commit 990c0c6
* Tue Sep 10 2024 tiwai@suse.de
- kABI workaround for cros_ec stuff (git-fixes).
- commit cb01b4e
* Tue Sep 10 2024 tiwai@suse.de
- platform/chrome: cros_ec_lpc: MEC access can use an AML mutex
  (stable-fixes).
- commit d9de020
* Mon Sep  9 2024 ohering@suse.de
- Drivers: hv: vmbus: Fix rescind handling in uio_hv_generic
  (git-fixes).
- uio_hv_generic: Fix kernel NULL pointer dereference in
  hv_uio_rescind (git-fixes).
- net: mana: Fix error handling in mana_create_txq/rxq's NAPI
  cleanup (git-fixes).
- commit 27572d4
* Mon Sep  9 2024 jgross@suse.com
- x86/pat: Fix W^X violation false-positives when running as
  Xen PV guest (bsc#1221527).
- commit 9acf0ca
* Mon Sep  9 2024 jgross@suse.com
- x86/pat: Restructure _lookup_address_cpa() (bsc#1221527).
- commit 56f7c9c
* Mon Sep  9 2024 msuchanek@suse.de
- powerpc/qspinlock: Fix deadlock in MCS queue (bac#1230295
  ltc#206656).
- commit c4a2ba1
* Mon Sep  9 2024 mwilck@suse.com
- Refresh
  patches.kabi/kabi-dm_blk_ioctl-implement-path-failover-for-SG_IO.patch.
- Refresh
  patches.suse/dm_blk_ioctl-implement-path-failover-for-SG_IO.patch.
- commit 73c5a36
* Mon Sep  9 2024 jgross@suse.com
- x86/mm: Use lookup_address_in_pgd_attr() in show_fault_oops()
  (bsc#1221527).
- commit 84d383c
* Mon Sep  9 2024 jgross@suse.com
- x86/pat: Introduce lookup_address_in_pgd_attr() (bsc#1221527).
- commit 09ca5ca
* Mon Sep  9 2024 tiwai@suse.de
- drm/amd/display: Replace dm_execute_dmub_cmd with
  dc_wake_and_execute_dmub_cmd (git-fixes).
- commit 6d87705
* Mon Sep  9 2024 tiwai@suse.de
- wifi: cfg80211: make hash table duplicates more survivable
  (stable-fixes).
- Refresh patches.kabi/wireless-kabi-workaround.patch.
- commit 62f6e12
* Mon Sep  9 2024 tiwai@suse.de
- VMCI: Fix use-after-free when removing resource in
  vmci_resource_remove() (git-fixes).
- misc: fastrpc: Fix double free of 'buf' in error path
  (git-fixes).
- iio: fix scale application in
  iio_convert_raw_to_processed_unlocked (git-fixes).
- iio: adc: ad7124: fix config comparison (git-fixes).
- iio: adc: ad7124: fix chip ID mismatch (git-fixes).
- iio: buffer-dmaengine: fix releasing dma channel on error
  (git-fixes).
- iio: adc: ad7606: remove frstdata check for serial mode
  (git-fixes).
- staging: iio: frequency: ad9834: Validate frequency parameter
  value (git-fixes).
- usb: dwc3: Avoid waking up gadget during startxfer (git-fixes).
- net: usb: qmi_wwan: add MeiG Smart SRM825L (stable-fixes).
- drm/gpuvm: fix missing dependency to DRM_EXEC (git-fixes).
- drm: panel-orientation-quirks: Add quirk for OrangePi Neo
  (stable-fixes).
- drm/fb-helper: Don't schedule_work() to flush frame buffer
  during panic() (stable-fixes).
- PCI: al: Check IORESOURCE_BUS existence during probe
  (stable-fixes).
- usb: typec: ucsi: Fix null pointer dereference in trace
  (stable-fixes).
- usbip: Don't submit special requests twice (stable-fixes).
- media: uvcvideo: Enforce alignment of frame and interval
  (stable-fixes).
- wifi: ath12k: initialize 'ret' in
  ath12k_dp_rxdma_ring_sel_config_wcn7850() (stable-fixes).
- wifi: ath11k: initialize 'ret' in
  ath11k_qmi_load_file_target_mem() (stable-fixes).
- wifi: ath12k: initialize 'ret' in
  ath12k_qmi_load_file_target_mem() (stable-fixes).
- wifi: rtw89: ser: avoid multiple deinit on same CAM
  (stable-fixes).
- wifi: mac80211: check ieee80211_bss_info_change_notify()
  against MLD (stable-fixes).
- wifi: cfg80211: restrict operation during radar detection
  (stable-fixes).
- pwm: xilinx: Fix u32 overflow issue in 32-bit width PWM mode
  (stable-fixes).
- hwmon: (k10temp) Check return value of amd_smn_read()
  (stable-fixes).
- regmap: spi: Fix potential off-by-one when calculating reserved
  size (stable-fixes).
- commit 73bbd93
* Mon Sep  9 2024 tiwai@suse.de
- clocksource/drivers/imx-tpm: Fix next event not taking effect
  sometime (git-fixes).
- clocksource/drivers/imx-tpm: Fix return -ETIME when delta
  exceeds INT_MAX (git-fixes).
- dma-debug: avoid deadlock between dma debug vs printk and
  netconsole (stable-fixes).
- drm/amdgpu: fix contiguous handling for IB parsing v2
  (git-fixes).
- dmaengine: altera-msgdma: properly free descriptor in
  msgdma_free_descriptor (stable-fixes).
- dmaengine: altera-msgdma: use irq variant of spin_lock/unlock
  while invoking callbacks (stable-fixes).
- driver: iio: add missing checks on iio_info's callback access
  (stable-fixes).
- drm/amd/display: Skip wbscl_set_scaler_filter if filter is null
  (stable-fixes).
- drm/amd/display: Check BIOS images before it is used
  (stable-fixes).
- drm/amd/display: Avoid overflow from uint32_t to uint8_t
  (stable-fixes).
- drm/amd/display: use preferred link settings for dp signal only
  (stable-fixes).
- drm/amd/display: Remove register from DCN35 DMCUB diagnostic
  collection (stable-fixes).
- drm/amd/display: Correct the defined value for
  AMDGPU_DMUB_NOTIFICATION_MAX (stable-fixes).
- drm/amd/display: added NULL check at start of dc_validate_stream
  (stable-fixes).
- drm/amd/display: Wake DMCUB before sending a command for replay
  feature (stable-fixes).
- drm/amd/display: Don't use fsleep for PSR exit waits on dmub
  replay (stable-fixes).
- drm/amdgpu: fix overflowed constant warning in
  mmhub_set_clockgating() (stable-fixes).
- drm/amdgpu: add lock in kfd_process_dequeue_from_device
  (stable-fixes).
- drm/amdgpu: add lock in amdgpu_gart_invalidate_tlb
  (stable-fixes).
- drm/amdgpu: add skip_hw_access checks for sriov (stable-fixes).
- drm/bridge: tc358767: Check if fully initialized before
  signalling HPD event via IRQ (stable-fixes).
- drm/meson: plane: Add error handling (stable-fixes).
- drm/drm-bridge: Drop conditionals around of_node pointers
  (stable-fixes).
- drm/amd/display: Add null checks for 'stream' and 'plane'
  before dereferencing (stable-fixes).
- drm/amdgu: fix Unintentional integer overflow for mall size
  (stable-fixes).
- drm/amdgpu: update type of buf size to u32 for eeprom functions
  (stable-fixes).
- drm/amd/display: Fix pipe addition logic in
  calc_blocks_to_ungate DCN35 (stable-fixes).
- drm/kfd: Correct pinned buffer handling at kfd restore and
  validate process (stable-fixes).
- drm/amd/pm: check negtive return for table entries
  (stable-fixes).
- drm/amdgpu: the warning dereferencing obj for nbio_v7_4
  (stable-fixes).
- drm/amd/pm: check specific index for smu13 (stable-fixes).
- drm/amd/pm: check specific index for aldebaran (stable-fixes).
- drm/amdgpu: fix the waring dereferencing hive (stable-fixes).
- drm/amdgpu: fix dereference after null check (stable-fixes).
- drm/amdgpu: Fix the warning division or modulo by zero
  (stable-fixes).
- drm/amdgpu/pm: Check input value for CUSTOM profile mode
  setting on legacy SOCs (stable-fixes).
- drm/amdkfd: Reconcile the definition and use of oem_id in
  struct kfd_topology_device (stable-fixes).
- drm/amdgpu: fix mc_data out-of-bounds read warning
  (stable-fixes).
- drm/amdgpu: fix ucode out-of-bounds read warning (stable-fixes).
- drm/amdgpu: Fix uninitialized variable warning in
  amdgpu_info_ioctl (stable-fixes).
- drm/amdgpu: Fix out-of-bounds read of df_v1_7_channel_number
  (stable-fixes).
- drm/amdkfd: Check debug trap enable before write dbg_ev_file
  (stable-fixes).
- drm/amdgpu: Fix out-of-bounds write warning (stable-fixes).
- drm/amdgpu: Fix the uninitialized variable warning
  (stable-fixes).
- drm/amdgpu/pm: Fix uninitialized variable agc_btc_response
  (stable-fixes).
- drm/amdgpu/pm: Fix uninitialized variable warning for smu10
  (stable-fixes).
- drm/amd/pm: fix uninitialized variable warnings for vangogh_ppt
  (stable-fixes).
- drm/amd/amdgpu: Check tbo resource pointer (stable-fixes).
- drm/amd/display: Fix index may exceed array range within
  fpu_update_bw_bounding_box (stable-fixes).
- drm/amd/display: Skip inactive planes within
  ModeSupportAndSystemConfiguration (stable-fixes).
- drm/amd/display: Ensure index calculation will not overflow
  (stable-fixes).
- drm/amd/display: Fix Coverity INTEGER_OVERFLOW within
  decide_fallback_link_setting_max_bw_policy (stable-fixes).
- drm/amd/display: Spinlock before reading event (stable-fixes).
- drm/amd/display: Fix Coverity INTEGER_OVERFLOW within
  dal_gpio_service_create (stable-fixes).
- drm/amd/display: Fix Coverity INTERGER_OVERFLOW within
  construct_integrated_info (stable-fixes).
- drm/amd/display: Check msg_id before processing transcation
  (stable-fixes).
- drm/amd/display: Check num_valid_sets before accessing
  reader_wm_sets[] (stable-fixes).
- drm/amd/display: Add array index check for hdcp ddc access
  (stable-fixes).
- drm/amd/display: Check index for aux_rd_interval before using
  (stable-fixes).
- drm/amd/display: Stop amdgpu_dm initialize when stream nums
  greater than 6 (stable-fixes).
- drm/amd/display: Check gpio_id before used as array index
  (stable-fixes).
- drm/amd/display: Ensure array index tg_inst won't be -1
  (stable-fixes).
- drm/amdgpu: avoid reading vf2pf info size from FB
  (stable-fixes).
- drm/amd/pm: fix uninitialized variable warnings for vega10_hwmgr
  (stable-fixes).
- drm/amdgpu: fix uninitialized scalar variable warning
  (stable-fixes).
- drm/amd/pm: fix the Out-of-bounds read warning (stable-fixes).
- drm/amd/pm: Fix negative array index read (stable-fixes).
- drm/amd/pm: fix warning using uninitialized value of
  max_vid_step (stable-fixes).
- drm/amd/pm: fix uninitialized variable warning for smu8_hwmgr
  (stable-fixes).
- drm/amd/pm: fix uninitialized variable warning (stable-fixes).
- drm/amdgpu/pm: Check the return value of smum_send_msg_to_smc
  (stable-fixes).
- drm/amdgpu: fix overflowed array index read warning
  (stable-fixes).
- drm/amdgpu: Handle sg size limit for contiguous allocation
  (stable-fixes).
- drm/amd/display: Assign linear_pitch_alignment even for VM
  (stable-fixes).
- drm/amd/display: Handle the case which quad_part is equal 0
  (stable-fixes).
- drm/amdgpu: Fix uninitialized variable warning in
  amdgpu_afmt_acr (stable-fixes).
- cpufreq: scmi: Avoid overflow of target_freq in fast switch
  (stable-fixes).
- commit e23c4dc
* Mon Sep  9 2024 nmorey@suse.com
- RDMA/efa: Properly handle unexpected AQ completions (git-fixes)
- commit 8c8b9e5
* Sun Sep  8 2024 tiwai@suse.de
- clk: qcom: gcc-sc8280xp: don't use parking clk_ops for QUPs
  (git-fixes).
- clk: qcom: gcc-sm8550: Don't park the USB RCG at registration
  time (git-fixes).
- clk: qcom: gcc-sm8550: Don't use parking clk_ops for QUPs
  (git-fixes).
- clk: qcom: ipq9574: Update the alpha PLL type for GPLLs
  (git-fixes).
- clk: qcom: clk-alpha-pll: Fix zonda set_rate failure when PLL
  is disabled (git-fixes).
- clk: qcom: clk-alpha-pll: Fix the trion pll postdiv set rate
  API (git-fixes).
- clk: qcom: clk-alpha-pll: Fix the pll post div mask (git-fixes).
- commit 060a67a
* Sat Sep  7 2024 tiwai@suse.de
- ALSA: hda/realtek - Fix inactive headset mic jack for ASUS
  Vivobook 15 X1504VAP (stable-fixes).
- ALSA: hda/realtek: Support mute LED on HP Laptop 14-dq2xxx
  (stable-fixes).
- ALSA: hda/realtek: Enable Mute Led for HP Victus 15-fb1xxx
  (stable-fixes).
- ALSA: hda/realtek: extend quirks for Clevo V5[46]0
  (stable-fixes).
- ALSA: hda/realtek: add patch for internal mic in Lenovo V145
  (stable-fixes).
- ALSA: hda/conexant: Add pincfg quirk to enable top speakers
  on Sirius devices (stable-fixes).
- commit 5538dd8
* Sat Sep  7 2024 tiwai@suse.de
- ASoC: sunxi: sun4i-i2s: fix LRCLK polarity in i2s mode
  (git-fixes).
- ASoc: SOF: topology: Clear SOF link platform name upon unload
  (git-fixes).
- ASoC: tegra: Fix CBB error during probe() (git-fixes).
- ASoC: dapm: Fix UAF for snd_soc_pcm_runtime object (git-fixes).
- mmc: cqhci: Fix checking of CQHCI_HALT state (git-fixes).
- mmc: dw_mmc: Fix IDMAC operation with pages bigger than 4K
  (git-fixes).
- mmc: sdhci-of-aspeed: fix module autoloading (git-fixes).
- mmc: core: apply SD quirks earlier during probe (git-fixes).
- gpio: modepin: Enable module autoloading (git-fixes).
- gpio: rockchip: fix OF node leak in probe() (git-fixes).
- Revert "drm/amdgpu: align pp_power_profile_mode with kernel
  docs" (stable-fixes).
- nouveau: fix the fwsec sb verification register (git-fixes).
- drm/i915/fence: Mark debug_fence_free() with __maybe_unused
  (git-fixes).
- drm/i915/fence: Mark debug_fence_init_onstack() with
  __maybe_unused (git-fixes).
- drm/i915: Do not attempt to load the GSC multiple times
  (git-fixes).
- commit 7a89765
* Fri Sep  6 2024 dsterba@suse.com
- ipv6: fix possible UAF in ip6_finish_output2() (bsc#1230206)
- commit 64f6ea9
* Fri Sep  6 2024 dsterba@suse.com
- ipv6: prevent possible UAF in ip6_xmit() (CVE-2024-44985 bsc#1230206)
- commit 209198a
* Fri Sep  6 2024 ddiss@suse.de
- vfs: Don't evict inode under the inode lru traversing context
  (CVE-2024-45003 bsc#1230245).
- commit 630b67a
* Fri Sep  6 2024 tiwai@suse.de
- Restore dropped fields for bluetooth MGMT/SMP structs
  (git-fixes).
- commit 5313ecb
* Fri Sep  6 2024 tiwai@suse.de
- usbnet: modern method to get random MAC (git-fixes).
- net: phy: Fix missing of_node_put() for leds (git-fixes).
- Bluetooth: MGMT: Ignore keys being loaded with invalid type
  (git-fixes).
- Revert "Bluetooth: MGMT/SMP: Fix address type when using SMP
  over BREDR/LE" (git-fixes).
- can: mcp251x: fix deadlock if an interrupt occurs during
  mcp251x_open (git-fixes).
- can: mcp251xfd: fix ring configuration when switching from
  CAN-CC to CAN-FD mode (git-fixes).
- can: m_can: Release irq on error in m_can_open (git-fixes).
- can: bcm: Remove proc entry when dev is unregistered
  (git-fixes).
- spi: rockchip: Resolve unbalanced runtime PM / system PM
  handling (git-fixes).
- regulator: core: Stub devm_regulator_bulk_get_const() if
  !CONFIG_REGULATOR (git-fixes).
- platform/x86: dell-smbios: Fix error path in dell_smbios_init()
  (git-fixes).
- commit b6769e6
* Fri Sep  6 2024 jslaby@suse.cz
- serial: sc16is7xx: fix invalid FIFO access with special register
  set (CVE-2024-44950 bsc#1230180).
- serial: sc16is7xx: fix TX fifo corruption (CVE-2024-44951
  bsc#1230181).
- serial: sc16is7xx: refactor FIFO access functions to increase
  commonality (CVE-2024-44951 bsc#1230181).
- commit 4ab54b2
* Fri Sep  6 2024 neilb@suse.de
- NFS: never reuse a NFSv4.0 lock-owner (bsc#1227726).
- commit ed692a4
* Thu Sep  5 2024 tiwai@suse.de
- atm: idt77252: prevent use after free in dequeue_rx()
  (CVE-2024-44998 bsc#1230171).
- commit fd57936
* Thu Sep  5 2024 sjaeckel@suse.de
- tcp: add sanity checks to rx zerocopy (CVE-2024-26640
  bsc#1221650).
- commit 21286c2
* Thu Sep  5 2024 oneukum@suse.com
- USB: serial: option: add MeiG Smart SRM825L (git-fixes).
- commit 047a639
* Thu Sep  5 2024 ailiop@suse.com
- nilfs2: fix state management in error path of log writing
  function (git-fixes).
- commit 9b55988
* Thu Sep  5 2024 oneukum@suse.com
- cdc-acm: Add DISABLE_ECHO quirk for GE HealthCare UI Controller
  (git-fixes).
- commit a322b71
* Thu Sep  5 2024 oneukum@suse.com
- usb: dwc3: core: Prevent USB core invalid event buffer address
  access (git-fixes).
- commit de7b6b3
* Thu Sep  5 2024 ailiop@suse.com
- nilfs2: fix missing cleanup on rollforward recovery error
  (git-fixes).
- commit b4149d3
* Thu Sep  5 2024 ailiop@suse.com
- nilfs2: protect references to superblock parameters exposed
  in sysfs (git-fixes).
- commit e7215f6
* Thu Sep  5 2024 iivanov@suse.de
- arm64: tlb: Allow range operation for MAX_TLBI_RANGE_PAGES (bsc#1229585)
- commit a52467b
* Thu Sep  5 2024 iivanov@suse.de
- arm64: tlb: Improve __TLBI_VADDR_RANGE() (bsc#1229585)
- commit 26752eb
* Thu Sep  5 2024 iivanov@suse.de
- arm64: tlb: Fix TLBI RANGE operand (bsc#1229585)
- commit 24bd468
* Thu Sep  5 2024 iivanov@suse.de
- arm64/mm: Update tlb invalidation routines for FEAT_LPA2 (bsc#1229585)
- commit b8ec0d4
* Thu Sep  5 2024 iivanov@suse.de
- arm64/mm: Modify range-based tlbi to decrement scale (bsc#1229585)
- commit e08c708
* Thu Sep  5 2024 tiwai@suse.de
- USB: serial: option: add MeiG Smart SRM825L (stable-fixes).
- cdc-acm: Add DISABLE_ECHO quirk for GE HealthCare UI Controller
  (stable-fixes).
- usb: dwc3: core: Prevent USB core invalid event buffer address
  access (stable-fixes).
- selinux,smack: don't bypass permissions check in inode_setsecctx
  hook (stable-fixes).
- drm/amdgpu/swsmu: always force a state reprogram on init
  (stable-fixes).
- drm/amdgpu: align pp_power_profile_mode with kernel docs
  (stable-fixes).
- commit 1d64229
* Wed Sep  4 2024 krisman@suse.de
- Resort io_uring kABI patches
  These ended up in the wrong section.  Push them to the right place, next
  to the other io_uring kabi patches.
- commit f218522
* Wed Sep  4 2024 krisman@suse.de
- kABI: Split kABI out of 'io_uring: Re-add dummy_ubuf for kABI purposes'
  When introducing this patch, I merged the kABI patch with the actual
  backport, which is not recommended.  Split it up, such that the backport
  is similar to the upstream patch and handle the kABI issue exactly the
  same way, but through a separate kABI patch.
- commit 5b3aa8f
* Wed Sep  4 2024 krisman@suse.de
- kABI: Split kABI out of 'io_uring/kbuf: get rid of bl->is_ready'
  When introducing this patch, I merged the kABI patch with the actual
  backport, which is not recommended.  Split it up, such that the backport
  is similar to the upstream patch and handle the kABI issue exactly the
  same way, but through a separate kABI patch.
- commit d39d376
* Wed Sep  4 2024 jack@suse.cz
- ext4: sanity check for NULL pointer after ext4_force_shutdown
  (bsc#1229753 CVE-2024-43898).
- commit d9361cb
* Wed Sep  4 2024 jack@suse.cz
- udf: Fix bogus checksum computation in udf_rename() (bsc#1229389
  CVE-2024-43845).
- commit 985c73e
* Wed Sep  4 2024 jack@suse.cz
- ext4: fix infinite loop when replaying fast_commit (bsc#1229394
  CVE-2024-43828).
- commit c9c168b
* Wed Sep  4 2024 jack@suse.cz
- block: fix deadlock between sd_remove & sd_release (bsc#1229371
  CVE-2024-42294).
- commit a556834
* Wed Sep  4 2024 jack@suse.cz
- udf: Avoid using corrupted block bitmap buffer (bsc#1229362
  CVE-2024-42306).
- commit 26b3a5d
* Wed Sep  4 2024 jack@suse.cz
- ext4: check dot and dotdot of dx_root before making dir indexed
  (bsc#1229363 CVE-2024-42305).
- commit d42c7e5
* Wed Sep  4 2024 jack@suse.cz
- mm/filemap: make MAX_PAGECACHE_ORDER acceptable to xarray
  (bsc#1229001 CVE-2024-42243).
- commit 962c57e
* Wed Sep  4 2024 jack@suse.cz
- protect the fetch of ->fd[fd] in do_dup2() from mispredictions
  (bsc#1229334 CVE-2024-42265).
- commit 1088a58
* Wed Sep  4 2024 jack@suse.cz
- ext4: make sure the first directory block is not a hole
  (bsc#1229364 CVE-2024-42304).
- commit 0ee54f7
* Wed Sep  4 2024 davide.benini@suse.com
- netfilter: ctnetlink: use helper function to calculate expect ID
  (CVE-2024-44944 bsc#1229899).
- commit da9b5c6
* Wed Sep  4 2024 davide.benini@suse.com
- sctp: Fix null-ptr-deref in reuseport_add_sock()
  (CVE-2024-44935 bsc#1229810).
- commit c34ddb2
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/uncore: Cleanup unused unit structure (bsc#1230119).
- commit 48a66a6
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/uncore: Apply the unit control RB tree to PCI uncore
  units (bsc#1230119).
- commit e202e9f
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/uncore: Apply the unit control RB tree to MSR uncore
  units (bsc#1230119).
- commit 8a1e34d
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/uncore: Apply the unit control RB tree to MMIO uncore
  units (bsc#1230119).
- commit 956825c
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/uncore: Retrieve the unit ID from the unit control
  RB tree (bsc#1230119).
- commit 81ab2f7
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/uncore: Support per PMU cpumask (bsc#1230119).
- commit e0b1be5
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/uncore: Save the unit control address of all units
  (bsc#1230119).
- commit 3062251
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/intel/uncore: Support HBM and CXL PMON counters
  (bsc#1230119).
- commit a4c2665
* Wed Sep  4 2024 lhenriques@suse.de
- fuse: update stats for pages in dropped aux writeback list
  (bsc#1230125).
- fuse: fix memory leak in fuse_create_open (bsc#1230124).
- fuse: use unsigned type for getxattr/listxattr size truncation
  (bsc#1230123).
- commit c8902bc
* Wed Sep  4 2024 mwilck@suse.com
- Split kabi part of dm_blk_ioctl-implement-path-failover-for-SG_IO.patch
- kabi: dm_blk_ioctl: implement path failover for SG_IO
  (bsc#1183045, bsc#1216776).
- Refresh
  patches.suse/dm_blk_ioctl-implement-path-failover-for-SG_IO.patch.
- commit 9a2ecb0
* Wed Sep  4 2024 neilb@suse.de
- NFSD: Fix frame size warning in svc_export_parse() (git-fixes).
- NFSD: Rewrite synopsis of nfsd_percpu_counters_init()
  (git-fixes).
- commit 3ab58b8
* Wed Sep  4 2024 krisman@suse.de
- kABI: Split kABI out of io_uring/kbuf: protect io_buffer_list teardown with a
  reference
  When introducing this patch, I merged the kABI patch with the actual
  backport, which is not recommended.  Split it up, such that the backport
  is similar to the upstream patch and handle the kABI issue exactly the
  same way, but through a separate kABI patch.
- commit 08e57d6
* Tue Sep  3 2024 oneukum@suse.com
- usb: typec: ucsi: Wait 20ms before reading CCI after a reset
  (git-fixes).
- commit 26d16be
* Mon Sep  2 2024 msuchanek@suse.de
- Update config files (jsc#PED-10537).
  ppc64le: NR_CPUS=8192
  This alings with x86.
- commit fce54e8
* Mon Sep  2 2024 lhenriques@suse.de
- ceph: periodically flush the cap releases (bsc#1230056).
- commit e22b6e0
* Mon Sep  2 2024 denis.kirjanov@suse.com
- Bluetooth: Fix usage of __hci_cmd_sync_status (git-fixes).
- commit 1bec58d
* Mon Sep  2 2024 denis.kirjanov@suse.com
- Bluetooth: L2CAP: Fix deadlock (git-fixes).
- commit 13aba13
* Mon Sep  2 2024 sjaeckel@suse.de
- net/sched: act_ct: fix skb leak and crash on ooo frags
  (CVE-2023-52610 bsc#1221610).
- commit 7a32533
* Mon Sep  2 2024 denis.kirjanov@suse.com
- bluetooth/l2cap: sync sock recv cb and release (bsc#1228576
  CVE-2024-41062).
- commit 6553526
* Mon Sep  2 2024 osalvador@suse.de
- mm: prevent derefencing NULL ptr in pfn_section_valid()
  (git-fixes).
- commit 35f619d
* Mon Sep  2 2024 osalvador@suse.de
- mm, kmsan: fix infinite recursion due to RCU critical section
  (git-fixes).
- commit 16ad73a
* Mon Sep  2 2024 osalvador@suse.de
- mm/sparsemem: fix race in accessing memory_section->usage
  (bsc#1221326 CVE-2023-52489).
- commit 6aa8957
* Mon Sep  2 2024 ohering@suse.de
- net: mana: Fix race of mana_hwc_post_rx_wqe and new hwc response (git-fixes).
- commit 4dc1da1
* Sun Sep  1 2024 ailiop@suse.com
- xfs: Fix missing interval for missing_owner in xfs fsmap
  (git-fixes).
- commit 5448ab5
* Sun Sep  1 2024 ailiop@suse.com
- xfs: use XFS_BUF_DADDR_NULL for daddrs in getfsmap code
  (git-fixes).
- commit 288ad9b
* Sun Sep  1 2024 ailiop@suse.com
- xfs: Fix the owner setting issue for rmap query in xfs fsmap
  (git-fixes).
- commit 49b5eec
* Sun Sep  1 2024 tiwai@suse.de
- usb: cdnsp: fix for Link TRB with TC (git-fixes).
- usb: dwc3: st: add missing depopulate in probe error path
  (git-fixes).
- usb: dwc3: st: fix probed platform device ref count on probe
  error path (git-fixes).
- usb: core: sysfs: Unmerge @usb3_hardware_lpm_attr_group in
  remove_power_attributes() (git-fixes).
- usb: typec: fsa4480: Relax CHIP_ID check (git-fixes).
- usb: dwc3: omap: add missing depopulate in probe error path
  (git-fixes).
- usb: cdnsp: fix incorrect index in cdnsp_get_hw_deq function
  (git-fixes).
- soc: qcom: pmic_glink: Actually communicate when remote goes
  down (git-fixes).
- soc: qcom: cmd-db: Map shared memory as WC, not WB (git-fixes).
- commit 7121142
* Sat Aug 31 2024 tiwai@suse.de
- dmaengine: dw: Add memory bus width verification (git-fixes).
- dmaengine: dw: Add peripheral bus width verification
  (git-fixes).
- soundwire: stream: fix programming slave ports for non-continous
  port maps (git-fixes).
- commit b7e9784
* Fri Aug 30 2024 mkoutny@suse.com
- Update
  patches.suse/0001-net-rds-fix-possible-cp-null-dereference.patch
  (git-fixes CVE-2024-35902 bsc#1224496).
- Update
  patches.suse/ASoC-TAS2781-Fix-tasdev_load_calibrated_data.patch
  (git-fixes CVE-2024-42278 bsc#1229403).
- Update
  patches.suse/ASoC-amd-Adjust-error-handling-in-case-of-absent-cod.patch
  (git-fixes CVE-2024-43818 bsc#1229296).
- Update
  patches.suse/ASoC-fsl-fsl_qmc_audio-Check-devm_kasprintf-returned.patch
  (git-fixes CVE-2024-42298 bsc#1229369).
- Update
  patches.suse/Bluetooth-MGMT-Add-error-handling-to-pair_device.patch
  (git-fixes CVE-2024-43884 bsc#1229739).
- Update
  patches.suse/KVM-Always-flush-async-PF-workqueue-when-vCPU-is-bei.patch
  (git-fixes CVE-2024-26976 bsc#1223635).
- Update
  patches.suse/PCI-DPC-Fix-use-after-free-on-concurrent-DPC-and-hot.patch
  (git-fixes CVE-2024-42302 bsc#1229366).
- Update
  patches.suse/PCI-endpoint-Clean-up-error-handling-in-vpci_scan_bu.patch
  (git-fixes CVE-2024-43875 bsc#1229486).
- Update
  patches.suse/PCI-endpoint-pci-epf-test-Make-use-of-cached-epc_fea.patch
  (git-fixes CVE-2024-43824 bsc#1229320).
- Update
  patches.suse/PCI-keystone-Fix-NULL-pointer-dereference-in-case-of.patch
  (git-fixes CVE-2024-43823 bsc#1229303).
- Update
  patches.suse/PCI-rcar-Demote-WARN-to-dev_warn_ratelimited-in-rcar.patch
  (git-fixes CVE-2024-43876 bsc#1229485).
- Update
  patches.suse/RDMA-hns-Fix-soft-lockup-under-heavy-CEQE-load.patch
  (git-fixes CVE-2024-43872 bsc#1229489).
- Update
  patches.suse/RDMA-iwcm-Fix-a-use-after-free-related-to-destroying.patch
  (git-fixes CVE-2024-42285 bsc#1229381).
- Update
  patches.suse/Revert-ALSA-firewire-lib-operate-for-period-elapse-e.patch
  (bsc#1208783 CVE-2024-42274 bsc#1229417).
- Update
  patches.suse/SUNRPC-add-a-missing-rpc_stat-for-TCP-TLS.patch
  (git-fixes CVE-2024-36907 bsc#1225751).
- Update
  patches.suse/bpf-arm64-Fix-trampoline-for-BPF_TRAMP_F_CALL_ORIG.patch
  (git-fixes CVE-2024-43840 bsc#1229344).
- Update
  patches.suse/btrfs-fix-double-inode-unlock-for-direct-IO-sync-wri.patch
  (git-fixes CVE-2024-43885 bsc#1229747).
- Update
  patches.suse/btrfs-fix-extent-map-use-after-free-when-adding-page.patch
  (git-fixes CVE-2024-42314 bsc#1229355).
- Update
  patches.suse/cgroup-cpuset-Prevent-UAF-in-proc_cpuset_show.patch
  (bsc#1228801 CVE-2024-43853 bsc#1229292).
- Update
  patches.suse/crypto-ccp-Fix-null-pointer-dereference-in-__sev_snp.patch
  (git-fixes CVE-2024-43874 bsc#1229487).
- Update
  patches.suse/devres-Fix-memory-leakage-caused-by-driver-API-devm_.patch
  (git-fixes CVE-2024-43871 bsc#1229490).
- Update
  patches.suse/dma-fix-call-order-in-dmam_free_coherent.patch
  (git-fixes CVE-2024-43856 bsc#1229346).
- Update
  patches.suse/drm-admgpu-fix-dereferencing-null-pointer-context.patch
  (stable-fixes CVE-2024-43906 bsc#1229785).
- Update
  patches.suse/drm-amd-display-Add-NULL-check-for-afb-before-derefe.patch
  (stable-fixes CVE-2024-43903 bsc#1229781).
- Update
  patches.suse/drm-amd-display-Add-null-checker-before-passing-vari.patch
  (stable-fixes CVE-2024-43902 bsc#1229767).
- Update
  patches.suse/drm-amd-display-Skip-Recompute-DSC-Params-if-no-Stre.patch
  (stable-fixes CVE-2024-43895 bsc#1229755).
- Update
  patches.suse/drm-amd-pm-Fix-the-null-pointer-dereference-for-vega.patch
  (stable-fixes CVE-2024-43905 bsc#1229784).
- Update
  patches.suse/drm-amdgpu-Fix-the-null-pointer-dereference-to-ras_m.patch
  (stable-fixes CVE-2024-43908 bsc#1229788).
- Update
  patches.suse/drm-amdgpu-pm-Fix-the-null-pointer-dereference-for-s.patch
  (stable-fixes CVE-2024-43909 bsc#1229789).
- Update
  patches.suse/drm-amdgpu-pm-Fix-the-null-pointer-dereference-in-ap.patch
  (stable-fixes CVE-2024-43907 bsc#1229787).
- Update
  patches.suse/drm-client-fix-null-pointer-dereference-in-drm_clien.patch
  (git-fixes CVE-2024-43894 bsc#1229746).
- Update
  patches.suse/drm-gma500-fix-null-pointer-dereference-in-cdv_intel.patch
  (git-fixes CVE-2024-42310 bsc#1229358).
- Update
  patches.suse/drm-gma500-fix-null-pointer-dereference-in-psb_intel.patch
  (git-fixes CVE-2024-42309 bsc#1229359).
- Update
  patches.suse/drm-nouveau-prime-fix-refcount-underflow.patch
  (git-fixes CVE-2024-43867 bsc#1229493).
- Update patches.suse/drm-qxl-Add-check-for-drm_cvt_mode.patch
  (git-fixes CVE-2024-43829 bsc#1229341).
- Update
  patches.suse/drm-vmwgfx-Fix-a-deadlock-in-dma-buf-fence-polling.patch
  (git-fixes CVE-2024-43863 bsc#1229497).
- Update
  patches.suse/exfat-fix-potential-deadlock-on-__exfat_get_dentry_set.patch
  (git-fixes CVE-2024-42315 bsc#1229354).
- Update
  patches.suse/gpio-prevent-potential-speculation-leaks-in-gpio_dev.patch
  (stable-fixes CVE-2024-44931 bsc#1229837).
- Update
  patches.suse/hfs-fix-to-initialize-fields-of-hfs_inode_info-after-hfs_alloc_inode.patch
  (git-fixes CVE-2024-42311 bsc#1229413).
- Update
  patches.suse/iio-Fix-the-sorting-functionality-in-iio_gts_build_a.patch
  (git-fixes CVE-2024-43825 bsc#1229298).
- Update
  patches.suse/jfs-Fix-array-index-out-of-bounds-in-diFree.patch
  (git-fixes CVE-2024-43858 bsc#1229414).
- Update
  patches.suse/jfs-Fix-shift-out-of-bounds-in-dbDiscardAG.patch
  (git-fixes CVE-2024-44938 bsc#1229792).
- Update
  patches.suse/jfs-fix-null-ptr-deref-in-dtInsertEntry.patch
  (git-fixes CVE-2024-44939 bsc#1229820).
- Update
  patches.suse/kobject_uevent-Fix-OOB-access-within-zap_modalias_en.patch
  (git-fixes CVE-2024-42292 bsc#1229373).
- Update
  patches.suse/kvm-s390-Reject-memory-region-operations-for-ucontrol-VMs.patch
  (git-fixes bsc#1229168 CVE-2024-43819 bsc#1229290).
- Update
  patches.suse/leds-trigger-Unregister-sysfs-attributes-before-call.patch
  (git-fixes CVE-2024-43830 bsc#1229305).
- Update
  patches.suse/lib-objagg-Fix-general-protection-fault.patch
  (git-fixes CVE-2024-43846 bsc#1229360).
- Update
  patches.suse/libbpf-Use-OPTS_SET-macro-in-bpf_xdp_query.patch
  (git-fixes CVE-2024-27050 bsc#1223767).
- Update
  patches.suse/mISDN-Fix-a-use-after-free-in-hfcmulti_tx.patch
  (git-fixes CVE-2024-42280 bsc#1229388).
- Update
  patches.suse/mailbox-mtk-cmdq-Move-devm_mbox_controller_register-.patch
  (git-fixes CVE-2024-42319 bsc#1229350).
- Update
  patches.suse/md-raid5-fix-deadlock-that-raid5d-wait-for-itself-to-clear-MD_SB_CHANGE_PENDING-151f.patch
  (git-fixes CVE-2024-39476 bsc#1227437).
- Update
  patches.suse/media-imx-pxp-Fix-ERR_PTR-dereference-in-pxp_probe.patch
  (git-fixes CVE-2024-42303 bsc#1229365).
- Update
  patches.suse/media-pci-ivtv-Add-check-for-DMA-map-result.patch
  (git-fixes CVE-2024-43877 bsc#1229484).
- Update
  patches.suse/media-v4l-async-Fix-NULL-pointer-dereference-in-addi.patch
  (git-fixes CVE-2024-43833 bsc#1229299).
- Update
  patches.suse/media-venus-fix-use-after-free-in-vdec_close.patch
  (git-fixes CVE-2024-42313 bsc#1229356).
- Update
  patches.suse/media-xc2028-avoid-use-after-free-in-load_firmware_c.patch
  (stable-fixes CVE-2024-43900 bsc#1229756).
- Update
  patches.suse/memcg-protect-concurrent-access-to-mem_cgroup_idr.patch
  (git-fixes CVE-2024-43892 bsc#1229761).
- Update
  patches.suse/net-drop-bad-gso-csum_start-and-offset-in-virtio_net.patch
  (git-fixes CVE-2024-43897 bsc#1229752).
- Update
  patches.suse/net-iucv-fix-use-after-free-in-iucv_sock_close.patch
  (bsc#1228973 CVE-2024-42271 bsc#1229400).
- Update patches.suse/net-missing-check-virtio.patch (git-fixes
  CVE-2024-43817 bsc#1229312).
- Update
  patches.suse/net-usb-qmi_wwan-fix-memory-leak-for-not-ip-packets.patch
  (git-fixes CVE-2024-43861 bsc#1229500).
- Update
  patches.suse/nfs-pass-explicit-offset-count-to-trace-events.patch
  (git-fixes CVE-2024-43826 bsc#1229294).
- Update
  patches.suse/nvme-pci-add-missing-condition-check-for-existence-o.patch
  (git-fixes CVE-2024-42276 bsc#1229410).
- Update
  patches.suse/padata-Fix-possible-divide-by-0-panic-in-padata_mt_h.patch
  (git-fixes CVE-2024-43889 bsc#1229743).
- Update
  patches.suse/remoteproc-imx_rproc-Skip-over-memory-region-when-no.patch
  (git-fixes CVE-2024-43860 bsc#1229319).
- Update
  patches.suse/s390-dasd-fix-error-checks-in-dasd_copy_pair_store.patch
  (git-fixes bsc#1229173 CVE-2024-42320 bsc#1229349).
- Update
  patches.suse/scsi-lpfc-Revise-lpfc_prep_embed_io-routine-with-pro.patch
  (bsc#1228857 CVE-2024-43816 bsc#1229318).
- Update
  patches.suse/scsi-qla2xxx-Complete-command-early-within-lock.patch
  (bsc#1228850 CVE-2024-42287 bsc#1229392).
- Update
  patches.suse/scsi-qla2xxx-During-vport-delete-send-async-logout-e.patch
  (bsc#1228850 CVE-2024-42289 bsc#1229399).
- Update
  patches.suse/scsi-qla2xxx-Fix-for-possible-memory-corruption.patch
  (bsc#1228850 CVE-2024-42288 bsc#1229398).
- Update
  patches.suse/scsi-qla2xxx-validate-nvme_local_port-correctly.patch
  (bsc#1228850 CVE-2024-42286 bsc#1229395).
- Update
  patches.suse/serial-core-check-uartclk-for-zero-to-avoid-divide-b.patch
  (stable-fixes CVE-2024-43893 bsc#1229759).
- Update
  patches.suse/soc-qcom-pdr-protect-locator_addr-with-the-main-mute.patch
  (git-fixes CVE-2024-43849 bsc#1229307).
- Update
  patches.suse/soc-xilinx-rename-cpu_number1-to-dummy_cpu_number.patch
  (git-fixes CVE-2024-43851 bsc#1229313).
- Update
  patches.suse/spi-microchip-core-ensure-TX-and-RX-FIFOs-are-empty-.patch
  (git-fixes CVE-2024-42279 bsc#1229390).
- Update
  patches.suse/usb-vhci-hcd-Do-not-drop-references-before-new-refer.patch
  (stable-fixes CVE-2024-43883 bsc#1229707).
- Update
  patches.suse/vhost-vsock-always-initialize-seqpacket_allow.patch
  (git-fixes CVE-2024-43873 bsc#1229488).
- Update
  patches.suse/wifi-ath12k-change-DMA-direction-while-mapping-reinj.patch
  (git-fixes CVE-2024-43881 bsc#1229480).
- Update
  patches.suse/wifi-ath12k-fix-invalid-memory-access-while-processi.patch
  (git-fixes CVE-2024-43847 bsc#1229291).
- Update
  patches.suse/wifi-cfg80211-handle-2x996-RU-allocation-in-cfg80211.patch
  (git-fixes CVE-2024-43879 bsc#1229482).
- Update
  patches.suse/wifi-nl80211-disallow-setting-special-AP-channel-wid.patch
  (stable-fixes CVE-2024-43912 bsc#1229830).
- Update
  patches.suse/wifi-rtw89-Fix-array-index-mistake-in-rtw89_sta_info.patch
  (git-fixes CVE-2024-43842 bsc#1229317).
- Update
  patches.suse/wifi-virt_wifi-avoid-reporting-connection-success-wi.patch
  (git-fixes CVE-2024-43841 bsc#1229304).
- commit 140ec33
* Fri Aug 30 2024 vkarasulli@suse.de
- iommu/amd: Convert comma to semicolon (git-fixes).
- commit 2714d8b
* Fri Aug 30 2024 lduncan@suse.com
- scsi: lpfc: Fix a possible null pointer dereference (bsc#1229315
  CVE-2024-43821).
- commit eb73e94
* Fri Aug 30 2024 vkarasulli@suse.de
- iommu/vt-d: Fix identity map bounds in si_domain_init()
  (git-fixes).
- commit b4d27e5
* Fri Aug 30 2024 vkarasulli@suse.de
- iommufd/device: Fix hwpt at err_unresv in
  iommufd_device_do_replace() (git-fixes).
- commit bbc9a65
* Fri Aug 30 2024 lhenriques@suse.de
- virtiofs: forbid newlines in tags (bsc#1229940).
- commit 61514ce
* Fri Aug 30 2024 petr.pavlu@suse.com
- trace/pid_list: Change gfp flags in pid_list_fill_irq()
  (git-fixes).
- commit 88d1dac
* Fri Aug 30 2024 ailiop@suse.com
- evm: don't copy up 'security.evm' xattr (git-fixes).
- commit d3bb5af
* Fri Aug 30 2024 ailiop@suse.com
- afs: fix __afs_break_callback() / afs_drop_open_mmap() race
  (git-fixes).
- commit 150e615
* Fri Aug 30 2024 ailiop@suse.com
- jfs: define xtree root and page independently (git-fixes).
- commit fc62e49
* Fri Aug 30 2024 ailiop@suse.com
- kernfs: fix false-positive WARN(nr_mmapped) in
  kernfs_drain_open_files (git-fixes).
- commit 7fa46d1
* Fri Aug 30 2024 ailiop@suse.com
- gfs2: setattr_chown: Add missing initialization (git-fixes).
- commit 9b6ef3b
* Fri Aug 30 2024 tiwai@suse.de
- nfc: pn533: Add poll mod list filling check (git-fixes).
- wifi: wfx: repair open network AP mode (git-fixes).
- wifi: iwlwifi: fw: fix wgds rev 3 exact size (git-fixes).
- wifi: mwifiex: duplicate static structs used in driver instances
  (git-fixes).
- Input: i8042 - use new forcenorestore quirk to replace old
  buggy quirk combination (stable-fixes).
- Input: i8042 - add forcenorestore quirk to leave controller
  untouched even on s3 (stable-fixes).
- platform/surface: aggregator: Fix warning when controller is
  destroyed in probe (git-fixes).
- thunderbolt: Mark XDomain as unplugged when router is removed
  (stable-fixes).
- Input: MT - limit max slots (stable-fixes).
- usb: dwc3: core: Skip setting event buffers for host only
  controllers (stable-fixes).
- platform/x86: lg-laptop: fix %%s null argument warning
  (stable-fixes).
- rtc: nct3018y: fix possible NULL dereference (stable-fixes).
- usb: gadget: fsl: Increase size of name buffer for endpoints
  (stable-fixes).
- media: drivers/media/dvb-core: copy user arrays safely
  (stable-fixes).
- media: pci: cx23885: check cx23885_vdev_init() return
  (stable-fixes).
- memory: stm32-fmc2-ebi: check regmap_read return value
  (stable-fixes).
- memory: tegra: Skip SID programming if SID registers aren't set
  (stable-fixes).
- Revert "usb: gadget: uvc: cleanup request when not in correct
  state" (stable-fixes).
- usb: gadget: uvc: cleanup request when not in correct state
  (stable-fixes).
- staging: ks7010: disable bh on tx_dev_lock (stable-fixes).
- staging: iio: resolver: ad2s1210: fix use before initialization
  (stable-fixes).
- ssb: Fix division by zero issue in ssb_calc_clock_rate
  (stable-fixes).
- commit b84d799
* Fri Aug 30 2024 tiwai@suse.de
- drm/vmwgfx: Fix prime with external buffers (git-fixes).
- drm/i915/dsi: Make Lenovo Yoga Tab 3 X90F DMI match less strict
  (git-fixes).
- drm/amd/display: avoid using null object of framebuffer
  (git-fixes).
- Bluetooth: hci_core: Fix not handling hibernation actions
  (git-fixes).
- drm/amdgpu: Validate TA binary size (stable-fixes).
- drm/msm/dpu: take plane rotation into account for wide planes
  (git-fixes).
- drm/msm/dpu: move dpu_encoder's connector assignment to
  atomic_enable() (git-fixes).
- char: xillybus: Refine workqueue handling (git-fixes).
- char: xillybus: Don't destroy workqueue from work item running
  on it (stable-fixes).
- drm/amdgpu: Actually check flags for all context ops
  (stable-fixes).
- drm/amdgpu/jpeg4: properly set atomics vmid field
  (stable-fixes).
- drm/amdgpu/jpeg2: properly set atomics vmid field
  (stable-fixes).
- drm/amd/display: fix s2idle entry for DCN3.5+ (stable-fixes).
- drm/amdgpu: fix dereference null return value for the function
  amdgpu_vm_pt_parent (stable-fixes).
- hwmon: (ltc2992) Fix memory leak in ltc2992_parse_dt()
  (git-fixes).
- firmware: cirrus: cs_dsp: Initialize debugfs_root to invalid
  (stable-fixes).
- drm/msm/dpu: capture snapshot on the first commit_done timeout
  (stable-fixes).
- drm/msm/dpu: split dpu_encoder_wait_for_event into two functions
  (stable-fixes).
- drm/lima: set gp bus_stop bit before hard reset (stable-fixes).
- drm/panel: nt36523: Set 120Hz fps for xiaomi,elish panels
  (stable-fixes).
- gpio: sysfs: extend the critical section for unregistering
  sysfs devices (stable-fixes).
- Bluetooth: bnep: Fix out-of-bound access (stable-fixes).
- hwmon: (pc87360) Bounds check data->innr usage (stable-fixes).
- ASoC: SOF: ipc4: check return value of snd_sof_ipc_msg_data
  (stable-fixes).
- drm/msm/dpu: drop MSM_ENC_VBLANK support (stable-fixes).
- drm/msm/dpu: use drmm-managed allocation for dpu_encoder_phys
  (stable-fixes).
- drm/msm/mdss: Rename path references to mdp_path (stable-fixes).
- drm/msm/mdss: switch mdss to use devm_of_icc_get()
  (stable-fixes).
- drm/msm/dpu: try multirect based on mdp clock limits
  (stable-fixes).
- drm/msm: Reduce fallout of fence signaling vs reclaim hangs
  (stable-fixes).
- drm/rockchip: vop2: clear afbc en and transform bit for cluster
  window at linear mode (stable-fixes).
- Bluetooth: hci_conn: Check non NULL function before calling
  for HFP offload (stable-fixes).
- i2c: stm32f7: Add atomic_xfer method to driver (stable-fixes).
- i2c: riic: avoid potential division by zero (stable-fixes).
- i3c: mipi-i3c-hci: Do not unmap region not mapped for transfer
  (stable-fixes).
- i3c: mipi-i3c-hci: Remove BUG() when Ring Abort request times
  out (stable-fixes).
- ASoC: SOF: Intel: hda-dsp: Make sure that no irq handler is
  pending before suspend (stable-fixes).
- ASoC: cs35l45: Checks index of cs35l45_irqs[] (stable-fixes).
- clk: visconti: Add bounds-checking coverage for struct
  visconti_pll_provider (stable-fixes).
- hwmon: (ltc2992) Avoid division by zero (stable-fixes).
- commit 1b92ddd
* Thu Aug 29 2024 petr.pavlu@suse.com
- jump_label: Fix the fix, brown paper bags galore (git-fixes).
- commit 89b2827
* Thu Aug 29 2024 petr.pavlu@suse.com
- jump_label: Simplify and clarify
  static_key_fast_inc_cpus_locked() (git-fixes).
- commit 954eaa3
* Thu Aug 29 2024 petr.pavlu@suse.com
- jump_label: Clarify condition in
  static_key_fast_inc_not_disabled() (git-fixes).
- commit eb457dc
* Thu Aug 29 2024 petr.pavlu@suse.com
- jump_label: Fix concurrency issues in static_key_slow_dec()
  (git-fixes).
- commit 6e92a06
* Thu Aug 29 2024 petr.pavlu@suse.com
- tracing: Return from tracing_buffers_read() if the file has
  been closed (bsc#1229136 git-fixes).
- commit 8dc8510
* Thu Aug 29 2024 petr.pavlu@suse.com
- kprobes: Fix to check symbol prefixes correctly (git-fixes).
- commit e8b168b
* Thu Aug 29 2024 petr.pavlu@suse.com
- kprobes: Prohibit probing on CFI preamble symbol (git-fixes).
- commit 2f9e2b1
* Thu Aug 29 2024 petr.pavlu@suse.com
- bpf: kprobe: remove unused declaring of bpf_kprobe_override
  (git-fixes).
- commit 4045c94
* Thu Aug 29 2024 tiwai@suse.de
- wifi: mac80211: fix NULL dereference at band check in starting
  tx ba session (CVE-2024-43911 bsc#1229827).
- commit 0892b94
* Thu Aug 29 2024 andrea.porta@suse.com
- syscalls: fix compat_sys_io_pgetevents_time64 usage (git-fixes).
- commit b90dd07
* Thu Aug 29 2024 vkarasulli@suse.de
- iommu: sprd: Avoid NULL deref in sprd_iommu_hw_en
  (CVE-2024-42277 bsc#1229409).
- commit ede2511
* Wed Aug 28 2024 dsterba@suse.com
- Update references patches.suse/drm-amd-display-Add-null-checks-for-stream-and-plane.patch (CVE-2024-43904 bsc#1229768 stable-fixes)
- commit aaa26ef
* Wed Aug 28 2024 tbogendoerfer@suse.de
- kabi: lib: objagg: Put back removed metod in struct objagg_ops
  (CVE-2024-43880 bsc#1229481).
- commit 9566f2d
* Wed Aug 28 2024 denis.kirjanov@suse.com
- net/sched: initialize noop_qdisc owner (git-fixes).
- commit 66e8d18
* Wed Aug 28 2024 pjakobsson@suse.de
- drm/amd/display: Fix null pointer deref in dcn20_resource.c (CVE-2024-43899 bsc#1229754).
- commit 1811990
* Wed Aug 28 2024 mhocko@suse.com
- exec: Fix ToCToU between perm check and set-uid/gid usage
  (CVE-2024-43882 bsc#1229503).
- commit 7a21b9d
* Wed Aug 28 2024 tiwai@suse.de
- ALSA: hda/realtek: support HP Pavilion Aero 13-bg0xxx Mute LED
  (stable-fixes).
- ALSA: hda/realtek: Fix the speaker output on Samsung Galaxy
  Book3 Ultra (stable-fixes).
- ASoC: allow module autoloading for table board_ids
  (stable-fixes).
- ASoC: allow module autoloading for table db1200_pids
  (stable-fixes).
- ASoC: mediatek: mt8188: Mark AFE_DAC_CON0 register as volatile
  (stable-fixes).
- ASoC: SOF: mediatek: Add missing board compatible
  (stable-fixes).
- ALSA: hda/realtek - FIxed ALC285 headphone no sound
  (stable-fixes).
- ALSA: hda/realtek - Fixed ALC256 headphone no sound
  (stable-fixes).
- ALSA: hda/realtek: Enable mute/micmute LEDs on HP Laptop
  14-ey0xxx (stable-fixes).
- ALSA: hda/realtek: Implement sound init sequence for Samsung
  Galaxy Book3 Pro 360 (stable-fixes).
- commit 97adcb2
* Wed Aug 28 2024 tbogendoerfer@suse.de
- ip6_tunnel: Fix broken GRO (bsc#1229444).
- net/mlx5: Always drain health in shutdown callback
  (CVE-2024-43866 bsc#1229495).
- mlxsw: spectrum_acl_erp: Fix object nesting warning
  (CVE-2024-43880 bsc#1229481).
- commit d9a404d
* Wed Aug 28 2024 tiwai@suse.de
- pinctrl: rockchip: correct RK3328 iomux width flag for GPIO2-B
  pins (git-fixes).
- pinctrl: starfive: jh7110: Correct the level trigger
  configuration of iev register (git-fixes).
- pinctrl: mediatek: common-v2: Fix broken bias-disable for
  PULL_PU_PD_RSEL_TYPE (git-fixes).
- pinctrl: single: fix potential NULL dereference in
  pcs_get_function() (git-fixes).
- ASoC: SOF: amd: Fix for acp init sequence (git-fixes).
- ASoC: amd: acp: fix module autoloading (git-fixes).
- ALSA: seq: Skip event type filtering for UMP events (git-fixes).
- commit 3fa4a0b
* Tue Aug 27 2024 tbogendoerfer@suse.de
- ice: Fix NULL pointer access, if PF doesn't support SRIOV_LAG
  (bsc#1228737).
- commit f1a9730
* Tue Aug 27 2024 vkarasulli@suse.de
- kABI: vfio: struct virqfd kABI workaround (CVE-2024-26812
  bsc#1222808).
- commit ae735c0
* Tue Aug 27 2024 denis.kirjanov@suse.com
- net/sched: Fix mirred deadlock on device recursion
  (CVE-2024-27010 bsc#1223720).
- commit 8c34ee8
* Tue Aug 27 2024 dsterba@suse.com
- Fix reference in patches.suse/netfilter-tproxy-bail-out-if-IP-has-been-disabled-on.patch (CVE-2024-36270 bsc#1226798)
- commit 052d917
* Tue Aug 27 2024 denis.kirjanov@suse.com
- net: qdisc: preserve kabi for struct QDisc (CVE-2024-27010 bsc#1223720).
- commit e31d466
* Tue Aug 27 2024 vbabka@suse.cz
- mm/userfaultfd: reset ptes when close() for wr-protected ones
  (CVE-2024-36881 bsc#1225718).
- commit 2267d46
* Tue Aug 27 2024 vbabka@suse.cz
- mm/mglru: fix div-by-zero in vmpressure_calc_level()
  (CVE-2024-42316 bsc#1229353).
- commit ba00671
* Tue Aug 27 2024 colyli@suse.de
- md/raid1: set max_sectors during early return from
  choose_slow_rdev() (git-fixes).
- md/raid5: recheck if reshape has finished with device_lock held
  (git-fixes).
- md: Don't wait for MD_RECOVERY_NEEDED for HOT_REMOVE_DISK ioctl
  (git-fixes).
- md/raid5: fix spares errors about rcu usage (git-fixes).
- md/md-bitmap: fix writing non bitmap pages (git-fixes).
- md: fix deadlock between mddev_suspend and flush bio
  (bsc#1229342, CVE-2024-43855).
- md: change the return value type of md_write_start to void
  (git-fixes).
- md: do not delete safemode_timer in mddev_suspend (git-fixes).
- md: don't account sync_io if iostats of the disk is disabled
  (git-fixes).
- md: add check for sleepers in md_wakeup_thread() (git-fixes).
- md/raid5: fix deadlock that raid5d() wait for itself to clear
  MD_SB_CHANGE_PENDING (git-fixes).
- md: add a mddev_add_trace_msg helper (git-fixes).
- Revert "Revert "md/raid5: Wait for MD_SB_CHANGE_PENDING in
  raid5d"" (git-fixes).
- md: fix a suspicious RCU usage warning (git-fixes).
- md/raid1: support read error check (git-fixes).
- commit f1ec0d4
* Tue Aug 27 2024 colyli@suse.de
- md: factor out a helper exceed_read_errors() to check
  read_errors (git-fixes).
- Refresh for the above change,
  patches.suse/md-display-timeout-error.patch.
  patches.suse/md-raid1-10-add-a-helper-raid1_check_read_range-f298.patch.
- commit 035e3f0
* Tue Aug 27 2024 colyli@suse.de
- Revert "md/raid5: Wait for MD_SB_CHANGE_PENDING in raid5d"
  (git-fixes).
- commit 5cc0fdd
* Mon Aug 26 2024 dsterba@suse.com
- net/mlx5e: Fix CT entry update leaks of modify header context (CVE-2024-43864 bsc#1229496)
- commit 316a4fe
* Mon Aug 26 2024 msuchanek@suse.de
- rpm/check-for-config-changes: Exclude ARCH_USING_PATCHABLE_FUNCTION_ENTRY
  gcc version dependent, at least on ppc
- commit 16da158
* Mon Aug 26 2024 mkoutny@suse.com
- af_unix: Fix data races in unix_release_sock/unix_stream_sendmsg
  (bsc#1226846 CVE-2024-38596).
- Update
  patches.suse/af_unix-Fix-data-races-around-sk-sk_shutdown.patch
  (git-fixes bsc#1226846).
- commit 7ceb0cd
* Mon Aug 26 2024 sjaeckel@suse.de
- ipv6: mcast: fix data-race in ipv6_mc_down / mld_ifc_work
  (CVE-2024-26631 bsc#1221630).
- commit 317a097
* Mon Aug 26 2024 dsterba@suse.com
- netfilter: nf_tables: unconditionally flush pending work before notifier (CVE-2024-42109 bsc#1228505)
- commit 7a6a06c
* Mon Aug 26 2024 dsterba@suse.com
- cxl/region: Avoid null pointer dereference in region lookup (CVE-2024-41084 bsc#1228472)
- commit fc1408b
* Mon Aug 26 2024 dsterba@suse.com
- cxl/region: Move cxl_dpa_to_region() work to the region driver (bsc#1228472)
- commit ac0e984
* Mon Aug 26 2024 dsterba@suse.com
- ipv6: fix possible race in __fib6_drop_pcpu_from() (CVE-2024-40905 bsc#1227761)
- commit 6fcd399
* Mon Aug 26 2024 dsterba@suse.com
- ipv6: sr: fix memleak in seg6_hmac_init_algo (CVE-2024-39489 bsc#1227623)
- commit c55beb2
* Mon Aug 26 2024 ptesarik@suse.com
- swiotlb: do not set total_used to 0 in
  swiotlb_create_debugfs_files() (git-fixes).
- swiotlb: fix swiotlb_bounce() to do partial sync's correctly
  (git-fixes).
- commit 99fe6bb
* Mon Aug 26 2024 bdas@suse.de
- x86/kaslr: Expose and use the end of the physical memory
  address space (bsc#1229443).
- commit 5b98c4e
* Mon Aug 26 2024 dsterba@suse.com
- tls: fix missing memory barrier in tls_init (CVE-2024-36489 bsc#1226874)
- commit 67db543
* Mon Aug 26 2024 vkarasulli@suse.de
- iommu: Add kABI workaround patch (bsc#1223742
  CVE-2024-27079).
- commit c4ebc76
* Mon Aug 26 2024 wqu@suse.com
- btrfs: copy dir permission and time when creating a stub
  subvolume (bsc#1228321).
- commit 46e95d1
* Sat Aug 24 2024 tiwai@suse.de
- nouveau/firmware: use dma non-coherent allocator (git-fixes).
- drm/amdgpu/sdma5.2: limit wptr workaround to sdma 5.2.1
  (git-fixes).
- drm/msm/dpu: cleanup FB if dpu_format_populate_layout fails
  (git-fixes).
- drm/msm/dp: reset the link phy params before link training
  (git-fixes).
- drm/msm/dp: fix the max supported bpp logic (git-fixes).
- drm/msm/dpu: don't play tricks with debug macros (git-fixes).
- mmc: mmc_test: Fix NULL dereference on allocation failure
  (git-fixes).
- mmc: dw_mmc: allow biu and ciu clocks to defer (git-fixes).
- mmc: mtk-sd: receive cmd8 data when hs400 tuning fail
  (git-fixes).
- commit ec72baf
* Fri Aug 23 2024 krisman@suse.de
- filelock: Fix fcntl/close race recovery compat path (bsc#1228427
  CVE-2024-41020).
- commit 2c615e8
* Fri Aug 23 2024 vkarasulli@suse.de
- vfio/pci: fix potential memory leak in vfio_intx_enable()
  (git-fixes).
- commit 45c2786
* Fri Aug 23 2024 vkarasulli@suse.de
- vfio: Introduce interface to flush virqfd inject workqueue
  (CVE-2024-26812 bsc#1222808).
- commit 0704da7
* Fri Aug 23 2024 vkarasulli@suse.de
- vfio/pci: Create persistent INTx handler (CVE-2024-26812
  bsc#1222808).
- commit c0eeff7
* Fri Aug 23 2024 mkubecek@suse.cz
- netfilter: nf_tables: discard table flag update with pending
  basechain deletion (CVE-2024-35897 bsc#1224510).
- netfilter: nf_tables: reject table flag and netdev basechain
  updates (CVE-2024-35897 bsc#1224510).
- commit bc3bca5
* Fri Aug 23 2024 mkubecek@suse.cz
- kabi: restore const specifier in flow_offload_route_init()
  (CVE-2024-27403 bsc#1224415).
- netfilter: nft_flow_offload: reset dst in route object after
  setting up flow (CVE-2024-27403 bsc#1224415).
- commit f1d28bc
* Fri Aug 23 2024 tiwai@suse.de
- Bluetooth: MGMT: Add error handling to pair_device()
  (git-fixes).
- Bluetooth: SMP: Fix assumption of Central always being Initiator
  (git-fixes).
- Bluetooth: hci_core: Fix LE quote calculation (git-fixes).
- commit 82ede4a
* Fri Aug 23 2024 sjaeckel@suse.de
- netfilter: nf_tables: fix memleak in map from abort path
  (CVE-2024-27011 bsc#1223803).
- commit df3e052
* Fri Aug 23 2024 jgross@suse.com
- KVM: Reject overly excessive IDs in KVM_CREATE_VCPU (git-fixes).
- commit acfc6dd
* Fri Aug 23 2024 jgross@suse.com
- KVM: arm64: Fix __pkvm_init_switch_pgd call ABI (git-fixes).
- commit ca5dde8
* Fri Aug 23 2024 jgross@suse.com
- KVM: Stop processing *all* memslots when "null" mmu_notifier
  handler is found (git-fixes).
- commit edcaf30
* Fri Aug 23 2024 jgross@suse.com
- virt: guest_memfd: fix reference leak on hwpoisoned page
  (git-fixes).
- commit 7ac89c3
* Fri Aug 23 2024 jgross@suse.com
- KVM: arm64: AArch32: Fix spurious trapping of conditional
  instructions (git-fixes).
- commit 6b4a32b
* Fri Aug 23 2024 jgross@suse.com
- KVM: arm64: Allow AArch32 PSTATE.M to be restored as System mode
  (git-fixes).
- commit d2c979d
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: Fix AArch32 register narrowing on userspace write
  (git-fixes).
- commit c002253
* Thu Aug 22 2024 jgross@suse.com
- KVM: fix kvm_mmu_memory_cache allocation warning (git-fixes).
- commit 9570c83
* Thu Aug 22 2024 jgross@suse.com
- KVM: Always flush async #PF workqueue when vCPU is being
  destroyed (git-fixes).
- commit bbeeae4
* Thu Aug 22 2024 vkarasulli@suse.de
- iommu: Add static iommu_ops->release_domain (bsc#1223742
  CVE-2024-27079).
- iommu/vt-d: Fix NULL domain on device release (bsc#1223742
  CVE-2024-27079).
- Refresh
  patches.suse/iommu-vt-d-Fix-WARN_ON-in-iommu-probe-path.patch.
- commit 5ddde3c
* Thu Aug 22 2024 jgross@suse.com
- KVM: Make KVM_MEM_GUEST_MEMFD mutually exclusive with
  KVM_MEM_READONLY (git-fixes).
- commit 7a71a2a
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: vgic-its: Test for valid IRQ in MOVALL handler
  (git-fixes).
- commit ebc54df
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: vgic-its: Test for valid IRQ in
  its_sync_lpi_pending_table() (git-fixes).
- commit 989930f
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: Add missing memory barriers when switching to
  pKVM's hyp pgd (git-fixes).
- commit 5599b84
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: vgic-v4: Restore pending state on host userspace
  write (git-fixes).
- commit ba9826d
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: vgic: Force vcpu vgic teardown on vcpu destroy
  (git-fixes).
- commit 26e04aa
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: vgic: Add a non-locking primitive for
  kvm_vgic_vcpu_destroy() (git-fixes).
- commit 686bc1c
* Thu Aug 22 2024 mkubecek@suse.cz
- netfilter: nft_limit: reject configurations that cause integer
  overflow (CVE-2024-26668 bsc#1222335).
- commit 8ea214b
* Thu Aug 22 2024 mkubecek@suse.cz
- netfilter: nf_tables: set dormant flag on hook register failure
  (CVE-2024-26835 bsc#1222967).
- commit 8f4d028
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: vgic: Simplify kvm_vgic_destroy() (git-fixes).
- commit 3a96863
* Thu Aug 22 2024 jgross@suse.com
- Revert "KVM: Prevent module exit until all VMs are freed"
  (git-fixes).
- commit c075225
* Thu Aug 22 2024 mkubecek@suse.cz
- netfilter: nft_chain_filter: handle NETDEV_UNREGISTER for
  inet/ingress basechain (CVE-2024-26808 bsc#1222634).
- commit 7f0379b
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: GICv4: Do not perform a map to a mapped vLPI
  (git-fixes).
- commit 919175d
* Thu Aug 22 2024 mkubecek@suse.cz
- netfilter: nft_set_pipapo: release elements in clone only from
  destroy path (CVE-2024-26809 bsc#1222633).
- commit d3a3287
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: vgic-v2: Use cpuid from userspace as vcpu_id
  (git-fixes).
- commit 7b3deae
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: timers: Correctly handle TGE flip with CNTPOFF_EL2
  (git-fixes).
- commit 48c0cad
* Thu Aug 22 2024 mkubecek@suse.cz
- netfilter: nf_tables: fix memleak when more than 255 elements
  expired (CVE-2023-52581 bsc#1220877).
- commit 26441fd
* Thu Aug 22 2024 jgross@suse.com
- KVM: Protect vcpu->pid dereference via debugfs with RCU
  (git-fixes).
- commit 55ae2a6
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: timers: Fix resource leaks in kvm_timer_hyp_init()
  (git-fixes).
- commit f80cefe
* Thu Aug 22 2024 shung-hsi.yu@suse.com
- bpf: Fix updating attached freplace prog in prog_array map
  (bsc#1229297 CVE-2024-43837).
- commit a9d7d77
* Thu Aug 22 2024 nik.borisov@suse.com
- dma-direct: Leak pages on dma_set_decrypted() failure (bsc#1224535 CVE-2024-35939).
- commit 7de8166
* Thu Aug 22 2024 tbogendoerfer@suse.de
- ice: Add a per-VF limit on number of FDIR filters
  (CVE-2024-42291 bsc#1229374).
- commit ee2b93b
* Thu Aug 22 2024 tbogendoerfer@suse.de
- net/mlx5: Fix missing lock on sync reset reload (CVE-2024-42268
  bsc#1229391).
- commit 268cdf6
* Thu Aug 22 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add a test to verify previous stacksafe() fix
  (bsc#1225903).
- bpf: Fix a kernel verifier crash in stacksafe() (bsc#1225903).
- commit dab2844
* Thu Aug 22 2024 dsterba@suse.com
- xdp: fix invalid wait context of page_pool_destroy() (CVE-2024-43834 bsc#1229314)
- commit 6348ec4
* Thu Aug 22 2024 jlee@suse.com
- clk: mediatek: mt7622-apmixedsys: Fix an error handling path
  in clk_mt8135_apmixed_probe() (bsc#1224711 CVE-2024-27433).
- commit 30e1ef1
* Thu Aug 22 2024 dsterba@suse.com
- netfilter: nfnetlink_queue: acquire rcu_read_lock() in instance_destroy_rcu() (CVE-2024-36286 bsc#1226801)
- commit 3278d5d
* Thu Aug 22 2024 dsterba@suse.com
- netfilter: tproxy: bail out if IP has been disabled on the device (CVE-2024-36270 1226798)
- commit 26814d6
* Thu Aug 22 2024 dsterba@suse.com
- netfilter: nf_conntrack_h323: Add protection for bmp length out of range (CVE-2024-26851 bsc#1223074)
- commit 6ad2cbe
* Wed Aug 21 2024 sjaeckel@suse.de
- net: bridge: mst: fix suspicious rcu usage in br_mst_set_state
  (CVE-2024-40920 bsc#1227781).
- net: bridge: mst: pass vlan group directly to
  br_mst_vlan_set_state (CVE-2024-40921 bsc#1227784).
- net: bridge: mst: fix vlan use-after-free (CVE-2024-36979
  bsc#1226604).
- commit 7beae73
* Wed Aug 21 2024 rgoldwyn@suse.com
- erofs: fix inconsistent per-file compression format (bsc#1220252, CVE-2024-26590).
- commit 4f99bd1
* Wed Aug 21 2024 jlee@suse.com
- perf: hisi: Fix use-after-free when register pmu fails
  (bsc#1225582 CVE-2023-52859).
- commit a50ce06
* Wed Aug 21 2024 pmladek@suse.com
- printk/panic: Allow cpu backtraces to be written into ringbuffer
  during panic (bsc#1225607).
- commit 1ebfff4
* Wed Aug 21 2024 jgross@suse.com
- net: drop bad gso csum_start and offset in virtio_net_hdr
  (git-fixes).
- commit 6d27b13
* Wed Aug 21 2024 shung-hsi.yu@suse.com
- selftests/bpf: Test for null-pointer-deref bugfix in
  resolve_prog_type() (bsc#1229297 CVE-2024-43837).
- bpf: Fix null pointer dereference in resolve_prog_type()
  for BPF_PROG_TYPE_EXT (bsc#1229297 CVE-2024-43837).
- commit 37e60d8
* Wed Aug 21 2024 shung-hsi.yu@suse.com
- bpf: simplify btf_get_prog_ctx_type() into
  btf_is_prog_ctx_type() (git-fixes).
- Refresh patches.suse/bpf-don-t-infer-PTR_TO_CTX-for-programs-with-unnamed.patch
- Refresh patches.suse/bpf-handle-bpf_user_pt_regs_t-typedef-explicitly-for.patch
- bpf: extract bpf_ctx_convert_map logic and make it more reusable
  (git-fixes).
- Refresh patches.suse/bpf-handle-bpf_user_pt_regs_t-typedef-explicitly-for.patch
- commit a1a0c24
* Wed Aug 21 2024 jgross@suse.com
- vhost: Release worker mutex during flushes (git-fixes).
- commit be0d4d9
* Wed Aug 21 2024 jgross@suse.com
- virtio: reenable config if freezing device failed (git-fixes).
- commit d96d64e
* Wed Aug 21 2024 neilb@suse.de
- kabi fix for SUNRPC: add a missing rpc_stat for TCP TLS
  (git-fixes).
- SUNRPC: add a missing rpc_stat for TCP TLS (git-fixes).
- commit 4fa6f6d
* Wed Aug 21 2024 dsterba@suse.com
- netfilter: iptables: Fix null-ptr-deref in iptable_nat_table_init() (CVE-2024-42270 bsc#1229404)
- commit eb407e1
* Wed Aug 21 2024 dsterba@suse.com
- netfilter: iptables: Fix potential null-ptr-deref in ip6table_nat_table_init() (CVE-2024-42269 bsc#1229402)
- commit 6f31e8c
* Wed Aug 21 2024 dsterba@suse.com
- tipc: Return non-zero value from tipc_udp_addr2str() on error (CVE-2024-42284 bsc#1229382)
- commit 003e7ab
* Wed Aug 21 2024 dsterba@suse.com
- net: nexthop: Initialize all fields in dumped nexthops (CVE-2024-42283 bsc#1229383)
- commit dd830eb
* Wed Aug 21 2024 dsterba@suse.com
- sysctl: always initialize i_uid/i_gid (CVE-2024-42312 bsc#1229357)
- commit 683a109
* Wed Aug 21 2024 dsterba@suse.com
- block: initialize integrity buffer to zero before writing it to media (CVE-2024-43854 bsc#1229345)
- commit bc065ac
* Tue Aug 20 2024 dsterba@suse.com
- ipvs: properly dereference pe in ip_vs_add_service (CVE-2024-42322 bsc#1229347)
- commit 5abcd51
* Tue Aug 20 2024 jgross@suse.com
- vhost-vdpa: switch to use vmf_insert_pfn() in the fault handler
  (git-fixes).
- commit efaee02
* Tue Aug 20 2024 jgross@suse.com
- net: missing check virtio (git-fixes).
- commit 547a4d8
* Tue Aug 20 2024 jgross@suse.com
- vhost/vsock: always initialize seqpacket_allow (git-fixes).
- commit 1501797
* Tue Aug 20 2024 jgross@suse.com
- vhost: Use virtqueue mutex for swapping worker (git-fixes).
- commit ee31e9d
* Tue Aug 20 2024 dwagner@suse.de
- nvme-sysfs: add 'tls_keyring' attribute (bsc#1221857).
- nvme-sysfs: add 'tls_configured_key' sysfs attribute
  (bsc#1221857).
- nvme: split off TLS sysfs attributes into a separate group
  (bsc#1221857).
- nvme: add a newline to the 'tls_key' sysfs attribute
  (bsc#1221857).
- nvme-tcp: check for invalidated or revoked key (bsc#1221857).
- nvme-tcp: sanitize TLS key handling (bsc#1221857).
- nvme: tcp: remove unnecessary goto statement (bsc#1221857).
- commit 95902b1
* Tue Aug 20 2024 dwagner@suse.de
- Refresh patches.suse/nvme-fabrics-typo-in-nvmf_parse_key.patch.
  Move into sorted section.
- commit 24e43c3
* Tue Aug 20 2024 jgross@suse.com
- vhost-scsi: Handle vhost_vq_work_queue failures for events
  (git-fixes).
- commit bb54ef9
* Tue Aug 20 2024 tiwai@suse.de
- Update DRM patch reference (CVE-2024-42308 bsc#1229411)
- commit ddc1933
* Tue Aug 20 2024 dwagner@suse.de
- Update
  patches.suse/nvme-tcp-fix-compile-time-checks-for-TLS-mode.patch
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535
  bsc#1221857).
  Fix backporting error.
- commit 35c7df3
* Tue Aug 20 2024 tiwai@suse.de
- Update parport patch reference (CVE-2024-42301 bsc#1229407)
- commit 6707829
* Tue Aug 20 2024 dwagner@suse.de
- Refresh
  patches.suse/nvme-tcp-strict-pdu-pacing-to-avoid-send-stalls-on-T.patch.
  Use the version which got upload upstream.
- commit 4896f98
* Tue Aug 20 2024 jgross@suse.com
- virtio_net: use u64_stats_t infra to avoid data-races
  (git-fixes).
- commit 1825530
* Tue Aug 20 2024 oneukum@suse.com
- usb: typec: fsa4480: Check if the chip is really there
  (git-fixes).
- commit 771af75
* Tue Aug 20 2024 oneukum@suse.com
- usb: typec: fsa4480: Add support to swap SBU orientation
  (git-fixes).
- commit b744e01
* Tue Aug 20 2024 oneukum@suse.com
- usb: typec: fsa4480: add support for Audio Accessory Mode
  (git-fixes).
- commit 471d14e
* Tue Aug 20 2024 oneukum@suse.com
- usb: typec: fsa4480: rework mux & switch setup to handle more
  states (git-fixes).
- commit dc03605
* Tue Aug 20 2024 tiwai@suse.de
- irqchip/imx-irqsteer: Handle runtime power management correctly
  (CVE-2024-42290 bsc#1229379).
- commit a3bbc63
* Tue Aug 20 2024 ailiop@suse.com
- landlock: Don't lose track of restrictions on cred_transfer
  (bsc#1229351 CVE-2024-42318).
- commit e161e74
* Tue Aug 20 2024 rgoldwyn@suse.com
- apparmor: Fix null pointer deref when receiving skb during sock creation (bsc#1229287, CVE-2023-52889).
- commit 7a47d08
* Tue Aug 20 2024 jgross@suse.com
- kABI fix of: virtio-crypto: handle config changed by work queue
  (git-fixes).
- commit 2e4646f
* Tue Aug 20 2024 dwagner@suse.de
- nvme-multipath: implement "queue-depth" iopolicy (bsc#1227706).
- nvme-multipath: prepare for "queue-depth" iopolicy
  (bsc#1227706).
- commit 796fd31
* Tue Aug 20 2024 ailiop@suse.com
- nilfs2: handle inconsistent state in nilfs_btnode_create_block()
  (bsc#1229370 CVE-2024-42295).
- commit 34231c4
* Tue Aug 20 2024 iivanov@suse.de
- arm64: dts: imx8mp: Fix pgc vpu locations (git-fixes)
- commit 6f29859
* Tue Aug 20 2024 iivanov@suse.de
- arm64: dts: imx8mp: Fix pgc_mlmix location (git-fixes)
- commit 6b6ab8a
* Tue Aug 20 2024 tiwai@suse.de
- soc: qcom: icc-bwmon: Fix refcount imbalance seen during
  bwmon_remove (CVE-2024-43850 bsc#1229316).
- soc: qcom: icc-bwmon: Set default thresholds dynamically
  (CVE-2024-43850 bsc#1229316).
- commit e842a77
* Tue Aug 20 2024 iivanov@suse.de
- arm64: dts: imx8mp: add HDMI power-domains (git-fixes)
- commit 88b7cca
* Tue Aug 20 2024 iivanov@suse.de
- arm64: dts: imx8mp: Add NPU Node (git-fixes)
- commit 55a2e84
* Tue Aug 20 2024 tiwai@suse.de
- media: mediatek: vcodec: Handle invalid decoder vsi
  (CVE-2024-43831 bsc#1229309).
- commit a7b1ec0
* Tue Aug 20 2024 tbogendoerfer@suse.de
- bna: adjust 'name' buf size of bna_tcb and bna_ccb structures
  (CVE-2024-43839 bsc#1229301).
- net: mana: Add support for page sizes other than 4KB on ARM64
  (jsc#PED-8491 bsc#1226530).
- commit 24750b5
* Tue Aug 20 2024 ailiop@suse.com
- Squashfs: fix variable overflow triggered by sysbot (git-fixes).
- commit 90b77e5
* Tue Aug 20 2024 ailiop@suse.com
- squashfs: squashfs_read_data need to check if the length is 0
  (git-fixes).
- commit 1ab3d64
* Tue Aug 20 2024 ailiop@suse.com
- jfs: Fix shift-out-of-bounds in dbDiscardAG (git-fixes).
- commit f862c1b
* Tue Aug 20 2024 ailiop@suse.com
- jfs: fix null ptr deref in dtInsertEntry (git-fixes).
- commit 72d65ab
* Tue Aug 20 2024 ailiop@suse.com
- reiserfs: fix uninit-value in comp_keys (git-fixes).
- commit aeea4b8
* Tue Aug 20 2024 sjaeckel@suse.de
- Update
  patches.suse/0001-netlink-add-nla-be16-32-types-to-minlen-array.patch
  (CVE-2024-26849 bsc#1223053).
  Fixes: 2747893c94d9b55340403026d9430f2f93947449
- commit 4cf09d7
* Tue Aug 20 2024 jgross@suse.com
- virtio-crypto: handle config changed by work queue (git-fixes).
- Refresh
  patches.suse/crypto-virtio-Wait-for-tasklet-to-complete-on-device.patch.
- commit 3719b45
* Tue Aug 20 2024 lhenriques@suse.de
- fuse: Initialize beyond-EOF page contents before setting
  uptodate (bsc#1229456).
- fs/netfs/fscache_cookie: add missing "n_accesses" check
  (bsc#1229455).
- commit 1ffdccd
* Tue Aug 20 2024 mfranc@suse.cz
- s390/dasd: fix error recovery leading to data corruption on
  ESE devices (git-fixes bsc#1229452).
- commit 421d882
* Tue Aug 20 2024 pjakobsson@suse.de
- blacklist.conf: Change entry to alt-commit
- Refresh patches.suse/tools-Disable-__packed-attribute-compiler-warning-due-to-Werror-attributes.patch.
- commit a7c7d40
* Tue Aug 20 2024 mfranc@suse.cz
- net/iucv: fix the allocation size of iucv_path_table array
  (git-fixes bsc#1229451).
- commit 4e0b259
* Tue Aug 20 2024 pjakobsson@suse.de
- Refresh patches.suse/0001-drm-mst-Fix-NULL-pointer-dereference-at-drm_dp_add_p.patch (git-fixes)
  Alt-commit
- commit 98e41cf
* Tue Aug 20 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-i915-vma-Fix-UAF-on-destroy-against-retire-race.patch (git-fixes)
  Alt-commit
- commit 11ef901
* Tue Aug 20 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Send-DTBCLK-disable-message-on-first.patch (git-fixes)
  Alt-commit
- commit 6d9aa0a
* Tue Aug 20 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Fix-DPSTREAM-CLK-on-and-off-sequence.patch (git-fixes)
  Alt-commit
- commit 24768b9
* Tue Aug 20 2024 sjaeckel@suse.de
- tcp: use signed arithmetic in tcp_rtx_probe0_timed_out()
  (CVE-2024-41007 bsc#1227863).
- commit 35aaaf5
* Tue Aug 20 2024 tiwai@suse.de
- HID: wacom: Defer calculation of resolution until
  resolution_code is known (git-fixes).
- ALSA: usb: Fix UBSAN warning in parse_audio_unit()
  (stable-fixes).
- commit a485c9b
* Tue Aug 20 2024 shung-hsi.yu@suse.com
- bpf: Fix a segment issue when downgrading gso_size (bsc#1229386
  CVE-2024-42281).
- commit f593f1f
* Mon Aug 19 2024 sjaeckel@suse.de
- kABI fix for net/sched: flower: Fix chain template offload
  (CVE-2024-26669 bsc#1222350).
- net/sched: flower: Fix chain template offload (CVE-2024-26669
  bsc#1222350).
- commit 43f1cd6
* Mon Aug 19 2024 sjaeckel@suse.de
- kABI fix for rxrpc: Fix delayed ACKs to not set the reference
  serial number (CVE-2024-26677 bsc#1222387).
- rxrpc: Fix delayed ACKs to not set the reference serial number
  (CVE-2024-26677 bsc#1222387).
- commit c3c3a27
* Mon Aug 19 2024 msuchanek@suse.de
- Update patches.suse/cpu-SMT-Enable-SMT-only-if-a-core-is-online.patch
  (bsc#1214285 bsc#1205462 ltc#200161 ltc#200588 git-fixes
  bsc#1229327 ltc#206365).
- Update patches.suse/powerpc-topology-Check-if-a-core-is-online.patch
  (bsc#1214285 bsc#1205462 ltc#200161 ltc#200588 git-fixes
  bsc#1229327 ltc#206365).
- commit fd7ec4b
* Mon Aug 19 2024 neilb@suse.de
- xprtrdma: Fix rpcrdma_reqs_reset() (git-fixes).
- gss_krb5: Fix the error handling path for
  crypto_sync_skcipher_setkey (git-fixes).
- commit c717fae
* Mon Aug 19 2024 neilb@suse.de
- SUNRPC: Fix a race to wake a sync task (git-fixes).
- nfs: pass explicit offset/count to trace events (git-fixes).
- commit 6f41a0a
* Mon Aug 19 2024 neilb@suse.de
- NFSv4.1 another fix for EXCHGID4_FLAG_USE_PNFS_DS for DS server
  (git-fixes).
- NFSD: Support write delegations in LAYOUTGET (git-fixes).
- nfs: don't invalidate dentries on transient errors (git-fixes).
- nfs: propagate readlink errors in nfs_symlink_filler
  (git-fixes).
- nfs: make the rpc_stat per net namespace (git-fixes).
- nfs: expose /proc/net/sunrpc/nfs in net namespaces (git-fixes).
- sunrpc: add a struct rpc_stats arg to rpc_create_args
  (git-fixes).
- commit 6ab4001
* Mon Aug 19 2024 jlee@suse.com
- Update
  patches.suse/ata-libata-core-Fix-double-free-on-error.patch
  (git-fixes CVE-2024-41087 bsc#1228740 bsc#1228466).
- Update
  patches.suse/cachefiles-add-missing-lock-protection-when-polling.patch
  (bsc#1229256 CVE-2024-42250 bsc#1228977).
- Update
  patches.suse/cachefiles-defer-exposing-anon_fd-until-after-copy_to.patch
  (bsc#1229251 CVE-2024-40913 bsc#1227839).
- Update
  patches.suse/cachefiles-fix-slab-use-after-free-in-cachefiles_onde.patch
  (bsc#1229247 CVE-2024-39510 bsc#1227734).
- Update
  patches.suse/cachefiles-fix-slab-use-after-free-in-cachefiles_ondemand_daemon_read.patch
  (bsc#1229246 CVE-2024-40899 bsc#1227758).
- Update
  patches.suse/drm-i915-gem-Fix-Virtual-Memory-mapping-boundaries-c.patch
  (git-fixes CVE-2024-42259 bsc#1229156).
- Update
  patches.suse/powerpc-pseries-Whitelist-dtl-slub-object-for-copyin.patch
  (bsc#1194869 CVE-2024-41065 bsc#1228636).
- commit 3fec826
* Mon Aug 19 2024 tiwai@suse.de
- char: xillybus: Check USB endpoints when probing device
  (git-fixes).
- Revert "misc: fastrpc: Restrict untrusted app to attach to
  privileged PD" (git-fixes).
- tty: atmel_serial: use the correct RTS flag (git-fixes).
- tty: serial: fsl_lpuart: mark last busy before uart_add_one_port
  (git-fixes).
- xhci: Fix Panther point NULL pointer deref at full-speed
  re-enumeration (git-fixes).
- Revert "usb: typec: tcpm: clear pd_event queue in PORT_RESET"
  (git-fixes).
- commit e3fe681
* Mon Aug 19 2024 neilb@suse.de
- Refresh patches.suse/SUNRPC-avoid-soft-lockup-when-transmitting-UDP-to-re.patch.
  Add git-commit
- commit 7a1e763
* Sun Aug 18 2024 ailiop@suse.com
- xfs: attr forks require attr, not attr2 (git-fixes).
- commit d1644af
* Sun Aug 18 2024 tiwai@suse.de
- i2c: qcom-geni: Add missing geni_icc_disable in
  geni_i2c_runtime_resume (git-fixes).
- i2c: Use IS_REACHABLE() for substituting empty ACPI functions
  (git-fixes).
- commit 37fcb0e
* Sun Aug 18 2024 tiwai@suse.de
- Move upstreamed powerpc patches into sorted section
- commit 7bdd775
* Sun Aug 18 2024 ailiop@suse.com
- xfs: journal geometry is not properly bounds checked
  (git-fixes).
- commit 7680aeb
* Sat Aug 17 2024 svarbanov@suse.de
- arm64: Fix KASAN random tag seed initialization (git-fixes)
- commit a300263
* Sat Aug 17 2024 svarbanov@suse.de
- arm64: ACPI: NUMA: initialize all values of acpi_early_node_map to (git-fixes)
- commit a089c62
* Sat Aug 17 2024 tiwai@suse.de
- spi: Add empty versions of ACPI functions (stable-fixes).
- i2c: Fix conditional for substituting empty ACPI functions
  (stable-fixes).
- commit 3dc083c
* Sat Aug 17 2024 tiwai@suse.de
- gpio: mlxbf3: Support shutdown() function (git-fixes).
- ALSA: hda/tas2781: Use correct endian conversion (git-fixes).
- ALSA: usb-audio: Support Yamaha P-125 quirk entry
  (stable-fixes).
- ALSA: hda/tas2781: fix wrong calibrated data order (git-fixes).
- ALSA: usb-audio: Add delay quirk for VIVO USB-C-XE710 HEADSET
  (stable-fixes).
- ALSA: hda/realtek: Add support for new HP G12 laptops
  (stable-fixes).
- ALSA: hda/realtek: Fix noise from speakers on Lenovo IdeaPad
  3 15IAU7 (git-fixes).
- ALSA: timer: Relax start tick time check for slave timer
  elements (git-fixes).
- drm/amd/display: Adjust cursor position (git-fixes).
- drm/amd/display: fix cursor offset on rotation 180 (git-fixes).
- device property: Add cleanup.h based fwnode_handle_put()
  scope based cleanup (stable-fixes).
- commit 51be9a0
* Fri Aug 16 2024 ailiop@suse.com
- xfs: allow cross-linking special files without project quota
  (git-fixes).
- commit 8d26aca
* Fri Aug 16 2024 jgross@suse.com
- KVM: nVMX: Check for pending posted interrupts when looking
  for nested events (git-fixes).
- commit 0b1027c
* Fri Aug 16 2024 jgross@suse.com
- KVM: VMX: Split out the non-virtualization part of
  vmx_interrupt_blocked() (git-fixes).
- commit 47fc351
* Fri Aug 16 2024 ailiop@suse.com
- xfs: use consistent uid/gid when grabbing dquots for inodes
  (git-fixes).
- commit c1c88ce
* Fri Aug 16 2024 ailiop@suse.com
- xfs: honor init_xattrs in xfs_init_new_inode for !ATTR fs
  (git-fixes).
- commit fae2711
* Fri Aug 16 2024 ailiop@suse.com
- xfs: allow unlinked symlinks and dirs with zero size
  (git-fixes).
- commit 184b713
* Fri Aug 16 2024 jgross@suse.com
- KVM: x86/mmu: Bug the VM if KVM tries to split a !hugepage SPTE
  (git-fixes).
- commit 96acab8
* Fri Aug 16 2024 ailiop@suse.com
- xfs: fix unlink vs cluster buffer instantiation race
  (git-fixes).
- commit 0ae592b
* Fri Aug 16 2024 ailiop@suse.com
- xfs: upgrade the extent counters in xfs_reflink_end_cow_extent
  later (git-fixes).
- commit 730a4f0
* Fri Aug 16 2024 ailiop@suse.com
- xfs: match lock mode in xfs_buffered_write_iomap_begin()
  (git-fixes).
- commit e70a195
* Fri Aug 16 2024 ailiop@suse.com
- xfs: require XFS_SB_FEAT_INCOMPAT_LOG_XATTRS for attr log
  intent item recovery (git-fixes).
- commit 85919a1
* Fri Aug 16 2024 ailiop@suse.com
- xfs: don't use current->journal_info (git-fixes).
- commit d96f684
* Fri Aug 16 2024 jgross@suse.com
- KVM: nVMX: Request immediate exit iff pending nested event
  needs injection (git-fixes).
- commit 9d306b8
* Fri Aug 16 2024 lhenriques@suse.de
- cachefiles: add missing lock protection when polling
  (bsc#1229256).
- cachefiles: cyclic allocation of msg_id to avoid reuse
  (bsc#1228499 CVE-2024-41050).
- cachefiles: wait for ondemand_object_worker to finish when
  dropping  object (bsc#1228468 CVE-2024-41051).
- cachefiles: cancel all requests for the object that is being
  dropped (bsc#1229255).
- cachefiles: stop sending new request when dropping object
  (bsc#1229254).
- cachefiles: propagate errors from vfs_getxattr() to avoid
  infinite  loop (bsc#1229253).
- cachefiles: make on-demand read killable (bsc#1229252).
- cachefiles: Set object to close if ondemand_id < 0 in copen
  (bsc#1228643 CVE-2024-41074).
- cachefiles: defer exposing anon_fd until after copy_to_user()
  succeeds (bsc#1229251).
- cachefiles: never get a new anonymous fd if ondemand_id is valid
  (bsc#1229250).
- cachefiles: add spin_lock for cachefiles_ondemand_info
  (bsc#1229249).
- cachefiles: add consistency check for copen/cread (bsc#1228646
  CVE-2024-41075).
- cachefiles: remove err_put_fd label in
  cachefiles_ondemand_daemon_read() (bsc#1229248).
- cachefiles: fix slab-use-after-free in
  cachefiles_ondemand_daemon_read() (bsc#1229247).
- cachefiles: fix slab-use-after-free in
  cachefiles_ondemand_get_fd() (bsc#1229246).
- cachefiles, erofs: Fix NULL deref in when cachefiles is not
  doing  ondemand-mode (bsc#1229245).
- cachefiles: add restore command to recover inflight ondemand
  read  requests (bsc#1229244).
- cachefiles: narrow the scope of triggering EPOLLIN events in
  ondemand  mode (bsc#1229243).
- cachefiles: resend an open request if the read request's object
  is  closed (bsc#1229241).
- cachefiles: extract ondemand info field from cachefiles_object
  (bsc#1229240).
- cachefiles: introduce object ondemand state (bsc#1229239).
- commit 3d893c5
* Fri Aug 16 2024 jgross@suse.com
- KVM: nVMX: Add a helper to get highest pending from Posted
  Interrupt vector (git-fixes).
- commit ebf04ff
* Fri Aug 16 2024 jgross@suse.com
- KVM: VMX: Switch __vmx_exit() and kvm_x86_vendor_exit() in
  vmx_exit() (git-fixes).
- commit 8ef91ee
* Fri Aug 16 2024 jgross@suse.com
- KVM: x86: Limit check IDs for KVM_SET_BOOT_CPU_ID (git-fixes).
- commit 395837f
* Fri Aug 16 2024 jgross@suse.com
- KVM: VMX: Move posted interrupt descriptor out of VMX code
  (git-fixes).
- commit feb966b
* Fri Aug 16 2024 ailiop@suse.com
- xfs: allow symlinks with short remote targets (bsc#1229160).
- commit e82d4ad
* Fri Aug 16 2024 jgross@suse.com
- x86/xen: Convert comma to semicolon (git-fixes).
- commit c8d2d16
* Fri Aug 16 2024 tbogendoerfer@suse.de
- net: mana: Fix doorbell out of order violation and avoid
  unnecessary doorbell rings (bsc#1229154).
- net: mana: Fix RX buf alloc_size alignment and atomic op panic
  (bsc#1229086).
- commit 59cb1c7
* Fri Aug 16 2024 tiwai@suse.de
- wifi: brcmfmac: cfg80211: Handle SSID based pmksa deletion
  (git-fixes).
- net: ethernet: mtk_wed: fix use-after-free panic in
  mtk_wed_setup_tc_block_cb() (git-fixes).
- media: Revert "media: dvb-usb: Fix unexpected infinite loop
  in dvb_usb_read_remote_control()" (git-fixes).
- commit daf04e2
* Thu Aug 15 2024 krisman@suse.de
- filelock: Remove locks reliably when fcntl/close race is
  detected (CVE-2024-41012 bsc#1228247).
- commit a736b9b
* Thu Aug 15 2024 krisman@suse.de
- io_uring: fix possible deadlock in
  io_register_iowq_max_workers() (bsc#1228616 CVE-2024-41080).
- commit eae6448
* Thu Aug 15 2024 krisman@suse.de
- io_uring: fix io_match_task must_hold (git-fixes).
- io_uring: tighten task exit cancellations (git-fixes).
- commit f9ce2d8
* Thu Aug 15 2024 krisman@suse.de
- io_uring: Fix probe of disabled operations (git-fixes).
- io_uring/advise: support 64-bit lengths (git-fixes).
- commit 7566a8d
* Thu Aug 15 2024 krisman@suse.de
- io_uring: Drop per-ctx dummy_ubuf (git-fixes).
- commit 2717cc1
* Thu Aug 15 2024 msuchanek@suse.de
- powerpc/kexec_file: fix cpus node update to FDT (bsc#1194869).
- powerpc/pseries: Whitelist dtl slub object for copying to
  userspace (bsc#1194869).
- powerpc/kexec: make the update_cpus_node() function public
  (bsc#1194869).
- powerpc/xmon: Check cpu id in commands "c#", "dp#" and "dx#"
  (bsc#1194869).
- powerpc/64: Set _IO_BASE to POISON_POINTER_DELTA not 0 for
  CONFIG_PCI=n (bsc#1194869).
- powerpc/io: Avoid clang null pointer arithmetic warnings
  (bsc#1194869).
- powerpc/pseries: Add failure related checks for h_get_mpp and
  h_get_ppp (bsc#1194869).
- powerpc/kexec: split CONFIG_KEXEC_FILE and CONFIG_CRASH_DUMP
  (bsc#1194869).
- powerpc: xor_vmx: Add '-mhard-float' to CFLAGS (bsc#1194869).
- powerpc/radix: Move some functions into #ifdef
  CONFIG_KVM_BOOK3S_HV_POSSIBLE (bsc#1194869).
- commit 4e7f0fe
* Thu Aug 15 2024 iivanov@suse.de
- arm64: errata: Expand speculative SSBS workaround (again) (git-fixes)
- commit e589bbc
* Thu Aug 15 2024 iivanov@suse.de
- arm64: cputype: Add Cortex-A725 definitions (git-fixes)
- commit 0d04176
* Thu Aug 15 2024 iivanov@suse.de
- arm64: cputype: Add Cortex-X1C definitions (git-fixes)
- commit 6a5ea61
* Thu Aug 15 2024 iivanov@suse.de
- arm64: errata: Expand speculative SSBS workaround (git-fixes)
- commit f75d6ba
* Thu Aug 15 2024 iivanov@suse.de
- arm64: errata: Unify speculative SSBS errata logic (git-fixes).
  Update config files.
- commit ffaab08
* Thu Aug 15 2024 iivanov@suse.de
- arm64: cputype: Add Cortex-X925 definitions (git-fixes)
- commit 3c8ddb7
* Thu Aug 15 2024 iivanov@suse.de
- arm64: cputype: Add Cortex-A720 definitions (git-fixes)
- commit f5fd7c6
* Thu Aug 15 2024 iivanov@suse.de
- arm64: cputype: Add Cortex-X3 definitions (git-fixes)
- commit d87d988
* Thu Aug 15 2024 iivanov@suse.de
- arm64: errata: Add workaround for Arm errata 3194386 and 3312417 (git-fixes)
  Refresh patches.suse/kabi-arm64-reserve-space-in-cpu_hwcaps-and-cpu_hwcap.patch
  and enable around.
- commit b3747ef
* Thu Aug 15 2024 iivanov@suse.de
- arm64: cputype: Add Neoverse-V3 definitions (git-fixes)
- commit 78aeee9
* Thu Aug 15 2024 iivanov@suse.de
- arm64: cputype: Add Cortex-X4 definitions (git-fixes)
- commit 2841965
* Thu Aug 15 2024 iivanov@suse.de
- arm64: barrier: Restore spec_bar() macro (git-fixes)
- commit 5c935b6
* Thu Aug 15 2024 iivanov@suse.de
- arm64: Add Neoverse-V2 part (git-fixes)
- commit 0f9f30b
* Thu Aug 15 2024 sjaeckel@suse.de
- net/rds: fix possible cp null dereference (git-fixes).
- commit cac3126
* Thu Aug 15 2024 mfranc@suse.cz
- s390/pci: Add missing virt_to_phys() for directed DIBV
  (git-fixes bsc#1229174).
- commit ea8e3e7
* Thu Aug 15 2024 mfranc@suse.cz
- s390/dasd: fix error checks in dasd_copy_pair_store()
  (git-fixes bsc#1229173).
- commit f5c4fe8
* Thu Aug 15 2024 mfranc@suse.cz
- s390/pci: Allow allocation of more than 1 MSI interrupt
  (git-fixes bsc#1229172).
- s390/pci: Refactor arch_setup_msi_irqs() (git-fixes
  bsc#1229172).
- commit ad8c54b
* Thu Aug 15 2024 mfranc@suse.cz
- s390/cpum_cf: Fix endless loop in CF_DIAG event stop (git-fixes
  bsc#1229171).
- commit 94c7469
* Thu Aug 15 2024 mfranc@suse.cz
- s390/uv: Panic for set and remove shared access UVC errors
  (git-fixes bsc#1229170).
- commit 447c271
* Thu Aug 15 2024 mfranc@suse.cz
- s390/sclp: Prevent release of buffer in I/O (git-fixes
  bsc#1229169).
- commit 9daf007
* Thu Aug 15 2024 mfranc@suse.cz
- kvm: s390: Reject memory region operations for ucontrol VMs
  (git-fixes bsc#1229168).
- commit 14a9742
* Thu Aug 15 2024 mfranc@suse.cz
- KVM: s390: fix validity interception issue when gisa is switched
  off (git-fixes bsc#1229167).
- commit 5c4e348
* Thu Aug 15 2024 tiwai@suse.de
- Update patch reference of USB patch (jsc#PED-10108)
- commit edfa08b
* Thu Aug 15 2024 tiwai@suse.de
- USB: serial: debug: do not echo input by default (stable-fixes).
- usb: vhci-hcd: Do not drop references before new references
  are gained (stable-fixes).
- serial: core: check uartclk for zero to avoid divide by zero
  (stable-fixes).
- media: xc2028: avoid use-after-free in load_firmware_cb()
  (stable-fixes).
- media: uvcvideo: Fix the bandwdith quirk on USB 3.x
  (stable-fixes).
- media: uvcvideo: Ignore empty TS packets (stable-fixes).
- media: amphion: Remove lock in s_ctrl callback (stable-fixes).
- wifi: nl80211: don't give key data to userspace (stable-fixes).
- PCI: Add Edimax Vendor ID to pci_ids.h (stable-fixes).
- wifi: ath12k: fix memory leak in ath12k_dp_rx_peer_frag_setup()
  (stable-fixes).
- wifi: nl80211: disallow setting special AP channel widths
  (stable-fixes).
- gpio: prevent potential speculation leaks in
  gpio_device_get_desc() (stable-fixes).
- commit 2335bf9
* Thu Aug 15 2024 tiwai@suse.de
- docs: KVM: Fix register ID of SPSR_FIQ (git-fixes).
- drm/i915/gem: Adjust vma offset for framebuffer mmap offset
  (stable-fixes).
- drm/amd/display: Skip Recompute DSC Params if no Stream on Link
  (stable-fixes).
- drm/amdgpu: Forward soft recovery errors to userspace
  (stable-fixes).
- drm/dp_mst: Skip CSN if topology probing is not done yet
  (stable-fixes).
- drm/mediatek/dp: Fix spurious kfree() (git-fixes).
- drm/amd/display: Add null checker before passing variables
  (stable-fixes).
- Revert "drm/amd/display: Add NULL check for 'afb' before
  dereferencing in amdgpu_dm_plane_handle_cursor_update"
  (stable-fixes).
- drm/amd/display: Add NULL check for 'afb' before dereferencing
  in amdgpu_dm_plane_handle_cursor_update (stable-fixes).
- drm/bridge: analogix_dp: properly handle zero sized AUX
  transactions (stable-fixes).
- drm/amd/pm: Fix the null pointer dereference for vega10_hwmgr
  (stable-fixes).
- drm/radeon: Remove __counted_by from StateArray.states[]
  (git-fixes).
- drm/amdgpu: Add lock around VF RLCG interface (stable-fixes).
- drm/admgpu: fix dereferencing null pointer context
  (stable-fixes).
- drm/amdgpu/pm: Fix the null pointer dereference in
  apply_state_adjust_rules (stable-fixes).
- drm/amdgpu: Fix the null pointer dereference to ras_manager
  (stable-fixes).
- drm/amdgpu/pm: Fix the null pointer dereference for smu7
  (stable-fixes).
- drm/amdgpu/pm: Fix the param type of set_power_profile_mode
  (stable-fixes).
- drm/amdgpu: fix potential resource leak warning (stable-fixes).
- drm/amd/display: Add delay to improve LTTPR UHBR interop
  (stable-fixes).
- Bluetooth: btnxpuart: Shutdown timer and prevent rearming when
  driver unloading (stable-fixes).
- can: mcp251xfd: tef: update workaround for erratum DS80000789E
  6 of mcp2518fd (stable-fixes).
- can: mcp251xfd: tef: prepare to workaround broken TEF FIFO
  tail index erratum (stable-fixes).
- ACPI: SBS: manage alarm sysfs attribute through psy core
  (stable-fixes).
- ACPI: battery: create alarm sysfs attribute atomically
  (stable-fixes).
- clocksource/drivers/sh_cmt: Address race condition for clock
  events (stable-fixes).
- commit 2a8ca72
* Wed Aug 14 2024 tiwai@suse.de
- Update patch reference for SPI patch (jsc#PED-10105)
- commit a896d55
* Wed Aug 14 2024 mfranc@suse.cz
- kabi fix for KVM: s390: fix LPSWEY handling (bsc#1227634
  git-fixes).
- KVM: s390: fix LPSWEY handling (bsc#1227634 git-fixes).
- commit 576de67
* Wed Aug 14 2024 mkoutny@suse.com
- kernfs: Convert kernfs_path_from_node_locked() from strlcpy()
  to strscpy() (bsc#1229134).
- Refresh
  patches.suse/cgroup-cpuset-Prevent-UAF-in-proc_cpuset_show.patch.
- commit bc8376b
* Wed Aug 14 2024 tiwai@suse.de
- Update patch reference for iwlwifi fix (jsc#PED-10055)
- commit 73fda85
* Wed Aug 14 2024 tiwai@suse.de
- Input: i8042 - add Fujitsu Lifebook E756 to i8042 quirk table
  (bsc#1229056).
- commit 0ae7f4e
* Wed Aug 14 2024 jlee@suse.com
- bpf: hardcode BPF_PROG_PACK_SIZE to 2MB * num_possible_nodes()
  (git-fixes).
- bpf: don't infer PTR_TO_CTX for programs with unnamed context
  type (git-fixes).
- bpf: handle bpf_user_pt_regs_t typedef explicitly for PTR_TO_CTX
  global arg (git-fixes).
- bpf: Mark bpf_spin_{lock,unlock}() helpers with notrace
  correctly (git-fixes).
- commit dd0591b
* Wed Aug 14 2024 neilb@suse.de
- net, sunrpc: Remap EPERM in case of connection failure in
  xs_tcp_setup_socket (CVE-2024-42246 bsc#1228989).
- commit 12865c8
* Wed Aug 14 2024 jlee@suse.com
- tools/resolve_btfids: Fix comparison of distinct pointer types
  warning in resolve_btfids (git-fixes).
- tools/resolve_btfids: fix build with musl libc (git-fixes).
- commit f42b517
* Tue Aug 13 2024 fdmanana@suse.com
- btrfs: fix leak of qgroup extent records after transaction abort
  (git-fixes).
- btrfs: fix ordered extent split error handling in
  btrfs_dio_submit_io (git-fixes).
- btrfs: use irq safe locking when running and adding delayed
  iputs (git-fixes).
- commit 59b18df
* Tue Aug 13 2024 fdmanana@suse.com
- btrfs: fix extent map use-after-free when adding pages to
  compressed bio (git-fixes).
- commit b3e7c96
* Tue Aug 13 2024 tiwai@suse.de
- Drop libata patch that caused a regression (bsc#1229054)
- commit 3d5faca
* Tue Aug 13 2024 fdmanana@suse.com
- btrfs: fix double inode unlock for direct IO sync writes
  (git-fixes).
- btrfs: fix corruption after buffer fault in during direct IO
  append write (git-fixes).
- btrfs: use a btrfs_inode local variable at btrfs_sync_file()
  (git-fixes).
- btrfs: pass a btrfs_inode to btrfs_wait_ordered_range()
  (git-fixes).
- btrfs: pass a btrfs_inode to btrfs_fdatawrite_range()
  (git-fixes).
- btrfs: use a btrfs_inode in the log context (struct
  btrfs_log_ctx) (git-fixes).
- btrfs: make btrfs_finish_ordered_extent() return void
  (git-fixes).
- btrfs: ensure fast fsync waits for ordered extents after a
  write failure (git-fixes).
- btrfs: rename err to ret in btrfs_direct_write() (git-fixes).
- btrfs: uninline some static inline helpers from tree-log.h
  (git-fixes).
- btrfs: use btrfs_finish_ordered_extent to complete buffered
  writes (git-fixes).
- btrfs: use btrfs_finish_ordered_extent to complete direct writes
  (git-fixes).
- btrfs: use btrfs_finish_ordered_extent to complete compressed
  writes (git-fixes).
- btrfs: open code end_extent_writepage in
  end_bio_extent_writepage (git-fixes).
- btrfs: add a btrfs_finish_ordered_extent helper (git-fixes).
- btrfs: factor out a btrfs_queue_ordered_fn helper (git-fixes).
- btrfs: factor out a can_finish_ordered_extent helper
  (git-fixes).
- btrfs: use bbio->ordered in btrfs_csum_one_bio (git-fixes).
- btrfs: add an ordered_extent pointer to struct btrfs_bio
  (git-fixes).
- btrfs: open code btrfs_bio_end_io in btrfs_dio_submit_io
  (git-fixes).
- btrfs: add a is_data_bbio helper (git-fixes).
- btrfs: remove btrfs_add_ordered_extent (git-fixes).
- btrfs: pass an ordered_extent to btrfs_submit_compressed_write
  (git-fixes).
- btrfs: pass an ordered_extent to btrfs_reloc_clone_csums
  (git-fixes).
- btrfs: merge the two calls to btrfs_add_ordered_extent in
  run_delalloc_nocow (git-fixes).
- btrfs: limit write bios to a single ordered extent (git-fixes).
- commit 90ea198
* Tue Aug 13 2024 msuchanek@suse.de
- powerpc/topology: Check if a core is online (bsc#1214285
  bsc#1205462 ltc#200161 ltc#200588 git-fixes).
- cpu/SMT: Enable SMT only if a core is online (bsc#1214285
  bsc#1205462 ltc#200161 ltc#200588 git-fixes).
- commit 3d340df
* Tue Aug 13 2024 tiwai@suse.de
- Update patch reference for MD patch (jsc#PED-10029 jsc#PED-10045)
- commit 1bf8fd1
* Tue Aug 13 2024 tiwai@suse.de
- Update patch refefernce for MFD patch (jsc#PED-10029)
- commit f36d989
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Check HSMP support on AMD family of processors (jsc#PED-8779).
- commit c606582
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: switch to use device_add_groups() (jsc#PED-8779).
- commit 4007799
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Change devm_kzalloc() to devm_kcalloc() (jsc#PED-8779).
- commit 9854658
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Remove extra parenthesis and add a space (jsc#PED-8779).
- commit 0a84b39
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Check num_sockets against MAX_AMD_SOCKETS (jsc#PED-8779).
- commit 85ba4b7
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Non-ACPI support for AMD F1A_M00~0Fh (jsc#PED-8779).
- commit 1b89039
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Add support for ACPI based probing (jsc#PED-8779).
- commit 73c2646
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Restructure sysfs group creation (jsc#PED-8779).
- commit 9e31807
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Move dev from platdev to hsmp_socket (jsc#PED-8779).
- commit f6baa58
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Define a struct to hold mailbox regs (jsc#PED-8779).
- commit 07f864e
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Create static func to handle platdev (jsc#PED-8779).
- commit d5ea9be
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Cache pci_dev in struct hsmp_socket (jsc#PED-8779).
- commit d314cb6
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Move hsmp_test to probe (jsc#PED-8779).
- commit b00829d
* Tue Aug 13 2024 jlee@suse.com
- tools/resolve_btfids: Fix cross-compilation to non-host
  endianness (git-fixes).
- tools/resolve_btfids: Refactor set sorting with types from
  btf_ids.h (git-fixes).
- libbpf: Use OPTS_SET() macro in bpf_xdp_query() (git-fixes).
- commit 6fc7b9e
* Tue Aug 13 2024 jlee@suse.com
- libbpf: Add missing LIBBPF_API annotation to
  libbpf_set_memlock_rlim API (git-fixes).
- selftests/bpf: Disable IPv6 for lwt_redirect test (git-fixes).
- libbpf: Fix faccessat() usage on Android (git-fixes).
- selftests/bpf: Wait for the netstamp_needed_key static key to
  be turned on (git-fixes).
- commit 89d6f3b
* Tue Aug 13 2024 jlee@suse.com
- selftests/bpf: Fix the flaky tc_redirect_dtime test (git-fixes).
- selftest/bpf: Add map_in_maps with BPF_MAP_TYPE_PERF_EVENT_ARRAY
  values (git-fixes).
- libbpf: Apply map_set_def_max_entries() for inner_maps on
  creation (git-fixes).
- selftests/bpf: Fix potential premature unload in bpf_testmod
  (git-fixes).
- bpftool: Silence build warning about calloc() (git-fixes).
- commit 7aaf2fc
* Tue Aug 13 2024 nik.borisov@suse.com
- x86/asm: Use %%c/%%n instead of %%P operand modifier in asm  templates (git-fixes).
- Refresh
  patches.suse/x86-uaccess-Fix-missed-zeroing-of-ia32-u64-get_user-range-.patch.
- commit 97ffc68
* Tue Aug 13 2024 jlee@suse.com
- selftests/bpf: Fix up xdp bonding test wrt feature flags
  (git-fixes).
- selftests/bpf: fix compiler warnings in RELEASE=1 mode
  (git-fixes).
- selftests/bpf: Relax time_tai test for equal timestamps in
  tai_forward (git-fixes).
- bpf: Set uattr->batch.count as zero before batched update or
  deletion (git-fixes).
- bpf: Remove unnecessary wait from bpf_map_copy_value()
  (git-fixes).
- commit 19ebfe6
* Tue Aug 13 2024 jlee@suse.com
- bpf: enforce precision of R0 on callback return (git-fixes).
- selftests/bpf: Fix erroneous bitmask operation (git-fixes).
- bpf/tests: Remove duplicate JSGT tests (git-fixes).
- bpftool: mark orphaned programs during prog show (git-fixes).
- commit 2b6a18e
* Tue Aug 13 2024 jlee@suse.com
- bpf: Fix a few selftest failures due to llvm18 change
  (git-fixes).
- selftests/bpf: Fix issues in setup_classid_environment()
  (git-fixes).
- selftests/bpf: Add assert for user stacks in test_task_stack
  (git-fixes).
- selftests/bpf: Fix pyperf180 compilation failure with clang18
  (git-fixes).
- bpf: Add crosstask check to __bpf_get_stack (git-fixes).
- commit fce00e9
* Tue Aug 13 2024 jlee@suse.com
- bpf, lpm: Fix check prefixlen before walking trie (git-fixes).
- selftests/bpf: satisfy compiler by having explicit return in
  btf test (git-fixes).
- selftests/bpf: fix RELEASE=1 build for tc_opts (git-fixes).
- bpf: Fix prog_array_map_poke_run map poke update (git-fixes).
- commit ca200c8
* Mon Aug 12 2024 lduncan@suse.com
- scsi: mpi3mr: Use proper format specifier in
  mpi3mr_sas_port_add() (bsc#1228754 CVE-2024-42159 git-fixes).
- scsi: mpi3mr: Sanitise num_phys (bsc#1228754 CVE-2024-42159).
- commit e024eb0
* Mon Aug 12 2024 davide.benini@suse.com
- tcp_metrics: validate source addr length
  (CVE-2024-42154 bsc#1228507).
- commit a83d949
* Mon Aug 12 2024 jlee@suse.com
- selftests/bpf: check if max number of bpf_loop iterations is
  tracked (git-fixes).
  Refresh
  patches.suse/selftests-bpf-test-case-for-callback_depth-states-pr.patch.
- selftests/bpf: fix bpf_loop_bench for new callback verification
  scheme (git-fixes).
- selftests/bpf: Add netkit to tc_redirect selftest (git-fixes).
- selftests/bpf: De-veth-ize the tc_redirect test case
  (git-fixes).
- bpf: fix control-flow graph checking in privileged mode
  (git-fixes).
- commit 27db2c6
* Mon Aug 12 2024 jlee@suse.com
- bpf: Fix check_stack_write_fixed_off() to correctly spill imm
  (git-fixes).
- bpf: Fix unnecessary -EBUSY from htab_lock_bucket (git-fixes).
- commit b5c430e
* Mon Aug 12 2024 mhocko@suse.com
- mm/shmem: disable PMD-sized page cache if needed (CVE-2024-42241
  bsc#1228986).
- commit 8ecdd91
* Mon Aug 12 2024 nik.borisov@suse.com
- x86/mm: Fix pti_clone_pgtable() alignment assumption (git-fixes).
- commit 1d041a1
* Mon Aug 12 2024 nik.borisov@suse.com
- x86/mm: Fix pti_clone_entry_text() for i386 (git-fixes).
- commit 5407674
* Mon Aug 12 2024 nik.borisov@suse.com
- x86/pci: Skip early E820 check for ECAM region (git-fixes).
- commit 7ac1bfc
* Mon Aug 12 2024 nik.borisov@suse.com
- x86/mtrr: Check if fixed MTRRs exist before saving them (git-fixes).
- commit 03de6ee
* Mon Aug 12 2024 nik.borisov@suse.com
- x86/entry/64: Remove obsolete comment on tracing vs. SYSRET (git-fixes).
- commit 41708c1
* Mon Aug 12 2024 mhocko@suse.com
- memcg: protect concurrent access to mem_cgroup_idr (git-fixes).
- commit e9979b2
* Mon Aug 12 2024 rhopkins@suse.de
- Revert "sched/fair: Make sure to try to detach at least one
  movable task" (CVE-2024-42245 bsc#1228978).
- commit bff0dc0
* Mon Aug 12 2024 jlee@suse.com
- selftests/bpf: Make linked_list failure test more robust
  (git-fixes).
- bpf: Ensure proper register state printing for cond jumps
  (git-fixes).
- commit 2ec4f49
* Mon Aug 12 2024 denis.kirjanov@suse.com
- ipv6: sr: fix incorrect unregister order (git-fixes).
- commit f975fdd
* Mon Aug 12 2024 denis.kirjanov@suse.com
- ipv6: sr: fix possible use-after-free and null-ptr-deref
  (CVE-2024-26735 bsc#1222372).
- commit 75aaed9
* Mon Aug 12 2024 jlee@suse.com
- bpftool: Align output skeleton ELF code (git-fixes).
- samples/bpf: syscall_tp_user: Fix array out-of-bound access
  (git-fixes).
- samples/bpf: syscall_tp_user: Rename num_progs into nr_tests
  (git-fixes).
- bpf: Fix kfunc callback register type handling (git-fixes).
- commit ee3cca0
* Mon Aug 12 2024 jlee@suse.com
- bpf: Detect IP == ksym.end as part of BPF program (git-fixes).
- commit b5b57d0
* Mon Aug 12 2024 jlee@suse.com
- selftests/bpf: Skip module_fentry_shadow test when bpf_testmod
  is not available (git-fixes).
- commit 85b5d5e
* Mon Aug 12 2024 jlee@suse.com
- bpftool: Fix -Wcast-qual warning (git-fixes).
- commit 0417873
* Mon Aug 12 2024 sjaeckel@suse.de
- net: bridge: switchdev: Skip MDB replays of deferred events
  on offload (CVE-2024-26837 bsc#1222973).
- commit 2f55c98
* Mon Aug 12 2024 mfranc@suse.cz
- s390/pkey: Wipe copies of protected- and secure-keys
  (CVE-2024-42155 bsc#1228733).
- s390/pkey: Wipe copies of clear-key structures on failure
  (CVE-2024-42156 bsc#1228722).
- s390/pkey: Wipe sensitive data on failure (CVE-2024-42157
  bsc#1228727).
- s390/pkey: Use kfree_sensitive() to fix Coccinelle warnings
  (CVE-2024-42158 bsc#1228720).
- s390/pkey: introduce dynamic debugging for pkey (bsc#1228720).
- s390/pkey: harmonize pkey s390 debug feature calls
  (bsc#1228720).
- commit 72f0617
* Mon Aug 12 2024 tiwai@suse.de
- usb: gadget: u_serial: Set start_delayed during suspend
  (git-fixes).
- usb: gadget: core: Check for unset descriptor (git-fixes).
- usb: gadget: u_audio: Check return codes from usb_ep_enable
  and config_ep_by_speed (git-fixes).
- driver core: Fix uevent_show() vs driver detach race
  (git-fixes).
- thermal/drivers/broadcom: Fix race between removal and clock
  disable (git-fixes).
- thermal: bcm2835: Convert to platform remove callback returning
  void (stable-fixes).
- commit 9bfd8af
* Mon Aug 12 2024 shung-hsi.yu@suse.com
- selftests/bpf: Cover verifier checks for mutating
  sockmap/sockhash (bsc#1226885 CVE-2024-38662).
- Revert "bpf, sockmap: Prevent lock inversion deadlock in map
  delete elem" (bsc#1226885 CVE-2024-38662).
- bpf: Allow delete from sockmap/sockhash only if update is
  allowed (bsc#1226885 CVE-2024-38662).
- commit 7f528cf
* Mon Aug 12 2024 jslaby@suse.cz
- rpm/kernel-binary.spec.in: fix klp_symbols macro
  The commit below removed openSUSE filter from %%ifs of the klp_symbols
  definition. But it removed -c of grep too and that causes:
  error: syntax error in expression:  01 && (  || 1 )
  error:                                        ^
  error: unmatched (:  01 && (  || 1 )
  error:                     ^
  error: kernel-default.spec:137: bad %%if condition:  01 && (  || 1 )
  So reintroduce -c to the PTF's grep.
  Fixes: fd0b293bebaf (kernel-binary.spec.in: Enable klp_symbols on openSUSE Tumbleweed (boo#1229042).)
- commit 4a36fe3
* Sun Aug 11 2024 tiwai@suse.de
- i2c: qcom-geni: Add missing geni_icc_disable in
  geni_i2c_runtime_resume (git-fixes).
- i2c: qcom-geni: Add missing clk_disable_unprepare in
  geni_i2c_runtime_resume (git-fixes).
- i2c: smbus: Send alert notifications to all devices if source
  not found (git-fixes).
- i2c: smbus: Improve handling of stuck alerts (git-fixes).
- spi: spi-fsl-lpspi: Fix scldiv calculation (git-fixes).
- spi: spidev: Add missing spi_device_id for bh2228fv (git-fixes).
- drm/i915/gem: Fix Virtual Memory mapping boundaries calculation
  (git-fixes).
- drm/client: fix null pointer dereference in
  drm_client_modeset_probe (git-fixes).
- commit e093c66
* Sat Aug 10 2024 tiwai@suse.de
- Update patch references for ASoC regression fixes (bsc#1229045 bsc#1229046)
- commit 4e3f007
* Sat Aug 10 2024 tiwai@suse.de
- rpm/kernel-binary.spec.in: Fix build regression
  The previous fix forgot to take over grep -c option that broke the
  conditional expression
- commit d29edf2
* Sat Aug 10 2024 tiwai@suse.de
- Moved upstreamed ASoC patch into sorted section
- commit 3058bc3
* Sat Aug 10 2024 tiwai@suse.de
- ASoC: cs35l56: Patch CS35L56_IRQ1_MASK_18 to the default value
  (stable-fixes).
- ASoC: amd: yc: Support mic on Lenovo Thinkpad E14 Gen 6
  (stable-fixes).
- ASoC: cs35l56: Handle OTP read latency over SoundWire
  (stable-fixes).
- ASoC: nau8822: Lower debug print priority (stable-fixes).
- ASoC: fsl_micfil: Expand the range of FIFO watermark mask
  (stable-fixes).
- ASoC: amd: yc: Support mic on HP 14-em0002la (stable-fixes).
- ALSA: hda/realtek: Add Framework Laptop 13 (Intel Core Ultra)
  to quirks (stable-fixes).
- ALSA: hda/hdmi: Yet more pin fix for HP EliteDesk 800 G4
  (stable-fixes).
- ALSA: hda: Add HP MP9 G4 Retail System AMS to force connect list
  (stable-fixes).
- ALSA: line6: Fix racy access to midibuf (stable-fixes).
- ASoC: cs35l56: Patch CS35L56_IRQ1_MASK_18 to the default value
  (stable-fixes).
- ASoC: amd: yc: Support mic on Lenovo Thinkpad E14 Gen 6
  (stable-fixes).
- ASoC: cs35l56: Handle OTP read latency over SoundWire
  (stable-fixes).
- ASoC: nau8822: Lower debug print priority (stable-fixes).
- ASoC: fsl_micfil: Expand the range of FIFO watermark mask
  (stable-fixes).
- ASoC: amd: yc: Support mic on HP 14-em0002la (stable-fixes).
- ALSA: hda/realtek: Add Framework Laptop 13 (Intel Core Ultra)
  to quirks (stable-fixes).
- ALSA: hda/hdmi: Yet more pin fix for HP EliteDesk 800 G4
  (stable-fixes).
- ALSA: hda: Add HP MP9 G4 Retail System AMS to force connect list
  (stable-fixes).
- ALSA: line6: Fix racy access to midibuf (stable-fixes).
- commit a8c8868
* Sat Aug 10 2024 tiwai@suse.de
- ASoC: meson: axg-fifo: fix irq scheduling issue with PREEMPT_RT
  (git-fixes).
- ASoC: SOF: Remove libraries from topology lookups (git-fixes).
- ASoC: codecs: wsa884x: Correct Soundwire ports mask (git-fixes).
- ASoC: codecs: wsa883x: Correct Soundwire ports mask (git-fixes).
- ASoC: codecs: wsa881x: Correct Soundwire ports mask (git-fixes).
- ASoC: codecs: wcd938x-sdw: Correct Soundwire ports mask
  (git-fixes).
- ALSA: usb-audio: Re-add ScratchAmp quirk entries (git-fixes).
- ASoC: meson: axg-fifo: fix irq scheduling issue with PREEMPT_RT
  (git-fixes).
- ASoC: SOF: Remove libraries from topology lookups (git-fixes).
- ASoC: codecs: wsa884x: Correct Soundwire ports mask (git-fixes).
- ASoC: codecs: wsa883x: Correct Soundwire ports mask (git-fixes).
- ASoC: codecs: wsa881x: Correct Soundwire ports mask (git-fixes).
- ASoC: codecs: wcd938x-sdw: Correct Soundwire ports mask
  (git-fixes).
- ALSA: usb-audio: Re-add ScratchAmp quirk entries (git-fixes).
- commit cdc2939
* Fri Aug  9 2024 mpdesouza@suse.com
- kernel-binary.spec.in: Enable klp_symbols on openSUSE Tumbleweed (boo#1229042).
  After the Jump project the kernel used by SLE and openSUSE Leap are the
  same. As consequence the klp_symbols variable is set, enabling
  kernel-default-livepatch-devel on both SLE and openSUSE.
  The current rules to avoid enabling the package exclude openSUSE
  Tumbleweed alone, which doesn't makes sense for now. Enabling
  kernel-default-livepatch-devel on TW makes it easier to test the
  creation of kernel livepatches of the next SLE versions.
- commit fd0b293
* Fri Aug  9 2024 tiwai@suse.de
- Split kABI workaround of recent hyperv fixes (bsc#1229040, bsc#1225745, CVE-2024-36911, bsc#1225717, CVE-2024-36910, bsc#1225744, CVE-2024-36909)
- commit 3639306
* Fri Aug  9 2024 tiwai@suse.de
- Yet more build fix without patches.kabi (bsc#1226502)
- commit 6bc3429
* Fri Aug  9 2024 tiwai@suse.de
- Fix build errors without patches.kabi (bsc#1226502)
  Now patches.suse/x86-Stop-using-weak-symbols-for-__iowrite32_copy.patch
  has a full backport and later partially reverted via
  patches.kabi/kabi-partial-revert-commit-20516d6e51dd.patch
- commit 44c5e90
* Fri Aug  9 2024 mfranc@suse.cz
- landlock: Fix d_parent walk (CVE-2024-40938 bsc#1227840).
- commit 36de641
* Fri Aug  9 2024 mfranc@suse.cz
- net: fix sk_memory_allocated_{add|sub} vs softirqs
  (bsc#1228757).
- commit a963c0f
* Fri Aug  9 2024 msuchanek@suse.de
- minmax: fix up min3() and max3() too (bsc#1229024).
- minmax: improve macro expansion and type checking (bsc#1229024).
- minmax: simplify min()/max()/clamp() implementation
  (bsc#1229024).
- minmax: don't use max() in situations that want a C constant
  expression (bsc#1229024).
- minmax: make generic MIN() and MAX() macros available everywhere
  (bsc#1229024).
- minmax: simplify and clarify min_t()/max_t() implementation
  (bsc#1229024).
- minmax: add a few more MIN_T/MAX_T users (bsc#1229024).
- minmax: avoid overly complicated constant expressions in VM code
  (bsc#1229024).
- drm/radeon/evergreen_cs: Clean up errors in evergreen_cs.c
  (bsc#1229024).
- commit c64c296
* Fri Aug  9 2024 jslaby@suse.cz
- Update
  patches.suse/ALSA-emux-improve-patch-ioctl-data-validation.patch
  (stable-fixes CVE-2024-42097 bsc#1228766).
- Update
  patches.suse/ASoC-SOF-Intel-hda-fix-null-deref-on-system-suspend-.patch
  (git-fixes CVE-2024-41037 bsc#1228508).
- Update
  patches.suse/ASoC-amd-acp-add-a-null-check-for-chip_pdev-structur.patch
  (git-fixes CVE-2024-42074 bsc#1228481).
- Update
  patches.suse/ASoC-fsl-asoc-card-set-priv-pdev-before-using-it.patch
  (git-fixes CVE-2024-42089 bsc#1228450).
- Update
  patches.suse/Bluetooth-ISO-Check-socket-flag-instead-of-hcon.patch
  (git-fixes CVE-2024-42141 bsc#1228502).
- Update
  patches.suse/Bluetooth-Ignore-too-large-handle-values-in-BIG.patch
  (git-fixes CVE-2024-42133 bsc#1228511).
- Update
  patches.suse/Bluetooth-hci_core-cancel-all-works-upon-hci_unregis.patch
  (stable-fixes CVE-2024-41063 bsc#1228580).
- Update
  patches.suse/Bluetooth-qca-Fix-BT-enable-failure-again-for-QCA639.patch
  (git-fixes CVE-2024-42137 bsc#1228563).
- Update patches.suse/PCI-MSI-Fix-UAF-in-msi_capability_init.patch
  (git-fixes CVE-2024-41096 bsc#1228479).
- Update
  patches.suse/RDMA-restrack-Fix-potential-invalid-address-access.patch
  (git-fixes CVE-2024-42080 bsc#1228673).
- Update
  patches.suse/USB-core-Fix-duplicate-endpoint-bug-by-clearing-rese.patch
  (git-fixes CVE-2024-41035 bsc#1228485).
- Update patches.suse/USB-serial-mos7840-fix-crash-on-resume.patch
  (git-fixes CVE-2024-42244 bsc#1228967).
- Update
  patches.suse/ata-libata-core-Fix-null-pointer-dereference-on-erro.patch
  (git-fixes CVE-2024-41098 bsc#1228467).
- Update
  patches.suse/bluetooth-hci-disallow-setting-handle-bigger-than-HC.patch
  (git-fixes CVE-2024-42132 bsc#1228492).
- Update
  patches.suse/bpf-Fail-bpf_timer_cancel-when-callback-is-being-can.patch
  (bsc#1228531 CVE-2024-41045 CVE-2024-42239 bsc#1228979).
- Update
  patches.suse/can-mcp251xfd-fix-infinite-loop-when-xmit-fails.patch
  (git-fixes CVE-2024-41088 bsc#1228469).
- Update
  patches.suse/cdrom-rearrange-last_media_change-check-to-avoid-uni.patch
  (stable-fixes CVE-2024-42136 bsc#1228758).
- Update
  patches.suse/crypto-aead-cipher-zeroize-key-buffer-after-use.patch
  (stable-fixes CVE-2024-42229 bsc#1228708).
- Update
  patches.suse/crypto-ecdh-explicitly-zeroize-private_key.patch
  (stable-fixes CVE-2024-42098 bsc#1228779).
- Update
  patches.suse/drm-amd-display-ASSERT-when-failing-to-find-index-by.patch
  (stable-fixes CVE-2024-42117 bsc#1228582).
- Update
  patches.suse/drm-amd-display-Check-index-msg_id-before-read-or-wr.patch
  (stable-fixes CVE-2024-42121 bsc#1228590).
- Update
  patches.suse/drm-amd-display-Check-pipe-offset-before-setting-vbl.patch
  (stable-fixes CVE-2024-42120 bsc#1228588).
- Update
  patches.suse/drm-amd-display-Fix-array-index-out-of-bounds-in-dml.patch
  (stable-fixes CVE-2024-41061 bsc#1228572).
- Update
  patches.suse/drm-amd-display-Fix-overlapping-copy-within-dml_core.patch
  (stable-fixes CVE-2024-42227 bsc#1228707).
- Update
  patches.suse/drm-amd-display-Skip-finding-free-audio-for-unknown-.patch
  (stable-fixes CVE-2024-42119 bsc#1228584).
- Update
  patches.suse/drm-amd-display-Skip-pipe-if-the-pipe-idx-not-set-pr.patch
  (stable-fixes CVE-2024-42064 bsc#1228586).
- Update
  patches.suse/drm-amdgpu-Fix-signedness-bug-in-sdma_v4_0_process_t.patch
  (git-fixes CVE-2024-41022 bsc#1228429).
- Update
  patches.suse/drm-amdgpu-Using-uninitialized-value-size-when-calli.patch
  (stable-fixes CVE-2024-42228 bsc#1228667).
- Update
  patches.suse/drm-amdgpu-avoid-using-null-object-of-framebuffer.patch
  (stable-fixes CVE-2024-41093 bsc#1228660).
- Update
  patches.suse/drm-fbdev-dma-Only-set-smem_start-is-enable-per-modu.patch
  (git-fixes CVE-2024-41094 bsc#1228458).
- Update
  patches.suse/drm-i915-gt-Fix-potential-UAF-by-revoke-of-fence-reg.patch
  (git-fixes CVE-2024-41092 bsc#1228483).
- Update
  patches.suse/drm-lima-fix-shared-irq-handling-on-driver-remove.patch
  (stable-fixes CVE-2024-42127 bsc#1228721).
- Update
  patches.suse/drm-nouveau-dispnv04-fix-null-pointer-dereference-in-66edf3f.patch
  (stable-fixes CVE-2024-41095 bsc#1228662).
- Update
  patches.suse/drm-nouveau-dispnv04-fix-null-pointer-dereference-in.patch
  (stable-fixes CVE-2024-41089 bsc#1228658).
- Update
  patches.suse/drm-nouveau-fix-null-pointer-dereference-in-nouveau_.patch
  (git-fixes CVE-2024-42101 bsc#1228495).
- Update
  patches.suse/drm-panel-ilitek-ili9881c-Fix-warning-with-GPIO-cont.patch
  (stable-fixes CVE-2024-42087 bsc#1228677).
- Update
  patches.suse/drm-radeon-check-bo_va-bo-is-non-NULL-before-using-i.patch
  (stable-fixes CVE-2024-41060 bsc#1228567).
- Update
  patches.suse/filelock-fix-potential-use-after-free-in-posix_lock_inode.patch
  (git-fixes CVE-2024-41049 bsc#1228486).
- Update
  patches.suse/firmware-cs_dsp-Fix-overflow-checking-of-wmfw-header.patch
  (git-fixes CVE-2024-41039 bsc#1228515).
- Update
  patches.suse/firmware-cs_dsp-Prevent-buffer-overrun-when-processi.patch
  (git-fixes CVE-2024-41038 bsc#1228509).
- Update
  patches.suse/firmware-cs_dsp-Return-error-if-block-header-overflo.patch
  (git-fixes CVE-2024-42238 bsc#1228991).
- Update
  patches.suse/firmware-cs_dsp-Use-strnlen-on-name-fields-in-V1-wmf.patch
  (git-fixes CVE-2024-41056 bsc#1228480).
- Update
  patches.suse/firmware-cs_dsp-Validate-payload-length-before-proce.patch
  (git-fixes CVE-2024-42237 bsc#1228992).
- Update
  patches.suse/genirq-cpuhotplug-x86-vector-Prevent-vector-leak-dur.patch
  (git-fixes CVE-2024-31076 bsc#1226765).
- Update
  patches.suse/gpio-davinci-Validate-the-obtained-number-of-IRQs.patch
  (git-fixes CVE-2024-42092 bsc#1228447).
- Update
  patches.suse/gpio-pca953x-fix-pca953x_irq_bus_sync_unlock-race.patch
  (stable-fixes CVE-2024-42253 bsc#1229005).
- Update
  patches.suse/i2c-pnx-Fix-potential-deadlock-warning-from-del_time.patch
  (git-fixes CVE-2024-42153 bsc#1228510).
- Update
  patches.suse/iio-chemical-bme680-Fix-overflows-in-compensate-func.patch
  (git-fixes CVE-2024-42086 bsc#1228452).
- Update
  patches.suse/jffs2-Fix-potential-illegal-address-access-in-jffs2_free_inode.patch
  (git-fixes CVE-2024-42115 bsc#1228656).
- Update
  patches.suse/libceph-fix-race-between-delayed_work-and-ceph_monc_s.patch
  (bsc#1228192 CVE-2024-42232 bsc#1228959).
- Update
  patches.suse/media-dvb-frontends-tda10048-Fix-integer-overflow.patch
  (stable-fixes CVE-2024-42223 bsc#1228726).
- Update
  patches.suse/misc-fastrpc-Fix-memory-leak-in-audio-daemon-attach-.patch
  (git-fixes CVE-2024-41025 bsc#1228527).
- Update
  patches.suse/misc-fastrpc-Restrict-untrusted-app-to-attach-to-pri.patch
  (git-fixes CVE-2024-41024 bsc#1228525).
- Update
  patches.suse/mm-Avoid-overflows-in-dirty-throttling-logic.patch
  (bsc#1222364 CVE-2024-26720 CVE-2024-42131 bsc#1228650).
- Update
  patches.suse/msft-hv-3022-net-mana-Fix-possible-double-free-in-error-handling-.patch
  (git-fixes CVE-2024-42069 bsc#1228463).
- Update
  patches.suse/net-can-j1939-Initialize-unused-data-in-j1939_send_o.patch
  (git-fixes CVE-2024-42076 bsc#1228484).
- Update
  patches.suse/net-can-j1939-enhanced-error-handling-for-tightly-re.patch
  (git-fixes CVE-2023-52887 bsc#1228426).
- Update
  patches.suse/nfc-nci-Add-the-inconsistency-check-between-the-inpu.patch
  (stable-fixes CVE-2024-42130 bsc#1228687).
- Update
  patches.suse/nilfs2-add-missing-check-for-inode-numbers-on-direct.patch
  (stable-fixes CVE-2024-42104 bsc#1228654).
- Update patches.suse/nvme-avoid-double-free-special-payload.patch
  (git-fixes CVE-2024-41073 bsc#1228635).
- Update patches.suse/nvmet-always-initialize-cqe.result.patch
  (git-fixes CVE-2024-41079 bsc#1228615).
- Update
  patches.suse/nvmet-fix-a-possible-leak-when-destroy-a-ctrl-during.patch
  (git-fixes CVE-2024-42152 bsc#1228724).
- Update
  patches.suse/ocfs2-fix-DIO-failure-due-to-insufficient-transaction-credits.patch
  (git-fixes CVE-2024-42077 bsc#1228516).
- Update
  patches.suse/ocfs2-strict-bound-check-before-memcmp-in-ocfs2_xatt.patch
  (bsc#1228410 CVE-2024-41016).
- Update patches.suse/orangefs-fix-out-of-bounds-fsid-access.patch
  (git-fixes CVE-2024-42143 bsc#1228748).
- Update
  patches.suse/pinctrl-fix-deadlock-in-create_pinctrl-when-handling.patch
  (git-fixes CVE-2024-42090 bsc#1228449).
- Update
  patches.suse/platform-x86-toshiba_acpi-Fix-array-out-of-bounds-ac.patch
  (git-fixes CVE-2024-41028 bsc#1228539).
- Update
  patches.suse/powerpc-Avoid-nmi_enter-nmi_exit-in-real-mode-interr.patch
  (bsc#1221645 ltc#205739 bsc#1223191 CVE-2024-42126 bsc#1228718).
- Update
  patches.suse/powerpc-pseries-Fix-scv-instruction-crash-with-kexec.patch
  (bsc#1194869 CVE-2024-42230 bsc#1228489).
- Update
  patches.suse/thermal-drivers-mediatek-lvts_thermal-Check-NULL-ptr.patch
  (stable-fixes CVE-2024-42144 bsc#1228666).
- Update
  patches.suse/usb-atm-cxacru-fix-endpoint-checking-in-cxacru_bind.patch
  (git-fixes CVE-2024-41097 bsc#1228513).
- Update
  patches.suse/usb-dwc3-core-remove-lock-of-otg-mode-during-gadget-.patch
  (git-fixes CVE-2024-42085 bsc#1228456).
- Update
  patches.suse/usb-gadget-configfs-Prevent-OOB-read-write-in-usb_st.patch
  (stable-fixes CVE-2024-42236 bsc#1228964).
- Update
  patches.suse/usb-xhci-prevent-potential-failure-in-handle_tx_even.patch
  (stable-fixes CVE-2024-42226 bsc#1228709).
- Update
  patches.suse/wifi-cfg80211-restrict-NL80211_ATTR_TXQ_QUANTUM-valu.patch
  (git-fixes CVE-2024-42114 bsc#1228564).
- Update
  patches.suse/wifi-cfg80211-wext-add-extra-SIOCSIWSCAN-data-check.patch
  (stable-fixes CVE-2024-41072 bsc#1228626).
- Update
  patches.suse/wifi-mac80211-Avoid-address-calculations-via-out-of-.patch
  (stable-fixes CVE-2024-41071 bsc#1228625).
- Update
  patches.suse/wifi-mt76-replace-skb_put-with-skb_put_zero.patch
  (stable-fixes CVE-2024-42225 bsc#1228710).
- Update
  patches.suse/wifi-rtw89-fw-scan-offload-prohibit-all-6-GHz-channe.patch
  (bsc#1227149 CVE-2024-42125 bsc#1228674).
- Update
  patches.suse/x86-bhi-Avoid-warning-in-DB-handler-due-to-BHI-mitigation
  (git-fixes CVE-2024-42240 bsc#1228966).
  Add CVE references.
- commit dfa8582
* Fri Aug  9 2024 tiwai@suse.de
- Bluetooth: hci_sync: avoid dup filtering when passive scanning
  with adv monitor (git-fixes).
- Bluetooth: l2cap: always unlock channel in
  l2cap_conless_channel() (git-fixes).
- net: usb: qmi_wwan: fix memory leak for not ip packets
  (git-fixes).
- padata: Fix possible divide-by-0 panic in padata_mt_helper()
  (git-fixes).
- kcov: properly check for softirq context (git-fixes).
- commit fc99a65
* Fri Aug  9 2024 tbogendoerfer@suse.de
- wireguard: allowedips: avoid unaligned 64-bit memory accesses
  (CVE-2024-42247 bsc#1228988).
- commit 12abe6d
* Fri Aug  9 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add netlink helper library (bsc#1228021
  CVE-2024-41010).
- Fix BPF selftest build failure
- commit c3e9de4
* Fri Aug  9 2024 jlee@suse.com
- x86/numa: Fix the sort compare func used in numa_fill_memblks()
  (git-fixes).
- x86/numa: Fix the address overlap check in numa_fill_memblks()
  (git-fixes).
- commit b42baa2
* Thu Aug  8 2024 davide.benini@suse.com
- inet_diag: Initialize pad field in struct inet_diag_req_v2
  (CVE-2024-42106 bsc#1228493).
- commit 87d015b
* Thu Aug  8 2024 jlee@suse.com
- x86/numa: Fix SRAT lookup of CFMWS ranges with
  numa_fill_memblks() (git-fixes).
- ACPI/NUMA: Apply SRAT proximity domain to entire CFMWS window
  (git-fixes).
- x86/numa: Introduce numa_fill_memblks() (git-fixes).
- commit 7f40727
* Thu Aug  8 2024 jlee@suse.com
- ACPI: processor_idle: use raw_safe_halt() in
  acpi_idle_play_dead() (git-fixes).
- perf/smmuv3: Enable HiSilicon Erratum 162001900 quirk for
  HIP08/09 (git-fixes).
- commit 23f94eb
* Thu Aug  8 2024 duwe@suse.de
- Update
  patches.suse/crypto-hisilicon-debugfs-Fix-debugfs-uninit-process-.patch
  (bsc#1228764 CVE-2024-42147).
- commit 9b42aa7
* Thu Aug  8 2024 jslaby@suse.cz
- serial: 8250_omap: Fix Errata i2310 with RX FIFO level check
  (bsc#1228446 CVE-2024-42095).
- commit 6d3406b
* Thu Aug  8 2024 jslaby@suse.cz
- serial: 8250_omap: Implementation of Errata i2310 (bsc#1228446
  CVE-2024-42095).
- commit a3bd324
* Thu Aug  8 2024 mfranc@suse.cz
- net/iucv: fix use after free in iucv_sock_close() (bsc#1228973).
- commit c3ed1a0
* Thu Aug  8 2024 mfranc@suse.cz
- s390/sclp: Fix sclp_init() cleanup on failure (bsc#1228579
  CVE-2024-41068).
- commit a8db9f2
* Thu Aug  8 2024 mvetter@suse.com
- config.sh: generate and install compile_commands.json (bsc#1228971)
  This file contains the command line options used to compile every C file.
  It's useful for the livepatching team.
- kernel-binary: generate and install compile_commands.json (bsc#1228971)
  This file contains the command line options used to compile every C file.
  It's useful for the livepatching team.
- commit 15eff3e
* Thu Aug  8 2024 jslaby@suse.cz
- irqdomain: Fixed unbalanced fwnode get and put (git-fixes).
- genirq/cpuhotplug, x86/vector: Prevent vector leak during CPU
  offline (git-fixes).
- genirq/generic_chip: Make irq_remove_generic_chip() irqdomain
  aware (git-fixes).
- genirq/matrix: Exclude managed interrupts in
  irq_matrix_allocated() (git-fixes).
- commit 592adb3
* Thu Aug  8 2024 shung-hsi.yu@suse.com
- selftests/bpf: Test pinning bpf timer to a core (bsc#1228531
  CVE-2024-41045).
- Refresh patches.suse/selftests-bpf-Test-racing-between-bpf_timer_cancel_a.patch
- commit 1026c30
* Thu Aug  8 2024 shung-hsi.yu@suse.com
- bpf: Add ability to pin bpf timer to calling CPU (bsc#1228531
  CVE-2024-41045).
- commit 060adb3
* Thu Aug  8 2024 tiwai@suse.de
- power: supply: qcom_battmgr: return EAGAIN when firmware
  service is not up (git-fixes).
- power: supply: axp288_charger: Round constant_charge_voltage
  writes down (git-fixes).
- power: supply: axp288_charger: Fix constant_charge_voltage
  writes (git-fixes).
- commit 5ff04d3
* Thu Aug  8 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add timer lockup selftest (bsc#1228531
  CVE-2024-41045).
- bpf: Defer work in bpf_timer_cancel_and_free (bsc#1228531
  CVE-2024-41045).
- bpf: Fail bpf_timer_cancel when callback is being cancelled
  (bsc#1228531 CVE-2024-41045).
- bpf: replace bpf_timer_cancel_and_free with a generic helper
  (bsc#1228531 CVE-2024-41045).
- bpf: replace bpf_timer_set_callback with a generic helper
  (bsc#1228531 CVE-2024-41045).
- bpf: replace bpf_timer_init with a generic helper (bsc#1228531
  CVE-2024-41045).
- bpf: make timer data struct more generic (bsc#1228531
  CVE-2024-41045).
- bpf: Check map->usercnt after timer->timer is assigned
  (bsc#1228531 CVE-2024-41045).
- commit a65dc5b
* Wed Aug  7 2024 tiwai@suse.de
- Move upstreamed sound patches into sorted section
- commit df9598d
* Wed Aug  7 2024 tiwai@suse.de
- ASoC: amd: yc: Add quirk entry for OMEN by HP Gaming Laptop
  16-n0xxx (bsc#1227182).
- commit 645364b
* Wed Aug  7 2024 sjaeckel@suse.de
- tcp: avoid too many retransmit packets (CVE-2024-41007
  bsc#1227863).
- commit 8f47fe6
* Wed Aug  7 2024 tbogendoerfer@suse.de
- mlxsw: core_linecards: Fix double memory deallocation in case
  of invalid INI file (CVE-2024-42138 bsc#1228500).
- ice: Don't process extts if PTP is disabled (CVE-2024-42107
  bsc#1228494).
- ice: Fix improper extts handling (CVE-2024-42139 bsc#1228503).
- net: ntb_netdev: Move ntb_netdev_rx_handler() to call netif_rx()
  from __netif_rx() (CVE-2024-42110 bsc#1228501).
- net: txgbe: initialize num_q_vectors for MSI/INTx interrupts
  (CVE-2024-42113 bsc#1228568).
- bnx2x: Fix multiple UBSAN array-index-out-of-bounds
  (CVE-2024-42148 bsc#1228487).
- net/mlx5: E-switch, Create ingress ACL when needed
  (CVE-2024-42142 bsc#1228491).
- mlxsw: spectrum_buffers: Fix memory corruptions on Spectrum-4
  systems (CVE-2024-42073 bsc#1228457).
- gve: Account for stopped queues when reading NIC stats
  (CVE-2024-42162 bsc#1228706).
- commit e94d07a
* Wed Aug  7 2024 mkoutny@suse.com
- packaging: Add case-sensitive perl option parsing
  A recent change in Getopt::Long [1]:
  Changes in version 2.55
  - ----------------------
  * Fix long standing bug that duplicate options were not detected
  when the options differ in case while ignore_case is in effect.
  This will now yield a warning and become a fatal error in a future
  release.
  perl defaults to ignore_case by default, switch it off to avoid
  accidental misparsing of options.
  This was suggested after similar change in scripts/.
- commit e978477
* Wed Aug  7 2024 shung-hsi.yu@suse.com
- xdp: Remove WARN() from __xdp_reg_mem_model() (bsc#1228482
  CVE-2024-42082).
- commit 73e7677
* Wed Aug  7 2024 iivanov@suse.de
- arm64: jump_label: Ensure patched jump_labels are visible to all CPUs (git-fixes)
- commit 2480247
* Wed Aug  7 2024 iivanov@suse.de
- KVM: arm64: Fix clobbered ELR in sync abort/SError (git-fixes)
- commit 90dba9e
* Wed Aug  7 2024 iivanov@suse.de
- bpf, arm64: Fix trampoline for BPF_TRAMP_F_CALL_ORIG (git-fixes)
- commit e10a18b
* Wed Aug  7 2024 iivanov@suse.de
- arm64: armv8_deprecated: Fix warning in isndep cpuhp starting process (git-fixes)
- commit bae6c4b
* Wed Aug  7 2024 dwagner@suse.de
- nvme-pci: do not directly handle subsys reset fallout
  (bsc#1220066).
- commit 2082e5f
* Wed Aug  7 2024 tiwai@suse.de
- platform/x86/intel/ifs: Initialize union ifs_status to zero
  (git-fixes).
- commit b291cc1
* Tue Aug  6 2024 lduncan@suse.com
- scsi: qedi: Fix crash while reading debugfs attribute
  (bsc#1227929 CVE-2024-40978).
- block/ioctl: prefer different overflow check (bsc#1227867
  CVE-2024-41000).
- commit 4cc5e60
* Tue Aug  6 2024 davide.benini@suse.com
- tipc: force a dst refcount before doing decryption (CVE-2024-40983 bsc#1227819).
- commit cee1bad
* Tue Aug  6 2024 davide.benini@suse.com
- net/sched: act_api: fix possible infinite loop in tcf_idr_check_alloc()
  (CVE-2024-40995 bsc#1227830).
- commit 0580a17
* Tue Aug  6 2024 ohering@suse.de
- PCI: hv: Return zero, not garbage, when reading
  PCI_INTERRUPT_PIN (git-fixes).
- RDMA/mana_ib: Use virtual address in dma regions for MRs
  (git-fixes).
- commit 9336dc6
* Tue Aug  6 2024 shung-hsi.yu@suse.com
- bpf: Avoid uninitialized value in BPF_CORE_READ_BITFIELD
  (bsc#1228756 CVE-2024-42161).
- commit 64d3ad2
* Tue Aug  6 2024 tiwai@suse.de
- ASoC: topology: Fix route memory corruption (CVE-2024-41069
  bsc#1228644).
- ASoC: topology: Clean up route loading (CVE-2024-41069
  bsc#1228644).
- commit 30d44d4
* Tue Aug  6 2024 heming.zhao@suse.com
- md-cluster: keeping kabi compatibility for upstream commit
  35a0a409fa26 (bsc#1223395).
- md-cluster: fix no recovery job when adding/re-adding a disk
  (bsc#1223395).
- md-cluster: fix hanging issue while a new disk adding
  (bsc#1223395).
- commit dac906f
* Tue Aug  6 2024 tonyj@suse.de
- tools/perf: Fix timing issue with parallel threads in perf
  bench wake-up-parallel (bsc#1227747).
- tools/perf: Fix perf bench epoll to enable the run when some
  CPU's are offline (bsc#1227747).
- tools/perf: Fix perf bench futex to enable the run when some
  CPU's are offline (bsc#1227747).
- commit 7bc1e4f
* Mon Aug  5 2024 msuchanek@suse.de
- powerpc: fix a file leak in kvm_vcpu_ioctl_enable_cap()
  (bsc#1194869).
- KVM: PPC: Book3S HV: Fix the set_one_reg for MMCR3
  (bsc#1194869).
- commit f36d7ca
* Mon Aug  5 2024 msuchanek@suse.de
- KVM: PPC: Book3S HV: Handle pending exceptions on guest entry
  with MSR_EE (bsc#1215199).
- commit 6051d0b
* Mon Aug  5 2024 tbogendoerfer@suse.de
- liquidio: Adjust a NULL pointer handling path in
  lio_vf_rep_copy_packet (CVE-2024-39506 bsc#1227729).
- commit 6f4e943
* Mon Aug  5 2024 dwagner@suse.de
- kabi/severity: add nvme common code
  The nvme common code is also allowed to change the data structures, there
  are only internal users.
- commit 3abdbd5
* Mon Aug  5 2024 ddiss@suse.de
- apparmor: unpack transition table if dfa is not present
  (bsc#1226031).
- commit 10a598f
* Mon Aug  5 2024 dwagner@suse.de
- scsi: lpfc: Update lpfc version to 14.4.0.3 (bsc#1228857).
- scsi: lpfc: Revise lpfc_prep_embed_io routine with proper
  endian macro usages (bsc#1228857).
- scsi: lpfc: Fix incorrect request len mbox field when setting
  trunking via sysfs (bsc#1228857).
- scsi: lpfc: Handle mailbox timeouts in lpfc_get_sfp_info
  (bsc#1228857).
- scsi: lpfc: Fix handling of fully recovered fabric node in
  dev_loss callbk (bsc#1228857).
- scsi: lpfc: Relax PRLI issue conditions after GID_FT response
  (bsc#1228857).
- scsi: lpfc: Allow DEVICE_RECOVERY mode after RSCN receipt if
  in PRLI_ISSUE state (bsc#1228857).
- scsi: lpfc: Cancel ELS WQE instead of issuing abort when SLI
  port is inactive (bsc#1228857).
- commit c4b9763
* Mon Aug  5 2024 dwagner@suse.de
- scsi: qla2xxx: Convert comma to semicolon (bsc#1228850).
- scsi: qla2xxx: Update version to 10.02.09.300-k (bsc#1228850).
- scsi: qla2xxx: Use QP lock to search for bsg (bsc#1228850).
- scsi: qla2xxx: Reduce fabric scan duplicate code (bsc#1228850).
- scsi: qla2xxx: Fix optrom version displayed in FDMI
  (bsc#1228850).
- scsi: qla2xxx: During vport delete send async logout explicitly
  (bsc#1228850).
- scsi: qla2xxx: Complete command early within lock (bsc#1228850).
- scsi: qla2xxx: Fix flash read failure (bsc#1228850).
- scsi: qla2xxx: Return ENOBUFS if sg_cnt is more than one for
  ELS cmds (bsc#1228850).
- scsi: qla2xxx: Fix for possible memory corruption (bsc#1228850).
- scsi: qla2xxx: validate nvme_local_port correctly (bsc#1228850).
- scsi: qla2xxx: Unable to act on RSCN for port online
  (bsc#1228850).
- scsi: qla2xxx: Remove unused struct 'scsi_dif_tuple'
  (bsc#1228850).
- scsi: qla2xxx: Fix debugfs output for fw_resource_count
  (bsc#1228850).
- scsi: qla2xxx: Indent help text (bsc#1228850).
- scsi: qla2xxx: Drop driver owner assignment (bsc#1228850).
- scsi: qla2xxx: Avoid possible run-time warning with long
  model_num (bsc#1228850).
- string.h: Introduce memtostr() and memtostr_pad() (bsc#1228849).
- commit 072d194
* Mon Aug  5 2024 dwagner@suse.de
- nvme-pci: add missing condition check for existence of mapped
  data (git-fixes).
- nvme-pci: Fix the instructions for disabling power management
  (git-fixes).
- nvmet-auth: fix nvmet_auth hash error handling (git-fixes).
- nvmet: make 'tsas' attribute idempotent for RDMA (git-fixes).
- nvme: fixup comment for nvme RDMA Provider Type (git-fixes).
- nvmet: do not return 'reserved' for empty TSAS values
  (git-fixes).
- nvme: fix NVME_NS_DEAC may incorrectly identifying the disk
  as EXT_LBA (git-fixes).
- nvmet: always initialize cqe.result (git-fixes).
- nvme: avoid double free special payload (git-fixes).
- nvmet: fix a possible leak when destroy a ctrl during qp
  establishment (git-fixes).
- nvme: adjust multiples of NVME_CTRL_PAGE_SIZE in offset
  (git-fixes).
- nvme-multipath: find NUMA path only for online numa-node
  (git-fixes).
- commit 7935501
* Mon Aug  5 2024 mkubecek@suse.cz
- check-for-config-changes: ignore also GCC_ASM_GOTO_OUTPUT_BROKEN
  Mainline commit f2f6a8e88717 ("init/Kconfig: remove
  CONFIG_GCC_ASM_GOTO_OUTPUT_WORKAROUND") replaced
  GCC_ASM_GOTO_OUTPUT_WORKAROUND with GCC_ASM_GOTO_OUTPUT_BROKEN. Ignore both
  when checking config changes.
- commit b60be3e
* Sun Aug  4 2024 nmorey@suse.com
- RDMA: Fix netdev tracker in ib_device_set_netdev (git-fixes)
- commit 3130571
* Sun Aug  4 2024 nmorey@suse.com
- bnxt_re: Fix imm_data endianness (git-fixes)
- commit 49ce7dd
* Sun Aug  4 2024 nmorey@suse.com
- RDMA/hns: Fix mbx timing out before CMD execution is completed (git-fixes)
- commit 09de886
* Sun Aug  4 2024 nmorey@suse.com
- RDMA/hns: Fix insufficient extend DB for VFs. (git-fixes)
- commit 9e511e1
* Sun Aug  4 2024 nmorey@suse.com
- RDMA/hns: Fix undifined behavior caused by invalid max_sge (git-fixes)
- commit 75c8a8f
* Sun Aug  4 2024 nmorey@suse.com
- RDMA/hns: Fix shift-out-bounds when max_inline_data is 0 (git-fixes)
- commit f76d2ac
* Sun Aug  4 2024 nmorey@suse.com
- RDMA/hns: Fix missing pagesize and alignment check in FRMR (git-fixes)
- commit 3200c5d
* Sun Aug  4 2024 nmorey@suse.com
- RDMA/hns: Fix unmatch exception handling when init eq table fails (git-fixes)
- commit 1c3f5bc
* Sun Aug  4 2024 nmorey@suse.com
- RDMA/hns: Fix soft lockup under heavy CEQE load (git-fixes)
- commit bae3b01
* Sun Aug  4 2024 nmorey@suse.com
- RDMA/hns: Check atomic wr length (git-fixes)
- commit 53b999f
* Sun Aug  4 2024 nmorey@suse.com
- RDMA/device: Return error earlier if port in not valid (git-fixes)
- commit 1a6c9cf
* Sun Aug  4 2024 nmorey@suse.com
- RDMA/rxe: Don't set BTH_ACK_MASK for UC or UD QPs (git-fixes)
- commit ecbc61e
* Sun Aug  4 2024 nmorey@suse.com
- RDMA/mlx4: Fix truncated output warning in alias_GUID.c (git-fixes)
- commit 9a0a984
* Sun Aug  4 2024 nmorey@suse.com
- RDMA/mlx4: Fix truncated output warning in mad.c (git-fixes)
- commit e923a91
* Sun Aug  4 2024 nmorey@suse.com
- RDMA/cache: Release GID table even if leak is detected (git-fixes)
- commit e73316e
* Sun Aug  4 2024 nmorey@suse.com
- RDMA/mlx5: Set mkeys for dmabuf at PAGE_SIZE (git-fixes)
- commit ee50dd0
* Sun Aug  4 2024 nmorey@suse.com
- RDMA/iwcm: Fix a use-after-free related to destroying CM IDs (git-fixes)
- commit 6b71029
* Sun Aug  4 2024 nmorey@suse.com
- IB/core: Implement a limit on UMAD receive List (bsc#1228743 CVE-2024-42145)
- commit 673df57
* Sun Aug  4 2024 ailiop@suse.com
- xfs: convert comma to semicolon (git-fixes).
- commit 8f18daf
* Sun Aug  4 2024 ailiop@suse.com
- hfs: fix to initialize fields of hfs_inode_info after
  hfs_alloc_inode() (git-fixes).
- commit 1aa4511
* Sun Aug  4 2024 tiwai@suse.de
- kABI workaround for sound core UMP conversion (stable-fixes).
- commit b9e008a
* Sun Aug  4 2024 tiwai@suse.de
- ALSA: seq: ump: Explicitly reset RPN with Null RPN
  (stable-fixes).
- ALSA: seq: ump: Transmit RPN/NRPN message at each MSB/LSB data
  reception (stable-fixes).
- ALSA: seq: ump: Use the common RPN/bank conversion context
  (stable-fixes).
- ALSA: ump: Explicitly reset RPN with Null RPN (stable-fixes).
- ALSA: ump: Transmit RPN/NRPN message at each MSB/LSB data
  reception (stable-fixes).
- commit 508da4c
* Sun Aug  4 2024 tiwai@suse.de
- kabi/severities: ignore kABI for FireWire sound local symbols (bsc#1208783)
- commit 041506f
* Sun Aug  4 2024 tiwai@suse.de
- Drop doubly put References tags in sound patches
- commit 92b6eba
* Sun Aug  4 2024 tiwai@suse.de
- Revert "ALSA: firewire-lib: operate for period elapse event
  in process context" (bsc#1208783).
- commit 2045d7f
* Sun Aug  4 2024 tiwai@suse.de
- Revert "ALSA: firewire-lib: obsolete workqueue for period
  update" (bsc#1208783).
- commit 09a87ea
* Sun Aug  4 2024 tiwai@suse.de
- spi: microchip-core: switch to use modern name (stable-fixes).
- Refresh
  patches.suse/spi-microchip-core-defer-asserting-chip-select-until.patch.
- commit 31d15b3
* Sun Aug  4 2024 tiwai@suse.de
- spi: microchip-core: fix init function not setting the master
  and motorola modes (git-fixes).
- drm/amdgpu: reset vm state machine after gpu reset(vram lost)
  (stable-fixes).
- drm/amd/display: Check for NULL pointer (stable-fixes).
- drm/amdgpu/sdma5.2: Update wptr registers as well as doorbell
  (stable-fixes).
- efi/libstub: Zero initialize heap allocated struct screen_info
  (git-fixes).
- PCI: loongson: Enable MSI in LS7A Root Complex (stable-fixes).
- dev/parport: fix the array out-of-bounds risk (stable-fixes).
- clk: qcom: kpss-xcc: Return of_clk_add_hw_provider to transfer
  the error (git-fixes).
- clk: qcom: Park shared RCGs upon registration (git-fixes).
- clk: qcom: gpucc-sa8775p: Update wait_val fields for GPU GDSC's
  (git-fixes).
- clk: qcom: gpucc-sa8775p: Park RCG's clk source at XO during
  disable (git-fixes).
- clk: qcom: gpucc-sa8775p: Remove the CLK_IS_CRITICAL and
  ALWAYS_ON flags (git-fixes).
- clk: qcom: gcc-sa8775p: Update the GDSC wait_val fields and
  flags (git-fixes).
- clk: qcom: gpucc-sm8350: Park RCG's clk source at XO during
  disable (git-fixes).
- clk: qcom: camcc-sc7280: Add parent dependency to all camera
  GDSCs (git-fixes).
- clk: qcom: gcc-sc7280: Update force mem core bit for UFS ICE
  clock (git-fixes).
- clk: en7523: fix rate divider for slic and spi clocks
  (git-fixes).
- drm/etnaviv: don't block scheduler when GPU is still active
  (stable-fixes).
- media: uvcvideo: Add quirk for invalid dev_sof in Logitech C920
  (git-fixes).
- media: uvcvideo: Quirk for invalid dev_sof in Logitech C922
  (stable-fixes).
- ata: libata-scsi: Honor the D_SENSE bit for CK_COND=1 and no
  error (stable-fixes).
- ata: libata-scsi: Do not overwrite valid sense data when
  CK_COND=1 (stable-fixes).
- Bluetooth: btusb: Add Realtek RTL8852BE support ID 0x13d3:0x3591
  (stable-fixes).
- Bluetooth: btusb: Add RTL8852BE device 0489:e125 to device
  tables (stable-fixes).
- wifi: rtw88: usb: Fix disconnection after beacon loss
  (stable-fixes).
- media: uvcvideo: Disable autosuspend for Insta360 Link
  (stable-fixes).
- sbitmap: use READ_ONCE to access map->word (stable-fixes).
- Bluetooth: Add device 13d3:3572 IMC Networks Bluetooth Radio
  (stable-fixes).
- commit 5fabaee
* Sat Aug  3 2024 tiwai@suse.de
- ALSA: hda/realtek: Add quirk for Acer Aspire E5-574G
  (stable-fixes).
- commit ae4c81e
* Sat Aug  3 2024 tiwai@suse.de
- ALSA: hda: Conditionally use snooping for AMD HDMI (git-fixes).
- ALSA: usb-audio: Correct surround channels in UAC1 channel map
  (git-fixes).
- ALSA: seq: ump: Optimize conversions from SysEx to UMP
  (git-fixes).
- ALSA: hda: conexant: Fix headset auto detect fail in the
  polling mode (git-fixes).
- drm/vmwgfx: Fix overlay when using Screen Targets (git-fixes).
- drm/vmwgfx: Fix a deadlock in dma buf fence polling (git-fixes).
- drm/virtio: Fix type of dma-fence context variable (git-fixes).
- drm/nouveau: prime: fix refcount underflow (git-fixes).
- drm/i915: Fix possible int overflow in skl_ddi_calculate_wrpll()
  (git-fixes).
- drm/i915/hdcp: Fix HDCP2_STREAM_STATUS macro (git-fixes).
- i915/perf: Remove code to update PWR_CLK_STATE for gen12
  (git-fixes).
- commit 581e0b5
* Sat Aug  3 2024 krisman@suse.de
- ptp: fix integer overflow in max_vclocks_store (bsc#1227829
  CVE-2024-40994).
- commit f2dc01f
* Fri Aug  2 2024 krisman@suse.de
- Update
  patches.suse/79b5b4b18bc8-mlxsw-spectrum_acl_tcam-Fix-possible-use-after-free-.patch
  (CVE-2024-35854 bsc#1224636 CVE-2024-35855 bsc#1224694).
- Update
  patches.suse/ACPICA-Revert-ACPICA-avoid-Info-mapping-multiple-BAR.patch
  (git-fixes CVE-2024-40984 bsc#1227820).
- Update
  patches.suse/ALSA-hda-cs35l41-Possible-null-pointer-dereference-i.patch
  (git-fixes CVE-2024-40964 bsc#1227818).
- Update
  patches.suse/ALSA-hda-cs35l56-Fix-lifetime-of-cs_dsp-instance.patch
  (git-fixes CVE-2024-39491 bsc#1227627).
- Update
  patches.suse/Bluetooth-hci_core-Fix-possible-buffer-overflow.patch
  (git-fixes CVE-2024-26889 bsc#1228195).
- Update
  patches.suse/HID-core-remove-unnecessary-WARN_ON-in-implement.patch
  (git-fixes CVE-2024-39509 bsc#1227733).
- Update
  patches.suse/HID-logitech-dj-Fix-memory-leak-in-logi_dj_recv_swit.patch
  (git-fixes CVE-2024-40934 bsc#1227796).
- Update
  patches.suse/KVM-SVM-WARN-on-vNMI-NMI-window-iff-NMIs-are-outrigh.patch
  (git-fixes CVE-2024-39483 bsc#1227494).
- Update
  patches.suse/KVM-arm64-Fix-circular-locking-dependency.patch
  (bsc#1222463 (CVE-2024-26691) CVE-2024-26691).
- Update
  patches.suse/RDMA-mlx5-Add-check-for-srq-max_sge-attribute.patch
  (git-fixes CVE-2024-40990 bsc#1227824).
- Update
  patches.suse/RDMA-rxe-Fix-responder-length-checking-for-UD-reques.patch
  (git-fixes CVE-2024-40992 bsc#1227826).
- Update
  patches.suse/SUNRPC-Fix-loop-termination-condition-in-gss_free_in.patch
  (git-fixes CVE-2024-36288 bsc#1226834).
- Update
  patches.suse/USB-class-cdc-wdm-Fix-CPU-lockup-caused-by-excessive.patch
  (git-fixes CVE-2024-40904 bsc#1227772).
- Update
  patches.suse/arm64-asm-bug-Add-.align-2-to-the-end-of-__BUG_ENTRY.patch
  (git-fixes CVE-2024-39488 bsc#1227618).
- Update
  patches.suse/ata-libata-core-Fix-double-free-on-error.patch
  (git-fixes CVE-2024-41087 bsc#1228740).
- Update
  patches.suse/ax25-Fix-refcount-imbalance-on-inbound-connections.patch
  (git-fixes CVE-2024-40910 bsc#1227832).
- Update
  patches.suse/batman-adv-bypass-empty-buckets-in-batadv_purge_orig.patch
  (stable-fixes CVE-2024-40981 bsc#1227864).
- Update
  patches.suse/btrfs-zoned-allocate-dummy-checksums-for-zoned-NODAT.patch
  (bsc#1223731 CVE-2024-26944 CVE-2024-40962 bsc#1227815).
- Update
  patches.suse/cachefiles-remove-requests-from-xarray-during-flushin.patch
  (bsc#1226588 CVE-2024-40900 bsc#1227760).
- Update
  patches.suse/cpufreq-amd-pstate-fix-memory-leak-on-CPU-EPP-exit.patch
  (stable-fixes CVE-2024-40997 bsc#1227853).
- Update
  patches.suse/crypto-hisilicon-sec-Fix-memory-leak-for-sec-resourc.patch
  (stable-fixes CVE-2024-41002 bsc#1227870).
- Update
  patches.suse/crypto-qat-Fix-ADF_DEV_RESET_SYNC-memory-leak.patch
  (git-fixes CVE-2024-39493 bsc#1227620).
- Update
  patches.suse/cxl-region-Fix-memregion-leaks-in-devm_cxl_add_regio.patch
  (git-fixes CVE-2024-40936 bsc#1227833).
- Update
  patches.suse/drivers-core-synchronize-really_probe-and-dev_uevent.patch
  (git-fixes CVE-2024-39501 bsc#1227754).
- Update
  patches.suse/drm-amdgpu-fix-UBSAN-warning-in-kv_dpm.c.patch
  (stable-fixes CVE-2024-40987 bsc#1228235).
- Update
  patches.suse/drm-amdkfd-don-t-allow-mapping-the-MMIO-HDP-page-wit.patch
  (CVE-2024-41011 bsc#1228115 git-fixes bsc#1228114).
- Update
  patches.suse/drm-bridge-cdns-mhdp8546-Fix-possible-null-pointer-d.patch
  (git-fixes CVE-2024-38548 bsc#1228202).
- Update patches.suse/drm-drm_file-Fix-pid-refcounting-race.patch
  (git-fixes CVE-2024-39486 bsc#1227492).
- Update
  patches.suse/drm-exynos-hdmi-report-safe-640x480-mode-as-a-fallba.patch
  (git-fixes CVE-2024-40916 bsc#1227846).
- Update
  patches.suse/drm-exynos-vidi-fix-memory-leak-in-.get_modes.patch
  (stable-fixes CVE-2024-40932 bsc#1227828).
- Update
  patches.suse/drm-i915-dpt-Make-DPT-object-unshrinkable.patch
  (git-fixes CVE-2024-40924 bsc#1227787).
- Update
  patches.suse/drm-komeda-check-for-error-valued-pointer.patch
  (git-fixes CVE-2024-39505 bsc#1227728).
- Update
  patches.suse/drm-lima-mask-irqs-in-timeout-path-before-hard-reset.patch
  (stable-fixes CVE-2024-40976 bsc#1227893).
- Update
  patches.suse/drm-nouveau-don-t-attempt-to-schedule-hpd_work-on-he.patch
  (git-fixes CVE-2024-40926 bsc#1227791).
- Update
  patches.suse/drm-radeon-fix-UBSAN-warning-in-kv_dpm.c.patch
  (stable-fixes CVE-2024-40988 bsc#1227957).
- Update
  patches.suse/drm-shmem-helper-Fix-BUG_ON-on-mmap-PROT_WRITE-MAP_P.patch
  (git-fixes CVE-2024-39497 bsc#1227722).
- Update
  patches.suse/io_uring-io-wq-Use-set_bit-and-test_bit-at-worker-fl.patch
  (git-fixes CVE-2024-39508 bsc#1227732).
- Update
  patches.suse/io_uring-rsrc-don-t-lock-while-TASK_RUNNING.patch
  (git-fixes CVE-2024-40922 bsc#1227785).
- Update
  patches.suse/io_uring-sqpoll-work-around-a-potential-audit-memory.patch
  (git-fixes CVE-2024-41001 bsc#1227869).
- Update
  patches.suse/iommu-Return-right-value-in-iommu_sva_bind_device.patch
  (git-fixes CVE-2024-40945 bsc#1227802).
- Update
  patches.suse/jfs-xattr-fix-buffer-overflow-for-invalid-xattr.patch
  (bsc#1227383 CVE-2024-40902 bsc#1227764).
- Update
  patches.suse/mmc-davinci-Don-t-strip-remove-function-when-driver-.patch
  (git-fixes CVE-2024-39484 bsc#1227493).
- Update
  patches.suse/nfs-Handle-error-of-rpc_proc_register-in-nfs_net_ini.patch
  (git-fixes CVE-2024-36939 bsc#1225838).
- Update
  patches.suse/ocfs2-fix-races-between-hole-punching-and-AIO-DIO.patch
  (git-fixes CVE-2024-40943 bsc#1227849).
- Update
  patches.suse/serial-imx-Introduce-timeout-when-waiting-on-transmi.patch
  (stable-fixes CVE-2024-40967 bsc#1227891).
- Update
  patches.suse/sock_map-avoid-race-between-sock_map_close-and-sk_ps.patch
  (bsc#1225475 CVE-2023-52735 CVE-2024-39500 bsc#1227724).
- Update
  patches.suse/ssb-Fix-potential-NULL-pointer-dereference-in-ssb_de.patch
  (stable-fixes CVE-2024-40982 bsc#1227865).
- Update
  patches.suse/tracing-Build-event-generation-tests-only-as-modules.patch
  (git-fixes CVE-2024-41004 bsc#1227851).
- Update
  patches.suse/tracing-trigger-Fix-to-return-error-if-failed-to-alloc-snapshot.patch
  (git-fixes CVE-2024-26920 bsc#1228237).
- Update
  patches.suse/usb-typec-tcpm-fix-use-after-free-case-in-tcpm_regis.patch
  (git-fixes CVE-2024-40903 bsc#1227766).
- Update
  patches.suse/vmci-prevent-speculation-leaks-by-sanitizing-event-i.patch
  (git-fixes CVE-2024-39499 bsc#1227725).
- Update
  patches.suse/wifi-ath11k-rely-on-mac80211-debugfs-handling-for-vi.patch
  (bsc#1227149 CVE-2024-26637 bsc#1221652).
- Update
  patches.suse/wifi-cfg80211-Lock-wiphy-in-cfg80211_get_station.patch
  (git-fixes CVE-2024-40911 bsc#1227792).
- Update
  patches.suse/wifi-cfg80211-detect-stuck-ECSA-element-in-probe-res.patch
  (bsc#1227149 CVE-2024-26683 bsc#1222434).
- Update
  patches.suse/wifi-cfg80211-validate-HE-operation-element-parsing.patch
  (bsc#1227149 CVE-2024-40930 bsc#1228236).
- Update patches.suse/wifi-iwlwifi-Use-request_module_nowait.patch
  (bsc#1227149 CVE-2024-36970 bsc#1226127).
- Update
  patches.suse/wifi-iwlwifi-mvm-check-n_ssids-before-accessing-the-.patch
  (git-fixes CVE-2024-40929 bsc#1227774).
- Update
  patches.suse/wifi-iwlwifi-mvm-don-t-read-past-the-mfuart-notifcat.patch
  (git-fixes CVE-2024-40941 bsc#1227771).
- Update
  patches.suse/wifi-iwlwifi-mvm-pick-the-version-of-SESSION_PROTECT.patch
  (bsc#1227149 CVE-2024-35913 bsc#1224485).
- Update
  patches.suse/wifi-mac80211-Fix-deadlock-in-ieee80211_sta_ps_deliv.patch
  (git-fixes CVE-2024-40912 bsc#1227790).
- Update
  patches.suse/wifi-mac80211-improve-CSA-ECSA-connection-refusal.patch
  (bsc#1227149 CVE-2024-26682 bsc#1222433).
- Update
  patches.suse/wifi-mac80211-mesh-Fix-leak-of-mesh_preq_queue-objec.patch
  (git-fixes CVE-2024-40942 bsc#1227770).
- Update
  patches.suse/wifi-mt76-connac-check-for-null-before-dereferencing.patch
  (bsc#1227149 CVE-2024-38609 bsc#1226751).
- Update
  patches.suse/wifi-mt76-mt7921s-fix-potential-hung-tasks-during-ch.patch
  (stable-fixes CVE-2024-40977 bsc#1227950).
- Update
  patches.suse/wifi-mt76-mt7925e-fix-use-after-free-in-free_irq.patch
  (bsc#1227149 CVE-2024-27049 bsc#1223763).
- Update
  patches.suse/wifi-mt76-mt7996-fix-potential-memory-leakage-when-r.patch
  (bsc#1227149 CVE-2024-38563 bsc#1226743).
- Update
  patches.suse/x86-kexec-Fix-bug-with-call-depth-tracking.patch
  (git-fixes CVE-2024-40944 bsc#1227883).
- Update
  patches.suse/xhci-Handle-TD-clearing-for-multiple-streams-case.patch
  (git-fixes CVE-2024-40927 bsc#1227816).
- commit 2cd72fd
* Fri Aug  2 2024 krisman@suse.de
- Update
  patches.suse/SUNRPC-Fix-UAF-in-svc_tcp_listen_data_ready.patch
  (bsc#1012628 CVE-2023-52885 bsc#1227750).
- Update
  patches.suse/USB-core-Fix-race-by-not-overwriting-udev-descriptor.patch
  (bsc#1213123 CVE-2023-37453 CVE-2023-52886 bsc#1227981).
- Update
  patches.suse/btrfs-zoned-fix-lock-ordering-in-btrfs_zone_activate.patch
  (bsc#1223731 CVE-2024-26944 CVE-2023-52668 bsc#1224690).
- Update
  patches.suse/wifi-ath12k-fix-the-error-handler-of-rfkill-config.patch
  (bsc#1227149 CVE-2023-52688 bsc#1224631).
- commit 0637df8
* Fri Aug  2 2024 dsterba@suse.com
- scsi: qedf: Make qedf_execute_tmf() non-preemptible (CVE-2024-42124 bsc#1228705)
- commit a8638c5
* Fri Aug  2 2024 tonyj@suse.de
- x86: stop playing stack games in profile_pc() (bsc#1228633
  CVE-2024-42096).
- commit 5c85064
* Fri Aug  2 2024 dsterba@suse.com
- net: dsa: mv88e6xxx: Correct check for empty list (CVE-2024-42224 bsc#1228723)
- commit 48e8710
* Fri Aug  2 2024 dsterba@suse.com
- skmsg: Skip zero length skb in sk_msg_recvmsg (CVE-2024-41048 bsc#1228565)
- commit 1a6942b
* Fri Aug  2 2024 davide.benini@suse.com
- netns: Make get_net_ns() handle zero refcount net
  (CVE-2024-40958 bsc#1227812).
- commit f6c7d72
* Fri Aug  2 2024 dbond@suse.com
- nvme_core: scan namespaces asynchronously (bsc#1224105).
- commit e6f41be
* Fri Aug  2 2024 sjaeckel@suse.de
- net: wwan: iosm: Fix tainted pointer delete is case of region
  creation fail (CVE-2024-40939 bsc#1227799).
- commit 0b93a9f
* Fri Aug  2 2024 sjaeckel@suse.de
- nsh: Restore skb->{protocol,data,mac_header} for outer header
  in nsh_gso_segment() (CVE-2024-36933 bsc#1225832).
- commit 6740d82
* Fri Aug  2 2024 sjaeckel@suse.de
- net: core: reject skb_copy(_expand) for fraglist GSO skbs
  (CVE-2024-36929 bsc#1225814).
- commit e49ed10
* Fri Aug  2 2024 mkoutny@suse.com
- cgroup/cpuset: Prevent UAF in proc_cpuset_show() (bsc#1228801).
- commit 8707a09
* Fri Aug  2 2024 tiwai@suse.de
- Drop MD patches that caused dependency cycles
  Also the patch was placed in a wrong directory.
  Deleted:
  patches.kabi/0002-md-cluster-fix-no-recovery-job-when-adding-re-adding.patch
  patches.suse/0001-md-cluster-fix-hanging-issue-while-a-new-disk-adding.patch
- commit f696a5b
* Fri Aug  2 2024 tiwai@suse.de
- net: phy: micrel: Fix the KSZ9131 MDI-X status issue
  (git-fixes).
- Bluetooth: hci_sync: Fix suspending with wrong filter policy
  (git-fixes).
- Bluetooth: btintel: Fail setup on error (git-fixes).
- wifi: ath12k: fix soft lockup on suspend (git-fixes).
- wifi: cfg80211: fix reporting failed MLO links status with
  cfg80211_connect_done (git-fixes).
- wifi: mac80211: use monitor sdata with driver only if desired
  (git-fixes).
- net: phy: realtek: add support for RTL8366S Gigabit PHY
  (git-fixes).
- net: usb: sr9700: fix uninitialized variable use in sr_mdio_read
  (git-fixes).
- commit f33a0c2
* Fri Aug  2 2024 tbogendoerfer@suse.de
- ppp: reject claimed-as-LCP but actually malformed packets
  (CVE-2024-41044 bsc#1228530).
- ibmvnic: Add tx check to prevent skb leak (CVE-2024-41066
  bsc#1228640).
- net/dpaa2: Avoid explicit cpumask var allocation on stack
  (CVE-2024-42093 bsc#1228680).
- commit 960e23f
* Fri Aug  2 2024 tzimmermann@suse.com
- drm/amd/display: Add NULL pointer check for kzalloc (bsc#1228591 CVE-2024-42122)
- commit 22c79c5
* Thu Aug  1 2024 pmladek@suse.com
- workqueue: Improve scalability of workqueue watchdog touch
  (bsc#1193454).
- commit 3c83768
* Thu Aug  1 2024 pmladek@suse.com
- workqueue: wq_watchdog_touch is always called with valid CPU
  (bsc#1193454).
- commit 5cd5767
* Thu Aug  1 2024 fdmanana@suse.com
- btrfs: qgroup: fix quota root leak after quota disable failure
  (bsc#1228655 CVE-2024-41078).
- commit d598dd5
* Thu Aug  1 2024 jgross@suse.com
- KVM: arm64: Disassociate vcpus from redistributor region on
  teardown (CVE-2024-40989 bsc#1227823).
- commit 8e9651c
* Thu Aug  1 2024 msuchanek@suse.de
- powerpc/eeh: avoid possible crash when edev->pdev changes
  (CVE-2024-41064 bsc#1228599).
- commit 2510511
* Thu Aug  1 2024 dsterba@suse.com
- net: ks8851: Fix deadlock with the SPI chip variant (CVE-2024-41036 bsc#1228496)
- commit 3cf617f
* Thu Aug  1 2024 dsterba@suse.com
- net/sched: Fix UAF when resolving a clash (CVE-2024-41040 bsc#1228518)
- commit dea6a81
* Thu Aug  1 2024 dsterba@suse.com
- btrfs: make sure that WRITTEN is set on all metadata blocks (CVE-2024-35949 bsc#1224700)
  Changes: adjust returned error codes to -EUCLEAN and drop definition of
  the enum error.
- commit 7880179
* Wed Jul 31 2024 dsterba@suse.com
- ila: block BH in ila_output() (CVE-2024-41081 bsc#1228617)
- commit b832793
* Wed Jul 31 2024 dsterba@suse.com
- NFSv4: Fix memory leak in nfs4_set_security_label (CVE-2024-41076 bsc#1228649)
- commit c2db2a8
* Wed Jul 31 2024 ailiop@suse.com
- gfs2: Fix NULL pointer dereference in gfs2_log_flush
  (bsc#1228672 CVE-2024-42079).
- commit 61cd0c5
* Wed Jul 31 2024 tiwai@suse.de
- Update patch reference for ASoC fix (CVE-2024-41069 bsc#1228644)
- commit bc5c8af
* Wed Jul 31 2024 ailiop@suse.com
- Update patches.suse/nilfs2-fix-inode-number-range-checks.patch
  (stable-fixes bsc#1228665 CVE-2024-42105).
- commit c8d5b4d
* Wed Jul 31 2024 ailiop@suse.com
- Update patches.suse/hfsplus-fix-uninit-value-in-copy_name.patch
  (git-fixes bsc#1228561 CVE-2024-41059).
- commit f1238d0
* Wed Jul 31 2024 lhenriques@suse.de
- cachefiles: fix slab-use-after-free in
  cachefiles_withdraw_cookie() (bsc#1228462 CVE-2024-41057).
- cachefiles: fix slab-use-after-free in fscache_withdraw_volume()
  (bsc#1228459 CVE-2024-41058).
- netfs, fscache: export fscache_put_volume() and add
  fscache_try_get_volume() (bsc#1228459 bsc#1228462).
- commit a80ddf3
* Wed Jul 31 2024 oneukum@suse.com
- platform/chrome: cros_ec_proto: Lock device when updating MKBP
  version (git-fixes).
- commit ab277a6
* Wed Jul 31 2024 heming.zhao@suse.com
- ocfs2: add bounds checking to ocfs2_check_dir_entry()
  (bsc#1228409 CVE-2024-41015).
- ocfs2: strict bound check before memcmp in
  ocfs2_xattr_find_entry() (bsc#1228410).
- ocfs2: add bounds checking to ocfs2_xattr_find_entry()
  (bsc#1228410 CVE-2024-41016).
- commit ec6fa65
* Wed Jul 31 2024 tiwai@suse.de
- platform/chrome: cros_ec_proto: Lock device when updating MKBP
  version (git-fixes).
- commit d441a76
* Wed Jul 31 2024 tiwai@suse.de
- Update patch reference of dmaengine fix (CVE-2024-40956 bsc#1227810)
- commit d7e764c
* Wed Jul 31 2024 jslaby@suse.cz
- vfio/pci: Disable auto-enable of exclusive INTx IRQ (bsc#1222625
  CVE-2024-27437).
- commit de8901b
* Wed Jul 31 2024 dsterba@suse.com
- mm: vmalloc: check if a hash-index is in cpu_possible_mask (CVE-2024-41032 bsc#1228460)
- commit 9b04845
* Wed Jul 31 2024 dsterba@suse.com
- seg6: fix parameter passing when calling NF_HOOK() in End.DX4 and End.DX6 behaviors (CVE-2024-40957 bsc#1227811)
- commit a8ab7dd
* Wed Jul 31 2024 dsterba@suse.com
- udp: Set SOCK_RCU_FREE earlier in udp_lib_get_port() (CVE-2024-41041 bsc#1228520)
- commit 74b98cc
* Wed Jul 31 2024 dsterba@suse.com
- net: do not leave a dangling sk pointer, when socket creation fails (CVE-2024-40954 bsc#1227808)
- commit 5ea4aa9
* Wed Jul 31 2024 dsterba@suse.com
- netfilter: nf_tables: fully validate NFT_DATA_VALUE on store to data registers (CVE-2024-42070 bsc#1228470)
- commit 3ac6386
* Tue Jul 30 2024 msuchanek@suse.de
- KVM: PPC: Book3S HV: Prevent UAF in
  kvm_spapr_tce_attach_iommu_group() (bsc#1228581 CVE-2024-41070).
- commit 89912c7
* Tue Jul 30 2024 davide.benini@suse.com
- xfrm6: check ip6_dst_idev() return value in xfrm6_get_saddr()
  (CVE-2024-40959 bsc#1227884).
- commit 3a174d1
* Tue Jul 30 2024 tbogendoerfer@suse.de
- Update config files.
  Disable vdpa drivers for Alibaba ENI and SolidNET (jsc#PED-8954, bsc#1227834)
- commit 9287d7f
* Tue Jul 30 2024 shung-hsi.yu@suse.com
- selftests/bpf: Extend tcx tests to cover late tcx_entry release
  (bsc#1228021 CVE-2024-41010).
- bpf: Fix too early release of tcx_entry (bsc#1228021
  CVE-2024-41010).
- commit 57180df
* Tue Jul 30 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add more ring buffer test coverage (bsc#1228020
  CVE-2024-41009).
- bpf: Fix overrunning reservations in ringbuf (bsc#1228020
  CVE-2024-41009).
- commit cd82cf6
* Tue Jul 30 2024 heming.zhao@suse.com
- md-cluster: fix no recovery job when adding/re-adding a disk
  (bsc#1223395).
- md-cluster: fix hanging issue while a new disk adding
  (bsc#1223395).
- commit d3c6e61
* Tue Jul 30 2024 shung-hsi.yu@suse.com
- rpm/guards: fix precedence issue with control flow operator
  With perl 5.40 it report the following error on rpm/guards script:
  Possible precedence issue with control flow operator (exit) at scripts/guards line 208.
  Fix the issue by adding parenthesis around ternary operator.
- commit dfba20e
* Tue Jul 30 2024 tiwai@suse.de
- HID: wacom: Modify pen IDs (git-fixes).
- commit 9c450d7
* Tue Jul 30 2024 tiwai@suse.de
- Move upstreamed ASoC patch into sorted section
- commit adae4df
* Mon Jul 29 2024 ailiop@suse.com
- xfs: add bounds checking to xlog_recover_process_data
  (bsc#1228408 CVE-2024-41014).
- commit bb0300d
* Mon Jul 29 2024 ailiop@suse.com
- xfs: don't walk off the end of a directory data block
  (bsc#1228405 CVE-2024-41013).
- commit 8a0b7eb
* Mon Jul 29 2024 ailiop@suse.com
- jfs: don't walk off the end of ealist (bsc#1228403
  CVE-2024-41017).
- commit 4159bc5
* Mon Jul 29 2024 jack@suse.cz
- ext4: fold quota accounting into
  ext4_xattr_inode_lookup_create() (bsc#1227910 CVE-2024-40972).
- commit 94f6f2b
* Mon Jul 29 2024 jack@suse.cz
- ext4: fix mb_cache_entry's e_refcnt leak in
  ext4_xattr_block_cache_find() (bsc#1226993 CVE-2024-39276).
- commit d72f4d7
* Mon Jul 29 2024 jack@suse.cz
- block: fix request.queuelist usage in flush (bsc#1227789
  CVE-2024-40925).
- commit 4903430
* Mon Jul 29 2024 tbogendoerfer@suse.de
- supported.conf: mark vdpa modules supported (jsc#PED-8954)
- commit 483ffd4
* Mon Jul 29 2024 jack@suse.cz
- ext4: do not create EA inode under buffer lock (bsc#1227910
  CVE-2024-40972).
- commit 37fb4de
* Mon Jul 29 2024 jack@suse.cz
- ext4: fix uninitialized ratelimit_state->lock access in
  __ext4_fill_super() (bsc#1227866 CVE-2024-40998).
- commit cefc508
* Mon Jul 29 2024 tiwai@suse.de
- Update patch reference of AMDGPU fix (CVE-2024-41011 bsc#1228115)
- commit 96de263
* Mon Jul 29 2024 lhenriques@suse.de
- ceph: fix incorrect kmalloc size of pagevec mempool
  (bsc#1228417).
- commit 84977b0
* Mon Jul 29 2024 ddiss@suse.de
- ima: Fix use-after-free on a dentry's dname.name (bsc#1227716 CVE-2024-39494).
- commit f7cf8d6
* Mon Jul 29 2024 fdmanana@suse.com
- btrfs: zoned: fix use-after-free due to race with dev replace
  (bsc#1227719 CVE-2024-39496).
- commit c878f86
* Mon Jul 29 2024 tbogendoerfer@suse.de
- tun: add missing verification for short frame (CVE-2024-41091
  bsc#1228327).
- tap: add missing verification for short frame (CVE-2024-41090
  bsc#1228328).
- net: ena: Add validation for completion descriptors consistency
  (CVE-2024-40999 bsc#1227913).
- commit 7fa5ae2
* Mon Jul 29 2024 sjaeckel@suse.de
- netlink: add nla be16/32 types to minlen array (CVE-2024-26849
  bsc#1223053).
- commit 2747893
* Mon Jul 29 2024 jslaby@suse.cz
- Refresh
  patches.kabi/tty-add-the-option-to-have-a-tty-reject-a-new-ldisc.patch.
  Fix build for CONFIG_VT=n (ppc64le/kvmsmall).
- commit 9280ac5
* Sun Jul 28 2024 tiwai@suse.de
- spi: spidev: add correct compatible for Rohm BH2228FV
  (git-fixes).
- spi: microchip-core: ensure TX and RX FIFOs are empty at start
  of a transfer (git-fixes).
- spi: microchip-core: only disable SPI controller when register
  value change requires it (git-fixes).
- spi: microchip-core: defer asserting chip select until just
  before write to TX FIFO (git-fixes).
- spi: microchip-core: fix the issues in the isr (git-fixes).
- clk: davinci: da8xx-cfgchip: Initialize clk_init_data before
  use (git-fixes).
- decompress_bunzip2: fix rare decompression failure (git-fixes).
- commit 536a80d
* Sat Jul 27 2024 tiwai@suse.de
- ALSA: usb-audio: Add a quirk for Sonix HD USB Camera
  (stable-fixes).
- ALSA: usb-audio: Move HD Webcam quirk to the right place
  (git-fixes).
- ALSA: usb-audio: Fix microphone sound on HD webcam
  (stable-fixes).
- commit 07826dc
* Sat Jul 27 2024 tiwai@suse.de
- auxdisplay: ht16k33: Drop reference after LED registration
  (git-fixes).
- ASoC: SOF: ipc4-topology: Preserve the DMA Link ID for ChainDMA
  on unprepare (git-fixes).
- ASoC: TAS2781: Fix tasdev_load_calibrated_data() (git-fixes).
- ASoC: Intel: use soc_intel_is_byt_cr() only when IOSF_MBI is
  reachable (git-fixes).
- ASoC: sof: amd: fix for firmware reload failure in Vangogh
  platform (git-fixes).
- ASoC: SOF: imx8m: Fix DSP control regmap retrieval (git-fixes).
- ALSA: hda/realtek: cs35l41: Fixup remaining asus strix models
  (git-fixes).
- ALSA: ump: Force 1 Group for MIDI1 FBs (git-fixes).
- ALSA: ump: Don't update FB name for static blocks (git-fixes).
- drm/amd/amdgpu: Fix uninitialized variable warnings (git-fixes).
- drm/i915/gt: Do not consider preemption during execlists_dequeue
  for gen8 (git-fixes).
- drm/i915/dp: Don't switch the LTTPR mode on an active link
  (git-fixes).
- commit d7e2deb
* Fri Jul 26 2024 tiwai@suse.de
- ALSA: hda/conexant: Mute speakers at suspend / shutdown
  (bsc#1228269).
- ALSA: hda/generic: Add a helper to mute speakers at
  suspend/shutdown (bsc#1228269).
- commit e046d5e
* Fri Jul 26 2024 tiwai@suse.de
- Refresh the previous ASoC patch, landed in subsystem tree (bsc#1228269)
- commit 180425d
* Fri Jul 26 2024 jslaby@suse.cz
- kABI: tty: add the option to have a tty reject a new ldisc
  (kabi CVE-2024-40966 bsc#1227886).
- tty: add the option to have a tty reject a new ldisc
  (CVE-2024-40966 bsc#1227886).
- commit 00113b6
* Fri Jul 26 2024 ailiop@suse.com
- fs/file: fix the check in find_next_fd() (git-fixes).
- commit 3ec6b68
* Fri Jul 26 2024 ailiop@suse.com
- erofs: ensure m_llen is reset to 0 if metadata is invalid
  (git-fixes).
- commit 03e55bf
* Fri Jul 26 2024 ailiop@suse.com
- jfs: Fix array-index-out-of-bounds in diFree (git-fixes).
- commit a89a289
* Fri Jul 26 2024 ailiop@suse.com
- hfsplus: fix uninit-value in copy_name (git-fixes).
- commit 4f0ad7b
* Fri Jul 26 2024 tiwai@suse.de
- mISDN: Fix a use after free in hfcmulti_tx() (git-fixes).
- devres: Fix memory leakage caused by driver API
  devm_free_percpu() (git-fixes).
- devres: Fix devm_krealloc() wasting memory (git-fixes).
- kobject_uevent: Fix OOB access within zap_modalias_env()
  (git-fixes).
- watchdog: rzn1: Convert comma to semicolon (git-fixes).
- watchdog: rzg2l_wdt: Check return status of pm_runtime_put()
  (git-fixes).
- watchdog: rzg2l_wdt: Use pm_runtime_resume_and_get()
  (git-fixes).
- dma: fix call order in dmam_free_coherent (git-fixes).
- mISDN: fix MISDN_TIME_STAMP handling (git-fixes).
- commit 69aa862
* Fri Jul 26 2024 shung-hsi.yu@suse.com
- bpf: Fix a potential use-after-free in bpf_link_free()
  (bsc#1227798 CVE-2024-40909).
- Refresh patches.kabi/bpf-bpf_link-and-bpf_link_ops-kABI-workaround.patch
- commit 377837f
* Thu Jul 25 2024 tiwai@suse.de
- drm/amd/display: Fix array-index-out-of-bounds in
  dml2/FCLKChangeSupport (stable-fixes).
- drm/amd/display: Update efficiency bandwidth for dcn351
  (stable-fixes).
- drm/ttm: Always take the bo delayed cleanup path for imported
  bos (git-fixes).
- drm/amd/display: change dram_clock_latency to 34us for dcn35
  (stable-fixes).
- drm/amdgpu: fix locking scope when flushing tlb (stable-fixes).
- wifi: mac80211: Avoid address calculations via out of bounds
  array indexing (stable-fixes).
- drm/amdkfd: Let VRAM allocations go to GTT domain on small APUs
  (stable-fixes).
- drm/amd/display: ASSERT when failing to find index by
  plane/stream id (stable-fixes).
- drm/amd/display: Fix overlapping copy within
  dml_core_mode_programming (stable-fixes).
- drm/amd/display: Skip pipe if the pipe idx not set properly
  (stable-fixes).
- drm/amd/display: Workaround register access in idle race with
  cursor (stable-fixes).
- commit 830869c
* Thu Jul 25 2024 tiwai@suse.de
- ALSA: pcm_dmaengine: Don't synchronize DMA channel when DMA
  is paused (git-fixes).
- commit aadeb44
* Thu Jul 25 2024 tiwai@suse.de
- spi: mux: set ctlr->bits_per_word_mask (stable-fixes).
- wifi: iwlwifi: mvm: don't wake up rx_sync_waitq upon RFKILL
  (git-fixes).
- wifi: iwlwifi: properly set WIPHY_FLAG_SUPPORTS_EXT_KEK_KCK
  (stable-fixes).
- wifi: mac80211: disable softirqs for queued frame handling
  (git-fixes).
- wifi: cfg80211: wext: add extra SIOCSIWSCAN data check
  (stable-fixes).
- wifi: cfg80211: wext: set ssids=NULL for passive scans
  (git-fixes).
- wifi: mac80211: fix UBSAN noise in ieee80211_prep_hw_scan()
  (stable-fixes).
- wifi: iwlwifi: mvm: Fix scan abort handling with HW rfkill
  (stable-fixes).
- wifi: iwlwifi: mvm: properly set 6 GHz channel direct probe
  option (stable-fixes).
- wifi: iwlwifi: mvm: handle BA session teardown in RF-kill
  (stable-fixes).
- wifi: iwlwifi: mvm: Handle BIGTK cipher in kek_kck cmd
  (stable-fixes).
- wifi: iwlwifi: mvm: remove stale STA link data during restart
  (stable-fixes).
- wifi: iwlwifi: mvm: d3: fix WoWLAN command version lookup
  (stable-fixes).
- wifi: cfg80211: fix 6 GHz scan request building (stable-fixes).
- wifi: mac80211: handle tasklet frames before stopping
  (stable-fixes).
- wifi: mac80211: apply mcast rate only if interface is up
  (stable-fixes).
- wifi: mac80211: mesh: init nonpeer_pm to active by default in
  mesh sdata (stable-fixes).
- tools/power/cpupower: Fix Pstate frequency reporting on AMD
  Family 1Ah CPUs (stable-fixes).
- tools/power turbostat: Remember global max_die_id
  (stable-fixes).
- commit 37df9b4
* Thu Jul 25 2024 tiwai@suse.de
- phy: cadence-torrent: Check return value on register read
  (git-fixes).
- kbuild: avoid build error when single DTB is turned into
  composite DTB (git-fixes).
- remoteproc: stm32_rproc: Fix mailbox interrupts queuing
  (git-fixes).
- remoteproc: k3-r5: Fix IPC-only mode detection (git-fixes).
- remoteproc: imx_rproc: Fix refcount mistake in
  imx_rproc_addr_init (git-fixes).
- remoteproc: imx_rproc: Skip over memory region when node value
  is NULL (git-fixes).
- mailbox: mtk-cmdq: Move devm_mbox_controller_register() after
  devm_pm_runtime_enable() (git-fixes).
- power: supply: ingenic: Fix some error handling paths in
  ingenic_battery_get_property() (git-fixes).
- power: supply: ab8500: Fix error handling when calling
  iio_read_channel_processed() (git-fixes).
- spi: imx: Don't expect DMA for i.MX{25,35,50,51,53} cspi devices
  (stable-fixes).
- net: mac802154: Fix racy device stats updates by DEV_STATS_INC()
  and DEV_STATS_ADD() (stable-fixes).
- platform/x86: lg-laptop: Use ACPI device handle when evaluating
  WMAB/WMBB (stable-fixes).
- platform/x86: lg-laptop: Change ACPI device id (stable-fixes).
- platform/x86: lg-laptop: Remove LGEX0815 hotkey handling
  (stable-fixes).
- platform/x86: wireless-hotkey: Add support for LG Airplane
  Button (stable-fixes).
- net: usb: qmi_wwan: add Telit FN912 compositions (stable-fixes).
- Input: ads7846 - use spi_device_id table (stable-fixes).
- mei: demote client disconnect warning on suspend to debug
  (stable-fixes).
- kconfig: remove wrong expr_trans_bool() (stable-fixes).
- kconfig: gconf: give a proper initial state to the Save button
  (stable-fixes).
- commit f6cec75
* Thu Jul 25 2024 tiwai@suse.de
- dmaengine: ti: k3-udma: Fix BCHAN count with UHC and HC channels
  (git-fixes).
- docs: crypto: async-tx-api: fix broken code example (git-fixes).
- drm/radeon: check bo_va->bo is non-NULL before using it
  (stable-fixes).
- drm/amd/display: Fix refresh rate range for some panel
  (stable-fixes).
- drm/amd/display: Account for cursor prefetch BW in DML1 mode
  support (stable-fixes).
- drm/amd/display: Add refresh rate range check (stable-fixes).
- gpio: pca953x: fix pca953x_irq_bus_sync_unlock race
  (stable-fixes).
- can: kvaser_usb: fix return value for hif_usb_send_regout
  (stable-fixes).
- Input: xpad - add support for ASUS ROG RAIKIRI PRO
  (stable-fixes).
- Input: i8042 - add Ayaneo Kun to i8042 quirk table
  (stable-fixes).
- Input: elantech - fix touchpad state on resume for Lenovo N24
  (stable-fixes).
- drm/vmwgfx: Fix missing HYPERVISOR_GUEST dependency
  (stable-fixes).
- drm/amdgpu: Indicate CU havest info to CP (stable-fixes).
- drm/exynos: dp: drop driver owner initialization (stable-fixes).
- drm/mediatek: Call drm_atomic_helper_shutdown() at shutdown time
  (stable-fixes).
- drm: panel-orientation-quirks: Add quirk for Aya Neo KUN
  (stable-fixes).
- HID: Ignore battery for ELAN touchscreens 2F2C and 4116
  (stable-fixes).
- input: Add support for "Do Not Disturb" (stable-fixes).
- input: Add event code for accessibility key (stable-fixes).
- Input: silead - Always support 10 fingers (stable-fixes).
- commit a5bc4da
* Thu Jul 25 2024 tiwai@suse.de
- Bluetooth: btnxpuart: Enable Power Save feature on startup
  (stable-fixes).
- Bluetooth: hci_core: cancel all works upon hci_unregister_dev()
  (stable-fixes).
- ASoC: amd: yc: Fix non-functional mic on ASUS M5602RA
  (stable-fixes).
- ASoC: rt722-sdca-sdw: add debounce time for type detection
  (stable-fixes).
- ASoC: SOF: sof-audio: Skip unprepare for in-use widgets on
  error rollback (stable-fixes).
- ASoC: ti: davinci-mcasp: Set min period size using FIFO config
  (stable-fixes).
- ALSA: dmaengine: Synchronize dma channel after drop()
  (stable-fixes).
- ASoC: ti: omap-hdmi: Fix too long driver name (stable-fixes).
- ASoC: topology: Do not assign fields that are already set
  (stable-fixes).
- ASoC: topology: Fix references to freed memory (stable-fixes).
- bytcr_rt5640 : inverse jack detect for Archos 101 cesium
  (stable-fixes).
- ASoC: rt722-sdca-sdw: add silence detection register as volatile
  (stable-fixes).
- ALSA: dmaengine_pcm: terminate dmaengine before synchronize
  (stable-fixes).
- ALSA: hda/relatek: Enable Mute LED on HP Laptop 15-gw0xxx
  (stable-fixes).
- ALSA: PCM: Allow resume only for suspended streams
  (stable-fixes).
- ACPI: EC: Avoid returning AE_OK on errors in address space
  handler (stable-fixes).
- ACPI: EC: Abort address space access upon error (stable-fixes).
- commit aa63c91
* Thu Jul 25 2024 iivanov@suse.de
- config/arm64: Enable CoreSight PMU drivers (bsc#1228289 jsc#PED-7859)
- commit f80ff65
* Thu Jul 25 2024 tiwai@suse.de
- platform/x86: x86-android-tablets: Unregister devices in
  reverse order (CVE-2024-40975 bsc#1227926).
- commit 16439fd
* Thu Jul 25 2024 tiwai@suse.de
- Avoid hw_desc array overrun in dw-axi-dmac (CVE-2024-40970
  bsc#1227899).
- commit 8f7016c
* Thu Jul 25 2024 tiwai@suse.de
- ASoC: amd: yc: Support mic on Lenovo Thinkpad E16 Gen 2
  (bsc#1228269).
- commit 78e0f74
* Wed Jul 24 2024 rgoldwyn@suse.com
- ima: Avoid blocking in RCU read-side critical section (bsc#1227803, CVE-2024-40947).
- commit 6fea688
* Wed Jul 24 2024 sjaeckel@suse.de
- net/rds: fix WARNING in rds_conn_connect_if_down (CVE-2024-27024
  bsc#1223777).
- commit 466c800
* Wed Jul 24 2024 mhocko@suse.com
- Update config files. Disable CONFIG_KFENCE on ppc64le (bsc#1226920)
- commit 05180ef
* Tue Jul 23 2024 shung-hsi.yu@suse.com
- bpf: Set run context for rawtp test_run callback (bsc#1227783
  CVE-2024-40908).
- commit c965ae8
* Tue Jul 23 2024 jack@suse.cz
- nfs: Fix up kabi after adding write_congestion_wait
  (bsc#1218442).
- commit fa72236
* Tue Jul 23 2024 mhocko@suse.com
- ipv6: prevent possible NULL dereference in rt6_probe()
  (CVE-2024-40960 bsc#1227813).
- commit acda250
* Tue Jul 23 2024 jslaby@suse.cz
- PCI: keystone: Relocate ks_pcie_set/clear_dbi_mode()
  (git-fixes).
- commit e717f73
* Tue Jul 23 2024 nik.borisov@suse.com
- x86/csum: clean up `csum_partial' further (git-fixes).
- commit eb0657c
* Tue Jul 23 2024 nik.borisov@suse.com
- x86/resctrl: Remove redundant variable in mbm_config_write_domain() (git-fixes).
- commit 7ae6079
* Tue Jul 23 2024 nik.borisov@suse.com
- x86/resctrl: Read supported bandwidth sources from CPUID (git-fixes).
- commit 907534d
* Tue Jul 23 2024 nik.borisov@suse.com
- x86/shstk: Make return uprobe work with shadow stack (git-fixes).
- commit a22c34a
* Tue Jul 23 2024 nik.borisov@suse.com
- x86/kconfig: Add as-instr64 macro to properly evaluate AS_WRUSS (git-fixes).
- commit 0887d68
* Tue Jul 23 2024 nik.borisov@suse.com
- x86/insn: Add VEX versions of VPDPBUSD, VPDPBUSDS, VPDPWSSD and  VPDPWSSDS (git-fixes).
- commit 4b4922f
* Tue Jul 23 2024 nik.borisov@suse.com
- x86/fpu: Fix AMD X86_BUG_FXSAVE_LEAK fixup (git-fixes).
- commit 4c24788
* Tue Jul 23 2024 nik.borisov@suse.com
- x86/cpu: Provide default cache line size if not enumerated (git-fixes).
- commit c2b6a76
* Tue Jul 23 2024 nik.borisov@suse.com
- x86/bhi: Avoid warning in #DB handler due to BHI mitigation :(git-fixes).
- commit d32b5a4
* Tue Jul 23 2024 nik.borisov@suse.com
- x86/apic: Force native_apic_mem_read() to use the MOV instruction (git-fixes).
- commit a7c18d6
* Tue Jul 23 2024 nik.borisov@suse.com
- x86/amd_nb: Check for invalid SMN reads (git-fixes).
- commit 5e0a2ff
* Tue Jul 23 2024 lhenriques@suse.de
- cachefiles: flush all requests after setting CACHEFILES_DEAD
  (bsc#1227797 CVE-2024-40935).
- commit 6acb040
* Tue Jul 23 2024 jslaby@suse.cz
- PCI: tegra194: Set EP alignment restriction for inbound ATU
  (git-fixes).
- PCI: keystone: Fix NULL pointer dereference in case of DT
  error in ks_pcie_setup_rc_app_regs() (git-fixes).
- PCI: keystone: Don't enable BAR 0 for AM654x (git-fixes).
- commit 3d6a567
* Tue Jul 23 2024 mhocko@suse.com
- ipv6: prevent possible NULL deref in fib6_nh_init()
  (CVE-2024-40961 bsc#1227814).
- commit 3de66de
* Tue Jul 23 2024 jslaby@suse.cz
- PCI: Extend ACS configurability (bsc#1228090).
- commit 3be1ce1
* Tue Jul 23 2024 nik.borisov@suse.com
- netfilter: nft_inner: validate mandatory meta and payload (bsc#1227757 CVE-2024-39504).
- commit becdc7a
* Mon Jul 22 2024 jack@suse.cz
- nfs: Block on write congestion (bsc#1218442).
- commit b7f1cad
* Mon Jul 22 2024 jack@suse.cz
- nfs: Properly initialize server->writeback (bsc#1218442).
- commit c293976
* Mon Jul 22 2024 jack@suse.cz
- nfs: Drop pointless check from nfs_commit_release_pages()
  (bsc#1218442).
- commit 20931fe
* Mon Jul 22 2024 tiwai@suse.de
- kabi/severities: cleanup and update for WiFi driver entries (bsc#1227149)
- commit 777b4e0
* Mon Jul 22 2024 tiwai@suse.de
- wifi: libertas: Follow renaming of SPI "master" to "controller"
  (bsc#1227149).
- wifi: cw1200: restore endian swapping (bsc#1227149).
- wifi: wlcore: sdio: Rate limit wl12xx_sdio_raw_{read,write}()
  failures warns (bsc#1227149).
- wifi: zd1211rw: silence sparse warnings (bsc#1227149).
- wifi: rt2x00: silence sparse warnings (bsc#1227149).
- wifi: brcmsmac: silence sparse warnings (bsc#1227149).
- wifi: b43: silence sparse warnings (bsc#1227149).
- wifi: brcmfmac: do not pass hidden SSID attribute as value
  directly (bsc#1227149).
- wifi: brcmfmac: fweh: Fix boot crash on Raspberry Pi 4
  (bsc#1227149).
- wifi: wilc1000: remove AKM suite be32 conversion for external
  auth request (bsc#1227149).
- wifi: wilc1000: add missing read critical sections around vif
  list traversal (bsc#1227149).
- wifi: wilc1000: fix declarations ordering (bsc#1227149).
- wifi: wilc1000: use SRCU instead of RCU for vif list traversal
  (bsc#1227149).
- wifi: wilc1000: split deeply nested RCU list traversal in
  dedicated helper (bsc#1227149).
- wifi: wilc1000: validate chip id during bus probe (bsc#1227149).
- wifi: brcmfmac: do not cast hidden SSID attribute value to
  boolean (bsc#1227149).
- wifi: mwifiex: Refactor 1-element array into flexible array
  in struct mwifiex_ie_types_chan_list_param_set (bsc#1227149).
- wifi: wilc1000: correct CRC7 calculation (bsc#1227149).
- wifi: wilc1000: set preamble size to auto as default in
  wilc_init_fw_config() (bsc#1227149).
- wifi: mwifiex: use kstrtoX_from_user() in debugfs handlers
  (bsc#1227149).
- wifi: wilc1000: remove setting msg.spi (bsc#1227149).
- wifi: cw1200: Convert to GPIO descriptors (bsc#1227149).
- wifi: plfxlc: Drop unused include (bsc#1227149).
- wifi: mwifiex: Drop unused headers (bsc#1227149).
- wifi: ti: wlcore: sdio: Drop unused include (bsc#1227149).
- wifi: cw1200: fix __le16 sparse warnings (bsc#1227149).
- wifi: rsi: fix restricted __le32 degrades to integer sparse
  warnings (bsc#1227149).
- wifi: zd1211rw: remove __nocast from zd_addr_t (bsc#1227149).
- wifi: brcmfmac: add linefeed at end of file (bsc#1227149).
- wifi: brcmfmac: allow per-vendor event handling (bsc#1227149).
- wifi: brcmfmac: move feature overrides before feature_disable
  (bsc#1227149).
- wifi: brcmfmac: export firmware interface functions
  (bsc#1227149).
- wifi: rt2x00: simplify rt2x00crypto_rx_insert_iv()
  (bsc#1227149).
- wifi: mwifiex: Use helpers to check multicast addresses
  (bsc#1227149).
- wifi: brcmsmac: phy: Remove unreachable code (bsc#1227149).
- wifi: wilc1000: fix incorrect power down sequence (bsc#1227149).
- wifi: wilc1000: fix driver_handler when committing initial
  configuration (bsc#1227149).
- wifi: fill in MODULE_DESCRIPTION()s for wilc1000 (bsc#1227149).
- wifi: fill in MODULE_DESCRIPTION()s for wl18xx (bsc#1227149).
- wifi: fill in MODULE_DESCRIPTION()s for p54spi (bsc#1227149).
- wifi: fill in MODULE_DESCRIPTION()s for Broadcom WLAN
  (bsc#1227149).
- wifi: fill in MODULE_DESCRIPTION()s for wl1251 and wl12xx
  (bsc#1227149).
- wifi: fill in MODULE_DESCRIPTION()s for wlcore (bsc#1227149).
- wifi: p54: fix GCC format truncation warning with
  wiphy->fw_version (bsc#1227149).
- wifi: mwifiex: use cfg80211_ssid_eq() instead of
  mwifiex_ssid_cmp() (bsc#1227149).
- wifi: rt2x00: remove useless code in
  rt2x00queue_create_tx_descriptor() (bsc#1227149).
- commit 08ddd32
* Mon Jul 22 2024 tiwai@suse.de
- wifi: rt2x00: make watchdog param per device (bsc#1227149).
- wifi: rt2x00: Simplify bool conversion (bsc#1227149).
- wifi: mwifiex: mwifiex_process_sleep_confirm_resp(): remove
  unused priv variable (bsc#1227149).
- wifi: rt2x00: disable RTS threshold for rt2800 by default
  (bsc#1227149).
- wifi: rt2x00: introduce DMA busy check watchdog for rt2800
  (bsc#1227149).
- wifi: wilc1000: simplify wilc_scan() (bsc#1227149).
- wifi: wilc1000: cleanup struct wilc_conn_info (bsc#1227149).
- wifi: wilc1000: always release SDIO host in wilc_sdio_cmd53()
  (bsc#1227149).
- wifi: wilc1000: simplify remain on channel support
  (bsc#1227149).
- wifi: brcmsmac: replace deprecated strncpy with memcpy
  (bsc#1227149).
- wifi: brcm80211: replace deprecated strncpy with strscpy
  (bsc#1227149).
- wifi: rt2x00: rework MT7620 PA/LNA RF calibration (bsc#1227149).
- wifi: rt2x00: rework MT7620 channel config function
  (bsc#1227149).
- commit 055fd52
* Mon Jul 22 2024 tiwai@suse.de
- wifi: rt2x00: improve MT7620 register initialization
  (bsc#1227149).
- wifi: wlcore: main: replace deprecated strncpy with strscpy
  (bsc#1227149).
- wifi: wlcore: boot: replace deprecated strncpy with strscpy
  (bsc#1227149).
- wifi: wl18xx: replace deprecated strncpy with strscpy
  (bsc#1227149).
- wifi: wl1251: replace deprecated strncpy with strscpy
  (bsc#1227149).
- wifi: rt2x00: fix rt2800 watchdog function (bsc#1227149).
- wifi: brcmfmac: fix format-truncation warnings (bsc#1227149).
- wifi: hostap: remove unused ioctl function (bsc#1227149).
- wifi: atmel: remove unused ioctl function (bsc#1227149).
- wifi: p54: Annotate struct p54_cal_database with __counted_by
  (bsc#1227149).
- wifi: brcmfmac: fweh: Add __counted_by for struct
  brcmf_fweh_queue_item and use struct_size() (bsc#1227149).
- wifi: hostap: Add __counted_by for struct prism2_download_data
  and use struct_size() (bsc#1227149).
- wifi: wfx: implement wfx_remain_on_channel() (bsc#1227149).
- wifi: wfx: allow to send frames during ROC (bsc#1227149).
- wifi: wfx: scan_lock is global to the device (bsc#1227149).
- wifi: wfx: simplify exclusion between scan and Rx filters
  (bsc#1227149).
- wifi: wfx: introduce hif_scan_uniq() (bsc#1227149).
- wifi: wfx: move wfx_skb_*() out of the header file
  (bsc#1227149).
- wifi: wfx: relocate wfx_rate_mask_to_hw() (bsc#1227149).
- wifi: wfx: fix power_save setting when AP is stopped
  (bsc#1227149).
- commit 859f128
* Mon Jul 22 2024 tiwai@suse.de
- wifi: mwifiex: Replace one-element array with flexible-array
  member in struct mwifiex_ie_types_rxba_sync (bsc#1227149).
- Refresh
  patches.suse/wifi-mwifiex-Sanity-check-tlv_len-and-tlv_bitmap_len.patch.
- commit 0e5befb
* Mon Jul 22 2024 tiwai@suse.de
- wifi: rt2x00: fix MT7620 low RSSI issue (bsc#1227149).
- wifi: rt2x00: remove redundant check if u8 array element is
  less than zero (bsc#1227149).
- wifi: mwifiex: followup PCIE and related cleanups (bsc#1227149).
- wifi: mwifiex: simplify PCIE write operations (bsc#1227149).
- wifi: wilc1000: add back-off algorithm to balance tx queue
  packets (bsc#1227149).
- wifi: mwifiex: use MODULE_FIRMWARE to add firmware files
  metadata (bsc#1227149).
- wifi: mwifiex: cleanup struct mwifiex_sdio_mpa_rx (bsc#1227149).
- wifi: brcmfmac: firmware: Annotate struct brcmf_fw_request
  with __counted_by (bsc#1227149).
- wifi: brcmfmac: Annotate struct brcmf_gscan_config with
  __counted_by (bsc#1227149).
- wifi: cw1200: Avoid processing an invalid TIM IE (bsc#1227149).
- wifi: wlcore: sdio: Use module_sdio_driver macro to simplify
  the code (bsc#1227149).
- wifi: wilc1000: Remove unused declarations (bsc#1227149).
- wifi: rt2x00: limit MT7620 TX power based on eeprom calibration
  (bsc#1227149).
- wifi: wfx: Use devm_kmemdup to replace devm_kmalloc + memcpy
  (bsc#1227149).
- wifi: rsi: rsi_91x_usb_ops: Remove unnecessary (void*)
  conversions (bsc#1227149).
- wifi: rsi: rsi_91x_usb: Remove unnecessary (void*) conversions
  (bsc#1227149).
- wifi: rsi: rsi_91x_sdio_ops: Remove unnecessary (void*)
  conversions (bsc#1227149).
- wifi: rsi: rsi_91x_sdio: Remove unnecessary (void*) conversions
  (bsc#1227149).
- commit a544c26
* Mon Jul 22 2024 tiwai@suse.de
- wifi: rsi: rsi_91x_main: Remove unnecessary (void*) conversions
  (bsc#1227149).
- wifi: rsi: rsi_91x_mac80211: Remove unnecessary conversions
  (bsc#1227149).
- wifi: rsi: rsi_91x_hal: Remove unnecessary conversions
  (bsc#1227149).
- wifi: rsi: rsi_91x_debugfs: Remove unnecessary (void*)
  conversions (bsc#1227149).
- wifi: rsi: rsi_91x_coex: Remove unnecessary (void*) conversions
  (bsc#1227149).
- wifi: rt2x00: correct MAC_SYS_CTRL register RX mask in
  R-Calibration (bsc#1227149).
- wifi: mwifiex: fix comment typos in SDIO module (bsc#1227149).
- wifi: mwifiex: cleanup adapter data (bsc#1227149).
- wifi: mwifiex: use is_zero_ether_addr() instead of
  ether_addr_equal() (bsc#1227149).
- wifi: mwifiex: drop BUG_ON from TX paths (bsc#1227149).
- wifi: mwifiex: handle possible mwifiex_write_reg() errors
  (bsc#1227149).
- wifi: mwifiex: handle possible sscanf() errors (bsc#1227149).
- wifi: mwifiex: cleanup private data structures (bsc#1227149).
- wlcore: spi: Remove redundant of_match_ptr() (bsc#1227149).
- wifi: brcmsmac: cleanup SCB-related data types (bsc#1227149).
- wifi: brcmsmac: remove more unused data types (bsc#1227149).
- wifi: libertas: prefer kstrtoX() for simple integer conversions
  (bsc#1227149).
- wifi: libertas: handle possible spu_write_u16() errors
  (bsc#1227149).
- wifi: libertas: cleanup SDIO reset (bsc#1227149).
- wifi: libertas: simplify list operations in free_if_spi_card()
  (bsc#1227149).
- wifi: libertas: use convenient lists to manage SDIO packets
  (bsc#1227149).
- wifi: libertas: add missing calls to cancel_work_sync()
  (bsc#1227149).
- wifi: wilc1000: add SPI commands retry mechanism (bsc#1227149).
- wifi: wilc1000: remove use of has_thrpt_enh3 flag (bsc#1227149).
- wifi: brcmsmac: remove unused data type (bsc#1227149).
- wifi: mwifiex: Set WIPHY_FLAG_NETNS_OK flag (bsc#1227149).
- wifi: mwifiex: prefer strscpy() over strlcpy() (bsc#1227149).
- wifi: zd1211rw: fix typo "tranmits" (bsc#1227149).
- wifi: p54: Add missing MODULE_FIRMWARE macro (bsc#1227149).
- wifi: hostap: fix stringop-truncations GCC warning
  (bsc#1227149).
- wifi: brcmsmac: fix gnu_printf warnings (bsc#1227149).
- wifi: brcmfmac: fix gnu_printf warnings (bsc#1227149).
- wifi: rt2x00: fix the typo in comments (bsc#1227149).
- wifi: brcmfmac: Detect corner error case earlier with log
  (bsc#1227149).
- wifi: brcmutil: use helper function pktq_empty() instead of
  open code (bsc#1227149).
- wifi: add HAS_IOPORT dependencies (bsc#1227149).
- wifi: wilc1000: Increase ASSOC response buffer (bsc#1227149).
- wifi: mwifiex: Use list_count_nodes() (bsc#1227149).
- wifi: mwifiex: Use default @max_active for workqueues
  (bsc#1227149).
- commit edbabc2
* Mon Jul 22 2024 ailiop@suse.com
- xfs: Add cond_resched to block unmap range and reflink remap
  path (bsc#1228211).
- commit 4c79a42
* Mon Jul 22 2024 oneukum@suse.com
- supported.conf: Add support for v4l2-dv-timings
  (jsc#PED-8645)
- commit 6262df7
* Mon Jul 22 2024 oneukum@suse.com
- supported.conf: Add support for v4l2-dv-timings
  (jsc#PED-8644)
- commit a3622c5
* Mon Jul 22 2024 mhocko@suse.com
- netrom: Fix a memory leak in nr_heartbeat_expiry()
  (CVE-2024-41006 bsc#1227862).
- commit 59ef181
* Mon Jul 22 2024 iivanov@suse.de
- arm64: dts: rockchip: Add missing power-domains for rk356x vop_mmu (git-fixes)
- commit 6571948
* Mon Jul 22 2024 iivanov@suse.de
- arm64: dts: rockchip: Fix mic-in-differential usage on (git-fixes)
- commit 67939cb
* Mon Jul 22 2024 iivanov@suse.de
- arm64: dts: rockchip: Fix mic-in-differential usage on rk3566-roc-pc (git-fixes)
- commit 5ed815a
* Mon Jul 22 2024 iivanov@suse.de
- arm64: dts: rockchip: Drop invalid mic-in-differential on (git-fixes)
- commit af4620a
* Mon Jul 22 2024 iivanov@suse.de
- arm64: dts: rockchip: Increase VOP clk rate on RK3328 (git-fixes)
- commit 0171830
* Mon Jul 22 2024 iivanov@suse.de
- arm64: dts: rockchip: Update WIFi/BT related nodes on (git-fixes)
- commit 2186774
* Mon Jul 22 2024 iivanov@suse.de
- arm64: dts: rockchip: Add mdio and ethernet-phy nodes to (git-fixes)
- commit 7bd1596
* Mon Jul 22 2024 iivanov@suse.de
- arm64: dts: rockchip: Add pinctrl for UART0 to rk3308-rock-pi-s (git-fixes)
- commit a5c559a
* Mon Jul 22 2024 iivanov@suse.de
- arm64: dts: rockchip: Add sdmmc related properties on (git-fixes)
- commit 07ed999
* Mon Jul 22 2024 iivanov@suse.de
- arm64: dts: rockchip: Add sound-dai-cells for RK3368 (git-fixes)
- commit 0d2dc44
* Mon Jul 22 2024 iivanov@suse.de
- arm64: dts: rockchip: fix PMIC interrupt pin on ROCK Pi E (git-fixes)
- commit 17c17ec
* Mon Jul 22 2024 iivanov@suse.de
- arm64: dts: rockchip: Fix the value of `dlg,jack-det-rate` mismatch (git-fixes)
- commit ef568ac
* Mon Jul 22 2024 iivanov@suse.de
- arm64: dts: rockchip: Rename LED related pinctrl nodes on (git-fixes)
- commit 3ac3475
* Mon Jul 22 2024 iivanov@suse.de
- arm64: dts: rockchip: Fix SD NAND and eMMC init on rk3308-rock-pi-s (git-fixes)
- commit f0f8ba5
* Mon Jul 22 2024 iivanov@suse.de
- arm64: dts: rockchip: Fix the DCDC_REG2 minimum voltage on Quartz64 (git-fixes)
- commit a564fef
* Mon Jul 22 2024 iivanov@suse.de
- arm64: dts: imx8qm-mek: fix gpio number for reg_usdhc2_vmmc (git-fixes)
- commit d7e72e1
* Mon Jul 22 2024 iivanov@suse.de
- arm64: dts: freescale: imx8mm-verdin: enable hysteresis on slow input (git-fixes)
- commit ca6c1bb
* Mon Jul 22 2024 iivanov@suse.de
- arm64: dts: imx93-11x11-evk: Remove the 'no-sdio' property (git-fixes)
- commit a10e3de
* Mon Jul 22 2024 tiwai@suse.de
- Move upstreamed patches into sorted section
- commit 0bb0cc8
* Mon Jul 22 2024 lhenriques@suse.de
- fuse: verify {g,u}id mount options correctly (bsc#1228193).
- libceph: fix race between delayed_work() and ceph_monc_stop()
  (bsc#1228192).
- commit 10e7bb9
* Mon Jul 22 2024 tiwai@suse.de
- nilfs2: avoid undefined behavior in nilfs_cnt32_ge macro
  (git-fixes).
- checkpatch: really skip LONG_LINE_* when LONG_LINE is ignored
  (git-fixes).
- rtc: interface: Add RTC offset to alarm after fix-up
  (git-fixes).
- rtc: abx80x: Fix return value of nvmem callback on read
  (git-fixes).
- rtc: cmos: Fix return value of nvmem callbacks (git-fixes).
- rtc: isl1208: Fix return value of nvmem callbacks (git-fixes).
- pinctrl: renesas: r8a779g0: Fix TPU suffixes (git-fixes).
- pinctrl: renesas: r8a779g0: Fix TCLK suffixes (git-fixes).
- pinctrl: renesas: r8a779g0: FIX PWM suffixes (git-fixes).
- pinctrl: renesas: r8a779g0: Fix IRQ suffixes (git-fixes).
- pinctrl: renesas: r8a779g0: Fix (H)SCIF3 suffixes (git-fixes).
- pinctrl: renesas: r8a779g0: Fix (H)SCIF1 suffixes (git-fixes).
- pinctrl: renesas: r8a779g0: Fix FXR_TXEN[AB] suffixes
  (git-fixes).
- pinctrl: renesas: r8a779g0: Fix CANFD5 suffix (git-fixes).
- pinctrl: freescale: mxs: Fix refcount of child (git-fixes).
- pinctrl: ti: ti-iodelay: fix possible memory leak when
  pinctrl_enable() fails (git-fixes).
- pinctrl: single: fix possible memory leak when pinctrl_enable()
  fails (git-fixes).
- pinctrl: core: fix possible memory leak when pinctrl_enable()
  fails (git-fixes).
- pinctrl: rockchip: update rk3308 iomux routes (git-fixes).
- selftests/sigaltstack: Fix ppc64 GCC build (git-fixes).
- PCI: dw-rockchip: Fix initial PERST# GPIO value (git-fixes).
- PCI: rockchip: Use GPIOD_OUT_LOW flag while requesting ep_gpio
  (git-fixes).
- PCI: rcar: Demote WARN() to dev_warn_ratelimited() in
  rcar_pcie_wakeup() (git-fixes).
- PCI: qcom-ep: Disable resources unconditionally during PERST#
  assert (git-fixes).
- PCI: dwc: Fix index 0 incorrectly being interpreted as a free
  ATU slot (git-fixes).
- PCI: endpoint: Fix error handling in epf_ntb_epc_cleanup()
  (git-fixes).
- PCI: endpoint: Clean up error handling in vpci_scan_bus()
  (git-fixes).
- PCI: endpoint: pci-epf-test: Make use of cached 'epc_features'
  in pci_epf_test_core_init() (git-fixes).
- PCI: Fix resource double counting on remove & rescan
  (git-fixes).
- PCI/DPC: Fix use-after-free on concurrent DPC and hot-removal
  (git-fixes).
- PCI: Introduce cleanup helpers for device reference counts
  and locks (stable-fixes).
- commit a7e6cbc
* Sat Jul 20 2024 tiwai@suse.de
- ALSA: hda/realtek: Fix the speaker output on Samsung Galaxy
  Book Pro 360 (stable-fixes).
- ALSA: hda/tas2781: Add new quirk for Lenovo Hera2 Laptop
  (stable-fixes).
- ASoC: SOF: ipc4-topology: Use correct queue_id for requesting
  input pin format (stable-fixes).
- ALSA: hda/realtek: Enable headset mic on Positivo SU C1400
  (stable-fixes).
- commit be4d8bf
* Sat Jul 20 2024 tiwai@suse.de
- eeprom: at24: Probe for DDR3 thermal sensor in the SPD case
  (stable-fixes).
- Refresh
  patches.suse/eeprom-at24-fix-memory-corruption-race-condition.patch.
- commit 82fbd42
* Sat Jul 20 2024 tiwai@suse.de
- Input: elan_i2c - do not leave interrupt disabled on suspend
  failure (git-fixes).
- Input: qt1050 - handle CHIP_ID reading error (git-fixes).
- interconnect: qcom: qcm2290: Fix mas_snoc_bimc RPM master ID
  (git-fixes).
- iio: frequency: adrf6780: rm clk provider include (git-fixes).
- iio: Fix the sorting functionality in
  iio_gts_build_avail_time_table (git-fixes).
- eeprom: digsy_mtc: Fix 93xx46 driver probe failure (git-fixes).
- Revert "usb: musb: da8xx: Set phy in OTG mode by default"
  (stable-fixes).
- ALSA: seq: ump: Skip useless ports for static blocks
  (git-fixes).
- ASoC: fsl: fsl_qmc_audio: Check devm_kasprintf() returned value
  (git-fixes).
- ASoC: amd: Adjust error handling in case of absent codec device
  (git-fixes).
- ASoC: max98088: Check for clk_prepare_enable() error
  (git-fixes).
- ASoC: qcom: Adjust issues in case of DT error in
  asoc_qcom_lpass_cpu_platform_probe() (git-fixes).
- ASoC: cs35l56: Accept values greater than 0 as IRQ numbers
  (git-fixes).
- ASoc: tas2781: Enable RCA-based playback without DSP firmware
  download (git-fixes).
- crypto: qat - extend scope of lock in
  adf_cfg_add_key_value_param() (git-fixes).
- hwrng: core - Fix wrong quality calculation at hw rng
  registration (git-fixes).
- crypto: ccp - Fix null pointer dereference in
  __sev_snp_shutdown_locked (git-fixes).
- crypto: ecdsa - Fix the public key format description
  (git-fixes).
- hwrng: amd - Convert PCIBIOS_* return codes to errnos
  (git-fixes).
- commit 7fcc337
* Fri Jul 19 2024 tiwai@suse.de
- Add Alt-commit for amdgpu patch (git-fixes)
- commit 7fbd801
* Fri Jul 19 2024 tbogendoerfer@suse.de
- gve: Clear napi->skb before dev_kfree_skb_any() (CVE-2024-40937
  bsc#1227836).
- net: hns3: fix kernel crash problem in concurrent scenario
  (CVE-2024-39507 bsc#1227730).
- net/mlx5: Fix tainted pointer delete is case of flow rules
  creation fail (CVE-2024-40940 bsc#1227800).
- commit 8d4dcfb
* Fri Jul 19 2024 mhocko@suse.com
- net: ethtool: fix the error condition in
  ethtool_get_phy_stats_ethtool() (CVE-2024-40928 bsc#1227788).
- commit be667d4
* Fri Jul 19 2024 fdmanana@suse.com
- btrfs: zoned: fix lock ordering in btrfs_zone_activate()
  (bsc#1223731 CVE-2024-26944).
- commit c6e27f8
* Fri Jul 19 2024 mhocko@suse.com
- vmxnet3: disable rx data ring on dma allocation failure
  (CVE-2024-40923 bsc#1227786).
- commit 3828e87
* Fri Jul 19 2024 mhocko@suse.com
- mptcp: ensure snd_una is properly initialized on connect
  (CVE-2024-40931 bsc#1227780).
- commit 60fd0e2
* Fri Jul 19 2024 mhocko@suse.com
- bnxt_en: Adjust logging of firmware messages in case of released
  token in __hwrm_send() (CVE-2024-40919 bsc#1227779).
- commit c060c32
* Fri Jul 19 2024 fdmanana@suse.com
- btrfs: zoned: allocate dummy checksums for zoned NODATASUM
  writes (bsc#1223731 CVE-2024-26944).
- btrfs: zoned: fix use-after-free in do_zone_finish()
  (bsc#1223731 CVE-2024-26944).
- btrfs: zoned: fix chunk map leak when loading block group zone
  info (bsc#1223731 CVE-2024-26944).
- btrfs: fix unbalanced unlock of mapping_tree_lock (bsc#1223731
  CVE-2024-26944).
- btrfs: remove stripe size local variable from
  insert_dev_extents() (bsc#1223731 CVE-2024-26944).
- btrfs: use a dedicated data structure for chunk maps
  (bsc#1223731 CVE-2024-26944).
- commit 201e016
* Fri Jul 19 2024 fdmanana@suse.com
- btrfs: zoned: wait for data BG to be finished on direct IO
  allocation (bsc#1223731 CVE-2024-26944).
- btrfs: zoned: drop no longer valid write pointer check
  (bsc#1223731 CVE-2024-26944).
- commit a5e78f9
* Fri Jul 19 2024 fdmanana@suse.com
- btrfs: do not require EXTENT_NOWAIT for btrfs_redirty_list_add()
  (bsc#1223731 CVE-2024-26944).
- commit f638537
* Fri Jul 19 2024 tiwai@suse.de
- drm/mediatek: Add DRM_MODE_ROTATE_0 to rotation property
  (git-fixes).
- commit f21db33
* Fri Jul 19 2024 fdmanana@suse.com
- btrfs: drop gfp from parameter extent state helpers (bsc#1223731
  CVE-2024-26944).
- Refresh
  patches.suse/btrfs-make-find_first_extent_bit-return-a-boolean.patch.
- Refresh
  patches.suse/btrfs-open-code-trivial-btrfs_add_excluded_extent.patch.
- commit 2097a9c
* Fri Jul 19 2024 tiwai@suse.de
- drm/fbdev-dma: Fix framebuffer mode for big endian devices
  (git-fixes).
- drm/msm/mdp5: Remove MDP_CAP_SRC_SPLIT from msm8x53_config
  (git-fixes).
- drm/msm/dpu: drop validity checks for clear_pending_flush()
  ctl op (git-fixes).
- drm/msm/dsi: set VIDEO_COMPRESSION_MODE_CTRL_WC (git-fixes).
- USB: serial: option: add Rolling RW350-GL variants
  (stable-fixes).
- USB: serial: option: add support for Foxconn T99W651
  (stable-fixes).
- USB: serial: option: add Netprisma LCUK54 series modules
  (stable-fixes).
- usb: gadget: configfs: Prevent OOB read/write in
  usb_string_copy() (stable-fixes).
- usb: dwc3: pci: add support for the Intel Panther Lake
  (stable-fixes).
- USB: Add USB_QUIRK_NO_SET_INTF quirk for START BP-850k
  (stable-fixes).
- xhci: always resume roothubs if xHC was reset during resume
  (stable-fixes).
- USB: serial: option: add Telit generic core-dump composition
  (stable-fixes).
- USB: serial: option: add Fibocom FM350-GL (stable-fixes).
- USB: serial: option: add Telit FN912 rmnet compositions
  (stable-fixes).
- commit f9ac994
* Fri Jul 19 2024 tiwai@suse.de
- drm/msm/dpu: fix encoder irq wait skip (git-fixes).
- drm/dp_mst: Fix all mstb marked as not probed after
  suspend/resume (git-fixes).
- drm/panfrost: Mark simple_ondemand governor as softdep
  (git-fixes).
- drm/lima: Mark simple_ondemand governor as softdep (git-fixes).
- drm/mediatek: Remove less-than-zero comparison of an unsigned
  value (git-fixes).
- drm/mediatek: Fix bit depth overwritten for mtk_ovl_set
  bit_depth() (git-fixes).
- drm/mediatek: Support DRM plane alpha in Mixer (git-fixes).
- drm/mediatek: Support DRM plane alpha in OVL (git-fixes).
- drm/mediatek: Support RGBA8888 and RGBX8888 in OVL on MT8195
  (git-fixes).
- drm/mediatek: Set DRM mode configs accordingly (git-fixes).
- drm/mediatek: Add OVL compatible name for MT8195 (git-fixes).
- drm/mediatek: Turn off the layers with zero width or height
  (git-fixes).
- drm/mediatek: Fix destination alpha error in OVL (git-fixes).
- drm/mediatek: Fix XRGB setting error in Mixer (git-fixes).
- drm/mediatek: Fix XRGB setting error in OVL (git-fixes).
- drm/mediatek: Use 8-bit alpha in ETHDR (git-fixes).
- drm/mediatek: Add missing plane settings when async update
  (git-fixes).
- drm/etnaviv: fix DMA direction handling for cached RW buffers
  (git-fixes).
- Revert "drm/bridge: tc358767: Set default CLRSIPO count"
  (stable-fixes).
- drm/qxl: Add check for drm_cvt_mode (git-fixes).
- drm: zynqmp_kms: Fix AUX bus not getting unregistered
  (git-fixes).
- drm: zynqmp_dpsub: Fix an error handling path in
  zynqmp_dpsub_probe() (git-fixes).
- drm/bridge: samsung-dsim: Set P divider based on min/max of
  fin pll (git-fixes).
- drm/bridge: it6505: fix hibernate to resume no display issue
  (git-fixes).
- drm/panel: ilitek-ili9882t: Check for errors on the NOP in
  prepare() (git-fixes).
- drm/panel: ilitek-ili9882t: If prepare fails, disable GPIO
  before regulators (git-fixes).
- drm/panel: boe-tv101wum-nl6: Check for errors on the NOP in
  prepare() (git-fixes).
- drm/panel: boe-tv101wum-nl6: If prepare fails, disable GPIO
  before regulators (git-fixes).
- drm/panel: himax-hx8394: Handle errors from
  mipi_dsi_dcs_set_display_on() better (git-fixes).
- drm/mgag200: Bind I2C lifetime to DRM device (git-fixes).
- drm/mgag200: Set DDC timeout in milliseconds (git-fixes).
- drm/mipi-dsi: Fix theoretical int overflow in
  mipi_dsi_generic_write_seq() (git-fixes).
- drm/mipi-dsi: Fix theoretical int overflow in
  mipi_dsi_dcs_write_seq() (git-fixes).
- commit 6fb58b4
* Fri Jul 19 2024 tiwai@suse.de
- drm/udl: Remove DRM_CONNECTOR_POLL_HPD (git-fixes).
- drm/arm/komeda: Fix komeda probe failing if there are no links
  in the secondary pipeline (git-fixes).
- drm/rockchip: vop2: Fix the port mux of VP2 (git-fixes).
- drm/amd/display: Move 'struct scaler_data' off stack
  (git-fixes).
- drm/amdgpu: Remove GC HW IP 9.3.0 from noretry=1 (git-fixes).
- drm/amdgpu: Check if NBIO funcs are NULL in
  amdgpu_device_baco_exit (git-fixes).
- drm/amdgpu: Fix memory range calculation (git-fixes).
- drm/amd/pm: Fix aldebaran pcie speed reporting (git-fixes).
- drm/amd/pm: remove logically dead code for renoir (git-fixes).
- drm/amdkfd: Fix CU Masking for GFX 9.4.3 (git-fixes).
- drm/amdgpu: Fix signedness bug in sdma_v4_0_process_trap_irq()
  (git-fixes).
- commit ba21687
* Fri Jul 19 2024 tiwai@suse.de
- Add Alt-commit to AMDGPU patches from 6.11-rc1
- commit f4ae72a
* Fri Jul 19 2024 iivanov@suse.de
- PCI/ASPM: Update save_state when configuration changes (bsc#1226915)
- commit 5192284
* Fri Jul 19 2024 lduncan@suse.com
- block: Move checking GENHD_FL_NO_PART to bdev_add_partition()
  (bsc#1226213).
- commit 6855b2f
* Fri Jul 19 2024 dsterba@suse.com
- bonding: Fix out-of-bounds read in bond_option_arp_ip_targets_set() (CVE-2024-39487 bsc#1227573)
- commit 1c7a482
* Fri Jul 19 2024 dsterba@suse.com
- tls: get psock ref after taking rxlock to avoid leak (CVE-2024-35908 bsc#1224490)
- commit b0d23d0
* Fri Jul 19 2024 dsterba@suse.com
- netfilter: nf_tables: flush pending destroy work before exit_net release (CVE-2024-35899 bsc#1224499)
- commit 8a86808
* Thu Jul 18 2024 dsterba@suse.com
- net/smc: reduce rtnl pressure in smc_pnet_create_pnetids_list() (CVE-2024-35934 bsc#1224641)
- commit 812f420
* Thu Jul 18 2024 dsterba@suse.com
- net/sched: act_skbmod: prevent kernel-infoleak (CVE-2024-35893 bsc#1224512)
- commit 5be3514
* Thu Jul 18 2024 lduncan@suse.com
- scsi: mpt3sas: Avoid test/set_bit() operating in non-allocated
  memory (bsc#1227762 CVE-2024-40901).
- commit 5eb5075
* Thu Jul 18 2024 fdmanana@suse.com
- btrfs: pass NOWAIT for set/clear extent bits as another bit
  (bsc#1223731 CVE-2024-26944).
- commit 33253df
* Thu Jul 18 2024 fdmanana@suse.com
- btrfs: drop NOFAIL from set_extent_bit allocation masks
  (bsc#1223731 CVE-2024-26944).
- commit 46559ec
* Thu Jul 18 2024 fdmanana@suse.com
- btrfs: open code set_extent_bits (bsc#1223731 CVE-2024-26944).
- Refresh
  patches.suse/btrfs-make-find_first_extent_bit-return-a-boolean.patch.
- Refresh
  patches.suse/btrfs-open-code-trivial-btrfs_add_excluded_extent.patch.
- commit 460a0d4
* Thu Jul 18 2024 ailiop@suse.com
- xfs: fix log recovery buffer allocation for the legacy h_size
  fixup (bsc#1227432 CVE-2024-39472).
- commit 04ef30f
* Thu Jul 18 2024 jgross@suse.com
- KVM: Fix a data race on last_boosted_vcpu in kvm_vcpu_on_spin()
  (CVE-2024-40953, bsc#1227806).
- commit 60989df
* Thu Jul 18 2024 jwiesner@suse.de
- Update config files (bsc#1227282).
  Update the CONFIG_LSM option to include the selinux LSM in the default set
  of LSMs. The selinux LSM will not get enabled because it is preceded by
  apparmor, which is the first exclusive LSM. Updating CONFIG_LSM resolves
  failures that result in the system not booting up when "security=selinux
  selinux=1" is passed to the kernel and SELinux policies are installed.
- commit 0a95a78
* Thu Jul 18 2024 ailiop@suse.com
- xfs: use roundup_pow_of_two instead of ffs during xlog_find_tail
  (git-fixes).
- commit 44812b1
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: connac: use muar idx 0xe for non-mt799x as well
  (bsc#1227149).
- wifi: mt76: mt7996: fix potential memory leakage when reading
  chip temperature (bsc#1227149).
- wifi: mt76: mt7996: fix uninitialized variable in
  mt7996_irq_tasklet() (bsc#1227149).
- wifi: mt76: mt7925: ensure 4-byte alignment for suspend &
  wow command (bsc#1227149).
- wifi: mt76: mt7996: fix size of txpower MCU command
  (bsc#1227149).
- wifi: mt76: connac: check for null before dereferencing
  (bsc#1227149).
- commit 4e5584e
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: Remove redundant assignment to variable tidno
  (bsc#1227149).
- wifi: mt76: fix the issue of missing txpwr settings from ch153
  to ch177 (bsc#1227149).
- wifi: mt76: mt7921: fix suspend issue on MediaTek COB platform
  (bsc#1227149).
- wifi: mt76: mt7921: fix a potential association failure upon
  resuming (bsc#1227149).
- wifi: mt76: mt7921: fix the unfinished command of regd_notifier
  before suspend (bsc#1227149).
- wifi: mt76: mt792x: update the country list of EU for ACPI SAR
  (bsc#1227149).
- wifi: mt76: mt7925e: fix use-after-free in free_irq()
  (bsc#1227149).
- wifi: mt76: mt792x: add the illegal value check for mtcl table
  of acpi (bsc#1227149).
- wifi: mt76: mt7925: fix the wrong data type for scan command
  (bsc#1227149).
- wifi: mt76: set page_pool napi pointer for mmio devices
  (bsc#1227149).
- wifi: mt76: mt792x: fix ethtool warning (bsc#1227149).
- commit 3499113
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: connac: set correct muar_idx for mt799x chipsets
  (bsc#1227149).
- wifi: mt76: mt7996: remove TXS queue setting (bsc#1227149).
- wifi: mt76: mt7996: mark GCMP IGTK unsupported (bsc#1227149).
- wifi: mt76: mt7996: ensure 4-byte alignment for beacon commands
  (bsc#1227149).
- wifi: mt76: mt7996: check txs format before getting skb by pid
  (bsc#1227149).
- wifi: mt76: mt7925: support temperature sensor (bsc#1227149).
- wifi: mt76: mt7925: update PCIe DMA settings (bsc#1227149).
- wifi: mt76: mt7925: add support to set ifs time by mcu command
  (bsc#1227149).
- wifi: mt76: mt7925: add flow to avoid chip bt function fail
  (bsc#1227149).
- wifi: mt76: mt7925: fix the wrong header translation config
  (bsc#1227149).
- commit 7f22357
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7925: fix WoW failed in encrypted mode
  (bsc#1227149).
- wifi: mt76: mt7925: fix fw download fail (bsc#1227149).
- wifi: mt76: mt7925: fix wmm queue mapping (bsc#1227149).
- wifi: mt76: mt7925: fix mcu query command fail (bsc#1227149).
- wifi: mt76: mt7925: fix SAP no beacon issue in 5Ghz and 6Ghz
  band (bsc#1227149).
- wifi: mt76: mt7925: fix connect to 80211b mode fail in 2Ghz band
  (bsc#1227149).
- wifi: mt76: mt76x2u: add netgear wdna3100v3 to device table
  (bsc#1227149).
- wifi: mt76: mt792xu: enable dmashdl support (bsc#1227149).
- wifi: mt76: usb: store usb endpoint in mt76_queue (bsc#1227149).
- wifi: mt76: usb: create a dedicated queue for psd traffic
  (bsc#1227149).
- commit 01e1acb
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7996: fix fw loading timeout (bsc#1227149).
- wifi: mt76: mt7915: update mt798x_wmac_adie_patch_7976
  (bsc#1227149).
- wifi: mt76: mt7915: add locking for accessing mapped registers
  (bsc#1227149).
- wifi: mt76: mt7915: fix error recovery with WED enabled
  (bsc#1227149).
- wifi: mt76: check txs format before getting skb by pid
  (bsc#1227149).
- wifi: mt76: disable HW AMSDU when using fixed rate
  (bsc#1227149).
- wifi: mt76: mt7996: fix fortify warning (bsc#1227149).
- commit 0013ef2
* Thu Jul 18 2024 tiwai@suse.de
- wifi: fill in MODULE_DESCRIPTION()s for mt76 drivers
  (bsc#1227149).
- wifi: mt76: mt7996: Use DECLARE_FLEX_ARRAY() and fix
  - Warray-bounds warnings (bsc#1227149).
- wifi: mt76: mt7921: fix wrong 6Ghz power type (bsc#1227149).
- wifi: mt76: mt7921: fix CLC command timeout when suspend/resume
  (bsc#1227149).
- wifi: mt76: mt7921: reduce the size of MCU firmware download
  Rx queue (bsc#1227149).
- wifi: mt76: mt7996: set DMA mask to 36 bits for boards with
  more than 4GB of RAM (bsc#1227149).
- wifi: mt76: Convert to platform remove callback returning void
  (bsc#1227149).
- wifi: mt76: mt7925: remove iftype from mt7925_init_eht_caps
  signature (bsc#1227149).
- wifi: mt76: connac: add new definition of tx descriptor
  (bsc#1227149).
- wifi: mt76: mt7996: adjust interface num and wtbl size for
  mt7992 (bsc#1227149).
- commit cbff43f
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7996: support mt7992 eeprom loading (bsc#1227149).
- wifi: mt76: mt7996: rework register offsets for mt7992
  (bsc#1227149).
- wifi: mt76: mt7996: add DMA support for mt7992 (bsc#1227149).
- wifi: mt76: connac: add firmware support for mt7992
  (bsc#1227149).
- wifi: mt76: mt7996: introduce mt7996_band_valid() (bsc#1227149).
- wifi: mt76: mt7996: fix mt7996_mcu_all_sta_info_event struct
  packing (bsc#1227149).
- wifi: mt76: mt7915: also MT7981 is 3T3R but nss2 on 5 GHz band
  (bsc#1227149).
- wifi: mt76: mt7915: fix EEPROM offset of TSSI flag on MT7981
  (bsc#1227149).
- wifi: mt76: connac: add beacon protection support for mt7996
  (bsc#1227149).
- wifi: mt76: mt7996: rework ampdu params setting (bsc#1227149).
- commit 3e59fd6
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7996: add txpower setting support (bsc#1227149).
- commit fd1825a
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7996: fix alignment of sta info event
  (bsc#1227149).
- wifi: mt76: mt7996: switch to mcu command for TX GI report
  (bsc#1227149).
- wifi: mt76: use chainmask for power delta calculation
  (bsc#1227149).
- wifi: mt76: change txpower init to per-phy (bsc#1227149).
- wifi: mt76: mt7996: align the format of fixed rate command
  (bsc#1227149).
- wifi: mt76: mt7996: handle IEEE80211_RC_SMPS_CHANGED
  (bsc#1227149).
- wifi: mt76: connac: set fixed_bw bit in TX descriptor for
  fixed rate frames (bsc#1227149).
- wifi: mt76: mt7996: adjust WFDMA settings to improve performance
  (bsc#1227149).
- wifi: mt76: connac: add beacon duplicate TX mode support for
  mt7996 (bsc#1227149).
- commit e90dd6a
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: move wed reset common code in mt76 module
  (bsc#1227149).
- commit b63457a
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7996: add thermal sensor device support
  (bsc#1227149).
- wifi: mt76: connac: add thermal protection support for mt7996
  (bsc#1227149).
- wifi: mt76: mt7996: add TX statistics for EHT mode in debugfs
  (bsc#1227149).
- wifi: mt76: mt7996: add support for variants with auxiliary
  RX path (bsc#1227149).
- wifi: mt76: mt7996: use u16 for val field in mt7996_mcu_set_rro
  signature (bsc#1227149).
- wifi: mt76: dma: introduce __mt76_dma_queue_reset utility
  routine (bsc#1227149).
- commit dd57284
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: increase MT_QFLAG_WED_TYPE size (bsc#1227149).
- wifi: mt76: introduce wed pointer in mt76_queue (bsc#1227149).
- wifi: mt76: introduce mt76_queue_is_wed_tx_free utility routine
  (bsc#1227149).
- wifi: mt76: move mt76_net_setup_tc in common code (bsc#1227149).
- wifi: mt76: move mt76_mmio_wed_offload_{enable,disable} in
  common code (bsc#1227149).
- wifi: mt76: mmio: move mt76_mmio_wed_{init,release}_rx_buf in
  common code (bsc#1227149).
- wifi: mt76: Remove unnecessary (void*) conversions
  (bsc#1227149).
- wifi: mt76: permit to load precal from NVMEM cell for mt7915
  (bsc#1227149).
- wifi: mt76: permit to use alternative cell name to eeprom
  NVMEM load (bsc#1227149).
- commit 15e9dc7
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7921: support 5.9/6GHz channel config in acpi
  (bsc#1227149).
- Refresh
  patches.suse/wifi-mt76-mt7921-fix-country-count-limitation-for-CL.patch.
- Refresh
  patches.suse/wifi-mt76-mt7921-fix-incorrect-type-conversion-for-C.patch.
- commit 915b272
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: make mt76_get_of_eeprom static again (bsc#1227149).
- wifi: mt76: limit support of precal loading for mt7915 to MTD
  only (bsc#1227149).
- wifi: mt76: fix typo in mt76_get_of_eeprom_from_nvmem function
  (bsc#1227149).
- wifi: mt76: mt7996: fix uninitialized variable in parsing txfree
  (bsc#1227149).
- wifi: mt76: add ability to explicitly forbid LED registration
  with DT (bsc#1227149).
- wifi: mt76: mt7925: fix typo in mt7925_init_he_caps
  (bsc#1227149).
- wifi: mt76: mt7921: fix 6GHz disabled by the missing default
  CLC config (bsc#1227149).
- net: fill in MODULE_DESCRIPTION()s in kuba@'s modules
  (bsc#1227149).
- wifi: mt76: mt7921: fix kernel panic by accessing invalid 6GHz
  channel info (bsc#1227149).
- commit b106ffb
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: Annotate struct mt76_rx_tid with __counted_by
  (bsc#1227149).
- commit aecab86
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7921: update the channel usage when the regd
  domain changed (bsc#1227149).
- Refresh
  patches.suse/wifi-mt76-mt7921-fix-country-count-limitation-for-CL.patch.
- Refresh
  patches.suse/wifi-mt76-mt7921-fix-incorrect-type-conversion-for-C.patch.
- commit b09df3f
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7921: get regulatory information from the clc
  event (bsc#1227149).
- Refresh
  patches.suse/wifi-mt76-mt7921-fix-country-count-limitation-for-CL.patch.
- Refresh
  patches.suse/wifi-mt76-mt7921-fix-incorrect-type-conversion-for-C.patch.
- commit 04b07d9
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7921: add 6GHz power type support for clc
  (bsc#1227149).
- Refresh
  patches.suse/wifi-mt76-mt7921-fix-country-count-limitation-for-CL.patch.
- commit b7bb561
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7921: enable set txpower for UNII-4 (bsc#1227149).
- wifi: mt76: mt7921: move connac nic capability handling to
  mt7921 (bsc#1227149).
- wifi: mt76: reduce spin_lock_bh held up in mt76_dma_rx_cleanup
  (bsc#1227149).
- wifi: mt76: mt7996: remove periodic MPDU TXS request
  (bsc#1227149).
- wifi: mt76: mt7996: enable PPDU-TxS to host (bsc#1227149).
- wifi: mt76: mt7996: Add mcu commands for getting sta tx
  statistic (bsc#1227149).
- commit e37a1c7
* Thu Jul 18 2024 tiwai@suse.de
- Update config files for mt76 stuff (bsc#1227149)
- commit debbb92
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: connac: add MBSSID support for mt7996 (bsc#1227149).
- Refresh
  patches.suse/wifi-mt76-update-beacon-size-limitation.patch.
- commit 54772eb
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7996: get tx_retries and tx_failed from txfree
  (bsc#1227149).
- wifi: mt76: mt792x: move some common usb code in mt792x module
  (bsc#1227149).
- wifi: mt76: mt792x: move mt7921_skb_add_usb_sdio_hdr in mt792x
  module (bsc#1227149).
- wifi: mt76: mt7915 add tc offloading support (bsc#1227149).
- wifi: mt76: mt7925: add Mediatek Wi-Fi7 driver for mt7925 chips
  (bsc#1227149).
- wifi: mt76: mt7915: update mpdu density capability
  (bsc#1227149).
- wifi: mt76: check vif type before reporting cca and csa
  (bsc#1227149).
- wifi: mt76: check sta rx control frame to multibss capability
  (bsc#1227149).
- wifi: mt76: Use PTR_ERR_OR_ZERO() to simplify code
  (bsc#1227149).
- commit 2106e27
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7996: support per-band LED control (bsc#1227149).
- wifi: mt76: mt7996: support more options for
  mt7996_set_bitrate_mask() (bsc#1227149).
- wifi: mt76: mt7996: only set vif teardown cmds at remove
  interface (bsc#1227149).
- wifi: mt76: connac: add more unified event IDs (bsc#1227149).
- wifi: mt76: connac: add more unified command IDs (bsc#1227149).
- wifi: mt76: connac: add data field in struct tlv (bsc#1227149).
- wifi: mt76: connac: add eht support for tx power (bsc#1227149).
- wifi: mt76: connac: add eht support for phy mode config
  (bsc#1227149).
- wifi: mt76: connac: export functions for mt7925 (bsc#1227149).
- wifi: mt76: mt792x: support mt7925 chip init (bsc#1227149).
- commit 135e742
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: connac: introduce helper for mt7925 chipset
  (bsc#1227149).
- wifi: mt76: mt7915: fix monitor mode issues (bsc#1227149).
- wifi: mt76: add DMA mapping error check in mt76_alloc_txwi()
  (bsc#1227149).
- wifi: mt76: fix race condition related to checking tx queue
  fill status (bsc#1227149).
- wifi: mt76: use atomic iface iteration for pre-TBTT work
  (bsc#1227149).
- wifi: mt76: mt7603: disable A-MSDU tx support on MT7628
  (bsc#1227149).
- wifi: mt76: mt7603: add missing register initialization for
  MT7628 (bsc#1227149).
- commit 6594bb5
* Thu Jul 18 2024 tiwai@suse.de
- net: ethernet: mtk_wed: introduce mtk_wed_buf structure
  (bsc#1227149).
- net: ethernet: mtk_wed: rename mtk_rxbm_desc in mtk_wed_bm_desc
  (bsc#1227149).
- wifi: mt76: Replace strlcpy() with strscpy() (bsc#1227149).
- wifi: mt76: mt76x02: fix return value check in
  mt76x02_mac_process_rx (bsc#1227149).
- wifi: mt76: mt7921: move mt7921u_disconnect mt792x-lib
  (bsc#1227149).
- wifi: mt76: mt7921: move mt7921_dma_init in pci.c (bsc#1227149).
- wifi: mt76: mt792x: move MT7921_PM_TIMEOUT and
  MT7921_HW_SCAN_TIMEOUT in common code (bsc#1227149).
- wifi: mt76: mt76_connac3: move lmac queue enumeration in
  mt76_connac3_mac.h (bsc#1227149).
- wifi: mt76: mt792x: move mt7921_load_firmware in mt792x-lib
  module (bsc#1227149).
- commit 1179b28
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt792x: introduce mt792x-usb module (bsc#1227149).
- commit bb743ca
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7921: move acpi_sar code in mt792x-lib module
  (bsc#1227149).
- Refresh
  patches.suse/wifi-mt76-mt7921-fix-country-count-limitation-for-CL.patch.
- Refresh
  patches.suse/wifi-mt76-mt7921-fix-incorrect-type-conversion-for-C.patch.
- Refresh
  patches.suse/wifi-mt76-mt792x-fix-a-potential-loading-failure-of-.patch.
- commit e00ae3f
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7921: move runtime-pm pci code in mt792x-lib
  (bsc#1227149).
- commit 35d834e
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7921: move shared runtime-pm code on mt792x-lib
  (bsc#1227149).
- commit 5efac2c
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7921: move hif_ops macro in mt792x.h
  (bsc#1227149).
- commit 945f2ed
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt792x: move more dma shared code in mt792x_dma
  (bsc#1227149).
- Refresh
  patches.suse/wifi-mt76-mt7921e-fix-use-after-free-in-free_irq.patch.
- commit 4136c03
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt792x: introduce mt792x_irq_map (bsc#1227149).
- Refresh
  patches.suse/wifi-mt76-mt7921e-fix-use-after-free-in-free_irq.patch.
- Refresh
  patches.suse/wifi-mt76-mt7921s-fix-potential-hung-tasks-during-ch.patch.
- commit 94984c8
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7921: move init shared code in mt792x-lib module
  (bsc#1227149).
- wifi: mt76: mt7921: move debugfs shared code in mt792x-lib
  module (bsc#1227149).
- wifi: mt76: mt7921: move dma shared code in mt792x-lib module
  (bsc#1227149).
- commit 8138035
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7921: move mac shared code in mt792x-lib module
  (bsc#1227149).
- commit 118e960
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt792x: introduce mt792x-lib module (bsc#1227149).
- Refresh
  patches.suse/wifi-mt76-move-struct-ieee80211_chanctx_conf-up-to-s.patch.
- commit bba35bb
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7921: move mt792x_hw_dev in mt792x.h
  (bsc#1227149).
- Refresh
  patches.suse/wifi-mt76-move-struct-ieee80211_chanctx_conf-up-to-s.patch.
- commit e5956d4
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7921: move mt792x_mutex_{acquire/release} in
  mt792x.h (bsc#1227149).
- Refresh
  patches.suse/wifi-mt76-move-struct-ieee80211_chanctx_conf-up-to-s.patch.
- commit ea3046f
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt792x: move shared structure definition in mt792x.h
  (bsc#1227149).
- Refresh
  patches.suse/wifi-mt76-move-struct-ieee80211_chanctx_conf-up-to-s.patch.
- commit c60dc5e
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7921: rename mt7921_dev in mt792x_dev
  (bsc#1227149).
- Refresh
  patches.suse/wifi-mt76-move-struct-ieee80211_chanctx_conf-up-to-s.patch.
- Refresh
  patches.suse/wifi-mt76-mt7921e-fix-use-after-free-in-free_irq.patch.
- Refresh
  patches.suse/wifi-mt76-mt792x-fix-a-potential-loading-failure-of-.patch.
- commit 845aa52
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7921: rename mt7921_vif in mt792x_vif
  (bsc#1227149).
- Refresh
  patches.suse/wifi-mt76-move-struct-ieee80211_chanctx_conf-up-to-s.patch.
- commit d4d2c1b
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7921: rename mt7921_hif_ops in mt792x_hif_ops
  (bsc#1227149).
- wifi: mt76: mt7921: rename mt7921_phy in mt792x_phy
  (bsc#1227149).
- wifi: mt76: mt7921: rename mt7921_sta in mt792x_sta
  (bsc#1227149).
- commit 47cecdc
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: move rate info in mt76_vif (bsc#1227149).
- Refresh
  patches.suse/wifi-mt76-move-struct-ieee80211_chanctx_conf-up-to-s.patch.
- Refresh
  patches.suse/wifi-mt76-mt7996-fix-rate-usage-of-inband-discovery-.patch.
- commit 8909aa1
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7921: convert acpisar and clc pointers to void
  (bsc#1227149).
- wifi: mt76: mt7921: move common register definition in
  mt792x_regs.h (bsc#1227149).
- wifi: mt76: mt7603: fix tx filter/flush function (bsc#1227149).
- wifi: mt76: mt7603: fix beacon interval after disabling a
  single vif (bsc#1227149).
- wifi: mt76: add support for providing eeprom in nvmem cells
  (bsc#1227149).
- wifi: mt76: split get_of_eeprom in subfunction (bsc#1227149).
- wifi: mt76: connac: add connac3 mac library (bsc#1227149).
- mt76: connac: move more mt7921/mt7915 mac shared code in connac
  lib (bsc#1227149).
- wifi: mt76: move ampdu_state in mt76_wcid (bsc#1227149).
- commit 343ad65
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7921: rely on shared sta_poll_list and
  sta_poll_lock (bsc#1227149).
- Refresh
  patches.suse/wifi-mt76-move-struct-ieee80211_chanctx_conf-up-to-s.patch.
- commit 72ca75a
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7921: rely on shared poll_list field
  (bsc#1227149).
- wifi: mt76: mt7996: rely on shared poll_list field
  (bsc#1227149).
- wifi: mt76: mt7615: rely on shared poll_list field
  (bsc#1227149).
- wifi: mt76: mt7603: rely on shared poll_list field
  (bsc#1227149).
- wifi: mt76: mt7915: move poll_list in mt76_wcid (bsc#1227149).
- wifi: mt76: mt7996: rely on shared sta_poll_list and
  sta_poll_lock (bsc#1227149).
- wifi: mt76: mt7615: rely on shared sta_poll_list and
  sta_poll_lock (bsc#1227149).
- wifi: mt76: mt7603: rely on shared sta_poll_list and
  sta_poll_lock (bsc#1227149).
- wifi: mt76: mt7915: move sta_poll_list and sta_poll_lock in
  mt76_dev (bsc#1227149).
- commit 2965d6e
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7996: increase tx token size (bsc#1227149).
- wifi: mt76: mt7996: add muru support (bsc#1227149).
- wifi: mt76: connac: add support to set ifs time by mcu command
  (bsc#1227149).
- wifi: mt76: mt7996: enable VHT extended NSS BW feature
  (bsc#1227149).
- wifi: mt76: connac: add support for dsp firmware download
  (bsc#1227149).
- wifi: mt76: mt7996: move radio ctrl commands to proper functions
  (bsc#1227149).
- wifi: mt76: mt7921: get rid of MT7921_RESET_TIMEOUT marco
  (bsc#1227149).
- mt76: mt7996: rely on mt76_sta_stats in mt76_wcid (bsc#1227149).
- wifi: mt76: mt7921: make mt7921_mac_sta_poll static
  (bsc#1227149).
- wifi: mt76: mt7996: disable WFDMA Tx/Rx during SER recovery
  (bsc#1227149).
- commit fc1c367
* Thu Jul 18 2024 tiwai@suse.de
- Update config files: adjust for Arm CONFIG_MT798X_WMAC (bsc#1227149)
- commit 5938ea9
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7921: rely on mib_stats shared definition
  (bsc#1227149).
- Refresh
  patches.suse/wifi-mt76-move-struct-ieee80211_chanctx_conf-up-to-s.patch.
- commit a519a6e
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7915: disable WFDMA Tx/Rx during SER recovery
  (bsc#1227149).
- wifi: mt76: mt7921: Support temp sensor (bsc#1227149).
- wifi: mt76: mt7915: accumulate mu-mimo ofdma muru stats
  (bsc#1227149).
- wifi: mt76: add tx_nss histogram to ethtool stats (bsc#1227149).
- wifi: mt76: mt7921e: report tx retries/failed counts in tx
  free event (bsc#1227149).
- wifi: mt76: mt7915: add support for MT7981 (bsc#1227149).
- wifi: mt76: mt7996: rely on mib_stats shared definition
  (bsc#1227149).
- wifi: mt76: mt7915: move mib_stats structure in mt76.h
  (bsc#1227149).
- wifi: mt76: mt7921: remove macro duplication in regs.h
  (bsc#1227149).
- commit c307798
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7915: report tx retries/failed counts for non-WED
  path (bsc#1227149).
- Refresh
  patches.suse/wifi-mt76-mt7915-rework-tx-packets-counting-when-WED.patch.
- commit 25e2b06
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7996: enable BSS_CHANGED_MU_GROUPS support
  (bsc#1227149).
- Refresh
  patches.suse/wifi-mt76-update-beacon-size-limitation.patch.
- commit b121af9
* Thu Jul 18 2024 tiwai@suse.de
- wifi: mt76: mt7996: drop return in mt7996_sta_statistics
  (bsc#1227149).
- wifi: mt76: mt7915: drop return in mt7915_sta_statistics
  (bsc#1227149).
- wifi: mt76: report non-binding skb tx rate when WED is active
  (bsc#1227149).
- wifi: mt76: enable UNII-4 channel 177 support (bsc#1227149).
- wifi: mt76: mt7615: enable BSS_CHANGED_MU_GROUPS support
  (bsc#1227149).
- wifi: mt7601u: replace strlcpy() with strscpy() (bsc#1227149).
- wifi: mt7601u: delete dead code checking debugfs returns
  (bsc#1227149).
- commit 3625743
* Thu Jul 18 2024 ailiop@suse.com
- exfat: fix potential deadlock on __exfat_get_dentry_set
  (git-fixes).
- commit aaa908a
* Thu Jul 18 2024 tiwai@suse.de
- media: venus: fix use after free in vdec_close (git-fixes).
- media: venus: flush all buffers in output plane streamoff
  (git-fixes).
- media: v4l: subdev: Fix typo in documentation (git-fixes).
- media: imx-pxp: Fix ERR_PTR dereference in pxp_probe()
  (git-fixes).
- media: renesas: vsp1: Store RPF partition configuration per
  RPF instance (git-fixes).
- media: renesas: vsp1: Fix _irqsave and _irq mix (git-fixes).
- media: rcar-vin: Fix YUYV8_1X16 handling for CSI-2 (git-fixes).
- media: imx-jpeg: Drop initial source change event if capture
  has been setup (git-fixes).
- media: imx-jpeg: Remove some redundant error logs (git-fixes).
- media: uvcvideo: Override default flags (git-fixes).
- media: uvcvideo: Fix integer overflow calculating timestamp
  (git-fixes).
- saa7134: Unchecked i2c_transfer function result fixed
  (git-fixes).
- media: v4l: async: Fix NULL pointer dereference in adding
  ancillary links (git-fixes).
- media: i2c: Fix imx412 exposure control (git-fixes).
- media: imon: Fix race getting ictx->lock (git-fixes).
- media: dvb-usb: Fix unexpected infinite loop in
  dvb_usb_read_remote_control() (git-fixes).
- media: pci: ivtv: Add check for DMA map result (git-fixes).
- leds: flash: leds-qcom-flash: Test the correct variable in init
  (git-fixes).
- Revert "leds: led-core: Fix refcount leak in of_led_get()"
  (git-fixes).
- leds: mt6360: Fix memory leak in mt6360_init_isnk_properties()
  (git-fixes).
- leds: triggers: Flush pending brightness before activating
  trigger (git-fixes).
- leds: ss4200: Convert PCIBIOS_* return codes to errnos
  (git-fixes).
- leds: trigger: Unregister sysfs attributes before calling
  deactivate() (git-fixes).
- mfd: omap-usb-tll: Use struct_size to allocate tll (git-fixes).
- mfd: pm8008: Fix regmap irq chip initialisation (git-fixes).
- ipmi: ssif_bmc: prevent integer overflow on 32bit systems
  (git-fixes).
- ata: libata-scsi: Fix offsets for the fixed format sense data
  (git-fixes).
- commit a8e6a5f
* Thu Jul 18 2024 mhocko@suse.com
- Update
  patches.suse/mptcp-ensure-snd_nxt-is-properly-initialized-on-conn.patch
  (CVE-2024-36889 bsc#1225746).
- commit 98abb2b
* Thu Jul 18 2024 dsterba@suse.com
- mptcp: fix data races on remote_id (CVE-2024-27404 bsc#1224422)
- commit ed12cfe
* Wed Jul 17 2024 dsterba@suse.com
- netfilter: nf_tables: Fix potential data-race in __nft_expr_type_get() (CVE-2024-27020 bsc#1223815)
- commit 79c457d
* Wed Jul 17 2024 dsterba@suse.com
- netfilter: nf_tables: Fix potential data-race in __nft_obj_type_get() (CVE-2024-27019 bsc#1223813)
- commit 73c5c5f
* Wed Jul 17 2024 fdmanana@suse.com
- btrfs: open code set_extent_bits_nowait (bsc#1223731
  CVE-2024-26944).
- commit da5e600
* Wed Jul 17 2024 fdmanana@suse.com
- btrfs: open code set_extent_dirty (bsc#1223731 CVE-2024-26944).
- commit 3076056
* Wed Jul 17 2024 fdmanana@suse.com
- btrfs: open code set_extent_new (bsc#1223731 CVE-2024-26944).
- Refresh
  patches.suse/btrfs-make-find_first_extent_bit-return-a-boolean.patch.
- commit 3afda0a
* Wed Jul 17 2024 mhocko@suse.com
- mm/page_table_check: fix crash on ZONE_DEVICE (CVE-2024-40948
  bsc#1227801).
- commit 69b3c59
* Wed Jul 17 2024 fdmanana@suse.com
- btrfs: open code set_extent_delalloc (bsc#1223731
  CVE-2024-26944).
- btrfs: open code set_extent_defrag (bsc#1223731 CVE-2024-26944).
- commit 646bcad
* Wed Jul 17 2024 fdmanana@suse.com
- btrfs: use btrfs_next_item() at scrub.c:find_first_extent_item()
  (bsc#1223731 CVE-2024-26944).
- btrfs: unexport extent_map_block_end() (bsc#1223731
  CVE-2024-26944).
- btrfs: split assert into two different asserts when removing
  block group (bsc#1223731 CVE-2024-26944).
- btrfs: mark sanity checks when getting chunk map as unlikely
  (bsc#1223731 CVE-2024-26944).
- commit b0dd338
* Wed Jul 17 2024 mhocko@suse.com
- gro: fix ownership transfer (CVE-2024-35890 bsc#1224516).
- commit 8c57ce0
* Wed Jul 17 2024 mhocko@suse.com
- mptcp: ensure snd_nxt is properly initialized on connect
  (CVE-2024-36889).
- commit 724d285
* Wed Jul 17 2024 mhocko@suse.com
- ipv6: fib6_rules: avoid possible NULL dereference in
  fib6_rule_action() (CVE-2024-36902 bsc#1225719).
- commit d8c5ba2
* Wed Jul 17 2024 mhocko@suse.com
- phonet: fix rtm_phonet_notify() skb allocation (CVE-2024-36946
  bsc#1225851).
- commit a878203
* Wed Jul 17 2024 mhocko@suse.com
- r8169: Fix possible ring buffer corruption on fragmented Tx
  packets (CVE-2024-38586 bsc#1226750).
- commit 1324b27
* Wed Jul 17 2024 fdmanana@suse.com
- btrfs: zoned: factor out DUP bg handling from
  btrfs_load_block_group_zone_info (bsc#1223731 CVE-2024-26944).
- btrfs: zoned: factor out single bg handling from
  btrfs_load_block_group_zone_info (bsc#1223731 CVE-2024-26944).
- btrfs: zoned: factor out per-zone logic from
  btrfs_load_block_group_zone_info (bsc#1223731 CVE-2024-26944).
- btrfs: zoned: introduce a zone_info struct in
  btrfs_load_block_group_zone_info (bsc#1223731 CVE-2024-26944).
- commit f06e144
* Wed Jul 17 2024 tiwai@suse.de
- wifi: virt_wifi: don't use strlen() in const context
  (git-fixes).
- commit b4154c8
* Wed Jul 17 2024 tiwai@suse.de
- wifi: rtw89: Fix array index mistake in
  rtw89_sta_info_get_iter() (git-fixes).
- wifi: rtl8xxxu: 8188f: Limit TX power index (git-fixes).
- wifi: rtw89: 8852b: fix definition of KIP register number
  (git-fixes).
- wifi: mac80211: chanctx emulation set CHANGE_CHANNEL when
  in_reconfig (git-fixes).
- wifi: virt_wifi: avoid reporting connection success with wrong
  SSID (git-fixes).
- wifi: ath12k: fix peer metadata parsing (git-fixes).
- wifi: ath11k: fix wrong handling of CCMP256 and GCMP ciphers
  (git-fixes).
- wifi: ath11k: fix RCU documentation in
  ath11k_mac_op_ipv6_changed() (git-fixes).
- wifi: iwlwifi: mvm: don't limit VLP/AFC to UATS-enabled
  (git-fixes).
- wifi: iwlwifi: fix iwl_mvm_get_valid_rx_ant() (git-fixes).
- wifi: mac80211: correcty limit wider BW TDLS STAs (git-fixes).
- wifi: mac80211: add ieee80211_tdls_sta_link_id() (stable-fixes).
- commit 949fcca
* Wed Jul 17 2024 tiwai@suse.de
- wifi: cfg80211: handle 2x996 RU allocation in
  cfg80211_calculate_bitrate_he() (git-fixes).
- wifi: cfg80211: fix typo in cfg80211_calculate_bitrate_he()
  (git-fixes).
- wifi: ath12k: fix wrong definition of CE ring's base address
  (git-fixes).
- wifi: ath11k: fix wrong definition of CE ring's base address
  (git-fixes).
- wifi: ath12k: fix firmware crash during reo reinject
  (git-fixes).
- wifi: ath12k: fix invalid memory access while processing
  fragmented packets (git-fixes).
- wifi: ath12k: change DMA direction while mapping reinjected
  packets (git-fixes).
- wifi: ath11k: restore country code during resume (git-fixes).
- wifi: ath11k: refactor setting country code logic
  (stable-fixes).
- wifi: ath12k: Fix tx completion ring (WBM2SW) setup failure
  (git-fixes).
- wifi: ath12k: Correct 6 GHz frequency value in rx status
  (git-fixes).
- wifi: ath12k: avoid duplicated vdev stop (git-fixes).
- wifi: ath12k: drop failed transmitted frames from metric
  calculation (git-fixes).
- wifi: ath12k: Don't drop tx_status in failure case (git-fixes).
- wifi: rtw89: fix HW scan not aborting properly (git-fixes).
- commit 7f555ea
* Wed Jul 17 2024 tiwai@suse.de
- wifi: mac80211: reset negotiated TTLM on disconnect (git-fixes).
- Refresh patches.kabi/wireless-kabi-workaround.patch.
- commit e02cbd1
* Wed Jul 17 2024 tiwai@suse.de
- wifi: mac80211: cancel multi-link reconf work on disconnect
  (git-fixes).
- wifi: mwifiex: Fix interface type change (git-fixes).
- wifi: brcmsmac: LCN PHY code is used for BCM4313 2G-only device
  (git-fixes).
- vmlinux.lds.h: catch .bss..L* sections into BSS") (git-fixes).
- wifi: mac80211: Recalc offload when monitor stop (git-fixes).
- commit 0c5d63e
* Wed Jul 17 2024 tiwai@suse.de
- Bluetooth: hci_event: Set QoS encryption from BIGInfo report
  (git-fixes).
- Bluetooth: btnxpuart: Add handling for boot-signature timeout
  errors (git-fixes).
- Bluetooth: btintel: Refactor btintel_set_ppag() (git-fixes).
- Bluetooth: hci_bcm4377: Use correct unit for timeouts
  (git-fixes).
- lib: objagg: Fix general protection fault (git-fixes).
- lib: test_objagg: Fix spelling (git-fixes).
- lib: objagg: Fix spelling (git-fixes).
- cpufreq: ti-cpufreq: Handle deferred probe with dev_err_probe()
  (git-fixes).
- cpufreq/amd-pstate: Fix the scaling_max_freq setting on shared
  memory CPPC systems (git-fixes).
- firmware: turris-mox-rwtm: Initialize completion before mailbox
  (git-fixes).
- firmware: turris-mox-rwtm: Fix checking return value of
  wait_for_completion_timeout() (git-fixes).
- firmware: turris-mox-rwtm: Do not complete if there are no
  waiters (git-fixes).
- drivers: soc: xilinx: check return status of get_api_version()
  (git-fixes).
- soc: xilinx: rename cpu_number1 to dummy_cpu_number (git-fixes).
- soc: qcom: pdr: fix parsing of domains lists (git-fixes).
- soc: qcom: pdr: protect locator_addr with the main mutex
  (git-fixes).
- soc: qcom: rpmh-rsc: Ensure irqs aren't disabled by
  rpmh_rsc_send_data() callers (git-fixes).
- soc: qcom: pmic_glink: Handle the return value of
  pmic_glink_init (git-fixes).
- commit aea26b0
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: remove the need_raid_map parameter from btrfs_map_block()
  (bsc#1223731 CVE-2024-26944).
- btrfs: zoned: skip splitting and logical rewriting on pre-alloc
  write (bsc#1223731 CVE-2024-26944).
- btrfs: zoned: do not zone finish data relocation block group
  (bsc#1223731 CVE-2024-26944).
- btrfs: add comments for btrfs_map_block() (bsc#1223731
  CVE-2024-26944).
- commit 0c47c71
* Tue Jul 16 2024 ailiop@suse.com
- Revert "gfs2: fix glock shrinker ref issues" (git-fixes).
- commit f7bfdba
* Tue Jul 16 2024 ailiop@suse.com
- gfs2: Fix "ignore unlock failures after withdraw" (git-fixes).
- commit 519ac22
* Tue Jul 16 2024 ailiop@suse.com
- gfs2: Don't forget to complete delayed withdraw (git-fixes).
- commit 7f71d47
* Tue Jul 16 2024 ailiop@suse.com
- gfs2: Fix invalid metadata access in punch_hole (git-fixes).
- commit 1be0540
* Tue Jul 16 2024 ailiop@suse.com
- gfs2: Rename gfs2_lookup_{ simple => meta } (git-fixes).
- commit d7e53ef
* Tue Jul 16 2024 ailiop@suse.com
- gfs2: Use mapping->gfp_mask for metadata inodes (git-fixes).
- commit 78503fa
* Tue Jul 16 2024 ailiop@suse.com
- gfs2: convert to ctime accessor functions (git-fixes).
- commit b024418
* Tue Jul 16 2024 ailiop@suse.com
- gfs2: Get rid of gfs2_alloc_blocks generation parameter
  (git-fixes).
- commit e229d26
* Tue Jul 16 2024 ailiop@suse.com
- dlm: fix user space lock decision to copy lvb (git-fixes).
- commit 9a5eade
* Tue Jul 16 2024 ailiop@suse.com
- ocfs2: fix DIO failure due to insufficient transaction credits
  (git-fixes).
- commit cf885b6
* Tue Jul 16 2024 ailiop@suse.com
- ocfs2: use coarse time for new created files (git-fixes).
- commit 61f3cb7
* Tue Jul 16 2024 ailiop@suse.com
- ocfs2: fix races between hole punching and AIO+DIO (git-fixes).
- commit bdcd35b
* Tue Jul 16 2024 ailiop@suse.com
- filelock: fix potential use-after-free in posix_lock_inode
  (git-fixes).
- commit 4ceada4
* Tue Jul 16 2024 ailiop@suse.com
- fs/pipe: Fix lockdep false-positive in watchqueue pipe_write()
  (git-fixes).
- commit 047ac8f
* Tue Jul 16 2024 ailiop@suse.com
- tracefs: Add missing lockdown check to tracefs_create_dir()
  (git-fixes).
- commit 65b8efc
* Tue Jul 16 2024 ailiop@suse.com
- f2fs: fix error path of __f2fs_build_free_nids (git-fixes).
- commit 6c1efec
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: zoned: re-enable metadata over-commit for zoned mode
  (bsc#1223731 CVE-2024-26944).
- btrfs: zoned: don't activate non-DATA BG on allocation
  (bsc#1223731 CVE-2024-26944).
- btrfs: zoned: no longer count fresh BG region as zone unusable
  (bsc#1223731 CVE-2024-26944).
- commit cc48fd8
* Tue Jul 16 2024 ematsumiya@suse.de
- smb: client: fix deadlock in smb2_find_smb_tcon() (bsc#1227103,
  CVE-2024-39468).
- commit 1548cc0
* Tue Jul 16 2024 ailiop@suse.com
- orangefs: fix out-of-bounds fsid access (git-fixes).
- commit 8d69475
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: zoned: activate metadata block group on write time
  (bsc#1223731 CVE-2024-26944).
- btrfs: zoned: reserve zones for an active metadata/system
  block group (bsc#1223731 CVE-2024-26944).
- commit 00c0b10
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: zoned: update meta write pointer on zone finish
  (bsc#1223731 CVE-2024-26944).
- btrfs: zoned: defer advancing meta write pointer (bsc#1223731
  CVE-2024-26944).
- commit 9625328
* Tue Jul 16 2024 tbogendoerfer@suse.de
- net/mlx5: Always stop health timer during driver removal
  (CVE-2024-40906 bsc#1227763).
- commit 3630f6e
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: zoned: return int from btrfs_check_meta_write_pointer
  (bsc#1223731 CVE-2024-26944).
- btrfs: zoned: introduce block group context to
  btrfs_eb_write_context (bsc#1223731 CVE-2024-26944).
- btrfs: introduce struct to consolidate extent buffer write
  context (bsc#1223731 CVE-2024-26944).
- commit d8f8b66
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: zoned: use vcalloc instead of for vzalloc in
  btrfs_get_dev_zone_info (bsc#1223731 CVE-2024-26944).
- commit 4837f02
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: open code need_full_stripe conditions (bsc#1223731
  CVE-2024-26944).
- Refresh
  patches.suse/btrfs-be-a-bit-more-careful-when-setting-mirror.patch.
- commit 0011c1e
* Tue Jul 16 2024 ailiop@suse.com
- nilfs2: fix incorrect inode allocation from reserved inodes
  (git-fixes).
- commit 9ce9b3c
* Tue Jul 16 2024 ailiop@suse.com
- nilfs2: convert persistent object allocator to use kmap_local
  (git-fixes).
- commit dc36fd2
* Tue Jul 16 2024 mkubecek@suse.cz
- netfilter: nf_tables: restore set elements when delete set fails
  (CVE-2024-27012 bsc#1223804).
- commit 8ba3bb4
* Tue Jul 16 2024 ailiop@suse.com
- jffs2: Fix potential illegal address access in jffs2_free_inode
  (git-fixes).
- commit 282ccaf
* Tue Jul 16 2024 ailiop@suse.com
- hfsplus: fix to avoid false alarm of circular locking
  (git-fixes).
- commit 490432a
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: open code btrfs_map_sblock (bsc#1223731 CVE-2024-26944).
- commit 5fa5c99
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: rename __btrfs_map_block to btrfs_map_block (bsc#1223731
  CVE-2024-26944).
- commit de51f30
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: remove unused btrfs_map_block (bsc#1223731
  CVE-2024-26944).
- commit 0ff7c2f
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: optimize simple reads in btrfsic_map_block (bsc#1223731
  CVE-2024-26944).
- commit 3260913
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: remove unused BTRFS_MAP_DISCARD (bsc#1223731
  CVE-2024-26944).
- commit 68b562a
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: pass the new logical address to split_extent_map
  (bsc#1223731 CVE-2024-26944).
- commit c2e8884
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: defer splitting of ordered extents until I/O completion
  (bsc#1223731 CVE-2024-26944).
- commit 5ae3e38
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: handle completed ordered extents in
  btrfs_split_ordered_extent (bsc#1223731 CVE-2024-26944).
- commit ddd9e87
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: atomically insert the new extent in
  btrfs_split_ordered_extent (bsc#1223731 CVE-2024-26944).
- commit 4030656
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: split btrfs_alloc_ordered_extent to allocation and
  insertion helpers (bsc#1223731 CVE-2024-26944).
- Refresh
  patches.suse/0002-btrfs-fix-qgroup_free_reserved_data-int-overflow.patch.
- commit e1bc1c4
* Tue Jul 16 2024 tzimmermann@suse.com
- drm/mst: Fix NULL pointer dereference at drm_dp_add_payload_part2 (bsc#1227723 CVE-2024-39498)
- commit bb19e55
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: return the new ordered_extent from
  btrfs_split_ordered_extent (bsc#1223731 CVE-2024-26944).
- commit c61ece3
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: reorder conditions in btrfs_extract_ordered_extent
  (bsc#1223731 CVE-2024-26944).
- commit 7ad1725
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: move split_extent_map to extent_map.c (bsc#1223731
  CVE-2024-26944).
- commit 4667690
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: record orig_physical only for the original bio
  (bsc#1223731 CVE-2024-26944).
- commit f1ddea8
* Tue Jul 16 2024 fdmanana@suse.com
- btrfs: optimize the logical to physical mapping for zoned writes
  (bsc#1223731 CVE-2024-26944).
- Refresh
  patches.suse/0002-btrfs-fix-qgroup_free_reserved_data-int-overflow.patch.
- commit 59cfe96
* Tue Jul 16 2024 tbogendoerfer@suse.de
- ionic: fix use after netif_napi_del() (CVE-2024-39502
  bsc#1227755).
- commit a8905bd
* Tue Jul 16 2024 mkubecek@suse.cz
- netfilter: flowtable: validate pppoe header (CVE-2024-27016
  bsc#1223807).
- commit 4c0256f
* Tue Jul 16 2024 tbogendoerfer@suse.de
- i40e: fix: remove needless retries of NVM update (bsc#1227736).
- commit df4f038
* Tue Jul 16 2024 tiwai@suse.de
- spi: spi-microchip-core: Fix the number of chip selects
  supported (git-fixes).
- spi: atmel-quadspi: Add missing check for clk_prepare
  (git-fixes).
- gpio: mc33880: Convert comma to semicolon (git-fixes).
- pwm: stm32: Always do lazy disabling (git-fixes).
- hwmon: (max6697) Fix swapped temp{1,8} critical alarms
  (git-fixes).
- hwmon: (max6697) Fix underflow when writing limit attributes
  (git-fixes).
- hwmon: (adt7475) Fix default duty on fan is disabled
  (git-fixes).
- platform/chrome: cros_ec_debugfs: fix wrong EC message version
  (git-fixes).
- char: tpm: Fix possible memory leak in
  tpm_bios_measurements_open() (git-fixes).
- tools/memory-model: Fix bug in lock.cat (git-fixes).
- drm/gma500: fix null pointer dereference in
  cdv_intel_lvds_get_modes (git-fixes).
- drm/gma500: fix null pointer dereference in
  psb_intel_lvds_get_modes (git-fixes).
- drm/meson: fix canvas release in bind function (git-fixes).
- commit 027008e
* Tue Jul 16 2024 tiwai@suse.de
- Move upstreamed patches into sorted section
- commit da52786
* Tue Jul 16 2024 dsterba@suse.com
- ipv6: prevent NULL dereference in ip6_output() (CVE-2024-36901 bsc#1225711)
- commit 299bf13
* Tue Jul 16 2024 dsterba@suse.com
- i40e: Do not use WQ_MEM_RECLAIM flag for workqueue (CVE-2024-36004 bsc#1224545)
- commit 42d6eee
* Tue Jul 16 2024 dsterba@suse.com
- nbd: null check for nla_nest_start (CVE-2024-27025 bsc#1223778)
- commit a23796b
* Mon Jul 15 2024 fdmanana@suse.com
- btrfs: rename the bytenr field in struct btrfs_ordered_sum to
  logical (bsc#1223731 CVE-2024-26944).
- btrfs: mark the len field in struct btrfs_ordered_sum as
  unsigned (bsc#1223731 CVE-2024-26944).
- btrfs: don't call btrfs_record_physical_zoned for failed append
  (bsc#1223731 CVE-2024-26944).
- btrfs: optimize out btrfs_is_zoned for !CONFIG_BLK_DEV_ZONED
  (bsc#1223731 CVE-2024-26944).
- commit 7e64d12
* Mon Jul 15 2024 fdmanana@suse.com
- btrfs: use SECTOR_SHIFT to convert LBA to physical offset
  (bsc#1223731 CVE-2024-26944).
- Refresh
  patches.suse/btrfs-don-t-warn-if-discard-range-is-not-aligned-to-.patch.
- commit ad23354
* Mon Jul 15 2024 fdmanana@suse.com
- btrfs: don't hold an extra reference for redirtied buffers
  (bsc#1223731 CVE-2024-26944).
- Refresh
  patches.suse/0003-btrfs-free-qgroup-pertrans-reserve-on-transaction-ab.patch.
- commit 47897b2
* Mon Jul 15 2024 fdmanana@suse.com
- btrfs: export bitmap_test_range_all_{set,zero} (bsc#1223731
  CVE-2024-26944).
- commit fcba900
* Mon Jul 15 2024 tiwai@suse.de
- Update patch reference for ath12k fix (CVE-2024-40979 bsc#1227855)
- commit 0463455
* Mon Jul 15 2024 mhocko@suse.com
- mlxsw: spectrum_acl_tcam: Fix memory leak during rehash
  (CVE-2024-35853 bsc#1224604).
- commit d46e600
* Mon Jul 15 2024 mhocko@suse.com
- mlxsw: spectrum_acl_tcam: Fix possible use-after-free during
  activity update (CVE-2024-35854 bsc#1224636).
- commit 7cd7b18
* Mon Jul 15 2024 mhocko@suse.com
- phonet/pep: fix racy skb_queue_empty() use (CVE-2024-27402
  bsc#1224414).
- commit 9f9d7b5
* Mon Jul 15 2024 petr.pavlu@suse.com
- kprobe/ftrace: fix build error due to bad function definition
  (git-fixes).
- commit 16bb0c0
* Mon Jul 15 2024 mhocko@suse.com
- net: prevent mss overflow in skb_segment() (CVE-2023-52435
  bsc#1220138).
- commit b718cb4
* Mon Jul 15 2024 mhocko@suse.com
- netfilter: nf_tables: do not compare internal table flags on
  updates (CVE-2024-27065 bsc#1223836).
- commit 0e49dd8
* Mon Jul 15 2024 petr.pavlu@suse.com
- tracing/net_sched: NULL pointer dereference in
  perf_trace_qdisc_reset() (git-fixes).
- commit c773566
* Mon Jul 15 2024 petr.pavlu@suse.com
- tracing: Build event generation tests only as modules
  (git-fixes).
- commit dd7f603
* Mon Jul 15 2024 oneukum@suse.com
- usb: ucsi: stm32: fix command completion handling (git-fixes).
- commit 3155170
* Mon Jul 15 2024 oneukum@suse.com
- Bluetooth: qca: set power_ctrl_enabled on NULL returned by
  gpiod_get_optional() (git-fixes).
- commit 3a34099
* Mon Jul 15 2024 petr.pavlu@suse.com
- cachefiles: add output string to
  cachefiles_obj_[get|put]_ondemand_fd (git-fixes).
- commit 12446de
* Mon Jul 15 2024 tiwai@suse.de
- iommu/vt-d: Allocate DMAR fault interrupts locally
  (bsc#1224767).
- commit 85bf7e2
* Mon Jul 15 2024 tiwai@suse.de
- iommu/amd: Fix panic accessing amd_iommu_enable_faulting
  (bsc#1224767).
- commit 567c8c9
* Mon Jul 15 2024 mhocko@suse.com
- netfilter: flowtable: incorrect pppoe tuple (CVE-2024-27015
  bsc#1223806).
- commit e834f51
* Mon Jul 15 2024 mhocko@suse.com
- netfilter: nf_tables: Fix a memory leak in nf_tables_updchain
  (CVE-2024-27064 bsc#1223740).
- commit daf6634
* Mon Jul 15 2024 petr.pavlu@suse.com
- kprobe/ftrace: bail out if ftrace was killed (git-fixes).
- commit 43ba702
* Mon Jul 15 2024 mhocko@suse.com
- tipc: Check the bearer type before calling
  tipc_udp_nl_bearer_add() (CVE-2024-26663 bsc#1222326).
- commit fff5ef3
* Mon Jul 15 2024 petr.pavlu@suse.com
- Update
  patches.suse/ring-buffer-Fix-a-race-between-readers-and-resize-checks.patch
  (bsc#1222893).
- commit eebb09a
* Mon Jul 15 2024 tiwai@suse.de
- wifi: ath11k: Add coldboot calibration support for QCN9074
  (bsc#1227149).
- wifi: ath11k: Split coldboot calibration hw_param (bsc#1227149).
- Refresh
  patches.suse/wifi-ath11k-fix-boot-failure-with-one-MSI-vector.patch.
- Refresh patches.suse/wifi-ath11k-support-hibernation.patch.
- commit e553d75
* Mon Jul 15 2024 tiwai@suse.de
- wifi: ath9k: avoid using uninitialized array (bsc#1227149).
- Refresh patches.suse/wifi-ath9k-fix-fortify-warnings.patch.
- commit 7a06512
* Mon Jul 15 2024 vkarasulli@suse.de
- iommu: Fix compilation without CONFIG_IOMMU_INTEL (git-fixes).
- commit dcdbf4a
* Mon Jul 15 2024 tiwai@suse.de
- wifi: mt76: mt7615: add missing chanctx ops (bsc#1227149).
- wifi: mt76: mt7915: add missing chanctx ops (bsc#1227149).
- commit 5e9fc63
* Sun Jul 14 2024 tiwai@suse.de
- kABI workaround for wireless updates (bsc#1227149).
- commit 956c903
* Sun Jul 14 2024 tiwai@suse.de
- i2c: rcar: bring hardware to known state when probing
  (git-fixes).
- i2c: testunit: avoid re-issued work after read message
  (git-fixes).
- i2c: mark HostNotify target address as used (git-fixes).
- i2c: testunit: correct Kconfig description (git-fixes).
- commit 834d4d5
* Sat Jul 13 2024 tiwai@suse.de
- supported.conf: update for mt76 stuff (bsc#1227149)
- commit 276fbe5
* Sat Jul 13 2024 tiwai@suse.de
- kabi/severities: cover all mt76 modules (bsc#1227149)
- commit 8877f2f
* Sat Jul 13 2024 tiwai@suse.de
- wifi: mac80211: fix BSS_CHANGED_UNSOL_BCAST_PROBE_RESP
  (bsc#1227149).
- commit a3d6465
* Sat Jul 13 2024 tiwai@suse.de
- wifi: mac80211: fix monitor channel with chanctx emulation
  (bsc#1227149).
- wifi: cfg80211: validate HE operation element parsing
  (bsc#1227149).
- wifi: mac80211: don't select link ID if not provided in scan
  request (bsc#1227149).
- wifi: mac80211: check EHT/TTLM action frame length
  (bsc#1227149).
- wifi: mac80211: correctly set active links upon TTLM
  (bsc#1227149).
- wifi: cfg80211: set correct param change count in ML element
  (bsc#1227149).
- wifi: mac80211: use deflink and fix typo in link ID check
  (bsc#1227149).
- commit e4d62d6
* Sat Jul 13 2024 tiwai@suse.de
- kabi/severities: ignore kABI changes Realtek WiFi drivers (bsc#1227149)
  All those symbols are local and used for its own helpers
- commit c402c7b
* Sat Jul 13 2024 tiwai@suse.de
- wifi: rtlwifi: Ignore IEEE80211_CONF_CHANGE_RETRY_LIMITS
  (bsc#1227149).
- wifi: rtw89: wow: refine WoWLAN flows of HCI interrupts and
  low power mode (bsc#1227149).
- wifi: rtl8xxxu: enable MFP support with security flag of RX
  descriptor (bsc#1227149).
- wifi: rtw89: fw: scan offload prohibit all 6 GHz channel if
  no 6 GHz sband (bsc#1227149).
- wifi: rtw89: 8852c: add quirk to set PCI BER for certain
  platforms (bsc#1227149).
- wifi: rtw89: download firmware with five times retry
  (bsc#1227149).
- commit 70ec305
* Sat Jul 13 2024 tiwai@suse.de
- wifi: rtw89: coex: fix configuration for shared antenna for
  8922A (bsc#1227149).
- wifi: rtw89: wow: move release offload packet earlier for
  WoWLAN mode (bsc#1227149).
- wifi: rtw89: wow: set security engine options for 802.11ax
  chips only (bsc#1227149).
- wifi: rtw89: update suspend/resume for different generation
  (bsc#1227149).
- wifi: rtw89: wow: update config mac function with different
  generation (bsc#1227149).
- wifi: rtw89: update DMA function with different generation
  (bsc#1227149).
- wifi: rtw89: wow: update WoWLAN status register for different
  generation (bsc#1227149).
- wifi: rtw89: wow: update WoWLAN reason register for different
  chips (bsc#1227149).
- wifi: rtw89: coex: Add coexistence policy to decrease WiFi
  packet CRC-ERR (bsc#1227149).
- wifi: rtw89: coex: When Bluetooth not available don't set
  power/gain (bsc#1227149).
- wifi: rtw89: coex: add return value to ensure H2C command is
  success or not (bsc#1227149).
- wifi: rtw89: coex: Reorder H2C command index to align with
  firmware (bsc#1227149).
- wifi: rtw89: coex: add BTC ctrl_info version 7 and related logic
  (bsc#1227149).
- wifi: rtw89: coex: add init_info H2C command format version 7
  (bsc#1227149).
- wifi: rtw89: 8922a: add coexistence helpers of SW grant
  (bsc#1227149).
- wifi: rtw89: mac: add coexistence helpers {cfg/get}_plt
  (bsc#1227149).
- wifi: rtlwifi: Remove rtl_intf_ops.read_efuse_byte
  (bsc#1227149).
- wifi: rtl8xxxu: fix mixed declarations in rtl8xxxu_set_aifs()
  (bsc#1227149).
- wifi: rtw89: pci: implement PCI CLK/ASPM/L1SS for WiFi 7 chips
  (bsc#1227149).
- wifi: rtw89: Update EHT PHY beamforming capability
  (bsc#1227149).
- wifi: rtw89: advertise missing extended scan feature
  (bsc#1227149).
- wifi: rtlwifi: set initial values for unexpected cases of USB
  endpoint priority (bsc#1227149).
- wifi: rtl8xxxu: check vif before using in rtl8xxxu_tx()
  (bsc#1227149).
- wifi: rtlwifi: rtl8192cu: Fix TX aggregation (bsc#1227149).
- commit e9149f1
* Sat Jul 13 2024 tiwai@suse.de
- wifi: rtw89: 8922a: add helper of set_channel (bsc#1227149).
- wifi: rtw89: 8922a: add set_channel RF part (bsc#1227149).
- wifi: rtw89: 8922a: add set_channel BB part (bsc#1227149).
- wifi: rtw89: 8922a: add set_channel MAC part (bsc#1227149).
- wifi: rtlwifi: rtl_usb: Store the endpoint addresses
  (bsc#1227149).
- wifi: rtlwifi: rtl8192cu: Fix 2T2R chip type detection
  (bsc#1227149).
- wifi: rtw89: 8922a: declare to support two chanctx
  (bsc#1227149).
- wifi: rtw89: chan: support MCC on Wi-Fi 7 chips (bsc#1227149).
- wifi: rtw89: fw: implement MRC H2C command functions
  (bsc#1227149).
- wifi: rtw89: mac: implement MRC C2H event handling
  (bsc#1227149).
- wifi: rtw89: fw: add definition of H2C command and C2H event
  for MRC series (bsc#1227149).
- wifi: rtw89: change qutoa to DBCC by default for WiFi 7 chips
  (bsc#1227149).
- wifi: rtw89: reference quota mode when setting Tx power
  (bsc#1227149).
- wifi: rtw89: 8922a: implement AP mode related reg for BE
  generation (bsc#1227149).
- wifi: rtw89: 8922a: correct register definition and merge IO
  for ctrl_nbtg_bt_tx() (bsc#1227149).
- wifi: rtw89: differentiate narrow_bw_ru_dis setting according
  to chip gen (bsc#1227149).
- wifi: rtw89: use PLCP information to match BSS_COLOR and AID
  (bsc#1227149).
- wifi: rtw89: mac: reset PHY-1 hardware when going to
  enable/disable (bsc#1227149).
- wifi: rtw89: mac: correct MUEDCA setting for MAC-1
  (bsc#1227149).
- wifi: rtw89: mac: return held quota of DLE when changing MAC-1
  (bsc#1227149).
- wifi: rtw89: load BB parameters to PHY-1 (bsc#1227149).
- wifi: rtw89: correct PHY register offset for PHY-1
  (bsc#1227149).
- wifi: rtw89: chan: MCC take reconfig into account (bsc#1227149).
- wifi: rtw89: chan: move handling from add/remove to
  assign/unassign for MLO (bsc#1227149).
- wifi: rtw89: chan: tweak weight recalc ahead before MLO
  (bsc#1227149).
- wifi: rtw89: chan: tweak bitmap recalc ahead before MLO
  (bsc#1227149).
- wifi: rtw89: chan: add sub-entity swap function to cover
  replacing (bsc#1227149).
- wifi: rtw89: drop TIMING_BEACON_ONLY and sync beacon TSF by self
  (bsc#1227149).
- wifi: rtl8xxxu: update rate mask per sta (bsc#1227149).
- wifi: rtw89: fw: download firmware with key data for secure boot
  (bsc#1227149).
- wifi: rtw89: fw: parse secure section from firmware file
  (bsc#1227149).
- wifi: rtw89: fw: read firmware secure information from efuse
  (bsc#1227149).
- wifi: rtw89: fw: consider checksum length of security data
  (bsc#1227149).
- wifi: rtw89: 8922a: add chip_ops::rfk_hw_init (bsc#1227149).
- wifi: rtw89: 8922a: add chip_ops::rfk_init_late to do initial
  RF calibrations later (bsc#1227149).
- commit 28c4b55
* Sat Jul 13 2024 tiwai@suse.de
- wifi: rtw89: 8922a: rfk: implement chip_ops to call RF
  calibrations (bsc#1227149).
- wifi: rtw89: rfk: add H2C command to trigger TSSI (bsc#1227149).
- wifi: rtw89: rfk: add H2C command to trigger TXGAPK
  (bsc#1227149).
- wifi: rtw89: rfk: add H2C command to trigger DACK (bsc#1227149).
- wifi: rtw89: rfk: add H2C command to trigger DPK (bsc#1227149).
- wifi: rtw89: rfk: add H2C command to trigger RX DCK
  (bsc#1227149).
- wifi: rtw89: rfk: add H2C command to trigger IQK (bsc#1227149).
- wifi: rtw89: rfk: send channel information to firmware for RF
  calibrations (bsc#1227149).
- wifi: rtw89: rfk: add a completion to wait RF calibration
  report from C2H event (bsc#1227149).
- wifi: rtl8xxxu: Add TP-Link TL-WN823N V2 (bsc#1227149).
- wifi: rtl8xxxu: fix error messages (bsc#1227149).
- wifi: rtw89: 8922a: add more fields to beacon H2C command to
  support multi-links (bsc#1227149).
- wifi: rtw89: update ps_state register for chips with different
  generation (bsc#1227149).
- wifi: rtw89: add new H2C for PS mode in 802.11be chip
  (bsc#1227149).
- wifi: rtw89: 8922a: add ieee80211_ops::hw_scan (bsc#1227149).
- wifi: rtw89: prepare scan leaf functions for wifi 7 ICs
  (bsc#1227149).
- wifi: rtw89: debug: add FW log component for scan (bsc#1227149).
- wifi: rtw89: update scan C2H messages for wifi 7 IC
  (bsc#1227149).
- wifi: rtw89: 8922a: set chip_ops FEM and GPIO to NULL
  (bsc#1227149).
- wifi: rtw89: 8922a: add chip_ops to get thermal value
  (bsc#1227149).
- wifi: rtw89: 8922a: add RF read/write v2 (bsc#1227149).
- wifi: rtw89: 8922a: add chip_ops::cfg_txrx_path (bsc#1227149).
- wifi: rtw89: 8922a: implement {stop,resume}_sch_tx and cfg_ppdu
  (bsc#1227149).
- wifi: rtw89: 8922a: hook handlers of TX/RX descriptors to
  chip_ops (bsc#1227149).
- wifi: rtw89: pci: validate RX tag for RXQ and RPQ (bsc#1227149).
- wifi: rtw89: pci: interrupt v2 refine IMR for SER (bsc#1227149).
- wifi: rtw89: pci: update SER timer unit and timeout time
  (bsc#1227149).
- wifi: rtw89: fix disabling concurrent mode TX hang issue
  (bsc#1227149).
- wifi: rtw89: fix HW scan timeout due to TSF sync issue
  (bsc#1227149).
- wifi: rtw89: add wait/completion for abort scan (bsc#1227149).
- wifi: rtw89: disable RTS when broadcast/multicast (bsc#1227149).
- wifi: rtw89: Set default CQM config if not present
  (bsc#1227149).
- wifi: rtw89: refine hardware scan C2H events (bsc#1227149).
- wifi: rtw89: refine add_chan H2C command to encode_bits
  (bsc#1227149).
- wifi: rtw89: 8922a: add BTG functions to assist BT coexistence
  to control TX/RX (bsc#1227149).
- wifi: rtw89: 8922a: add TX power related ops (bsc#1227149).
- wifi: rtw89: 8922a: add register definitions of H2C, C2H,
  page, RRSR and EDCCA (bsc#1227149).
- wifi: rtw89: 8922a: add chip_ops related to BB init
  (bsc#1227149).
- wifi: rtw89: 8922a: add chip_ops::{enable,disable}_bb_rf
  (bsc#1227149).
- wifi: rtw89: add mlo_dbcc_mode for WiFi 7 chips (bsc#1227149).
- wifi: rtlwifi: Speed up firmware loading for USB (bsc#1227149).
- wifi: rtl8xxxu: add missing number of sec cam entries for all
  variants (bsc#1227149).
- wifi: rtl8xxxu: make instances of iface limit and combination
  to be static const (bsc#1227149).
- wifi: rtl8xxxu: convert EN_DESC_ID of TX descriptor to le32 type
  (bsc#1227149).
- wifi: rtlwifi: rtl8192de: Don't read register in
  _rtl92de_query_rxphystatus (bsc#1227149).
- wifi: rtw89: fw: extend JOIN H2C command to support WiFi 7 chips
  (bsc#1227149).
- wifi: rtw89: fw: use struct to fill JOIN H2C command
  (bsc#1227149).
- wifi: rtw89: fw: add H2C command to reset DMAC table for WiFi 7
  (bsc#1227149).
- wifi: rtw89: fw: add H2C command to reset CMAC table for WiFi 7
  (bsc#1227149).
- wifi: rtw89: fw: update TX AMPDU parameter to CMAC table
  (bsc#1227149).
- wifi: rtw89: fw: add chip_ops to update CMAC table to associated
  station (bsc#1227149).
- wifi: rtw89: fw: fill CMAC table to associated station for
  WiFi 7 chips (bsc#1227149).
- wifi: rtw89: fw: add H2C command to update security CAM v2
  (bsc#1227149).
- wifi: rtw89: declare EXT NSS BW of VHT capability (bsc#1227149).
- wifi: rtw89: add EHT capabilities for WiFi 7 chips
  (bsc#1227149).
- wifi: rtw89: change supported bandwidths of chip_info to bit
  mask (bsc#1227149).
- wifi: rtw89: adjust init_he_cap() to add EHT cap into
  iftype_data (bsc#1227149).
- wifi: rtw88: use kstrtoX_from_user() in debugfs handlers
  (bsc#1227149).
- wifi: rtl8xxxu: enable channel switch support (bsc#1227149).
- wifi: rtlwifi: rtl_usb: Use sync register writes (bsc#1227149).
- commit 055a697
* Sat Jul 13 2024 tiwai@suse.de
- wifi: rtlwifi: cleanup few rtlxxx_tx_fill_desc() routines
  (bsc#1227149).
- wifi: rtw89: add chip_ops::update_beacon to abstract update
  beacon operation (bsc#1227149).
- wifi: rtw89: add H2C command to download beacon frame for WiFi
  7 chips (bsc#1227149).
- wifi: rtw89: use struct to fill H2C command to download beacon
  frame (bsc#1227149).
- wifi: rtw89: add new H2C command to pause/sleep transmitting
  by MAC ID (bsc#1227149).
- wifi: rtw89: refine H2C command that pause transmitting by
  MAC ID (bsc#1227149).
- wifi: rtw89: fw: use struct to fill BA CAM H2C commands
  (bsc#1227149).
- wifi: rtw89: 8922a: update BA CAM number to 24 (bsc#1227149).
- wifi: rtw89: add chip_ops::h2c_ba_cam() to configure BA CAM
  (bsc#1227149).
- wifi: rtw89: mac: add feature_init to initialize BA CAM V1
  (bsc#1227149).
- wifi: rtw89: add firmware H2C command of BA CAM V1
  (bsc#1227149).
- wifi: rtl8xxxu: Fix off by one initial RTS rate (bsc#1227149).
- wifi: rtl8xxxu: Fix LED control code of RTL8192FU (bsc#1227149).
- wifi: rtl8xxxu: declare concurrent mode support for 8188f
  (bsc#1227149).
- wifi: rtl8xxxu: make supporting AP mode only on port 0
  transparent (bsc#1227149).
- wifi: rtl8xxxu: add hw crypto support for AP mode (bsc#1227149).
- wifi: rtl8xxxu: remove obsolete priv->vif (bsc#1227149).
- wifi: rtl8xxxu: add macids for STA mode (bsc#1227149).
- wifi: rtl8xxxu: support multiple interface in start_ap()
  (bsc#1227149).
- wifi: rtl8xxxu: support multiple interfaces in
  bss_info_changed() (bsc#1227149).
- wifi: rtl8xxxu: support multiple interfaces in
  {add,remove}_interface() (bsc#1227149).
- wifi: rtl8xxxu: support multiple interfaces in
  watchdog_callback() (bsc#1227149).
- wifi: rtl8xxxu: support multiple interfaces in
  configure_filter() (bsc#1227149).
- wifi: rtl8xxxu: support multiple interfaces in
  update_beacon_work_callback() (bsc#1227149).
- wifi: rtl8xxxu: support multiple interfaces in set_aifs()
  (bsc#1227149).
- wifi: rtl8xxxu: support setting bssid register for multiple
  interfaces (bsc#1227149).
- wifi: rtl8xxxu: don't parse CFO, if both interfaces are
  connected in STA mode (bsc#1227149).
- wifi: rtl8xxxu: extend check for matching bssid to both
  interfaces (bsc#1227149).
- wifi: rtl8xxxu: extend wifi connected check to both interfaces
  (bsc#1227149).
- wifi: rtl8xxxu: support setting mac address register for both
  interfaces (bsc#1227149).
- wifi: rtl8xxxu: 8188e: convert usage of priv->vif to
  priv->vifs[0] (bsc#1227149).
- wifi: rtl8xxxu: support setting linktype for both interfaces
  (bsc#1227149).
- wifi: rtl8xxxu: prepare supporting two virtual interfaces
  (bsc#1227149).
- wifi: rtl8xxxu: remove assignment of priv->vif in
  rtl8xxxu_bss_info_changed() (bsc#1227149).
- wifi: rtw88: 8822ce: refine power parameters for RFE type 5
  (bsc#1227149).
- wifi: rtw89: mac: Fix spelling mistakes "notfify" -> "notify"
  (bsc#1227149).
- wifi: rtw89: phy: set channel_info for WiFi 7 chips
  (bsc#1227149).
- wifi: rtw89: phy: add BB wrapper of TX power for WiFi 7 chips
  (bsc#1227149).
- wifi: rtw89: 8922a: add NCTL pre-settings for WiFi 7 chips
  (bsc#1227149).
- wifi: rtw89: phy: ignore special data from BB parameter file
  (bsc#1227149).
- wifi: rtw89: 8922a: update the register used in DIG and the
  DIG flow (bsc#1227149).
- wifi: rtw89: 8922a: set RX gain along with set_channel operation
  (bsc#1227149).
- wifi: rtw89: phy: add parser to support RX gain dynamic setting
  flow (bsc#1227149).
- wifi: rtw89: phy: move bb_gain_info used by WiFi 6 chips to
  union (bsc#1227149).
- wifi: rtw89: 8851b: update TX power tables to R37 (bsc#1227149).
- wifi: rtw89: 8852b: update TX power tables to R36 (bsc#1227149).
- wifi: rtw89: pci: use DBI function for 8852AE/8852BE/8851BE
  (bsc#1227149).
- wifi: rtlwifi: rtl8821ae: phy: using calculate_bit_shift()
  (bsc#1227149).
- wifi: rtw89: coex: To improve Wi-Fi performance while BT is idle
  (bsc#1227149).
- wifi: rtw89: coex: Translate antenna configuration from ID to
  string (bsc#1227149).
- commit d99b9e1
* Sat Jul 13 2024 tiwai@suse.de
- wifi: rtw89: coex: Update RF parameter control setting logic
  (bsc#1227149).
- wifi: rtw89: coex: Add Bluetooth RSSI level information
  (bsc#1227149).
- wifi: rtw89: coex: Set Bluetooth scan low-priority when Wi-Fi
  link/scan (bsc#1227149).
- wifi: rtw89: coex: Update coexistence policy for Wi-Fi LPS
  (bsc#1227149).
- wifi: rtw89: coex: Still show hardware grant signal info even
  Wi-Fi is PS (bsc#1227149).
- wifi: rtw89: coex: Update BTG control related logic
  (bsc#1227149).
- wifi: rtw89: coex: Add Pre-AGC control to enhance Wi-Fi RX
  performance (bsc#1227149).
- wifi: rtw89: coex: Record down Wi-Fi initial mode information
  (bsc#1227149).
- wifi: rtw89: coex: Fix wrong Wi-Fi role info and FDDT parameter
  members (bsc#1227149).
- wifi: rtw88: use cfg80211_ssid_eq() instead of rtw_ssid_equal()
  (bsc#1227149).
- wifi: rtw89: mac: implement to configure TX/RX engines for
  WiFi 7 chips (bsc#1227149).
- wifi: rtw89: mac: add sys_init and filter option for WiFi 7
  chips (bsc#1227149).
- wifi: rtw89: only reset BB/RF for existing WiFi 6 chips while
  starting up (bsc#1227149).
- wifi: rtw89: add DBCC H2C to notify firmware the status
  (bsc#1227149).
- wifi: rtw89: mac: add suffix _ax to MAC functions (bsc#1227149).
- wifi: rtw89: mac: add flags to check if CMAC and DMAC are
  enabled (bsc#1227149).
- wifi: rtw89: 8922a: add power on/off functions (bsc#1227149).
- wifi: rtw89: add XTAL SI for WiFi 7 chips (bsc#1227149).
- wifi: rtw89: phy: print out RFK log with formatted string
  (bsc#1227149).
- wifi: rtw89: parse and print out RFK log from C2H events
  (bsc#1227149).
- wifi: rtw89: add C2H event handlers of RFK log and report
  (bsc#1227149).
- wifi: rtw89: load RFK log format string from firmware file
  (bsc#1227149).
- wifi: rtw89: fw: add version field to BB MCU firmware element
  (bsc#1227149).
- wifi: rtw89: fw: load TX power track tables from fw_element
  (bsc#1227149).
- wifi: rtw88: Use random MAC when efuse MAC invalid
  (bsc#1227149).
- wifi: rtw89: avoid stringop-overflow warning (bsc#1227149).
- wifi: rtw89: mac: refine SER setting during WiFi CPU power on
  (bsc#1227149).
- wifi: rtw89: 8922a: dump MAC registers when SER occurs
  (bsc#1227149).
- wifi: rtw89: 8922a: add SER IMR tables (bsc#1227149).
- wifi: rtw89: fw: extend program counter dump for Wi-Fi 7 chip
  (bsc#1227149).
- wifi: rtw89: 8922a: configure CRASH_TRIGGER FW feature
  (bsc#1227149).
- wifi: rtw89: fix misbehavior of TX beacon in concurrent mode
  (bsc#1227149).
- wifi: rtw89: refine remain on channel flow to improve P2P
  connection (bsc#1227149).
- wifi: rtw89: Refine active scan behavior in 6 GHz (bsc#1227149).
- wifi: rtw89: fix not entering PS mode after AP stops
  (bsc#1227149).
- wifi: rtlwifi: Remove bridge vendor/device ids (bsc#1227149).
- wifi: rtlwifi: Remove unused PCI related defines and struct
  (bsc#1227149).
- wifi: rtlwifi: rtl8821ae: Access full PMCS reg and use
  pci_regs.h (bsc#1227149).
- wifi: rtlwifi: rtl8821ae: Add pdev into
  _rtl8821ae_clear_pci_pme_status() (bsc#1227149).
- wifi: rtlwifi: rtl8821ae: Use pci_find_capability()
  (bsc#1227149).
- wifi: rtlwifi: rtl8821ae: Reverse PM Capability exists check
  (bsc#1227149).
- wifi: rtlwifi: rtl8821ae: Remove unnecessary PME_Status bit set
  (bsc#1227149).
- wifi: rtlwifi: Convert to use PCIe capability accessors
  (bsc#1227149).
- wifi: rtw89: mac: functions to configure hardware engine and
  quota for WiFi 7 chips (bsc#1227149).
- wifi: rtw89: mac: use pointer to access functions of hardware
  engine and quota (bsc#1227149).
- wifi: rtw89: mac: move code related to hardware engine to
  individual functions (bsc#1227149).
- wifi: rtw89: mac: check queue empty according to chip gen
  (bsc#1227149).
- wifi: rtw89: refine element naming used by queue empty check
  (bsc#1227149).
- wifi: rtw89: add reserved size as factor of DLE used size
  (bsc#1227149).
- wifi: rtw89: mac: add to get DLE reserved quota (bsc#1227149).
- commit cf41ac5
* Sat Jul 13 2024 tiwai@suse.de
- wifi: rtw89: 8922a: extend and add quota number (bsc#1227149).
- wifi: rtw89: debug: remove wrapper of rtw89_debug()
  (bsc#1227149).
- wifi: rtw89: debug: add debugfs entry to disable dynamic
  mechanism (bsc#1227149).
- wifi: rtw89: phy: dynamically adjust EDCCA threshold
  (bsc#1227149).
- wifi: rtw89: debug: add to check if debug mask is enabled
  (bsc#1227149).
- wifi: rtlwifi: rtl8821ae: phy: remove some useless code
  (bsc#1227149).
- wifi: rtw88: debug: remove wrapper of rtw_dbg() (bsc#1227149).
- wifi: rtw89: 8922a: read efuse content from physical map
  (bsc#1227149).
- wifi: rtw89: 8922a: read efuse content via efuse map struct
  from logic map (bsc#1227149).
- wifi: rtw89: 8852c: read RX gain offset from efuse for 6GHz
  channels (bsc#1227149).
- wifi: rtw89: mac: add to access efuse for WiFi 7 chips
  (bsc#1227149).
- wifi: rtw89: mac: use mac_gen pointer to access about efuse
  (bsc#1227149).
- wifi: rtw89: 8922a: add 8922A basic chip info (bsc#1227149).
- wifi: rtlwifi: drop unused const_amdpci_aspm (bsc#1227149).
- wifi: rtw89: regd: update regulatory map to R65-R44
  (bsc#1227149).
- wifi: rtw89: regd: handle policy of 6 GHz according to BIOS
  (bsc#1227149).
- wifi: rtw89: acpi: process 6 GHz band policy from DSM
  (bsc#1227149).
- wifi: rtlwifi: simplify rtl_action_proc() and rtl_tx_agg_start()
  (bsc#1227149).
- wifi: rtw89: pci: update interrupt mitigation register for
  8922AE (bsc#1227149).
- wifi: rtw89: pci: correct interrupt mitigation register for
  8852CE (bsc#1227149).
- wifi: rtw89: 8922ae: add v2 interrupt handlers for 8922AE
  (bsc#1227149).
- wifi: rtw89: pci: generalize interrupt status bits of interrupt
  handlers (bsc#1227149).
- wifi: rtw89: pci: add pre_deinit to be called after probe
  complete (bsc#1227149).
- wifi: rtw89: pci: stop/start DMA for level 1 recovery according
  to chip gen (bsc#1227149).
- wifi: rtw89: pci: reset BDRAM according to chip gen
  (bsc#1227149).
- wifi: rtw88: simplify __rtw_tx_work() (bsc#1227149).
- wifi: rtw89: coex: use struct assignment to replace memcpy()
  to append TDMA content (bsc#1227149).
- wifi: rtw89: pci: implement PCI mac_post_init for WiFi 7 chips
  (bsc#1227149).
- wifi: rtw89: pci: add LTR v2 for WiFi 7 chip (bsc#1227149).
- wifi: rtw89: pci: implement PCI mac_pre_init for WiFi 7 chips
  (bsc#1227149).
- commit dcfcac7
* Sat Jul 13 2024 tiwai@suse.de
- wifi: rtw89: pci: use gen_def pointer to configure
  mac_{pre,post}_init and clear PCI ring index (bsc#1227149).
- wifi: rtw89: pci: add PCI generation information to pci_info
  for each chip (bsc#1227149).
- wifi: rtw89: extend PHY status parser to support WiFi 7 chips
  (bsc#1227149).
- wifi: rtw89: consider RX info for WiFi 7 chips (bsc#1227149).
- wifi: rtw89: configure PPDU max user by chip (bsc#1227149).
- wifi: rtw89: set entry size of address CAM to H2C field by chip
  (bsc#1227149).
- wifi: rtw89: pci: generalize code of PCI control DMA IO for
  WiFi 7 (bsc#1227149).
- wifi: rtw89: pci: add new RX ring design to determine full RX
  ring efficiently (bsc#1227149).
- wifi: rtw89: pci: define PCI ring address for WiFi 7 chips
  (bsc#1227149).
- wifi: rtw89: 8922ae: add 8922AE PCI entry and basic info
  (bsc#1227149).
- wifi: rtlwifi: rtl92ee_dm_dynamic_primary_cca_check(): fix
  typo in function name (bsc#1227149).
- wifi: rtlwifi: cleanup struct rtl_phy (bsc#1227149).
- wifi: rtlwifi: cleanup struct rtl_hal (bsc#1227149).
- wifi: rtw89: cleanup firmware elements parsing (bsc#1227149).
- wifi: rtlwifi: drop chk_switch_dmdp() from HAL interface
  (bsc#1227149).
- wifi: rtlwifi: drop fill_fake_txdesc() from HAL interface
  (bsc#1227149).
- wifi: rtlwifi: drop pre_fill_tx_bd_desc() from HAL interface
  (bsc#1227149).
- wifi: rtw89: move software DCFO compensation setting to proper
  position (bsc#1227149).
- wifi: rtw89: correct the DCFO tracking flow to improve CFO
  compensation (bsc#1227149).
- wifi: rtw89: modify the register setting and the flow of CFO
  tracking (bsc#1227149).
- wifi: rtw89: phy: generalize valid bit of BSS color
  (bsc#1227149).
- wifi: rtw89: phy: change naming related BT coexistence functions
  (bsc#1227149).
- wifi: rtw88: dump firmware debug information in abnormal state
  (bsc#1227149).
- wifi: rtw88: debug: add to check if debug mask is enabled
  (bsc#1227149).
- wifi: rtlwifi: cleanup struct rtl_ps_ctl (bsc#1227149).
- wifi: rtw89: mac: do bf_monitor only if WiFi 6 chips
  (bsc#1227149).
- wifi: rtw89: mac: set bf_assoc capabilities according to chip
  gen (bsc#1227149).
- wifi: rtw89: mac: set bfee_ctrl() according to chip gen
  (bsc#1227149).
- wifi: rtw89: mac: add registers of MU-EDCA parameters for WiFi
  7 chips (bsc#1227149).
- wifi: rtw89: mac: generalize register of MU-EDCA switch
  according to chip gen (bsc#1227149).
- wifi: rtw89: mac: update RTS threshold according to chip gen
  (bsc#1227149).
- wifi: rtlwifi: simplify TX command fill callbacks (bsc#1227149).
- wifi: rtw89: coex: add annotation __counted_by() to struct
  rtw89_btc_btf_set_mon_reg (bsc#1227149).
- wifi: rtw89: coex: add annotation __counted_by() for struct
  rtw89_btc_btf_set_slot_table (bsc#1227149).
- wifi: rtw89: add EHT radiotap in monitor mode (bsc#1227149).
- wifi: rtw89: show EHT rate in debugfs (bsc#1227149).
- wifi: rtw89: parse TX EHT rate selected by firmware from RA
  C2H report (bsc#1227149).
- wifi: rtw89: Add EHT rate mask as parameters of RA H2C command
  (bsc#1227149).
- wifi: rtw89: parse EHT information from RX descriptor and PPDU
  status packet (bsc#1227149).
- wifi: rtlwifi: use convenient list_count_nodes() (bsc#1227149).
- commit 53661e1
* Sat Jul 13 2024 tiwai@suse.de
- wifi: rtlwifi: use unsigned long for bt_coexist_8723 timestamp
  (bsc#1227149).
- wifi: rtw88: 8821c: tweak CCK TX filter setting for SRRC
  regulation (bsc#1227149).
- wifi: rtw88: regd: update regulatory map to R64-R42
  (bsc#1227149).
- wifi: rtw88: 8822c: update TX power limit to V70 (bsc#1227149).
- wifi: rtw88: 8821c: update TX power limit to V67 (bsc#1227149).
- wifi: rtw88: regd: configure QATAR and UK (bsc#1227149).
- wifi: rtlwifi: remove unreachable code in
  rtl92d_dm_check_edca_turbo() (bsc#1227149).
- wifi: rtw89: debug: txpwr table supports Wi-Fi 7 chips
  (bsc#1227149).
- wifi: rtw89: debug: show txpwr table according to chip gen
  (bsc#1227149).
- wifi: rtw89: phy: set TX power RU limit according to chip gen
  (bsc#1227149).
- wifi: rtw89: phy: set TX power limit according to chip gen
  (bsc#1227149).
- wifi: rtw89: phy: set TX power offset according to chip gen
  (bsc#1227149).
- wifi: rtw89: phy: set TX power by rate according to chip gen
  (bsc#1227149).
- wifi: rtw89: mac: get TX power control register according to
  chip gen (bsc#1227149).
- wifi: rtlwifi: use unsigned long for rtl_bssid_entry timestamp
  (bsc#1227149).
- wifi: rtw89: refine bandwidth 160MHz uplink OFDMA performance
  (bsc#1227149).
- wifi: rtw89: refine uplink trigger based control mechanism
  (bsc#1227149).
- wifi: rtw89: 8851b: update TX power tables to R34 (bsc#1227149).
- wifi: rtw89: 8852b: update TX power tables to R35 (bsc#1227149).
- wifi: rtw89: 8852c: update TX power tables to R67 (bsc#1227149).
- wifi: rtw89: regd: configure Thailand in regulation type
  (bsc#1227149).
- wifi: rtlwifi: cleanup few rtlxxxx_set_hw_reg() routines
  (bsc#1227149).
- wifi: rtw89: declare MCC in interface combination (bsc#1227149).
- wifi: rtw89: 8852c: declare to support two chanctx
  (bsc#1227149).
- wifi: rtw89: pause/proceed MCC for ROC and HW scan
  (bsc#1227149).
- wifi: rtw89: mcc: fix NoA start time when GO is auxiliary
  (bsc#1227149).
- wifi: rtw89: load TX power related tables from FW elements
  (bsc#1227149).
- wifi: rtw89: phy: extend TX power common stuffs for Wi-Fi 7
  chips (bsc#1227149).
- wifi: rtw89: load TX power by rate when RFE parms setup
  (bsc#1227149).
- wifi: rtw89: phy: refine helpers used for raw TX power
  (bsc#1227149).
- commit 62f3f4a
* Sat Jul 13 2024 tiwai@suse.de
- wifi: rtw89: indicate TX power by rate table inside RFE
  parameter (bsc#1227149).
- wifi: rtw89: indicate TX shape table inside RFE parameter
  (bsc#1227149).
- wifi: rtw89: add subband index of primary channel to struct
  rtw89_chan (bsc#1227149).
- wifi: rtl8xxxu: Add a description about the device ID
  0x7392:0xb722 (bsc#1227149).
- wifi: rtw89: add mac_gen pointer to access mac port registers
  (bsc#1227149).
- wifi: rtw89: consolidate registers of mac port to struct
  (bsc#1227149).
- wifi: rtw89: add chip_info::txwd_info size to generalize TX
  WD submit (bsc#1227149).
- wifi: rtw89: add to fill TX descriptor v2 (bsc#1227149).
- wifi: rtw89: add to fill TX descriptor for firmware command v2
  (bsc#1227149).
- wifi: rtw89: add to query RX descriptor format v2 (bsc#1227149).
- wifi: rtw89: mcc: deal with beacon NoA if GO exists
  (bsc#1227149).
- wifi: rtw89: mcc: deal with BT slot change (bsc#1227149).
- wifi: rtw89: mcc: deal with P2P PS change (bsc#1227149).
- wifi: rtw89: mcc: track beacon offset and update when needed
  (bsc#1227149).
- wifi: rtw89: mcc: update role bitmap when changed (bsc#1227149).
- wifi: rtw89: 52c: rfk: disable DPK during MCC (bsc#1227149).
- wifi: rtw89: rfk: disable driver tracking during MCC
  (bsc#1227149).
- wifi: rtw89: 52c: rfk: refine MCC channel info notification
  (bsc#1227149).
- wifi: rtw89: 8922a: set memory heap address for secure firmware
  (bsc#1227149).
- wifi: rtw89: fw: refine download flow to support variant
  firmware suits (bsc#1227149).
- wifi: rtw89: 8922a: add chip_ops::bb_preinit to enable BB
  before downloading firmware (bsc#1227149).
- wifi: rtw89: fw: propagate an argument include_bb for BB MCU
  firmware (bsc#1227149).
- wifi: rtw89: fw: add checking type for variant type of firmware
  (bsc#1227149).
- wifi: rtw89: fw: implement supported functions of download
  firmware for WiFi 7 chips (bsc#1227149).
- wifi: rtw89: fw: generalize download firmware flow by mac_gen
  pointers (bsc#1227149).
- wifi: rtw89: fw: move polling function of firmware path ready
  to an individual function (bsc#1227149).
- wifi: rtw89: mcc: trigger FW to start/stop MCC (bsc#1227149).
- wifi: rtw89: fix typo of rtw89_fw_h2c_mcc_macid_bitmap()
  (bsc#1227149).
- wifi: rtw89: mcc: decide pattern and calculate parameters
  (bsc#1227149).
- wifi: rtw89: mcc: consider and determine BT duration
  (bsc#1227149).
- commit bd46e4d
* Sat Jul 13 2024 tiwai@suse.de
- wifi: rtw89: mcc: fill fundamental configurations (bsc#1227149).
- wifi: rtw89: mcc: initialize start flow (bsc#1227149).
- wifi: rtw89: 8852c: Fix TSSI causes transmit power inaccuracy
  (bsc#1227149).
- wifi: rtw89: 8852c: Update bandedge parameters for better
  performance (bsc#1227149).
- wifi: rtl8xxxu: mark TOTOLINK N150UA V5/N150UA-B as tested
  (bsc#1227149).
- wifi: rtw88: fix typo rtw8822cu_probe (bsc#1227149).
- wifi: rtlwifi: rtl8723: Remove unused function
  rtl8723_cmd_send_packet() (bsc#1227149).
- wifi: rtw89: Fix clang -Wimplicit-fallthrough in
  rtw89_query_sar() (bsc#1227149).
- wifi: rtw89: phy: modify register setting of ENV_MNTR, PHYSTS
  and DIG (bsc#1227149).
- wifi: rtw89: phy: add phy_gen_def::cr_base to support WiFi 7
  chips (bsc#1227149).
- wifi: rtw89: mac: define register address of rx_filter to
  generalize code (bsc#1227149).
- wifi: rtw89: mac: define internal memory address for WiFi 7 chip
  (bsc#1227149).
- wifi: rtw89: mac: generalize code to indirectly access WiFi
  internal memory (bsc#1227149).
- wifi: rtw89: mac: add mac_gen_def::band1_offset to map MAC
  band1 register address (bsc#1227149).
- wifi: rtw89: initialize multi-channel handling (bsc#1227149).
- wifi: rtw89: provide functions to configure NoA for beacon
  update (bsc#1227149).
- wifi: rtw89: call rtw89_chan_get() by vif chanctx if aware of
  vif (bsc#1227149).
- wifi: rtw89: sar: let caller decide the center frequency to
  query (bsc#1227149).
- wifi: rtw89: refine rtw89_correct_cck_chan() by
  rtw89_hw_to_nl80211_band() (bsc#1227149).
- wifi: rtw89: add function prototype for coex request duration
  (bsc#1227149).
- wifi: rtw89: regd: update regulatory map to R64-R43
  (bsc#1227149).
- wifi: rtw89: fix a width vs precision bug (bsc#1227149).
- wifi: rtlwifi: use eth_broadcast_addr() to assign broadcast
  address (bsc#1227149).
- wifi: rtw89: Introduce Time Averaged SAR (TAS) feature
  (bsc#1227149).
- wifi: rtw89: return failure if needed firmware elements are
  not recognized (bsc#1227149).
- wifi: rtw89: add to parse firmware elements of BB and RF tables
  (bsc#1227149).
- wifi: rtw89: introduce infrastructure of firmware elements
  (bsc#1227149).
- wifi: rtw89: add firmware suit for BB MCU 0/1 (bsc#1227149).
- wifi: rtw89: add firmware parser for v1 format (bsc#1227149).
- wifi: rtw89: introduce v1 format of firmware header
  (bsc#1227149).
- wifi: rtw89: support firmware log with formatted text
  (bsc#1227149).
- wifi: rtw89: recognize log format from firmware file
  (bsc#1227149).
- wifi: rtw89: get data rate mode/NSS/MCS v1 from RX descriptor
  (bsc#1227149).
- wifi: rtw89: add to display hardware rates v1 histogram in
  debugfs (bsc#1227149).
- wifi: rtw89: add C2H RA event V1 to support WiFi 7 chips
  (bsc#1227149).
- wifi: rtw89: use struct to access RA report (bsc#1227149).
- wifi: rtw89: use struct to access firmware C2H event header
  (bsc#1227149).
- wifi: rtw89: add H2C RA command V1 to support WiFi 7 chips
  (bsc#1227149).
- wifi: rtw89: use struct to set RA H2C command (bsc#1227149).
- wifi: rtw89: phy: rate pattern handles HW rate by chip gen
  (bsc#1227149).
- commit cdaa97d
* Sat Jul 13 2024 tiwai@suse.de
- wifi: rtlwifi: simplify LED management (bsc#1227149).
- Refresh
  patches.suse/wifi-mac80211-simplify-non-chanctx-drivers.patch.
- commit 34b32c5
* Sat Jul 13 2024 tiwai@suse.de
- wifi: rtw89: define hardware rate v1 for WiFi 7 chips
  (bsc#1227149).
- wifi: rtw89: add chip_info::chip_gen to determine chip
  generation (bsc#1227149).
- wifi: rtl8xxxu: Enable AP mode for RTL8723BU (bsc#1227149).
- wifi: rtl8xxxu: Enable AP mode for RTL8192EU (bsc#1227149).
- wifi: rtl8xxxu: Enable AP mode for RTL8710BU (RTL8188GU)
  (bsc#1227149).
- wifi: rtl8xxxu: Enable AP mode for RTL8192FU (bsc#1227149).
- wifi: rtw88: simplify vif iterators (bsc#1227149).
- wifi: rtw88: remove unused USB bulkout size set (bsc#1227149).
- wifi: rtw88: remove unused and set but unused leftovers
  (bsc#1227149).
- wifi: rtlwifi: cleanup USB interface (bsc#1227149).
- wifi: rtw89: use struct to parse firmware header (bsc#1227149).
- wifi: rtw89: TX power stuffs replace confusing naming of _max
  with _num (bsc#1227149).
- wifi: rtw89: 8851b: configure to force 1 TX power value
  (bsc#1227149).
- wifi: rtw89: 8851b: rfk: update IQK to version 0x8
  (bsc#1227149).
- wifi: rtw89: 8851b: rfk: add LCK track (bsc#1227149).
- wifi: rtw89: 8851b: update TX power tables to R28 (bsc#1227149).
- wifi: rtw89: 8851b: update RF radio A parameters to R28
  (bsc#1227149).
- wifi: rtw88: fix not entering PS mode after AP stops
  (bsc#1227149).
- wifi: rtw88: refine register based H2C command (bsc#1227149).
- wifi: rtw88: Stop high queue during scan (bsc#1227149).
- wifi: rtw88: Skip high queue in hci_flush (bsc#1227149).
- wifi: rtw88: Fix AP mode incorrect DTIM behavior (bsc#1227149).
- wifi: rtw88: use struct instead of macros to set TX desc
  (bsc#1227149).
- wifi: rtw88: process VO packets without workqueue to avoid
  PTK rekey failed (bsc#1227149).
- wifi: rtw88: Fix action frame transmission fail before
  association (bsc#1227149).
- wifi: rtw89: fix spelling typo of IQK debug messages
  (bsc#1227149).
- wifi: rtw89: cleanup rtw89_iqk_info and related code
  (bsc#1227149).
- wifi: rtw89: cleanup private data structures (bsc#1227149).
- wifi: rtw88: add missing unwind goto for
  __rtw_download_firmware() (bsc#1227149).
- commit 9b282ce
* Sat Jul 13 2024 tiwai@suse.de
- wifi: rtlwifi: remove misused flag from HAL data (bsc#1227149).
- wifi: rtlwifi: remove unused dualmac control leftovers
  (bsc#1227149).
- wifi: rtlwifi: remove unused timer and related code
  (bsc#1227149).
- wifi: rtw89: 8852c: update RF radio A/B parameters to R63
  (bsc#1227149).
- wifi: rtw89: 8852c: update TX power tables to R63 with 6 GHz
  power type (3 of 3) (bsc#1227149).
- wifi: rtw89: 8852c: update TX power tables to R63 with 6 GHz
  power type (2 of 3) (bsc#1227149).
- wifi: rtw89: 8852c: update TX power tables to R63 with 6 GHz
  power type (1 of 3) (bsc#1227149).
- wifi: rtw89: process regulatory for 6 GHz power type
  (bsc#1227149).
- wifi: rtw89: regd: update regulatory map to R64-R40
  (bsc#1227149).
- wifi: rtw89: regd: judge 6 GHz according to chip and BIOS
  (bsc#1227149).
- commit f81b870
* Sat Jul 13 2024 tiwai@suse.de
- wifi: rtw89: refine clearing supported bands to check 2/5 GHz
  first (bsc#1227149).
- Refresh
  patches.suse/wifi-cfg80211-annotate-iftype_data-pointer-with-spar.patch.
- commit 1873f0a
* Sat Jul 13 2024 tiwai@suse.de
- wifi: rtw89: 8851b: configure CRASH_TRIGGER feature for 8851B
  (bsc#1227149).
- wifi: rtw89: set TX power without precondition during setting
  channel (bsc#1227149).
- wifi: rtw89: debug: txpwr table access only valid page according
  to chip (bsc#1227149).
- wifi: rtw89: 8851b: enable hw_scan support (bsc#1227149).
- wifi: rtlwifi: use helper function rtl_get_hdr() (bsc#1227149).
- wifi: rtw89: use flexible array member in rtw89_btc_btf_tlv
  (bsc#1227149).
- wifi: rtw89: 8851b: rfk: Fix spelling mistake KIP_RESOTRE ->
  KIP_RESTORE (bsc#1227149).
- wifi: rtw89: use struct to access register-based H2C/C2H
  (bsc#1227149).
- wifi: rtw89: use struct and le32_get_bits() to access RX
  descriptor (bsc#1227149).
- commit 21eb4e8
* Sat Jul 13 2024 tiwai@suse.de
- Update config files: update for the realtek wifi driver updates (bsc#1227149)
- commit 33b8d09
* Sat Jul 13 2024 tiwai@suse.de
- wifi: rtw89: use struct and le32_get_bits() to access received
  PHY status IEs (bsc#1227149).
- wifi: rtw89: use struct and le32_get_bits to access RX info
  (bsc#1227149).
- wifi: rtw89: add chip_ops::query_rxdesc() and rxd_len as
  helpers to support newer chips (bsc#1227149).
- wifi: rtw89: 8851b: add 8851be to Makefile and Kconfig
  (bsc#1227149).
- wifi: rtw89: add tx_wake notify for 8851B (bsc#1227149).
- wifi: rtw89: enlarge supported length of read_reg debugfs entry
  (bsc#1227149).
- wifi: rtw89: 8851b: add RF configurations (bsc#1227149).
- wifi: rtw89: 8851b: add MAC configurations to chip_info
  (bsc#1227149).
- wifi: rtw89: 8851b: fill BB related capabilities to chip_info
  (bsc#1227149).
- wifi: rtw89: 8851b: add TX power related functions
  (bsc#1227149).
- commit 66eef0c
* Sat Jul 13 2024 tiwai@suse.de
- Update config files: update for the realtek wifi driver updates (bsc#1227149)
- commit 75bc634
* Sat Jul 13 2024 tiwai@suse.de
- wifi: rtw89: refine packet offload handling under SER
  (bsc#1227149).
- wifi: rtw89: tweak H2C TX waiting function for SER
  (bsc#1227149).
- wifi: rtw89: ser: reset total_sta_assoc and tdls_peer when L2
  (bsc#1227149).
- wifi: rtw88: Add support for the SDIO based RTL8723DS chipset
  (bsc#1227149).
- wifi: rtw88: rtw8723d: Implement RTL8723DS (SDIO) efuse parsing
  (bsc#1227149).
- wifi: rtw89: 8851b: rfk: add TSSI (bsc#1227149).
- wifi: rtw89: 8851b: rfk: add DPK (bsc#1227149).
- wifi: rtw89: 8851b: rfk: add RX DCK (bsc#1227149).
- wifi: rtw89: 8851b: add to parse efuse content (bsc#1227149).
- wifi: rtw89: 8851b: add set channel function (bsc#1227149).
- wifi: rtw89: 8851b: add basic power on function (bsc#1227149).
- wifi: rtw89: 8851b: add BT coexistence support function
  (bsc#1227149).
- wifi: rtw89: 8851b: configure GPIO according to RFE type
  (bsc#1227149).
- wifi: rtw89: 8851b: add to read efuse version to recognize
  hardware version B (bsc#1227149).
- wifi: rtl8xxxu: Rename some registers (bsc#1227149).
- wifi: rtl8xxxu: Support new chip RTL8192FU (bsc#1227149).
- wifi: rtw89: suppress the log for specific SER called
  CMDPSR_FRZTO (bsc#1227149).
- wifi: rtw89: ser: L1 add pre-M0 and post-M0 states
  (bsc#1227149).
- wifi: rtw89: pci: fix interrupt enable mask for HALT C2H of
  RTL8851B (bsc#1227149).
- wifi: rtw89: support U-NII-4 channels on 5GHz band
  (bsc#1227149).
- wifi: rtw89: regd: judge UNII-4 according to BIOS and chip
  (bsc#1227149).
- wifi: rtw89: introduce realtek ACPI DSM method (bsc#1227149).
- wifi: rtw89: 8851b: rfk: add IQK (bsc#1227149).
- wifi: rtw89: 8851b: rfk: add DACK (bsc#1227149).
- wifi: rtw89: 8851b: rfk: add RCK (bsc#1227149).
- wifi: rtw89: 8851b: rfk: add AACK (bsc#1227149).
- wifi: rtw89: 8851b: add set_channel_rf() (bsc#1227149).
- wifi: rtw89: 8851b: add DLE mem and HFC quota (bsc#1227149).
- wifi: rtw89: 8851b: add support WoWLAN to 8851B (bsc#1227149).
- wifi: rtw89: change naming of BA CAM from V1 to V0_EXT
  (bsc#1227149).
- commit a1de2dd
* Sat Jul 13 2024 tiwai@suse.de
- wifi: rtw89: use chip_info::small_fifo_size to choose debug_mask
  (bsc#1227149).
- wifi: rtw89: add CFO XTAL registers field to support 8851B
  (bsc#1227149).
- wifi: rtw89: 8851b: add NCTL post table (bsc#1227149).
- wifi: rtw89: 8851be: add 8851BE PCI entry and fill PCI
  capabilities (bsc#1227149).
- wifi: rtw89: 8851b: add 8851B basic chip_info (bsc#1227149).
- wifi: rtw89: scan offload wait for FW done ACK (bsc#1227149).
- wifi: rtw89: mac: handle C2H receive/done ACK in interrupt
  context (bsc#1227149).
- wifi: rtw89: packet offload wait for FW response (bsc#1227149).
- wifi: rtw89: refine packet offload delete flow of 6 GHz probe
  (bsc#1227149).
- wifi: rtw89: release bit in rtw89_fw_h2c_del_pkt_offload()
  (bsc#1227149).
- wifi: rtw89: add EVM for antenna diversity (bsc#1227149).
- wifi: rtw89: add RSSI based antenna diversity (bsc#1227149).
- wifi: rtw89: initialize antenna for antenna diversity
  (bsc#1227149).
- wifi: rtw89: add EVM and SNR statistics to debugfs
  (bsc#1227149).
- wifi: rtw89: add RSSI statistics for the case of antenna
  diversity to debugfs (bsc#1227149).
- wifi: rtw89: set capability of TX antenna diversity
  (bsc#1227149).
- wifi: rtw89: use struct rtw89_phy_sts_ie0 instead of macro to
  access PHY IE0 status (bsc#1227149).
- wifi: rtw88: fix incorrect error codes in rtw_debugfs_set_*
  (bsc#1227149).
- wifi: rtw88: fix incorrect error codes in
  rtw_debugfs_copy_from_user (bsc#1227149).
- wifi: rtl8xxxu: rtl8xxxu_rx_complete(): remove unnecessary
  return (bsc#1227149).
- commit fef25cd
* Sat Jul 13 2024 tiwai@suse.de
- wifi: rtl8xxxu: Add sta_add() and sta_remove() callbacks
  (bsc#1227149).
- commit a27e0ec
* Sat Jul 13 2024 tiwai@suse.de
- wifi: rtl8xxxu: Support USB RX aggregation for the newer chips
  (bsc#1227149).
- wifi: rtl8xxxu: Set maximum number of supported stations
  (bsc#1227149).
- wifi: rtl8xxxu: Declare AP mode support for 8188f (bsc#1227149).
- wifi: rtl8xxxu: Remove usage of tx_info->control.rates[0].flags
  (bsc#1227149).
- wifi: rtl8xxxu: Remove usage of ieee80211_get_tx_rate()
  (bsc#1227149).
- wifi: rtl8xxxu: Clean up filter configuration (bsc#1227149).
- wifi: rtl8xxxu: Enable hw seq for mgmt/non-QoS data frames
  (bsc#1227149).
- wifi: rtl8xxxu: Add parameter macid to update_rate_mask
  (bsc#1227149).
- wifi: rtl8xxxu: Put the macid in txdesc (bsc#1227149).
- commit 6125130
* Sat Jul 13 2024 tiwai@suse.de
- wifi: radiotap: add bandwidth definition of EHT U-SIG
  (bsc#1227149).
- wifi: ieee80211: add UL-bandwidth definition of trigger frame
  (bsc#1227149).
- wifi: rtl8xxxu: Add parameter force to
  rtl8xxxu_refresh_rate_mask (bsc#1227149).
- wifi: rtl8xxxu: Add parameter role to report_connect
  (bsc#1227149).
- wifi: rtl8xxxu: Actually use macid in
  rtl8xxxu_gen2_report_connect (bsc#1227149).
- wifi: rtl8xxxu: Allow creating interface in AP mode
  (bsc#1227149).
- wifi: rtl8xxxu: Allow setting rts threshold to -1 (bsc#1227149).
- wifi: rtl8xxxu: Add set_tim() callback (bsc#1227149).
- wifi: rtl8xxxu: Add beacon functions (bsc#1227149).
- wifi: rtl8xxxu: Select correct queue for beacon frames
  (bsc#1227149).
- wifi: rtl8xxxu: Add start_ap() callback (bsc#1227149).
- commit 02b75ed
* Sat Jul 13 2024 tiwai@suse.de
- wifi: iwlwifi: bump FW API to 90 for BZ/SC devices (bsc#1227149
  CVE-2023-47210 bsc#1225601 CVE-2023-38417 bsc#1225600).
- commit ea4853c
* Sat Jul 13 2024 tiwai@suse.de
- wifi: iwlwifi: bump FW API to 89 for AX/BZ/SC devices
  (bsc#1227149 CVE-2023-47210 bsc#1225601 CVE-2023-38417
  bsc#1225600).
- commit bc49209
* Sat Jul 13 2024 tiwai@suse.de
- ASoC: SOF: Intel: hda-pcm: Limit the maximum number of periods
  by MAX_BDL_ENTRIES (stable-fixes).
- ASoC: rt711-sdw: add missing readable registers (stable-fixes).
- ALSA: hda/realtek: Enable Mute LED on HP 250 G7 (stable-fixes).
- ALSA: hda/realtek: Limit mic boost on VAIO PRO PX
  (stable-fixes).
- ALSA: hda/realtek: add quirk for Clevo V5[46]0TU (stable-fixes).
- commit 1ddd32b
* Sat Jul 13 2024 tiwai@suse.de
- hpet: Support 32-bit userspace (git-fixes).
- misc: fastrpc: Restrict untrusted app to attach to privileged PD
  (git-fixes).
- misc: fastrpc: Fix ownership reassignment of remote heap
  (git-fixes).
- misc: fastrpc: Fix memory leak in audio daemon attach operation
  (git-fixes).
- misc: fastrpc: Avoid updating PD type for capability request
  (git-fixes).
- misc: fastrpc: Copy the complete capability structure to user
  (git-fixes).
- misc: fastrpc: Fix DSP capabilities request (git-fixes).
- USB: serial: mos7840: fix crash on resume (git-fixes).
- USB: core: Fix duplicate endpoint bug by clearing reserved
  bits in the descriptor (git-fixes).
- firmware: cs_dsp: Use strnlen() on name fields in V1 wmfw files
  (git-fixes).
- ASoC: SOF: Intel: hda: fix null deref on system suspend entry
  (git-fixes).
- firmware: cs_dsp: Prevent buffer overrun when processing V2
  alg headers (git-fixes).
- firmware: cs_dsp: Validate payload length before processing
  block (git-fixes).
- firmware: cs_dsp: Return error if block header overflows file
  (git-fixes).
- firmware: cs_dsp: Fix overflow checking of wmfw header
  (git-fixes).
- ALSA: hda: cs35l41: Fix swapped l/r audio channels for Lenovo
  ThinBook 13x Gen4 (git-fixes).
- commit 34ebce1
* Fri Jul 12 2024 vkarasulli@suse.de
- net/smc: avoid data corruption caused by decline (bsc#1225088
  CVE-2023-52775).
- commit 621e8ca
* Fri Jul 12 2024 vkarasulli@suse.de
- net: openvswitch: fix overwriting ct original tuple for  ICMPv6
  (bsc#1226783 CVE-2024-38558).
- commit 748cf39
* Fri Jul 12 2024 vkarasulli@suse.de
- ipv6: sr: fix missing sk_buff release in seg6_input_core
  (bsc#1227626 CVE-2024-39490).
- commit 3d59f52
* Fri Jul 12 2024 vkarasulli@suse.de
- mptcp: fix data re-injection from stale subflow (bsc#1223010
  CVE-2024-26826).
- commit f3a102e
* Fri Jul 12 2024 vkarasulli@suse.de
- net/smc: fix illegal rmb_desc access in SMC-D connection dump
  (bsc#1220942 CVE-2024-26615).
- commit f21afb0
* Fri Jul 12 2024 tiwai@suse.de
- kabi/severities: cover all ath/* drivers (bsc#1227149)
  All symbols in ath/* network drivers are local and can be ignored
- commit d902566
* Fri Jul 12 2024 tiwai@suse.de
- Refresh kabi workaround ath updates (bsc#1227149#)
- commit b0fa38b
* Fri Jul 12 2024 tiwai@suse.de
- wifi: mac80211: simplify non-chanctx drivers (bsc#1227149).
- commit eeb4722
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: move power type check to ASSOC stage when
  connecting to 6 GHz AP (bsc#1227149).
- wifi: ath11k: fix WCN6750 firmware crash caused by 17 num_vdevs
  (bsc#1227149).
- wifi: ath12k: fix the problem that down grade phy mode operation
  (bsc#1227149).
- wifi: ath12k: check M3 buffer size as well whey trying to
  reuse it (bsc#1227149).
- wifi: ath12k: fix kernel crash during resume (bsc#1227149).
- wifi: ath9k: work around memset overflow warning (bsc#1227149).
- wifi: ath12k: use correct flag field for 320 MHz channels
  (bsc#1227149).
- commit 58db5ff
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: use RCU when accessing struct inet6_dev::ac_list
  (bsc#1227149).
- wifi: ath12k: fix license in p2p.c and p2p.h (bsc#1227149).
- wifi: ath11k: constify MHI channel and controller configs
  (bsc#1227149).
- wifi: ath12k: add rcu lock for ath12k_wmi_p2p_noa_event()
  (bsc#1227149).
- wifi: ath11k: remove unused scan_events from struct
  scan_req_params (bsc#1227149).
- wifi: ath11k: add support for QCA2066 (bsc#1227149).
- wifi: ath11k: move pci.ops registration ahead (bsc#1227149).
- commit 29f553c
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: provide address list if chip supports 2 stations
  (bsc#1227149).
- wifi: ath11k: support 2 station interfaces (bsc#1227149).
- wifi: ath12k: remove the unused scan_events from
  ath12k_wmi_scan_req_arg (bsc#1227149).
- wifi: ath12k: Remove unused scan_flags from struct
  ath12k_wmi_scan_req_arg (bsc#1227149).
- wifi: ath12k: Do not use scan_flags from struct
  ath12k_wmi_scan_req_arg (bsc#1227149).
- wifi: carl9170: Remove redundant assignment to pointer super
  (bsc#1227149).
- wifi: ath11k: Remove scan_flags union from struct
  scan_req_params (bsc#1227149).
- wifi: ath11k: Do not directly use scan_flags in struct
  scan_req_params (bsc#1227149).
- wifi: ath12k: Fix uninitialized use of ret in
  ath12k_mac_allocate() (bsc#1227149).
- wifi: ath11k: Really consistently use ath11k_vif_to_arvif()
  (bsc#1227149).
- wifi: ath12k: advertise P2P dev support for WCN7850
  (bsc#1227149).
- wifi: ath12k: designating channel frequency for ROC scan
  (bsc#1227149).
- wifi: ath12k: move peer delete after vdev stop of station for
  WCN7850 (bsc#1227149).
- wifi: ath12k: allow specific mgmt frame tx while vdev is not up
  (bsc#1227149).
- wifi: ath12k: change WLAN_SCAN_PARAMS_MAX_IE_LEN from 256 to
  512 (bsc#1227149).
- wifi: ath12k: implement remain on channel for P2P mode
  (bsc#1227149).
- wifi: ath12k: implement handling of P2P NoA event (bsc#1227149).
- wifi: ath12k: add P2P IE in beacon template (bsc#1227149).
- wifi: ath12k: change interface combination for P2P mode
  (bsc#1227149).
- wifi: ath12k: fix broken structure wmi_vdev_create_cmd
  (bsc#1227149).
- commit 21d36c7
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: initialize eirp_power before use (bsc#1227149).
- wifi: ath12k: enable 802.11 power save mode in station mode
  (bsc#1227149).
- wifi: ath12k: refactor the rfkill worker (bsc#1227149).
- wifi: ath12k: add processing for TWT disable event
  (bsc#1227149).
- wifi: ath12k: add processing for TWT enable event (bsc#1227149).
- wifi: ath12k: disable QMI PHY capability learn in split-phy
  QCN9274 (bsc#1227149).
- wifi: ath12k: Read board id to support split-PHY QCN9274
  (bsc#1227149).
- wifi: ath12k: fix PCI read and write (bsc#1227149).
- wifi: ath12k: add MAC id support in WBM error path
  (bsc#1227149).
- wifi: ath12k: subscribe required word mask from rx tlv
  (bsc#1227149).
- commit c884365
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath12k: remove hal_desc_sz from hw params (bsc#1227149).
- wifi: ath12k: split hal_ops to support RX TLVs word mask
  compaction (bsc#1227149).
- wifi: ath12k: fix firmware assert during insmod in memory
  segment mode (bsc#1227149).
- wifi: ath12k: Add logic to write QRTR node id to scratch
  (bsc#1227149).
- wifi: ath12k: fix fetching MCBC flag for QCN9274 (bsc#1227149).
- wifi: ath12k: add support for peer meta data version
  (bsc#1227149).
- wifi: ath12k: fetch correct pdev id from
  WMI_SERVICE_READY_EXT_EVENTID (bsc#1227149).
- wifi: ath12k: indicate NON MBSSID vdev by default during vdev
  start (bsc#1227149).
- wifi: ath12k: add firmware-2.bin support (bsc#1227149).
- wifi: ath9k:  remove redundant assignment to variable ret
  (bsc#1227149).
- commit 777dc1c
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: fix connection failure due to unexpected peer
  delete (bsc#1227149).
- wifi: ath11k: avoid forward declaration of
  ath11k_mac_start_vdev_delay() (bsc#1227149).
- wifi: ath11k: rename ath11k_start_vdev_delay() (bsc#1227149).
- wifi: fill in MODULE_DESCRIPTION()s for wcn36xx (bsc#1227149).
- wifi: fill in MODULE_DESCRIPTION()s for ar5523 (bsc#1227149).
- commit d2a4b44
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: remove invalid peer create logic (bsc#1227149).
- wifi: ath11k: enable 36 bit mask for stream DMA (bsc#1227149).
- wifi: ath10k: Fix enum ath10k_fw_crash_dump_type kernel-doc
  (bsc#1227149).
- wifi: ath10k: Fix htt_data_tx_completion kernel-doc warning
  (bsc#1227149).
- wifi: ath10k: fix htt_q_state_conf & htt_q_state kernel-doc
  (bsc#1227149).
- wifi: ath10k: correctly document enum wmi_tlv_tx_pause_id
  (bsc#1227149).
- wifi: ath10k: add missing wmi_10_4_feature_mask documentation
  (bsc#1227149).
- wifi: ath12k: add support for collecting firmware log
  (bsc#1227149).
- wifi: ath12k: Introduce the container for mac80211 hw
  (bsc#1227149).
- wifi: ath12k: Refactor the mac80211 hw access from link/radio
  (bsc#1227149).
- commit 614fabb
* Fri Jul 12 2024 vkarasulli@suse.de
- iommu/vt-d: Improve ITE fault handling if target device isn't
  present (git-fixes).
- commit 134a3a5
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath12k: change MAC buffer ring size to 2048 (bsc#1227149).
- wifi: ath12k: add support for BA1024 (bsc#1227149).
- wifi: ath12k: fix wrong definitions of hal_reo_update_rx_queue
  (bsc#1227149).
- wifi: ath10k: replace ENOTSUPP with EOPNOTSUPP (bsc#1227149).
- wifi: ath11k: replace ENOTSUPP with EOPNOTSUPP (bsc#1227149).
- wifi: ath12k: replace ENOTSUPP with EOPNOTSUPP (bsc#1227149).
- wifi: ath12k: add QMI PHY capability learn support
  (bsc#1227149).
- wifi: ath12k: refactor QMI MLO host capability helper function
  (bsc#1227149).
- wifi: ath11k: document HAL_RX_BUF_RBM_SW4_BM (bsc#1227149).
- wifi: ath12k: ath12k_start_vdev_delay(): convert to use ar
  (bsc#1227149).
- commit dd312dc
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath12k: refactor ath12k_mac_op_flush() (bsc#1227149).
- wifi: ath12k: refactor ath12k_mac_op_ampdu_action()
  (bsc#1227149).
- wifi: ath12k: refactor ath12k_mac_op_configure_filter()
  (bsc#1227149).
- wifi: ath12k: refactor ath12k_mac_op_update_vif_offload()
  (bsc#1227149).
- wifi: ath12k: refactor ath12k_mac_op_stop() (bsc#1227149).
- wifi: ath12k: refactor ath12k_mac_op_start() (bsc#1227149).
- wifi: ath12k: refactor ath12k_mac_op_conf_tx() (bsc#1227149).
- wifi: ath12k: refactor ath12k_bss_assoc() (bsc#1227149).
- wifi: ath12k: refactor ath12k_mac_op_config() (bsc#1227149).
- wifi: ath12k: refactor ath12k_mac_register() and
  ath12k_mac_unregister() (bsc#1227149).
- commit b6ca728
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath12k: refactor ath12k_mac_setup_channels_rates()
  (bsc#1227149).
- wifi: ath12k: refactor ath12k_mac_allocate() and
  ath12k_mac_destroy() (bsc#1227149).
- wifi: ath12k: relocate ath12k_dp_pdev_pre_alloc() call
  (bsc#1227149).
- wifi: ath12k: Use initializers for QMI message buffers
  (bsc#1227149).
- wifi: ath12k: Add missing qmi_txn_cancel() calls (bsc#1227149).
- wifi: ath12k: Remove unnecessary struct qmi_txn initializers
  (bsc#1227149).
- wifi: ath11k: use WMI_VDEV_SET_TPC_POWER_CMDID when
  EXT_TPC_REG_SUPPORT for 6 GHz (bsc#1227149).
- wifi: ath11k: add handler for WMI_VDEV_SET_TPC_POWER_CMDID
  (bsc#1227149).
- wifi: ath11k: add WMI_TLV_SERVICE_EXT_TPC_REG_SUPPORT service
  bit (bsc#1227149).
- wifi: ath11k: fill parameters for vdev set tpc power WMI command
  (bsc#1227149).
- commit 3c338b0
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: save max transmit power in vdev start response
  event from firmware (bsc#1227149).
- commit 279ae7a
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: add parse of transmit power envelope element
  (bsc#1227149).
- commit e295f89
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: save power spectral density(PSD) of regulatory
  rule (bsc#1227149).
- wifi: ath11k: update regulatory rules when connect to AP on
  6 GHz band for station (bsc#1227149).
- wifi: ath11k: update regulatory rules when interface added
  (bsc#1227149).
- wifi: ath11k: fix a possible dead lock caused by ab->base_lock
  (bsc#1227149).
- wifi: ath11k: store cur_regulatory_info for each radio
  (bsc#1227149).
- wifi: ath11k: add support to select 6 GHz regulatory type
  (bsc#1227149).
- wifi: ath12k: refactor ath12k_wmi_tlv_parse_alloc()
  (bsc#1227149).
- wifi: ath11k: fix IOMMU errors on buffer rings (bsc#1227149).
- commit d84dbd2
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath12k: Make QMI message rules const (bsc#1227149).
- wifi: ath12k: support default regdb while searching board-2.bin
  for WCN7850 (bsc#1227149).
- wifi: ath12k: add support to search regdb data in board-2.bin
  for WCN7850 (bsc#1227149).
- wifi: ath12k: remove unused ATH12K_BD_IE_BOARD_EXT
  (bsc#1227149).
- wifi: ath12k: add fallback board name without variant while
  searching board-2.bin (bsc#1227149).
- wifi: ath12k: add string type to search board data in
  board-2.bin for WCN7850 (bsc#1227149).
- wifi: ath10k: remove duplicate memset() in 10.4 TDLS peer update
  (bsc#1227149).
- wifi: ath10k: use flexible array in struct
  wmi_tdls_peer_capabilities (bsc#1227149).
- wifi: ath10k: remove unused template structs (bsc#1227149).
- wifi: ath10k: remove struct wmi_pdev_chanlist_update_event
  (bsc#1227149).
- commit e73f8dc
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath10k: use flexible arrays for WMI start scan TLVs
  (bsc#1227149).
- wifi: ath10k: use flexible array in struct wmi_host_mem_chunks
  (bsc#1227149).
- wifi: ath9k: Convert to platform remove callback returning void
  (bsc#1227149).
- wifi: ath9k: delete some unused/duplicate macros (bsc#1227149).
- wifi: ath11k: refactor ath11k_wmi_tlv_parse_alloc()
  (bsc#1227149).
- wifi: ath11k: rely on mac80211 debugfs handling for vif
  (bsc#1227149).
- wifi: ath11k: workaround too long expansion sparse warnings
  (bsc#1227149).
- Revert "wifi: ath12k: use ATH12K_PCI_IRQ_DP_OFFSET for DP IRQ"
  (bsc#1227149).
- wifi: ath9k: reset survey of current channel after a scan
  started (bsc#1227149).
- wifi: ath12k: fix the issue that the multicast/broadcast
  indicator is not read correctly for WCN7850 (bsc#1227149).
- commit 6cf204e
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: Fix ath11k_htc_record flexible record
  (bsc#1227149).
- wifi: ath5k: remove unused ath5k_eeprom_info::ee_antenna
  (bsc#1227149).
- wifi: ath10k: add support to allow broadcast action frame RX
  (bsc#1227149).
- wifi: ath12k: avoid repeated wiphy access from hw (bsc#1227149).
- wifi: ath12k: set IRQ affinity to CPU0 in case of one MSI vector
  (bsc#1227149).
- wifi: ath12k: do not restore ASPM in case of single MSI vector
  (bsc#1227149).
- wifi: ath12k: add support one MSI vector (bsc#1227149).
- wifi: ath12k: refactor multiple MSI vector implementation
  (bsc#1227149).
- wifi: ath12k: use ATH12K_PCI_IRQ_DP_OFFSET for DP IRQ
  (bsc#1227149).
- wifi: ath12k: add CE and ext IRQ flag to indicate irq_handler
  (bsc#1227149).
- commit 908caeb
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath12k: get msi_data again after request_irq is called
  (bsc#1227149).
- wifi: wcn36xx: Convert to platform remove callback returning
  void (bsc#1227149).
- wifi: ath5k: Convert to platform remove callback returning void
  (bsc#1227149).
- wifi: ath12k: avoid repeated hw access from ar (bsc#1227149).
- wifi: ath12k: Optimize the mac80211 hw data access
  (bsc#1227149).
- wifi: ath12k: add 320 MHz bandwidth enums (bsc#1227149).
- wifi: ath11k: Convert to platform remove callback returning void
  (bsc#1227149).
- wifi: ath11k: remove ath11k_htc_record::pauload[] (bsc#1227149).
- wifi: ath10k: Use DECLARE_FLEX_ARRAY() for ath10k_htc_record
  (bsc#1227149).
- wifi: ath10k: remove ath10k_htc_record::pauload[] (bsc#1227149).
- commit 67bc0a7
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath10k: Update Qualcomm Innovation Center, Inc. copyrights
  (bsc#1227149).
- commit e13fd24
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: Update Qualcomm Innovation Center, Inc. copyrights
  (bsc#1227149).
- Refresh
  patches.suse/wifi-ath11k-do-not-dump-SRNG-statistics-during-resum.patch.
- Refresh
  patches.suse/wifi-ath11k-fix-warning-on-DMA-ring-capabilities-eve.patch.
- Refresh patches.suse/wifi-ath11k-support-hibernation.patch.
- Refresh
  patches.suse/wifi-ath11k-thermal-don-t-try-to-register-multiple-t.patch.
- commit a886227
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath9k: Remove unnecessary (void*) conversions
  (bsc#1227149).
- wifi: ath12k: refactor DP Rxdma ring structure (bsc#1227149).
- wifi: ath12k: avoid explicit HW conversion argument in Rxdma
  replenish (bsc#1227149).
- wifi: ath12k: avoid explicit RBM id argument in Rxdma replenish
  (bsc#1227149).
- wifi: ath12k: avoid explicit mac id argument in Rxdma replenish
  (bsc#1227149).
- wifi: ath12k: fix the error handler of rfkill config
  (bsc#1227149).
- wifi: ath12k: use select for CRYPTO_MICHAEL_MIC (bsc#1227149).
- wifi: ath11k: use select for CRYPTO_MICHAEL_MIC (bsc#1227149).
- commit a869013
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath12k: Consolidate WMI peer flags (bsc#1227149).
- wifi: ath11k: Consolidate WMI peer flags (bsc#1227149).
- wifi: ath12k: Remove obsolete struct wmi_peer_flags_map
  * peer_flags (bsc#1227149).
- wifi: ath11k: Remove obsolete struct wmi_peer_flags_map
  * peer_flags (bsc#1227149).
- wifi: ath12k: Remove struct ath12k::ops (bsc#1227149).
- wifi: ath11k: Remove struct ath11k::ops (bsc#1227149).
- wifi: ath10k: Remove unused struct ath10k_htc_frame
  (bsc#1227149).
- wifi: ath10k: simplify __ath10k_htt_tx_txq_recalc()
  (bsc#1227149).
- wifi: ath11k: Remove unneeded semicolon (bsc#1227149).
- wifi: ath10k: replace deprecated strncpy with memcpy
  (bsc#1227149).
- commit e59240f
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath12k: drop NULL pointer check in
  ath12k_update_per_peer_tx_stats() (bsc#1227149).
- Revert "wifi: ath11k: call ath11k_mac_fils_discovery() without
  condition" (bsc#1227149).
- wifi: ath12k: Introduce and use ath12k_sta_to_arsta()
  (bsc#1227149).
- wifi: ath12k: rename the sc naming convention to ab
  (bsc#1227149).
- wifi: ath12k: rename the wmi_sc naming convention to wmi_ab
  (bsc#1227149).
- commit f93677e
* Fri Jul 12 2024 tiwai@suse.de
- bus: mhi: host: allow MHI client drivers to provide the firmware
  via a pointer (bsc#1227149).
- commit 494649c
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: add firmware-2.bin support (bsc#1227149).
- Refresh patches.suse/wifi-ath11k-support-hibernation.patch.
- commit 677d325
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: qmi: refactor ath11k_qmi_m3_load() (bsc#1227149).
- commit 296ac8f
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: rename the sc naming convention to ab
  (bsc#1227149).
- Refresh patches.suse/wifi-ath11k-support-hibernation.patch.
- Refresh
  patches.suse/wifi-ath11k-thermal-don-t-try-to-register-multiple-t.patch.
- commit 6eedd0d
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: rename the wmi_sc naming convention to wmi_ab
  (bsc#1227149).
- wifi: ath6kl: replace deprecated strncpy with memcpy
  (bsc#1227149).
- commit cd59b03
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath5k: replace deprecated strncpy with strscpy
  (bsc#1227149).
- wifi: ath12k: Remove ath12k_base::bd_api (bsc#1227149).
- wifi: ath11k: Remove ath11k_base::bd_api (bsc#1227149).
- wifi: ath12k: Enable Mesh support for QCN9274 (bsc#1227149).
- wifi: ath12k: register EHT mesh capabilities (bsc#1227149).
- wifi: ath11k: Use device_get_match_data() (bsc#1227149).
- wifi: ath11k: Introduce and use ath11k_sta_to_arsta()
  (bsc#1227149).
- wifi: ath11k: Remove unused struct ath11k_htc_frame
  (bsc#1227149).
- wifi: ath12k: fix invalid m3 buffer address (bsc#1227149).
- wifi: ath12k: add ath12k_qmi_free_resource() for recovery
  (bsc#1227149).
- commit a18a8d4
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath12k: configure RDDM size to MHI for device recovery
  (bsc#1227149).
- wifi: ath12k: add parsing of phy bitmap for reg rules
  (bsc#1227149).
- wifi: ath11k: add parsing of phy bitmap for reg rules
  (bsc#1227149).
- wifi: ath11k: ath11k_debugfs_register(): fix format-truncation
  warning (bsc#1227149).
- wifi: ath12k: Consistently use ath12k_vif_to_arvif()
  (bsc#1227149).
- wifi: ath11k: call ath11k_mac_fils_discovery() without condition
  (bsc#1227149).
- wifi: ath12k: remove redundant memset() in
  ath12k_hal_reo_qdesc_setup() (bsc#1227149).
- wifi: ath9k_htc: fix format-truncation warning (bsc#1227149).
- wifi: ath12k: fix debug messages (bsc#1227149).
- wifi: ath11k: fix CAC running state during virtual interface
  start (bsc#1227149).
- commit c2f2e92
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath10k: simplify ath10k_peer_create() (bsc#1227149).
- wifi: ath10k: indicate to mac80211 scan complete with aborted
  flag for ATH10K_SCAN_STARTING state (bsc#1227149).
- wifi: ath: dfs_pattern_detector: Use flex array to simplify code
  (bsc#1227149).
- wifi: carl9170: remove unnecessary (void*) conversions
  (bsc#1227149).
- wifi: ath10k: consistently use kstrtoX_from_user() functions
  (bsc#1227149).
- wifi: ath12k: add keep backward compatibility of PHY mode to
  avoid firmware crash (bsc#1227149).
- wifi: ath12k: add read variant from SMBIOS for download board
  data (bsc#1227149).
- wifi: ath12k: do not drop data frames from unassociated stations
  (bsc#1227149).
- wifi: ath11k: mac: fix struct ieee80211_sband_iftype_data
  handling (bsc#1227149).
- wifi: ath11k: fix ath11k_mac_op_remain_on_channel() stack usage
  (bsc#1227149).
- commit b844022
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath12k: add msdu_end structure for WCN7850 (bsc#1227149).
- wifi: ath12k: Set default beacon mode to burst mode
  (bsc#1227149).
- wifi: ath12k: call ath12k_mac_fils_discovery() without condition
  (bsc#1227149).
- wifi: ath11k: remove unnecessary (void*) conversions
  (bsc#1227149).
- wifi: ath12k: enable IEEE80211_HW_SINGLE_SCAN_ON_ALL_BANDS
  for WCN7850 (bsc#1227149).
- wifi: ath12k: change to treat alpha code na as world wide
  regdomain (bsc#1227149).
- wifi: ath12k: indicate scan complete for scan canceled when
  scan running (bsc#1227149).
- wifi: ath12k: indicate to mac80211 scan complete with aborted
  flag for ATH12K_SCAN_STARTING state (bsc#1227149).
- wifi: ath12k: fix recovery fail while firmware crash when
  doing channel switch (bsc#1227149).
- wifi: ath12k: add support for hardware rfkill for WCN7850
  (bsc#1227149).
- commit 087627b
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: use kstrtoul_from_user() where appropriate
  (bsc#1227149).
- wifi: ath11k: remove unused members of 'struct ath11k_base'
  (bsc#1227149).
- wifi: ath11k: drop redundant check in
  ath11k_dp_rx_mon_dest_process() (bsc#1227149).
- wifi: ath11k: drop NULL pointer check in
  ath11k_update_per_peer_tx_stats() (bsc#1227149).
- wifi: ath10k: drop HTT_DATA_TX_STATUS_DOWNLOAD_FAIL
  (bsc#1227149).
- wifi: ath10k: Annotate struct ath10k_ce_ring with __counted_by
  (bsc#1227149).
- wifi: wcn36xx: Annotate struct wcn36xx_hal_ind_msg with
  __counted_by (bsc#1227149).
- wifi: ath12k: Remove unnecessary (void*) conversions
  (bsc#1227149).
- wifi: ath10k: Remove unnecessary (void*) conversions
  (bsc#1227149).
- wifi: ath6kl: remove unnecessary (void*) conversions
  (bsc#1227149).
- commit 3f20dbc
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath5k: remove unnecessary (void*) conversions
  (bsc#1227149).
- wifi: wcn36xx: remove unnecessary (void*) conversions
  (bsc#1227149).
- wifi: ar5523: Remove unnecessary (void*) conversions
  (bsc#1227149).
- wifi: ath9k: clean up function ath9k_hif_usb_resume
  (bsc#1227149).
- wifi: ath11k: add chip id board name while searching board-2.bin
  for WCN6855 (bsc#1227149).
- wifi: ath12k: change to initialize recovery variables earlier
  in ath12k_core_reset() (bsc#1227149).
- wifi: ath12k: enable 320 MHz bandwidth for 6 GHz band in EHT
  PHY capability for WCN7850 (bsc#1227149).
- wifi: ath9k: use u32 for txgain indexes (bsc#1227149).
- wifi: ath9k: simplify ar9003_hw_process_ini() (bsc#1227149).
- wifi: ath12k: fix radar detection in 160 MHz (bsc#1227149).
- commit 0b35606
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath12k: fix WARN_ON during ath12k_mac_update_vif_chan
  (bsc#1227149).
- wifi: ath11k: fix tid bitmap is 0 in peer rx mu stats
  (bsc#1227149).
- wifi: ath11k: move references from rsvd2 to info fields
  (bsc#1227149).
- wifi: ath11k: mhi: add a warning message for MHI_CB_EE_RDDM
  crash (bsc#1227149).
- wifi: ath: Use is_multicast_ether_addr() to check multicast
  Ether address (bsc#1227149).
- wifi: ath12k: Remove unused declarations (bsc#1227149).
- wifi: ath5k: ath5k_hw_get_median_noise_floor(): use swap()
  (bsc#1227149).
- wifi: ath: remove unused-but-set parameter (bsc#1227149).
- wifi: ath11k: Remove unused declarations (bsc#1227149).
- wifi: ath10k: fix Wvoid-pointer-to-enum-cast warning
  (bsc#1227149).
- commit 1f3c3b8
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: fix Wvoid-pointer-to-enum-cast warning
  (bsc#1227149).
- wifi: ath11k: simplify the code with module_platform_driver
  (bsc#1227149).
- wifi: ath12k: Fix a few spelling errors (bsc#1227149).
- wifi: ath11k: Fix a few spelling errors (bsc#1227149).
- wifi: ath10k: Fix a few spelling errors (bsc#1227149).
- wifi: ath11k: Consistently use ath11k_vif_to_arvif()
  (bsc#1227149).
- wifi: ath9k: Remove unused declarations (bsc#1227149).
- wifi: ath9k: Remove unnecessary ternary operators (bsc#1227149).
- wifi: ath9k: consistently use kstrtoX_from_user() functions
  (bsc#1227149).
- wifi: ath9k: fix parameter check in ath9k_init_debug()
  (bsc#1227149).
- commit 6c737fb
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath5k: Remove redundant dev_err() (bsc#1227149).
- wifi: ath12k: avoid deadlock by change ieee80211_queue_work
  for regd_update_work (bsc#1227149).
- wifi: ath12k: add handler for scan event WMI_SCAN_EVENT_DEQUEUED
  (bsc#1227149).
- wifi: ath12k: relax list iteration in ath12k_mac_vif_unref()
  (bsc#1227149).
- wifi: ath12k: configure puncturing bitmap (bsc#1227149).
- wifi: ath12k: parse WMI service ready ext2 event (bsc#1227149).
- wifi: ath12k: add MLO header in peer association (bsc#1227149).
- wifi: ath12k: peer assoc for 320 MHz (bsc#1227149).
- wifi: ath12k: add WMI support for EHT peer (bsc#1227149).
- wifi: ath12k: prepare EHT peer assoc parameters (bsc#1227149).
- commit 3191784
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath12k: add EHT PHY modes (bsc#1227149).
- wifi: ath12k: propagate EHT capabilities to userspace
  (bsc#1227149).
- wifi: ath12k: WMI support to process EHT capabilities
  (bsc#1227149).
- wifi: ath12k: move HE capabilities processing to a new function
  (bsc#1227149).
- commit 7fb64df
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath12k: rename HE capabilities setup/copy functions
  (bsc#1227149).
- Refresh
  patches.suse/wifi-cfg80211-annotate-iftype_data-pointer-with-spar.patch.
- commit ddfeb0d
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath12k: change to use dynamic memory for channel list
  of scan (bsc#1227149).
- wifi: ath12k: trigger station disconnect on hardware restart
  (bsc#1227149).
- wifi: ath12k: Use pdev_id rather than mac_id to get pdev
  (bsc#1227149).
- wifi: ath12k: correct the data_type from QMI_OPT_FLAG to
  QMI_UNSIGNED_1_BYTE for mlo_capable (bsc#1227149).
- wifi: ath11k: Remove cal_done check during probe (bsc#1227149).
- commit e204950
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: simplify
  ath11k_mac_validate_vht_he_fixed_rate_settings() (bsc#1227149).
- wifi: ath6kl: Remove error checking for debugfs_create_dir()
  (bsc#1227149).
- wifi: ath5k: remove phydir check from ath5k_debug_init_device()
  (bsc#1227149).
- wifi: drivers: Explicitly include correct DT includes
  (bsc#1227149).
- wifi: ath10k: improve structure padding (bsc#1227149).
- wifi: ath12k: fix conf_mutex in
  ath12k_mac_op_unassign_vif_chanctx() (bsc#1227149).
- wifi: ath11k: debug: add ATH11K_DBG_CE (bsc#1227149).
- commit 3345b7e
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: htc: cleanup debug messages (bsc#1227149).
- wifi: ath11k: don't use %%pK (bsc#1227149).
- wifi: ath11k: hal: cleanup debug message (bsc#1227149).
- wifi: ath11k: debug: use all upper case in ATH11k_DBG_HAL
  (bsc#1227149).
- wifi: ath11k: dp: cleanup debug message (bsc#1227149).
- wifi: ath11k: pci: cleanup debug logging (bsc#1227149).
- wifi: ath11k: wmi: add unified command debug messages
  (bsc#1227149).
- wifi: ath11k: wmi: use common error handling style
  (bsc#1227149).
- wifi: ath11k: wmi: cleanup error handling in
  ath11k_wmi_send_init_country_cmd() (bsc#1227149).
- wifi: ath11k: remove unsupported event handlers (bsc#1227149).
- commit 37105bd
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: add WMI event debug messages (bsc#1227149).
- Refresh
  patches.suse/wifi-ath11k-fix-gtk-offload-status-event-locking.patch.
- Refresh
  patches.suse/wifi-ath11k-fix-temperature-event-locking.patch.
- commit 572fd2c
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: remove manual mask names from debug messages
  (bsc#1227149).
- Refresh
  patches.suse/wifi-ath11k-fix-gtk-offload-status-event-locking.patch.
- commit a7ae7bf
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: print debug level in debug messages (bsc#1227149).
- wifi: ath11k: debug: remove unused ATH11K_DBG_ANY (bsc#1227149).
- wifi: ath12k: delete the timer rx_replenish_retry during rmmod
  (bsc#1227149).
- wifi: ath12k: Use msdu_end to check MCBC (bsc#1227149).
- wifi: ath12k: check hardware major version for WCN7850
  (bsc#1227149).
- wifi: ath11k: update proper pdev/vdev id for testmode command
  (bsc#1227149).
- wifi: atk10k: Don't opencode ath10k_pci_priv() in
  ath10k_ahb_priv() (bsc#1227149).
- wifi: ath10k: Convert to platform remove callback returning void
  (bsc#1227149).
- commit cafd8ed
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath10k: Drop checks that are always false (bsc#1227149).
- wifi: ath10k: Drop cleaning of driver data from probe error
  path and remove (bsc#1227149).
- wifi: ath11k: Add HTT stats for PHY reset case (bsc#1227149).
- commit dde2040
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: Allow ath11k to boot without caldata in ftm mode
  (bsc#1227149).
- Refresh
  patches.suse/wifi-ath11k-do-not-dump-SRNG-statistics-during-resum.patch.
- commit adbddfc
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: factory test mode support (bsc#1227149).
- Refresh
  patches.suse/wifi-ath11k-fix-warning-on-DMA-ring-capabilities-eve.patch.
- Refresh
  patches.suse/wifi-ath11k-rearrange-IRQ-enable-disable-in-reset-pa.patch.
- Refresh patches.suse/wifi-ath11k-support-hibernation.patch.
- commit 030f59a
* Fri Jul 12 2024 tiwai@suse.de
- wifi: ath11k: remove unused function ath11k_tm_event_wmi()
  (bsc#1227149).
- wifi: ath12k: Add support to parse new WMI event for 6 GHz
  regulatory (bsc#1227149).
- wifi: wil6210: wmi: Replace zero-length array with
  DECLARE_FLEX_ARRAY() helper (bsc#1227149).
- wifi: wil6210: fw: Replace zero-length arrays with
  DECLARE_FLEX_ARRAY() helper (bsc#1227149).
- wifi: ath11k: Send HT fixed rate in WMI peer fixed param
  (bsc#1227149).
- wifi: ath11k: Relocate the func
  ath11k_mac_bitrate_mask_num_ht_rates() and change hweight16
  to hweight8 (bsc#1227149).
- wifi: ath12k: increase vdev setup timeout (bsc#1227149).
- wifi: ath11k: EMA beacon support (bsc#1227149).
- wifi: ath11k: MBSSID beacon support (bsc#1227149).
- wifi: ath11k: refactor vif parameter configurations
  (bsc#1227149).
- wifi: ath11k: MBSSID parameter configuration in AP mode
  (bsc#1227149).
- wifi: ath11k: rename MBSSID fields in wmi_vdev_up_cmd
  (bsc#1227149).
- wifi: ath11k: MBSSID configuration during vdev create/start
  (bsc#1227149).
- wifi: ath11k: driver settings for MBSSID and EMA (bsc#1227149).
- wifi: ath: work around false-positive stringop-overread warning
  (bsc#1227149).
- wifi: ath11k: Use list_count_nodes() (bsc#1227149).
- wifi: ath10k: Use list_count_nodes() (bsc#1227149).
- wifi: ath12k: fix potential wmi_mgmt_tx_queue race condition
  (bsc#1227149).
- wifi: ath12k: add wait operation for tx management packets
  for flush from mac80211 (bsc#1227149).
- wifi: ath12k: Remove some dead code (bsc#1227149).
- wifi: ath12k: send WMI_PEER_REORDER_QUEUE_SETUP_CMDID when
  ADDBA session starts (bsc#1227149).
- wifi: ath12k: set PERST pin no pull request for WCN7850
  (bsc#1227149).
- wifi: ath12k: add qmi_cnss_feature_bitmap field to hardware
  parameters (bsc#1227149).
- wifi: ath10/11/12k: Use alloc_ordered_workqueue() to create
  ordered workqueues (bsc#1227149).
- commit 1763ceb
* Fri Jul 12 2024 tiwai@suse.de
- net: phy: microchip: lan87xx: reinit PHY after cable test
  (git-fixes).
- i2c: pnx: Fix potential deadlock warning from del_timer_sync()
  call in isr (git-fixes).
- drm/amdgpu/atomfirmware: silence UBSAN warning (stable-fixes).
- drm: panel-orientation-quirks: Add quirk for Valve Galileo
  (stable-fixes).
- nilfs2: add missing check for inode numbers on directory entries
  (stable-fixes).
- nilfs2: fix inode number range checks (stable-fixes).
- drm/amdgpu: silence UBSAN warning (stable-fixes).
- spi: cadence: Ensure data lines set to low during dummy-cycle
  period (stable-fixes).
- regmap-i2c: Subtract reg size from max_write (stable-fixes).
- platform/x86: touchscreen_dmi: Add info for the EZpad 6s Pro
  (stable-fixes).
- platform/x86: touchscreen_dmi: Add info for GlobalSpace SolT
  IVW 11.6" tablet (stable-fixes).
- nfc/nci: Add the inconsistency check between the input data
  length and count (stable-fixes).
- Input: ff-core - prefer struct_size over open coded arithmetic
  (stable-fixes).
- cdrom: rearrange last_media_change check to avoid unintentional
  overflow (stable-fixes).
- serial: imx: Raise TX trigger level to 8 (stable-fixes).
- usb: xhci: prevent potential failure in handle_tx_event()
  for Transfer events without TRB (stable-fixes).
- thermal/drivers/mediatek/lvts_thermal: Check NULL ptr on
  lvts_data (stable-fixes).
- firmware: dmi: Stop decoding on broken entry (stable-fixes).
- i2c: i801: Annotate apanel_addr as __ro_after_init
  (stable-fixes).
- media: dvb-frontends: tda10048: Fix integer overflow
  (stable-fixes).
- media: s2255: Use refcount_t instead of atomic_t for
  num_channels (stable-fixes).
- media: dvb-frontends: tda18271c2dd: Remove casting during div
  (stable-fixes).
- media: dw2102: fix a potential buffer overflow (git-fixes).
- media: dw2102: Don't translate i2c read into write
  (stable-fixes).
- media: dvb-usb: dib0700_devices: Add missing release_firmware()
  (stable-fixes).
- media: dvb: as102-fe: Fix as10x_register_addr packing
  (stable-fixes).
- drm/amdgpu: fix the warning about the expression (int)size -
  len (stable-fixes).
- drm/amdgpu: fix uninitialized scalar variable warning
  (stable-fixes).
- drm/amd/display: Fix uninitialized variables in DM
  (stable-fixes).
- drm/amd/display: Skip finding free audio for unknown engine_id
  (stable-fixes).
- drm/amd/display: Check pipe offset before setting vblank
  (stable-fixes).
- drm/amd/display: Check index msg_id before read or write
  (stable-fixes).
- drm/amdgpu: Initialize timestamp for some legacy SOCs
  (stable-fixes).
- drm/amdgpu: Using uninitialized value *size when calling
  amdgpu_vce_cs_reloc (stable-fixes).
- drm/amdgpu: Fix uninitialized variable warnings (stable-fixes).
- drm/lima: fix shared irq handling on driver remove
  (stable-fixes).
- wifi: mt76: mt7996: add sanity checks for background radar
  trigger (stable-fixes).
- wifi: mt76: replace skb_put with skb_put_zero (stable-fixes).
- crypto: aead,cipher - zeroize key buffer after use
  (stable-fixes).
- crypto: hisilicon/debugfs - Fix debugfs uninit process issue
  (stable-fixes).
- commit 240e65e
* Thu Jul 11 2024 tiwai@suse.de
- Refresh patches.kabi/wireless-kabi-workaround.patch (bsc#1227149)
  More fixes for 6.9 API updates
- commit 25eb11c
* Thu Jul 11 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: fix ROC version check (bsc#1227149).
- wifi: iwlwifi: mvm: fix a crash on 7265 (bsc#1227149).
- wifi: iwlwifi: Use request_module_nowait (bsc#1227149).
- wifi: iwlwifi: mvm: don't always disable EMLSR due to BT coex
  (bsc#1227149).
- wifi: iwlwifi: mvm: calculate EMLSR mode after connection
  (bsc#1227149).
- wifi: iwlwifi: mvm: introduce esr_disable_reason (bsc#1227149).
- wifi: iwlwifi: mvm: Do not warn on invalid link on scan complete
  (bsc#1227149).
- wifi: iwlwifi: mvm: support iwl_dev_tx_power_cmd_v8
  (bsc#1227149).
- commit 74beb0b
* Thu Jul 11 2024 ohering@suse.de
- net: mana: Fix possible double free in error handling path
  (git-fixes).
- RDMA/mana_ib: Ignore optional access flags for MRs (git-fixes).
- net: mana: Fix the extra HZ in mana_hwc_send_request
  (git-fixes).
- commit cb4a2bd
* Thu Jul 11 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: fix link ID management (bsc#1227149).
- Revert "wifi: iwlwifi: bump FW API to 90 for BZ/SC devices"
  (bsc#1227149).
- wifi: iwlwifi: mvm: handle debugfs names more carefully
  (bsc#1227149).
- commit 1b2b558
* Thu Jul 11 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: Configure the link mapping for non-MLD FW
  (bsc#1227149).
- wifi: iwlwifi: mvm: consider having one active link
  (bsc#1227149).
- wifi: iwlwifi: mvm: pick the version of SESSION_PROTECTION_NOTIF
  (bsc#1227149).
- wifi: iwlwifi: mvm: disable MLO for the time being
  (bsc#1227149).
- wifi: cfg80211: add a flag to disable wireless extensions
  (bsc#1227149).
- iwlwifi: mvm: Use for_each_thermal_trip() for walking trip
  points (bsc#1227149).
- iwlwifi: mvm: Populate trip table before registering thermal
  zone (bsc#1227149).
- iwlwifi: mvm: Drop unused fw_trips_index[] from
  iwl_mvm_thermal_device (bsc#1227149).
- commit 53ce28e
* Thu Jul 11 2024 tiwai@suse.de
- wifi: mac80211: add link id to ieee80211_gtk_rekey_add()
  (bsc#1227149).
- wifi: iwlwifi: load b0 version of ucode for HR1/HR2
  (bsc#1227149).
- wifi: iwlwifi: handle per-phy statistics from fw (bsc#1227149).
- wifi: iwlwifi: iwl-fh.h: fix kernel-doc issues (bsc#1227149).
- wifi: iwlwifi: api: fix kernel-doc reference (bsc#1227149).
- wifi: iwlwifi: mvm: unlock mvm if there is no primary link
  (bsc#1227149).
- wifi: iwlwifi: mvm: partially support PHY context version 6
  (bsc#1227149).
- commit 590b6b6
* Thu Jul 11 2024 tiwai@suse.de
- wifi: iwlwifi: cancel session protection only if there is one
  (bsc#1227149).
- wifi: iwlwifi: mvm: remove IWL_MVM_STATUS_NEED_FLUSH_P2P
  (bsc#1227149).
- wifi: iwlwifi: mvm: check own capabilities for EMLSR
  (bsc#1227149).
- wifi: iwlwifi: iwl-trans.h: clean up kernel-doc (bsc#1227149).
- wifi: iwlwifi: fw: file: clean up kernel-doc (bsc#1227149).
- wifi: iwlwifi: api: dbg-tlv: fix up kernel-doc (bsc#1227149).
- wifi: iwlwifi: error-dump: fix kernel-doc issues (bsc#1227149).
- commit b9417e2
* Thu Jul 11 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: fix thermal kernel-doc (bsc#1227149).
- wifi: iwlwifi: don't use TRUE/FALSE with bool (bsc#1227149).
- wifi: iwlwifi: api: fix constant version to match FW
  (bsc#1227149).
- wifi: iwlwifi: mvm: Extend support for P2P service discovery
  (bsc#1227149).
- wifi: iwlwifi: mvm: work around A-MSDU size problem
  (bsc#1227149).
- wifi: iwlwifi: nvm: parse the VLP/AFC bit from regulatory
  (bsc#1227149).
- wifi: iwlwifi: iwlmvm: handle unprotected deauth/disassoc in d3
  (bsc#1227149).
- wifi: iwlwifi: fix #ifdef CONFIG_ACPI check (bsc#1227149).
- wifi: iwlwifi: queue: improve warning for no skb in reclaim
  (bsc#1227149).
- wifi: iwlwifi: mvm: move BA notif messages before action
  (bsc#1227149).
- commit da274a5
* Thu Jul 11 2024 tiwai@suse.de
- wifi: cfg80211: report unprotected deauth/disassoc in wowlan
  (bsc#1227149).
- Refresh patches.kabi/wireless-kabi-workaround.patch.
- commit 8a7655b
* Thu Jul 11 2024 tiwai@suse.de
- wifi: nl80211: allow reporting wakeup for unprot deauth/disassoc
  (bsc#1227149).
- Refresh patches.kabi/wireless-kabi-workaround.patch.
- commit e91caa5
* Thu Jul 11 2024 tiwai@suse.de
- wifi: cfg80211: rename UHB to 6 GHz (bsc#1227149).
- Refresh patches.kabi/wireless-kabi-workaround.patch.
- commit 72d3017
* Thu Jul 11 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: show skb_mac_gso_segment() failure reason
  (bsc#1227149).
- wifi: iwlwifi: mvm: remove flags for enable/disable beacon
  filter (bsc#1227149).
- wifi: iwlwifi: pcie: Add new PCI device id and CNVI
  (bsc#1227149).
- wifi: iwlwifi: mvm: don't send the smart fifo command if not
  needed (bsc#1227149).
- wifi: iwlwifi: fw: allow vmalloc for PNVM image (bsc#1227149).
- wifi: iwlwifi: mvm: don't do duplicate detection for nullfunc
  packets (bsc#1227149).
- wifi: iwlwifi: mvm: avoid garbage iPN (bsc#1227149).
- wifi: iwlwifi: mvm: always update keys in D3 exit (bsc#1227149).
- wifi: iwlwifi: mvm: limit pseudo-D3 to 60 seconds (bsc#1227149).
- wifi: iwlwifi: mvm: combine condition/warning (bsc#1227149).
- commit 9013bb7
* Thu Jul 11 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: fix the key PN index (bsc#1227149).
- wifi: iwlwifi: mvm: Keep connection in case of missed beacons
  during RX (bsc#1227149).
- wifi: iwlwifi: properly check if link is active (bsc#1227149).
- wifi: iwlwifi: take SGOM and UATS code out of ACPI ifdef
  (bsc#1227149).
- wifi: iwlwifi: mvm: don't abort queue sync in CT-kill
  (bsc#1227149).
- wifi: iwlwifi: mvm: define RX queue sync timeout as a macro
  (bsc#1227149).
- wifi: iwlwifi: mvm: expand queue sync warning messages
  (bsc#1227149).
- wifi: iwlwifi: mvm: Declare support for secure LTF measurement
  (bsc#1227149).
- wifi: iwlwifi: mvm: advertise support for protected ranging
  negotiation (bsc#1227149).
- wifi: iwlwifi: mvm: remove one queue sync on BA session stop
  (bsc#1227149).
- commit d32b4ac
* Thu Jul 11 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: don't support reduced tx power on ack for
  new devices (bsc#1227149).
- wifi: iwlwifi: use system_unbound_wq for debug dump
  (bsc#1227149).
- wifi: iwlwifi: mvm: remove EHT code from mac80211.c
  (bsc#1227149).
- wifi: iwlwifi: read mac step from aux register (bsc#1227149).
- wifi: iwlwifi: adjust rx_phyinfo debugfs to MLO (bsc#1227149).
- wifi: iwlwifi: mvm: const-ify chandef pointers (bsc#1227149).
- wifi: iwlwifi: Add support for PPAG cmd v5 and PPAG revision 3
  (bsc#1227149).
- wifi: iwlwifi: pcie: don't allow hw-rfkill to stop device on
  gen2 (bsc#1227149).
- wifi: iwlwifi: add HONOR to PPAG approved list (bsc#1227149).
- commit 6501846
* Thu Jul 11 2024 tiwai@suse.de
- wifi: mac80211: update beacon counters per link basis
  (bsc#1227149).
- wifi: iwlwifi: return negative -EINVAL instead of positive
  EINVAL (bsc#1227149).
- wifi: iwlwifi: fw: fix compiler warning for NULL string print
  (bsc#1227149).
- wifi: iwlwifi: mvm: make functions public (bsc#1227149).
- wifi: iwlwifi: bump FW API to 88 for AX/BZ/SC devices
  (bsc#1227149).
- wifi: iwlwifi: mvm: don't send BT_COEX_CI command on new devices
  (bsc#1227149).
- wifi: iwlwifi: read DSM functions from UEFI (bsc#1227149).
- commit 4b3d0a2
* Thu Jul 11 2024 tiwai@suse.de
- wifi: iwlwifi: prepare for reading DSM from UEFI (bsc#1227149).
- wifi: iwlwifi: simplify getting DSM from ACPI (bsc#1227149).
- wifi: iwlwifi: take send-DSM-to-FW flows out of ACPI ifdef
  (bsc#1227149).
- wifi: iwlwifi: rfi: use a single DSM function for all RFI
  configurations (bsc#1227149).
- wifi: iwlwifi: read ECKV table from UEFI (bsc#1227149).
- wifi: iwlwifi: read WRDD table from UEFI (bsc#1227149).
- wifi: iwlwifi: support link command version 2 (bsc#1227149).
- wifi: iwlwifi: mvm: use fast balance scan in case of an active
  P2P GO (bsc#1227149).
- wifi: iwlwifi: mvm: don't send NDPs for new tx devices
  (bsc#1227149).
- wifi: iwlwifi: read SPLC from UEFI (bsc#1227149).
- commit 10d0457
* Thu Jul 11 2024 tiwai@suse.de
- wifi: iwlwifi: prepare for reading SPLC from UEFI (bsc#1227149).
- wifi: iwlwifi: api: clean up some kernel-doc/typos
  (bsc#1227149).
- wifi: iwlwifi: remove unused function prototype (bsc#1227149).
- iwlwifi: fw: fix more kernel-doc warnings (bsc#1227149).
- wifi: iwlwifi: read WTAS table from UEFI (bsc#1227149).
- commit edb7009
* Thu Jul 11 2024 tiwai@suse.de
- wifi: iwlwifi: separate TAS 'read-from-BIOS' and 'send-to-FW'
  flows (bsc#1227149).
- Refresh
  patches.suse/wifi-iwlwifi-mvm-fix-warnings-from-dmi_get_system_in.patch.
- commit cbe5734
* Thu Jul 11 2024 tiwai@suse.de
- wifi: iwlwifi: prepare for reading TAS table from UEFI
  (bsc#1227149).
- Refresh
  patches.suse/wifi-iwlwifi-mvm-fix-warnings-from-dmi_get_system_in.patch.
- commit 37ff9f0
* Thu Jul 11 2024 tiwai@suse.de
- wifi: iwlwifi: don't check TAS block list size twice
  (bsc#1227149).
- wifi: iwlwifi: read PPAG table from UEFI (bsc#1227149).
- wifi: iwlwifi: validate PPAG table when sent to FW
  (bsc#1227149).
- commit aab6534
* Thu Jul 11 2024 tiwai@suse.de
- wifi: iwlwifi: prepare for reading PPAG table from UEFI
  (bsc#1227149).
- Refresh
  patches.suse/wifi-iwlwifi-fw-fix-compile-w-o-CONFIG_ACPI.patch.
- commit b317fc2
* Thu Jul 11 2024 tiwai@suse.de
- wifi: iwlwifi: small cleanups in PPAG table flows (bsc#1227149).
- wifi: iwlwifi: read SAR tables from UEFI (bsc#1227149).
- wifi: iwlwifi: cleanup sending PER_CHAIN_LIMIT_OFFSET_CMD
  (bsc#1227149).
- wifi: iwlwifi: prepare for reading SAR tables from UEFI
  (bsc#1227149).
- wifi: iwlwifi: mvm: check AP supports EMLSR (bsc#1227149).
- wifi: iwlwifi: mvm: d3: implement suspend with MLO
  (bsc#1227149).
- wifi: iwlwifi: mvm: refactor duplicate chanctx condition
  (bsc#1227149).
- wifi: iwlwifi: mvm: log dropped packets due to MIC error
  (bsc#1227149).
- commit ab26861
* Thu Jul 11 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: support SPP A-MSDUs (bsc#1227149).
- Refresh
  patches.suse/wifi-iwlwifi-mvm-don-t-set-the-MFP-flag-for-the-GTK.patch.
- commit d834590
* Thu Jul 11 2024 tiwai@suse.de
- wifi: mac80211: add support for SPP A-MSDUs (bsc#1227149).
- commit 265cdf6
* Thu Jul 11 2024 tiwai@suse.de
- wifi: cfg80211: add support for SPP A-MSDUs (bsc#1227149).
- Refresh patches.kabi/wireless-kabi-workaround.patch.
- commit f498490
* Thu Jul 11 2024 tiwai@suse.de
- wifi: iwlwifi: implement GLAI ACPI table loading (bsc#1227149).
- Refresh
  patches.suse/wifi-iwlwifi-fw-fix-compile-w-o-CONFIG_ACPI.patch.
- commit 85303bc
* Thu Jul 11 2024 tiwai@suse.de
- wifi: iwlwifi: remove Gl A-step remnants (bsc#1227149).
- wifi: iwlwifi: mvm: Fix FTM initiator flags (bsc#1227149).
- wifi: iwlwifi: always have 'uats_enabled' (bsc#1227149).
- wifi: iwlwifi: mvm: don't set trigger frame padding in AP mode
  (bsc#1227149).
- wifi: iwlwifi: Fix spelling mistake "SESION" -> "SESSION"
  (bsc#1227149).
- wifi: iwlwifi: mvm: add support for TID to link mapping neg
  request (bsc#1227149).
- wifi: iwlwifi: cleanup uefi variables loading (bsc#1227149).
- wifi: iwlwifi: mvm: disconnect station vifs if recovery failed
  (bsc#1227149).
- wifi: iwlwifi: fw: dbg: ensure correct config name sizes
  (bsc#1227149).
- commit ff842c3
* Thu Jul 11 2024 tiwai@suse.de
- wifi: ieee80211: add definitions for negotiated TID to Link map
  (bsc#1227149).
- commit b1d66f3
* Thu Jul 11 2024 tiwai@suse.de
- wifi: mac80211: process and save negotiated TID to Link mapping
  request (bsc#1227149).
- Refresh patches.kabi/wireless-kabi-workaround.patch.
- commit 32a5092
* Thu Jul 11 2024 tiwai@suse.de
- wifi: cfg80211: add RNR with reporting AP information
  (bsc#1227149).
- commit 8fede1e
* Thu Jul 11 2024 tiwai@suse.de
- wifi: iwlwifi: implement can_activate_links callback
  (bsc#1227149).
- Refresh
  patches.suse/wifi-iwlwifi-mvm-fix-active-link-counting-during-rec.patch.
- commit 7e399ce
* Thu Jul 11 2024 tiwai@suse.de
- wifi: iwlwifi: remove retry loops in start (bsc#1227149).
- commit 3c4f0f3
* Thu Jul 11 2024 tiwai@suse.de
- wifi: iwlwifi: dbg-tlv: use struct_size() for allocation
  (bsc#1227149).
- wifi: iwlwifi: dbg-tlv: avoid extra allocation/copy
  (bsc#1227149).
- wifi: iwlwifi: fix some kernel-doc issues (bsc#1227149).
- wifi: iwlwifi: mvm: d3: disconnect on GTK rekey failure
  (bsc#1227149).
- wifi: iwlwifi: mvm: Add support for removing responder TKs
  (bsc#1227149).
- wifi: iwlwifi: disable eSR when BT is active (bsc#1227149).
- wifi: iwlwifi: add support for a wiphy_work rx handler
  (bsc#1227149).
- wifi: iwlwifi: bump FW API to 87 for AX/BZ/SC devices
  (bsc#1227149).
- wifi: iwlwifi: mvm: introduce PHY_CONTEXT_CMD_API_VER_5
  (bsc#1227149).
- wifi: iwlwifi: skip affinity setting on non-SMP (bsc#1227149).
- wifi: iwlwifi: nvm-parse: advertise common packet padding
  (bsc#1227149).
- wifi: iwlwifi: change link id in time event to s8 (bsc#1227149).
- wifi: iwlwifi: mvm: limit EHT 320 MHz MCS for STEP URM
  (bsc#1227149).
- wifi: iwlwifi: disable 160 MHz based on subsystem device ID
  (bsc#1227149).
- wifi: iwlwifi: make TB reallocation a debug message
  (bsc#1227149).
- wifi: iwlwifi: Add support for new 802.11be device
  (bsc#1227149).
- commit 6617b64
* Thu Jul 11 2024 tiwai@suse.de
- pmdomain: imx8mp-blk-ctrl: imx8mp_blk: Add fdcc clock to
  hdmimix domain (CVE-2024-35942 bsc#1224589).
- commit cf74548
* Thu Jul 11 2024 tiwai@suse.de
- platform/x86: toshiba_acpi: Fix array out-of-bounds access
  (git-fixes).
- ACPI: processor_idle: Fix invalid comparison with insertion
  sort for latency (git-fixes).
- commit ec2c4bc
* Thu Jul 11 2024 jgross@suse.com
- KVM: SEV-ES: Delegate LBR virtualization to the processor
  (git-fixes).
- commit ca0a7e8
* Wed Jul 10 2024 jgross@suse.com
- KVM: x86: Always sync PIR to IRR prior to scanning I/O APIC
  routes (git-fixes).
- commit 6653b01
* Wed Jul 10 2024 jgross@suse.com
- KVM: SEV-ES: Disallow SEV-ES guests when X86_FEATURE_LBRV is
  absent (git-fixes).
- commit 1094992
* Wed Jul 10 2024 jgross@suse.com
- KVM: SVM: WARN on vNMI + NMI window iff NMIs are outright masked
  (git-fixes).
- commit 2cc4a9c
* Wed Jul 10 2024 jgross@suse.com
- drivers/xen: Improve the late XenStore init protocol
  (git-fixes).
- commit cb805fb
* Wed Jul 10 2024 jgross@suse.com
- xen/x86: add extra pages to unpopulated-alloc if available
  (git-fixes).
- commit d9de7d9
* Wed Jul 10 2024 nik.borisov@suse.com
- kunit: Fix checksum tests on big endian CPUs (git-fixed).
- commit 91a58a6
* Wed Jul 10 2024 dfaggioli@suse.com
- KVM: arm64: Fix circular locking dependency (bsc#1222463 CVE-2024-26691).
- commit 3273efe
* Wed Jul 10 2024 ohering@suse.de
- Drivers: hv: vmbus: Don't free ring buffers that couldn't be re-encrypted (bsc#1225744, CVE-2024-36909).
- uio_hv_generic: Don't free decrypted memory (bsc#1225717, CVE-2024-36910).
- hv_netvsc: Don't free decrypted memory (bsc#1225745, CVE-2024-36911).
- Drivers: hv: vmbus: Track decrypted status in vmbus_gpadl (bsc#1225752, CVE-2024-36912).
- Drivers: hv: vmbus: Leak pages if set_memory_encrypted() fails (bsc#1225753, CVE-2024-36913).
- commit a78a9db
* Wed Jul 10 2024 nik.borisov@suse.com
- x86/speculation, objtool: Use absolute relocations for annotations (git-fixes).
- commit 14e0989
* Wed Jul 10 2024 nik.borisov@suse.com
- x86/head/64: Move the __head definition to <asm/init.h> (git-fixes).
- commit 36d1750
* Wed Jul 10 2024 nik.borisov@suse.com
- x86/csum: Remove unnecessary odd handling (git-fixes).
- commit 439ef62
* Wed Jul 10 2024 nik.borisov@suse.com
- x86/csum: Fix clang -Wuninitialized in csum_partial() (git-fixes).
- commit 98db437
* Wed Jul 10 2024 nik.borisov@suse.com
- x86/csum: Improve performance of `csum_partial` (git-fixes).
- commit 131cca3
* Wed Jul 10 2024 nik.borisov@suse.com
- x86/boot: Ignore NMIs during very early boot (git-fixes).
- commit 3c94948
* Wed Jul 10 2024 nik.borisov@suse.com
- x86/asm: Fix build of UML with KASAN (git-fixes).
- commit 89fc5d7
* Wed Jul 10 2024 nik.borisov@suse.com
- tunnels: fix out of bounds access when building IPv6 PMTU error (bsc#1222328 CVE-2024-26665).
- commit f28b881
* Wed Jul 10 2024 neilb@suse.de
- SUNRPC: avoid soft lockup when transmitting UDP to reachable
  server (bsc#1225272).
- commit 3fc313b
* Tue Jul  9 2024 tiwai@suse.de
- Move upstreamed turbostat patch into sorted section
- commit 768422e
* Tue Jul  9 2024 tiwai@suse.de
- Move out-of-tree patch to the right section
- commit a3dba46
* Tue Jul  9 2024 msuchanek@suse.de
- powerpc/pseries: Fix scv instruction crash with kexec
  (bsc#1194869).
- commit 245b529
* Tue Jul  9 2024 msuchanek@suse.de
- powerpc/prom: Add CPU info to hardware description string later
  (bsc#1215199).
- commit 75358e1
* Tue Jul  9 2024 msuchanek@suse.de
- kernel-binary: vdso: Own module_dir
- commit ff69986
* Tue Jul  9 2024 tbogendoerfer@suse.de
- enic: Validate length of nl attributes in enic_set_vf_port
  (CVE-2024-38659 bsc#1226883).
- commit 82dab70
* Tue Jul  9 2024 tiwai@suse.de
- wifi: wilc1000: fix ies_len type in connect path (git-fixes).
- commit 857b40a
* Mon Jul  8 2024 tabraham@suse.com
- net/dcb: check for detached device before executing callbacks
  (bsc#1215587).
- commit c563440
* Mon Jul  8 2024 mkoutny@suse.com
- Update patches.suse/atm-Fix-Use-After-Free-in-do_vcc_ioctl.patch
  (git-fixes bsc#1218730 CVE-2023-51780).
- commit 93588a3
* Mon Jul  8 2024 msuchanek@suse.de
- powerpc/64s/radix/kfence: map __kfence_pool at page granularity
  (bsc#1223570 ltc#205770).
- commit d4edfeb
* Mon Jul  8 2024 nstange@suse.de
- crypto/ecdsa: make ecdsa_ecc_ctx_deinit() to zeroize the public
  key (bsc#1222768).
- commit 817f8be
* Mon Jul  8 2024 nstange@suse.de
- crypto/ecdh: make ecdh_compute_value() to zeroize the public
  key (bsc#1222768).
- commit 3f5391b
* Mon Jul  8 2024 jslaby@suse.cz
- PCI: Do not wait for disconnected devices when resuming
  (git-fixes).
- commit f7f9960
* Mon Jul  8 2024 msuchanek@suse.de
- powerpc/rtas: Prevent Spectre v1 gadget construction in
  sys_rtas() (bsc#1227487).
- commit 42da489
* Mon Jul  8 2024 ptesarik@suse.com
- Enable CONFIG_SCHED_CLUSTER=y on arm64 (jsc#PED-8701).
- commit 9157a3d
* Mon Jul  8 2024 tiwai@suse.de
- clk: qcom: clk-alpha-pll: set ALPHA_EN bit for Stromer Plus PLLs
  (git-fixes).
- clk: qcom: gcc-sm6350: Fix gpll6* & gpll7 parents (git-fixes).
- clk: mediatek: mt8183: Only enable runtime PM on mt8183-mfgcfg
  (git-fixes).
- commit 1a2b239
* Mon Jul  8 2024 neilb@suse.de
- nfs: drop the incorrect assertion in nfs_swap_rw() (git-fixes).
- NFS: add barriers when testing for NFS_FSDATA_BLOCKED
  (git-fixes).
- SUNRPC: return proper error from gss_wrap_req_priv (git-fixes).
- NFSv4.1 enforce rootpath check in fs_location query (git-fixes).
- SUNRPC: Fix loop termination condition in
  gss_free_in_token_pages() (git-fixes).
- nfs: fix undefined behavior in nfs_block_bits() (git-fixes).
- pNFS/filelayout: fixup pNfs allocation modes (git-fixes).
- rpcrdma: fix handling for RDMA_CM_EVENT_DEVICE_REMOVAL
  (git-fixes).
- NFS: Fix READ_PLUS when server doesn't support OP_READ_PLUS
  (git-fixes).
- sunrpc: fix NFSACL RPC retry on soft mount (git-fixes).
- nfs: keep server info for remounts (git-fixes).
- NFSv4: Fixup smatch warning for ambiguous return (git-fixes).
- SUNRPC: Fix gss_free_in_token_pages() (git-fixes).
- knfsd: LOOKUP can return an illegal error value (git-fixes).
- nfs: Handle error of rpc_proc_register() in nfs_net_init()
  (git-fixes).
- nfsd: hold a lighter-weight client reference over CB_RECALL_ANY
  (git-fixes).
- NFSD: Fix checksum mismatches in the duplicate reply cache
  (git-fixes).
- commit e019385
* Mon Jul  8 2024 jlee@suse.com
- Update
  patches.suse/ALSA-hda-intel-sdw-acpi-fix-usage-of-device_get_name.patch
  (git-fixes CVE-2024-36955 bsc#1225810).
- Update
  patches.suse/ASoC-SOF-ipc4-topology-Fix-input-format-query-of-pro.patch
  (git-fixes CVE-2024-39473 bsc#1227433).
- Update
  patches.suse/Bluetooth-qca-fix-firmware-check-error-path.patch
  (git-fixes CVE-2024-36942 bsc#1225843).
- Update
  patches.suse/Reapply-drm-qxl-simplify-qxl_fence_wait.patch
  (stable-fixes CVE-2024-36944 bsc#1225847).
- Update
  patches.suse/amd-amdkfd-sync-all-devices-to-wait-all-processes-be.patch
  (stable-fixes CVE-2024-36949 bsc#1225894).
- Update
  patches.suse/drm-amdkfd-range-check-cp-bad-op-exception-interrupt.patch
  (stable-fixes CVE-2024-36951 bsc#1225896).
- Update patches.suse/drm-i915-hwmon-Get-rid-of-devm.patch
  (stable-fixes CVE-2024-39479 bsc#1227443).
- Update
  patches.suse/fbdev-savage-Handle-err-return-when-savagefb_check_v.patch
  (git-fixes CVE-2024-39475 bsc#1227435).
- Update
  patches.suse/firewire-ohci-mask-bus-reset-interrupts-between-ISR-.patch
  (stable-fixes CVE-2024-36950 bsc#1225895).
- Update
  patches.suse/media-mc-Fix-graph-walk-in-media_pipeline_start.patch
  (git-fixes CVE-2024-39481 bsc#1227446).
- Update
  patches.suse/pinctrl-core-delete-incorrect-free-in-pinctrl_enable.patch
  (git-fixes CVE-2024-36940 bsc#1225840).
- Update
  patches.suse/pinctrl-devicetree-fix-refcount-leak-in-pinctrl_dt_t.patch
  (git-fixes CVE-2024-36959 bsc#1225839).
- Update patches.suse/qibfs-fix-dentry-leak.patch (git-fixes
  CVE-2024-36947 bsc#1225856).
- Update
  patches.suse/spi-fix-null-pointer-dereference-within-spi_sync.patch
  (git-fixes CVE-2024-36930 bsc#1225830).
- Update
  patches.suse/wifi-iwlwifi-read-txq-read_ptr-under-lock.patch
  (stable-fixes CVE-2024-36922 bsc#1225805).
- Update
  patches.suse/wifi-nl80211-don-t-free-NULL-coalescing-rule.patch
  (git-fixes CVE-2024-36941 bsc#1225835).
- commit ffdc766
* Mon Jul  8 2024 jlee@suse.com
- Update
  patches.suse/crypto-rsa-add-a-check-for-allocation-failure.patch
  (bsc#1222775 CVE-2023-52472 bsc#1220430 bsc#1220427).
- commit 7754b95
* Sat Jul  6 2024 tiwai@suse.de
- drm/fbdev-generic: Fix framebuffer on big endian devices
  (git-fixes).
- drm/nouveau: fix null pointer dereference in
  nouveau_connector_get_modes (git-fixes).
- usb: dwc3: core: Workaround for CSR read timeout (stable-fixes).
- usb: gadget: printer: SS+ support (stable-fixes).
- drm/amdgpu: avoid using null object of framebuffer
  (stable-fixes).
- drm/amd/display: Send DP_TOTAL_LTTPR_CNT during detection if
  LTTPR is present (stable-fixes).
- drm/amdgpu/atomfirmware: fix parsing of vram_info
  (stable-fixes).
- drm/nouveau/dispnv04: fix null pointer dereference in
  nv17_tv_get_ld_modes (stable-fixes).
- drm/nouveau/dispnv04: fix null pointer dereference in
  nv17_tv_get_hd_modes (stable-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs don't work for
  EliteBook 645/665 G11 (stable-fixes).
- usb: typec: ucsi: Ack also failed Get Error commands
  (git-fixes).
- iio: pressure: bmp280: Fix BMP580 temperature reading
  (stable-fixes).
- usb: typec: ucsi: Never send a lone connector change ack
  (stable-fixes).
- mtd: partitions: redboot: Added conversion of operands to a
  larger type (stable-fixes).
- media: dvbdev: Initialize sbuf (stable-fixes).
- ALSA: emux: improve patch ioctl data validation (stable-fixes).
- drm/radeon/radeon_display: Decrease the size of allocated memory
  (stable-fixes).
- drm/panel: ilitek-ili9881c: Fix warning with GPIO controllers
  that sleep (stable-fixes).
- wifi: ieee80211: check for NULL in ieee80211_mle_size_ok()
  (stable-fixes).
- crypto: ecdh - explicitly zeroize private_key (stable-fixes).
- soc: ti: wkup_m3_ipc: Send NULL dummy message instead of
  pointer message (stable-fixes).
- usb: dwc3: core: Add DWC31 version 2.00a controller
  (stable-fixes).
- iio: pressure: fix some word spelling errors (stable-fixes).
- commit 42cf83f
* Sat Jul  6 2024 tiwai@suse.de
- Drop amd-pstate patch that caused a regression on 6.6.x stable
- commit d3672a6
* Sat Jul  6 2024 nmorey@suse.com
- RDMA/restrack: Fix potential invalid address access (git-fixes)
- commit 91e323d
* Fri Jul  5 2024 ematsumiya@suse.de
- smb: client: fix use-after-free in smb2_query_info_compound()
  (bsc#1225489, CVE-2023-52751).
- Refresh
  patches.suse/smb-client-fix-potential-OOBs-in-smb2_parse_contexts-.patch.
- commit fed05d1
* Fri Jul  5 2024 ematsumiya@suse.de
- smb: client: prevent new fids from being removed by laundromat
  (git-fixes, bsc#1225172).
- commit b3d54ea
* Fri Jul  5 2024 ematsumiya@suse.de
- smb: client: make laundromat a delayed worker (git-fixes,
  bsc#1225172).
- commit 97932f6
* Fri Jul  5 2024 ematsumiya@suse.de
- smb3: allow controlling length of time directory entries are
  cached with dir leases (git-fixes, bsc#1225172).
- commit c39c365
* Fri Jul  5 2024 ematsumiya@suse.de
- smb: client: do not start laundromat thread on nohandlecache
  (git-fixes, bsc#1225172).
- commit b320db3
* Fri Jul  5 2024 ematsumiya@suse.de
- smb3: allow controlling maximum number of cached directories
  (git-fixes, bsc#1225172).
- commit e5e6d01
* Fri Jul  5 2024 ematsumiya@suse.de
- smb3: do not start laundromat thread when dir leases disabled
  (git-fixes, bsc#1225172).
- commit b758cab
* Fri Jul  5 2024 ematsumiya@suse.de
- cifs: Add a laundromat thread for cached directories (git-fixes,
  bsc#1225172).
- commit b1876e3
* Fri Jul  5 2024 andrea.porta@suse.com
- bcache: fix variable length array abuse in btree_iter
  (CVE-2024-39482 bsc#1227447).
- commit 3d0cfa1
* Fri Jul  5 2024 andrea.porta@suse.com
- mm/vmalloc: fix vmalloc which may return null if called with
  __GFP_NOFAIL (CVE-2024-39474 bsc#1227434).
- commit 13add8a
* Fri Jul  5 2024 tiwai@suse.de
- selftests: make order checking verbose in msg_zerocopy selftest
  (git-fixes).
- selftests: fix OOM in msg_zerocopy selftest (git-fixes).
- can: kvaser_usb: Explicitly initialize family in leafimx
  driver_info struct (git-fixes).
- bluetooth/hci: disallow setting handle bigger than
  HCI_CONN_HANDLE_MAX (git-fixes).
- Bluetooth: ISO: Check socket flag instead of hcon (git-fixes).
- Bluetooth: Ignore too large handle values in BIG (git-fixes).
- Bluetooth: qca: Fix BT enable failure again for QCA6390 after
  warm reboot (git-fixes).
- Bluetooth: hci_event: Fix setting of unicast qos interval
  (git-fixes).
- Bluetooth: hci_bcm4377: Fix msgid release (git-fixes).
- mac802154: fix time calculation in
  ieee802154_configure_durations() (git-fixes).
- net: phy: phy_device: Fix PHY LED blinking code comment
  (git-fixes).
- wifi: cfg80211: restrict NL80211_ATTR_TXQ_QUANTUM values
  (git-fixes).
- platform/x86: toshiba_acpi: Fix quickstart quirk handling
  (git-fixes).
- commit 3db85da
* Thu Jul  4 2024 ddiss@suse.de
- jfs: xattr: fix buffer overflow for invalid xattr
  (bsc#1227383).
- commit ae2a0d9
* Thu Jul  4 2024 vkarasulli@suse.de
- iommu/arm-smmu-v3: Free MSIs in case of ENOMEM (git-fixes).
- commit 2fb4aa0
* Thu Jul  4 2024 ptesarik@suse.com
- Update
  patches.suse/arm64-mm-Batch-dsb-and-isb-when-populating-pgtables.patch
  (jsc#PED-8688 bsc#1226202).
- Update
  patches.suse/arm64-mm-Don-t-remap-pgtables-for-allocate-vs-populate.patch
  (jsc#PED-8688 bsc#1226202).
- Update
  patches.suse/arm64-mm-Don-t-remap-pgtables-per-cont-pte-pmd-block.patch
  (jsc#PED-8688 bsc#1226202).
- Update
  patches.suse/net-ena-Fix-redundant-device-NUMA-node-override.patch
  (jsc#PED-8688 bsc#1226202).
- commit 584efba
* Thu Jul  4 2024 oneukum@suse.com
- Update
  patches.suse/usb-gadget-printer-fix-races-against-disable.patch
  (CVE-2024-25741 bsc#1219832).
- commit 4a6f084
* Thu Jul  4 2024 mkubecek@suse.cz
- llc: make llc_ui_sendmsg() more robust against bonding changes
  (CVE-2024-26636 bsc#1221659).
- commit 1bb1c76
* Thu Jul  4 2024 mkubecek@suse.cz
- llc: Drop support for ETH_P_TR_802_2 (CVE-2024-26635
  bsc#1221656).
- commit 6a42a8d
* Thu Jul  4 2024 tiwai@suse.de
- PCI: vmd: Create domain symlink before pci_bus_add_devices()
  (bsc#1227363).
- commit 3666715
* Thu Jul  4 2024 colyli@suse.de
- md: fix resync softlockup when bitmap size is less than array
  size (CVE-2024-38598, bsc#1226757).
- commit 43087c7
* Wed Jul  3 2024 tbogendoerfer@suse.de
- ice: fix LAG and VF lock dependency in ice_reset_vf()
  (CVE-2024-36003 bsc#1224544).
- commit 0af15ab
* Wed Jul  3 2024 hare@suse.de
- Refresh
  patches.suse/nvme-tcp-strict-pdu-pacing-to-avoid-send-stalls-on-T.patch.
- commit a27eef2
* Wed Jul  3 2024 hare@suse.de
- block: refine the EOF check in blkdev_iomap_begin (bsc#1226866
  CVE-2024-38604).
- commit 9e332c1
* Wed Jul  3 2024 denis.kirjanov@suse.com
- kabi/severities: ignore amd pds internal symbols
- commit 3a9ca76
* Wed Jul  3 2024 mkubecek@suse.cz
- ip6_tunnel: make sure to pull inner header in __ip6_tnl_rcv()
  (CVE-2024-26641 bsc#1221654).
- commit 5bd1138
* Wed Jul  3 2024 lhenriques@suse.de
- hsr: Fix uninit-value access in hsr_get_node() (bsc#1223021
  CVE-2024-26863).
- commit 21d04a8
* Wed Jul  3 2024 mkubecek@suse.cz
- ip6_tunnel: fix NEXTHDR_FRAGMENT handling in
  ip6_tnl_parse_tlv_enc_lim() (CVE-2024-26633 bsc#1221647).
- commit 78e628d
* Wed Jul  3 2024 denis.kirjanov@suse.com
- pds_core: Prevent race issues involving the adminq (bsc#1221057
  CVE-2024-26623).
- commit 94351ab
* Wed Jul  3 2024 vkarasulli@suse.de
- iommufd: Fix protection fault in iommufd_test_syz_conv_iova
  (bsc#1222779 CVE-2024-26785).
- commit 5644693
* Wed Jul  3 2024 lhenriques@suse.de
- devlink: fix possible use-after-free and memory leaks in
  devlink_init() (bsc#1222438 CVE-2024-26734).
- commit d3a3753
* Wed Jul  3 2024 colyli@suse.de
- dm snapshot: fix lockup in dm_exception_table_exit (bsc#1224743,
  CVE-2024-35805).
- commit ba12566
* Tue Jul  2 2024 krisman@suse.de
- io_uring/rsrc: fix incorrect assignment of iter->nr_segs in
  io_import_fixed (git-fixes).
- io_uring/rsrc: don't lock while !TASK_RUNNING (git-fixes).
- io_uring/io-wq: avoid garbage value of 'match' in
  io_wq_enqueue() (git-fixes).
- commit 7d3e252
* Tue Jul  2 2024 krisman@suse.de
- io_uring: check for non-NULL file pointer in io_file_can_poll()
  (bsc#1226990 CVE-2024-39371).
- io_uring/io-wq: Use set_bit() and test_bit() at worker->flags
  (git-fixes).
- io_uring/sqpoll: work around a potential audit memory leak
  (git-fixes).
- commit 24603fc
* Tue Jul  2 2024 krisman@suse.de
- io_uring: Fix io_cqring_wait() not restoring sigmask on
  get_timespec64() failure (git-fixes).
- commit e640a65
* Tue Jul  2 2024 rhopkins@suse.de
- hsr: Prevent use after free in prp_create_tagged_frame()
  (CVE-2023-52846 bsc#1225098).
- commit cf63988
* Tue Jul  2 2024 vbabka@suse.cz
- drivers/virt/acrn: fix PFNMAP PTE checks in acrn_vm_ram_map()
  (CVE-2024-38610 bsc#1226758).
- commit 7069ac2
* Tue Jul  2 2024 vbabka@suse.cz
- virt: acrn: stop using follow_pfn (CVE-2024-38610 bsc#1226758).
- commit c2ea51b
* Tue Jul  2 2024 fdmanana@suse.com
- btrfs: fix crash on racing fsync and size-extending write into
  prealloc (bsc#1227101 CVE-2024-37354).
- commit 1d355af
* Tue Jul  2 2024 dwagner@suse.de
- blk-mq: add helper for checking if one CPU is mapped to
  specified hctx (bsc#1223600).
- blk-mq: don't schedule block kworker on isolated CPUs
  (bsc#1223600).
- commit 2b67848
* Tue Jul  2 2024 tbogendoerfer@suse.de
- kernel-doc: fix struct_group_tagged() parsing (git-fixes).
- commit e3a2a2e
* Tue Jul  2 2024 tiwai@suse.de
- mtd: rawnand: rockchip: ensure NVDDR timings are rejected
  (git-fixes).
- mtd: rawnand: Bypass a couple of sanity checks during NAND
  identification (git-fixes).
- mtd: rawnand: Fix the nand_read_data_op() early check
  (git-fixes).
- mtd: rawnand: Ensure ECC configuration is propagated to upper
  layers (git-fixes).
- commit e545951
* Tue Jul  2 2024 tiwai@suse.de
- Correct SCSI patch references (bsc#1225767 CVE-2024-36919 bsc#1226785 CVE-2024-38559)
- commit e8ea587
* Tue Jul  2 2024 heming.zhao@suse.com
- gfs2: Fix potential glock use-after-free on unmount (bsc#1226775
  CVE-2024-38570).
- gfs2: Rename sd_{ glock => kill }_wait (bsc#1226775
  CVE-2024-38570).
- commit f3adbca
* Mon Jul  1 2024 jlee@suse.com
- X.509: Fix the parser of extended key usage for length
  (bsc#1218820).
- commit a9df6a7
* Mon Jul  1 2024 mkubecek@suse.cz
- tcp: Use refcount_inc_not_zero() in tcp_twsk_unique()
  (CVE-2024-36904 bsc#1225732).
- commit d578dcc
* Mon Jul  1 2024 mhocko@suse.com
- Update
  patches.suse/1352-drm-amdgpu-Fix-possible-null-pointer-dereference.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52883
  bsc#1226630).
- Update
  patches.suse/9p-add-missing-locking-around-taking-dentry-fid-list.patch
  (git-fixes CVE-2024-39463 bsc#1227090).
- Update
  patches.suse/ALSA-Fix-deadlocks-with-kctl-removals-at-disconnecti.patch
  (stable-fixes CVE-2024-38600 bsc#1226864).
- Update
  patches.suse/ALSA-core-Fix-NULL-module-pointer-assignment-at-card.patch
  (git-fixes CVE-2024-38605 bsc#1226740).
- Update
  patches.suse/ALSA-hda-Fix-possible-null-ptr-deref-when-assigning-.patch
  (git-fixes CVE-2023-52806 bsc#1225554).
- Update
  patches.suse/ALSA-hda-cs_dsp_ctl-Use-private_free-for-control-cle.patch
  (git-fixes CVE-2024-38388 bsc#1226890).
- Update
  patches.suse/ALSA-timer-Set-lower-bound-of-start-tick-time.patch
  (stable-fixes git-fixes CVE-2024-38618 bsc#1226754).
- Update
  patches.suse/ASoC-kirkwood-Fix-potential-NULL-dereference.patch
  (git-fixes CVE-2024-38550 bsc#1226633).
- Update
  patches.suse/ASoC-mediatek-Assign-dummy-when-codec-not-specified-.patch
  (git-fixes CVE-2024-38551 bsc#1226761).
- Update
  patches.suse/Bluetooth-btusb-Add-date-evt_skb-is-NULL-check.patch
  (git-fixes CVE-2023-52833 bsc#1225595).
- Update
  patches.suse/Bluetooth-hci_core-Fix-possible-buffer-overflow.patch
  (git-fixes CVE-2024-26889).
- Update
  patches.suse/HID-uclogic-Fix-user-memory-access-bug-in-uclogic_pa.patch
  (git-fixes CVE-2023-52866 bsc#1225120).
- Update
  patches.suse/IB-mlx5-Fix-init-stage-error-handling-to-avoid-doubl.patch
  (jsc#PED-6864 CVE-2023-52851 bsc#1225587).
- Update
  patches.suse/Input-cyapa-add-missing-input-core-locking-to-suspen.patch
  (git-fixes CVE-2023-52884 bsc#1226764).
- Update
  patches.suse/Input-synaptics-rmi4-fix-use-after-free-in-rmi_unreg.patch
  (git-fixes CVE-2023-52840 bsc#1224928).
- Update
  patches.suse/KEYS-trusted-Do-not-use-WARN-when-encode-fails.patch
  (git-fixes CVE-2024-36975 bsc#1226520).
- Update
  patches.suse/KEYS-trusted-Fix-memory-leak-in-tpm2_key_encode.patch
  (git-fixes CVE-2024-36967 bsc#1226131).
- Update
  patches.suse/RDMA-cma-Fix-kmemleak-in-rdma_core-observed-during-b.patch
  (git-fixes CVE-2024-38539 bsc#1226608).
- Update patches.suse/RDMA-hns-Fix-UAF-for-cq-async-event.patch
  (git-fixes CVE-2024-38545 bsc#1226595).
- Update
  patches.suse/RDMA-hns-Fix-deadlock-on-SRQ-async-events.patch
  (git-fixes CVE-2024-38591 bsc#1226738).
- Update
  patches.suse/RDMA-hns-Modify-the-print-level-of-CQE-error.patch
  (git-fixes CVE-2024-38590 bsc#1226839).
- Update
  patches.suse/RDMA-rxe-Fix-seg-fault-in-rxe_comp_queue_pkt.patch
  (git-fixes CVE-2024-38544 bsc#1226597).
- Update
  patches.suse/SUNRPC-Fix-RPC-client-cleaned-up-the-freed-pipefs-de.patch
  (git-fixes CVE-2023-52803 bsc#1225008).
- Update patches.suse/af_unix-Clear-stale-u-oob_skb.patch
  (CVE-2024-26676 bsc#1222380 CVE-2024-35970 bsc#1224584).
- Update
  patches.suse/af_unix-Drop-oob_skb-ref-before-purging-queue-in-GC.patch
  (CVE-2024-26676 bsc#1222380 CVE-2024-26750 bsc#1222617).
- Update
  patches.suse/af_unix-Fix-task-hung-while-purging-oob_skb-in-GC.patch
  (CVE-2024-26676 bsc#1222380 CVE-2024-26780 bsc#1222588).
- Update
  patches.suse/af_unix-Update-unix_sk-sk-oob_skb-under-sk_receive_queue-lock.patch
  (CVE-2024-26676 bsc#1222380 CVE-2024-36972 bsc#1226163).
- Update
  patches.suse/arm64-Restrict-CPU_BIG_ENDIAN-to-GNU-as-or-LLVM-IAS-.patch
  (git-fixes CVE-2023-52750 bsc#1225485).
- Update
  patches.suse/atl1c-Work-around-the-DMA-RX-overflow-issue.patch
  (git-fixes CVE-2023-52834 bsc#1225599).
- Update
  patches.suse/ax25-Fix-reference-count-leak-issue-of-net_device.patch
  (git-fixes CVE-2024-38554 bsc#1226742).
- Update
  patches.suse/ax25-Fix-reference-count-leak-issues-of-ax25_dev.patch
  (git-fixes CVE-2024-38602 bsc#1226613).
- Update
  patches.suse/blk-cgroup-fix-list-corruption-from-reorder-of-WRITE-lqueued.patch
  (bsc#1225605 CVE-2024-38384 bsc#1226938).
- Update
  patches.suse/blk-cgroup-fix-list-corruption-from-resetting-io-stat.patch
  (bsc#1225605 CVE-2024-38663 bsc#1226939).
- Update
  patches.suse/bnxt_re-avoid-shift-undefined-behavior-in-bnxt_qplib.patch
  (git-fixes CVE-2024-38540 bsc#1226582).
- Update
  patches.suse/bonding-stop-the-device-in-bond_setup_by_slave.patch
  (git-fixes CVE-2023-52784 bsc#1224946).
- Update
  patches.suse/can-dev-can_put_echo_skb-don-t-crash-kernel-if-can_p.patch
  (git-fixes CVE-2023-52878 bsc#1225000).
- Update
  patches.suse/clk-mediatek-clk-mt2701-Add-check-for-mtk_alloc_clk_.patch
  (git-fixes CVE-2023-52875 bsc#1225096).
- Update
  patches.suse/clk-mediatek-clk-mt6765-Add-check-for-mtk_alloc_clk_.patch
  (git-fixes CVE-2023-52870 bsc#1224937).
- Update
  patches.suse/clk-mediatek-clk-mt6779-Add-check-for-mtk_alloc_clk_.patch
  (git-fixes CVE-2023-52873 bsc#1225589).
- Update
  patches.suse/clk-mediatek-clk-mt6797-Add-check-for-mtk_alloc_clk_.patch
  (git-fixes CVE-2023-52865 bsc#1225086).
- Update
  patches.suse/clk-mediatek-clk-mt7629-Add-check-for-mtk_alloc_clk_.patch
  (git-fixes CVE-2023-52858 bsc#1225566).
- Update
  patches.suse/clk-mediatek-clk-mt7629-eth-Add-check-for-mtk_alloc_.patch
  (git-fixes CVE-2023-52876 bsc#1225036).
- Update
  patches.suse/cppc_cpufreq-Fix-possible-null-pointer-dereference.patch
  (git-fixes CVE-2024-38573 bsc#1226739).
- Update patches.suse/cpufreq-exit-callback-is-optional.patch
  (git-fixes CVE-2024-38615 bsc#1226592).
- Update patches.suse/crypto-bcm-Fix-pointer-arithmetic.patch
  (git-fixes CVE-2024-38579 bsc#1226637).
- Update
  patches.suse/crypto-pcrypt-Fix-hungtask-for-PADATA_RESET.patch
  (git-fixes CVE-2023-52813 bsc#1225527).
- Update patches.suse/cxl-mem-Fix-shutdown-order.patch (git-fixes
  CVE-2023-52849 bsc#1224949).
- Update
  patches.suse/cxl-region-Do-not-try-to-cleanup-after-cxl_region_se.patch
  (git-fixes CVE-2023-52792 bsc#1225477).
- Update patches.suse/cxl-region-Fix-cxlr_pmem-leaks.patch
  (git-fixes CVE-2024-38391 bsc#1226894).
- Update
  patches.suse/dma-buf-sw-sync-don-t-enable-IRQ-from-sync_print_obj.patch
  (git-fixes CVE-2024-38780 bsc#1226886).
- Update
  patches.suse/dma-mapping-benchmark-fix-node-id-validation.patch
  (git-fixes CVE-2024-34777 bsc#1226796).
- Update
  patches.suse/dma-mapping-benchmark-handle-NUMA_NO_NODE-correctly.patch
  (git-fixes CVE-2024-39277 bsc#1226909).
- Update
  patches.suse/dmaengine-idxd-Avoid-unnecessary-destruction-of-file.patch
  (git-fixes CVE-2024-38629 bsc#1226905).
- Update
  patches.suse/drm-amd-Fix-UBSAN-array-index-out-of-bounds-for-Pola.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52819
  bsc#1225532).
- Update
  patches.suse/drm-amd-Fix-UBSAN-array-index-out-of-bounds-for-SMU7.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52818
  bsc#1225530).
- Update
  patches.suse/drm-amd-check-num-of-link-levels-when-update-pcie-pa.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52812
  bsc#1225564).
- Update
  patches.suse/drm-amd-display-Avoid-NULL-dereference-of-timing-gen.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52753
  bsc#1225478).
- Update
  patches.suse/drm-amd-display-Fix-division-by-zero-in-setup_dsc_co.patch
  (stable-fixes CVE-2024-36969 bsc#1226155).
- Update
  patches.suse/drm-amd-display-Fix-null-pointer-dereference-in-erro.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52862
  bsc#1225015).
- Update
  patches.suse/drm-amd-display-Fix-potential-index-out-of-bounds-in.patch
  (git-fixes CVE-2024-38552 bsc#1226767).
- Update
  patches.suse/drm-amd-display-fix-a-NULL-pointer-dereference-in-am.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52773
  bsc#1225041).
- Update
  patches.suse/drm-amd-display-fixed-integer-types-and-null-check-l.patch
  (git-fixes CVE-2024-26767).
- Update
  patches.suse/drm-amdgpu-Fix-a-null-pointer-access-when-the-smc_rr.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52817
  bsc#1225569).
- Update
  patches.suse/drm-amdgpu-Fix-buffer-size-in-gfx_v9_4_3_init_-cp_co.patch
  (git-fixes CVE-2024-39291 bsc#1226934).
- Update
  patches.suse/drm-amdgpu-Fix-potential-null-pointer-derefernce.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52814
  bsc#1225565).
- Update
  patches.suse/drm-amdgpu-add-error-handle-to-avoid-out-of-bounds.patch
  (stable-fixes CVE-2024-39471 bsc#1227096).
- Update
  patches.suse/drm-amdgpu-mes-fix-use-after-free-issue.patch
  (stable-fixes CVE-2024-38581 bsc#1226657).
- Update
  patches.suse/drm-amdgpu-vkms-fix-a-possible-null-pointer-derefere.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52815
  bsc#1225568).
- Update
  patches.suse/drm-amdkfd-Fix-a-race-condition-of-vram-buffer-unref.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52825
  bsc#1225076).
- Update
  patches.suse/drm-amdkfd-Fix-shift-out-of-bounds-issue.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52816
  bsc#1225529).
- Update
  patches.suse/drm-bridge-cdns-mhdp8546-Fix-possible-null-pointer-d.patch
  (git-fixes CVE-2024-38548).
- Update
  patches.suse/drm-bridge-it66121-Fix-invalid-connector-dereference.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52861
  bsc#1224941).
- Update
  patches.suse/drm-bridge-lt8912b-Fix-crash-on-bridge-detach.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52856
  bsc#1224932).
- Update
  patches.suse/drm-mediatek-Add-0-size-check-to-mtk_drm_gem_obj.patch
  (git-fixes CVE-2024-38549 bsc#1226735).
- Update
  patches.suse/drm-mediatek-Fix-coverity-issue-with-unintentional-i.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52857
  bsc#1225581).
- Update
  patches.suse/drm-mediatek-Init-ddp_comp-with-devm_kcalloc.patch
  (git-fixes CVE-2024-38592 bsc#1226844).
- Update
  patches.suse/drm-msm-a6xx-Avoid-a-nullptr-dereference-when-speedb.patch
  (git-fixes CVE-2024-38390 bsc#1226891).
- Update
  patches.suse/drm-msm-dpu-Add-callback-function-pointer-check-befo.patch
  (git-fixes CVE-2024-38622 bsc#1226856).
- Update
  patches.suse/drm-panel-fix-a-possible-null-pointer-dereference.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52821
  bsc#1225022).
- Update
  patches.suse/drm-panel-panel-tpo-tpg110-fix-a-possible-null-point.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52826
  bsc#1225077).
- Update patches.suse/drm-radeon-possible-buffer-overflow.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52867
  bsc#1225009).
- Update
  patches.suse/drm-vc4-Fix-possible-null-pointer-dereference.patch
  (git-fixes CVE-2024-38546 bsc#1226593).
- Update
  patches.suse/drm-vmwgfx-Fix-invalid-reads-in-fence-signaled-event.patch
  (git-fixes CVE-2024-36960 bsc#1225872).
- Update
  patches.suse/drm-zynqmp_dpsub-Always-register-bridge.patch
  (git-fixes CVE-2024-38664 bsc#1226941).
- Update
  patches.suse/e1000e-change-usleep_range-to-udelay-in-PHY-mdic-acc.patch
  (CVE-2024-39296 bsc#1226989 CVE-2024-36887 bsc#1225731).
- Update
  patches.suse/ecryptfs-Fix-buffer-size-for-tag-66-packet.patch
  (git-fixes CVE-2024-38578 bsc#1226634).
- Update
  patches.suse/efi-libstub-only-free-priv.runtime_map-when-allocate.patch
  (git-fixes CVE-2024-33619 bsc#1226768).
- Update
  patches.suse/fbdev-imsttfb-fix-a-resource-leak-in-probe.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52838
  bsc#1225031).
- Update
  patches.suse/fs-9p-only-translate-RWX-permissions-for-plain-9P200.patch
  (git-fixes CVE-2024-36964 bsc#1225866).
- Update
  patches.suse/fs-jfs-Add-check-for-negative-db_l2nbperpage.patch
  (git-fixes CVE-2023-52810 bsc#1225557).
- Update
  patches.suse/fs-jfs-Add-validity-check-for-db_maxag-and-db_agpref.patch
  (git-fixes CVE-2023-52804 bsc#1225550).
- Update
  patches.suse/ftrace-Fix-possible-use-after-free-issue-in-ftrace_location.patch
  (git-fixes CVE-2024-38588 bsc#1226837).
- Update
  patches.suse/genirq-irqdesc-Prevent-use-after-free-in-irq_find_at.patch
  (git-fixes CVE-2024-38385 bsc#1227085).
- Update patches.suse/gfs2-ignore-negated-quota-changes.patch
  (git-fixes CVE-2023-52759 bsc#1225560).
- Update
  patches.suse/hid-cp2112-Fix-duplicate-workqueue-initialization.patch
  (git-fixes CVE-2023-52853 bsc#1224988).
- Update
  patches.suse/hwmon-axi-fan-control-Fix-possible-NULL-pointer-dere.patch
  (git-fixes CVE-2023-52863 bsc#1225586).
- Update
  patches.suse/i2c-acpi-Unbind-mux-adapters-before-delete.patch
  (git-fixes CVE-2024-39362 bsc#1226995).
- Update
  patches.suse/i2c-core-Run-atomic-i2c-xfer-when-preemptible.patch
  (git-fixes CVE-2023-52791 bsc#1225108).
- Update
  patches.suse/i3c-master-mipi-i3c-hci-Fix-a-kernel-panic-for-acces.patch
  (git-fixes CVE-2023-52763 bsc#1225570).
- Update
  patches.suse/i3c-mipi-i3c-hci-Fix-out-of-bounds-access-in-hci_dma.patch
  (git-fixes CVE-2023-52766).
- Update
  patches.suse/i915-perf-Fix-NULL-deref-bugs-with-drm_dbg-calls.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52788
  bsc#1225106).
- Update
  patches.suse/igb-Fix-string-truncation-warnings-in-igb_set_fw_ver.patch
  (git-fixes CVE-2024-36010 bsc#1225594).
- Update
  patches.suse/iommu-vt-d-Fix-WARN_ON-in-iommu-probe-path.patch
  (git-fixes CVE-2024-35957 bsc#1224673).
- Update
  patches.suse/iommufd-Fix-missing-update-of-domains_itree-after-splitting-iopt
  (jsc#PED-7779 jsc#PED-7780 CVE-2023-52801 bsc#1225006).
- Update
  patches.suse/ipvlan-add-ipvlan_route_v6_outbound-helper.patch
  (git-fixes CVE-2023-52796 bsc#1224930).
- Update
  patches.suse/jffs2-prevent-xattr-node-from-overflowing-the-eraseblock.patch
  (git-fixes CVE-2024-38599 bsc#1226848).
- Update
  patches.suse/jfs-fix-array-index-out-of-bounds-in-dbFindLeaf.patch
  (git-fixes CVE-2023-52799 bsc#1225472).
- Update
  patches.suse/jfs-fix-array-index-out-of-bounds-in-diAlloc.patch
  (git-fixes CVE-2023-52805 bsc#1225553).
- Update
  patches.suse/kunit-fortify-Fix-mismatched-kvalloc-vfree-usage.patch
  (git-fixes CVE-2024-38617 bsc#1226859).
- Update
  patches.suse/lib-generic-radix-tree.c-Don-t-overflow-in-peek.patch
  (git-fixes CVE-2021-47432 bsc#1225391).
- Update
  patches.suse/lib-test_hmm.c-handle-src_pfns-and-dst_pfns-allocati.patch
  (git-fixes CVE-2024-38543 bsc#1226594).
- Update
  patches.suse/locking-ww_mutex-test-Fix-potential-workqueue-corrup.patch
  (bsc#1219953 CVE-2023-52836 bsc#1225609).
- Update
  patches.suse/md-Don-t-ignore-suspended-array-in-md_check_recovery-1baa.patch
  (bsc#1219596 CVE-2024-26758).
- Update
  patches.suse/media-atomisp-ssh_css-Fix-a-null-pointer-dereference.patch
  (git-fixes CVE-2024-38547 bsc#1226632).
- Update
  patches.suse/media-bttv-fix-use-after-free-error-due-to-btv-timeo.patch
  (git-fixes CVE-2023-52847 bsc#1225588).
- Update
  patches.suse/media-gspca-cpia1-shift-out-of-bounds-in-set_flicker.patch
  (git-fixes CVE-2023-52764 bsc#1225571).
- Update
  patches.suse/media-hantro-Check-whether-reset-op-is-defined-befor.patch
  (git-fixes CVE-2023-52850 bsc#1225014).
- Update
  patches.suse/media-i2c-et8ek8-Don-t-strip-remove-function-when-dr.patch
  (git-fixes CVE-2024-38611 bsc#1226760).
- Update
  patches.suse/media-imon-fix-access-to-invalid-resource-for-the-se.patch
  (git-fixes CVE-2023-52754 bsc#1225490).
- Update
  patches.suse/media-lgdt3306a-Add-a-check-against-null-pointer-def.patch
  (stable-fixes CVE-2022-48772 bsc#1226976).
- Update
  patches.suse/media-stk1160-fix-bounds-checking-in-stk1160_copy_vi.patch
  (git-fixes CVE-2024-38621 bsc#1226895).
- Update
  patches.suse/media-vidtv-mux-Add-check-and-kfree-for-kstrdup.patch
  (git-fixes CVE-2023-52841 bsc#1225592).
- Update patches.suse/media-vidtv-psi-Add-check-for-kstrdup.patch
  (git-fixes CVE-2023-52844 bsc#1225590).
- Update
  patches.suse/mfd-qcom-spmi-pmic-Fix-revid-implementation.patch
  (git-fixes CVE-2023-52765 bsc#1225029).
- Update
  patches.suse/misc-microchip-pci1xxxx-fix-double-free-in-the-error.patch
  (git-fixes CVE-2024-36973 bsc#1226457).
- Update
  patches.suse/net-hns3-fix-out-of-bounds-access-may-occur-when-coa.patch
  (git-fixes CVE-2023-52807 bsc#1225097).
- Update
  patches.suse/net-ks8851-Queue-RX-packets-in-IRQ-handler-instead-o.patch
  (git-fixes CVE-2024-36962 bsc#1225827).
- Update
  patches.suse/net-mlx5-Fix-peer-devlink-set-for-SF-representor-dev.patch
  (git-fixes CVE-2024-38595 bsc#1226741).
- Update
  patches.suse/net-mlx5e-Track-xmit-submission-to-PTP-WQ-after-popu.patch
  (jsc#PED-3311 CVE-2023-52782 bsc#1225103).
- Update
  patches.suse/net-mvneta-fix-calls-to-page_pool_get_stats.patch
  (git-fixes CVE-2023-52780 bsc#1224933).
- Update
  patches.suse/net-wangxun-fix-kernel-panic-due-to-null-pointer.patch
  (git-fixes CVE-2023-52783 bsc#1225104).
- Update
  patches.suse/netfilter-complete-validation-of-user-input.patch
  (git-fixes CVE-2024-35896 bsc#1224662 CVE-2024-35962
  bsc#1224583).
- Update
  patches.suse/nfc-nci-Fix-uninit-value-in-nci_rx_work.patch
  (git-fixes CVE-2024-38381 bsc#1226878).
- Update
  patches.suse/nilfs2-fix-nilfs_empty_dir-misjudgment-and-long-loop.patch
  (git-fixes CVE-2024-39469 bsc#1226992).
- Update
  patches.suse/nilfs2-fix-potential-hang-in-nilfs_detach_log_writer.patch
  (git-fixes CVE-2024-38582 bsc#1226658).
- Update
  patches.suse/nilfs2-fix-use-after-free-of-timer-for-log-writer-th.patch
  (git-fixes CVE-2024-38583 bsc#1226777).
- Update
  patches.suse/of-module-add-buffer-overflow-check-in-of_modalias.patch
  (git-fixes CVE-2024-38541 bsc#1226587).
- Update
  patches.suse/padata-Fix-refcnt-handling-in-padata_free_shell.patch
  (git-fixes CVE-2023-52854 bsc#1225584).
- Update
  patches.suse/perf-core-Bail-out-early-if-the-request-AUX-area-is-out-of-bound.patch
  (git-fixes CVE-2023-52835 bsc#1225602).
- Update
  patches.suse/platform-x86-wmi-Fix-opening-of-char-device.patch
  (git-fixes CVE-2023-52864 bsc#1225132).
- Update
  patches.suse/powerpc-pseries-iommu-LPAR-panics-during-boot-up-wit.patch
  (bsc#1222011 ltc#205900 CVE-2024-36926 bsc#1225829).
- Update patches.suse/pstore-platform-Add-check-for-kstrdup.patch
  (git-fixes CVE-2023-52869 bsc#1225050).
- Update
  patches.suse/remoteproc-mediatek-Make-sure-IPI-buffer-fits-in-L2T.patch
  (git-fixes CVE-2024-36965 bsc#1226149).
- Update
  patches.suse/ring-buffer-Fix-a-race-between-readers-and-resize-checks.patch
  (git-fixes CVE-2024-38601 bsc#1226876).
- Update
  patches.suse/s390-dasd-protect-device-queue-against-concurrent-access.patch
  (git-fixes bsc#1217481 CVE-2023-52774 bsc#1225572).
- Update
  patches.suse/scsi-hisi_sas-Set-debugfs_dir-pointer-to-NULL-after-removing-debugfs.patch
  (git-fixes CVE-2023-52808 bsc#1225555).
- Update
  patches.suse/scsi-ibmvfc-Remove-BUG_ON-in-the-case-of-an-empty-ev.patch
  (bsc#1209834 ltc#202097 CVE-2023-52811 bsc#1225559).
- Update
  patches.suse/scsi-libfc-Fix-potential-NULL-pointer-dereference-in-fc_lport_ptp_setup.patch
  (git-fixes CVE-2023-52809 bsc#1225556).
- Update
  patches.suse/scsi-lpfc-Move-NPIV-s-transport-unregistration-to-af.patch
  (bsc#1221777 CVE-2024-36952 bsc#1225898).
- Update
  patches.suse/scsi-lpfc-Release-hbalock-before-calling-lpfc_worker.patch
  (bsc#1221777 CVE-2024-36924 bsc#1225820).
- Update
  patches.suse/serial-max3100-Lock-port-lock-when-calling-uart_hand.patch
  (git-fixes CVE-2024-38634 bsc#1226868).
- Update
  patches.suse/serial-max3100-Update-uart_driver_registered-on-driv.patch
  (git-fixes CVE-2024-38633 bsc#1226867).
- Update
  patches.suse/soc-qcom-llcc-Handle-a-second-device-without-data-co.patch
  (git-fixes CVE-2023-52871 bsc#1225534).
- Update
  patches.suse/soundwire-cadence-fix-invalid-PDI-offset.patch
  (stable-fixes CVE-2024-38635 bsc#1226863).
- Update patches.suse/speakup-Fix-sizeof-vs-ARRAY_SIZE-bug.patch
  (git-fixes CVE-2024-38587 bsc#1226780).
- Update patches.suse/spi-Fix-null-dereference-on-suspend.patch
  (git-fixes CVE-2023-52749 bsc#1225476).
- Update
  patches.suse/thermal-core-prevent-potential-string-overflow.patch
  (git-fixes CVE-2023-52868 bsc#1225044).
- Update
  patches.suse/thermal-drivers-qcom-lmh-Check-for-SCM-availability-.patch
  (git-fixes CVE-2024-39466 bsc#1227089).
- Update
  patches.suse/thermal-drivers-tsens-Fix-null-pointer-dereference.patch
  (git-fixes CVE-2024-38571 bsc#1226737).
- Update
  patches.suse/thermal-intel-powerclamp-fix-mismatch-in-get-functio.patch
  (git-fixes CVE-2023-52794 bsc#1225028).
- Update
  patches.suse/tls-fix-NULL-deref-on-tls_sw_splice_eof-with-empty-r.patch
  (jsc#PED-6831 CVE-2023-52767 bsc#1224998).
- Update
  patches.suse/tpm_tis_spi-Account-for-SPI-header-when-allocating-T.patch
  (git-fixes CVE-2024-36477 bsc#1226840).
- Update
  patches.suse/tracing-Have-trace_event_file-have-ref-counters.patch
  (git-fixes CVE-2023-52879 bsc#1225101).
- Update
  patches.suse/tracing-trigger-Fix-to-return-error-if-failed-to-alloc-snapshot.patch
  (git-fixes CVE-2024-26920).
- Update
  patches.suse/tty-n_gsm-fix-race-condition-in-status-line-change-o.patch
  (git-fixes CVE-2023-52872 bsc#1225591).
- Update
  patches.suse/tty-n_gsm-require-CAP_NET_ADMIN-to-attach-N_GSM0710-.patch
  (bsc#1222619 CVE-2023-52880).
- Update
  patches.suse/tty-vcc-Add-check-for-kstrdup-in-vcc_probe.patch
  (git-fixes CVE-2023-52789 bsc#1225180).
- Update
  patches.suse/usb-config-fix-iteration-issue-in-usb_get_bos_descri.patch
  (git-fixes CVE-2023-52781 bsc#1225092).
- Update
  patches.suse/usb-dwc3-Wait-unconditionally-after-issuing-EndXfer-.patch
  (git-fixes CVE-2024-36977 bsc#1226513).
- Update
  patches.suse/usb-gadget-u_audio-Fix-race-condition-use-of-control.patch
  (git-fixes CVE-2024-38628 bsc#1226911).
- Update
  patches.suse/usb-storage-alauda-Check-whether-the-media-is-initia.patch
  (git-fixes CVE-2024-38619 bsc#1226861).
- Update
  patches.suse/usb-typec-tcpm-Fix-NULL-pointer-dereference-in-tcpm_.patch
  (git-fixes CVE-2023-52877 bsc#1224944).
- Update
  patches.suse/vhost-vdpa-fix-use-after-free-in-vhost_vdpa_probe.patch
  (jsc#PED-3311 CVE-2023-52795 bsc#1225085).
- Update
  patches.suse/virtio-blk-fix-implicit-overflow-on-virtio_max_dma_s.patch
  (git-fixes CVE-2023-52762 bsc#1225573).
- Update
  patches.suse/virtio-vsock-Fix-uninit-value-in-virtio_transport_re.patch
  (jsc#PED-5505 CVE-2023-52842 bsc#1225025).
- Update
  patches.suse/watchdog-cpu5wdt.c-Fix-use-after-free-bug-caused-by-.patch
  (git-fixes CVE-2024-38630 bsc#1226908).
- Update
  patches.suse/wifi-ar5523-enable-proper-endpoint-verification.patch
  (git-fixes CVE-2024-38565 bsc#1226747).
- Update
  patches.suse/wifi-ath11k-fix-dfs-radar-event-locking.patch
  (git-fixes CVE-2023-52798 bsc#1224947).
- Update
  patches.suse/wifi-ath11k-fix-gtk-offload-status-event-locking.patch
  (git-fixes CVE-2023-52777 bsc#1224992).
- Update patches.suse/wifi-ath11k-fix-htt-pktlog-locking.patch
  (git-fixes CVE-2023-52800).
- Update
  patches.suse/wifi-ath12k-fix-dfs-radar-and-temperature-event-lock.patch
  (git-fixes CVE-2023-52776 bsc#1225090).
- Update
  patches.suse/wifi-ath12k-fix-htt-mlo-offset-event-locking.patch
  (git-fixes CVE-2023-52769 bsc#1225001).
- Update
  patches.suse/wifi-ath12k-fix-out-of-bound-access-of-qmi_invoke_ha.patch
  (git-fixes CVE-2024-38572 bsc#1226776).
- Update
  patches.suse/wifi-ath12k-fix-possible-out-of-bound-read-in-ath12k.patch
  (git-fixes CVE-2023-52827 bsc#1225078).
- Update
  patches.suse/wifi-ath12k-fix-possible-out-of-bound-write-in-ath12.patch
  (git-fixes CVE-2023-52829 bsc#1225081).
- Update
  patches.suse/wifi-brcmfmac-pcie-handle-randbuf-allocation-failure.patch
  (git-fixes CVE-2024-38575 bsc#1226612).
- Update
  patches.suse/wifi-carl9170-add-a-proper-sanity-check-for-endpoint.patch
  (git-fixes CVE-2024-38567 bsc#1226769).
- Update
  patches.suse/wifi-carl9170-re-fix-fortified-memset-warning.patch
  (git-fixes CVE-2024-38616 bsc#1226852).
- Update
  patches.suse/wifi-mac80211-don-t-return-unset-power-in-ieee80211_.patch
  (git-fixes CVE-2023-52832 bsc#1225577).
- Update
  patches.suse/wifi-nl80211-Avoid-address-calculations-via-out-of-b.patch
  (git-fixes CVE-2024-38562 bsc#1226788).
- Update
  patches.suse/wifi-wilc1000-use-vmm_table-as-array-in-wilc-struct.patch
  (git-fixes CVE-2023-52768 bsc#1225004).
- Update
  patches.suse/x86-tdx-Zero-out-the-missing-RSI-in-TDX_HYPERCALL-macro.patch
  (jsc#PED-5824 CVE-2023-52874 bsc#1225049).
- commit 33efdc4
* Mon Jul  1 2024 mkubecek@suse.cz
- tcp: do not accept ACK of bytes we never sent (CVE-2023-52881
  bsc#1225611).
- commit 16404a6
* Mon Jul  1 2024 ptesarik@suse.com
- net: ena: Fix redundant device NUMA node override
  (jsc#PED-8688).
- commit 6ad6684
* Mon Jul  1 2024 tiwai@suse.de
- ata: ahci: Clean up sysfs file on error (git-fixes).
- ata: libata-core: Fix double free on error (git-fixes).
- ata,scsi: libata-core: Do not leak memory for ata_port struct
  members (git-fixes).
- ata: libata-core: Fix null pointer dereference on error
  (git-fixes).
- kbuild: Fix build target deb-pkg: ln: failed to create hard link
  (git-fixes).
- kbuild: doc: Update default INSTALL_MOD_DIR from extra to
  updates (git-fixes).
- kbuild: Install dtb files as 0644 in Makefile.dtbinst
  (git-fixes).
- counter: ti-eqep: enable clock at probe (git-fixes).
- iio: chemical: bme680: Fix sensor data read operation
  (git-fixes).
- iio: chemical: bme680: Fix overflows in compensate() functions
  (git-fixes).
- iio: chemical: bme680: Fix calibration data variable
  (git-fixes).
- iio: chemical: bme680: Fix pressure value output (git-fixes).
- iio: accel: fxls8962af: select IIO_BUFFER & IIO_KFIFO_BUF
  (git-fixes).
- iio: adc: ad7266: Fix variable checking bug (git-fixes).
- iio: xilinx-ams: Don't include ams_ctrl_channels in scan_mask
  (git-fixes).
- serial: bcm63xx-uart: fix tx after conversion to
  uart_port_tx_limited() (git-fixes).
- serial: core: introduce uart_port_tx_limited_flags()
  (git-fixes).
- Revert "serial: core: only stop transmit when HW fifo is empty"
  (git-fixes).
- tty: mcf: MCF54418 has 10 UARTS (git-fixes).
- usb: gadget: aspeed_udc: fix device address configuration
  (git-fixes).
- usb: dwc3: core: remove lock of otg mode during gadget
  suspend/resume to avoid deadlock (git-fixes).
- usb: typec: ucsi: glink: fix child node release in probe
  function (git-fixes).
- usb: musb: da8xx: fix a resource leak in probe() (git-fixes).
- usb: atm: cxacru: fix endpoint checking in cxacru_bind()
  (git-fixes).
- usb: gadget: printer: fix races against disable (git-fixes).
- PCI/MSI: Fix UAF in msi_capability_init (git-fixes).
- commit a2ea5a9
* Sun Jun 30 2024 tiwai@suse.de
- crypto: deflate - Add aliases to deflate (bsc#1227190).
- commit 27ffd92
* Sun Jun 30 2024 tiwai@suse.de
- crypto: iaa - Account for cpu-less numa nodes (bsc#1227190).
- commit cd600aa
* Sun Jun 30 2024 tiwai@suse.de
- i2c: testunit: discard write requests while old command is
  running (git-fixes).
- i2c: testunit: don't erase registers after STOP (git-fixes).
- mmc: sdhci: Do not lock spinlock around mmc_gpio_get_ro()
  (git-fixes).
- mmc: sdhci: Do not invert write-protect twice (git-fixes).
- mmc: sdhci-brcmstb: check R1_STATUS for erase/trim/discard
  (git-fixes).
- mmc: sdhci-pci: Convert PCIBIOS_* return codes to errnos
  (git-fixes).
- commit 448487d
* Sat Jun 29 2024 tiwai@suse.de
- gpiolib: cdev: Disallow reconfiguration without direction
  (uAPI v1) (git-fixes).
- gpio: davinci: Validate the obtained number of IRQs (git-fixes).
- commit 919ebd1
* Fri Jun 28 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: fix the TXF mapping for BZ devices
  (bsc#1227149).
- wifi: iwlwifi: clear link_id in time_event (bsc#1227149).
- wifi: iwlwifi: mvm: fix a battery life regression (bsc#1227149).
- wifi: iwlwifi: remove extra kernel-doc (bsc#1227149).
- wifi: iwlwifi: mvm: skip adding debugfs symlink for reconfig
  (bsc#1227149).
- wifi: iwlwifi: replace ENOTSUPP with EOPNOTSUPP (bsc#1227149).
- wifi: iwlwifi: mvm: use the new command to clear the internal
  buffer (bsc#1227149).
- commit acd03db
* Fri Jun 28 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: add US/Canada MCC to API (bsc#1227149).
- Refresh
  patches.suse/wifi-iwlwifi-mvm-fix-warnings-from-dmi_get_system_in.patch.
- commit 70a9591
* Fri Jun 28 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: disallow puncturing in US/Canada
  (bsc#1227149).
- wifi: iwlwifi: Add rf_mapping of new wifi7 devices
  (bsc#1227149).
- wifi: iwlwifi: cleanup BT Shared Single Antenna code
  (bsc#1227149).
- wifi: iwlwifi: mvm: Do not warn if valid link pair was not found
  (bsc#1227149).
- wifi: iwlwifi: mvm: d3: avoid intermediate/early mutex unlock
  (bsc#1227149).
- wifi: iwlwifi: Don't mark DFS channels as NO-IR (bsc#1227149).
- wifi: iwlwifi: mvm: Allow DFS concurrent operation
  (bsc#1227149).
- wifi: iwlwifi: mvm: do not send STA_DISABLE_TX_CMD for newer
  firmware (bsc#1227149).
- wifi: iwlwifi: remove async command callback (bsc#1227149).
- commit 0205124
* Fri Jun 28 2024 tiwai@suse.de
- wifi: iwlwifi: fw: file: don't use [0] for variable arrays
  (bsc#1227149).
- wifi: iwlwifi: pcie: get_crf_id() can be void (bsc#1227149).
- wifi: iwlwifi: pcie: dump CSRs before removal (bsc#1227149).
- wifi: iwlwifi: pcie: clean up device removal work (bsc#1227149).
- wifi: iwlwifi: mvm: add a debugfs hook to clear the monitor data
  (bsc#1227149).
- wifi: iwlwifi: refactor RX tracing (bsc#1227149).
- wifi: iwlwifi: mvm: Correctly report TSF data in scan complete
  (bsc#1227149).
- wifi: iwlwifi: mvm: Use the link ID provided in scan request
  (bsc#1227149).
- wifi: iwlwifi: fw: replace deprecated strncpy with strscpy_pad
  (bsc#1227149).
- wifi: iwlwifi: fix system commands group ordering (bsc#1227149).
- commit 6cae420
* Fri Jun 28 2024 tiwai@suse.de
- wifi: iwlwifi: drop NULL pointer check in
  iwl_mvm_tzone_set_trip_temp() (bsc#1227149).
- wifi: iwlwifi: bump FW API to 86 for AX/BZ/SC devices
  (bsc#1227149).
- wifi: iwlwifi: read DSM func 2 for specific RF types
  (bsc#1227149).
- wifi: iwlwifi: mvm: show dump even for pldr_sync (bsc#1227149).
- wifi: iwlwifi: mvm: cycle FW link on chanctx removal
  (bsc#1227149).
- wifi: iwlwifi: trace full frames with TX status request
  (bsc#1227149).
- wifi: iwlwifi: fw: Add support for UATS table in UHB
  (bsc#1227149).
- wifi: iwlwifi: mvm: add a print when sending RLC command
  (bsc#1227149).
- wifi: iwlwifi: mvm: debugfs for fw system stats (bsc#1227149).
- wifi: iwlwifi: mvm: implement new firmware API for statistics
  (bsc#1227149).
- commit ed6b54f
* Fri Jun 28 2024 tiwai@suse.de
- wifi: iwlwifi: disable multi rx queue for 9000 (bsc#1227149).
- Refresh
  patches.suse/wifi-iwlwifi-mvm-include-link-ID-when-releasing-fram.patch.
- commit 9866ec0
* Fri Jun 28 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: fix regdb initialization (bsc#1227149).
- wifi: iwlwifi: mvm: simplify the reorder buffer (bsc#1227149).
- wifi: iwlwifi: mvm: Return success if link could not be removed
  (bsc#1227149).
- wifi: iwlwifi: add support for SNPS DPHYIP region type
  (bsc#1227149).
- wifi: iwlwifi: mvm: remove set_tim callback for MLD ops
  (bsc#1227149).
- wifi: iwlwifi: api: fix center_freq label in PHY diagram
  (bsc#1227149).
- wifi: iwlwifi: support link id in SESSION_PROTECTION_NOTIF
  (bsc#1227149).
- wifi: iwlwifi: support link_id in SESSION_PROTECTION cmd
  (bsc#1227149).
- wifi: iwlwifi: make time_events MLO aware (bsc#1227149).
- commit 1ea0f35
* Fri Jun 28 2024 tiwai@suse.de
- wifi: iwlwifi: add support for activating UNII-1 in WW via BIOS
  (bsc#1227149).
- wifi: iwlwifi: mvm: extend alive timeout to 2 seconds
  (bsc#1227149).
- wifi: iwlwifi: mvm: fix the PHY context resolution for p2p
  device (bsc#1227149).
- wifi: iwlwifi: mvm: fold the ref++ into iwl_mvm_phy_ctxt_add
  (bsc#1227149).
- wifi: iwlwifi: mvm: don't add dummy phy context (bsc#1227149).
- wifi: iwlwifi: mvm: cleanup MLO and non-MLO unification code
  (bsc#1227149).
- wifi: iwlwifi: mvm: implement ROC version 3 (bsc#1227149).
- wifi: iwlwifi: send EDT table to FW (bsc#1227149).
- wifi: iwlmvm: fw: Add new OEM vendor to tas approved list
  (bsc#1227149).
- wifi: iwlwifi: mvm: Fix unreachable code path (bsc#1227149).
- commit 50ebcaa
* Fri Jun 28 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: advertise support for SCS traffic
  description (bsc#1227149).
- Refresh
  patches.suse/wifi-iwlwifi-do-not-announce-EPCS-support.patch.
- commit 7208326
* Fri Jun 28 2024 tiwai@suse.de
- wifi: iwlwifi: add new RF support for wifi7 (bsc#1227149).
- wifi: iwlwifi: fw: increase fw_version string size
  (bsc#1227149).
- wifi: iwlwifi: check for kmemdup() return value in
  iwl_parse_tlv_firmware() (bsc#1227149).
- wifi: iwlwifi: fix the rf step and flavor bits range
  (bsc#1227149).
- wifi: iwlwifi: fw: Fix debugfs command sending (bsc#1227149).
- wifi: iwlwifi: mvm: add start mac ctdp sum calculation debugfs
  handler (bsc#1227149).
- wifi: iwlwifi: abort scan when rfkill on but device enabled
  (bsc#1227149).
- wifi: iwlwifi: mvm: Add basic link selection logic
  (bsc#1227149).
- wifi: iwlwifi: mei: return error from register when not built
  (bsc#1227149).
- commit fddf9eb
* Fri Jun 28 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: fix SB CFG check (bsc#1227149).
- wifi: iwlwifi: mvm: add a per-link debugfs (bsc#1227149).
- wifi: iwlwifi: mvm: rework debugfs handling (bsc#1227149).
- wifi: iwlwifi: add support for new ini region types
  (bsc#1227149).
- wifi: iwlwifi: Extract common prph mac/phy regions data dump
  logic (bsc#1227149).
- wifi: iwlwifi: bump FW API to 84 for AX/BZ/SC devices
  (bsc#1227149).
- wifi: iwlwifi: mvm: offload IGTK in AP if BIGTK is supported
  (bsc#1227149).
- wifi: iwlwifi: pcie: clean up WFPM control bits (bsc#1227149).
- wifi: iwlwifi: fix opmode start/stop race (bsc#1227149).
- wifi: iwlwifi: skip opmode start retries on dead transport
  (bsc#1227149).
- commit 36551d1
* Fri Jun 28 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: add support for new wowlan_info_notif
  (bsc#1227149).
- Refresh
  patches.suse/wifi-iwlwifi-mvm-d3-fix-IPN-byte-order.patch.
- commit 0b379ae
* Fri Jun 28 2024 tiwai@suse.de
- wifi: iwlwifi: pcie: propagate iwl_pcie_gen2_apm_init() error
  (bsc#1227149).
- wifi: iwlwifi: add mapping of a periphery register crf for WH RF
  (bsc#1227149).
- wifi: iwlwifi: mvm: check for iwl_mvm_mld_update_sta() errors
  (bsc#1227149).
- wifi: iwlwifi: mvm: support injection antenna control
  (bsc#1227149).
- wifi: iwlwifi: mvm: refactor TX rate handling (bsc#1227149).
- wifi: iwlwifi: mvm: make pldr_sync AX210 specific (bsc#1227149).
- wifi: iwlwifi: fail NIC access fast on dead NIC (bsc#1227149).
- wifi: iwlwifi: pcie: (re-)assign BAR0 on driver bind
  (bsc#1227149).
- commit 0882d6d
* Fri Jun 28 2024 tiwai@suse.de
- wifi: iwlwifi: implement enable/disable for China 2022
  regulatory (bsc#1227149).
- wifi: iwlwifi: mvm: handle link-STA allocation in restart
  (bsc#1227149).
- wifi: iwlwifi: mvm: iterate active links for STA queues
  (bsc#1227149).
- wifi: iwlwifi: mvm: support set_antenna() (bsc#1227149).
- wifi: iwlwifi: mvm: add a debug print when we get a BAR
  (bsc#1227149).
- wifi: iwlwifi: mvm: move listen interval to constants
  (bsc#1227149).
- wifi: iwlwifi: no power save during transition to D3
  (bsc#1227149).
- wifi: iwlwifi: update context info structure definitions
  (bsc#1227149).
- wifi: iwlwifi: mvm: fix recovery flow in CSA (bsc#1227149).
- wifi: iwlwifi: mvm: enable FILS DF Tx on non-PSC channel
  (bsc#1227149).
- commit 5c7efaf
* Fri Jun 28 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: make "pldr_sync" mode effective
  (bsc#1227149).
- wifi: iwlwifi: mvm: log dropped frames (bsc#1227149).
- wifi: iwlwifi: fw: disable firmware debug asserts (bsc#1227149).
- wifi: iwlwifi: remove dead-code (bsc#1227149).
- wifi: iwlwifi: pcie: enable TOP fatal error interrupt
  (bsc#1227149).
- wifi: iwlwifi: pcie: give up mem read if HW is dead
  (bsc#1227149).
- wifi: iwlwifi: pcie: rescan bus if no parent (bsc#1227149).
- wifi: iwlwifi: mvm: reduce maximum RX A-MPDU size (bsc#1227149).
- wifi: iwlwifi: mvm: check link more carefully (bsc#1227149).
- wifi: iwlwifi: mvm: move RU alloc B2 placement (bsc#1227149).
- commit 8aa4ff8
* Fri Jun 28 2024 jgross@suse.com
- virtio: delete vq in vp_find_vqs_msix() when request_irq()
  fails (CVE-2024-37353 bsc#1226875).
- commit 4591439
* Fri Jun 28 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: fix kernel-doc (bsc#1227149).
- Refresh
  patches.suse/wifi-iwlwifi-mvm-ensure-offloading-TID-queue-exists.patch.
- commit 68376c9
* Fri Jun 28 2024 tiwai@suse.de
- wifi: iwlwifi: pcie: fix kernel-doc issues (bsc#1227149).
- Refresh
  patches.suse/wifi-iwlwifi-pcie-fix-RB-status-reading.patch.
- commit f106797
* Fri Jun 28 2024 tiwai@suse.de
- wifi: iwlwifi: fw: reconstruct the API/CAPA enum number
  (bsc#1227149).
- wifi: iwlwifi: dvm: remove kernel-doc warnings (bsc#1227149).
- wifi: iwlwifi: queue: fix kernel-doc (bsc#1227149).
- wifi: iwlwifi: fix some kernel-doc issues (bsc#1227149).
- wifi: iwlwifi: mvm: disconnect long CSA only w/o alternative
  (bsc#1227149).
- wifi: iwlwifi: mvm: increase session protection after CSA
  (bsc#1227149).
- wifi: iwlwifi: mvm: support CSA with MLD (bsc#1227149).
- wifi: iwlmei: don't send nic info with invalid mac address
  (bsc#1227149).
- commit 85cbe83
* Fri Jun 28 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: support flush on AP interfaces
  (bsc#1227149).
- Refresh
  patches.suse/wifi-iwlwifi-mvm-change-iwl_mvm_flush_sta-API.patch.
- commit 908ff7c
* Fri Jun 28 2024 tiwai@suse.de
- wifi: iwlmei: send driver down SAP message only if wiamt is
  enabled (bsc#1227149).
- wifi: iwlmei: send HOST_GOES_DOWN message even if wiamt is
  disabled (bsc#1227149).
- wifi: iwlmei: don't send SAP messages if AMT is disabled
  (bsc#1227149).
- wifi: iwlwifi: remove memory check for LMAC error address
  (bsc#1227149).
- wifi: iwlwifi: mvm: enable HE TX/RX <242 tone RU on new RFs
  (bsc#1227149).
- wifi: iwlwifi: add Razer to ppag approved list (bsc#1227149).
- wifi: iwlwifi: pcie: point invalid TFDs to invalid data
  (bsc#1227149).
- wifi: iwlwifi: queue: move iwl_txq_gen2_set_tb() up
  (bsc#1227149).
- wifi: iwlwifi: pcie: move gen1 TB handling to header
  (bsc#1227149).
- commit 92ab309
* Fri Jun 28 2024 tiwai@suse.de
- wifi: iwlwifi: remove 'def_rx_queue' struct member
  (bsc#1227149).
- wifi: iwlwifi: pcie: clean up gen1/gen2 TFD unmap (bsc#1227149).
- wifi: iwlwifi: remove WARN from read_mem32() (bsc#1227149).
- wifi: iwlwifi: api: fix a small upper/lower-case typo
  (bsc#1227149).
- wifi: iwlwifi: mvm: advertise MLO only if EHT is enabled
  (bsc#1227149).
- commit aa9a391
* Fri Jun 28 2024 tiwai@suse.de
- Add alt-commit to iwlwifi patches
- commit 865aa7a
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: fix unsolicited broadcast probe config
  (bsc#1227149).
- wifi: mac80211: initialize SMPS mode correctly (bsc#1227149).
- wifi: mac80211: fix driver debugfs for vif type change
  (bsc#1227149).
- wifi: mac80211: improve CSA/ECSA connection refusal
  (bsc#1227149).
- wifi: cfg80211: detect stuck ECSA element in probe resp
  (bsc#1227149).
- wifi: mac80211: add/remove driver debugfs entries as appropriate
  (bsc#1227149).
- wifi: mac80211: do not re-add debugfs entries during resume
  (bsc#1227149).
- commit 769161a
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: remove redundant ML element check (bsc#1227149).
- wifi: cfg80211: Update the default DSCP-to-UP mapping
  (bsc#1227149).
- wifi: mac80211: fix spelling typo in comment (bsc#1227149).
- wifi: mac80211: add a driver callback to check active_links
  (bsc#1227149).
- wifi: mac80211: fix advertised TTLM scheduling (bsc#1227149).
- wifi: cfg80211: avoid double free if updating BSS fails
  (bsc#1227149).
- commit e8bab13
* Fri Jun 28 2024 tiwai@suse.de
- wifi: cfg80211: handle UHB AP and STA power type (bsc#1227149).
- commit 6021aa4
* Fri Jun 28 2024 tiwai@suse.de
- wifi: cfg80211: ensure cfg80211_bss_update frees IEs on error
  (bsc#1227149).
- wifi: mac80211: allow 64-bit radiotap timestamps (bsc#1227149).
- wifi: mac80211: rework RX timestamp flags (bsc#1227149).
- wifi: mac80211: Schedule regulatory channels check on bandwith
  change (bsc#1227149).
- wifi: cfg80211: Schedule regulatory check on BSS STA channel
  change (bsc#1227149).
- wifi: cfg80211: reg: Support P2P operation on DFS channels
  (bsc#1227149).
- wifi: mac80211: Skip association timeout update after comeback
  rejection (bsc#1227149).
- wifi: mac80211: address some kerneldoc warnings (bsc#1227149).
- wifi: cfg80211: address several kerneldoc warnings
  (bsc#1227149).
- commit bc44e06
* Fri Jun 28 2024 tiwai@suse.de
- wifi: cfg80211: generate an ML element for per-STA profiles
  (bsc#1227149).
- Refresh
  patches.suse/wifi-cfg80211-parse-all-ML-elements-in-an-ML-probe-r.patch.
- commit d924102
* Fri Jun 28 2024 tiwai@suse.de
- wifi: cfg80211: introduce cfg80211_ssid_eq() (bsc#1227149).
- wifi: mac80211: sta_info.c: fix sentence grammar (bsc#1227149).
- wifi: mac80211: rx.c: fix sentence grammar (bsc#1227149).
- wifi: cfg80211: fix spelling & punctutation (bsc#1227149).
- wifi: cfg80211: sort certificates in build (bsc#1227149).
- wifi: mac80211: drop spurious WARN_ON() in
  ieee80211_ibss_csa_beacon() (bsc#1227149).
- wifi: mac80211: don't set ESS capab bit in assoc request
  (bsc#1227149).
- wifi: cfg80211: consume both probe response and beacon IEs
  (bsc#1227149).
- wifi: cfg80211: Replace ENOTSUPP with EOPNOTSUPP (bsc#1227149).
- commit 5e5ecdb
* Fri Jun 28 2024 tiwai@suse.de
- wifi: cfg80211: OWE DH IE handling offload (bsc#1227149).
- commit 58c8e33
* Fri Jun 28 2024 tiwai@suse.de
- wifi: cfg80211: add BSS usage reporting (bsc#1227149).
- Refresh
  patches.suse/wifi-cfg80211-parse-all-ML-elements-in-an-ML-probe-r.patch.
- commit 5b2693d
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: Replace ENOTSUPP with EOPNOTSUPP (bsc#1227149).
- wifi: mac80211: add a flag to disallow puncturing (bsc#1227149).
- wifi: cfg80211: Add support for setting TID to link mapping
  (bsc#1227149).
- wifi: mac80211: update some locking documentation (bsc#1227149).
- wifi: nl80211: Extend del pmksa support for SAE and OWE security
  (bsc#1227149).
- wifi: mac80211: cleanup airtime arithmetic with
  ieee80211_sta_keep_active() (bsc#1227149).
- wifi: cfg80211: expose nl80211_chan_width_to_mhz for wide
  sharing (bsc#1227149).
- wifi: cfg80211: make RX assoc data const (bsc#1227149).
- commit e4b61c4
* Fri Jun 28 2024 tiwai@suse.de
- wifi: cfg80211: Extend support for scanning while MLO connected
  (bsc#1227149).
- commit b4c9412
* Fri Jun 28 2024 tiwai@suse.de
- wifi: cfg80211: hold wiphy mutex for send_interface
  (bsc#1227149).
- Refresh
  patches.suse/wifi-cfg80211-fix-missing-interfaces-when-dumping.patch.
- commit 2123690
* Fri Jun 28 2024 tiwai@suse.de
- wifi: cfg80211: fix CQM for non-range use (bsc#1227149).
- commit 3c8ba48
* Fri Jun 28 2024 tiwai@suse.de
- wifi: nl80211: refactor nl80211_send_mlme_event() arguments
  (bsc#1227149).
- wifi: mac80211: Extend support for scanning while MLO connected
  (bsc#1227149).
- wifi: mac80211: use wiphy locked debugfs for sdata/link
  (bsc#1227149).
- wifi: mac80211: use wiphy locked debugfs helpers for agg_status
  (bsc#1227149).
- wifi: cfg80211: add locked debugfs wrappers (bsc#1227149).
- wifi: mac80211: drop robust action frames before assoc
  (bsc#1227149).
- wifi: cfg80211: Allow AP/P2PGO to indicate port authorization
  to peer STA/P2PClient (bsc#1227149).
- commit 03e12a0
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: fix another key installation error path
  (bsc#1227149).
- wifi: mac80211: rename struct cfg80211_rx_assoc_resp to
  cfg80211_rx_assoc_resp_data (bsc#1227149).
- wifi: mac80211: rename ieee80211_tx_status() to
  ieee80211_tx_status_skb() (bsc#1227149).
- wifi: mac80211: fix change_address deadlock during unregister
  (bsc#1227149).
- wifi: mac80211: Add __counted_by for struct ieee802_11_elems
  and use struct_size() (bsc#1227149).
- wifi: remove unused argument of ieee80211_get_tdls_action()
  (bsc#1227149).
- wifi: mac80211: fix header kernel-doc typos (bsc#1227149).
- wifi: cfg80211: fix header kernel-doc typos (bsc#1227149).
- wifi: mac80211: add link id to mgd_prepare_tx() (bsc#1227149).
- wifi: mac80211: Check if we had first beacon with relevant links
  (bsc#1227149).
- commit fa14599
* Fri Jun 28 2024 jgross@suse.com
- kABI fix of KVM: x86/pmu: Prioritize VMX interception over
- commit 1f1d114
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: flush STA queues on unauthorization
  (bsc#1227149).
- wifi: mac80211: purge TX queues in flush_queues flow
  (bsc#1227149).
- wifi: cfg80211: wext: convert return value to kernel-doc
  (bsc#1227149).
- wifi: mac80211: fix a expired vs. cancel race in roc
  (bsc#1227149).
- wifi: mac80211: make mgd_protect_tdls_discover MLO-aware
  (bsc#1227149).
- wifi: cfg80211: Fix typo in documentation (bsc#1227149).
- wifi: cfg80211: Handle specific BSSID in 6GHz scanning
  (bsc#1227149).
- wifi: mac80211: mesh: fix some kdoc warnings (bsc#1227149).
- wifi: cfg80211: Include operating class 137 in 6GHz band
  (bsc#1227149).
- wifi: mac80211: Rename and update
  IEEE80211_VIF_DISABLE_SMPS_OVERRIDE (bsc#1227149).
- commit 585676b
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: split ieee80211_drop_unencrypted_mgmt() return
  value (bsc#1227149).
- commit 3835ef2
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: fix error path key leak (bsc#1227149).
- Refresh patches.suse/wifi-mac80211-remove-key_mtx.patch.
- commit 3b93fe9
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: fix potential key leak (bsc#1227149).
- Refresh patches.suse/wifi-mac80211-remove-key_mtx.patch.
- commit 9fa5ec3
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: handle debugfs when switching to/from MLO
  (bsc#1227149).
- wifi: mac80211: add a driver callback to add vif debugfs
  (bsc#1227149).
- wifi: mac80211: cleanup auth_data only if association continues
  (bsc#1227149).
- wifi: mac80211: add back SPDX identifier (bsc#1227149).
- wifi: mac80211: fix ieee80211_drop_unencrypted_mgmt return
  type/value (bsc#1227149).
- wifi: mac80211: expand __ieee80211_data_to_8023() status
  (bsc#1227149).
- wifi: mac80211: remove RX_DROP_UNUSABLE (bsc#1227149).
- commit e0a6a5e
* Fri Jun 28 2024 tiwai@suse.de
- wifi: cfg80211: add local_state_change to deauth trace
  (bsc#1227149).
- wifi: mac80211: reject MLO channel configuration if not
  supported (bsc#1227149).
- wifi: mac80211: report per-link error during association
  (bsc#1227149).
- wifi: cfg80211: report per-link errors during association
  (bsc#1227149).
- wifi: mac80211: support antenna control in injection
  (bsc#1227149).
- wifi: mac80211: support handling of advertised TID-to-link
  mapping (bsc#1227149).
- wifi: mac80211: add support for parsing TID to Link mapping
  element (bsc#1227149).
- wifi: mac80211: Notify the low level driver on change in MLO
  valid links (bsc#1227149).
- wifi: mac80211: describe return values in kernel-doc
  (bsc#1227149).
- wifi: cfg80211: reg: describe return values in kernel-doc
  (bsc#1227149).
- commit df6c84a
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: allow for_each_sta_active_link() under RCU
  (bsc#1227149).
- wifi: mac80211: relax RCU check in for_each_vif_active_link()
  (bsc#1227149).
- wifi: mac80211: don't connect to an AP while it's in a CSA
  process (bsc#1227149).
- wifi: mac80211: update the rx_chains after set_antenna()
  (bsc#1227149).
- wifi: mac80211: use bandwidth indication element for CSA
  (bsc#1227149).
- wifi: cfg80211: split struct cfg80211_ap_settings (bsc#1227149).
- wifi: mac80211: ethtool: always hold wiphy mutex (bsc#1227149).
- wifi: cfg80211: make read-only array centers_80mhz static const
  (bsc#1227149).
- wifi: cfg80211: save power spectral density(psd) of regulatory
  rule (bsc#1227149).
- wifi: cfg80211: fix kernel-doc for wiphy_delayed_work_flush()
  (bsc#1227149).
- commit 7f3b9af
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: Sanity check tx bitrate if not provided by
  driver (bsc#1227149).
- wifi: cfg80211: export DFS CAC time and usable state helper
  functions (bsc#1227149).
- wifi: cfg80211: call reg_call_notifier on beacon hints
  (bsc#1227149).
- wifi: cfg80211: allow reg update by driver even if wiphy->regd
  is set (bsc#1227149).
- wifi: mac80211: additions to change_beacon() (bsc#1227149).
- wifi: nl80211: additions to NL80211_CMD_SET_BEACON
  (bsc#1227149).
- wifi: cfg80211: modify prototype for change_beacon
  (bsc#1227149).
- wifi: mac80211: fixes in FILS discovery updates (bsc#1227149).
- wifi: nl80211: fixes to FILS discovery updates (bsc#1227149).
- wifi: lib80211: remove unused variables iv32 and iv16
  (bsc#1227149).
- commit 67ccb18
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: fix various kernel-doc issues (bsc#1227149).
- Refresh
  patches.suse/wifi-mac80211-track-capability-opmode-NSS-separately.patch.
- commit b1c042f
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: remove shifted rate support (bsc#1227149).
- wifi: cfg80211: remove scan_width support (bsc#1227149).
- wifi: wext: avoid extra calls to strlen() in ieee80211_bss()
  (bsc#1227149).
- wifi: mac80211: fix channel switch link data (bsc#1227149).
- wifi: mac80211: Do not force off-channel for management Tx
  with MLO (bsc#1227149).
- wifi: mac80211: take MBSSID/EHT data also from probe resp
  (bsc#1227149).
- wifi: mac80211: Print local link address during authentication
  (bsc#1227149).
- wifi: cfg80211: reg: fix various kernel-doc issues
  (bsc#1227149).
- wifi: mac80211: remove unnecessary struct forward declaration
  (bsc#1227149).
- commit 5936128
* Fri Jun 28 2024 tiwai@suse.de
- wifi: cfg80211: annotate iftype_data pointer with sparse
  (bsc#1227149).
- Refresh
  patches.suse/wifi-cfg80211-fix-wiphy-delayed-work-queueing.patch.
- commit 031b8a7
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: add more warnings about inserting sta info
  (bsc#1227149).
- wifi: mac80211: add support for mld in ieee80211_chswitch_done
  (bsc#1227149).
- wifi: mac80211: fix BA session teardown race (bsc#1227149).
- wifi: mac80211: fix TXQ error path and cleanup (bsc#1227149).
- commit 8e5b425
* Fri Jun 28 2024 tiwai@suse.de
- wifi: cfg80211: remove wdev mutex (bsc#1227149).
- commit 4d7cf99
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: set wiphy for virtual monitors (bsc#1227149).
- commit 6022030
* Fri Jun 28 2024 vkarasulli@suse.de
- iommu/amd: Fix sysfs leak in iommu init (git-fixes).
- commit 5b11e2a
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: remove key_mtx (bsc#1227149).
- commit 36d4ad3
* Fri Jun 28 2024 vkarasulli@suse.de
- iommu: Return right value in iommu_sva_bind_device()
  (git-fixes).
- commit 769b149
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: remove sta_mtx (bsc#1227149).
- Refresh
  patches.suse/wifi-mac80211-check-if-the-existing-link-config-rema.patch.
- Refresh
  patches.suse/wifi-mac80211-don-t-re-add-debugfs-during-reconfig.patch.
- commit 5b967e8
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: reduce iflist_mtx (bsc#1227149).
- wifi: mac80211: remove local->mtx (bsc#1227149).
- wifi: mac80211: remove ampdu_mlme.mtx (bsc#1227149).
- wifi: mac80211: remove chanctx_mtx (bsc#1227149).
- wifi: mac80211: take wiphy lock for MAC addr change
  (bsc#1227149).
- wifi: mac80211: extend wiphy lock in interface removal
  (bsc#1227149).
- wifi: mac80211: hold wiphy_lock around concurrency checks
  (bsc#1227149).
- wifi: mac80211: ethtool: hold wiphy mutex (bsc#1227149).
- commit b3dacec
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: check wiphy mutex in ops (bsc#1227149).
- Refresh
  patches.suse/wifi-mac80211-do-not-pass-AP_VLAN-vif-pointer-to-dri.patch.
- commit 3b00636
* Fri Jun 28 2024 tiwai@suse.de
- wifi: cfg80211: check wiphy mutex is held for wdev mutex
  (bsc#1227149).
- wifi: cfg80211: hold wiphy lock in
  cfg80211_any_wiphy_oper_chan() (bsc#1227149).
- wifi: cfg80211: sme: hold wiphy lock for wdev iteration
  (bsc#1227149).
- wifi: cfg80211: reg: hold wiphy mutex for wdev iteration
  (bsc#1227149).
- wifi: mac80211: move color change finalize to wiphy work
  (bsc#1227149).
- wifi: mac80211: move CSA finalize to wiphy work (bsc#1227149).
- wifi: mac80211: move filter reconfig to wiphy work
  (bsc#1227149).
- wifi: mac80211: move tspec work to wiphy work (bsc#1227149).
- wifi: mac80211: move key tailroom work to wiphy work
  (bsc#1227149).
- commit d930910
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: move dynamic PS to wiphy work (bsc#1227149).
- Refresh
  patches.suse/wifi-mac80211-move-sched-scan-stop-work-to-wiphy-wor.patch.
- commit 6350819
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: move DFS CAC work to wiphy work (bsc#1227149).
- Refresh
  patches.suse/wifi-mac80211-move-radar-detect-work-to-wiphy-work.patch.
- commit 46fc728
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: move TDLS work to wiphy work (bsc#1227149).
- wifi: mac80211: move link activation work to wiphy work
  (bsc#1227149).
- wifi: mac80211: lock wiphy in IP address notifier (bsc#1227149).
- wifi: mac80211: move monitor work to wiphy work (bsc#1227149).
- wifi: mac80211: add more ops assertions (bsc#1227149).
- wifi: mac80211: convert A-MPDU work to wiphy work (bsc#1227149).
- wifi: mac80211: flush wiphy work where appropriate
  (bsc#1227149).
- wifi: cfg80211: check RTNL when iterating devices (bsc#1227149).
- commit 425f8ad
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: lock wiphy for aggregation debugfs
  (bsc#1227149).
- wifi: mac80211: hold wiphy lock in netdev/link debugfs
  (bsc#1227149).
- wifi: mac80211: debugfs: lock wiphy instead of RTNL
  (bsc#1227149).
- wifi: mac80211: fix SMPS status handling (bsc#1227149).
- wifi: mac80211: Fix SMPS handling in the context of MLO
  (bsc#1227149).
- wifi: mac80211: rework ack_frame_id handling a bit
  (bsc#1227149).
- wifi: mac80211: tx: clarify conditions in if statement
  (bsc#1227149).
- wifi: mac80211: Do not include crypto/algapi.h (bsc#1227149).
- wifi: cfg80211: improve documentation for flag fields
  (bsc#1227149).
- wifi: nl80211: Remove unused declaration
  nl80211_pmsr_dump_results() (bsc#1227149).
- commit 75d4c97
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: mesh: Remove unused function declaration
  mesh_ids_set_default() (bsc#1227149).
- commit b3033c6
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mac80211: Remove unused function declarations
  (bsc#1227149).
- Refresh
  patches.suse/wifi-mac80211-move-radar-detect-work-to-wiphy-work.patch.
- commit 343f020
* Fri Jun 28 2024 jwiesner@suse.de
- x86/tsc: Trust initial offset in architectural TSC-adjust MSRs
  (bsc#1222015 bsc#1226962).
- commit ba98363
* Fri Jun 28 2024 jgross@suse.com
- KVM: x86/pmu: Prioritize VMX interception over #GP on RDPMC
  due to bad index (bsc#1226158).
- commit fdb5ce1
* Fri Jun 28 2024 bdas@suse.de
- net/9p: fix uninit-value in p9_client_rpc() (CVE-2024-39301
  bsc#1226994).
- commit d8af728
* Fri Jun 28 2024 iivanov@suse.de
- arm64/io: add constant-argument check (bsc#1226502 git-fixes)
- commit 45e8b78
* Fri Jun 28 2024 tiwai@suse.de
- struct acpi_ec kABI workaround (git-fixes).
- commit 3605f74
* Fri Jun 28 2024 tiwai@suse.de
- wifi: mt76: mt7921s: fix potential hung tasks during chip
  recovery (stable-fixes).
- commit d9504b4
* Fri Jun 28 2024 tiwai@suse.de
- drm/drm_file: Fix pid refcounting race (git-fixes).
- drm/i915/gt: Fix potential UAF by revoke of fence registers
  (git-fixes).
- drm/amdgpu: Fix pci state save during mode-1 reset (git-fixes).
- drm/panel: simple: Add missing display timing flags for KOE
  TX26D202VM0BWA (git-fixes).
- drm/fbdev-dma: Only set smem_start is enable per module option
  (git-fixes).
- net: usb: ax88179_178a: improve link status logs (git-fixes).
- net: phy: micrel: add Microchip KSZ 9477 to the device table
  (git-fixes).
- batman-adv: Don't accept TT entries for out-of-spec VIDs
  (git-fixes).
- can: mcp251xfd: fix infinite loop when xmit fails (git-fixes).
- net: can: j1939: recover socket queue on CAN bus error during
  BAM transmission (git-fixes).
- net: can: j1939: Initialize unused data in j1939_send_one()
  (git-fixes).
- net: can: j1939: enhanced error handling for tightly received
  RTS messages in xtp_rx_rts_session_new (git-fixes).
- ASoC: fsl-asoc-card: set priv->pdev before using it (git-fixes).
- ASoC: amd: acp: remove i2s configuration check in
  acp_i2s_probe() (git-fixes).
- ASoC: amd: acp: add a null check for chip_pdev structure
  (git-fixes).
- ASoC: q6apm-lpass-dai: close graph on prepare errors
  (git-fixes).
- ASoC: rockchip: i2s-tdm: Fix trcm mode by setting clock on
  right mclk (git-fixes).
- ALSA: seq: Fix missing MSB in MIDI2 SPP conversion (git-fixes).
- ALSA: hda/realtek: Fix conflicting quirk for PCI SSID 17aa:3820
  (git-fixes).
- ALSA: seq: Fix missing channel at encoding RPN/NRPN MIDI2
  messages (git-fixes).
- drm/amdgpu: fix UBSAN warning in kv_dpm.c (stable-fixes).
- drm/radeon: fix UBSAN warning in kv_dpm.c (stable-fixes).
- ACPI: EC: Evaluate orphan _REG under EC device (git-fixes).
- serial: exar: adding missing CTI and Exar PCI ids
  (stable-fixes).
- serial: imx: Introduce timeout when waiting on transmitter empty
  (stable-fixes).
- usb: gadget: function: Remove usage of the deprecated
  ida_simple_xx() API (stable-fixes).
- usb: typec: ucsi_glink: drop special handling for CCI_BUSY
  (stable-fixes).
- usb: dwc3: pci: Don't set "linux,phy_charger_detect" property
  on Lenovo Yoga Tab2 1380 (stable-fixes).
- usb: misc: uss720: check for incompatible versions of the
  Belkin F5U002 (stable-fixes).
- usb: gadget: uvc: configfs: ensure guid to be valid before set
  (stable-fixes).
- cpufreq: amd-pstate: fix memory leak on CPU EPP exit
  (stable-fixes).
- ACPI: EC: Install address space handler at the namespace root
  (stable-fixes).
- PCI/PM: Avoid D3cold for HP Pavilion 17 PC/1972 PCIe Ports
  (stable-fixes).
- power: supply: cros_usbpd: provide ID table for avoiding
  fallback match (stable-fixes).
- platform/x86: toshiba_acpi: Add quirk for buttons on Z830
  (stable-fixes).
- ASoC: Intel: sof-sdw: really remove FOUR_SPEAKER quirk
  (git-fixes).
- ASoC: Intel: sof_sdw: add quirk for Dell SKU 0C0F
  (stable-fixes).
- ASoC: Intel: sof_sdw: add JD2 quirk for HP Omen 14
  (stable-fixes).
- drm/lima: mask irqs in timeout path before hard reset
  (stable-fixes).
- drm/lima: add mask irq callback to gp and pp (stable-fixes).
- drm/amd/display: revert Exit idle optimizations before HDCP
  execution (stable-fixes).
- drm/amd/display: Exit idle optimizations before HDCP execution
  (stable-fixes).
- Bluetooth: ath3k: Fix multiple issues reported by checkpatch.pl
  (stable-fixes).
- batman-adv: bypass empty buckets in batadv_purge_orig_ref()
  (stable-fixes).
- ssb: Fix potential NULL pointer dereference in
  ssb_device_uevent() (stable-fixes).
- HID: Add quirk for Logitech Casa touchpad (stable-fixes).
- ACPI: x86: Add PNP_UART1_SKIP quirk for Lenovo Blade2 tablets
  (stable-fixes).
- crypto: hisilicon/qm - Add the err memory release process to
  qm uninit (stable-fixes).
- crypto: hisilicon/sec - Fix memory leak for sec resource release
  (stable-fixes).
- commit bbedf42
* Thu Jun 27 2024 tbogendoerfer@suse.de
- net/mlx5: Fix MTMP register capability offset in MCAM register
  (git-fixes).
- bonding: fix oops during rmmod (CVE-2024-39296 bsc#1226989).
- e1000e: change usleep_range to udelay in PHY mdic access
  (CVE-2024-39296 bsc#1226989).
- dpll: spec: use proper enum for pin capabilities attribute
  (git-fixes).
- tools: ynl: fix handling of multiple mcast groups (git-fixes).
- tools: ynl: don't leak mcast_groups on init error (git-fixes).
- tools: ynl: make sure we always pass yarg to mnl_cb_run
  (git-fixes).
- commit 164182f
* Thu Jun 27 2024 vkarasulli@suse.de
- iommu/vt-d: Fix WARN_ON in iommu probe path (git-fixes).
- iommu/vt-d: Use device rbtree in iopf reporting path
  (bsc#1224751 CVE-2024-35843).
- iommu/vt-d: Use rbtree to track iommu probed devices
  (git-fixes).
- commit 5f366a7
* Thu Jun 27 2024 ailiop@suse.com
- nilfs2: fix potential kernel bug due to lack of writeback flag
  waiting (bsc#1227066 CVE-2024-37078).
- commit bd6df7f
* Thu Jun 27 2024 tiwai@suse.de
- kABI workaround for FPGA changes (CVE-2024-35247 bsc#1226948
  CVE-2024-36479 bsc#1226949 CVE-2024-37021 bsc#1226950).
- commit 4b32e86
* Thu Jun 27 2024 tiwai@suse.de
- fpga: region: add owner module and take its refcount
  (CVE-2024-35247 bsc#1226948).
- Refresh patches.suse/fpga-add-kABI-padding.patch.
- commit 670051c
* Thu Jun 27 2024 tiwai@suse.de
- fpga: manager: add owner module and take its refcount
  (CVE-2024-37021 bsc#1226950).
- Refresh patches.suse/fpga-add-kABI-padding.patch.
- commit 34a2533
* Thu Jun 27 2024 tiwai@suse.de
- fpga: bridge: add owner module and take its refcount
  (CVE-2024-36479 bsc#1226949).
- commit 545627b
* Thu Jun 27 2024 nik.borisov@suse.com
- Fix build failure on powerpc
  Refresh
  patches.suse/powerpc-uaccess-Use-YZ-asm-constraint-for-ld.patch.
- commit 4cafc95
* Thu Jun 27 2024 iivanov@suse.de
- kabi: Use __iowriteXX_copy_inlined for in-kernel modules (bsc#1226502)
- commit 54c3656
* Thu Jun 27 2024 iivanov@suse.de
- net: hns3: Remove io_stop_wc() calls after __iowrite64_copy() (bsc#1226502)
- commit 5ea0ed2
* Thu Jun 27 2024 iivanov@suse.de
- arm64/io: Provide a WC friendly __iowriteXX_copy() (bsc#1226502)
- commit a39a193
* Thu Jun 27 2024 iivanov@suse.de
- s390: Stop using weak symbols for __iowrite64_copy() (bsc#1226502)
- commit 4a798a5
* Thu Jun 27 2024 iivanov@suse.de
- s390: Implement __iowrite32_copy() (bsc#1226502)
- commit 80e689b
* Thu Jun 27 2024 iivanov@suse.de
- x86: Stop using weak symbols for __iowrite32_copy() (bsc#1226502)
- commit 894aede
* Thu Jun 27 2024 tbogendoerfer@suse.de
- net/mlx5: Use mlx5_ipsec_rx_status_destroy to correctly delete
  status rules (CVE-2024-36281 bsc#1226799).
- commit a7197fd
* Wed Jun 26 2024 lhenriques@suse.de
- ceph: switch to use cap_delay_lock for the unlink delay list
  (bsc#1226022).
- ceph: break the check delayed cap loop every 5s (bsc#1226022).
- ceph: add ceph_cap_unlink_work to fire check_caps() immediately
  (bsc#1226022).
- ceph: always queue a writeback when revoking the Fb caps
  (bsc#1226022).
- ceph: always check dir caps asynchronously (bsc#1226022).
- commit 7eb372a
* Wed Jun 26 2024 ptesarik@suse.com
- arm64: mm: Don't remap pgtables for allocate vs populate
  (jsc#PED-8688).
- arm64: mm: Batch dsb and isb when populating pgtables
  (jsc#PED-8688).
- arm64: mm: Don't remap pgtables per-cont(pte|pmd) block
  (jsc#PED-8688).
- commit fdec960
* Wed Jun 26 2024 jack@suse.cz
- epoll: be better about file lifetimes (bsc#1226610
  CVE-2024-38580).
- commit 4ff3c13
* Wed Jun 26 2024 jack@suse.cz
- null_blk: Fix return value of nullb_device_power_store()
  (bsc#1226841 CVE-2024-36478).
- commit f213a2a
* Wed Jun 26 2024 rgoldwyn@suse.com
- f2fs: multidev: fix to recognize valid zero block address (bsc#1226879, CVE-2024-38636).
- commit ec1ded3
* Wed Jun 26 2024 mfranc@suse.cz
- s390/cpacf: Make use of invalid opcode produce a link error
  (git-fixes bsc#1227072).
- commit 24c76d1
* Wed Jun 26 2024 mfranc@suse.cz
- s390/ap: Fix crash in AP internal function modify_bitmap()
  (CVE-2024-38661 bsc#1226996 git-fixes).
- commit 456a41d
* Wed Jun 26 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add sockopt case to verify prog_type (bsc#1226789
  CVE-2024-38564).
- selftests/bpf: Extend sockopt tests to use BPF_LINK_CREATE
  (bsc#1226789 CVE-2024-38564).
- bpf: Add BPF_PROG_TYPE_CGROUP_SKB attach type enforcement in
  BPF_LINK_CREATE (bsc#1226789 CVE-2024-38564).
- commit 2f12314
* Wed Jun 26 2024 shung-hsi.yu@suse.com
- bpf: Fix verifier assumptions about socket->sk (bsc#1226790
  CVE-2024-38566).
- commit dc586b3
* Tue Jun 25 2024 lduncan@suse.com
- scsi: qedf: Ensure the copied buf is NUL terminated (bsc#1226758
  CVE-2024-38559).
- scsi: bfa: Ensure the copied buf is NUL terminated (bsc#1226786
  CVE-2024-38560).
- scsi: bnx2fc: Remove spin_lock_bh while releasing resources
  after upload (bsc#1224767 CVE-2024-36919).
- commit 3cabc93
* Tue Jun 25 2024 dwagner@suse.de
- nvme: do not retry authentication failures (bsc#1186716).
- nvme-fabrics: short-circuit reconnect retries (bsc#1186716).
- nvme: return kernel error codes for admin queue connect
  (bsc#1186716).
- nvmet: return DHCHAP status codes from nvmet_setup_auth()
  (bsc#1186716).
- nvmet: lock config semaphore when accessing DH-HMAC-CHAP key
  (bsc#1186716).
- commit ac2b954
* Tue Jun 25 2024 davide.benini@suse.com
- net: sched: sch_multiq: fix possible OOB write in multiq_tune()
  (CVE-2024-36978 bsc#1226514).
- commit 3b6fd26
* Tue Jun 25 2024 dwagner@suse.de
- nvmet: prevent sprintf() overflow in nvmet_subsys_nsid_exists()
  (git-fixes).
- commit 556ea4a
* Tue Jun 25 2024 jack@suse.cz
- null_blk: fix null-ptr-dereference while configuring 'power'
  and 'submit_queues' (bsc#1226841 CVE-2024-36478).
- commit d0b4b2a
* Tue Jun 25 2024 jack@suse.cz
- block: fix overflow in blk_ioctl_discard() (bsc#1225770
  CVE-2024-36917).
- commit bbdd816
* Tue Jun 25 2024 jack@suse.cz
- mm: Avoid overflows in dirty throttling logic (bsc#1222364
  CVE-2024-26720).
- commit 77e301c
* Tue Jun 25 2024 davide.benini@suse.com
- net/sched: taprio: always validate TCA_TAPRIO_ATTR_PRIOMAP
  (CVE-2024-36974 bsc#1226519).
- commit f911add
* Tue Jun 25 2024 iivanov@suse.de
- PCI: Clear Secondary Status errors after enumeration (bsc#1226928)
- commit 606f4e7
* Tue Jun 25 2024 dwagner@suse.de
- nvmet-passthru: propagate status from id override functions
  (git-fixes).
- nvme: fix nvme_pr_* status code parsing (git-fixes).
- nvmet: fix nvme status code when namespace is disabled
  (git-fixes).
- nvmet-tcp: fix possible memory leak when tearing down a
  controller (git-fixes).
- nvmet-auth: replace pr_debug() with pr_err() to report an error
  (git-fixes).
- nvmet-auth: return the error code to the nvmet_auth_host_hash()
  callers (git-fixes).
- nvme: find numa distance only if controller has valid numa id
  (git-fixes).
- commit 3709ef4
* Tue Jun 25 2024 dwagner@suse.de
- nvme: cancel pending I/O if nvme controller is in terminal state
  (bsc#1226503).
  Refresh:
  - patches.suse/nvme-multipath-fix-io-accounting-on-failover.patch
- commit 7dbf1d4
* Tue Jun 25 2024 tiwai@suse.de
- stm class: Fix a double free in stm_register_device()
  (CVE-2024-38627 bsc#1226857).
- commit ef5c589
* Tue Jun 25 2024 tiwai@suse.de
- Input: ili210x - fix ili251x_read_touch_data() return value
  (git-fixes).
- pinctrl: rockchip: fix pinmux reset in rockchip_pmx_set
  (git-fixes).
- pinctrl: rockchip: use dedicated pinctrl type for RK3328
  (git-fixes).
- pinctrl: rockchip: fix pinmux bits for RK3328 GPIO3-B pins
  (git-fixes).
- pinctrl: rockchip: fix pinmux bits for RK3328 GPIO2-B pins
  (git-fixes).
- pinctrl: fix deadlock in create_pinctrl() when handling
  - EPROBE_DEFER (git-fixes).
- pinctrl: qcom: spmi-gpio: drop broken pm8008 support
  (git-fixes).
- commit a1b46e3
* Tue Jun 25 2024 tiwai@suse.de
- drivers/perf: hisi: hns3: Actually use
  devm_add_action_or_reset() (CVE-2024-38603 bsc#1226842).
- commit 4db6ba6
* Tue Jun 25 2024 neilb@suse.de
- NFSv4.x: by default serialize open/close operations (bsc#1223863 bsc#1227362).
- commit 6ed2498
* Mon Jun 24 2024 nik.borisov@suse.com
- work around gcc bugs with 'asm goto' with outputs (git-fixes).
- Refresh
  patches.suse/powerpc-uaccess-Fix-build-errors-seen-with-GCC-13-14.patch.
- Refresh
  patches.suse/powerpc-uaccess-Use-YZ-asm-constraint-for-ld.patch.
- commit eac0f3f
* Mon Jun 24 2024 nik.borisov@suse.com
- x86/asm: Remove the __iomem annotation of movdir64b()'s dst argument (git-fixes).
- commit 8a8a749
* Mon Jun 24 2024 nik.borisov@suse.com
- x86/tdx: Preserve shared bit on mprotect() (git-fixes).
- commit ea4a8f6
* Mon Jun 24 2024 nik.borisov@suse.com
- x86/sev: Fix position dependent variable references in startup code (git-fixes).
- Refresh
  patches.suse/x86-coco-Require-seeding-RNG-with-RDRAND-on-CoCo-systems.patch.
- commit 2efccd0
* Mon Jun 24 2024 nik.borisov@suse.com
- x86/mce: Mark fatal MCE's page as poison to avoid panic in the kdump  kernel (git-fixes).
- Refresh
  patches.suse/x86-mce-Differentiate-real-hardware-MCs-from-TDX-erratum-o.patch.
- commit d75f0fd
* Mon Jun 24 2024 nik.borisov@suse.com
- x86/kexec: Fix bug with call depth tracking (git-fixes).
- commit 926155d
* Mon Jun 24 2024 nik.borisov@suse.com
- x86/nmi: Drop unused declaration of proc_nmi_enabled() (git-fixes).
- commit 3441c2e
* Mon Jun 24 2024 nik.borisov@suse.com
- x86/insn: Fix PUSH instruction in x86 instruction decoder opcode map (git-fixes).
- commit 820085a
* Mon Jun 24 2024 nik.borisov@suse.com
- x86/uaccess: Fix missed zeroing of ia32 u64 get_user() range checking (git-fixes).
- commit 1c4403a
* Mon Jun 24 2024 tbogendoerfer@suse.de
- net: fec: remove .ndo_poll_controller to avoid deadlocks
  (CVE-2024-38553 bsc#1226744).
- net/mlx5: Discard command completions in internal error
  (CVE-2024-38555 bsc#1226607).
- net/mlx5: Add a timeout to acquire the command queue semaphore
  (CVE-2024-38556 bsc#1226774).
- net/mlx5: Reload only IB representors upon lag disable/enable
  (CVE-2024-38557 bsc#1226781).
- net/mlx5e: Fix netif state handling (CVE-2024-38608
  bsc#1226746).
- eth: sungem: remove .ndo_poll_controller to avoid deadlocks
  (CVE-2024-38597 bsc#1226749).
- net: stmmac: move the EST lock to struct stmmac_priv
  (CVE-2024-38594 bsc#1226734).
- commit d6f20aa
* Mon Jun 24 2024 tiwai@suse.de
- i2c: ocores: set IACK bit after core is enabled (git-fixes).
- commit dc04936
* Sun Jun 23 2024 tiwai@suse.de
- regulator: bd71815: fix ramp values (git-fixes).
- regulator: core: Fix modpost error "regulator_get_regmap"
  undefined (git-fixes).
- spi: stm32: qspi: Clamp stm32_qspi_get_mode() output to
  CCR_BUSWIDTH_4 (git-fixes).
- spi: stm32: qspi: Fix dual flash mode sanity test in
  stm32_qspi_setup() (git-fixes).
- firmware: psci: Fix return value from psci_system_suspend()
  (git-fixes).
- commit 5c1d1d7
* Sat Jun 22 2024 nmorey@suse.com
- RDMA/mlx5: Add check for srq max_sge attribute (git-fixes)
- commit 5a7a44c
* Sat Jun 22 2024 nmorey@suse.com
- RDMA/mlx5: Fix unwind flow as part of mlx5_ib_stage_init_init (git-fixes)
- commit a73b3cb
* Sat Jun 22 2024 nmorey@suse.com
- RDMA/mlx5: Ensure created mkeys always have a populated rb_key (git-fixes)
- commit 194920a
* Sat Jun 22 2024 nmorey@suse.com
- RDMA/mlx5: Follow rb_key.ats when creating new mkeys (git-fixes)
- commit 93d4abb
* Sat Jun 22 2024 nmorey@suse.com
- RDMA/mlx5: Remove extra unlock on error path (git-fixes)
- commit 662ecd8
* Sat Jun 22 2024 nmorey@suse.com
- RDMA/rxe: Fix responder length checking for UD request packets (git-fixes)
- commit 77ecb50
* Sat Jun 22 2024 nmorey@suse.com
- RDMA/rxe: Fix data copy for IB_SEND_INLINE (git-fixes)
- commit 9ec1cd9
* Sat Jun 22 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix the max msix vectors macro (git-fixes)
- commit 19f32fe
* Sat Jun 22 2024 tiwai@suse.de
- drm/i915/mso: using joiner is not possible with eDP MSO
  (git-fixes).
- ALSA: hda/realtek: Add quirk for Lenovo Yoga Pro 7 14AHP9
  (stable-fixes).
- ACPICA: Revert "ACPICA: avoid Info: mapping multiple BARs. Your
  kernel is fine." (git-fixes).
- thermal/drivers/mediatek/lvts_thermal: Return error in case
  of invalid efuse data (git-fixes).
- dmaengine: ioatdma: Fix missing kmem_cache_destroy()
  (git-fixes).
- dmaengine: ioatdma: Fix kmemleak in ioat_pci_probe()
  (git-fixes).
- dmaengine: ioatdma: Fix error path in ioat3_dma_probe()
  (git-fixes).
- dmaengine: ioatdma: Fix leaking on version mismatch (git-fixes).
- dmaengine: idxd: Fix possible Use-After-Free in
  irq_process_work_list (git-fixes).
- xhci: Apply broken streams quirk to Etron EJ188 xHCI host
  (stable-fixes).
- xhci: Apply reset resume quirk to Etron EJ188 xHCI host
  (stable-fixes).
- xhci: Set correct transferred length for cancelled bulk
  transfers (stable-fixes).
- drm/exynos/vidi: fix memory leak in .get_modes() (stable-fixes).
- ACPI: x86: Force StorageD3Enable on more products
  (stable-fixes).
- nilfs2: fix nilfs_empty_dir() misjudgment and long loop on
  I/O errors (git-fixes).
- kheaders: explicitly define file modes for archived headers
  (stable-fixes).
- intel_th: pci: Add Lunar Lake support (stable-fixes).
- intel_th: pci: Add Meteor Lake-S support (stable-fixes).
- intel_th: pci: Add Sapphire Rapids SOC support (stable-fixes).
- intel_th: pci: Add Granite Rapids SOC support (stable-fixes).
- intel_th: pci: Add Granite Rapids support (stable-fixes).
- clkdev: Update clkdev id usage to allow for longer names
  (stable-fixes).
- nilfs2: return the mapped address from nilfs_get_page()
  (stable-fixes).
- commit 8bec8e0
* Fri Jun 21 2024 tiwai@suse.de
- drivers/perf: hisi_pcie: Fix out-of-bound access when valid
  event group (CVE-2024-38569 bsc#1226772).
- commit 6715b52
* Fri Jun 21 2024 tiwai@suse.de
- drivers/perf: hisi: hns3: Fix out-of-bound access when valid
  event group (CVE-2024-38568 bsc#1226771).
- commit 33d69e0
* Fri Jun 21 2024 mkoutny@suse.com
- sched/core: Fix incorrect initialization of the 'burst'
  parameter in cpu_max_write() (bsc#1226791).
- commit 6b67975
* Fri Jun 21 2024 dfaggioli@suse.com
- virtio_net: checksum offloading handling fix (git-fixes).
- commit d283709
* Fri Jun 21 2024 dfaggioli@suse.com
- virtio_net: avoid data-races on dev->stats fields (git-fixes).
- commit 50373fb
* Fri Jun 21 2024 dfaggioli@suse.com
- vfio/fsl-mc: Block calling interrupt handler without trigger
  (bsc#1222810 CVE-2024-26814).
- commit b1aee55
* Fri Jun 21 2024 dfaggioli@suse.com
- vfio/platform: Create persistent IRQ handlers (bsc#1222809
  CVE-2024-26813).
- commit 28ae90e
* Fri Jun 21 2024 tiwai@suse.de
- ALSA: hda/realtek: Add more codec ID to no shutup pins list
  (stable-fixes).
- ALSA: hda/realtek: Add quirk for Lenovo Yoga Pro 7 14ARP8
  (stable-fixes).
- ALSA: hda/realtek: Support Lenovo Thinkbook 13x Gen 4
  (stable-fixes).
- ALSA: hda/realtek: Support Lenovo Thinkbook 16P Gen 5
  (stable-fixes).
- ALSA: hda: cs35l41: Support Lenovo Thinkbook 13x Gen 4
  (stable-fixes).
- ALSA: hda: cs35l41: Support Lenovo Thinkbook 16P Gen 5
  (stable-fixes).
- ALSA: hda/realtek: Limit mic boost on N14AP7 (stable-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs don't work for ProBook
  445/465 G11 (stable-fixes).
- ALSA: hda: cs35l56: Fix lifecycle of codec pointer
  (stable-fixes).
- commit 3c2cbdc
* Fri Jun 21 2024 tiwai@suse.de
- net: usb: rtl8150 fix unintiatilzed variables in
  rtl8150_get_link_ksettings (git-fixes).
- net: usb: ax88179_178a: improve reset check (git-fixes).
- net: phy: mxl-gpy: Remove interrupt mask clearing from
  config_init (git-fixes).
- net: lan743x: Support WOL at both the PHY and MAC appropriately
  (git-fixes).
- net: lan743x: disable WOL upon resume to restore full data
  path operation (git-fixes).
- ALSA: hda/realtek: Enable headset mic on IdeaPad 330-17IKB 81DM
  (git-fixes).
- ALSA: hda: tas2781: Component should be unbound before
  deconstruction (git-fixes).
- ALSA: hda: cs35l41: Component should be unbound before
  deconstruction (git-fixes).
- ALSA: hda: cs35l56: Component should be unbound before
  deconstruction (git-fixes).
- ALSA/hda: intel-dsp-config: Document AVS as dsp_driver option
  (git-fixes).
- ALSA: hda/realtek: Remove Framework Laptop 16 from quirks
  (git-fixes).
- ALSA: seq: ump: Fix missing System Reset message handling
  (git-fixes).
- ALSA: hda: cs35l41: Possible null pointer dereference in
  cs35l41_hda_unbind() (git-fixes).
- commit 045593b
* Fri Jun 21 2024 mkubecek@suse.cz
- tcp: Dump bound-only sockets in inet_diag (bsc#1204562).
- commit ff006da
* Thu Jun 20 2024 lhenriques@suse.de
- cachefiles: remove requests from xarray during flushing requests
  (bsc#1226588).
- commit b238f81
* Thu Jun 20 2024 mfranc@suse.cz
- net/smc: fix neighbour and rtable leak in smc_ib_find_route()
  (git-fixes bsc#1225823 CVE-2024-36945 bsc#1226547).
- commit d4aa573
* Thu Jun 20 2024 shung-hsi.yu@suse.com
- selftests/bpf: test case for callback_depth states pruning logic
  (bsc#1225903).
- bpf: check bpf_func_state->callback_depth when pruning states
  (bsc#1225903).
- commit 6632e43
* Wed Jun 19 2024 iivanov@suse.de
- supported.conf: Add APM X-Gene SoC hardware monitoring driver (jsc#PED-8649)
  Module is marked supported because of merge from SP6, but lets add
  reference to SLM6.0 maintenance task.
- commit d270c07
* Wed Jun 19 2024 tiwai@suse.de
- gpio: tqmx86: introduce shadow register for GPIO output value
  (git-fixes).
- Refresh
  patches.suse/gpio-tqmx86-store-IRQ-trigger-type-and-unmask-status.patch.
- commit 559245f
* Wed Jun 19 2024 tiwai@suse.de
- efi/x86: Free EFI memory map only when installing a new one
  (git-fixes).
- gpio: lpc32xx: fix module autoloading (stable-fixes).
- commit d39df35
* Wed Jun 19 2024 tiwai@suse.de
- Move upstreamed NFS patch into sorted section
- commit 19c3986
* Wed Jun 19 2024 neilb@suse.de
- nfsd: optimise recalculate_deny_mode() for a common case
  (bsc#1217912).
- commit 882d2ff
* Wed Jun 19 2024 neilb@suse.de
- NFS: avoid infinite loop in pnfs_update_layout (bsc#1219633
  bsc#1226226).
- commit b98e69a
* Wed Jun 19 2024 neilb@suse.de
- NFS: abort nfs_atomic_open_v23 if name is too long
  (bsc#1219847).
- NFS: add atomic_open for NFSv3 to handle O_TRUNC correctly
  (bsc#1219847).
- commit 772961e
* Tue Jun 18 2024 krisman@suse.de
- fs/9p: fix uninitialized values during inode evict (bsc#1225815
  CVE-2024-36923).
- commit b349473
* Tue Jun 18 2024 tiwai@suse.de
- x86/mce: Dynamically size space for machine check records
  (bsc#1222241).
- commit 2d0d4b2
* Tue Jun 18 2024 hare@suse.de
- nvme-tcp: Export the nvme_tcp_wq to sysfs (bsc#1224049).
- Refresh
  patches.suse/nvme-tcp-Add-wq_unbound-modparam-for-nvme_tcp_wq.patch.
- commit 099b967
* Tue Jun 18 2024 denis.kirjanov@suse.com
- net: preserve kabi for struct dst_ops (CVE-2024-36971
  bsc#1226145).
- commit 6d764b6
* Tue Jun 18 2024 tiwai@suse.de
- kcov: don't lose track of remote references during softirqs
  (git-fixes).
- commit fc5abf0
* Tue Jun 18 2024 davide.benini@suse.com
- rtnetlink: fix error logic of IFLA_BRIDGE_FLAGS writing back
  (CVE-2024-27414 bsc#1224439).
- commit 6651625
* Tue Jun 18 2024 davide.benini@suse.com
- netfilter: nf_tables: reject new basechain after table flag update
  (CVE-2024-35900 bsc#1224497).
- commit ef2c4d5
* Tue Jun 18 2024 denis.kirjanov@suse.com
- net: fix __dst_negative_advice() race (CVE-2024-36971
  bsc#1226145).
- commit 604ed28
* Tue Jun 18 2024 denis.kirjanov@suse.com
- ipv6: Fix infinite recursion in fib6_dump_done() (CVE-2024-35886
  bsc#1224670).
- commit ba91bc1
* Mon Jun 17 2024 tzimmermann@suse.com
- drm/amd/display: Disable idle reallow as part of command/gpint (bsc#1225702 CVE-2024-36024)
- commit 6d53e8c
* Mon Jun 17 2024 tiwai@suse.de
- RAS/AMD/ATL: Use system settings for MI300 DRAM to normalized
  address translation (bsc#1225300).
- RAS/AMD/ATL: Fix MI300 bank hash (bsc#1225300).
- commit 82b08f9
* Mon Jun 17 2024 tiwai@suse.de
- i2c: designware: Fix the functionality flags of the slave-only
  interface (git-fixes).
- i2c: at91: Fix the functionality flags of the slave-only
  interface (git-fixes).
- USB: class: cdc-wdm: Fix CPU lockup caused by excessive log
  messages (git-fixes).
- xhci: Handle TD clearing for multiple streams case (git-fixes).
- thunderbolt: debugfs: Fix margin debugfs node creation condition
  (git-fixes).
- usb-storage: alauda: Check whether the media is initialized
  (git-fixes).
- usb: typec: tcpm: Ignore received Hard Reset in TOGGLING state
  (git-fixes).
- usb: typec: tcpm: fix use-after-free case in
  tcpm_register_source_caps (git-fixes).
- USB: xen-hcd: Traverse host/ when CONFIG_USB_XEN_HCD is selected
  (git-fixes).
- tty: n_tty: Fix buffer offsets when lookahead is used
  (git-fixes).
- drivers: core: synchronize really_probe() and dev_uevent()
  (git-fixes).
- iio: imu: inv_icm42600: delete unneeded update watermark call
  (git-fixes).
- iio: dac: ad5592r: fix temperature channel scaling value
  (git-fixes).
- iio: adc: ad9467: fix scan type sign (git-fixes).
- misc: microchip: pci1xxxx: Fix a memory leak in the error
  handling of gp_aux_bus_probe() (git-fixes).
- misc: microchip: pci1xxxx: fix double free in the error handling
  of gp_aux_bus_probe() (git-fixes).
- mei: me: release irq in mei_me_pci_resume error path
  (git-fixes).
- ax25: Fix refcount imbalance on inbound connections (git-fixes).
- tpm_tis: Do *not* flush uninitialized work (git-fixes).
- selftests/mm: fix build warnings on ppc64 (stable-fixes).
- selftests/mm: compaction_test: fix incorrect write of zero to
  nr_hugepages (git-fixes).
- genirq/irqdesc: Prevent use-after-free in irq_find_at_or_after()
  (git-fixes).
- drm/amdgpu/atomfirmware: add intergrated info v2.3 table
  (stable-fixes).
- intel_th: pci: Add Meteor Lake-S CPU support (stable-fixes).
- mmc: sdhci-acpi: Add quirk to enable pull-up on the card-detect
  GPIO on Asus T100TA (git-fixes).
- mmc: sdhci-acpi: Disable write protect detection on Toshiba
  WT10-A (stable-fixes).
- mmc: sdhci-acpi: Fix Lenovo Yoga Tablet 2 Pro 1380 sdcard slot
  not working (stable-fixes).
- mmc: sdhci-acpi: Sort DMI quirks alphabetically (stable-fixes).
- mmc: sdhci: Add support for "Tuning Error" interrupts
  (stable-fixes).
- mmc: core: Add mmc_gpiod_set_cd_config() function
  (stable-fixes).
- media: mxl5xx: Move xpt structures off stack (stable-fixes).
- media: lgdt3306a: Add a check against null-pointer-def
  (stable-fixes).
- media: v4l2-core: hold videodev_lock until dev reg, finishes
  (stable-fixes).
- drm/amdgpu: add error handle to avoid out-of-bounds
  (stable-fixes).
- drm/i915/hwmon: Get rid of devm (stable-fixes).
- wifi: rtw89: correct aSIFSTime for 6GHz band (stable-fixes).
- wifi: rtlwifi: rtl8192de: Fix endianness issue in RX path
  (stable-fixes).
- wifi: rtlwifi: rtl8192de: Fix low speed with WPA3-SAE
  (stable-fixes).
- wifi: rtlwifi: rtl8192de: Fix 5 GHz TX power (stable-fixes).
- wifi: rtl8xxxu: Fix the TX power of RTL8192CU, RTL8723AU
  (stable-fixes).
- ACPI: resource: Do IRQ override on TongFang GXxHRXx and GMxHGxx
  (stable-fixes).
- crypto: ecrdsa - Fix module auto-load on add_key (stable-fixes).
- drm/sun4i: hdmi: Move mode_set into enable (stable-fixes).
- drm/sun4i: hdmi: Convert encoder to atomic (stable-fixes).
- mmc: core: Do not force a retune before RPMB switch
  (stable-fixes).
- commit 8df97c4
* Mon Jun 17 2024 hare@suse.de
- nvme/tcp: Add wq_unbound modparam for nvme_tcp_wq (bsc#1224049).
- commit 7af7bce
* Sun Jun 16 2024 heming.zhao@suse.com
- ocfs2: fix sparse warnings (bsc#1219224).
- ocfs2: speed up chain-list searching (bsc#1219224).
- ocfs2: adjust enabling place for la window (bsc#1219224).
- ocfs2: improve write IO performance when fragmentation is high
  (bsc#1219224).
- commit 98a3adb
* Sat Jun 15 2024 tiwai@suse.de
- drm/exynos: hdmi: report safe 640x480 mode as a fallback when
  no EDID found (git-fixes).
- drm/nouveau: don't attempt to schedule hpd_work on headless
  cards (git-fixes).
- drm/bridge/panel: Fix runtime warning on panel bridge release
  (git-fixes).
- drm/komeda: check for error-valued pointer (git-fixes).
- commit b393dd7
* Fri Jun 14 2024 ematsumiya@suse.de
- smb: client: fix use-after-free bug in
  cifs_debug_data_proc_show() (bsc#1225487, CVE-2023-52752).
- commit c4e1b53
* Fri Jun 14 2024 tiwai@suse.de
- Temporarily drop KVM patch that caused a regression (bsc#1226158)
  Delete patches.suse/KVM-x86-pmu-Prioritize-VMX-interception-over-GP-on-R.patch
- commit 33f31da
* Fri Jun 14 2024 shung-hsi.yu@suse.com
- kABI: bpf: verifier kABI workaround
  (bsc#1225903).
- commit 726091c
* Fri Jun 14 2024 shung-hsi.yu@suse.com
- bpf: keep track of max number of bpf_loop callback iterations
  (bsc#1225903).
- selftests/bpf: test widening for iterating callbacks
  (bsc#1225903).
- bpf: widening for callback iterators (bsc#1225903).
- selftests/bpf: tests for iterating callbacks (bsc#1225903).
- bpf: verify callbacks as if they are called unknown number of
  times (bsc#1225903).
- bpf: extract setup_func_entry() utility function (bsc#1225903).
- bpf: extract __check_reg_arg() utility function (bsc#1225903).
- selftests/bpf: track string payload offset as scalar in
  strobemeta (bsc#1225903).
- selftests/bpf: track tcp payload offset as scalar in
  xdp_synproxy (bsc#1225903).
- bpf: print full verifier states on infinite loop detection
  (bsc#1225903).
- selftests/bpf: test if state loops are detected in a tricky case
  (bsc#1225903).
- bpf: correct loop detection for iterators convergence
  (bsc#1225903).
- selftests/bpf: tests with delayed read/precision makrs in loop
  body (bsc#1225903).
- bpf: exact states comparison for iterator convergence checks
  (bsc#1225903).
- bpf: extract same_callsites() as utility function (bsc#1225903).
- bpf: move explored_state() closer to the beginning of verifier.c
  (bsc#1225903).
- commit 63dfc45
* Fri Jun 14 2024 denis.kirjanov@suse.com
- ipv6: Fix potential uninit-value access in __ip6_make_skb()
  (CVE-2024-36903 bsc#1225741).
- commit f510672
* Fri Jun 14 2024 denis.kirjanov@suse.com
- Update references
- commit 36a2563
* Fri Jun 14 2024 pjakobsson@suse.de
- drm/amd/display: Skip on writeback when it's not applicable (CVE-2024-36914 bsc#1225757).
- commit e1ad803
* Fri Jun 14 2024 tiwai@suse.de
- cpufreq: amd-pstate: Fix the inconsistency in max frequency
  units (git-fixes).
- commit 9dd9a2b
* Fri Jun 14 2024 jdelvare@suse.de
- gpiolib: cdev: Fix use after free in lineinfo_changed_notify
  (bsc#1225737 CVE-2024-36899).
- commit 24144db
* Fri Jun 14 2024 tiwai@suse.de
- nouveau: report byte usage in VRAM usage (git-fixes).
- Refresh
  patches.suse/drm-nouveau-use-tile_mode-and-pte_kind-for-VM_BIND-b.patch.
- commit 5638f93
* Fri Jun 14 2024 tiwai@suse.de
- nouveau: add an ioctl to report vram usage (stable-fixes).
- Refresh
  patches.suse/drm-nouveau-use-tile_mode-and-pte_kind-for-VM_BIND-b.patch.
- commit 7ea88ac
* Fri Jun 14 2024 tiwai@suse.de
- nouveau: add an ioctl to return vram bar size (stable-fixes).
- Refresh
  patches.suse/drm-nouveau-use-tile_mode-and-pte_kind-for-VM_BIND-b.patch.
- commit 07ddfce
* Fri Jun 14 2024 tiwai@suse.de
- platform/x86: dell-smbios: Fix wrong token data in sysfs
  (git-fixes).
- net: phy: Micrel KSZ8061: fix errata solution not taking effect
  problem (git-fixes).
- wifi: ath10k: fix QCOM_RPROC_COMMON dependency (git-fixes).
- wifi: mac80211: correctly parse Spatial Reuse Parameter Set
  element (git-fixes).
- wifi: iwlwifi: mvm: don't read past the mfuart notifcation
  (git-fixes).
- wifi: iwlwifi: mvm: check n_ssids before accessing the ssids
  (git-fixes).
- wifi: iwlwifi: dbg_ini: move iwl_dbg_tlv_free outside of
  debugfs ifdef (git-fixes).
- wifi: iwlwifi: mvm: set properly mac header (git-fixes).
- wifi: iwlwifi: mvm: revert gen2 TX A-MPDU size to 64
  (git-fixes).
- wifi: iwlwifi: mvm: don't initialize csa_work twice (git-fixes).
- wifi: cfg80211: pmsr: use correct nla_get_uX functions
  (git-fixes).
- wifi: cfg80211: Lock wiphy in cfg80211_get_station (git-fixes).
- wifi: cfg80211: fully move wiphy work to unbound workqueue
  (git-fixes).
- wifi: mac80211: Fix deadlock in
  ieee80211_sta_ps_deliver_wakeup() (git-fixes).
- wifi: mac80211: mesh: Fix leak of mesh_preq_queue objects
  (git-fixes).
- net: phy: micrel: fix KSZ9477 PHY issues after suspend/resume
  (git-fixes).
- module: don't ignore sysfs_create_link() failures (git-fixes).
- soundwire: cadence: fix invalid PDI offset (stable-fixes).
- platform/x86/intel/tpmi: Handle error from tpmi_process_info()
  (stable-fixes).
- platform/x86: thinkpad_acpi: Take hotkey_mutex during
  hotkey_exit() (git-fixes).
- media: radio-shark2: Avoid led_names truncations (git-fixes).
- wifi: nl80211: Avoid address calculations via out of bounds
  array indexing (git-fixes).
- selftests: mptcp: add ms units for tc-netem delay
  (stable-fixes).
- pwm: sti: Simplify probe function using devm functions
  (git-fixes).
- regulator: vqmmc-ipq4019: fix module autoloading (stable-fixes).
- regulator: irq_helpers: duplicate IRQ name (stable-fixes).
- platform/x86: ISST: Add Grand Ridge to HPM CPU list
  (stable-fixes).
- selftests: sud_test: return correct emulated syscall value on
  RISC-V (stable-fixes).
- wifi: cfg80211: fix the order of arguments for trace events
  of the tx_rx_evt class (stable-fixes).
- wifi: mac80211: ensure beacon is non-S1G prior to extracting
  the beacon timestamp field (stable-fixes).
- wifi: mac80211: don't use rate mask for scanning (stable-fixes).
- pwm: sti: Prepare removing pwm_chip from driver data
  (stable-fixes).
- commit d252b95
* Fri Jun 14 2024 tiwai@suse.de
- HID: logitech-dj: Fix memory leak in
  logi_dj_recv_switch_to_dj_mode() (git-fixes).
- HID: core: remove unnecessary WARN_ON() in implement()
  (git-fixes).
- kconfig: doc: fix a typo in the note about 'imply' (git-fixes).
- gpio: tqmx86: fix broken IRQ_TYPE_EDGE_BOTH interrupt type
  (git-fixes).
- gpio: tqmx86: store IRQ trigger type and unmask status
  separately (git-fixes).
- gpio: tqmx86: fix typo in Kconfig label (git-fixes).
- drm/vmwgfx: Don't memcmp equivalent pointers (git-fixes).
- drm/vmwgfx: 3D disabled should not effect STDU memory limits
  (git-fixes).
- drm/vmwgfx: Filter modes which exceed graphics memory
  (git-fixes).
- drm/panel: sitronix-st7789v: Add check for
  of_drm_get_panel_orientation (git-fixes).
- drm/amd: Fix shutdown (again) on some SMU v13.0.4/11 platforms
  (git-fixes).
- kconfig: fix comparison to constant symbols, 'm', 'n'
  (git-fixes).
- drm/amdgpu: Fix buffer size in gfx_v9_4_3_init_
  cp_compute_microcode() and rlc_microcode() (git-fixes).
- drm/amdgpu: init microcode chip name from ip versions
  (stable-fixes).
- fpga: dfl-pci: add PCI subdevice ID for Intel D5005 card
  (stable-fixes).
- iio: accel: mxc4005: Reset chip on probe() and resume()
  (stable-fixes).
- drm/amdkfd: Flush the process wq before creating a kfd_process
  (stable-fixes).
- drm/amd/display: Disable seamless boot on 128b/132b encoding
  (stable-fixes).
- drm/amd/display: Fix DC mode screen flickering on DCN321
  (stable-fixes).
- drm/amd/display: Add VCO speed parameter for DCN31 FPU
  (stable-fixes).
- drm/amd/display: Allocate zero bw after bw alloc enable
  (stable-fixes).
- drm/amd/display: Add dtbclk access to dcn315 (stable-fixes).
- drm/amdgpu: Fix VRAM memory accounting (stable-fixes).
- drm/etnaviv: fix tx clock gating on some GC7000 variants
  (stable-fixes).
- HID: mcp-2221: cancel delayed_work only when CONFIG_IIO is
  enabled (stable-fixes).
- iio: adc: ad9467: use chip_info variables instead of array
  (stable-fixes).
- iio: adc: ad9467: use spi_get_device_match_data()
  (stable-fixes).
- iio: accel: mxc4005: allow module autoloading via OF compatible
  (stable-fixes).
- commit 4e48378
* Fri Jun 14 2024 tiwai@suse.de
- kABI workaround for sof_ipc_pcm_ops (git-fixes).
- commit 070cfe5
* Fri Jun 14 2024 tiwai@suse.de
- Bluetooth: L2CAP: Fix rejecting L2CAP_CONN_PARAM_UPDATE_REQ
  (git-fixes).
- cxl/region: Fix memregion leaks in devm_cxl_add_region()
  (git-fixes).
- cxl/test: Add missing vmalloc.h for tools/testing/cxl/test/mem.c
  (git-fixes).
- cxl/region: Fix cxlr_pmem leaks (git-fixes).
- cxl/trace: Correct DPA field masks for general_media & dram
  events (git-fixes).
- ASoC: SOF: pcm: Restrict DSP D0i3 during S0ix to IPC3
  (stable-fixes).
- drm/amdgpu/mes: fix use-after-free issue (stable-fixes).
- drm/amdgpu: Fix the ring buffer size for queue VM flush
  (stable-fixes).
- drm/amdkfd: Add VRAM accounting for SVM migration
  (stable-fixes).
- drm/amd/pm: Restore config space after reset (stable-fixes).
- drm/amdgpu: Update BO eviction priorities (stable-fixes).
- drm/amd/display: Set color_mgmt_changed to true on unsuspend
  (stable-fixes).
- drm/amd/display: Revert Remove pixle rate limit for subvp
  (stable-fixes).
- drm/amd/display: Remove pixle rate limit for subvp
  (stable-fixes).
- Bluetooth: hci_event: Remove code to removed CONFIG_BT_HS
  (stable-fixes).
- Bluetooth: Remove usage of the deprecated ida_simple_xx() API
  (stable-fixes).
- ASoC: Intel: common: add ACPI matching tables for Arrow Lake
  (stable-fixes).
- Bluetooth: ISO: Fix BIS cleanup (stable-fixes).
- commit b6ffdb9
* Fri Jun 14 2024 dfaggioli@suse.com
- KVM: arm64: Use local TLBI on permission relaxation
  (bsc#1219478).
- Refresh
  patches.suse/KVM-arm64-Always-invalidate-TLB-for-stage-2-permission-faults.
- commit c414679
* Thu Jun 13 2024 dfaggioli@suse.com
- KVM: x86: Don't advertise guest.MAXPHYADDR as host.MAXPHYADDR
  in CPUID (git-fixes).
- commit 001738e
* Thu Jun 13 2024 mkoutny@suse.com
- cgroup: preserve KABI of cgroup_root (bsc#1222254).
- commit d652cd6
* Thu Jun 13 2024 mkoutny@suse.com
- cgroup: Add annotation for holding namespace_sem in
  current_cgns_cgroup_from_root() (bsc#1222254).
- cgroup: Eliminate the need for cgroup_mutex in
  proc_cgroup_show() (bsc#1222254).
- cgroup: Make operations on the cgroup root_list RCU safe
  (bsc#1222254).
- cgroup: Remove unnecessary list_empty() (bsc#1222254).
- commit 8dc654b
* Thu Jun 13 2024 oneukum@suse.com
- net: usb: qmi_wwan: add Telit FN920C04 compositions (git-fixes).
- commit 49f5909
* Thu Jun 13 2024 colyli@suse.de
- Replace the inhouse patch with following upstream patch
  (bsc#1221097, bsc#1224572, CVE-2024-35979)
  patches.suse/raid1-fix-use-after-free-for-original-bio-in-raid1_-fcf3.patch.
- commit 03ae28a
* Thu Jun 13 2024 ailiop@suse.com
- supported.conf: mark ufs as unsupported
  UFS is an unsupported filesystem, mark it as such. We still keep it
  around (not marking as optional), to accommodate any potential
  migrations from BSD systems.
- commit 5192abd
* Thu Jun 13 2024 ailiop@suse.com
- supported.conf: mark orangefs as optional
  We don't support orangefs at all (and it is already marked as such), but
  since there are no SLE consumers of it, mark it as optional.
- commit 264e3d2
* Thu Jun 13 2024 ailiop@suse.com
- nilfs2: fix potential hang in nilfs_detach_log_writer()
  (git-fixes).
- commit 181df2f
* Thu Jun 13 2024 fvogt@suse.de
- rpm/kernel-obs-build.spec.in: Add iso9660 (bsc#1226212)
  Some builds don't just create an iso9660 image, but also mount it during
  build.
- commit aaee141
* Thu Jun 13 2024 oneukum@suse.com
- Input: xpad - add support for ASUS ROG RAIKIRI (git-fixes).
- commit 9d3a015
* Wed Jun 12 2024 jack@suse.cz
- ext4: correct offset of gdb backup in non meta_bg group to
  update_backups (bsc#1224735 CVE-2024-35807).
- commit 68779d8
* Wed Jun 12 2024 jack@suse.cz
- ext4: remove unnecessary check from alloc_flex_gd() (bsc#1222080
  CVE-2023-52622).
- commit 2e6ec2e
* Wed Jun 12 2024 davide.benini@suse.com
- llc: verify mac len before reading mac header
  (CVE-2023-52843 bsc#1224951).
- commit ea955e6
* Wed Jun 12 2024 davide.benini@suse.com
- netfilter: nf_tables: Fix potential data-race in __nft_flowtable_type_get()
  (CVE-2024-35898 bsc#1224498).
- commit 47a49f0
* Wed Jun 12 2024 davide.benini@suse.com
- nfc: llcp: fix nfc_llcp_setsockopt() unsafe copies
  (CVE-2024-36915 bsc#1225758).
- commit 0955416
* Wed Jun 12 2024 davide.benini@suse.com
- net: add copy_safe_from_sockptr() helper
  (git-fixes prerequisite CVE-2024-36915 bsc#1225758).
- commit e4ca26d
* Wed Jun 12 2024 fvogt@suse.de
- rpm/kernel-obs-build.spec.in: Add networking modules for docker
  (bsc#1226211)
  docker needs more networking modules, even legacy iptable_nat and _filter.
- commit 415e132
* Tue Jun 11 2024 davide.benini@suse.com
- rtnetlink: Correct nested IFLA_VF_VLAN_LIST attribute validation
  (CVE-2024-36017 bsc#1225681).
- commit 349b81e
* Tue Jun 11 2024 jack@suse.cz
- mm: use memalloc_nofs_save() in page_cache_ra_order()
  (bsc#1225723 CVE-2024-36882).
- commit 858537f
* Tue Jun 11 2024 jack@suse.cz
- blk-iocost: avoid out of bounds shift (bsc#1225759
  CVE-2024-36916).
- commit 9e35e70
* Tue Jun 11 2024 davide.benini@suse.com
- netfilter: complete validation of user input
  (git-fixes CVE-2024-35896 bsc#1224662).
- commit a54ae57
* Tue Jun 11 2024 tbogendoerfer@suse.de
- net: hns3: fix kernel crash when devlink reload during
  initialization (CVE-2024-36900 bsc#1225726).
- net: hns3: release PTP resources if pf initialization failed
  (CVE-2024-36900 bsc#1225726).
- commit ad59124
* Tue Jun 11 2024 jack@suse.cz
- blk-mq: make sure active queue usage is held for
  bio_integrity_prep() (bsc#1225105 CVE-2023-52787).
- commit 6131890
* Tue Jun 11 2024 jack@suse.cz
- block: prevent division by zero in blk_rq_stat_sum()
  (bsc#1224661 CVE-2024-35925).
- commit 7339ca3
* Tue Jun 11 2024 jack@suse.cz
- Update refs for patches.suse/nbd-fix-uaf-in-nbd_open.patch (bsc#1216436
  bsc#1224935 CVE-2023-52837).
- commit 95ff8cb
* Tue Jun 11 2024 davide.benini@suse.com
- netfilter: validate user input for expected length
  (CVE-2024-35896 bsc#1224662).
- commit 6a29de4
* Tue Jun 11 2024 jack@suse.cz
- ext4: fix corruption during on-line resize (bsc#1224735
  CVE-2024-35807).
- commit 751677a
* Tue Jun 11 2024 jack@suse.cz
- ext4: fix racy may inline data check in dio write (bsc#1224939
  CVE-2023-52786).
- commit 742009f
* Tue Jun 11 2024 jack@suse.cz
- ext4: avoid online resizing failures due to oversized flex bg
  (bsc#1222080 CVE-2023-52622).
- commit 817510d
* Tue Jun 11 2024 andrea.porta@suse.com
- arm64: asm-bug: Add .align 2 to the end of __BUG_ENTRY
  (git-fixes).
- commit d2efb00
* Tue Jun 11 2024 tbogendoerfer@suse.de
- net: mana: Enable MANA driver on ARM64 with 4K page size
  (jsc#PED-8491).
- Update config files.
- commit 5211306
* Tue Jun 11 2024 tbogendoerfer@suse.de
- bna: ensure the copied buf is NUL terminated (CVE-2024-36934
  bsc#1225760).
- ice: ensure the copied buf is NUL terminated (CVE-2024-36935
  bsc#1225763).
- commit ab36d7d
* Tue Jun 11 2024 shung-hsi.yu@suse.com
- xdp: use flags field to disambiguate broadcast redirect
  (bsc#1225834 CVE-2024-36937).
- commit de0720c
* Tue Jun 11 2024 krisman@suse.de
- fs/pipe: move check to pipe_has_watch_queue() (bsc#1224614
  CVE-2023-52672).
- commit 66a9a3f
* Mon Jun 10 2024 davide.benini@suse.com
- tipc: Change nla_policy for bearer-related names to NLA_NUL_STRING
  (CVE-2023-52845 bsc#1225585).
- commit a73a0ca
* Mon Jun 10 2024 krisman@suse.de
- pipe: wakeup wr_wait after setting max_usage (bsc#1224614
  CVE-2023-52672).
- commit 333fe30
* Mon Jun 10 2024 davide.benini@suse.com
- netfilter: nf_tables: honor table dormant flag from netdev release event path
  (CVE-2024-36005 bsc#1224539).
- commit 5b08b61
* Sat Jun  8 2024 lduncan@suse.com
- scsi: target: core: Add TMF to tmr_list handling (bsc#1223018
  CVE-2024-26845).
- commit 6b81c05
* Fri Jun  7 2024 vkarasulli@suse.de
- iommu: mtk: fix module autoloading (git-fixes).
- commit 50334e4
* Fri Jun  7 2024 vkarasulli@suse.de
- iommu/amd: Enhance def_domain_type to handle untrusted device
  (git-fixes).
- commit 9d0dd7f
* Fri Jun  7 2024 vkarasulli@suse.de
- iommu: Undo pasid attachment only for the devices that have
  succeeded (git-fixes).
- commit 4de170c
* Fri Jun  7 2024 davide.benini@suse.com
- net/sched: fix lockdep splat in qdisc_tree_reduce_backlog()
  (CVE-2024-35892 bsc#1224515).
- commit e8fcaf3
* Fri Jun  7 2024 jdelvare@suse.de
- eeprom: at24: fix memory corruption race condition (bsc#1224612
  CVE-2024-35848).
- commit 269cd6c
* Fri Jun  7 2024 davide.benini@suse.com
- udp: do not accept non-tunnel GSO skbs landing in a tunnel
  (CVE-2024-35884 bsc#1224520).
- commit 78d5dd0
* Fri Jun  7 2024 davide.benini@suse.com
- Kabi workaround for icmp: prevent possible NULL dereferences from
  icmp_build_probe() (CVE-2024-35857 bsc#1224619).
- icmp: prevent possible NULL dereferences from icmp_build_probe()
  (CVE-2024-35857 bsc#1224619).
- commit fa789e3
* Thu Jun  6 2024 krisman@suse.de
- io_uring/net: correct the type of variable (git-fixes).
- commit 91963e3
* Thu Jun  6 2024 shung-hsi.yu@suse.com
- sock_map: avoid race between sock_map_close and sk_psock_put
  (bsc#1225475 CVE-2023-52735).
- commit 71eeba4
* Thu Jun  6 2024 oneukum@suse.com
- Update
  patches.suse/usb-dwc2-fix-possible-NULL-pointer-dereference-cause.patch
  (CVE-2023-52855 bsc#1225583).
  Adding references
- commit 4b5e987
* Thu Jun  6 2024 denis.kirjanov@suse.com
- net: preserve kabi for sk_buff (CVE-2024-26921 bsc#1223138).
- commit 7bf5961
* Thu Jun  6 2024 denis.kirjanov@suse.com
- inet: inet_defrag: prevent sk release while still in use
  (CVE-2024-26921 bsc#1223138).
- commit 2016faf
* Thu Jun  6 2024 tonyj@suse.de
- perf ui browser: Avoid SEGV on title (git fixes).
- commit 1578c22
* Wed Jun  5 2024 tonyj@suse.de
- perf pmu: Count sys and cpuid JSON events separately (git
  fixes).
- perf stat: Don't display metric header for non-leader uncore
  events (git-fixes).
- perf daemon: Fix file leak in daemon_session__control
  (git-fixes).
- perf symbols: Fix ownership of string in dso__load_vmlinux()
  (git-fixes).
- perf thread: Fixes to thread__new() related to initializing comm
  (git-fixes).
- perf report: Avoid SEGV in report__setup_sample_type()
  (git-fixes).
- perf ui browser: Don't save pointer to stack memory (git-fixes).
- perf bench internals inject-build-id: Fix trap divide when
  collecting just one DSO (git-fixes).
- perf intel-pt: Fix unassigned instruction op (discovered by
  MemorySanitizer) (git-fixes).
- perf test shell arm_coresight: Increase buffer size for
  Coresight basic tests (git-fixes).
- perf docs: Document bpf event modifier (git-fixes).
- perf bench uprobe: Remove lib64 from libc.so.6 binary path
  (git-fixes).
- perf record: Fix debug message placement for test consumption
  (git-fixes).
- perf tests: Apply attributes to all events in object code
  reading test (git-fixes).
- perf tests: Make "test data symbol" more robust on Neoverse N1
  (git-fixes).
- perf annotate: Fix annotation_calc_lines() to pass correct
  address to get_srcline() (git-fixes).
- perf stat: Do not fail on metrics on s390 z/VM systems
  (git-fixes).
- perf sched timehist: Fix -g/--call-graph option failure
  (git-fixes).
- perf annotate: Get rid of duplicate --group option item
  (git-fixes).
- perf probe: Add missing libgen.h header needed for using
  basename() (git-fixes).
- perf record: Delete session after stopping sideband thread
  (git-fixes).
- perf auxtrace: Fix multiple use of --itrace option (git-fixes).
- perf script: Show also errors for --insn-trace option
  (git-fixes).
- perf lock contention: Add a missing NULL check (git-fixes).
- perf vendor events amd: Fix Zen 4 cache latency events
  (git-fixes).
- libperf evlist: Avoid out-of-bounds access (git-fixes).
- perf pmu: Fix a potential memory leak in perf_pmu__lookup()
  (git-fixes).
- perf print-events: make is_event_supported() more robust
  (git-fixes).
- perf list: fix short description for some cache events
  (git-fixes).
- perf metric: Don't remove scale from counts (git-fixes).
- perf stat: Avoid metric-only segv (git-fixes).
- perf expr: Fix "has_event" function for metric style events
  (git-fixes).
- perf srcline: Add missed addr2line closes (git-fixes).
- perf thread_map: Free strlist on normal path in
  thread_map__new_by_tid_str() (git-fixes).
- perf bpf: Clean up the generated/copied vmlinux.h (git-fixes).
- perf jevents: Drop or simplify small integer values (git-fixes).
- perf evsel: Fix duplicate initialization of data->id in
  evsel__parse_sample() (git-fixes).
- perf pmu: Treat the msr pmu as software (git-fixes).
- perf record: Check conflict between '--timestamp-filename'
  option and pipe mode before recording (git-fixes).
- perf record: Fix possible incorrect free in
  record__switch_output() (git-fixes).
- perf vendor events amd: Add Zen 4 memory controller events
  (git-fixes).
- perf top: Uniform the event name for the hybrid machine
  (git-fixes).
- perf top: Use evsel's cpus to replace user_requested_cpus
  (git-fixes).
- commit a1f9340
* Wed Jun  5 2024 jack@suse.cz
- nfs: Bump default write congestion size (bsc#1218442).
- commit 563bd84
* Wed Jun  5 2024 jack@suse.cz
- nfs: Avoid flushing many pages with NFS_FILE_SYNC (bsc#1218442).
- commit 1092c12
* Wed Jun  5 2024 dsterba@suse.com
- blacklist.conf: remove fix for CVE-2024-35956 bsc#1224674, not applicable
- Delete patches.suse/btrfs-qgroup-fix-qgroup-prealloc-rsv-leak-in-subvolu.patch.
  Quoting bsc#1225945#c11:
  "So the upstream 6.5 kernel commit (1b53e51a4a8f ("btrfs: don't commit
  transaction for every subvol create")
  ) was never backported to SLE, so that fix eb96e221937a ("btrfs: fix
  unwritten extent buffer after snapshotting a new subvolume") was never
  backported."
- commit d947258
* Wed Jun  5 2024 oneukum@suse.com
- crypto: iaa - Fix async_disable descriptor leak (CVE-2024-35926
  bsc#1224655).
- commit c5d6a9b
* Wed Jun  5 2024 shung-hsi.yu@suse.com
- xsk: validate user input for XDP_{UMEM|COMPLETION}_FILL_RING
  (bsc#1224575 CVE-2024-35976).
- commit 794d5e8
* Wed Jun  5 2024 shung-hsi.yu@suse.com
- bpf, skmsg: Fix NULL pointer dereference in
  sk_psock_skb_ingress_enqueue (bsc#1225761 CVE-2024-36938).
- commit 2f2e817
* Wed Jun  5 2024 davide.benini@suse.com
- ipv4: check for NULL idev in ip_route_use_hint()
  (CVE-2024-36008 bsc#1224540)
- commit d751eb5
* Tue Jun  4 2024 ematsumiya@suse.de
- smb3: fix lock ordering potential deadlock in
  cifs_sync_mid_result (bsc#1225172, bsc#1224549, CVE-2024-35998).
- commit 98bfec0
* Tue Jun  4 2024 ematsumiya@suse.de
- smb: client: fix potential deadlock when releasing mids
  (bsc#1225172, bsc#1225548, CVE-2023-52757).
- commit 1b322a8
* Tue Jun  4 2024 iivanov@suse.de
- octeontx2-af: avoid off-by-one read from userspace (bsc#1225762 CVE-2024-36957)
- commit d3dcfbb
* Mon Jun  3 2024 krisman@suse.de
- kabi/severities: Ignore io_uring internal symbols
- commit 0e91c09
* Mon Jun  3 2024 tonyj@suse.de
- perf/x86: Fix out of range data (git-fixes).
- perf/x86/intel/ds: Don't clear ->pebs_data_cfg for the last
  PEBS event (git-fixes).
- perf/x86/amd/lbr: Discard erroneous branch entries (git-fixes).
- commit 664d77f
* Mon Jun  3 2024 ematsumiya@suse.de
- cifs: failure to add channel on iface should bump up weight
  (git-fixes, bsc#1225172).
- commit 007b237
* Mon Jun  3 2024 ematsumiya@suse.de
- smb: client: fix parsing of SMB3.1.1 POSIX create context
  (git-fixes, bsc#1225172).
- commit 5f27f69
* Mon Jun  3 2024 ematsumiya@suse.de
- Revert "cifs: reconnect work should have reference on server
  struct" (git-fixes, bsc#1225172).
- commit 3ca4c0c
* Mon Jun  3 2024 ematsumiya@suse.de
- cifs: fix leak of iface for primary channel (git-fixes,
  bsc#1225172).
- commit b7eb8e8
* Mon Jun  3 2024 ematsumiya@suse.de
- smb: client: fix mount when dns_resolver key is not available
  (git-fixes, bsc#1225172).
- commit 28edb5c
* Mon Jun  3 2024 dwagner@suse.de
- scsi: lpfc: Copyright updates for 14.4.0.2 patches
  (bsc#1225842).
- scsi: lpfc: Update lpfc version to 14.4.0.2 (bsc#1225842).
- scsi: lpfc: Add support for 32 byte CDBs (bsc#1225842).
- scsi: lpfc: Change lpfc_hba hba_flag member into a bitmask
  (bsc#1225842).
  Refresh:
  - patches.suse/lpfc-reintroduce-old-irq-probe-logic.patch
- scsi: lpfc: Introduce rrq_list_lock to protect active_rrq_list
  (bsc#1225842).
- scsi: lpfc: Clear deferred RSCN processing flag when driver
  is unloading (bsc#1225842).
- scsi: lpfc: Update logging of protection type for T10 DIF I/O
  (bsc#1225842).
- scsi: lpfc: Change default logging level for unsolicited CT
  MIB commands (bsc#1225842).
- commit 5a56384
* Mon Jun  3 2024 dwagner@suse.de
- nvmet: fix ns enable/disable possible hang (git-fixes).
- nvme-multipath: fix io accounting on failover (git-fixes).
- nvme: fix multipath batched completion accounting (git-fixes).
- commit ed3b392
* Mon Jun  3 2024 mfranc@suse.cz
- Update
  patches.suse/ALSA-hda-intel-sdw-acpi-fix-usage-of-device_get_name.patch
  (git-fixes CVE-2024-36955).
- Update
  patches.suse/ARM-9381-1-kasan-clear-stale-stack-poison.patch
  (git-fixes bsc#1225715 CVE-2024-36906).
- Update
  patches.suse/Bluetooth-HCI-Fix-potential-null-ptr-deref.patch
  (git-fixes bsc#1225579 CVE-2024-36011).
- Update
  patches.suse/Bluetooth-L2CAP-Fix-slab-use-after-free-in-l2cap_con.patch
  (git-fixes bsc#1225578 CVE-2024-36013).
- Update
  patches.suse/Bluetooth-msft-fix-slab-use-after-free-in-msft_do_cl.patch
  (git-fixes bsc#1225502 CVE-2024-36012).
- Update
  patches.suse/Bluetooth-qca-add-missing-firmware-sanity-checks.patch
  (git-fixes bsc#1225722 CVE-2024-36880).
- Update
  patches.suse/Bluetooth-qca-fix-firmware-check-error-path.patch
  (git-fixes CVE-2024-36942).
- Update
  patches.suse/Bluetooth-qca-fix-info-leak-when-fetching-fw-build-i.patch
  (git-fixes bsc#1225720 CVE-2024-36032).
- Update
  patches.suse/KVM-x86-mmu-Write-protect-L2-SPTEs-in-TDP-MMU-when-c.patch
  (git-fixes bsc#1223749 CVE-2024-26990).
- Update
  patches.suse/KVM-x86-pmu-Disable-support-for-adaptive-PEBS.patch
  (git-fixes bsc#1223692 CVE-2024-26992).
- Update
  patches.suse/Reapply-drm-qxl-simplify-qxl_fence_wait.patch
  (stable-fixes CVE-2024-36944).
- Update
  patches.suse/USB-core-Fix-access-violation-during-port-device-rem.patch
  (git-fixes bsc#1225734 CVE-2024-36896).
- Update
  patches.suse/amd-amdkfd-sync-all-devices-to-wait-all-processes-be.patch
  (stable-fixes CVE-2024-36949).
- Update patches.suse/bpf-Check-bloom-filter-map-value-size.patch
  (bsc#1224488 CVE-2024-35905 bsc#1225766 CVE-2024-36918).
- Update
  patches.suse/clk-sunxi-ng-h6-Reparent-CPUX-during-PLL-CPUX-rate-c.patch
  (git-fixes bsc#1225692 CVE-2023-52882).
- Update
  patches.suse/cxl-pci-Fix-disabling-memory-if-DVSEC-CXL-Range-does.patch
  (git-fixes CVE-2024-26761).
- Update
  patches.suse/drm-amd-display-Atom-Integrated-System-Info-v2_2-for.patch
  (stable-fixes bsc#1225735 CVE-2024-36897).
- Update
  patches.suse/drm-amd-pm-fixes-a-random-hang-in-S4-for-SMU-v13.0.4.patch
  (stable-fixes bsc#1225705 CVE-2024-36026).
- Update
  patches.suse/drm-amdkfd-range-check-cp-bad-op-exception-interrupt.patch
  (stable-fixes CVE-2024-36951).
- Update
  patches.suse/drm-arm-malidp-fix-a-possible-null-pointer-dereferen.patch
  (git-fixes bsc#1225593 CVE-2024-36014).
- Update
  patches.suse/drm-nouveau-firmware-Fix-SG_DEBUG-error-with-nvkm_fi.patch
  (stable-fixes bsc#1225728 CVE-2024-36885).
- Update
  patches.suse/efi-unaccepted-touch-soft-lockup-during-memory-accept.patch
  (git-fixes bsc#1225773 CVE-2024-36936).
- Update
  patches.suse/firewire-ohci-mask-bus-reset-interrupts-between-ISR-.patch
  (stable-fixes CVE-2024-36950).
- Update patches.suse/gpiolib-cdev-fix-uninitialised-kfifo.patch
  (git-fixes bsc#1225736 CVE-2024-36898).
- Update
  patches.suse/i40e-fix-vf-may-be-used-uninitialized-in-this-functi.patch
  (git-fixes bsc#1225698 CVE-2024-36020).
- Update
  patches.suse/maple_tree-fix-mas_empty_area_rev-null-pointer-deref.patch
  (git-fixes bsc#1225710 CVE-2024-36891).
- Update
  patches.suse/mm-slab-make-__free-kfree-accept-error-pointers.patch
  (git-fixes bsc#1225714 CVE-2024-36890).
- Update
  patches.suse/mmc-sdhci-msm-pervent-access-to-suspended-controller.patch
  (git-fixes bsc#1225708 CVE-2024-36029).
- Update
  patches.suse/net-hns3-fix-kernel-crash-when-devlink-reload-during.patch
  (git-fixes bsc#1225699 CVE-2024-36021).
- Update
  patches.suse/nouveau-dmem-handle-kcalloc-allocation-failure.patch
  (git-fixes CVE-2024-26943).
- Update
  patches.suse/nouveau-uvmm-fix-addr-range-calcs-for-remap-operatio.patch
  (git-fixes bsc#1225694 CVE-2024-36018).
- Update
  patches.suse/pinctrl-core-delete-incorrect-free-in-pinctrl_enable.patch
  (git-fixes CVE-2024-36940).
- Update
  patches.suse/pinctrl-devicetree-fix-refcount-leak-in-pinctrl_dt_t.patch
  (git-fixes CVE-2024-36959).
- Update
  patches.suse/ppdev-Add-an-error-check-in-register_device.patch
  (git-fixes bsc#1225640 CVE-2024-36015).
- Update patches.suse/qibfs-fix-dentry-leak.patch (git-fixes
  CVE-2024-36947).
- Update
  patches.suse/regmap-maple-Fix-cache-corruption-in-regcache_maple_.patch
  (git-fixes bsc#1225695 CVE-2024-36019).
- Update
  patches.suse/s390-cio-Ensure-the-copied-buf-is-NUL-terminated.patch
  (git-fixes bsc#1223869 bsc#1225747 CVE-2024-36931).
- Update
  patches.suse/s390-qeth-Fix-kernel-panic-after-setting-hsuid.patch
  (git-fixes bsc#1223874 bsc#1225775 CVE-2024-36928).
- Update
  patches.suse/scsi-qla2xxx-Fix-off-by-one-in-qla_edif_app_getstats.patch
  (git-fixes bsc#1225704 CVE-2024-36025).
- Update
  patches.suse/spi-fix-null-pointer-dereference-within-spi_sync.patch
  (git-fixes CVE-2024-36930).
- Update
  patches.suse/swiotlb-Fix-double-allocation-of-slots-due-to-broken-alignment-handling.patch
  (bsc#1224331 bsc#1224602 CVE-2024-35814).
- Update
  patches.suse/tty-n_gsm-fix-possible-out-of-bounds-in-gsm0_receive.patch
  (git-fixes bsc#1225642 CVE-2024-36016).
- Update
  patches.suse/usb-gadget-f_fs-Fix-race-between-aio_cancel-and-AIO-.patch
  (git-fixes bsc#1225749 CVE-2024-36894).
- Update
  patches.suse/usb-gadget-uvc-use-correct-buffer-size-when-parsing-.patch
  (git-fixes bsc#1225750 CVE-2024-36895).
- Update
  patches.suse/usb-typec-tcpm-Check-for-port-partner-validity-befor.patch
  (git-fixes bsc#1225748 CVE-2024-36893).
- Update
  patches.suse/wifi-iwlwifi-mvm-guard-against-invalid-STA-ID-on-rem.patch
  (stable-fixes bsc#1225769 CVE-2024-36921).
- Update
  patches.suse/wifi-iwlwifi-read-txq-read_ptr-under-lock.patch
  (stable-fixes CVE-2024-36922).
- Update
  patches.suse/wifi-nl80211-don-t-free-NULL-coalescing-rule.patch
  (git-fixes CVE-2024-36941).
- Update
  patches.suse/x86-efistub-Call-mixed-mode-boot-services-on-the-firmware-.patch
  (git-fixes bsc#1224742 CVE-2024-35803).
- commit 539780f
* Mon Jun  3 2024 msuchanek@suse.de
- powerpc/pseries/lparcfg: drop error message from guest name
  lookup (bsc#1187716 ltc#193451 git-fixes).
- commit ceab637
* Mon Jun  3 2024 msuchanek@suse.de
- powerpc/uaccess: Use YZ asm constraint for ld (bsc#1194869).
- powerpc/uaccess: Fix build errors seen with GCC 13/14
  (bsc#1194869).
- commit 46b5d84
* Mon Jun  3 2024 shung-hsi.yu@suse.com
- Add reference to L3 bsc#1225765 in BPF control flow graph and precision backtrack fixes (bsc#1225756)
  The L3 bsc#1225765 was created seperately since our customer requires
  PTF.
- Update patches.suse/bpf-fix-precision-backtracking-instruction-iteration.patch
- Update patches.suse/bpf-handle-ldimm64-properly-in-check_cfg.patch
- Update patches.suse/selftests-bpf-add-edge-case-backtracking-logic-test.patch
- Update patches.suse/selftests-bpf-precision-tracking-test-for-BPF_NEG-an.patch
- commit 054635e
* Mon Jun  3 2024 mkubecek@suse.cz
- netfilter: nf_tables: release mutex after nft_gc_seq_end from
  abort path (CVE-2024-26925 bsc#1223390).
- commit 578a709
* Mon Jun  3 2024 mkubecek@suse.cz
- series.conf: cleanup
  Fix subsection header to silence series_insert error.
- commit 4628dc3
* Sat Jun  1 2024 tiwai@suse.de
- ASoC: wm_adsp: Add missing MODULE_DESCRIPTION() (git-fixes).
- ALSA: ump: Set default protocol when not given explicitly
  (git-fixes).
- ALSA/hda: intel-dsp-config: reduce log verbosity (git-fixes).
- ALSA: core: Remove debugfs at disconnection (git-fixes).
- commit f8e0906
* Sat Jun  1 2024 tiwai@suse.de
- drm/panel: sitronix-st7789v: fix display size for
  jt240mhqs_hwt_ek_e3 panel (git-fixes).
- drm/panel: sitronix-st7789v: tweak timing for
  jt240mhqs_hwt_ek_e3 panel (git-fixes).
- drm/panel: sitronix-st7789v: fix timing for jt240mhqs_hwt_ek_e3
  panel (git-fixes).
- dma-buf/sw-sync: don't enable IRQ from sync_print_obj()
  (git-fixes).
- Revert "drm/amdkfd: fix gfx_target_version for certain 11.0.3
  devices" (stable-fixes).
- drm/amd/display: Enable colorspace property for MST connectors
  (git-fixes).
- drm/i915: Fix audio component initialization (git-fixes).
- drm/i915/dpt: Make DPT object unshrinkable (git-fixes).
- drm/i915/gt: Fix CCS id's calculation for CCS mode setting
  (git-fixes).
- drm/i915/guc: avoid FIELD_PREP warning (git-fixes).
- drm/i915/gt: Disarm breadcrumbs if engines are already idle
  (git-fixes).
- drm/shmem-helper: Fix BUG_ON() on mmap(PROT_WRITE, MAP_PRIVATE)
  (git-fixes).
- hwmon: (shtc1) Fix property misspelling (git-fixes).
- hwmon: (intel-m10-bmc-hwmon) Fix multiplier for N6000 board
  power sensor (git-fixes).
- spi: stm32: Don't warn about spurious interrupts (git-fixes).
- spi: Don't mark message DMA mapped when no transfer in it is
  (git-fixes).
- dma-mapping: benchmark: handle NUMA_NO_NODE correctly
  (git-fixes).
- dma-mapping: benchmark: fix node id validation (git-fixes).
- ALSA: seq: ump: Fix swapped song position pointer data
  (git-fixes).
- ASoC: SOF: ipc4-topology: Fix input format query of process
  modules without base extension (git-fixes).
- ALSA: seq: Fix yet another spot for system message conversion
  (git-fixes).
- ALSA: ump: Don't accept an invalid UMP protocol number
  (git-fixes).
- ALSA: ump: Don't clear bank selection after sending a program
  change (git-fixes).
- ALSA: seq: Fix incorrect UMP type for system messages
  (git-fixes).
- ALSA: seq: Don't clear bank selection at event -> UMP MIDI2
  conversion (git-fixes).
- ALSA: seq: Fix missing bank setup between MIDI1/MIDI2 UMP
  conversion (git-fixes).
- ALSA: hda/realtek: Adjust G814JZR to use SPI init for amp
  (git-fixes).
- docs: netdev: Fix typo in Signed-off-by tag (git-fixes).
- net: usb: smsc95xx: fix changing LED_SEL bit value updated
  from EEPROM (git-fixes).
- net: phy: micrel: set soft_reset callback to genphy_soft_reset
  for KSZ8061 (git-fixes).
- commit e5505a5
* Sat Jun  1 2024 tiwai@suse.de
- Add alt-commit to a nouveau patch
- commit 0024d10
* Fri May 31 2024 dsterba@suse.com
- 9p: add missing locking around taking dentry fid list (git-fixes)
- commit 581af2d
* Fri May 31 2024 dsterba@suse.com
- ecryptfs: Fix buffer size for tag 66 packet (git-fixes)
- commit 17aae28
* Fri May 31 2024 davide.benini@suse.com
- llc: call sock_orphan() at release time
  (CVE-2024-26625 bsc#1221086)
- commit fe6bd4d
* Fri May 31 2024 dsterba@suse.com
- fs/9p: translate O_TRUNC into OTRUNC (git-fixes)
- commit e03e9a5
* Fri May 31 2024 shung-hsi.yu@suse.com
- bpf: Fix precision tracking for BPF_ALU | BPF_TO_BE | BPF_END
  (git-fixes).
- commit e824dba
* Fri May 31 2024 dsterba@suse.com
- fs/9p: only translate RWX permissions for plain 9P2000 (git-fixes)
- commit ebd0dc6
* Fri May 31 2024 shung-hsi.yu@suse.com
- selftests/bpf: precision tracking test for BPF_NEG and BPF_END
  (bsc#1225756).
- commit a410d73
* Fri May 31 2024 shung-hsi.yu@suse.com
- selftests/bpf: add edge case backtracking logic test
  (bsc#1225756).
- bpf: fix precision backtracking instruction iteration
  (bsc#1225756).
- bpf: handle ldimm64 properly in check_cfg() (bsc#1225756).
- commit 9cbb99b
* Fri May 31 2024 dsterba@suse.com
- fs: indicate request originates from old mount API (git-fixes)
- commit 0754468
* Fri May 31 2024 dsterba@suse.com
- locks: fix KASAN: use-after-free in trace_event_raw_event_filelock_lock (git-fixes)
- commit 4c48f9f
* Fri May 31 2024 dsterba@suse.com
- fs: Fix error checking for d_hash_and_lookup() (git-fixes)
- commit c90513f
* Fri May 31 2024 dwagner@suse.de
- nvme-pci: Add quirk for broken MSIs (git-fixes).
- nvme: fix warn output about shared namespaces without
  CONFIG_NVME_MULTIPATH (git-fixes).
- drivers/nvme: Add quirks for device 126f:2262 (git-fixes).
- commit fff60eb
* Fri May 31 2024 dwagner@suse.de
- Update
  patches.suse/nvme-ensure-disabling-pairs-with-unquiesce.patch
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535
  bsc#1224534).
- commit d9497f3
* Fri May 31 2024 iivanov@suse.de
- octeontx2-af: fix the double free in rvu_npc_freemem() (bsc#1225712 CVE-2024-36030)
- commit 294ca99
* Fri May 31 2024 tbogendoerfer@suse.de
- idpf: extend tx watchdog timeout (bsc#1224137).
- commit fbf0ed6
* Fri May 31 2024 jgross@suse.com
- kABI fix of KVM: x86/pmu: Allow programming events that match
  unsupported arch events (bsc#1225696).
- Refresh
  patches.suse/KVM-x86-pmu-Allow-programming-events-that-match-unsu.patch.
- commit 0e4ccf5
* Thu May 30 2024 iivanov@suse.de
- swiotlb: extend buffer pre-padding to alloc_align_mask if necessary (bsc#1224331)
- commit c148fd3
* Thu May 30 2024 davide.benini@suse.com
- calipso: fix memory leak in netlbl_calipso_add_pass()
  (CVE-2023-52698 bsc#1224621)
- commit 5fc90b9
* Thu May 30 2024 jslaby@suse.cz
- kabi/severities: ignore IMS functions
  They were dropped in previous patches. Noone is supposed to use them.
- commit 494909c
* Thu May 30 2024 ematsumiya@suse.de
- smb: client: set correct id, uid and cruid for multiuser
  automounts (bsc#1223011, CVE-2024-26822).
- commit 6fce785
* Thu May 30 2024 ematsumiya@suse.de
- smb: client: fix potential OOBs in smb2_parse_contexts()
  (bsc#1220148, CVE-2023-52434).
- commit a00a7f6
* Wed May 29 2024 colyli@suse.de
- dm-integrity: fix a memory leak when rechecking the data
  (bsc#1223077, CVE-2024-26860).
- commit 29984e7
* Wed May 29 2024 fdmanana@suse.com
- btrfs: zoned: don't skip block groups with 100%% zone unusable
  (bsc#1220120).
- btrfs: don't refill whole delayed refs block reserve when
  starting transaction (bsc#1220120).
- btrfs: add new unused block groups to the list of unused block
  groups (bsc#1220120).
- btrfs: do not delete unused block group if it may be used soon
  (bsc#1220120).
- btrfs: add and use helper to check if block group is used
  (bsc#1220120).
- btrfs: always reserve space for delayed refs when starting
  transaction (bsc#1220120).
- btrfs: stop doing excessive space reservation for csum deletion
  (bsc#1220120).
- btrfs: remove pointless initialization at
  btrfs_delayed_refs_rsv_release() (bsc#1220120).
- btrfs: reserve space for delayed refs on a per ref basis
  (bsc#1220120).
- btrfs: allow to run delayed refs by bytes to be released
  instead of count (bsc#1220120).
- btrfs: simplify check for extent item overrun at
  lookup_inline_extent_backref() (bsc#1220120).
- btrfs: return -EUCLEAN if extent item is missing when searching
  inline backref (bsc#1220120).
- btrfs: use a single variable for return value at
  lookup_inline_extent_backref() (bsc#1220120).
- btrfs: use a single variable for return value at
  run_delayed_extent_op() (bsc#1220120).
- btrfs: remove pointless 'ref_root' variable from
  run_delayed_data_ref() (bsc#1220120).
- btrfs: initialize key where it's used when running delayed
  data ref (bsc#1220120).
- btrfs: remove refs_to_drop argument from __btrfs_free_extent()
  (bsc#1220120).
- btrfs: remove refs_to_add argument from __btrfs_inc_extent_ref()
  (bsc#1220120).
- btrfs: remove the refcount warning/check at
  btrfs_put_delayed_ref() (bsc#1220120).
- btrfs: remove unnecessary logic when running new delayed
  references (bsc#1220120).
- btrfs: pass a space_info argument to
  btrfs_reserve_metadata_bytes() (bsc#1220120).
- btrfs: log message if extent item not found when running
  delayed extent op (bsc#1220120).
- btrfs: remove redundant BUG_ON() from __btrfs_inc_extent_ref()
  (bsc#1220120).
- btrfs: move btrfs_free_excluded_extents() into block-group.c
  (bsc#1220120).
- btrfs: open code trivial btrfs_add_excluded_extent()
  (bsc#1220120).
- btrfs: make find_first_extent_bit() return a boolean
  (bsc#1220120).
- btrfs: make btrfs_destroy_pinned_extent() return void
  (bsc#1220120).
- btrfs: make btrfs_destroy_marked_extents() return void
  (bsc#1220120).
- btrfs: rename add_new_free_space() to btrfs_add_new_free_space()
  (bsc#1220120).
- btrfs: update documentation for add_new_free_space()
  (bsc#1220120).
- commit 37b05cd
* Wed May 29 2024 nstange@suse.de
- Refresh
  patches.suse/0002-PKCS-7-Check-codeSigning-EKU-for-kernel-module-and-k.patch (bsc#1222771).
  In preparation of enabling CONFIG_FIPS_SIGNATURE_SELFTEST, amend the
  missing 'usage' argument in the pkcs7_validate_trust() invocation
  from  the PKCS#7 selftest.
- commit cfa0827
* Wed May 29 2024 pmladek@suse.com
- printk: Let no_printk() use _printk() (bsc#1225618).
- commit 2abd745
* Wed May 29 2024 pmladek@suse.com
- printk: Update @console_may_schedule in
  console_trylock_spinning() (bsc#1225616).
- commit e5e7ac5
* Wed May 29 2024 mkoutny@suse.com
- af_unix: Update unix_sk(sk)->oob_skb under sk_receive_queue lock
  (CVE-2024-26676 bsc#1222380).
- af_unix: Don't peek OOB data without MSG_OOB (CVE-2024-26676 bsc#1222380).
- af_unix: Clear stale u->oob_skb (CVE-2024-26676 bsc#1222380).
- commit 7722c8d
* Wed May 29 2024 mkoutny@suse.com
- af_unix: fix use-after-free in unix_stream_read_actor()
  (CVE-2023-52772 bsc#1224989).
- commit 0f5ff3f
* Wed May 29 2024 nstange@suse.de
- certs: Add ECDSA signature verification self-test (bsc#1222777).
- Port "certs: Add ECDSA signature verification self-test".
- Enable new CONFIG_FIPS_SIGNATURE_SELFTEST_ECDSA.
- Refresh
  0002-PKCS-7-Check-codeSigning-EKU-for-kernel-module-and-k.patch:
  trivial context update to Kconfig
- commit 7338b2e
* Wed May 29 2024 pmladek@suse.com
- dump_stack: Do not get cpu_sync for panic CPU (bsc#1225607).
- commit 3d953e1
* Wed May 29 2024 pmladek@suse.com
- printk: Avoid non-panic CPUs writing to ringbuffer
  (bsc#1225607).
- commit 9a41cad
* Wed May 29 2024 nstange@suse.de
- certs: Move RSA self-test data to separate file (bsc#1222777).
- Port "certs: Move RSA self-test data to separate file".
- Enable new CONFIG_FIPS_SIGNATURE_SELFTEST_RSA.
- Refresh
  patches.suse/0002-PKCS-7-Check-codeSigning-EKU-for-kernel-module-and-k.patch:
  - trivial context update to Kconfig,
  - account for changed pkcs7_validate_trust() callsite amended by
    this refreshed patch.
- commit 248ad2a
* Wed May 29 2024 pmladek@suse.com
- printk: Disable passing console lock owner completely during
  panic() (bsc#1225607).
- commit a31a4d6
* Wed May 29 2024 pmladek@suse.com
- printk: ringbuffer: Skip non-finalized records in panic
  (bsc#1225607).
- commit 8be42db
* Wed May 29 2024 nstange@suse.de
- Enable CONFIG_FIPS_SIGNATURE_SELFTEST (bsc#1222771)
- commit 4ade1c7
* Wed May 29 2024 pmladek@suse.com
- printk: Wait for all reserved records with pr_flush()
  (bsc#1225607).
- commit 4a07b6c
* Wed May 29 2024 pmladek@suse.com
- printk: ringbuffer: Cleanup reader terminology (bsc#1225607).
- commit b3f2a50
* Wed May 29 2024 pmladek@suse.com
- printk: Add this_cpu_in_panic() (bsc#1225607).
- commit 8afb830
* Wed May 29 2024 pmladek@suse.com
- printk: For @suppress_panic_printk check for other CPU in panic
  (bsc#1225607).
- commit f2045e0
* Wed May 29 2024 pmladek@suse.com
- printk: ringbuffer: Clarify special lpos values (bsc#1225607).
- commit d1338d8
* Wed May 29 2024 pmladek@suse.com
- printk: ringbuffer: Do not skip non-finalized records with
  prb_next_seq() (bsc#1225607).
- commit 1ea687c
* Wed May 29 2024 mkoutny@suse.com
- prctl: generalize PR_SET_MDWE support check to be per-arch
  (bsc#1225610).
- commit b86afe4
* Wed May 29 2024 pmladek@suse.com
- printk: Use prb_first_seq() as base for 32bit seq macros
  (bsc#1225607).
- commit ea93856
* Wed May 29 2024 pmladek@suse.com
- printk: Adjust mapping for 32bit seq macros (bsc#1225607).
- commit e9e690d
* Wed May 29 2024 mkoutny@suse.com
- blk-cgroup: fix list corruption from reorder of WRITE ->lqueued
  (bsc#1225605).
- blk-cgroup: fix list corruption from resetting io stat
  (bsc#1225605).
- commit c132bd3
* Wed May 29 2024 pmladek@suse.com
- printk: nbcon: Relocate 32bit seq macros (bsc#1225607).
- commit 6293dd4
* Wed May 29 2024 pmladek@suse.com
- printk: Rename abandon_console_lock_in_panic() to
  other_cpu_in_panic() (bsc#1225607).
- commit 74aec78
* Wed May 29 2024 pmladek@suse.com
- printk: Consolidate console deferred printing (bsc#1225607).
- commit c45374f
* Wed May 29 2024 pmladek@suse.com
- printk: Do not take console lock for console_flush_on_panic()
  (bsc#1225607).
- commit ca5038f
* Wed May 29 2024 pmladek@suse.com
- printk: Keep non-panic-CPUs out of console lock (bsc#1225607).
- commit 2d7bf36
* Wed May 29 2024 pmladek@suse.com
- printk: Reduce console_unblank() usage in unsafe scenarios
  (bsc#1225607).
- commit 54eafaa
* Wed May 29 2024 pmladek@suse.com
- livepatch: Fix missing newline character in
  klp_resolve_symbols() (bsc#1223539).
- commit af0f908
* Wed May 29 2024 shung-hsi.yu@suse.com
- cpumap: Zero-initialise xdp_rxq_info struct before running
  XDP program (bsc#1224718 CVE-2024-27431).
- commit fb7728a
* Wed May 29 2024 shung-hsi.yu@suse.com
- kABI: bpf: struct bpf_link and bpf_link_ops kABI workaround
  (bsc#1224531 CVE-2024-35860).
- commit 7744489
* Wed May 29 2024 jslaby@suse.cz
- Revert "PCI/MSI: Provide IMS (Interrupt Message Store) support"
  (git-fixes).
- Revert "PCI/MSI: Provide pci_ims_alloc/free_irq()" (git-fixes).
- Revert "PCI/MSI: Provide stubs for IMS functions" (git-fixes).
- commit 0dc394b
* Wed May 29 2024 jslaby@suse.cz
- ppdev: Add an error check in register_device (git-fixes).
- commit cfdb6a2
* Wed May 29 2024 shung-hsi.yu@suse.com
- bpf: support deferring bpf_link dealloc to after RCU grace
  period (bsc#1224531 CVE-2024-35860).
- bpf: put uprobe link's path and task in release callback
  (bsc#1224531 CVE-2024-35860).
- commit a95dd44
* Wed May 29 2024 jlee@suse.com
- Bluetooth: ISO: Fix not validating setsockopt user input
  (bsc#1224581 CVE-2024-35964).
- commit 9d49d44
* Wed May 29 2024 jlee@suse.com
- Bluetooth: ISO: Add support for BT_PKT_STATUS (bsc#1224581
  CVE-2024-35964).
- commit cadac48
* Wed May 29 2024 jlee@suse.com
- Bluetooth: af_bluetooth: Make BT_PKT_STATUS generic (bsc#1224581
  CVE-2024-35964).
- Refresh
  patches.suse/Bluetooth-SCO-Fix-not-validating-setsockopt-user-inp.patch.
- commit 774d916
* Wed May 29 2024 shung-hsi.yu@suse.com
- bpf, sockmap: Prevent lock inversion deadlock in map delete elem
  (bsc#1209657 CVE-2023-0160 bsc#1224511 CVE-2024-35895).
- commit fa3fb92
* Wed May 29 2024 tiwai@suse.de
- tpm_tis_spi: Account for SPI header when allocating TPM SPI
  xfer buffer (git-fixes).
- commit 6d124e2
* Tue May 28 2024 ematsumiya@suse.de
- smb: client: fix potential UAF in cifs_debug_files_proc_show()
  (bsc#1225172, bsc#1223532, CVE-2024-26928).
- commit 1089c4a
* Tue May 28 2024 ematsumiya@suse.de
- smb3: missing lock when picking channel (bsc#1225172,
  bsc#1224550, CVE-2024-35999).
- commit d7be3a1
* Tue May 28 2024 ematsumiya@suse.de
- smb: client: fix potential UAF in
  cifs_signal_cifsd_for_reconnect() (bsc#1225172, bsc#1224766,
  CVE-2024-35861).
- commit 0d45a76
* Tue May 28 2024 ematsumiya@suse.de
- smb: client: fix potential UAF in smb2_is_network_name_deleted()
  (bsc#1225172, bsc#1224764, CVE-2024-35862).
- commit 6632102
* Tue May 28 2024 ematsumiya@suse.de
- smb: client: fix potential UAF in is_valid_oplock_break()
  (bsc#1225172, bsc#1224763, CVE-2024-35863).
- commit 06c348c
* Tue May 28 2024 ematsumiya@suse.de
- smb: client: fix potential UAF in smb2_is_valid_oplock_break()
  (bsc#1225172, bsc#1224668, CVE-2024-35865).
- commit 60bea5b
* Tue May 28 2024 ematsumiya@suse.de
- smb: client: fix potential UAF in smb2_is_valid_lease_break()
  (bsc#1225172, bsc#1224765, CVE-2024-35864).
- commit 52cc8d8
* Tue May 28 2024 ematsumiya@suse.de
- smb: client: fix potential UAF in cifs_stats_proc_show()
  (bsc#1225172, bsc#1224664, CVE-2024-35867).
- commit 3a82d6a
* Tue May 28 2024 ematsumiya@suse.de
- smb: client: fix potential UAF in cifs_stats_proc_write()
  (bsc#1225172, bsc#1224678, CVE-2024-35868).
- commit fb4bf4e
* Tue May 28 2024 ematsumiya@suse.de
- smb: client: fix potential UAF in cifs_dump_full_key()
  (bsc#1225172, bsc#1224667, CVE-2024-35866).
- commit b0961fe
* Tue May 28 2024 ematsumiya@suse.de
- smb: client: guarantee refcounted children from parent session
  (bsc#1225172, bsc#1224679, CVE-2024-35869).
- commit 97642d2
* Tue May 28 2024 ematsumiya@suse.de
- smb: client: fix UAF in smb2_reconnect_server() (bsc#1225172,
  bsc#1224672, CVE-2024-35870).
- commit e205efa
* Tue May 28 2024 ematsumiya@suse.de
- smb: Fix regression in writes when non-standard maximum write
  size negotiated (bsc#1222464, CVE-2024-26692).
- commit 761be1f
* Tue May 28 2024 ematsumiya@suse.de
- cifs: Fix writeback data corruption (bsc#1225172,
  bsc#1223810, CVE-2024-27036).
- commit 75108cc
* Tue May 28 2024 ematsumiya@suse.de
- cifs: Don't use certain unnecessary folio_*() functions
  (bsc#1225172).
- commit 3ddf86f
* Tue May 28 2024 nik.borisov@suse.com
- x86/bpf: Fix IP after emitting call depth accounting (bsc#1224493 CVE-2024-35903).
- commit 1c0fa71
* Tue May 28 2024 pjakobsson@suse.de
- drm/amdgpu: Skip do PCI error slot reset during RAS recovery (CVE-2024-35931 bsc#1224652).
- commit 1dec1c9
* Tue May 28 2024 tiwai@suse.de
- kabi/severities: ignore TAS2781 symbol drop, it's only locally used
- commit f367fdb
* Tue May 28 2024 tiwai@suse.de
- ASoC: tas2781: Fix wrong loading calibrated data sequence
  (git-fixes).
- commit 5851e36
* Tue May 28 2024 tiwai@suse.de
- mm: page_owner: fix wrong information in dump_page_owner
  (git-fixes).
- ALSA: scarlett2: Add missing error check to
  scarlett2_config_save() (git-fixes).
- commit 4b2ccd1
* Tue May 28 2024 jslaby@suse.cz
- x86/mm/pat: fix VM_PAT handling in COW mappings (bsc#1224525
  CVE-2024-35877).
- commit 24cc941
* Tue May 28 2024 krisman@suse.de
- io_uring: fail NOP if non-zero op flags is passed in
  (git-fixes).
- io_uring/net: fix sendzc lazy wake polling (git-fixes).
- io-wq: write next_work before dropping acct_lock (git-fixes).
- io_uring: use the right type for work_llist empty check
  (git-fixes).
- io_uring/net: restore msg_control on sendzc retry (git-fixes).
- commit 92fcddd
* Tue May 28 2024 krisman@suse.de
- io_uring/kbuf: hold io_buffer_list reference over mmap
  (git-fixes bsc#1224523 CVE-2024-35880).
- io_uring/kbuf: protect io_buffer_list teardown with a reference
  (git-fixes).
  Reuses a padding space in the structure.
- io_uring/kbuf: get rid of bl->is_ready (git-fixes).
- io_uring/kbuf: get rid of lower BGID lists (git-fixes).
  Including kabi preservation patch.
- io_uring/kbuf: rename is_mapped (git-fixes).
- commit 3037746
* Tue May 28 2024 krisman@suse.de
- io_uring: use private workqueue for exit work (git-fixes).
- io_uring/rw: don't allow multishot reads without NOWAIT support
  (git-fixes).
- io_uring: clear opcode specific data for an early failure
  (git-fixes).
- io_uring: fix poll_remove stalled req completion (git-fixes).
- io_uring: Fix release of pinned pages when __io_uaddr_map fails
  (git-fixes bsc#1224698 CVE-2024-35831).
- io_uring: clean rings on NO_MMAP alloc fail (git-fixes).
- io_uring/rw: return IOU_ISSUE_SKIP_COMPLETE for multishot retry
  (git-fixes).
- io_uring: don't save/restore iowait state (git-fixes).
- commit 289cc2c
* Tue May 28 2024 krisman@suse.de
- io_uring: fix mshot io-wq checks (git-fixes).
- io_uring/net: correctly handle multishot recvmsg retry setup
  (git-fixes).
- io_uring: fix io_queue_proc modifying req->flags (git-fixes).
- commit 78dda9b
* Mon May 27 2024 krisman@suse.de
- io_uring: fix mshot read defer taskrun cqe posting (git-fixes).
- commit de73141
* Mon May 27 2024 davide.benini@suse.com
- ipv6: fix race condition between ipv6_get_ifaddr and ipv6_del_addr
  (CVE-2024-35969 bsc#1224580)
- commit f419c6d
* Mon May 27 2024 tbogendoerfer@suse.de
- mlxsw: spectrum_acl_tcam: Fix memory leak when canceling rehash
  work (CVE-2024-35852 bsc#1224502).
- mlxsw: spectrum_acl_tcam: Fix incorrect list API usage
  (CVE-2024-36006 bsc#1224541).
- mlxsw: spectrum_acl_tcam: Fix warning during rehash
  (CVE-2024-36007 bsc#1224543).
- commit 88a980b
* Mon May 27 2024 vkarasulli@suse.de
- Revert "iommu/vt-d: Enable PCI/IMS" (git-fixes).
- commit f424462
* Mon May 27 2024 vkarasulli@suse.de
- Revert "iommu/amd: Enable PCI/IMS" (git-fixes).
- commit 278bf80
* Mon May 27 2024 vkarasulli@suse.de
- iommufd: Add missing IOMMUFD_DRIVER kconfig for the selftest
  (git-fixes).
- commit 481f9bd
* Mon May 27 2024 fdmanana@suse.com
- btrfs: avoid start and commit empty transaction when flushing
  qgroups (bsc#1220120).
- btrfs: avoid start and commit empty transaction when starting
  qgroup rescan (bsc#1220120).
- btrfs: avoid starting and committing empty transaction when
  flushing space (bsc#1220120).
- btrfs: avoid starting new transaction when flushing delayed
  items and refs (bsc#1220120).
- btrfs: merge find_free_dev_extent() and
  find_free_dev_extent_start() (bsc#1220120).
- btrfs: make find_free_dev_extent() static (bsc#1220120).
- btrfs: make btrfs_cleanup_fs_roots() static (bsc#1220120).
- btrfs: fail priority metadata ticket with real fs error
  (bsc#1220120).
- btrfs: return real error when orphan cleanup fails due to a
  transaction abort (bsc#1220120).
- btrfs: store the error that turned the fs into error state
  (bsc#1220120).
- btrfs: don't steal space from global rsv after a transaction
  abort (bsc#1220120).
- btrfs: print available space across all block groups when
  dumping space info (bsc#1220120).
- btrfs: print available space for a block group when dumping
  a space info (bsc#1220120).
- btrfs: print block group super and delalloc bytes when dumping
  space info (bsc#1220120).
- btrfs: print target number of bytes when dumping free space
  (bsc#1220120).
- btrfs: update comment for btrfs_join_transaction_nostart()
  (bsc#1220120).
- commit b4554d4
* Mon May 27 2024 vbabka@suse.cz
- mm/secretmem: fix GUP-fast succeeding on secretmem folios
  (CVE-2024-35872 bsc#1224530).
- commit 42a2f6f
* Mon May 27 2024 ematsumiya@suse.de
- cifs: fix charset issue in reconnection (bsc#1225172).
- commit b4ea103
* Mon May 27 2024 fdmanana@suse.com
- btrfs: make btrfs_destroy_delayed_refs() return void
  (bsc#1220120).
- btrfs: remove unnecessary prototype declarations at disk-io.c
  (bsc#1220120).
- btrfs: use a single switch statement when initializing delayed
  ref head (bsc#1220120).
- btrfs: use bool type for delayed ref head fields that are used
  as booleans (bsc#1220120).
- btrfs: assert correct lock is held at btrfs_select_ref_head()
  (bsc#1220120).
- btrfs: get rid of label and goto at insert_delayed_ref()
  (bsc#1220120).
- btrfs: make insert_delayed_ref() return a bool instead of an
  int (bsc#1220120).
- btrfs: use a bool to track qgroup record insertion when adding
  ref head (bsc#1220120).
- btrfs: remove pointless in_tree field from struct
  btrfs_delayed_ref_node (bsc#1220120).
- btrfs: remove unused is_head field from struct
  btrfs_delayed_ref_node (bsc#1220120).
- btrfs: reorder some members of struct btrfs_delayed_ref_head
  (bsc#1220120).
- commit 2e19466
* Mon May 27 2024 dsterba@suse.com
- btrfs: qgroup: fix qgroup prealloc rsv leak in subvolume operations (CVE-2024-35956 bsc#1224674)
- commit 9bb0c20
* Mon May 27 2024 dsterba@suse.com
- Update patches.suse/btrfs-send-handle-path-ref-underflow-in-header-itera.patch (CVE-2024-35935 bsc#1224645)
- commit 5aa2b5a
* Mon May 27 2024 dsterba@suse.com
- btrfs: make error messages more clear when getting a chunk map (git-fixes)
- commit 47ecf55
* Mon May 27 2024 dsterba@suse.com
- btrfs: compare the correct fsid/metadata_uuid in btrfs_validate_super (git-fixes)
- commit 907e740
* Mon May 27 2024 petr.pavlu@suse.com
- tracing: Add MODULE_DESCRIPTION() to preemptirq_delay_test
  (git-fixes).
- commit 113163c
* Mon May 27 2024 dsterba@suse.com
- btrfs: use the correct superblock to compare fsid in btrfs_validate_super (git-fixes)
- commit 4318f3e
* Mon May 27 2024 petr.pavlu@suse.com
- ring-buffer: Fix a race between readers and resize checks
  (git-fixes).
- commit 568ebcf
* Mon May 27 2024 dsterba@suse.com
- btrfs: add a helper to read the superblock metadata_uuid (git-fixes)
- commit 543d7b8
* Mon May 27 2024 petr.pavlu@suse.com
- ftrace: Fix possible use-after-free issue in ftrace_location()
  (git-fixes).
- commit 4cf7fca
* Mon May 27 2024 petr.pavlu@suse.com
- tracing: hide unused ftrace_event_id_fops (git-fixes).
- commit 61c90c7
* Mon May 27 2024 nik.borisov@suse.com
- x86/retpoline: Do the necessary fixup to the Zen3/4 srso return thunk  for !SRSO (git-fixes).
- commit 1340b2d
* Mon May 27 2024 nik.borisov@suse.com
- x86/efistub: Add missing boot_params for mixed mode compat entry (git-fixes).
- commit 12dcb3a
* Mon May 27 2024 nik.borisov@suse.com
- x86/efistub: Call mixed mode boot services on the firmware's stack (git-fixes).
- commit 9d83518
* Mon May 27 2024 nik.borisov@suse.com
- x86/pm: Work around false positive kmemleak report in msr_build_context() (git-fixes).
- commit 2e5a312
* Mon May 27 2024 nik.borisov@suse.com
- x86/kconfig: Select ARCH_WANT_FRAME_POINTERS again when UNWINDER_FRAME_POINTER=y (git-fixes).
- commit 453faa5
* Mon May 27 2024 nik.borisov@suse.com
- x86/mce: Make sure to grab mce_sysfs_mutex in set_bank() (git-fixes).
- commit e894262
* Mon May 27 2024 nik.borisov@suse.com
- mm/slab: make __free(kfree) accept error pointers (git-fixes).
- commit 8b5f449
* Mon May 27 2024 nik.borisov@suse.com
- x86/Kconfig: Remove CONFIG_AMD_MEM_ENCRYPT_ACTIVE_BY_DEFAULT (git-fixes).
- commit fa1d89a
* Mon May 27 2024 jgross@suse.com
- Update
  patches.suse/virtio_net-Do-not-send-RSS-key-if-it-is-not-supporte.patch
  (bsc#1224565, CVE-2024-35981).
- commit 50a448d
* Mon May 27 2024 jgross@suse.com
- Update
  patches.suse/KVM-x86-Mark-target-gfn-of-emulated-atomic-instructi.patch
  (bsc#1224638, CVE-2024-35804).
- commit aac65c3
* Mon May 27 2024 jgross@suse.com
- Update
  patches.suse/KVM-SVM-Flush-pages-under-kvm-lock-to-fix-UAF-in-svm.patch
  (bsc#1224725, CVE-2024-35791).
- commit 80eb8d1
* Mon May 27 2024 tiwai@suse.de
- cxl/port: Fix delete_endpoint() vs parent unregistration race
  (CVE-2023-52771 bsc#1225007).
- commit b115e15
* Sun May 26 2024 tiwai@suse.de
- i3c: master: svc: change ENXIO to EAGAIN when IBI occurs during
  start frame (git-fixes).
- commit cc09a8e
* Sun May 26 2024 tiwai@suse.de
- kselftest: Add a ksft_perror() helper (stable-fixes).
- Refresh
  patches.suse/selftests-timers-posix_timers-Reimplement-check_time.patch.
- commit f14f41c
* Sun May 26 2024 tiwai@suse.de
- nilfs2: fix unexpected freezing of nilfs_segctor_sync()
  (git-fixes).
- nilfs2: fix use-after-free of timer for log writer thread
  (git-fixes).
- kasan, fortify: properly rename memintrinsics (git-fixes).
- i3c: master: svc: fix invalidate IBI type and miss call client
  IBI handler (git-fixes).
- serial: kgdboc: Fix NMI-safety problems from keyboard reset code
  (stable-fixes).
- drm/amd/display: Fix division by zero in setup_dsc_config
  (stable-fixes).
- docs: kernel_include.py: Cope with docutils 0.21 (stable-fixes).
- mmc: core: Add HS400 tuning in HS400es initialization
  (stable-fixes).
- commit 0b2962b
* Sun May 26 2024 tiwai@suse.de
- Bluetooth: L2CAP: Fix slab-use-after-free in l2cap_connect()
  (git-fixes).
- commit 3e2fb47
* Sat May 25 2024 tiwai@suse.de
- ALSA: hda/realtek: fix mute/micmute LEDs don't work for ProBook
  440/460 G11 (stable-fixes).
- ALSA: hda/realtek: Enable headset mic of JP-IK LEAP W502 with
  ALC897 (stable-fixes).
- ALSA: usb-audio: Fix for sampling rates support for Mbox3
  (stable-fixes).
- ALSA: timer: Set lower bound of start tick time (stable-fixes).
- ALSA: usb-audio: Add sampling rates support for Mbox3
  (stable-fixes).
- commit ae40914
* Sat May 25 2024 tiwai@suse.de
- drm/nouveau: use tile_mode and pte_kind for VM_BIND bo
  allocations (git-fixes).
- Input: cyapa - add missing input core locking to suspend/resume
  functions (git-fixes).
- Input: pm8xxx-vibrator - correct VIB_MAX_LEVELS calculation
  (git-fixes).
- Input: ims-pcu - fix printf string overflow (git-fixes).
- ASoC: tas2552: Add TX path for capturing AUDIO-OUT data
  (git-fixes).
- ALSA: core: Fix NULL module pointer assignment at card init
  (git-fixes).
- speakup: Fix sizeof() vs ARRAY_SIZE() bug (git-fixes).
- serial: sc16is7xx: fix bug in sc16is7xx_set_baud() when using
  prescaler (git-fixes).
- serial: 8250_bcm7271: use default_mux_rate if possible
  (git-fixes).
- serial: 8520_mtk: Set RTS on shutdown for Rx in-band wakeup
  (git-fixes).
- tty: n_gsm: fix missing receive state reset after mode switch
  (git-fixes).
- tty: n_gsm: fix possible out-of-bounds in gsm0_receive()
  (git-fixes).
- commit be92dbc
* Sat May 25 2024 krisman@suse.de
- io_uring/net: fix overflow check in io_recvmsg_mshot_prep()
  (git-fixes CVE-2024-35827 bsc#1224606).
- commit e6510ec
* Sat May 25 2024 krisman@suse.de
- io_uring/net: move receive multishot out of the generic msghdr
  path (git-fixes).
- commit 98302d6
* Sat May 25 2024 krisman@suse.de
- io_uring/net: unify how recvmsg and sendmsg copy in the msghdr
  (git-fixes).
- commit 8bed9be
* Sat May 25 2024 ematsumiya@suse.de
- cifs: handle cases where multiple sessions share connection
  (bsc#1225172).
- commit 6704757
* Sat May 25 2024 ematsumiya@suse.de
- smb3: show beginning time for per share stats (bsc#1225172).
- commit 9dab491
* Sat May 25 2024 ematsumiya@suse.de
- cifs: cifs_chan_is_iface_active should be called with chan_lock
  held (bsc#1225172).
- commit 7f878c6
* Sat May 25 2024 ematsumiya@suse.de
- cifs: do not pass cifs_sb when trying to add channels
  (bsc#1225172).
- commit b48e89f
* Sat May 25 2024 ematsumiya@suse.de
- smb: client: remove extra @chan_count check in
  __cifs_put_smb_ses() (bsc#1225172).
- commit 58e3272
* Sat May 25 2024 ematsumiya@suse.de
- cifs: reconnect work should have reference on server struct
  (bsc#1225172).
- commit f1bff59
* Sat May 25 2024 ematsumiya@suse.de
- cifs: handle cases where a channel is closed (bsc#1225172).
- commit c305501
* Sat May 25 2024 ematsumiya@suse.de
- smb: client: reduce stack usage in cifs_try_adding_channels()
  (bsc#1225172).
- commit 16a3d64
* Sat May 25 2024 ematsumiya@suse.de
- smb: client: get rid of dfs code dep in namespace.c
  (bsc#1225172).
- commit 658ebd6
* Sat May 25 2024 ematsumiya@suse.de
- smb: client: get rid of dfs naming in automount code
  (bsc#1225172).
- commit b47e685
* Sat May 25 2024 ematsumiya@suse.de
- smb: client: rename cifs_dfs_ref.c to namespace.c (bsc#1225172).
- commit 429bc2d
* Sat May 25 2024 ematsumiya@suse.de
- smb: client: ensure to try all targets when finding nested links
  (bsc#1225172).
- commit b03bac4
* Sat May 25 2024 ematsumiya@suse.de
- smb: client: introduce DFS_CACHE_TGT_LIST() (bsc#1225172).
- commit f066846
* Sat May 25 2024 ematsumiya@suse.de
- cifs: account for primary channel in the interface list
  (bsc#1225172).
- commit 28558fb
* Sat May 25 2024 ematsumiya@suse.de
- cifs: distribute channels across interfaces based on speed
  (bsc#1225172).
- commit 66db7c6
* Sat May 25 2024 krisman@suse.de
- io_uring: remove unconditional looping in local task_work
  handling (git-fixes).
- commit 1df83aa
* Sat May 25 2024 krisman@suse.de
- io_uring: remove looping around handling traditional task_work
  (git-fixes).
- commit 6bdc394
* Fri May 24 2024 tiwai@suse.de
- dmaengine: dw-edma: eDMA: Add sync read before starting the
  DMA transfer in remote setup (CVE-2024-27408 bsc#1224430).
- commit 26ca7a6
* Fri May 24 2024 tiwai@suse.de
- pmdomain: ti: Add a null pointer check to the
  omap_prm_domain_init (CVE-2024-35943 bsc#1224649).
- commit 4abda58
* Fri May 24 2024 tiwai@suse.de
- media: mediatek: vcodec: Fix oops when HEVC init fails
  (CVE-2024-35921 bsc#1224477).
- commit 7226612
* Fri May 24 2024 tiwai@suse.de
- drivers/perf: hisi: use cpuhp_state_remove_instance_nocalls()
  for hisi_hns3_pmu uninit process (CVE-2023-52860 bsc#1224936).
- commit f0f6842
* Fri May 24 2024 tiwai@suse.de
- kABI workaround for struct idxd_evl (CVE-2024-35991
  bsc#1224553).
- commit 4c82821
* Fri May 24 2024 tiwai@suse.de
- dmaengine: idxd: Convert spinlock to mutex to lock evl workqueue
  (CVE-2024-35991 bsc#1224553).
- commit bba26d6
* Fri May 24 2024 mgorman@suse.de
- sched/topology: Optimize topology_span_sane() (bsc#1225053).
- cpumask: Add for_each_cpu_from() (bsc#1225053).
- commit a6ca3d0
* Fri May 24 2024 denis.kirjanov@suse.com
- mlxsw: spectrum_acl_tcam: Fix possible use-after-free during
  rehash (CVE-2024-35854 bsc#1224636).
- commit 2a8bef6
* Fri May 24 2024 davide.benini@suse.com
- net: mctp: take ownership of skb in mctp_local_output
  (CVE-2024-27418 bsc#1224720)
- commit afb99d9
* Fri May 24 2024 davide.benini@suse.com
- ipv6: fix potential "struct net" leak in inet6_rtm_getaddr()
  (CVE-2024-27417 bsc#1224721)
- commit 4e68c84
* Fri May 24 2024 tiwai@suse.de
- regulator: bd71828: Don't overwrite runtime voltages
  (git-fixes).
- nfc: nci: Fix handling of zero-length payload packets in
  nci_rx_work() (git-fixes).
- nfc: nci: Fix uninit-value in nci_rx_work (git-fixes).
- selftests: net: kill smcrouted in the cleanup logic in amt.sh
  (git-fixes).
- tools/latency-collector: Fix -Wformat-security compile warns
  (git-fixes).
- commit 3a26e1a
* Fri May 24 2024 shung-hsi.yu@suse.com
- bpf: Protect against int overflow for stack access size
  (bsc#1224488 CVE-2024-35905).
- bpf: Check bloom filter map value size (bsc#1224488
  CVE-2024-35905).
- commit 5fa3c11
* Fri May 24 2024 krisman@suse.de
- io_uring: drop any code related to SCM_RIGHTS (git-fixes
  CVE-2023-52656 bsc#1224187).
- io_uring/unix: drop usage of io_uring socket (git-fixes).
- Refresh
  patches.suse/fs-Rename-anon_inode_getfile_secure-and-anon_inode_getfd_secure.
  Commit together because this required explicit merging with the
  anonymous inode creation function change. Incldues kabi fix up.
- commit b304b67
* Fri May 24 2024 neilb@suse.de
- autofs: use wake_up() instead of wake_up_interruptible(()
  (bsc#1224166).
- commit eb57c74
* Thu May 23 2024 mwilck@suse.com
- Update patches.suse/scsi-qedf-Wait-for-stag-work-during-unload.patch (bsc#1214852)
- Update patches.suse/scsi-qedf-Don-t-process-stag-work-during-unload.patch (bsc#1214852)
- commit 4cb5fde
* Thu May 23 2024 rgoldwyn@suse.com
- Remove NTFSv3 from configs (bsc#1224429)
  References: bsc#1224429 comment#3
  We only support fuse version of the NTFS-3g driver. Disable NTFSv3 from
  all configs.
  This was enabled in
  d016c04d731 ("Bump to 6.4 kernel (jsc#PED-4593)")
- commit b4be251
* Thu May 23 2024 mfranc@suse.cz
- s390/ipl: Fix incorrect initialization of len fields in nvme
  reipl block (git-fixes bsc#1225136).
- commit 273e6f4
* Thu May 23 2024 mfranc@suse.cz
- s390/ipl: Fix incorrect initialization of nvme dump block
  (git-fixes bsc#1225134).
- commit 955c716
* Thu May 23 2024 mfranc@suse.cz
- s390/cpacf: Split and rework cpacf query functions (git-fixes
  bsc#1225133).
- commit ee9583e
* Thu May 23 2024 mfranc@suse.cz
- s390/bpf: Fix bpf_plt pointer arithmetic (git-fixes bsc#1224481
  CVE-2024-35917).
- commit 34e1a55
* Thu May 23 2024 tiwai@suse.de
- Move upstreamed mm patches into sorted section
- commit e3937f1
* Thu May 23 2024 tiwai@suse.de
- Move upstreamed powerpc patches into sorted section
- commit fdb5fa6
* Thu May 23 2024 tiwai@suse.de
- kABI workaround for cs35l56 (git-fixes).
- commit 331f8f7
* Thu May 23 2024 tiwai@suse.de
- ASoC: SOF: Intel: mtl: call dsp dump when boot retry fails
  (stable-fixes).
- Refresh
  patches.suse/ASoC-SOF-Intel-mtl-Implement-firmware-boot-state-che.patch.
- commit 8e475f5
* Thu May 23 2024 tiwai@suse.de
- ASoC: SOF: Intel: mtl: Disable interrupts when firmware boot
  failed (git-fixes).
- ASoC: cs35l56: Prevent overwriting firmware ASP config
  (git-fixes).
- commit 1a7f82c
* Thu May 23 2024 tiwai@suse.de
- ALSA: scarlett2: Add clamp() in scarlett2_mixer_ctl_put()
  (CVE-2023-52674 bsc#1224727).
- ALSA: scarlett2: Add missing error checks to *_ctl_get()
  (CVE-2023-52680 bsc#1224608).
- ALSA: scarlett2: Add missing error check to
  scarlett2_usb_set_config() (CVE-2023-52692 bsc#1224628).
- commit fff59c9
* Thu May 23 2024 tiwai@suse.de
- vmci: prevent speculation leaks by sanitizing event in
  event_deliver() (git-fixes).
- VMCI: Fix an error handling path in vmci_guest_probe_device()
  (git-fixes).
- VMCI: Fix possible memcpy() run-time warning in
  vmci_datagram_invoke_guest_handler() (stable-fixes).
- VMCI: Fix memcpy() run-time warning in dg_dispatch_as_host()
  (stable-fixes CVE-2024-35944 bsc#1224648).
- commit d9694ad
* Thu May 23 2024 tiwai@suse.de
- spmi: hisi-spmi-controller: Do not override device identifier
  (git-fixes).
- extcon: max8997: select IRQ_DOMAIN instead of depending on it
  (git-fixes).
- interconnect: qcom: qcm2290: Fix mas_snoc_bimc QoS port
  assignment (git-fixes).
- iio: pressure: dps310: support negative temperature values
  (git-fixes).
- iio: adc: stm32: Fixing err code to not indicate success
  (git-fixes).
- iio: core: Leave private pointer NULL when no private data
  supplied (git-fixes).
- counter: linux/counter.h: fix Excess kernel-doc description
  warning (git-fixes).
- staging: vt6655: Remove unused declaration of
  RFbAL7230SelectChannelPostProcess() (git-fixes).
- serial: sh-sci: protect invalidating RXDMA on shutdown
  (git-fixes).
- serial: sc16is7xx: add proper sched.h include for
  sched_set_fifo() (git-fixes).
- serial: max3100: Fix bitwise types (git-fixes).
- serial: max3100: Update uart_driver_registered on driver removal
  (git-fixes).
- serial: max3100: Lock port->lock when calling
  uart_handle_cts_change() (git-fixes).
- usb: fotg210: Add missing kernel doc description (git-fixes).
- usb: typec: tipd: fix event checking for tps6598x (git-fixes).
- usb: typec: ucsi: displayport: Fix potential deadlock
  (git-fixes).
- usb: dwc3: Wait unconditionally after issuing EndXfer command
  (git-fixes).
- usb: gadget: u_audio: Clear uac pointer when freed (git-fixes).
- usb: gadget: u_audio: Fix race condition use of controls after
  free during gadget unbind (git-fixes).
- usb: typec: ucsi: simplify partner's PD caps registration
  (git-fixes).
- usb: typec: ucsi: always register a link to USB PD device
  (git-fixes).
- leds: pwm: Disable PWM when going to suspend (git-fixes).
- commit 0d08462
* Wed May 22 2024 mkoutny@suse.com
- af_unix: Suppress false-positive lockdep splat for spin_lock()
  in __unix_gc() (CVE-2024-26923 bsc#1223384).
- af_unix: fix lockdep positive in sk_diag_dump_icons()
  (CVE-2024-26923 bsc#1223384).
- commit a652e3a
* Wed May 22 2024 jlee@suse.com
- Update
  patches.suse/ACPI-CPPC-Use-access_width-over-bit_width-for-system.patch
  (stable-fixes CVE-2024-35995 bsc#1224557).
- Update
  patches.suse/ALSA-usb-audio-Stop-parsing-channels-bits-when-all-c.patch
  (git-fixes CVE-2024-27436 bsc#1224803).
- Update
  patches.suse/ASoC-SOF-ipc4-pcm-Workaround-for-crashed-firmware-on.patch
  (stable-fixes CVE-2024-27057 bsc#1223831).
- Update
  patches.suse/ASoC-mediatek-sof-common-Add-NULL-check-for-normal_l.patch
  (git-fixes CVE-2024-35842 bsc#1224688).
- Update
  patches.suse/Bluetooth-Fix-memory-leak-in-hci_req_sync_complete.patch
  (git-fixes CVE-2024-35978 bsc#1224571).
- Update
  patches.suse/Bluetooth-Fix-use-after-free-bugs-caused-by-sco_sock.patch
  (git-fixes CVE-2024-27398 bsc#1224174).
- Update
  patches.suse/Bluetooth-L2CAP-Fix-not-validating-setsockopt-user-i.patch
  (git-fixes CVE-2024-35965 bsc#1224579).
- Update
  patches.suse/Bluetooth-RFCOMM-Fix-not-validating-setsockopt-user-.patch
  (git-fixes CVE-2024-35966 bsc#1224576).
- Update
  patches.suse/Bluetooth-SCO-Fix-not-validating-setsockopt-user-inp.patch
  (git-fixes CVE-2024-35967 bsc#1224587).
- Update
  patches.suse/Bluetooth-btintel-Fix-null-ptr-deref-in-btintel_read.patch
  (stable-fixes CVE-2024-35933 bsc#1224640).
- Update
  patches.suse/Bluetooth-hci_event-Fix-handling-of-HCI_EV_IO_CAPA_R.patch
  (git-fixes CVE-2024-27416 bsc#1224723).
- Update
  patches.suse/Bluetooth-hci_sock-Fix-not-validating-setsockopt-use.patch
  (git-fixes CVE-2024-35963 bsc#1224582).
- Update
  patches.suse/Bluetooth-l2cap-fix-null-ptr-deref-in-l2cap_chan_tim.patch
  (git-fixes CVE-2024-27399 bsc#1224177).
- Update
  patches.suse/Bluetooth-qca-fix-NULL-deref-on-non-serdev-setup.patch
  (git-fixes CVE-2024-35850 bsc#1224600).
- Update
  patches.suse/Bluetooth-qca-fix-NULL-deref-on-non-serdev-suspend.patch
  (git-fixes CVE-2024-35851 bsc#1224509).
- Update
  patches.suse/Bluetooth-rfcomm-Fix-null-ptr-deref-in-rfcomm_check_.patch
  (bsc#1219170 CVE-2024-22099 CVE-2024-26903 bsc#1223187).
- Update
  patches.suse/HID-i2c-hid-remove-I2C_HID_READ_PENDING-flag-to-prev.patch
  (git-fixes CVE-2024-35997 bsc#1224552).
- Update
  patches.suse/NFS-Fix-nfs_netfs_issue_read-xarray-locking-for-writ.patch
  (git-fixes CVE-2024-27031 bsc#1223805).
- Update
  patches.suse/NFSv4.2-fix-nfs4_listxattr-kernel-BUG-at-mm-usercopy.patch
  (git-fixes CVE-2024-26870 bsc#1223113).
- Update
  patches.suse/PCI-PM-Drain-runtime-idle-callbacks-before-driver-re.patch
  (stable-fixes CVE-2024-35809 bsc#1224738).
- Update
  patches.suse/SUNRPC-fix-some-memleaks-in-gssx_dec_option_array.patch
  (git-fixes CVE-2024-27388 bsc#1223744).
- Update
  patches.suse/USB-core-Fix-deadlock-in-usb_deauthorize_interface.patch
  (git-fixes CVE-2024-26934 bsc#1223671).
- Update patches.suse/accel-ivpu-Fix-deadlock-in-context_xa.patch
  (git-fixes CVE-2024-35953 bsc#1224704).
- Update
  patches.suse/arm64-hibernate-Fix-level3-translation-fault-in-swsu.patch
  (git-fixes CVE-2024-26989 bsc#1223748).
- Update patches.suse/ax25-Fix-netdev-refcount-issue.patch
  (git-fixes CVE-2024-36009 bsc#1224542).
- Update
  patches.suse/ax25-fix-use-after-free-bugs-caused-by-ax25_ds_del_t.patch
  (git-fixes CVE-2024-35887 bsc#1224663).
- Update
  patches.suse/batman-adv-Avoid-infinite-loop-trying-to-resize-loca.patch
  (git-fixes CVE-2024-35982 bsc#1224566).
- Update
  patches.suse/block-fix-q-blkg_list-corruption-during-disk-rebind.patch
  (bsc#1223591 CVE-2024-35974 bsc#1224573).
- Update
  patches.suse/bnxt_en-Fix-possible-memory-leak-in-bnxt_rdma_aux_de.patch
  (git-fixes CVE-2024-35972 bsc#1224577).
- Update
  patches.suse/bootconfig-use-memblock_free_late-to-free-xbc-memory.patch
  (git-fixes CVE-2024-26983 bsc#1223637).
- Update
  patches.suse/btrfs-fix-deadlock-with-fiemap-and-extent-locking.patch
  (bsc#1223285 CVE-2024-35784 bsc#1224804).
- Update
  patches.suse/btrfs-fix-information-leak-in-btrfs_ioctl_logical_to.patch
  (git-fixes CVE-2024-35849 bsc#1224733).
- Update
  patches.suse/btrfs-fix-race-between-ordered-extent-completion-and.patch
  (bsc#1223285 CVE-2024-26794 bsc#1222426).
- Update
  patches.suse/btrfs-fix-race-when-detecting-delalloc-ranges-during.patch
  (bsc#1223285 CVE-2024-27080 bsc#1223782).
- Update
  patches.suse/btrfs-handle-chunk-tree-lookup-error-in-btrfs_reloca.patch
  (git-fixes CVE-2024-35936 bsc#1224644).
- Update
  patches.suse/clk-Get-runtime-PM-before-walking-tree-during-disabl.patch
  (git-fixes CVE-2024-27004 bsc#1223762).
- Update
  patches.suse/clk-Get-runtime-PM-before-walking-tree-for-clk_summa.patch
  (git-fixes CVE-2024-27003 bsc#1223761).
- Update
  patches.suse/clk-mediatek-Do-a-runtime-PM-get-on-controllers-duri.patch
  (git-fixes CVE-2024-27002 bsc#1223759).
- Update
  patches.suse/comedi-vmk80xx-fix-incomplete-endpoint-checking.patch
  (git-fixes CVE-2024-27001 bsc#1223698).
- Update
  patches.suse/dm-raid-really-frozen-sync_thread-during-suspend-16c4.patch
  (jsc#PED-7542 CVE-2024-35794 bsc#1224706).
- Update
  patches.suse/dm-raid456-md-raid456-fix-a-deadlock-for-dm-raid456-4142.patch
  (bsc#1219596 CVE-2024-26962 bsc#1223654).
- Update
  patches.suse/dma-buf-Fix-NULL-pointer-dereference-in-sanitycheck.patch
  (git-fixes CVE-2024-35916 bsc#1224480).
- Update patches.suse/dma-xilinx_dpdma-Fix-locking.patch
  (git-fixes CVE-2024-35990 bsc#1224559).
- Update
  patches.suse/dmaengine-fsl-qdma-Fix-a-memory-leak-related-to-the--3aa58cb.patch
  (git-fixes CVE-2024-35833 bsc#1224632).
- Update
  patches.suse/dmaengine-idxd-Fix-oops-during-rmmod-on-single-CPU-p.patch
  (git-fixes CVE-2024-35989 bsc#1224558).
- Update
  patches.suse/dpll-fix-dpll_pin_on_pin_register-for-multiple-paren.patch
  (CVE-2024-27027 bsc#1223787 CVE-2024-36002 bsc#1224546).
- Update
  patches.suse/dpll-fix-pin-dump-crash-for-rebound-module.patch
  (jsc#PED-6079 CVE-2024-35836 bsc#1224633).
- Update
  patches.suse/drm-Check-output-polling-initialized-before-disablin.patch
  (stable-fixes CVE-2024-35927 bsc#1224654).
- Update
  patches.suse/drm-amd-amdgpu-Fix-potential-ioremap-memory-leaks-in.patch
  (stable-fixes CVE-2024-35928 bsc#1224653).
- Update
  patches.suse/drm-amd-display-Fix-bounds-check-for-dcn35-DcfClocks.patch
  (git-fixes CVE-2024-35788 bsc#1224709).
- Update
  patches.suse/drm-amd-display-Prevent-crash-when-disable-stream.patch
  (stable-fixes CVE-2024-35799 bsc#1224740).
- Update
  patches.suse/drm-amdgpu-amdgpu_ttm_gart_bind-set-gtt-bound-flag.patch
  (stable-fixes CVE-2024-35817 bsc#1224736).
- Update
  patches.suse/drm-amdgpu-fix-deadlock-while-reading-mqd-from-debug.patch
  (git-fixes CVE-2024-35795 bsc#1224634).
- Update
  patches.suse/drm-amdgpu-fix-mmhub-client-id-out-of-bounds-access.patch
  (git-fixes CVE-2024-27029 bsc#1223789).
- Update
  patches.suse/drm-amdgpu-once-more-fix-the-call-oder-in-amdgpu_ttm.patch
  (git-fixes CVE-2024-27400 bsc#1224180).
- Update
  patches.suse/drm-amdgpu-pm-Fix-NULL-pointer-dereference-when-get-.patch
  (git-fixes CVE-2024-26949 bsc#1223665).
- Update
  patches.suse/drm-amdgpu-validate-the-parameters-of-bo-mapping-ope.patch
  (git-fixes CVE-2024-26922 bsc#1223315).
- Update
  patches.suse/drm-amdkfd-Fix-memory-leak-in-create_process-failure.patch
  (git-fixes CVE-2024-26986 bsc#1223728).
- Update patches.suse/drm-ast-Fix-soft-lockup.patch (git-fixes
  CVE-2024-35952 bsc#1224705).
- Update
  patches.suse/drm-client-Fully-protect-modes-with-dev-mode_config..patch
  (stable-fixes CVE-2024-35950 bsc#1224703).
- Update
  patches.suse/drm-i915-bios-Tolerate-devdata-NULL-in-intel_bios_en.patch
  (stable-fixes CVE-2024-26938 bsc#1223678).
- Update
  patches.suse/drm-i915-gt-Reset-queue_priority_hint-on-parking.patch
  (git-fixes CVE-2024-26937 bsc#1223677).
- Update
  patches.suse/drm-lima-fix-a-memleak-in-lima_heap_alloc.patch
  (git-fixes CVE-2024-35829 bsc#1224707).
- Update
  patches.suse/drm-nouveau-fix-stale-locked-mutex-in-nouveau_gem_io.patch
  (git-fixes CVE-2024-35786 bsc#1224714).
- Update
  patches.suse/drm-nouveau-keep-DMA-buffers-required-for-suspend-re.patch
  (git-fixes CVE-2024-27411 bsc#1224433).
- Update patches.suse/drm-nv04-Fix-out-of-bounds-access.patch
  (git-fixes CVE-2024-27008 bsc#1223802).
- Update
  patches.suse/drm-panfrost-Fix-the-error-path-in-panfrost_mmu_map_.patch
  (git-fixes CVE-2024-35951 bsc#1224701).
- Update
  patches.suse/drm-vc4-don-t-check-if-plane-state-fb-state-fb.patch
  (stable-fixes CVE-2024-35932 bsc#1224650).
- Update
  patches.suse/drm-vmwgfx-Create-debugfs-ttm_resource_manager-entry.patch
  (git-fixes CVE-2024-26940 bsc#1223718).
- Update
  patches.suse/drm-vmwgfx-Fix-the-lifetime-of-the-bo-cursor-memory.patch
  (git-fixes CVE-2024-35810 bsc#1224626).
- Update
  patches.suse/dyndbg-fix-old-BUG_ON-in-control-parser.patch
  (stable-fixes CVE-2024-35947 bsc#1224647).
- Update
  patches.suse/efi-capsule-loader-fix-incorrect-allocation-size.patch
  (git-fixes CVE-2024-27413 bsc#1224438).
- Update patches.suse/efi-fix-panic-in-kdump-kernel.patch
  (git-fixes CVE-2024-35800 bsc#1224507).
- Update
  patches.suse/fat-fix-uninitialized-field-in-nostale-filehandles.patch
  (git-fixes CVE-2024-26973 bsc#1223641).
- Update
  patches.suse/fbmon-prevent-division-by-zero-in-fb_videomode_from_.patch
  (stable-fixes CVE-2024-35922 bsc#1224660).
- Update
  patches.suse/fs-aio-Check-IOCB_AIO_RW-before-the-struct-aio_kiocb.patch
  (bsc#1222721 CVE-2024-26764 CVE-2024-35815 bsc#1224685).
- Update
  patches.suse/geneve-fix-header-validation-in-geneve-6-_xmit_skb.patch
  (git-fixes CVE-2024-35973 bsc#1224586).
- Update
  patches.suse/geneve-make-sure-to-pull-inner-header-in-geneve_rx.patch
  (git-fixes CVE-2024-26857 bsc#1223058).
- Update
  patches.suse/i2c-smbus-fix-NULL-function-pointer-dereference.patch
  (git-fixes CVE-2024-35984 bsc#1224567).
- Update
  patches.suse/ice-fix-memory-corruption-bug-with-suspend-and-rebui.patch
  (git-fixes CVE-2024-35911 bsc#1224486).
- Update
  patches.suse/ice-fix-uninitialized-dplls-mutex-usage.patch
  (git-fixes CVE-2024-26854 bsc#1223039).
- Update
  patches.suse/idpf-fix-kernel-panic-on-unknown-packet-types.patch
  (git-fixes CVE-2024-35889 bsc#1224517).
- Update
  patches.suse/igc-avoid-returning-frame-twice-in-XDP_REDIRECT.patch
  (git-fixes CVE-2024-26853 bsc#1223061).
- Update
  patches.suse/init-main.c-Fix-potential-static_command_line-memory.patch
  (git-fixes CVE-2024-26988 bsc#1223747).
- Update
  patches.suse/iommufd-Fix-iopt_access_list_id-overwrite-bug.patch
  (git-fixes CVE-2024-26786 bsc#1222780).
- Update
  patches.suse/irqchip-gic-v3-its-Prevent-double-free-on-error.patch
  (git-fixes CVE-2024-35847 bsc#1224697).
- Update
  patches.suse/kprobes-Fix-possible-use-after-free-issue-on-kprobe-registration.patch
  (git-fixes CVE-2024-35955 bsc#1224676).
- Update
  patches.suse/mac802154-fix-llsec-key-resources-release-in-mac8021.patch
  (git-fixes CVE-2024-26961 bsc#1223652).
- Update
  patches.suse/md-dm-raid-don-t-call-md_reap_sync_thread-directly-cd32.patch
  (jsc#PED-7542 CVE-2024-35808 bsc#1224623).
- Update patches.suse/md-fix-kmemleak-of-rdev-serial-6cf3.patch
  (jsc#PED-7542 CVE-2024-26900 bsc#1223046).
- Update
  patches.suse/media-tc358743-register-v4l2-async-device-only-after.patch
  (git-fixes CVE-2024-35830 bsc#1224680).
- Update
  patches.suse/misc-lis3lv02d_i2c-Fix-regulators-getting-en-dis-abl.patch
  (git-fixes CVE-2024-35824 bsc#1224609).
- Update
  patches.suse/mlxbf_gige-call-request_irq-after-NAPI-initialized.patch
  (git-fixes CVE-2024-35907 bsc#1224492).
- Update
  patches.suse/mlxbf_gige-stop-interface-during-shutdown.patch
  (git-fixes CVE-2024-35885 bsc#1224519).
- Update
  patches.suse/mmc-core-Avoid-negative-index-with-array-access.patch
  (git-fixes CVE-2024-35813 bsc#1224618).
- Update
  patches.suse/msft-hv-2971-net-mana-Fix-Rx-DMA-datasize-and-skb_over_panic.patch
  (git-fixes CVE-2024-35901 bsc#1224495).
- Update
  patches.suse/net-ena-Fix-incorrect-descriptor-free-behavior.patch
  (git-fixes CVE-2024-35958 bsc#1224677).
- Update
  patches.suse/net-ethernet-mtk_eth_soc-fix-PPE-hanging-issue.patch
  (git-fixes CVE-2024-27432 bsc#1224716).
- Update
  patches.suse/net-hns3-fix-kernel-crash-when-1588-is-received-on-H.patch
  (git-fixes CVE-2024-26881 bsc#1223041).
- Update
  patches.suse/net-ice-Fix-potential-NULL-pointer-dereference-in-ic.patch
  (git-fixes CVE-2024-26855 bsc#1223051).
- Update
  patches.suse/net-ks8851-Handle-softirqs-at-the-end-of-IRQ-thread-.patch
  (git-fixes CVE-2024-35971 bsc#1224578).
- Update
  patches.suse/net-ll_temac-platform_get_resource-replaced-by-wrong.patch
  (git-fixes CVE-2024-35796 bsc#1224615).
- Update
  patches.suse/net-mlx5-Properly-link-new-fs-rules-into-the-tree.patch
  (git-fixes CVE-2024-35960 bsc#1224588).
- Update
  patches.suse/net-mlx5-Register-devlink-first-under-devlink-lock.patch
  (git-fixes CVE-2024-35961 bsc#1224585).
- Update
  patches.suse/net-mlx5e-Fix-mlx5e_priv_init-cleanup-flow.patch
  (git-fixes CVE-2024-35959 bsc#1224666).
- Update
  patches.suse/net-mlx5e-Use-a-memory-barrier-to-enforce-PTP-WQ-xmi.patch
  (git-fixes CVE-2024-26858 bsc#1223020).
- Update
  patches.suse/net-mlx5e-fix-a-double-free-in-arfs_create_groups.patch
  (jsc#PED-3311 CVE-2024-35835 bsc#1224605).
- Update
  patches.suse/net-mvpp2-clear-BM-pool-before-initialization.patch
  (git-fixes CVE-2024-35837 bsc#1224500).
- Update
  patches.suse/net-phy-micrel-Fix-potential-null-pointer-dereferenc.patch
  (git-fixes CVE-2024-35891 bsc#1224513).
- Update
  patches.suse/net-phy-phy_device-Prevent-nullptr-exceptions-on-ISR.patch
  (stable-fixes CVE-2024-35945 bsc#1224639).
- Update
  patches.suse/net-sparx5-Fix-use-after-free-inside-sparx5_del_mact.patch
  (git-fixes CVE-2024-26856 bsc#1223052).
- Update patches.suse/net-tls-fix-WARNIING-in-__sk_msg_free.patch
  (bsc#1221858 CVE-2024-35841 bsc#1224687).
- Update
  patches.suse/net-wwan-t7xx-Split-64bit-accesses-to-fix-alignment-.patch
  (git-fixes CVE-2024-35909 bsc#1224491).
- Update
  patches.suse/nfc-nci-Fix-uninit-value-in-nci_dev_up-and-nci_ntf_p.patch
  (git-fixes CVE-2024-35915 bsc#1224479).
- Update
  patches.suse/nfp-flower-handle-acti_netdevs-allocation-failure.patch
  (git-fixes CVE-2024-27046 bsc#1223827).
- Update
  patches.suse/nfs-fix-panic-when-nfs4_ff_layout_prepare_ds-fails.patch
  (git-fixes CVE-2024-26868 bsc#1223038).
- Update
  patches.suse/nfsd-Fix-error-cleanup-path-in-nfsd_rename.patch
  (bsc#1221044 CVE-2023-52591 CVE-2024-35914 bsc#1224482).
- Update
  patches.suse/nouveau-fix-instmem-race-condition-around-ptr-stores.patch
  (git-fixes CVE-2024-26984 bsc#1223633).
- Update patches.suse/nouveau-lock-the-client-object-tree.patch
  (stable-fixes CVE-2024-27062 bsc#1223834).
- Update
  patches.suse/nvme-fc-do-not-wait-in-vain-when-unloading-module.patch
  (git-fixes CVE-2024-26846 bsc#1223023).
- Update
  patches.suse/nvme-fix-reconnection-fail-due-to-reserved-tag-alloc.patch
  (git-fixes CVE-2024-27435 bsc#1224717).
- Update
  patches.suse/octeontx2-af-Use-separate-handlers-for-interrupts.patch
  (git-fixes CVE-2024-27030 bsc#1223790).
- Update
  patches.suse/octeontx2-pf-Fix-transmit-scheduler-resource-leak.patch
  (git-fixes CVE-2024-35975 bsc#1224569).
- Update
  patches.suse/of-dynamic-Synchronize-of_changeset_destroy-with-the.patch
  (git-fixes CVE-2024-35879 bsc#1224524).
- Update
  patches.suse/of-module-prevent-NULL-pointer-dereference-in-vsnpri.patch
  (stable-fixes CVE-2024-35878 bsc#1224671).
- Update
  patches.suse/phy-marvell-a3700-comphy-Fix-out-of-bounds-read.patch
  (git-fixes CVE-2024-35992 bsc#1224555).
- Update
  patches.suse/phy-ti-tusb1210-Resolve-charger-det-crash-if-charger.patch
  (git-fixes CVE-2024-35986 bsc#1224562).
- Update
  patches.suse/platform-chrome-cros_ec_uart-properly-fix-race-condi.patch
  (git-fixes CVE-2024-35977 bsc#1224568).
- Update
  patches.suse/power-supply-bq27xxx-i2c-Do-not-free-non-existing-IR.patch
  (git-fixes CVE-2024-27412 bsc#1224437).
- Update
  patches.suse/pstore-inode-Only-d_invalidate-is-needed.patch
  (git-fixes CVE-2024-27389 bsc#1223705).
- Update
  patches.suse/pstore-zone-Add-a-null-pointer-check-to-the-psz_kmsg.patch
  (stable-fixes CVE-2024-35940 bsc#1224537).
- Update
  patches.suse/s390-zcrypt-fix-reference-counting-on-zcrypt-card-objects.patch
  (git-fixes bsc#1223592 CVE-2024-26957 bsc#1223666).
- Update
  patches.suse/scsi-core-Fix-unremoved-procfs-host-directory-regression.patch
  (git-fixes CVE-2024-26935 bsc#1223675).
- Update
  patches.suse/scsi-lpfc-Fix-possible-memory-leak-in-lpfc_rcv_padis.patch
  (bsc#1220021 CVE-2024-35930 bsc#1224651).
- Update patches.suse/scsi-sg-Avoid-sg-device-teardown-race.patch
  (git-fixes CVE-2024-35954 bsc#1224675).
- Update
  patches.suse/scsi-smartpqi-Fix-disable_managed_interrupts.patch
  (git-fixes CVE-2024-26742 bsc#1222608).
- Update
  patches.suse/selinux-avoid-dereference-of-garbage-after-mount-fai.patch
  (git-fixes CVE-2024-35904 bsc#1224494).
- Update
  patches.suse/serial-mxs-auart-add-spinlock-around-changing-cts-st.patch
  (git-fixes CVE-2024-27000 bsc#1223757).
- Update
  patches.suse/serial-pmac_zilog-Remove-flawed-mitigation-for-rx-ir.patch
  (git-fixes CVE-2024-26999 bsc#1223754).
- Update
  patches.suse/soc-fsl-qbman-Always-disable-interrupts-when-taking-.patch
  (git-fixes CVE-2024-35806 bsc#1224699).
- Update
  patches.suse/soc-fsl-qbman-Use-raw-spinlock-for-cgr_lock.patch
  (git-fixes CVE-2024-35819 bsc#1224683).
- Update patches.suse/speakup-Avoid-crash-on-very-long-word.patch
  (git-fixes CVE-2024-26994 bsc#1223750).
- Update
  patches.suse/spi-lpspi-Avoid-potential-use-after-free-in-probe.patch
  (git-fixes CVE-2024-26866 bsc#1223024).
- Update
  patches.suse/spi-mchp-pci1xxx-Fix-a-possible-null-pointer-derefer.patch
  (git-fixes CVE-2024-35883 bsc#1224521).
- Update
  patches.suse/spi-spi-mt65xx-Fix-NULL-pointer-access-in-interrupt-.patch
  (git-fixes CVE-2024-27028 bsc#1223788).
- Update
  patches.suse/ubifs-Set-page-uptodate-in-the-correct-place.patch
  (git-fixes CVE-2024-35821 bsc#1224629).
- Update
  patches.suse/usb-cdc-wdm-close-race-between-read-and-workqueue.patch
  (git-fixes CVE-2024-35812 bsc#1224624).
- Update
  patches.suse/usb-dwc2-host-Fix-dereference-issue-in-DDMA-completi.patch
  (git-fixes CVE-2024-26997 bsc#1223741).
- Update
  patches.suse/usb-dwc3-am62-fix-module-unload-reload-behavior.patch
  (git-fixes CVE-2024-26963 bsc#1223651).
- Update
  patches.suse/usb-gadget-f_ncm-Fix-UAF-ncm-object-at-re-bind-after.patch
  (stable-fixes CVE-2024-26996 bsc#1223752).
- Update
  patches.suse/usb-gadget-ncm-Avoid-dropping-datagrams-of-properly-.patch
  (git-fixes CVE-2024-27405 bsc#1224423).
- Update
  patches.suse/usb-gadget-ncm-Fix-handling-of-zero-block-length-pac.patch
  (git-fixes CVE-2024-35825 bsc#1224681).
- Update
  patches.suse/usb-typec-altmodes-displayport-create-sysfs-nodes-as.patch
  (git-fixes CVE-2024-35790 bsc#1224712).
- Update
  patches.suse/usb-typec-tcpm-Correct-the-PDO-counting-in-pd_set.patch
  (git-fixes CVE-2024-26995 bsc#1223696).
- Update
  patches.suse/usb-typec-tcpm-fix-double-free-issue-in-tcpm_port_un.patch
  (git-fixes CVE-2024-26932 bsc#1223649).
- Update patches.suse/usb-typec-ucsi-Limit-read-size-on-v1.2.patch
  (stable-fixes CVE-2024-35924 bsc#1224657).
- Update
  patches.suse/usb-udc-remove-warning-when-queue-disabled-ep.patch
  (stable-fixes CVE-2024-35822 bsc#1224739).
- Update
  patches.suse/usb-xhci-Add-error-handling-in-xhci_map_urb_for_dma.patch
  (git-fixes CVE-2024-26964 bsc#1223650).
- Update
  patches.suse/vt-fix-unicode-buffer-corruption-when-deleting-chara.patch
  (git-fixes CVE-2024-35823 bsc#1224692).
- Update
  patches.suse/wifi-ath11k-decrease-MHI-channel-buffer-length-to-8K.patch
  (bsc#1207948 CVE-2024-35938 bsc#1224643).
- Update
  patches.suse/wifi-brcmfmac-Fix-use-after-free-bug-in-brcmf_cfg802.patch
  (CVE-2023-47233 bsc#1216702 CVE-2024-35811 bsc#1224592).
- Update
  patches.suse/wifi-cfg80211-check-A-MSDU-format-more-carefully.patch
  (stable-fixes CVE-2024-35937 bsc#1224526).
- Update
  patches.suse/wifi-iwlwifi-dbg-tlv-ensure-NUL-termination.patch
  (git-fixes CVE-2024-35845 bsc#1224731).
- Update
  patches.suse/wifi-iwlwifi-mvm-don-t-set-the-MFP-flag-for-the-GTK.patch
  (git-fixes CVE-2024-27434 bsc#1224710).
- Update
  patches.suse/wifi-iwlwifi-mvm-rfi-fix-potential-response-leaks.patch
  (git-fixes CVE-2024-35912 bsc#1224487).
- Update
  patches.suse/wifi-libertas-fix-some-memleaks-in-lbs_allocate_cmd_.patch
  (git-fixes CVE-2024-35828 bsc#1224622).
- Update
  patches.suse/wifi-mac80211-check-clear-fast-rx-for-non-4addr-sta-.patch
  (stable-fixes CVE-2024-35789 bsc#1224749).
- Update
  patches.suse/wifi-mac80211-fix-potential-sta-link-leak.patch
  (git-fixes CVE-2024-35838 bsc#1224613).
- Update
  patches.suse/wifi-nl80211-reject-iftype-change-with-mesh-ID-chang.patch
  (git-fixes CVE-2024-27410 bsc#1224432).
- Update
  patches.suse/wifi-rtw89-fix-null-pointer-access-when-abort-scan.patch
  (stable-fixes CVE-2024-35946 bsc#1224646).
- Update
  patches.suse/wireguard-netlink-access-device-through-ctx-instead-.patch
  (git-fixes CVE-2024-26950 bsc#1223661).
- Update
  patches.suse/wireguard-netlink-check-for-dangling-peer-via-is_dea.patch
  (git-fixes CVE-2024-26951 bsc#1223660).
- Update
  patches.suse/wireguard-receive-annotate-data-race-around-receivin.patch
  (git-fixes CVE-2024-26861 bsc#1223076).
- Update
  patches.suse/x86-coco-Require-seeding-RNG-with-RDRAND-on-CoCo-systems.patch
  (git-fixes CVE-2024-35875 bsc#1224665).
- Update
  patches.suse/x86-fpu-Keep-xfd_state-in-sync-with-MSR_IA32_XFD.patch
  (git-fixes CVE-2024-35801 bsc#1224732).
- Update
  patches.suse/xen-evtchn-avoid-WARN-when-unbinding-an-event-channe.patch
  (git-fixes CVE-2024-27067 bsc#1223739).
- Update
  patches.suse/xsk-recycle-buffer-in-case-Rx-queue-was-full.patch
  (bsc#1221303 CVE-2024-26611 CVE-2024-35834 bsc#1224620).
- commit 005afc6
* Wed May 22 2024 jlee@suse.com
- Update
  patches.suse/ACPI-LPIT-Avoid-u32-multiplication-overflow.patch
  (git-fixes CVE-2023-52683 bsc#1224627).
- Update
  patches.suse/ACPI-video-check-for-error-while-searching-for-backl.patch
  (git-fixes CVE-2023-52693 bsc#1224686).
- Update
  patches.suse/ASoC-Intel-sof_sdw_rt_sdca_jack_common-ctx-headset_c.patch
  (git-fixes CVE-2023-52697 bsc#1224596).
- Update
  patches.suse/ASoC-SOF-amd-Fix-memory-leak-in-amd_sof_acp_probe.patch
  (git-fixes CVE-2023-52663 bsc#1224630).
- Update
  patches.suse/Revert-drm-amd-pm-resolve-reboot-exception-for-si-ol.patch
  (git-fixes CVE-2023-52657 bsc#1224722).
- Update
  patches.suse/Revert-net-mlx5-Block-entering-switchdev-mode-with-n.patch
  (git-fixes CVE-2023-52658 bsc#1224719).
- Update
  patches.suse/SUNRPC-fix-a-memleak-in-gss_import_v2_context.patch
  (git-fixes CVE-2023-52653 bsc#1223712).
- Update
  patches.suse/bpf-Guard-stack-limits-against-32bit-overflow.patch
  (git-fixes CVE-2023-52676 bsc#1224730).
- Update
  patches.suse/crypto-rsa-add-a-check-for-allocation-failure.patch
  (bsc#1222775 CVE-2023-52472 bsc#1220430).
- Update
  patches.suse/crypto-s390-aes-Fix-buffer-overread-in-CTR-mode.patch
  (git-fixes CVE-2023-52669 bsc#1224637).
- Update
  patches.suse/crypto-safexcel-Add-error-handling-for-dma_map_sg-ca.patch
  (git-fixes CVE-2023-52687 bsc#1224501).
- Update
  patches.suse/drm-amd-display-Check-writeback-connectors-in-create.patch
  (git-fixes CVE-2023-52695 bsc#1224506).
- Update
  patches.suse/drm-amd-display-Fix-a-debugfs-null-pointer-error.patch
  (git-fixes CVE-2023-52673 bsc#1224741).
- Update
  patches.suse/drm-amd-display-Fix-hang-underflow-when-transitionin.patch
  (git-fixes CVE-2023-52671 bsc#1224729).
- Update
  patches.suse/drm-amd-pm-fix-a-double-free-in-si_dpm_init.patch
  (git-fixes CVE-2023-52691 bsc#1224607).
- Update
  patches.suse/drm-amdkfd-Confirm-list-is-non-empty-before-utilizin.patch
  (git-fixes CVE-2023-52678 bsc#1224617).
- Update
  patches.suse/drm-bridge-tpd12s015-Drop-buggy-__exit-annotation-fo.patch
  (git-fixes CVE-2023-52694 bsc#1224598).
- Update
  patches.suse/drm-tegra-rgb-Fix-missing-clk_put-in-the-error-handl.patch
  (git-fixes CVE-2023-52661 bsc#1224445).
- Update
  patches.suse/drm-vmwgfx-fix-a-memleak-in-vmw_gmrid_man_get_node.patch
  (git-fixes CVE-2023-52662 bsc#1224449).
- Update patches.suse/efivarfs-Free-s_fs_info-on-unmount.patch
  (bsc#1220328 CVE-2023-52463 CVE-2023-52681 bsc#1224505).
- Update
  patches.suse/media-rkisp1-Fix-IRQ-handling-due-to-shared-interrup.patch
  (stable-fixes CVE-2023-52660 bsc#1224443).
- Update
  patches.suse/net-atlantic-eliminate-double-free-in-error-handling.patch
  (git-fixes CVE-2023-52664 bsc#1224747).
- Update
  patches.suse/net-mlx5e-fix-a-potential-double-free-in-fs_any_crea.patch
  (jsc#PED-3311 CVE-2023-52667 bsc#1224603).
- Update
  patches.suse/of-Fix-double-free-in-of_parse_phandle_with_args_map.patch
  (git-fixes CVE-2023-52679 bsc#1224508).
- Update
  patches.suse/powerpc-imc-pmu-Add-a-null-pointer-check-in-update_events_in_group.patch
  (git-fixes CVE-2023-52675 bsc#1224504).
- Update
  patches.suse/powerpc-powernv-Add-a-null-pointer-check-in-opal_eve.patch
  (bsc#1065729 CVE-2023-52686 bsc#1224682).
- Update
  patches.suse/powerpc-powernv-Add-a-null-pointer-check-in-opal_pow.patch
  (bsc#1181674 ltc#189159 git-fixes CVE-2023-52696 bsc#1224601).
- Update
  patches.suse/powerpc-powernv-Add-a-null-pointer-check-to-scom_deb.patch
  (bsc#1194869 CVE-2023-52690 bsc#1224611).
- Update
  patches.suse/pstore-ram_core-fix-possible-overflow-in-persistent_.patch
  (git-fixes CVE-2023-52685 bsc#1224728).
- Update
  patches.suse/rpmsg-virtio-Free-driver_override-when-rpmsg_remove.patch
  (git-fixes CVE-2023-52670 bsc#1224696).
- commit 578211b
* Wed May 22 2024 jgross@suse.com
- vhost: Add smp_rmb() in vhost_enable_notify() (git-fixes).
- commit 2e20e2c
* Wed May 22 2024 jgross@suse.com
- vhost: Add smp_rmb() in vhost_vq_avail_empty() (git-fixes).
- commit 936d53e
* Wed May 22 2024 jgross@suse.com
- virtio_net: Do not send RSS key if it is not supported
  (git-fixes).
- commit cc7c4a0
* Wed May 22 2024 jgross@suse.com
- vsock/virtio: fix packet delivery to tap device (git-fixes).
- commit dfd8673
* Wed May 22 2024 jgross@suse.com
- virtio-blk: Ensure no requests in virtqueues before deleting
  vqs (git-fixes).
- commit 966a23e
* Wed May 22 2024 jgross@suse.com
- KVM: VMX: Disable LBR virtualization if the CPU doesn't support
  LBR callstacks (git-fixes).
- commit f941b05
* Wed May 22 2024 nik.borisov@suse.com
- efi/unaccepted: do not let /proc/vmcore try to access unaccepted memory (git-fixes).
- commit c99f198
* Wed May 22 2024 nik.borisov@suse.com
- proc/kcore: do not try to access unaccepted memory (git-fixes).
- commit 2daf00c
* Wed May 22 2024 nik.borisov@suse.com
- efi/unaccepted: touch soft lockup during memory accept (git-fixes).
- commit 45ed7cb
* Wed May 22 2024 nik.borisov@suse.com
- x86/mm: Ensure input to pfn_to_kaddr() is treated as a 64-bit type (bsc#1224442 CVE-2023-52659).
- commit dad72fd
* Wed May 22 2024 jgross@suse.com
- kabi fix of perf/x86/intel: Expose existence of callback support to KVM
  (git fixes).
- commit 5db441c
* Wed May 22 2024 jgross@suse.com
- perf/x86/intel: Expose existence of callback support to KVM
  (git-fixes).
- commit b24b5fc
* Wed May 22 2024 jgross@suse.com
- kABI fix of KVM: x86: Snapshot if a vCPU's vendor model is AMD vs.
  Intel compatible (git-fixes).
- commit 38bcaaa
* Wed May 22 2024 lhenriques@suse.de
- ceph: redirty page before returning AOP_WRITEPAGE_ACTIVATE
  (bsc#1224866).
- commit 6a4b4a1
* Wed May 22 2024 iivanov@suse.de
- supported.conf: Add APM X-Gene SoC hardware monitoring driver (bsc#1223265 jsc#PED-8570)
- commit 4b0eeb3
* Wed May 22 2024 tiwai@suse.de
- remoteproc: k3-r5: Jump to error handling labels in start/stop
  errors (git-fixes).
- commit 6f545f8
* Wed May 22 2024 tiwai@suse.de
- libsubcmd: Fix parse-options memory leak (git-fixes).
- dmaengine: idxd: Avoid unnecessary destruction of file_ida
  (git-fixes).
- dmaengine: axi-dmac: fix possible race in remove() (git-fixes).
- dmaengine: idma64: Add check for dma_set_max_seg_size
  (git-fixes).
- remoteproc: k3-r5: Do not allow core1 to power up before core0
  via sysfs (git-fixes).
- remoteproc: k3-r5: Wait for core0 power-up before powering up
  core1 (git-fixes).
- remoteproc: mediatek: Make sure IPI buffer fits in L2TCM
  (git-fixes).
- PCI: tegra194: Fix probe path for Endpoint mode (git-fixes).
- PCI: rockchip-ep: Remove wrong mask on subsys_vendor_id
  (git-fixes).
- PCI: dwc: ep: Fix DBI access failure for drivers requiring
  refclk from host (git-fixes).
- PCI/EDR: Align EDR_PORT_LOCATE_DSM with PCI Firmware r3.3
  (git-fixes).
- PCI/EDR: Align EDR_PORT_DPC_ENABLE_DSM with PCI Firmware r3.3
  (git-fixes).
- KEYS: trusted: Do not use WARN when encode fails (git-fixes).
- KEYS: trusted: Fix memory leak in tpm2_key_encode() (git-fixes).
- commit d7da373
* Tue May 21 2024 jgross@suse.com
- KVM: x86: Only set APICV_INHIBIT_REASON_ABSENT if APICv is
  enabled (git-fixes).
- commit 7d13726
* Tue May 21 2024 jgross@suse.com
- KVM: x86: Allow, don't ignore, same-value writes to immutable
  MSRs (git-fixes).
- commit e25e965
* Tue May 21 2024 jgross@suse.com
- KVM: nVMX: Clear EXIT_QUALIFICATION when injecting an EPT
  Misconfig (git-fixes).
- commit 21a74db
* Tue May 21 2024 jgross@suse.com
- KVM: x86/mmu: Don't force emulation of L2 accesses to non-APIC
  internal slots (git-fixes).
- commit b2d6429
* Tue May 21 2024 jgross@suse.com
- KVM: x86/mmu: Move private vs. shared check above slot validity
  checks (git-fixes).
- commit 2108d3a
* Tue May 21 2024 jgross@suse.com
- KVM: x86: Fully re-initialize supported_mce_cap on vendor
  module load (git-fixes).
- commit 52160e6
* Tue May 21 2024 jgross@suse.com
- KVM: x86/mmu: Write-protect L2 SPTEs in TDP MMU when clearing
  dirty status (git-fixes).
- commit 7bdd69f
* Tue May 21 2024 tiwai@suse.de
- drm/nouveau/disp: Fix missing backlight control on Macbook 5,
  1 (bsc#1223838).
- commit 07ffc12
* Tue May 21 2024 iivanov@suse.de
- iommu/dma: Force swiotlb_max_mapping_size on an untrusted device (bsc#1224331)
- commit 55fb87b
* Tue May 21 2024 iivanov@suse.de
- swiotlb: Fix alignment checks when both allocation and DMA masks are (bsc#1224331)
- commit 8bebd77
* Tue May 21 2024 iivanov@suse.de
- swiotlb: Honour dma_alloc_coherent() alignment in swiotlb_alloc() (bsc#1224331)
- commit fcf796a
* Tue May 21 2024 iivanov@suse.de
- swiotlb: Fix double-allocation of slots due to broken alignment (bsc#1224331)
- commit c65bb03
* Tue May 21 2024 jgross@suse.com
- KVM: x86/pmu: Set enable bits for GP counters in
  PERF_GLOBAL_CTRL at "RESET" (git-fixes).
- commit 1ba62ae
* Tue May 21 2024 jgross@suse.com
- KVM: x86/pmu: Disable support for adaptive PEBS (git-fixes).
- commit 9862bdd
* Tue May 21 2024 jgross@suse.com
- KVM: x86/pmu: Do not mask LVTPC when handling a PMI on AMD
  platforms (git-fixes).
- commit 5f8077d
* Tue May 21 2024 jgross@suse.com
- KVM: x86: Snapshot if a vCPU's vendor model is AMD vs. Intel
  compatible (git-fixes).
- commit c9c8902
* Tue May 21 2024 jgross@suse.com
- x86/kvm/Kconfig: Have KVM_AMD_SEV select ARCH_HAS_CC_PLATFORM
  (git-fixes).
- commit f882a8e
* Tue May 21 2024 jgross@suse.com
- KVM: x86: Use actual kvm_cpuid.base for clearing
  KVM_FEATURE_PV_UNHALT (git-fixes).
- commit 80b67d0
* Tue May 21 2024 mfranc@suse.cz
- s390/cio: fix tracepoint subchannel type field (git-fixes
  bsc#1224793).
- commit f1aa928
* Tue May 21 2024 mfranc@suse.cz
- s390/bpf: Emit a barrier for BPF_FETCH instructions (git-fixes
  bsc#1224792).
- commit d08e4ce
* Tue May 21 2024 mfranc@suse.cz
- KVM: s390: Check kvm pointer when testing KVM_CAP_S390_HPAGE_1M
  (git-fixes bsc#1224790).
- commit b0b1c22
* Tue May 21 2024 jgross@suse.com
- KVM: x86: Introduce __kvm_get_hypervisor_cpuid() helper
  (git-fixes).
- commit 652c188
* Tue May 21 2024 jslaby@suse.cz
- rpm/kernel-obs-build.spec.in: remove reiserfs from OBS initrd
  We disabled the FS in bug 1202309. And we actively blacklist it in:
  /usr/lib/modprobe.d/60-blacklist_fs-reiserfs.conf
  This, as a side-effect, fixes obs-build's warning:
  dracut-pre-udev[1463]: sh: line 1: /usr/lib/module-init-tools/unblacklist: No such file or directory
  Exactly due to the above 60-blacklist_fs-reiserfs.conf trying to call the
  above unblacklist.
  We should likely drop ext2+ext3 from the list too, as we don't build
  them at all. But that's a different story.
- commit 9e1a078
* Tue May 21 2024 jgross@suse.com
- KVM: SVM: Add support for allowing zero SEV ASIDs (git-fixes).
- commit 9327154
* Tue May 21 2024 jgross@suse.com
- KVM: SVM: Use unsigned integers when dealing with ASIDs
  (git-fixes).
- commit b0fec37
* Tue May 21 2024 cfamullaconrad@suse.de
- tools/power turbostat: Expand probe_intel_uncore_frequency()
  (bsc#1221765).
- commit 7c0d70f
* Tue May 21 2024 jgross@suse.com
- KVM: x86/xen: fix recursive deadlock in timer injection
  (git-fixes).
- commit 389ea84
* Tue May 21 2024 jgross@suse.com
- KVM: x86/xen: remove WARN_ON_ONCE() with false positives in
  evtchn delivery (git-fixes).
- commit d63a8c9
* Tue May 21 2024 jgross@suse.com
- KVM: x86/xen: inject vCPU upcall vector when local APIC is
  enabled (git-fixes).
- commit 538dcab
* Tue May 21 2024 jgross@suse.com
- KVM: x86/xen: improve accuracy of Xen timers (git-fixes).
- commit 921d76d
* Tue May 21 2024 jgross@suse.com
- KVM: x86/pmu: Explicitly check NMI from guest to reducee false
  positives (git-fixes).
- commit be2edf0
* Tue May 21 2024 jgross@suse.com
- KVM: x86/pmu: Zero out PMU metadata on AMD if PMU is disabled
  (git-fixes).
- commit fe18eef
* Tue May 21 2024 jgross@suse.com
- KVM: x86/pmu: Disallow "fast" RDPMC for architectural Intel PMUs
  (git-fixes).
- commit 406de6b
* Tue May 21 2024 jgross@suse.com
- KVM: x86/pmu: Apply "fast" RDPMC only to Intel PMUs (git-fixes).
- commit dd1520f
* Tue May 21 2024 jgross@suse.com
- KVM: x86/pmu: Prioritize VMX interception over #GP on RDPMC
  due to bad index (git-fixes).
- commit b2e9cf1
* Tue May 21 2024 jgross@suse.com
- KVM: x86/pmu: Don't ignore bits 31:30 for RDPMC index on AMD
  (git-fixes).
- commit fd656b7
* Tue May 21 2024 jgross@suse.com
- KVM: x86/pmu: Allow programming events that match unsupported
  arch events (git-fixes).
- commit 60f57dc
* Tue May 21 2024 tiwai@suse.de
- firmware: dmi-id: add a release callback function (git-fixes).
- watchdog: sa1100: Fix PTR_ERR_OR_ZERO() vs NULL check in
  sa1100dog_probe() (git-fixes).
- watchdog: rti_wdt: Set min_hw_heartbeat_ms to accommodate a
  safety margin (git-fixes).
- watchdog: bd9576: Drop "always-running" property (git-fixes).
- watchdog: cpu5wdt.c: Fix use-after-free bug caused by
  cpu5wdt_trigger (git-fixes).
- i2c: acpi: Unbind mux adapters before delete (git-fixes).
- i2c: synquacer: Fix an error handling path in
  synquacer_i2c_probe() (git-fixes).
- i2c: cadence: Avoid fifo clear after start (git-fixes).
- pinctrl: qcom: pinctrl-sm7150: Fix sdc1 and ufs special pins
  regs (git-fixes).
- pinctrl: armada-37xx: remove an unused variable (git-fixes).
- crypto: qat - Fix ADF_DEV_RESET_SYNC memory leak (git-fixes).
- commit 60d82a4
* Tue May 21 2024 jgross@suse.com
- KVM: x86/pmu: Always treat Fixed counters as available when
  supported (git-fixes).
- commit c4b0d18
* Tue May 21 2024 jgross@suse.com
- KVM: VMX: Report up-to-date exit qualification to userspace
  (git-fixes).
- commit d6b020d
* Tue May 21 2024 jgross@suse.com
- KVM: x86: Fix broken debugregs ABI for 32 bit kernels
  (git-fixes).
- commit 69a1ee8
* Tue May 21 2024 jgross@suse.com
- SEV: disable SEV-ES DebugSwap by default (git-fixes).
- commit dcaff2f
* Tue May 21 2024 jgross@suse.com
- KVM: x86/mmu: Restrict KVM_SW_PROTECTED_VM to the TDP MMU
  (git-fixes).
- commit c561279
* Tue May 21 2024 jgross@suse.com
- KVM: x86: Update KVM_SW_PROTECTED_VM docs to make it clear
  they're a WIP (git-fixes).
- commit aba16e8
* Tue May 21 2024 jgross@suse.com
- KVM: x86: Mark target gfn of emulated atomic instruction as
  dirty (git-fixes).
- commit 303882a
* Tue May 21 2024 jgross@suse.com
- KVM: SVM: Flush pages under kvm->lock to fix UAF in
  svm_register_enc_region() (git-fixes).
- commit 4382f8a
* Mon May 20 2024 ailiop@suse.com
- sysv: don't call sb_bread() with pointers_lock held
  (bsc#1224659 CVE-2023-52699).
- commit 6cad3fd
* Mon May 20 2024 lduncan@suse.com
- Update
  patches.suse/scsi-smartpqi-Fix-disable_managed_interrupts.patch
  (git-fixes bsc#1222608 CVE-2024-26742).
- commit 950259c
* Mon May 20 2024 dsterba@suse.com
- btrfs: always clear PERTRANS metadata during commit (git-fixes)
- commit f24386b
* Mon May 20 2024 dsterba@suse.com
- btrfs: record delayed inode root in transaction (git-fixes)
- commit 3382370
* Mon May 20 2024 dsterba@suse.com
- btrfs: send: handle path ref underflow in header iterate_inode_ref() (git-fixes)
- commit 21cfc26
* Mon May 20 2024 dsterba@suse.com
- btrfs: export: handle invalid inode or root reference in btrfs_get_parent() (git-fixes)
- commit a357818
* Mon May 20 2024 dsterba@suse.com
- btrfs: fix kvcalloc() arguments order in btrfs_ioctl_send() (git-fixes)
- commit 3227c75
* Mon May 20 2024 dsterba@suse.com
- btrfs: sysfs: validate scrub_speed_max value (git-fixes)
- commit 333b480
* Mon May 20 2024 dsterba@suse.com
- btrfs: prevent transaction block reserve underflow when starting transaction (git-fixes)
- commit e1ff84f
* Mon May 20 2024 dsterba@suse.com
- btrfs: fix race when refilling delayed refs block reserve (git-fixes)
- commit f241886
* Mon May 20 2024 dsterba@suse.com
- btrfs: assert delayed node locked when removing delayed item (git-fixes)
- commit 7298484
* Mon May 20 2024 dsterba@suse.com
- btrfs: check for BTRFS_FS_ERROR in pending ordered assert (git-fixes)
- commit f5815af
* Mon May 20 2024 dsterba@suse.com
- btrfs: output extra debug info if we failed to find an inline backref (git-fixes)
- commit 92fba41
* Mon May 20 2024 dsterba@suse.com
- btrfs: set page extent mapped after read_folio in relocate_one_page (git-fixes)
- commit 446041f
* Mon May 20 2024 dsterba@suse.com
- btrfs: handle errors properly in update_inline_extent_backref() (git-fixes)
- commit ca5b7a2
* Mon May 20 2024 nmorey@suse.com
- RDMA/cma: Fix kmemleak in rdma_core observed during blktests nvme/rdma use siw (git-fixes)
- commit 4bdc550
* Mon May 20 2024 nmorey@suse.com
- RDMA/IPoIB: Fix format truncation compilation errors (git-fixes)
- commit 6d737b0
* Mon May 20 2024 nmorey@suse.com
- bnxt_re: avoid shift undefined behavior in bnxt_qplib_alloc_init_hwq (git-fixes)
- commit 3e0bec3
* Mon May 20 2024 nmorey@suse.com
- IB/mlx5: Use __iowrite64_copy() for write combining stores (git-fixes)
- commit 9a3847d
* Mon May 20 2024 nmorey@suse.com
- RDMA/rxe: Fix incorrect rxe_put in error path (git-fixes)
- commit c50f3b5
* Mon May 20 2024 nmorey@suse.com
- RDMA/rxe: Allow good work requests to be executed (git-fixes)
- commit b36653a
* Mon May 20 2024 nmorey@suse.com
- RDMA/rxe: Fix seg fault in rxe_comp_queue_pkt (git-fixes)
- commit ba9e71d
* Mon May 20 2024 nmorey@suse.com
- RDMA/hns: Modify the print level of CQE error (git-fixes)
- commit 12a2ba5
* Mon May 20 2024 nmorey@suse.com
- RDMA/hns: Use complete parentheses in macros (git-fixes)
- commit 7a9c544
* Mon May 20 2024 nmorey@suse.com
- RDMA/hns: Fix GMV table pagesize (git-fixes)
- commit fb0321b
* Mon May 20 2024 nmorey@suse.com
- RDMA/hns: Fix UAF for cq async event (git-fixes)
- commit 8ea7fea
* Mon May 20 2024 nmorey@suse.com
- RDMA/hns: Fix deadlock on SRQ async events. (git-fixes)
- commit fb64efc
* Mon May 20 2024 nmorey@suse.com
- RDMA/hns: Add max_ah and cq moderation capacities in query_device() (git-fixes)
- commit 6c2f69b
* Mon May 20 2024 nmorey@suse.com
- RDMA/hns: Fix return value in hns_roce_map_mr_sg (git-fixes)
- commit 60cadbc
* Mon May 20 2024 nmorey@suse.com
- RDMA/mlx5: Adding remote atomic access flag to updatable flags (git-fixes)
- commit dacefcf
* Mon May 20 2024 nmorey@suse.com
- RDMA/mlx5: Change check for cacheable mkeys (git-fixes)
- commit c838c29
* Mon May 20 2024 nmorey@suse.com
- RDMA/mlx5: Uncacheable mkey has neither rb_key or cache_ent (git-fixes)
- commit 3012f2a
* Mon May 20 2024 nmorey@suse.com
- qibfs: fix dentry leak (git-fixes)
- commit 3dd0249
* Mon May 20 2024 nmorey@suse.com
- RDMA/mlx5: Fix port number for counter query in multi-port configuration (git-fixes)
- commit 52028fd
* Mon May 20 2024 nmorey@suse.com
- RDMA/cm: Print the old state when cm_destroy_id gets timeout (git-fixes)
- commit 1a1a1ef
* Mon May 20 2024 nmorey@suse.com
- RDMA/rxe: Fix the problem "mutex_destroy missing" (git-fixes)
- commit 0a73f85
* Mon May 20 2024 iivanov@suse.de
- arm64: dts: microchip: sparx5: fix mdio reg (git-fixes)
- commit 88132f5
* Mon May 20 2024 iivanov@suse.de
- arm64: dts: hi3798cv200: fix the size of GICR (git-fixes)
- commit 366d274
* Mon May 20 2024 iivanov@suse.de
- arm64: tegra: Correct Tegra132 I2C alias (git-fixes)
- commit da1130e
* Mon May 20 2024 iivanov@suse.de
- arm64: dts: allwinner: h616: Fix I2C0 pins (git-fixes)
- commit eee423c
* Mon May 20 2024 iivanov@suse.de
- arm64: dts: allwinner: Pine H64: correctly remove reg_gmac_3v3 (git-fixes)
- commit 7d432cc
* Mon May 20 2024 iivanov@suse.de
- arm64: dts: rockchip: Add enable-strobe-pulldown to emmc phy on ROCK (git-fixes)
- commit d52e38e
* Mon May 20 2024 iivanov@suse.de
- arm64: dts: rockchip: Add enable-strobe-pulldown to emmc phy on ROCK (git-fixes)
- commit 029788f
* Mon May 20 2024 iivanov@suse.de
- arm64: dts: rockchip: fix alphabetical ordering RK3399 puma (git-fixes)
  Refresh patches.suse/arm64-dts-rockchip-enable-internal-pull-up-on-PCIE_WAKE-for-RK3399-Puma.patch
- commit aeac8db
* Mon May 20 2024 iivanov@suse.de
- dt-bindings: clock: qcom: Add missing UFS QREF clocks (git-fixes)
- commit 4e403e4
* Mon May 20 2024 tiwai@suse.de
- selftests/kcmp: remove unused open mode (git-fixes).
- nilfs2: make superblock data array index computation sparse
  friendly (git-fixes).
- Docs/admin-guide/mm/damon/usage: fix wrong example of DAMOS
  filter matching sysfs file (git-fixes).
- lib/test_hmm.c: handle src_pfns and dst_pfns allocation failure
  (git-fixes).
- commit 7902091
* Mon May 20 2024 lzhong@suse.de
- powerpc/pseries/vio: Don't return ENODEV if node or compatible
  missing (bsc#1220783).
- commit 19e446b
* Sun May 19 2024 tiwai@suse.de
- clk: qcom: clk-alpha-pll: fix rate setting for Stromer PLLs
  (git-fixes).
- clk: qcom: mmcc-msm8998: fix venus clock issue (git-fixes).
- clk: qcom: dispcc-sm8550: fix DisplayPort clocks (git-fixes).
- clk: qcom: dispcc-sm6350: fix DisplayPort clocks (git-fixes).
- clk: qcom: dispcc-sm8450: fix DisplayPort clocks (git-fixes).
- clk: qcom: clk-alpha-pll: remove invalid Stromer register offset
  (git-fixes).
- clk: samsung: exynosautov9: fix wrong pll clock id value
  (git-fixes).
- clk: renesas: r9a07g043: Add clock and reset entry for PLIC
  (git-fixes).
- clk: renesas: r8a779a0: Fix CANFD parent clock (git-fixes).
- clk: rs9: fix wrong default value for clock amplitude
  (git-fixes).
- clk: mediatek: mt8365-mm: fix DPI0 parent (git-fixes).
- clk: mediatek: pllfh: Don't log error for missing fhctl node
  (git-fixes).
- commit 8bfa411
* Sat May 18 2024 tiwai@suse.de
- selftests: net: bridge: increase IGMP/MLD exclude timeout
  membership interval (git-fixes).
- of: module: add buffer overflow check in of_modalias()
  (git-fixes).
- selftests/powerpc/dexcr: Add -no-pie to hashchk tests
  (git-fixes).
- firmware: raspberrypi: Use correct device for DMA mappings
  (git-fixes).
- Revert "drm/nouveau/firmware: Fix SG_DEBUG error with
  nvkm_firmware_ctor()" (stable-fixes).
- drm/i915/audio: Fix audio time stamp programming for DP
  (stable-fixes).
- gpiolib: cdev: fix uninitialised kfifo (git-fixes).
- selftests: test_bridge_neigh_suppress.sh: Fix failures due to
  duplicate MAC (git-fixes).
- Bluetooth: qca: fix firmware check error path (git-fixes).
- dyndbg: fix old BUG_ON in >control parser (stable-fixes).
- mei: me: add lunar lake point M DID (stable-fixes).
- usb: xhci-plat: Don't include xhci.h (stable-fixes).
- ASoC: meson: axg-fifo: use threaded irq to check periods
  (git-fixes).
- drm/nouveau/firmware: Fix SG_DEBUG error with
  nvkm_firmware_ctor() (stable-fixes).
- drm/amd/display: Fix incorrect DSC instance for MST
  (stable-fixes).
- drm/amd/display: Atom Integrated System Info v2_2 for DCN35
  (stable-fixes).
- drm/amd/display: Handle Y carry-over in VCP X.Y calculation
  (stable-fixes).
- clk: Don't hold prepare_lock when calling kref_put()
  (stable-fixes).
- drm/nouveau/dp: Don't probe eDP ports twice harder
  (stable-fixes).
- drm/radeon: silence UBSAN warning (v3) (stable-fixes).
- net:usb:qmi_wwan: support Rolling modules (stable-fixes).
- gpio: crystalcove: Use -ENOTSUPP consistently (stable-fixes).
- gpio: wcove: Use -ENOTSUPP consistently (stable-fixes).
- platform/x86: ISST: Add Granite Rapids-D to HPM CPU list
  (stable-fixes).
- selftests: timers: Fix valid-adjtimex signed left-shift
  undefined behavior (stable-fixes).
- gpu: host1x: Do not setup DMA for virtual devices
  (stable-fixes).
- amd/amdkfd: sync all devices to wait all processes being evicted
  (stable-fixes).
- drm/amdgpu: Fix VCN allocation in CPX partition (stable-fixes).
- drm/amdgpu: implement IRQ_STATE_ENABLE for SDMA v4.4.2
  (stable-fixes).
- drm/amdgpu: Refine IB schedule error logging (stable-fixes).
- firewire: ohci: mask bus reset interrupts between ISR and
  bottom half (stable-fixes).
- regulator: tps65132: Add of_match table (stable-fixes).
- ata: sata_gemini: Check clk_enable() result (stable-fixes).
- ASoC: SOF: Intel: hda-dsp: Skip IMR boot on ACE platforms in
  case of S3 suspend (stable-fixes).
- ALSA: line6: Zero-initialize message buffers (stable-fixes).
- vboxsf: explicitly deny setlease attempts (stable-fixes).
- drm/amdkfd: range check cp bad op exception interrupts
  (stable-fixes).
- drm/amdkfd: Check cgroup when returning DMABuf info
  (stable-fixes).
- selftests/ftrace: Fix event filter target_func selection
  (stable-fixes).
- wifi: iwlwifi: mvm: guard against invalid STA ID on removal
  (stable-fixes).
- wifi: iwlwifi: read txq->read_ptr under lock (stable-fixes).
- wifi: mac80211: fix prep_connection error path (stable-fixes).
- wifi: cfg80211: fix rdev_dump_mpp() arguments order
  (stable-fixes).
- wifi: mac80211: fix ieee80211_bss_*_flags kernel-doc
  (stable-fixes).
- ASoC: meson: axg-fifo: use FIELD helpers (stable-fixes).
- gpiolib: cdev: relocate debounce_period_us from struct gpio_desc
  (stable-fixes).
- selftests/net: convert test_bridge_neigh_suppress.sh to run
  it in unique namespace (stable-fixes).
- commit 2872089
* Fri May 17 2024 mkoutny@suse.com
- af_unix: Fix garbage collector racing against connect()
  (CVE-2024-26923 bsc#1223384).
- af_unix: Replace BUG_ON() with WARN_ON_ONCE() (CVE-2024-26923
  bsc#1223384).
- af_unix: Do not use atomic ops for unix_sk(sk)->inflight
  (CVE-2024-26923 bsc#1223384).
- commit a683abb
* Fri May 17 2024 mwilck@suse.com
- dm-multipath: dont't attempt SG_IO on non-SCSI-disks
  (bsc#1223575).
- commit 2f6779f
* Fri May 17 2024 dsterba@suse.com
- btrfs: qgroup: convert PREALLOC to PERTRANS after record_root_in_trans (git-fixes)
- commit b85295a
* Fri May 17 2024 dsterba@suse.com
- btrfs: don't arbitrarily slow down delalloc if we're committing (git-fixes)
- commit d9b2223
* Fri May 17 2024 dsterba@suse.com
- btrfs: reset destination buffer when read_extent_buffer() gets invalid range (git-fixes)
- commit 7ef02d5
* Fri May 17 2024 dsterba@suse.com
- btrfs: return -EUCLEAN for delayed tree ref with a ref count not equals to 1 (git-fixes)
- commit e6b51c1
* Fri May 17 2024 dsterba@suse.com
- btrfs: file_remove_privs needs an exclusive lock in direct io write (git-fixes)
- commit 0bc88db
* Fri May 17 2024 dsterba@suse.com
- btrfs: don't start transaction when joining with TRANS_JOIN_NOSTART (git-fixes)
- commit 74fcad3
* Fri May 17 2024 dsterba@suse.com
- btrfs: fix start transaction qgroup rsv double free (git-fixes)
- commit 272247e
* Fri May 17 2024 dsterba@suse.com
- btrfs: free qgroup rsv on io failure (git-fixes)
- commit 384dac4
* Fri May 17 2024 denis.kirjanov@suse.com
- netfilter: nf_tables: disable toggling dormant table state
  more than once (git-fixes).
- commit 76bebd5
* Fri May 17 2024 denis.kirjanov@suse.com
- mptcp: process pending subflow error on close (git-fixes).
- commit ef629c5
* Fri May 17 2024 denis.kirjanov@suse.com
- mptcp: move __mptcp_error_report in protocol.c (git-fixes).
- commit a777e91
* Fri May 17 2024 denis.kirjanov@suse.com
- mptcp: fix bogus receive window shrinkage with multiple subflows
  (git-fixes).
- commit deea9a0
* Fri May 17 2024 denis.kirjanov@suse.com
- netfilter: nft_set_rbtree: use read spinlock to avoid datapath
  contention (git-fixes).
- commit ddc952e
* Fri May 17 2024 denis.kirjanov@suse.com
- net/smc: use smc_lgr_list.lock to protect smc_lgr_list.list
  iterate in smcr_port_add (git-fixes).
- commit 2d7895b
* Fri May 17 2024 denis.kirjanov@suse.com
- net/smc: bugfix for smcr v2 server connect success statistic
  (git-fixes).
- commit e746f6b
* Fri May 17 2024 denis.kirjanov@suse.com
- netfilter: nf_tables: uapi: Describe NFTA_RULE_CHAIN_ID
  (git-fixes).
- commit ec5b855
* Fri May 17 2024 denis.kirjanov@suse.com
- net: annotate data-races around sk->sk_bind_phc (git-fixes).
- commit 16b7a1e
* Fri May 17 2024 denis.kirjanov@suse.com
- net: annotate data-races around sk->sk_tsflags (git-fixes).
- commit b028530
* Fri May 17 2024 andrea.porta@suse.com
- arm64: Add the arm64.no32bit_el0 command line option
  (jsc#PED-3184).
  Please note that some adjustments were needed since the upstream commit
  is based on kernel 6.9 which has idreg-override.c moved under
  arch/arm64/kernel/pi/.
- commit 4fba46a
* Fri May 17 2024 mkoutny@suse.com
- af_unix: Drop oob_skb ref before purging queue in GC
  (CVE-2024-26676 bsc#1222380).
- commit 57acc3a
* Fri May 17 2024 mkoutny@suse.com
- af_unix: Fix task hung while purging oob_skb in GC
  (CVE-2024-26676 bsc#1222380).
- commit 3af3fbb
* Fri May 17 2024 mkoutny@suse.com
- af_unix: Call kfree_skb() for dead unix_(sk)->oob_skb in GC
  (CVE-2024-26676 bsc#1222380).
- commit 7728cdc
* Fri May 17 2024 tiwai@suse.de
- platform/x86/intel-uncore-freq: Don't present root domain on
  error (git-fixes).
- tools/arch/x86/intel_sdsi: Fix meter_certificate decoding
  (git-fixes).
- tools/arch/x86/intel_sdsi: Fix meter_show display (git-fixes).
- tools/arch/x86/intel_sdsi: Fix maximum meter bundle length
  (git-fixes).
- platform/x86: xiaomi-wmi: Fix race condition when reporting
  key events (git-fixes).
- mtd: rawnand: hynix: fixed typo (git-fixes).
- mtd: core: Report error if first mtd_otp_size() call fails in
  mtd_otp_nvmem_add() (git-fixes).
- mmc: davinci: Don't strip remove function when driver is builtin
  (git-fixes).
- mmc: sdhci_am654: Fix ITAPDLY for HS400 timing (git-fixes).
- mmc: sdhci_am654: Add ITAPDLYSEL in sdhci_j721e_4bit_set_clock
  (git-fixes).
- mmc: sdhci_am654: Add OTAP/ITAP delay enable (git-fixes).
- mmc: sdhci_am654: Write ITAPDLY for DDR52 timing (git-fixes).
- mmc: sdhci_am654: Add tuning algorithm for delay chain
  (git-fixes).
- media: sunxi: a83-mips-csi2: also select GENERIC_PHY
  (git-fixes).
- media: flexcop-usb: fix sanity check of bNumEndpoints
  (git-fixes).
- media: stk1160: fix bounds checking in stk1160_copy_video()
  (git-fixes).
- media: uvcvideo: Add quirk for Logitech Rally Bar (git-fixes).
- media: v4l: Don't turn on privacy LED if streamon fails
  (git-fixes).
- media: mc: mark the media devnode as registered from the,
  start (git-fixes).
- media: atomisp: ssh_css: Fix a null-pointer dereference in
  load_video_binaries (git-fixes).
- media: v4l2-subdev: Fix stream handling for crop API
  (git-fixes).
- media: mc: Fix graph walk in media_pipeline_start (git-fixes).
- media: i2c: et8ek8: Don't strip remove function when driver
  is builtin (git-fixes).
- media: dt-bindings: ovti,ov2680: Fix the power supply names
  (git-fixes).
- media: ipu3-cio2: Request IRQ earlier (git-fixes).
- media: rcar-vin: work around -Wenum-compare-conditional warning
  (git-fixes).
- media: ngene: Add dvb_ca_en50221_init return value check
  (git-fixes).
- commit ceb1555
* Fri May 17 2024 tiwai@suse.de
- Move upstreamed media patches into sorted section
- commit 521e539
* Thu May 16 2024 duwe@suse.de
- dmaengine: idxd: move safety flag to struct ends (bsc#1223625
  CVE-2024-21823).
- dmaengine: idxd: add a write() method for applications to
  submit work (bsc#1223625 CVE-2024-21823).
- dmaengine: idxd: add a new security check to deal with a
  hardware erratum (bsc#1223625 CVE-2024-21823).
- VFIO: Add the SPR_DSA and SPR_IAX devices to the denylist
  (bsc#1223625 CVE-2024-21823).
- commit 8718675
* Thu May 16 2024 mkoutny@suse.com
- Update
  patches.suse/io_uring-af_unix-disable-sending-io_uring-over-socke.patch
  (bsc#1218447 CVE-2023-6531 CVE-2023-52654 bsc#1224099).
- Update
  patches.suse/usb-aqc111-check-packet-for-fixup-for-true-limit.patch
  (git-fixes CVE-2023-52655 bsc#1217169).
- commit 07c8bc1
* Thu May 16 2024 denis.kirjanov@suse.com
- octeontx2-pf: fix FLOW_DIS_IS_FRAGMENT implementation
  (git-fixes).
- commit 78ec58d
* Thu May 16 2024 denis.kirjanov@suse.com
- net/mlx5: Fix peer devlink set for SF representor devlink port
  (git-fixes).
- commit 6a691b6
* Thu May 16 2024 denis.kirjanov@suse.com
- net/mlx5: Lag, restore buckets number to default after hash
  LAG deactivation (git-fixes).
- commit 19da0bb
* Thu May 16 2024 denis.kirjanov@suse.com
- net: sparx5: flower: fix fragment flags handling (git-fixes).
- commit 5fd27e9
* Thu May 16 2024 denis.kirjanov@suse.com
- net: ena: Set tx_info->xdpf value to NULL (git-fixes).
- commit 7d1d83a
* Thu May 16 2024 denis.kirjanov@suse.com
- net: ena: Fix incorrect descriptor free behavior (git-fixes).
- commit 69577fd
* Thu May 16 2024 denis.kirjanov@suse.com
- net: ena: Wrong missing IO completions check order (git-fixes).
- commit fbbd86e
* Thu May 16 2024 denis.kirjanov@suse.com
- net: ena: Fix potential sign extension issue (git-fixes).
- commit b3cc5f8
* Thu May 16 2024 denis.kirjanov@suse.com
- net: dsa: mt7530: trap link-local frames regardless of ST Port
  State (git-fixes).
- commit 726080b
* Thu May 16 2024 denis.kirjanov@suse.com
- net: sparx5: fix wrong config being used when reconfiguring PCS
  (git-fixes).
- commit d2d1229
* Thu May 16 2024 denis.kirjanov@suse.com
- net/mlx5e: RSS, Block XOR hash with over 128 channels
  (git-fixes).
- commit 40b1ccb
* Thu May 16 2024 denis.kirjanov@suse.com
- net/mlx5: Restore mistakenly dropped parts in register devlink
  flow (git-fixes).
- commit dfb4099
* Thu May 16 2024 dsterba@suse.com
- btrfs: defrag: avoid unnecessary defrag caused by incorrect extent size (git-fixes)
- commit a1c6e8c
* Thu May 16 2024 dsterba@suse.com
- btrfs: don't warn if discard range is not aligned to sector (git-fixes)
- commit f239c2a
* Thu May 16 2024 dsterba@suse.com
- btrfs: tree-checker: fix inline ref size in error messages (git-fixes)
- commit a304971
* Thu May 16 2024 dsterba@suse.com
- btrfs: defrag: reject unknown flags of btrfs_ioctl_defrag_range_args (git-fixes)
- commit 81a1329
* Thu May 16 2024 dsterba@suse.com
- btrfs: do not allow non subvolume root targets for snapshot (git-fixes)
- commit d495a4b
* Thu May 16 2024 dsterba@suse.com
- btrfs: send: ensure send_fd is writable (git-fixes)
- commit 5055583
* Thu May 16 2024 dsterba@suse.com
- btrfs: free the allocated memory if btrfs_alloc_page_array() fails (git-fixes)
- commit 532ad3c
* Thu May 16 2024 dsterba@suse.com
- btrfs: fix 64bit compat send ioctl arguments not initializing version member (git-fixes)
- commit 2c30d15
* Thu May 16 2024 dsterba@suse.com
- btrfs: fix off-by-one when checking chunk map includes logical address (git-fixes)
- commit e5842bb
* Thu May 16 2024 dsterba@suse.com
- btrfs: use u64 for buffer sizes in the tree search ioctls (git-fixes)
- commit a1c6ed1
* Thu May 16 2024 dsterba@suse.com
- btrfs: error out when reallocating block for defrag using a stale transaction (git-fixes)
- commit e6bb34b
* Thu May 16 2024 dsterba@suse.com
- btrfs: error when COWing block from a root that is being deleted (git-fixes)
- commit 78a2694
* Thu May 16 2024 dsterba@suse.com
- btrfs: error out when COWing block using a stale transaction (git-fixes)
- commit 850d86f
* Thu May 16 2024 mfranc@suse.cz
- s390/cpum_cf: make crypto counters upward compatible across
  machine types (bsc#1224348).
- commit 36c1e09
* Thu May 16 2024 dsterba@suse.com
- btrfs: always print transaction aborted messages with an error level (git-fixes)
- commit 26fa5ae
* Thu May 16 2024 denis.kirjanov@suse.com
- net/mlx5e: Do not produce metadata freelist entries in Tx port
  ts WQE xmit (git-fixes).
- commit 287b501
* Thu May 16 2024 denis.kirjanov@suse.com
- net/mlx5e: HTB, Fix inconsistencies with QoS SQs number
  (git-fixes).
- commit 0085432
* Thu May 16 2024 denis.kirjanov@suse.com
- net/mlx5e: Fix mlx5e_priv_init() cleanup flow (git-fixes).
- commit 01134b3
* Thu May 16 2024 denis.kirjanov@suse.com
- net/mlx5e: RSS, Block changing channels number when RXFH is
  configured (git-fixes).
- commit c93a7d5
* Thu May 16 2024 denis.kirjanov@suse.com
- net/mlx5: Correctly compare pkt reformat ids (git-fixes).
- commit 76a7159
* Thu May 16 2024 denis.kirjanov@suse.com
- net/mlx5: Properly link new fs rules into the tree (git-fixes).
- commit 7272c33
* Thu May 16 2024 denis.kirjanov@suse.com
- net/mlx5: offset comp irq index in name by one (git-fixes).
- commit 56809e4
* Thu May 16 2024 denis.kirjanov@suse.com
- net/mlx5: Register devlink first under devlink lock (git-fixes).
- commit 3162538
* Thu May 16 2024 denis.kirjanov@suse.com
- net/mlx5: E-switch, store eswitch pointer before registering
  devlink_param (git-fixes).
- commit d6f7fd4
* Thu May 16 2024 tiwai@suse.de
- ALSA: hda/realtek - fixed headset Mic not show (stable-fixes).
- ALSA: hda: hda_cs_dsp_ctl: Remove notification of driver write
  (stable-fixes).
- ALSA: Fix deadlocks with kctl removals at disconnection
  (stable-fixes).
- ALSA: hda: clarify Copyright information (stable-fixes).
- ALSA: hda/realtek: Add support for ASUS Zenbook 2024 HN7306W
  (stable-fixes).
- ALSA: hda/realtek: Fix internal speakers for Legion Y9000X
  2022 IAH7 (stable-fixes).
- ALSA: hda: Add Intel BMG PCI ID and HDMI codec vid
  (stable-fixes).
- ALSA: hda: cs35l41: Add support for ASUS ROG 2024 Laptops
  (stable-fixes).
- ALSA: hda: cs35l41: Ignore errors when configuring IRQs
  (stable-fixes).
- ALSA: hda/realtek: Add quirks for Lenovo 13X (stable-fixes).
- ALSA: hda: cs35l41: Support Lenovo 13X laptop without _DSD
  (stable-fixes).
- ALSA: hda: cs35l41: Remove redundant argument to
  cs35l41_request_firmware_file() (stable-fixes).
- ALSA: hda: cs35l41: Update DSP1RX5/6 Sources for DSP config
  (stable-fixes).
- ALSA: hda/realtek: Add quirks for HP Omen models using CS35L41
  (stable-fixes).
- ALSA: hda: cs35l41: Support HP Omen models without _DSD
  (stable-fixes).
- ALSA: hda: cs35l41: Set the max PCM Gain using tuning setting
  (stable-fixes).
- commit bd5e5fc
* Thu May 16 2024 tiwai@suse.de
- Add cherry-picked patch references to amdgpu patches
- commit fb4ef8e
* Thu May 16 2024 tiwai@suse.de
- ALSA: hda/realtek: Drop doubly quirk entry for 103c:8a2e
  (git-fixes).
- ASoC: tas2781: Fix a warning reported by robot kernel test
  (git-fixes).
- ASoC: tracing: Export SND_SOC_DAPM_DIR_OUT to its value
  (git-fixes).
- ASoC: Intel: avs: Test result of avs_get_module_entry()
  (git-fixes).
- ASoC: Intel: avs: Fix potential integer overflow (git-fixes).
- ASoC: Intel: avs: Fix ASRC module initialization (git-fixes).
- ASoC: SOF: Intel: mtl: Implement firmware boot state check
  (git-fixes).
- ASoC: SOF: Intel: lnl: Correct rom_status_reg (git-fixes).
- ASoC: SOF: Intel: mtl: Correct rom_status_reg (git-fixes).
- Revert "ASoC: SOF: Intel: hda-dai-ops: only allocate/release
  streams for first CPU DAI" (stable-fixes).
- Revert "ASoC: SOF: Intel: hda-dai-ops: reset device count for
  SoundWire DAIs" (stable-fixes).
- ASoC: kirkwood: Fix potential NULL dereference (git-fixes).
- ASoC: Intel: avs: ssm4567: Do not ignore route checks
  (git-fixes).
- ASoC: Intel: Disable route checks for Skylake boards
  (git-fixes).
- ASoC: mediatek: Assign dummy when codec not specified for a
  DAI link (git-fixes).
- ASoC: mediatek: mt8192: fix register configuration for tdm
  (git-fixes).
- ALSA: hda: cs35l56: Fix lifetime of cs_dsp instance (git-fixes).
- ALSA: hda/cs_dsp_ctl: Use private_free for control cleanup
  (git-fixes).
- ALSA: hda: cs35l41: Remove Speaker ID for Lenovo Legion slim
  7 16ARHA7 (git-fixes).
- fbdev: savage: Handle err return when savagefb_check_var failed
  (git-fixes).
- fbdev: sh7760fb: allow modular build (git-fixes).
- fbdev: sisfb: hide unused variables (git-fixes).
- fbdev: shmobile: fix snprintf truncation (git-fixes).
- drm: zynqmp_dpsub: Always register bridge (git-fixes).
- Revert "drm/bridge: ti-sn65dsi83: Fix enable error path"
  (git-fixes).
- drm/fbdev-generic: Do not set physical framebuffer address
  (git-fixes).
- drm/msm/a6xx: Avoid a nullptr dereference when speedbin setting
  fails (git-fixes).
- drm/msm/adreno: fix CP cycles stat retrieval on a7xx
  (git-fixes).
- drm/msm/dpu: Add callback function pointer check before its call
  (git-fixes).
- drm/msm/dpu: Allow configuring multiple active DSC blocks
  (git-fixes).
- drm/msm/dpu: Always flush the slave INTF on the CTL (git-fixes).
- drm/msm/dsi: Print dual-DSI-adjusted pclk instead of original
  mode pclk (git-fixes).
- drm/msm/dp: Avoid a long timeout for AUX transfer if nothing
  connected (git-fixes).
- drm/msm/dp: allow voltage swing / pre emphasis of 3 (git-fixes).
- drm/mediatek: dp: Fix mtk_dp_aux_transfer return value
  (git-fixes).
- drm/mediatek: Init `ddp_comp` with devm_kcalloc() (git-fixes).
- drm/mediatek: Add 0 size check to mtk_drm_gem_obj (git-fixes).
- drm/bridge: tc358775: fix support for jeida-18 and jeida-24
  (git-fixes).
- drm/meson: gate px_clk when setting rate (git-fixes).
- drm/rockchip: vop2: Do not divide height twice for YUV
  (git-fixes).
- drm/panel: simple: Add missing Innolux G121X1-L03 format,
  flags, connector (git-fixes).
- drm/bridge: anx7625: Update audio status while detecting
  (git-fixes).
- drm/panel: novatek-nt35950: Don't log an error when DSI host
  can't be found (git-fixes).
- drm/bridge: dpc3433: Don't log an error when DSI host can't
  be found (git-fixes).
- drm/bridge: tc358775: Don't log an error when DSI host can't
  be found (git-fixes).
- drm/bridge: lt9611uxc: Don't log an error when DSI host can't
  be found (git-fixes).
- drm/bridge: lt9611: Don't log an error when DSI host can't be
  found (git-fixes).
- drm/bridge: lt8912b: Don't log an error when DSI host can't
  be found (git-fixes).
- drm/bridge: icn6211: Don't log an error when DSI host can't
  be found (git-fixes).
- drm/bridge: anx7625: Don't log an error when DSI host can't
  be found (git-fixes).
- drm: vc4: Fix possible null pointer dereference (git-fixes).
- drm/arm/malidp: fix a possible null pointer dereference
  (git-fixes).
- drm/amd/display: Remove redundant condition in
  dcn35_calc_blocks_to_gate() (git-fixes).
- drm/amd/display: Fix potential index out of bounds in color
  transformation function (git-fixes).
- drm: bridge: cdns-mhdp8546: Fix possible null pointer
  dereference (git-fixes).
- drm/meson: vclk: fix calculation of 59.94 fractional rates
  (git-fixes).
- drm/panel: ltk050h3146w: drop duplicate commands from
  LTK050H3148W init (git-fixes).
- drm/panel: ltk050h3146w: add MIPI_DSI_MODE_VIDEO to LTK050H3148W
  flags (git-fixes).
- drm/lcdif: Do not disable clocks on already suspended hardware
  (git-fixes).
- drm/omapdrm: Fix console by implementing fb_dirty (git-fixes).
- drm/nouveau/dp: Fix incorrect return code in r535_dp_aux_xfer()
  (git-fixes).
- drm/ci: update device type for volteer devices (git-fixes).
- drm/bridge: Fix improper bridge init order with
  pre_enable_prev_first (git-fixes).
- commit e7d2777
* Thu May 16 2024 tiwai@suse.de
- Revert "selinux: introduce an initial SID for early boot processes" (bsc#1208593)
  It caused a regression on ALP-current branch, kernel-obs-qa build failed.
- commit 35271c3
* Wed May 15 2024 msuchanek@suse.de
- powerpc/eeh: Permanently disable the removed device (bsc#1223991
  ltc#205740).
- commit b9c2f2f
* Wed May 15 2024 dsterba@suse.com
- fat: fix uninitialized field in nostale filehandles (git-fixes)
- commit f1e1fd7
* Wed May 15 2024 denis.kirjanov@suse.com
- net: ks8851: Queue RX packets in IRQ handler instead of
  disabling BHs (git-fixes).
- commit cc9313f
* Wed May 15 2024 tiwai@suse.de
- Move upstreamed ACPI patch into sorted section
- commit 6c48aae
* Wed May 15 2024 dsterba@suse.com
- fs: relax mount_setattr() permission checks (git-fixes)
- commit 3b377cf
* Wed May 15 2024 iivanov@suse.de
- bpf, arm64: Fix incorrect runtime stats (git-fixes)
- commit c30a258
* Wed May 15 2024 dsterba@suse.com
- fast_dput(): handle underflows gracefully (git-fixes)
- commit 7a48807
* Wed May 15 2024 dsterba@suse.com
- ecryptfs: Reject casefold directory inodes (git-fixes)
- commit bc23622
* Wed May 15 2024 dsterba@suse.com
- fsverity: skip PKCS#7 parser when keyring is empty (git-fixes)
- commit 97f203b
* Wed May 15 2024 mkoutny@suse.com
- cifs: fix underflow in parse_server_interfaces() (CVE-2024-26828 bsc#1223084).
- commit 40aba68
* Wed May 15 2024 denis.kirjanov@suse.com
- octeontx2-af: Fix NIX SQ mode and BP config (git-fixes).
- commit 6fa6e4e
* Wed May 15 2024 denis.kirjanov@suse.com
- net: ks8851: Handle softirqs at the end of IRQ thread to fix
  hang (git-fixes).
- commit 871b504
* Wed May 15 2024 denis.kirjanov@suse.com
- net: ks8851: Inline ks8851_rx_skb() (git-fixes).
- commit 0fafe3f
* Wed May 15 2024 denis.kirjanov@suse.com
- bnxt_en: Reset PTP tx_avail after possible firmware reset
  (git-fixes).
- commit 9421aa8
* Wed May 15 2024 denis.kirjanov@suse.com
- bnxt_en: Fix error recovery for RoCE ulp client (git-fixes).
- commit a747a74
* Wed May 15 2024 denis.kirjanov@suse.com
- bnxt_en: Fix possible memory leak in bnxt_rdma_aux_device_init()
  (git-fixes).
- commit 6a62a82
* Wed May 15 2024 denis.kirjanov@suse.com
- geneve: fix header validation in geneve[6]_xmit_skb (git-fixes).
- commit d4d699c
* Wed May 15 2024 denis.kirjanov@suse.com
- octeontx2-pf: Fix transmit scheduler resource leak (git-fixes).
- commit 9beffaf
* Wed May 15 2024 denis.kirjanov@suse.com
- net/mlx5: SF, Stop waiting for FW as teardown was called
  (git-fixes).
- commit 2583247
* Wed May 15 2024 denis.kirjanov@suse.com
- mlxsw: Use refcount_t for reference counting (git-fixes).
- commit 5be65d6
* Wed May 15 2024 denis.kirjanov@suse.com
- net: ena: Use tx_ring instead of xdp_ring for XDP channel TX
  (git-fixes).
- commit d4b3628
* Wed May 15 2024 denis.kirjanov@suse.com
- net: ena: Pass ena_adapter instead of net_device to
  ena_xmit_common() (git-fixes).
- commit c080c13
* Wed May 15 2024 denis.kirjanov@suse.com
- net: ena: Move XDP code to its new files (git-fixes).
- commit 7cd4a35
* Wed May 15 2024 denis.kirjanov@suse.com
- net: openvswitch: Fix Use-After-Free in ovs_ct_exit (bsc#1224098
  CVE-2024-27395).
- commit a237c4c
* Wed May 15 2024 ddiss@suse.de
- selinux: introduce an initial SID for early boot processes
  (bsc#1208593).
- commit a82f05c
* Wed May 15 2024 mkubecek@suse.cz
- mctp: perform route lookups under a RCU read-side lock
  (CVE-2023-52483 bsc#1220738).
- commit 659b74f
* Wed May 15 2024 tbogendoerfer@suse.de
- net: gtp: Fix Use-After-Free in gtp_dellink (bsc#1224096
  CVE-2024-27396).
- commit 7f59223
* Wed May 15 2024 tiwai@suse.de
- Move upstreamed patches into sorted section
- commit 25085d6
* Wed May 15 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: fix check in iwl_mvm_sta_fw_id_mask
  (git-fixes).
- commit 61c5310
* Wed May 15 2024 tiwai@suse.de
- ax25: Fix reference count leak issue of net_device (git-fixes).
- ax25: Fix reference count leak issues of ax25_dev (git-fixes).
- net: usb: ax88179_178a: fix link status when link is set to
  down/up (git-fixes).
- selftests: net: move amt to socat for better compatibility
  (git-fixes).
- Bluetooth: qca: Fix error code in qca_read_fw_build_info()
  (git-fixes).
- net: usb: smsc95xx: stop lying about skb->truesize (git-fixes).
- wifi: mwl8k: initialize cmd->addr[] properly (git-fixes).
- wifi: rtw89: pci: correct TX resource checking for PCI DMA
  channel of firmware command (git-fixes).
- wifi: ar5523: enable proper endpoint verification (git-fixes).
- wifi: carl9170: add a proper sanity check for endpoints
  (git-fixes).
- wifi: ath10k: populate board data for WCN3990 (git-fixes).
- wifi: ath10k: Fix an error code problem in
  ath10k_dbg_sta_write_peer_debug_trigger() (git-fixes).
- wifi: ath12k: fix out-of-bound access of qmi_invoke_handler()
  (git-fixes).
- wifi: carl9170: re-fix fortified-memset warning (git-fixes).
- wifi: mt76: mt7603: add wpdma tx eof flag for PSE client reset
  (git-fixes).
- wifi: mt76: mt7603: fix tx queue of loopback packets
  (git-fixes).
- net: usb: sr9700: stop lying about skb->truesize (git-fixes).
- usb: aqc111: stop lying about skb->truesize (git-fixes).
- wifi: iwlwifi: mvm: init vif works only once (git-fixes).
- net: nfc: remove inappropriate attrs check (stable-fixes).
- wifi: ath11k: don't force enable power save on non-running vdevs
  (git-fixes).
- wifi: ath10k: poll service ready message before failing
  (git-fixes).
- wifi: iwlwifi: reconfigure TLC during HW restart (git-fixes).
- wifi: iwlwifi: mvm: select STA mask only for active links
  (git-fixes).
- wifi: iwlwifi: mvm: fix active link counting during recovery
  (git-fixes).
- wifi: iwlwifi: mvm: allocate STA links only for active links
  (git-fixes).
- wifi: ieee80211: fix ieee80211_mle_basic_sta_prof_size_ok()
  (git-fixes).
- wifi: mt76: mt7915: workaround too long expansion sparse
  warnings (git-fixes).
- wifi: brcmfmac: pcie: handle randbuf allocation failure
  (git-fixes).
- bitops: add missing prototype check (git-fixes).
- ata: pata_legacy: make legacy_exit() work again (git-fixes).
- efi: libstub: only free priv.runtime_map when allocated
  (git-fixes).
- HID: amd_sfh: Handle "no sensors" in PM operations (git-fixes).
- HID: intel-ish-hid: ipc: Add check for pci_alloc_irq_vectors
  (git-fixes).
- hwmon: (lm70) fix links in doc and comments (git-fixes).
- spi: xilinx: Fix kernel documentation in the xilinx_spi.h
  (git-fixes).
- ACPI: LPSS: Advertise number of chip selects via property
  (git-fixes).
- ACPI: bus: Indicate support for IRQ ResourceSource thru _OSC
  (git-fixes).
- ACPI: Fix Generic Initiator Affinity _OSC bit (git-fixes).
- ACPI: bus: Indicate support for the Generic Event Device thru
  _OSC (git-fixes).
- ACPI: bus: Indicate support for _TFP thru _OSC (git-fixes).
- ACPI: disable -Wstringop-truncation (git-fixes).
- cpufreq: brcmstb-avs-cpufreq: ISO C90 forbids mixed declarations
  (git-fixes).
- cppc_cpufreq: Fix possible null pointer dereference (git-fixes).
- cpufreq: exit() callback is optional (git-fixes).
- thermal/drivers/tsens: Fix null pointer dereference (git-fixes).
- thermal/drivers/qcom/lmh: Check for SCM availability at probe
  (git-fixes).
- selftests: default to host arch for LLVM builds (git-fixes).
- selftests/resctrl: fix clang build failure: use LOCAL_HDRS
  (git-fixes).
- selftests/binderfs: use the Makefile's rules, not Make's
  implicit rules (git-fixes).
- irqchip/loongson-pch-msi: Fix off-by-one on allocation error
  path (git-fixes).
- irqchip/alpine-msi: Fix off-by-one in allocation error path
  (git-fixes).
- commit ea6926d
* Tue May 14 2024 lduncan@suse.com
- block: Fix iterating over an empty bio with
  bio_for_each_folio_all (bsc#1221635 CVE-2024-26632).
- commit a419383
* Tue May 14 2024 dsterba@suse.com
- iomap: clear the per-folio dirty bits on all writeback failures (git-fixes)
- commit cfedccd
* Tue May 14 2024 nik.borisov@suse.com
- x86/retpoline: Add NOENDBR annotation to the SRSO dummy return thunk (git-fixes).
- commit 431e388
* Tue May 14 2024 nik.borisov@suse.com
- kabi/severities: Remove mitigation-related symbols
  Those are used by the core kernel to implement CPU vulnerabilities
  mitigation and are not expected to be consumed by 3rd party users.
- commit 8d79889
* Tue May 14 2024 oneukum@suse.com
- Update
  patches.suse/Bluetooth-hci_sync-Don-t-double-print-name-in-add-re.patch
  (bsc#1216358).
  Added bugzilla reference
- commit 3985fb5
* Tue May 14 2024 oneukum@suse.com
- Update patches.suse/usb-ulpi-Fix-debugfs-directory-leak.patch
  (bsc#1223847 CVE-2024-26919).
  Added bugzilla ID and CVE
- commit 44b677b
* Tue May 14 2024 ailiop@suse.com
- xfs: fix perag leak when growfs fails (git-fixes).
- commit 111377b
* Tue May 14 2024 ailiop@suse.com
- xfs: add lock protection when remove perag from radix tree
  (git-fixes).
- commit fdadeb0
* Tue May 14 2024 ailiop@suse.com
- xfs: force all buffers to be written during btree bulk load
  (git-fixes).
- commit bcc67e9
* Tue May 14 2024 ailiop@suse.com
- xfs: recompute growfsrtfree transaction reservation while
  growing rt volume (git-fixes).
- commit 0ef8d73
* Tue May 14 2024 ailiop@suse.com
- xfs: make xchk_iget safer in the presence of corrupt inode
  btrees (git-fixes).
- commit 3312038
* Tue May 14 2024 ailiop@suse.com
- xfs: transfer recovered intent item ownership in ->iop_recover
  (git-fixes).
- commit 9cdf2ef
* Tue May 14 2024 ailiop@suse.com
- xfs: pass the xfs_defer_pending object to iop_recover
  (git-fixes).
- commit c4d4eda
* Tue May 14 2024 ailiop@suse.com
- xfs: use xfs_defer_pending objects to recover intent items
  (git-fixes).
- commit 4e8f44d
* Tue May 14 2024 ailiop@suse.com
- jffs2: prevent xattr node from overflowing the eraseblock
  (git-fixes).
- commit bb15e9c
* Tue May 14 2024 nik.borisov@suse.com
- x86/cpu: Add model number for Intel Arrow Lake mobile processor (git-fixes).
- commit 7c55ce6
* Tue May 14 2024 nik.borisov@suse.com
- x86/bugs: Fix the SRSO mitigation on Zen3/4 (git-fixes).
- commit b73f38c
* Tue May 14 2024 nik.borisov@suse.com
- x86/calldepth: Rename __x86_return_skl() to call_depth_return_thunk() (git-fixes).
- commit 5ad2192
* Tue May 14 2024 nik.borisov@suse.com
- x86/nospec: Refactor UNTRAIN_RET[_*] (git-fixes).
- commit 653bafb
* Tue May 14 2024 nik.borisov@suse.com
- x86/rethunk: Use SYM_CODE_START[_LOCAL]_NOALIGN macros (git-fixes).
- commit 3e5de92
* Tue May 14 2024 nik.borisov@suse.com
- x86/srso: Disentangle rethunk-dependent options (git-fixes).
- Refresh
  patches.suse/x86-bugs-Cache-the-value-of-MSR_IA32_ARCH_CAPABILITIES.patch.
- commit 4761d61
* Tue May 14 2024 nik.borisov@suse.com
- x86/bugs: Remove default case for fully switched enums (git-fixes).
- commit caa1a64
* Tue May 14 2024 nik.borisov@suse.com
- x86/srso: Remove 'pred_cmd' label (git-fixes).
- commit d2d0e6a
* Tue May 14 2024 nik.borisov@suse.com
- x86/srso: Unexport untraining functions (git-fixes).
- commit f855258
* Tue May 14 2024 nik.borisov@suse.com
- x86/srso: Improve i-cache locality for alias mitigation (git-fixes).
- commit 8ffea3d
* Tue May 14 2024 nik.borisov@suse.com
- x86/srso: Fix unret validation dependencies (git-fixes).
- commit 95452af
* Tue May 14 2024 nik.borisov@suse.com
- x86/srso: Print actual mitigation if requested mitigation isn't  possible (git-fixes).
- Refresh
  patches.suse/x86-srso-fix-vulnerability-reporting-for-missing-microcode.patch.
- commit 3afb908
* Tue May 14 2024 nik.borisov@suse.com
- x86/coco: Require seeding RNG with RDRAND on CoCo systems (git-fixes).
- commit 9588be6
* Tue May 14 2024 nik.borisov@suse.com
- x86/nmi: Fix the inverse "in NMI handler" check (git-fixes).
- commit 3b9c9ee
* Tue May 14 2024 nik.borisov@suse.com
- x86/purgatory: Switch to the position-independent small code model (git-fixes).
- commit 57ab7d5
* Tue May 14 2024 nik.borisov@suse.com
- x86/CPU/AMD: Add models 0x10-0x1f to the Zen5 range (git-fixes).
- commit f043bca
* Tue May 14 2024 tiwai@suse.de
- Move upstreamed patches into sorted section
- commit 96e6c4c
* Tue May 14 2024 tiwai@suse.de
- soc: qcom: pmic_glink: Make client-lock non-sleeping
  (git-fixes).
- commit 410217d
* Tue May 14 2024 tiwai@suse.de
- soc: qcom: rpmh-rsc: Enhance check for VRM in-flight request
  (git-fixes).
- commit 2c41b82
* Tue May 14 2024 tiwai@suse.de
- crypto: qat - specify firmware files for 402xx (git-fixes).
- crypto: qat - improve error logging to be consistent across
  features (git-fixes).
- crypto: x86/sha512-avx2 - add missing vzeroupper (git-fixes).
- crypto: x86/sha256-avx2 - add missing vzeroupper (git-fixes).
- crypto: x86/nh-avx2 - add missing vzeroupper (git-fixes).
- crypto: ccp - drop platform ifdef checks (git-fixes).
- crypto: bcm - Fix pointer arithmetic (git-fixes).
- crypto: ecdsa - Fix module auto-load on add-key (git-fixes).
- kunit/fortify: Fix mismatched kvalloc()/vfree() usage
  (git-fixes).
- nilfs2: fix out-of-range warning (git-fixes).
- admin-guide/hw-vuln/core-scheduling: fix return type of
  PR_SCHED_CORE_GET (git-fixes).
- soc: mediatek: cmdq: Fix typo of CMDQ_JUMP_RELATIVE (git-fixes).
- soc: qcom: pmic_glink: notify clients about the current state
  (git-fixes).
- soc: qcom: pmic_glink: don't traverse clients list without a
  lock (git-fixes).
- commit 7da1cbc
* Mon May 13 2024 dsterba@suse.com
- btrfs: add missing mutex_unlock in btrfs_relocate_sys_chunks() (git-fixes)
- commit 8bc326a
* Mon May 13 2024 dsterba@suse.com
- btrfs: fix wrong block_start calculation for btrfs_drop_extent_map_range() (git-fixes)
  Dropped hunk in selftests (test_case_7), 92e1229b204d6.
- commit 8dcf7c1
* Mon May 13 2024 dsterba@suse.com
- btrfs: fix information leak in btrfs_ioctl_logical_to_ino() (git-fixes)
- commit 622d549
* Mon May 13 2024 dsterba@suse.com
- btrfs: handle chunk tree lookup error in btrfs_relocate_sys_chunks() (git-fixes)
- commit 84f4309
* Mon May 13 2024 dsterba@suse.com
- btrfs: reject encoded write if inode has nodatasum flag set (git-fixes)
- commit bbc649d
* Mon May 13 2024 dsterba@suse.com
- btrfs: send: return EOPNOTSUPP on unknown flags (git-fixes)
- commit 8ef1c53
* Mon May 13 2024 dsterba@suse.com
- btrfs: fix lockdep splat and potential deadlock after failure running delayed items (git-fixes)
- commit a6f28a6
* Mon May 13 2024 dsterba@suse.com
- btrfs: release path before inode lookup during the ino lookup ioctl (git-fixes)
- commit 4b7ba54
* Mon May 13 2024 tiwai@suse.de
- firewire: nosy: ensure user_length is taken into account when
  fetching packet contents (CVE-2024-27401 bsc#1224181).
- commit 5441039
* Mon May 13 2024 oneukum@suse.com
- Update
  patches.suse/usb-aqc111-check-packet-for-fixup-for-true-limit.patch
  (bsc#1217169 CVE-2023-52655).
  Added bugzilla and CVE
- commit 20db8f9
* Mon May 13 2024 dsterba@suse.com
- btrfs: fix off-by-one chunk length calculation at contains_pending_extent() (git-fixes)
- commit 9ec1333
* Mon May 13 2024 nstange@suse.de
- crypto: rsa - add a check for allocation failure (bsc#1222775).
- commit 8c6c396
* Mon May 13 2024 tiwai@suse.de
- kABI workaround for of driver changes (git-fixes).
- commit ef08885
* Mon May 13 2024 colyli@suse.de
- aoe: avoid potential deadlock at set_capacity (CVE-2024-26775,
  bsc#1222627).
- commit fd6e05d
* Mon May 13 2024 nstange@suse.de
- crypto: testmgr - remove unused xts4096 and xts512 algorithms
  from testmgr.c (bsc#1222769).
- commit 0de6756
* Mon May 13 2024 nstange@suse.de
- crypto: rsa - allow only odd e and restrict value in FIPS mode
  (bsc#1222775).
- commit c5ca0e4
* Mon May 13 2024 tiwai@suse.de
- of: module: prevent NULL pointer dereference in vsnprintf()
  (stable-fixes).
- of: dynamic: Synchronize of_changeset_destroy() with the
  devlink removals (git-fixes).
- of: property: fw_devlink: Fix stupid bug in remote-endpoint
  parsing (git-fixes).
- of: property: Add in-ports/out-ports support to
  of_graph_get_port_parent() (stable-fixes).
- of: property: Improve finding the supplier of a remote-endpoint
  property (git-fixes).
- of: property: Improve finding the consumer of a remote-endpoint
  property (git-fixes).
- of: unittest: Fix compile in the non-dynamic case (git-fixes).
- of: property: fix typo in io-channels (git-fixes).
- commit 7743bc7
* Mon May 13 2024 nstange@suse.de
- crypto: ecc - update ecc_gen_privkey for FIPS 186-5
  (bsc#1222782).
- commit bcc0381
* Mon May 13 2024 tiwai@suse.de
- selftests/pidfd: Fix config for pidfd_setns_test (git-fixes).
- EDAC/synopsys: Fix ECC status and IRQ control race condition
  (git-fixes).
- commit 85ce9d3
* Mon May 13 2024 neilb@suse.de
- nfs: fix UAF in direct writes (bsc#1223653 CVE-2024-26958).
- commit 9b53f23
* Sat May 11 2024 tiwai@suse.de
- drm/connector: Add \n to message about demoting connector
  force-probes (git-fixes).
- drm/meson: dw-hdmi: add bandgap setting for g12 (git-fixes).
- drm/meson: dw-hdmi: power up phy on device init (git-fixes).
- drm/amdgpu: Fix comparison in amdgpu_res_cpu_visible
  (git-fixes).
- drm/amdkfd: don't allow mapping the MMIO HDP page with large
  pages (git-fixes).
- dm/amd/pm: Fix problems with reboot/shutdown for some SMU
  13.0.4/13.0.11 users (git-fixes).
- drm/i915/bios: Fix parsing backlight BDB data (git-fixes).
- drm/i915/gt: Automate CCS Mode setting during engine resets
  (git-fixes).
- maple_tree: fix mas_empty_area_rev() null pointer dereference
  (git-fixes).
- spi: microchip-core-qspi: fix setting spi bus clock rate
  (git-fixes).
- regulator: core: fix debugfs creation regression (git-fixes).
- commit 3a3ad92
* Fri May 10 2024 jlee@suse.com
- netfilter: nf_tables: mark set as dead when unbinding anonymous
  set with timeout (bsc#1221829 CVE-2024-26643).
- commit c841ee9
* Fri May 10 2024 jlee@suse.com
- block/rnbd-srv: Check for unlikely string overflow (bsc#1221615
  CVE-2023-52618).
- commit 3cf7eb9
* Fri May 10 2024 dwagner@suse.de
- block: bio-integrity: fix kcalloc() arguments order (bsc#1217384
  CVE-2023-6238).
- commit 37816df
* Fri May 10 2024 tiwai@suse.de
- hwmon: (pmbus/ucd9000) Increase delay from 250 to 500us
  (git-fixes).
- hwmon: (corsair-cpro) Protect ccp->wait_input_report with a
  spinlock (git-fixes).
- hwmon: (corsair-cpro) Use complete_all() instead of complete()
  in ccp_raw_event() (git-fixes).
- hwmon: (corsair-cpro) Use a separate buffer for sending commands
  (git-fixes).
- nfc: nci: Fix kcov check in nci_rx_work() (git-fixes).
- Bluetooth: l2cap: fix null-ptr-deref in l2cap_chan_timeout
  (git-fixes).
- Bluetooth: HCI: Fix potential null-ptr-deref (git-fixes).
- Bluetooth: qca: fix info leak when fetching fw build id
  (git-fixes).
- Bluetooth: qca: fix NVM configuration parsing (git-fixes).
- Bluetooth: qca: add missing firmware sanity checks (git-fixes).
- Bluetooth: msft: fix slab-use-after-free in msft_do_close()
  (git-fixes).
- Bluetooth: Fix use-after-free bugs caused by sco_sock_timeout
  (git-fixes).
- ARM: 9381/1: kasan: clear stale stack poison (git-fixes).
- commit aa6a883
* Fri May 10 2024 krisman@suse.de
- Update
  patches.suse/xen-netfront-Add-missing-skb_mark_for_recycle.patch
  (git-fixes CVE-2024-27393 bsc#1224076).
- commit 3dacd9a
* Thu May  9 2024 jslaby@suse.cz
- kprobes/x86: Use copy_from_kernel_nofault() to read from unsafe
  address (CVE-2024-26946 bsc#1223669).
- commit c3ef9f9
* Thu May  9 2024 tiwai@suse.de
- Move upstreamed powerpc patches into sorted section
- commit de7fc3a
* Wed May  8 2024 dwagner@suse.de
- io_uring: kabi cookie remove (bsc#1217384).
- commit 6174cfd
* Wed May  8 2024 oneukum@suse.com
- Update
  patches.suse/USB-core-Fix-deadlock-in-port-disable-sysfs-attribut.patch
  (bsc#1223670 CVE-2024-26933).
  Added CVE and bugzilla ID
- commit 2932a82
* Wed May  8 2024 oneukum@suse.com
- crypto: iaa - Fix nr_cpus < nr_iaa case (bsc#1223732
  CVE-2024-26945).
- commit d4480a0
* Wed May  8 2024 dwagner@suse.de
- supported.conf: support tcp_dctcp module (jsc#PED-8111)
- commit 84b1f91
* Wed May  8 2024 nstange@suse.de
- Update
  patches.suse/crypto-lib-mpi-Fix-unexpected-pointer-access-in-mpi_.patch
  (git-fixes CVE-2023-52616 bsc#1221612).
- commit 0f801e9
* Wed May  8 2024 tzimmermann@suse.com
- Update "drm/vmwgfx: Fix possible null pointer derefence with invalid contexts" (CVE-2024-26979 bsc#1223628)
- commit 562486d
* Tue May  7 2024 fdmanana@suse.com
- btrfs: fix race when detecting delalloc ranges during fiemap
  (bsc#1223285).
- commit b4449a9
* Tue May  7 2024 fdmanana@suse.com
- btrfs: ensure fiemap doesn't race with writes when
  FIEMAP_FLAG_SYNC is given (bsc#1223285).
- commit e1d5456
* Tue May  7 2024 fdmanana@suse.com
- btrfs: fix race between ordered extent completion and fiemap
  (bsc#1223285).
- commit b2ade77
* Tue May  7 2024 fdmanana@suse.com
- btrfs: fix deadlock with fiemap and extent locking
  (bsc#1223285).
- commit 032df64
* Tue May  7 2024 fdmanana@suse.com
- btrfs: send: don't issue unnecessary zero writes for trailing
  hole (bsc#1222459).
- commit 79ef069
* Tue May  7 2024 vkarasulli@suse.de
- inet: read sk->sk_family once in inet_recv_error() (bsc#1222385
  CVE-2024-26679).
- commit cb5e75a
* Tue May  7 2024 tiwai@suse.de
- Move upstreamed HD-audio patch into sorted section
- commit d615f15
* Tue May  7 2024 tiwai@suse.de
- ACPI: video: Add backlight=native quirk for Lenovo Slim 7 16ARH7
  (bsc#1217750).
- commit 9e75dfd
* Tue May  7 2024 dsterba@suse.com
- btrfs: dev-replace: properly validate device names (CVE-2024-26791 bsc#1222793)
- commit 0244362
* Tue May  7 2024 dsterba@suse.com
- fs/ntfs3: Add NULL ptr dereference checking at the end of attr_allocate_frame() (CVE-2023-52641 bsc#1222303)
- commit 3195e8d
* Tue May  7 2024 mkubecek@suse.cz
- fix patch references (CVE-2024-26739 bsc#1222559):
  - patches.suse/net-sched-act_mirred-Create-function-tcf_mirred_to_d.patch
  - patches.suse/net-sched-act_mirred-don-t-override-retval-if-we-alr.patch
- commit af4b677
* Tue May  7 2024 oneukum@suse.com
- usb: dwc3: core: Prevent phy suspend during init (Git-fixes).
- commit 0feb823
* Tue May  7 2024 vkarasulli@suse.de
- netfilter: nft_ct: fix l3num expectations with inet pseudo
  family (git-fixes).
- commit e0fbf15
* Tue May  7 2024 pjakobsson@suse.de
- drm/i915/vma: Fix UAF on destroy against retire race (CVE-2024-26939 bsc#1223679).
- commit 0c69759
* Tue May  7 2024 tiwai@suse.de
- Reapply "drm/qxl: simplify qxl_fence_wait" (stable-fixes).
- commit 2bd2798
* Tue May  7 2024 mkubecek@suse.cz
- rds: tcp: Fix use-after-free of net in reqsk_timer_handler()
  (CVE-2024-26865 bsc#1223062).
- commit 4df5c35
* Mon May  6 2024 mkubecek@suse.cz
- packet: annotate data-races around ignore_outgoing
  (CVE-2024-26862 bsc#1223111).
- commit 50ec7e9
* Mon May  6 2024 mkubecek@suse.cz
- Update
  patches.suse/sctp-fix-potential-deadlock-on-net-sctp.addr_wq.patch
  references (add CVE-2024-0639 bsc#1218917).
- commit 61e4bcd
* Mon May  6 2024 dsterba@suse.com
- fs/ntfs3: Fix NULL pointer dereference on error in attr_allocate_frame() (CVE-2023-52641 bsc#1222303)
- commit 45e1211
* Mon May  6 2024 vkarasulli@suse.de
- netfilter: nft_ct: sanitize layer 3 and 4 protocol number in
  custom expectations (bsc#1222368 CVE-2024-26673).
- commit bffaac0
* Mon May  6 2024 dsterba@suse.com
- fs: sysfs: Fix reference leak in sysfs_break_active_protection() (CVE-2024-26993 bsc#1223693)
- commit b75cd2c
* Mon May  6 2024 dsterba@suse.com
- btrfs: don't drop extent_map for free space inode on write error (CVE-2024-26726 bsc#1222532)
- commit 60707c9
* Mon May  6 2024 petr.pavlu@suse.com
- ring-buffer: Only update pages_touched when a new page is
  touched (git-fixes).
- commit f2292de
* Mon May  6 2024 petr.pavlu@suse.com
- kprobes: Fix possible use-after-free issue on kprobe
  registration (git-fixes).
- commit 3121e4a
* Mon May  6 2024 vkarasulli@suse.de
- Update
  patches.suse/0001-s390-cio-fix-race-condition-during-online-processing.patch
  (bsc#1219485 bsc#1219451 git-fixes CVE-2024-27009 bsc#1223699).
- Update
  patches.suse/Bluetooth-btnxpuart-Fix-btnxpuart_close.patch
  (git-fixes CVE-2024-26959 bsc#1223667).
- Update
  patches.suse/USB-usb-storage-Prevent-divide-by-0-error-in-isd200_.patch
  (git-fixes CVE-2024-27059 bsc#1223738).
- Update
  patches.suse/backlight-hx8357-Fix-potential-NULL-pointer-derefere.patch
  (git-fixes CVE-2024-27071 bsc#1223734).
- Update patches.suse/clk-Fix-clk_core_get-NULL-dereference.patch
  (git-fixes CVE-2024-27038 bsc#1223816).
- Update
  patches.suse/clk-hisilicon-hi3559a-Fix-an-erroneous-devm_kfree.patch
  (git-fixes CVE-2024-27039 bsc#1223821).
- Update
  patches.suse/clk-qcom-gcc-ipq6018-fix-terminating-of-frequency-ta.patch
  (git-fixes CVE-2024-26970 bsc#1223644).
- Update
  patches.suse/clk-qcom-gcc-ipq8074-fix-terminating-of-frequency-ta.patch
  (git-fixes CVE-2024-26969 bsc#1223645).
- Update
  patches.suse/clk-qcom-gcc-ipq9574-fix-terminating-of-frequency-ta.patch
  (git-fixes CVE-2024-26968 bsc#1223642).
- Update
  patches.suse/clk-qcom-mmcc-apq8084-fix-terminating-of-frequency-t.patch
  (git-fixes CVE-2024-26966 bsc#1223646).
- Update
  patches.suse/clk-qcom-mmcc-msm8974-fix-terminating-of-frequency-t.patch
  (git-fixes CVE-2024-26965 bsc#1223648).
- Update
  patches.suse/clk-zynq-Prevent-null-pointer-dereference-caused-by-.patch
  (git-fixes CVE-2024-27037 bsc#1223717).
- Update
  patches.suse/cpufreq-brcmstb-avs-cpufreq-add-check-for-cpufreq_cp.patch
  (git-fixes CVE-2024-27051 bsc#1223769).
- Update
  patches.suse/crypto-qat-resolve-race-condition-during-AER-recover.patch
  (git-fixes CVE-2024-26974 bsc#1223638).
- Update
  patches.suse/drm-amd-display-Add-replay-NULL-check-in-edp_set_rep.patch
  (git-fixes CVE-2024-27040 bsc#1223711).
- Update
  patches.suse/drm-amd-display-Fix-a-potential-buffer-overflow-in-d.patch
  (git-fixes CVE-2024-27045 bsc#1223826).
- Update
  patches.suse/drm-amd-display-Fix-potential-NULL-pointer-dereferen.patch
  (git-fixes CVE-2024-27044 bsc#1223723).
- Update
  patches.suse/drm-amd-display-fix-NULL-checks-for-adev-dm.dc-in-am.patch
  (git-fixes CVE-2024-27041 bsc#1223714).
- Update
  patches.suse/drm-amdgpu-Fix-potential-out-of-bounds-access-in-amd.patch
  (git-fixes CVE-2024-27042 bsc#1223823).
- Update
  patches.suse/drm-vmwgfx-Fix-possible-null-pointer-derefence-with-.patch
  (git-fixes CVE-2024-26979 bsc#1223628).
- Update
  patches.suse/md-Fix-missing-release-of-active_io-for-flush-8556.patch
  (jsc#PED-7542 CVE-2024-27023 bsc#1223776).
- Update
  patches.suse/media-dvb-frontends-avoid-stack-overflow-warnings-wi.patch
  (git-fixes CVE-2024-27075 bsc#1223842).
- Update patches.suse/media-edia-dvbdev-fix-a-use-after-free.patch
  (git-fixes CVE-2024-27043 bsc#1223824).
- Update
  patches.suse/media-go7007-fix-a-memleak-in-go7007_load_encoder.patch
  (git-fixes CVE-2024-27074 bsc#1223844).
- Update
  patches.suse/media-imx-csc-scaler-fix-v4l2_ctrl_handler-memory-le.patch
  (git-fixes CVE-2024-27076 bsc#1223779).
- Update
  patches.suse/media-ttpci-fix-two-memleaks-in-budget_av_attach.patch
  (git-fixes CVE-2024-27073 bsc#1223843).
- Update
  patches.suse/media-usbtv-Remove-useless-locks-in-usbtv_video_free.patch
  (git-fixes CVE-2024-27072 bsc#1223837).
- Update
  patches.suse/media-v4l2-mem2mem-fix-a-memleak-in-v4l2_m2m_registe.patch
  (git-fixes CVE-2024-27077 bsc#1223780).
- Update
  patches.suse/media-v4l2-tpg-fix-some-memleaks-in-tpg_alloc.patch
  (git-fixes CVE-2024-27078 bsc#1223781).
- Update
  patches.suse/net-phy-fix-phy_get_internal_delay-accessing-an-empt.patch
  (git-fixes CVE-2024-27047 bsc#1223828).
- Update
  patches.suse/nilfs2-fix-failure-to-detect-DAT-corruption-in-btree.patch
  (git-fixes CVE-2024-26956 bsc#1223663).
- Update
  patches.suse/nilfs2-prevent-kernel-bug-at-submit_bh_wbc.patch
  (git-fixes CVE-2024-26955 bsc#1223657).
- Update patches.suse/pci_iounmap-Fix-MMIO-mapping-leak.patch
  (git-fixes CVE-2024-26977 bsc#1223631).
- Update
  patches.suse/powercap-intel_rapl-Fix-a-NULL-pointer-dereference.patch
  (git-fixes CVE-2024-26975 bsc#1223632).
- Update
  patches.suse/s390-Once-the-discipline-is-associated-with-the-device-de.patch
  (bsc#1141539 git-fixes CVE-2024-27054 bsc#1223819).
- Update
  patches.suse/scsi-qla2xxx-Fix-command-flush-on-cable-pull.patch
  (bsc#1221816 CVE-2024-26931 bsc#1223627).
- Update patches.suse/scsi-qla2xxx-Fix-double-free-of-fcport.patch
  (bsc#1221816 CVE-2024-26929 bsc#1223715).
- Update
  patches.suse/scsi-qla2xxx-Fix-double-free-of-the-ha-vp_map-pointe.patch
  (bsc#1221816 CVE-2024-26930 bsc#1223626).
- Update
  patches.suse/thermal-drivers-mediatek-lvts_thermal-Fix-a-memory-l.patch
  (git-fixes CVE-2024-27068 bsc#1223808).
- Update
  patches.suse/thunderbolt-Fix-NULL-pointer-dereference-in-tb_port_.patch
  (git-fixes CVE-2024-27060 bsc#1223725).
- Update patches.suse/usb-ulpi-Fix-debugfs-directory-leak.patch
  (git-fixes CVE-2024-26919 bsc#1223847).
- Update
  patches.suse/wifi-brcm80211-handle-pmk_op-allocation-failure.patch
  (git-fixes CVE-2024-27048 bsc#1223760).
- Update
  patches.suse/wifi-rtl8xxxu-add-cancel_work_sync-for-c2hcmd_work.patch
  (git-fixes CVE-2024-27052 bsc#1223829).
- Update
  patches.suse/wifi-wilc1000-do-not-realloc-workqueue-everytime-an-.patch
  (git-fixes CVE-2024-27391 bsc#1223709).
- Update
  patches.suse/wifi-wilc1000-fix-RCU-usage-in-connect-path.patch
  (git-fixes CVE-2024-27053 bsc#1223737).
- commit 9296e40
* Mon May  6 2024 vkarasulli@suse.de
- Update
  patches.suse/drm-tegra-dsi-Add-missing-check-for-of_find_device_b.patch
  (git-fixes CVE-2023-52650 bsc#1223770).
- Update
  patches.suse/drm-vkms-Avoid-reading-beyond-LUT-array.patch
  (git-fixes CVE-2023-52649 bsc#1223768).
- Update
  patches.suse/drm-vmwgfx-Unmap-the-surface-before-resetting-it-on-.patch
  (git-fixes CVE-2023-52648 bsc#1223765).
- Update
  patches.suse/media-nxp-imx8-isi-Check-whether-crossbar-pad-is-non.patch
  (git-fixes CVE-2023-52647 bsc#1223764).
- commit f67398e
* Mon May  6 2024 vkarasulli@suse.de
- Update
  patches.suse/powerpc-pseries-Fix-potential-memleak-in-papr_get_at.patch
  (bsc#1215199 CVE-2022-48669 bsc#1223756).
- commit e9a7939
* Mon May  6 2024 petr.pavlu@suse.com
- ring-buffer: use READ_ONCE() to read cpu_buffer->commit_page
  in concurrent environment (git-fixes).
- commit 8f1aa4c
* Mon May  6 2024 jgross@suse.com
- Delete
  patches.suse/iommufd-iova_bitmap-Move-symbols-to-IOMMUFD-namespace.
  (bsc#1222654)
- commit dc5c22e
* Mon May  6 2024 lhenriques@suse.de
- fuse: don't unhash root (bsc#1223946).
- fuse: fix root lookup with nonzero generation (bsc#1223945).
- virtio: treat alloc_dax() -EOPNOTSUPP failure as non-fatal
  (bsc#1223944).
- commit 5171d01
* Mon May  6 2024 tbogendoerfer@suse.de
- tun: limit printing rate when illegal packet received by tun
  dev (bsc#1223745 CVE-2024-27013).
- net/mlx5e: Prevent deadlock while disabling aRFS (bsc#1223735
  CVE-2024-27014).
- commit d039d3b
* Mon May  6 2024 tzimmermann@suse.com
- drm/amd/display: Add a dc_state NULL check in dc_state_release (CVE-2024-26948 bsc#1223664)
- commit adac21d
* Mon May  6 2024 tiwai@suse.de
- slimbus: qcom-ngd-ctrl: Add timeout for wait operation
  (git-fixes).
- iio:imu: adis16475: Fix sync mode setting (git-fixes).
- iio: accel: mxc4005: Interrupt handling fixes (git-fixes).
- iio: pressure: Fixes BME280 SPI driver data (git-fixes).
- usb: typec: tcpm: Check for port partner validity before
  consuming it (git-fixes).
- usb: typec: tcpm: unregister existing source caps before
  re-registration (git-fixes).
- usb: typec: tcpm: clear pd_event queue in PORT_RESET
  (git-fixes).
- usb: ohci: Prevent missed ohci interrupts (git-fixes).
- usb: gadget: f_fs: Fix a race condition when processing setup
  packets (git-fixes).
- USB: core: Fix access violation during port device removal
  (git-fixes).
- usb: gadget: uvc: use correct buffer size when parsing configfs
  lists (git-fixes).
- usb: gadget: composite: fix OS descriptors w_value logic
  (git-fixes).
- usb: gadget: f_fs: Fix race between aio_cancel() and AIO
  request complete (git-fixes).
- clk: sunxi-ng: h6: Reparent CPUX during PLL CPUX rate change
  (git-fixes).
- commit 8d8f752
* Mon May  6 2024 tiwai@suse.de
- Move upstreamed USB fix into sorted section
- commit 21751fe
* Sat May  4 2024 tiwai@suse.de
- ASoC: da7219-aad: fix usage of device_get_named_child_node()
  (git-fixes).
- ASoC: rt715-sdca: volume step modification (git-fixes).
- ASoC: rt715: add vendor clear control register (git-fixes).
- ASoC: cs35l41: Update DSP1RX5/6 Sources for DSP config
  (git-fixes).
- ASoC: cs35l56: Fix unintended bus access while resetting amp
  (git-fixes).
- ASoC: rt722-sdca: add headset microphone vrefo setting
  (git-fixes).
- ASoC: rt722-sdca: modify channel number to support 4 channels
  (git-fixes).
- ASoC: rt5645: Fix the electric noise due to the CBJ contacts
  floating (git-fixes).
- ASoC: acp: Support microphone from device Acer 315-24p
  (git-fixes).
- ASoC: Intel: bytcr_rt5640: Apply Asus T100TA quirk to Asus
  T100TAM too (git-fixes).
- commit 59787a2
* Sat May  4 2024 tiwai@suse.de
- ALSA: hda/realtek: Fix build error without CONFIG_PM
  (stable-fixes).
- ALSA: hda: cs35l56: Exit cache-only after
  cs35l56_wait_for_firmware_boot() (stable-fixes).
- ALSA: hda/realtek - Set GPIO3 to default at S4 state for
  Thinkpad with ALC1318 (stable-fixes).
- ALSA: hda: intel-dsp-config: harden I2C/I2S codec detection
  (stable-fixes).
- ALSA: hda/realtek: Fix mute led of HP Laptop 15-da3001TU
  (stable-fixes).
- commit 11f233b
* Sat May  4 2024 tiwai@suse.de
- ASoC: meson: axg-tdm-interface: manage formatters in trigger
  (git-fixes).
- ASoC: meson: axg-card: make links nonatomic (git-fixes).
- ASoC: meson: cards: select SND_DYNAMIC_MINORS (git-fixes).
- ASoC: codecs: wsa881x: set clk_stop_mode1 flag (git-fixes).
- ASoC: ti: davinci-mcasp: Fix race condition during probe
  (git-fixes).
- ASoC: Intel: avs: Set name of control as in topology
  (git-fixes).
- regmap: Add regmap_read_bypassed() (git-fixes).
- ASoC: SOF: Intel: add default firmware library path for LNL
  (git-fixes).
- ASoC: tegra: Fix DSPK 16-bit playback (git-fixes).
- ALSA: hda: intel-sdw-acpi: fix usage of
  device_get_named_child_node() (git-fixes).
- drm/panel: ili9341: Use predefined error codes (git-fixes).
- drm/panel: ili9341: Respect deferred probe (git-fixes).
- drm/vmwgfx: Fix invalid reads in fence signaled events
  (git-fixes).
- drm/vmwgfx: Fix Legacy Display Unit (git-fixes).
- drm/amdgpu: fix doorbell regression (git-fixes).
- drm/amdgpu: once more fix the call oder in amdgpu_ttm_move()
  v2 (git-fixes).
- spi: fix null pointer dereference within spi_sync (git-fixes).
- spi: hisi-kunpeng: Delete the dump interface of data registers
  in debugfs (git-fixes).
- commit de68d11
* Fri May  3 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: ensure offloading TID queue exists
  (CVE-2024-27056 bsc#1223822).
- commit 8f83255
* Fri May  3 2024 tiwai@suse.de
- dpll: fix dpll_pin_on_pin_register() for multiple parent pins
  (CVE-2024-27027 bsc#1223787).
- commit ce9b326
* Fri May  3 2024 tiwai@suse.de
- dpll: fix dpll_xa_ref_*_del() for multiple registrations
  (CVE-2024-27027 bsc#1223787).
- commit f5ff522
* Fri May  3 2024 mfranc@suse.cz
- s390/qeth: Fix kernel panic after setting hsuid (git-fixes
  bsc#1223874).
- commit eae1390
* Fri May  3 2024 mfranc@suse.cz
- s390/mm: Fix storage key clearing for guest huge pages
  (git-fixes bsc#1223872).
- commit 329e03c
* Fri May  3 2024 mfranc@suse.cz
- s390/mm: Fix clearing storage keys for huge pages (git-fixes
  bsc#1223871).
- commit a7e3ff2
* Fri May  3 2024 mfranc@suse.cz
- s390/vdso: Add CFI for RA register to asm macro vdso_func
  (git-fixes bsc#1223870).
- commit 2641ba1
* Fri May  3 2024 mfranc@suse.cz
- s390/cio: Ensure the copied buf is NUL terminated (git-fixes
  bsc#1223869).
- commit dcf45a9
* Fri May  3 2024 jgross@suse.com
- KVM: x86/mmu: x86: Don't overflow lpage_info when checking
  attributes (bsc#1223695, CVE-2024-26991).
- commit da41325
* Fri May  3 2024 vbabka@suse.cz
- mm: swap: fix race between free_swap_and_cache() and swapoff()
  (CVE-2024-26960 bsc#1223655).
- swap: comments get_swap_device() with usage rule (CVE-2024-26960
  bsc#1223655).
- commit 9df3192
* Fri May  3 2024 tiwai@suse.de
- NTB: fix possible name leak in ntb_register_device()
  (CVE-2023-52652 bsc#1223686).
- commit a6fcfa7
* Fri May  3 2024 msuchanek@suse.de
- Refresh patches.suse/powerpc-pseries-iommu-LPAR-panics-when-rebooted-with.patch.
- commit ca33aea
* Fri May  3 2024 msuchanek@suse.de
- powerpc/pseries: make max polling consistent for longer H_CALLs
  (bsc#1215199).
- commit bead2d2
* Fri May  3 2024 mhocko@suse.com
- fork: defer linking file vma until vma is fully initialized
  (bsc#1223774 CVE-2024-27022).
- commit 126ee1a
* Fri May  3 2024 wqu@suse.com
- btrfs: qgroup: always free reserved space for extent records
  (bsc#1216196).
- commit 5a30b4d
* Fri May  3 2024 tiwai@suse.de
- Fix a potential infinite loop in extract_user_to_sg()
  (git-fixes).
- mtd: diskonchip: work around ubsan link failure (stable-fixes).
- drm/amdgpu/sdma5.2: use legacy HDP flush for SDMA2/3
  (stable-fixes).
- drm/amdgpu: Assign correct bits for SDMA HDP flush
  (stable-fixes).
- drm/amdgpu: Fix leak when GPU memory allocation fails
  (stable-fixes).
- ACPI: CPPC: Fix access width used for PCC registers (git-fixes).
- ACPI: CPPC: Fix bit_offset shift in MASK_VAL() macro
  (git-fixes).
- Bluetooth: btusb: Add Realtek RTL8852BE support ID 0x0bda:0x4853
  (stable-fixes).
- Bluetooth: Fix type of len in {l2cap,sco}_sock_getsockopt_old()
  (stable-fixes).
- drm: add drm_gem_object_is_shared_for_memory_stats() helper
  (stable-fixes).
- ACPI: CPPC: Use access_width over bit_width for system memory
  accesses (stable-fixes).
- wifi: mac80211: clean up assignments to pointer cache
  (stable-fixes).
- commit 49aaf49
* Thu May  2 2024 dwagner@suse.de
- io_uring: remove uring_cmd cookie (bsc#1217384 CVE-2023-6238).
- iouring: remove IORING_URING_CMD_POLLED (bsc#1217384
  CVE-2023-6238).
- nvme: use bio_integrity_map_user (bsc#1217384 CVE-2023-6238).
- block: bio-integrity: directly map user buffers (bsc#1217384
  CVE-2023-6238).
- commit 3372add
* Thu May  2 2024 iivanov@suse.de
- arm64: dts: imx8-ss-lsio: fix pwm lpcg indices (git-fixes)
- commit c9b9705
* Thu May  2 2024 iivanov@suse.de
- arm64: dts: rockchip: regulator for sd needs to be always on for (git-fixes)
- commit 51da7a0
* Thu May  2 2024 iivanov@suse.de
- arm64: dts: rockchip: Remove unsupported node from the Pinebook Pro (git-fixes)
- commit d74d11d
* Thu May  2 2024 iivanov@suse.de
- arm64: dts: rockchip: enable internal pull-up on PCIE_WAKE# for (git-fixes)
- commit 300083f
* Thu May  2 2024 iivanov@suse.de
- arm64: dts: rockchip: enable internal pull-up on Q7_USB_ID for RK3399 (git-fixes)
- commit 7730872
* Thu May  2 2024 iivanov@suse.de
- arm64: dts: rockchip: enable internal pull-up for Q7_THRM# on RK3399 (git-fixes)
- commit 279e432
* Thu May  2 2024 iivanov@suse.de
- arm64: dts: rockchip: set PHY address of MT7531 switch to 0x1f (git-fixes)
- commit 57cc3f7
* Thu May  2 2024 iivanov@suse.de
- arm64: dts: imx8qm-ss-dma: fix can lpcg indices (git-fixes)
- commit 9f868d4
* Thu May  2 2024 tiwai@suse.de
- kABI workaround for cec_adapter (CVE-2024-23848 bsc#1219104).
- commit 03d06c5
* Thu May  2 2024 iivanov@suse.de
- arm64: dts: imx8-ss-dma: fix can lpcg indices (git-fixes)
- commit dd3deb9
* Thu May  2 2024 tiwai@suse.de
- media: cec: core: avoid recursive cec_claim_log_addrs
  (CVE-2024-23848 bsc#1219104).
- commit c64de88
* Thu May  2 2024 tiwai@suse.de
- Update media cec fix patches to the latest upstream version (CVE-2024-23848 bsc#1219104)
- commit 4a0b406
* Thu May  2 2024 iivanov@suse.de
- arm64: dts: imx8-ss-dma: fix adc lpcg indices (git-fixes)
- commit e69bdf0
* Thu May  2 2024 iivanov@suse.de
- arm64: dts: imx8-ss-dma: fix spi lpcg indices (git-fixes)
- commit 4dc5b7a
* Thu May  2 2024 iivanov@suse.de
- arm64: dts: imx8-ss-conn: fix usb lpcg indices (git-fixes)
- commit e2d7944
* Thu May  2 2024 iivanov@suse.de
- arm64: dts: imx8-ss-conn: fix usdhc wrong lpcg clock order (git-fixes)
- commit fbb3351
* Thu May  2 2024 iivanov@suse.de
- arm64: dts: rockchip: fix rk3399 hdmi ports node (git-fixes)
- commit a21edf3
* Thu May  2 2024 iivanov@suse.de
- arm64: dts: rockchip: fix rk3328 hdmi ports node (git-fixes)
- commit 3f691a1
* Thu May  2 2024 jslaby@suse.cz
- Update
  patches.suse/serial-max310x-fix-NULL-pointer-dereference-in-I2C-i.patch
  (git-fixes bsc#1223629 CVE-2024-26978).
- commit b81ff78
* Thu May  2 2024 ailiop@suse.com
- Squashfs: check the inode number is not the invalid value of
  zero (bsc#1223634 CVE-2024-26982).
- commit a406e7c
* Thu May  2 2024 ailiop@suse.com
- Update
  patches.suse/ubifs-ubifs_symlink-Fix-memleak-of-inode-i_link-in-error-path.patch
  (git-fixes CVE-2024-26972 bsc#1223643).
- commit 6db660a
* Thu May  2 2024 ailiop@suse.com
- Update
  patches.suse/nilfs2-prevent-kernel-bug-at-submit_bh_wbc.patch
  (git-fixes CVE-2024-26955 bsc#1223657).
- commit a77f45b
* Thu May  2 2024 ailiop@suse.com
- Update
  patches.suse/nilfs2-fix-failure-to-detect-DAT-corruption-in-btree.patch
  (git-fixes CVE-2024-26956 bsc#1223663).
- commit 95ba522
* Thu May  2 2024 ailiop@suse.com
- Update patches.suse/nilfs2-fix-OOB-in-nilfs_set_de_type.patch
  (git-fixes CVE-2024-26981 bsc#1223668).
- commit 5740c7f
* Thu May  2 2024 vkarasulli@suse.de
- Update
  patches.suse/ASoC-SOF-Add-some-bounds-checking-to-firmware-data.patch
  (git-fixes CVE-2024-26927 bsc#1223525).
- commit d3c5f91
* Thu May  2 2024 tiwai@suse.de
- cec: core: avoid confusing "transmit timed out" message
  (CVE-2024-23848 bsc#1219104).
- commit eae740c
* Thu May  2 2024 tiwai@suse.de
- regulator: change devm_regulator_get_enable_optional() stub
  to return Ok (git-fixes).
- regulator: change stubbed devm_regulator_get_enable to return Ok
  (git-fixes).
- regulator: mt6360: De-capitalize devicetree regulator subnodes
  (git-fixes).
- commit c50a631
* Wed May  1 2024 tiwai@suse.de
- power: supply: mt6360_charger: Fix of_match for usb-otg-vbus
  regulator (git-fixes).
- power: rt9455: hide unused rt9455_boost_voltage_values
  (git-fixes).
- pinctrl: baytrail: Fix selecting gpio pinctrl state (git-fixes).
- pinctrl: devicetree: fix refcount leak in pinctrl_dt_to_map()
  (git-fixes).
- pinctrl: mediatek: paris: Rework support for
  PIN_CONFIG_{INPUT,OUTPUT}_ENABLE (git-fixes).
- pinctrl: mediatek: paris: Fix PIN_CONFIG_INPUT_SCHMITT_ENABLE
  readback (git-fixes).
- pinctrl: core: delete incorrect free in pinctrl_enable()
  (git-fixes).
- pinctrl/meson: fix typo in PDM's pin name (git-fixes).
- pinctrl: pinctrl-aspeed-g6: Fix register offset for pinconf
  of GPIOR-T (git-fixes).
- crypto: lib/mpi - Fix unexpected pointer access in mpi_ec_init
  (git-fixes).
- commit d973920
* Tue Apr 30 2024 tiwai@suse.de
- ALSA: hda/realtek: Fix conflicting PCI SSID 17aa:386f for
  Lenovo Legion models (bsc#1223462).
- commit 6f0889c
* Tue Apr 30 2024 tiwai@suse.de
- usb: Fix regression caused by invalid ep0 maxpacket in virtual
  SuperSpeed device (bsc#1220569).
- commit 4748678
* Tue Apr 30 2024 tiwai@suse.de
- media: cec: cec-api: add locking in cec_release()
  (CVE-2024-23848 bsc#1219104).
- media: cec: cec-adap: always cancel work in cec_transmit_msg_fh
  (CVE-2024-23848 bsc#1219104).
- commit c39ac04
* Tue Apr 30 2024 mfranc@suse.cz
- s390/vdso: drop '-fPIC' from LDFLAGS (git-fixes bsc#1223593).
- commit 643ece2
* Tue Apr 30 2024 mfranc@suse.cz
- s390/zcrypt: fix reference counting on zcrypt card objects
  (git-fixes bsc#1223592).
- commit c37186f
* Tue Apr 30 2024 mkoutny@suse.com
- block: fix q->blkg_list corruption during disk rebind
  (bsc#1223591).
- commit 9da98d5
* Tue Apr 30 2024 mfranc@suse.cz
- s390/ism: Properly fix receive message buffer allocation
  (git-fixes bsc#1223590).
- commit 0652865
* Tue Apr 30 2024 jack@suse.cz
- block: fix deadlock between bd_link_disk_holder and partition
  scan (bsc#1223045 CVE-2024-26899).
- commit e4bd17c
* Tue Apr 30 2024 jack@suse.cz
- quota: Fix potential NULL pointer dereference (bsc#1223060
  CVE-2024-26878).
- commit dcf7382
* Tue Apr 30 2024 jack@suse.cz
- do_sys_name_to_handle(): use kzalloc() to fix kernel-infoleak
  (bsc#1223198 CVE-2024-26901).
- commit 5c1d722
* Tue Apr 30 2024 jack@suse.cz
- blk-mq: fix IO hang from sbitmap wakeup race (bsc#1222357 CVE-2024-26671).
- commit 1ebf5fb
* Tue Apr 30 2024 jack@suse.cz
- nbd: always initialize struct msghdr completely (bsc#1221649 CVE-2024-26638).
- commit eb8ab1c
* Tue Apr 30 2024 jack@suse.cz
- ext4: avoid allocating blocks from corrupted group in
  ext4_mb_find_by_goal() (bsc#1222613 CVE-2024-26772).
- commit 4004f20
* Tue Apr 30 2024 mfranc@suse.cz
- Update
  patches.suse/0001-s390-cio-fix-race-condition-during-online-processing.patch
  (bsc#1219485 bsc#1219451 git-fixes).
- Update patches.suse/0001-s390-qdio-handle-deferred-cc1.patch
  (bsc#1219485 bsc#1219451 git-fixes).
- Update
  patches.suse/s390-Once-the-discipline-is-associated-with-the-device-de.patch
  (bsc#1141539 git-fixes).
- commit 73a9e98
* Tue Apr 30 2024 davide.benini@suse.com
- net/ipv6: avoid possible UAF in ip6_route_mpath_notify()
  (CVE-2024-26852 bsc#1223057)
- commit 9474f59
* Tue Apr 30 2024 tiwai@suse.de
- PCI: Delay after FLR of Solidigm P44 Pro NVMe (stable-fixes).
- commit ec609ee
* Tue Apr 30 2024 tiwai@suse.de
- PCI: Fix typos in docs and comments (stable-fixes).
- PCI: switchtec: Add support for PCIe Gen5 devices
  (stable-fixes).
- PCI: switchtec: Use normal comment style (stable-fixes).
- PCI: Execute quirk_enable_clear_retrain_link() earlier
  (stable-fixes).
- commit 9bba47f
* Tue Apr 30 2024 tzimmermann@suse.com
- Edit "amdkfd: use calloc instead of kzalloc to avoid integer overflow"
  Reference CVE and bug numbers.
- commit 267eec1
* Tue Apr 30 2024 tiwai@suse.de
- soc: qcom: pmic_glink_altmode: fix drm bridge use-after-free
  (CVE-2024-26909 bsc#1223143).
- commit 043c9e0
* Tue Apr 30 2024 neilb@suse.de
- nfsd: use __fput_sync() to avoid delayed closing of files
  (bsc#1223380 bsc#1217408).
- commit 36cb9bb
* Mon Apr 29 2024 msuchanek@suse.de
- Update patches.suse/powerpc-pseries-vas-Hold-mmap_mutex-after-mmap-lock-.patch
  (bsc#1012628 jsc#PED-542 git-fixes bsc#1213573 ltc#203238).
- commit 8328f6d
* Mon Apr 29 2024 nik.borisov@suse.com
- x86/lib: Revert to _ASM_EXTABLE_UA() for {get,put}_user() fixups (bsc#1222378 CVE-2024-26674).
- commit 46190f1
* Mon Apr 29 2024 iluceno@suse.de
- ipvs: Fix checksumming on GSO of SCTP packets (bsc#1221958)
- commit 0b000e0
* Mon Apr 29 2024 nik.borisov@suse.com
- x86/mm: Disallow vsyscall page read for copy_from_kernel_nofault() (bsc#1223202 CVE-2024-26906).
- commit 664e61f
* Mon Apr 29 2024 nik.borisov@suse.com
- x86/mm: Move is_vsyscall_vaddr() into asm/vsyscall.h (bsc#1223202 CVE-2024-26906).
- commit 28c59d1
* Mon Apr 29 2024 nik.borisov@suse.com
- x86/boot: Ignore relocations in .notes sections in walk_relocs() too (bsc#1222624 CVE-2024-26816).
- commit 3cc2b03
* Mon Apr 29 2024 nik.borisov@suse.com
- x86, relocs: Ignore relocations in .notes section (bsc#1222624 CVE-2024-26816).
- commit 16f8af3
* Mon Apr 29 2024 osalvador@suse.de
- mm: zswap: fix missing folio cleanup in writeback race path
  (bsc#1223007 CVE-2024-26832).
- commit b985b2a
* Mon Apr 29 2024 osalvador@suse.de
- mm/vmscan: fix a bug calling wakeup_kswapd() with a wrong zone
  index (bsc#1222615 CVE-2024-26783).
- commit 7fe5b26
* Mon Apr 29 2024 jslaby@suse.cz
- Update config files. Disable N_GSM (jsc#PED-8240).
- commit ae9b7c6
* Mon Apr 29 2024 iivanov@suse.de
- Update patches.suse/gpio-tegra186-Fix-tegra186_gpio_is_accessible-check.patch (git-fixes bsc#1223439)
- commit 02eb8a1
* Mon Apr 29 2024 tiwai@suse.de
- irqchip/gic-v3-its: Prevent double free on error (git-fixes).
- irqchip/gic-v3-its: Fix VSYNC referencing an unmapped VPE on
  GIC v4.1 (git-fixes).
- irqchip/armada-370-xp: Suppress unused-function warning
  (git-fixes).
- irqchip/renesas-rzg2l: Prevent spurious interrupts when setting
  trigger type (git-fixes).
- irqchip/renesas-rzg2l: Rename rzg2l_irq_eoi() (stable-fixes).
- irqchip/renesas-rzg2l: Rename rzg2l_tint_eoi() (stable-fixes).
- irqchip/renesas-rzg2l: Flush posted write in irq_eoi()
  (git-fixes).
- irqchip/gic-v3-its: Do not assume vPE tables are preallocated
  (git-fixes).
- irqchip/mbigen: Don't use bus_get_dev_root() to find the parent
  (git-fixes).
- irqchip/renesas-rzg2l: Add macro to retrieve TITSR register
  offset based on register's index (stable-fixes).
- irqchip/renesas-rzg2l: Implement restriction when writing ISCR
  register (stable-fixes).
- commit 8e6882b
* Sun Apr 28 2024 tiwai@suse.de
- i2c: smbus: fix NULL function pointer dereference (git-fixes).
- soundwire: amd: fix for wake interrupt handling for clockstop
  mode (git-fixes).
- dmaengine: idxd: Fix oops during rmmod on single-CPU platforms
  (git-fixes).
- dma: xilinx_dpdma: Fix locking (git-fixes).
- idma64: Don't try to serve interrupts when device is powered
  off (git-fixes).
- dmaengine: tegra186: Fix residual calculation (git-fixes).
- dmaengine: owl: fix register access functions (git-fixes).
- phy: ti: tusb1210: Resolve charger-det crash if charger psy
  is unregistered (git-fixes).
- phy: rockchip: naneng-combphy: Fix mux on rk3588 (git-fixes).
- phy: rockchip-snps-pcie3: fix clearing PHP_GRF_PCIESEL_CON bits
  (git-fixes).
- phy: rockchip-snps-pcie3: fix bifurcation on rk3588 (git-fixes).
- phy: freescale: imx8m-pcie: fix pcie link-up instability
  (git-fixes).
- phy: marvell: a3700-comphy: Fix hardcoded array size
  (git-fixes).
- phy: marvell: a3700-comphy: Fix out of bounds read (git-fixes).
- commit 900a00b
* Sun Apr 28 2024 tiwai@suse.de
- selftests: kselftest: Mark functions that unconditionally call
  exit() as __noreturn (git-fixes).
- commit f533a19
* Sun Apr 28 2024 tiwai@suse.de
- selftests/timers/posix_timers: Reimplement
  check_timer_distribution() (git-fixes).
- commit d9f09cc
* Sun Apr 28 2024 tiwai@suse.de
- USB: serial: option: add Telit FN920C04 rmnet compositions
  (stable-fixes).
- USB: serial: option: add Rolling RW101-GL and RW135-GL support
  (stable-fixes).
- USB: serial: option: add Lonsung U8300/U9300 product
  (stable-fixes).
- USB: serial: option: add support for Fibocom FM650/FG650
  (stable-fixes).
- USB: serial: option: support Quectel EM060K sub-models
  (stable-fixes).
- USB: serial: option: add Fibocom FM135-GL variants
  (stable-fixes).
- thunderbolt: Avoid notify PM core about runtime PM resume
  (stable-fixes).
- thunderbolt: Fix wake configurations after device unplug
  (stable-fixes).
- usb: Disable USB3 LPM at shutdown (stable-fixes).
- usb: gadget: f_ncm: Fix UAF ncm object at re-bind after usb
  ep transport error (stable-fixes).
- clk: Get runtime PM before walking tree for clk_summary
  (git-fixes).
- clk: Get runtime PM before walking tree during disable_unused
  (git-fixes).
- clk: Initialize struct clk_core kref earlier (stable-fixes).
- arm64/head: Disable MMU at EL2 before clearing HCR_EL2.E2H
  (git-fixes).
- drm/radeon: make -fstrict-flex-arrays=3 happy (git-fixes).
- platform/x86/amd/pmc: Extend Framework 13 quirk to more BIOSes
  (stable-fixes).
- selftests/ftrace: Limit length in subsystem-enable tests
  (git-fixes).
- selftests: kselftest: Fix build failure with NOLIBC (git-fixes).
- selftests: timers: Fix abs() warning in posix_timers test
  (git-fixes).
- selftests: timers: Fix posix_timers ksft_print_msg() warning
  (git-fixes).
- drm/amd/display: Do not recursively call manual trigger
  programming (stable-fixes).
- drm/i915: Disable live M/N updates when using bigjoiner
  (stable-fixes).
- thunderbolt: Reset only non-USB4 host routers in resume
  (git-fixes).
- thunderbolt: Make tb_switch_reset() support Thunderbolt 2,
  3 and USB4 routers (stable-fixes).
- thunderbolt: Introduce tb_path_deactivate_hop() (stable-fixes).
- thunderbolt: Introduce tb_port_reset() (stable-fixes).
- ASoC: ti: Convert Pandora ASoC to GPIO descriptors
  (stable-fixes).
- ALSA: scarlett2: Add Focusrite Clarett 2Pre and 4Pre USB support
  (stable-fixes).
- ALSA: scarlett2: Add Focusrite Clarett+ 2Pre and 4Pre support
  (stable-fixes).
- ALSA: scarlett2: Add correct product series name to messages
  (stable-fixes).
- ALSA: scarlett2: Add support for Clarett 8Pre USB
  (stable-fixes).
- ALSA: scarlett2: Move USB IDs out from device_info struct
  (stable-fixes).
- ALSA: scarlett2: Default mixer driver to enabled (stable-fixes).
- PCI: Simplify pcie_capability_clear_and_set_word() to
  ..._clear_word() (stable-fixes).
- PCI/DPC: Use FIELD_GET() (stable-fixes).
- selftests: timers: Convert posix_timers test to generate KTAP
  output (stable-fixes).
- clk: Show active consumers of clocks in debugfs (stable-fixes).
- commit 8adba5b
* Sat Apr 27 2024 tiwai@suse.de
- Update patch reference for x86 p2sb fix (CVE-2024-26650 bsc#1222048)
- commit b68c2ef
* Sat Apr 27 2024 tiwai@suse.de
- mmc: sdhci-msm: pervent access to suspended controller
  (git-fixes).
- gpio: tangier: Use correct type for the IRQ chip data
  (git-fixes).
- gpio: tegra186: Fix tegra186_gpio_is_accessible() check
  (git-fixes).
- fbdev: fix incorrect address computation in deferred IO
  (git-fixes).
- drm/gma500: Remove lid code (git-fixes).
- commit 783bf0e
* Fri Apr 26 2024 tiwai@suse.de
- kabi/severities: ignore xfrm_bpf_md_dst that depends on CONFIG_DEBUG_* (bsc#1223415)
- commit 689bcfa
* Fri Apr 26 2024 denis.kirjanov@suse.com
- mptcp: annotate data-races around msk->rmem_fwd_alloc
  (git-fixes).
- commit a5d9cb6
* Fri Apr 26 2024 denis.kirjanov@suse.com
- net: annotate data-races around sk->sk_forward_alloc
  (git-fixes).
- commit bceb548
* Fri Apr 26 2024 denis.kirjanov@suse.com
- ipv4: annotate data-races around fi->fib_dead (git-fixes).
- commit f1e77d4
* Fri Apr 26 2024 denis.kirjanov@suse.com
- sctp: annotate data-races around sk->sk_wmem_queued (git-fixes).
- commit 66bd390
* Fri Apr 26 2024 denis.kirjanov@suse.com
- net: annotate data-races around sk->sk_lingertime (git-fixes).
- commit 33a5ffc
* Fri Apr 26 2024 denis.kirjanov@suse.com
- mptcp: Remove unnecessary test for __mptcp_init_sock()
  (git-fixes).
- commit dfc1c14
* Fri Apr 26 2024 denis.kirjanov@suse.com
- idpf: fix kernel panic on unknown packet types (git-fixes).
- commit def5526
* Fri Apr 26 2024 denis.kirjanov@suse.com
- ice: fix enabling RX VLAN filtering (git-fixes).
- commit 3d7f5a8
* Fri Apr 26 2024 denis.kirjanov@suse.com
- net: dsa: sja1105: Fix parameters order in
  sja1110_pcs_mdio_write_c45() (git-fixes).
- commit 9f9ee96
* Fri Apr 26 2024 denis.kirjanov@suse.com
- net: ravb: Always update error counters (git-fixes).
- commit 5d5deb7
* Fri Apr 26 2024 denis.kirjanov@suse.com
- net: ravb: Always process TX descriptor ring (git-fixes).
- commit 99798f7
* Fri Apr 26 2024 denis.kirjanov@suse.com
- net: stmmac: fix rx queue priority assignment (git-fixes).
- commit 3506dda
* Fri Apr 26 2024 denis.kirjanov@suse.com
- net: fec: Set mac_managed_pm during probe (git-fixes).
- commit c315308
* Fri Apr 26 2024 denis.kirjanov@suse.com
- octeontx2-af: Add array index check (git-fixes).
- commit 446ffd7
* Fri Apr 26 2024 denis.kirjanov@suse.com
- i40e: Fix VF MAC filter removal (git-fixes).
- commit fbb3a5f
* Fri Apr 26 2024 denis.kirjanov@suse.com
- octeontx2-pf: check negative error code in otx2_open()
  (git-fixes).
- commit a7c7e4f
* Fri Apr 26 2024 denis.kirjanov@suse.com
- i40e: fix vf may be used uninitialized in this function warning
  (git-fixes).
- commit 80b3415
* Fri Apr 26 2024 denis.kirjanov@suse.com
- i40e: fix i40e_count_filters() to count only active/new filters
  (git-fixes).
- commit 1870048
* Fri Apr 26 2024 denis.kirjanov@suse.com
- i40e: Enforce software interrupt during busy-poll exit
  (git-fixes).
- commit 2c9264a
* Fri Apr 26 2024 tiwai@suse.de
- wifi: mac80211: fix unaligned le16 access (git-fixes).
- wifi: mac80211: remove link before AP (git-fixes).
- wifi: mac80211_hwsim: init peer measurement result (git-fixes).
- wifi: nl80211: don't free NULL coalescing rule (git-fixes).
- wifi: iwlwifi: mvm: return uid from iwl_mvm_build_scan_cmd
  (git-fixes).
- wifi: iwlwifi: mvm: remove old PASN station when adding a new
  one (git-fixes).
- Bluetooth: qca: fix NULL-deref on non-serdev setup (git-fixes).
- Bluetooth: qca: fix NULL-deref on non-serdev suspend
  (git-fixes).
- Bluetooth: hci_event: Fix sending HCI_OP_READ_ENC_KEY_SIZE
  (git-fixes).
- Bluetooth: btusb: Fix triggering coredump implementation for
  QCA (git-fixes).
- net: usb: ax88179_178a: stop lying about skb->truesize
  (git-fixes).
- ax25: Fix netdev refcount issue (git-fixes).
- NFC: trf7970a: disable all regulators on removal (git-fixes).
- HID: logitech-dj: allow mice to use all types of reports
  (git-fixes).
- HID: intel-ish-hid: ipc: Fix dev_err usage with uninitialized
  dev->devc (git-fixes).
- HID: i2c-hid: remove I2C_HID_READ_PENDING flag to prevent
  lock-up (git-fixes).
- commit 416e04c
* Fri Apr 26 2024 tiwai@suse.de
- Move the upstreamed BT patch into sorted section
- commit aaffc85
* Fri Apr 26 2024 tiwai@suse.de
- Move the upstreamed BT fix patch to sorted section
- commit ab94ffe
* Fri Apr 26 2024 tiwai@suse.de
- Update kabi files: updated for post-PublicRC
- commit f978f5f
* Thu Apr 25 2024 tiwai@suse.de
- Update patch reference for PM devfreq fix (CVE-2023-52635 bsc#1222294)
- commit f099bed
* Thu Apr 25 2024 tiwai@suse.de
- Update kabi files: fix for arm64/64kb flavor, too (bsc#1223357)
- commit 8ef0762
* Thu Apr 25 2024 mkoutny@suse.com
- Update
  patches.suse/Bluetooth-btrtl-fix-out-of-bounds-memory-access.patch
  (git-fixes CVE-2024-26890 bsc#1223192).
- Update
  patches.suse/RDMA-mlx5-Fix-fortify-source-warning-while-accessing.patch
  (jsc#PED-3311 CVE-2024-26907 bsc#1223203).
- Update
  patches.suse/Revert-drm-amd-flush-any-delayed-gfxoff-on-suspend-e.patch
  (git-fixes CVE-2024-26916 bsc#1223137).
- Update
  patches.suse/crypto-xilinx-call-finalize-with-bh-disabled.patch
  (git-fixes CVE-2024-26877 bsc#1223140).
- Update
  patches.suse/dm-call-the-resume-method-on-internal-suspend-65e8.patch
  (git-fixes CVE-2024-26880 bsc#1223188).
- Update
  patches.suse/drm-amd-display-Fix-dcn35-8k30-Underflow-Corruption-.patch
  (git-fixes CVE-2024-26913 bsc#1223204).
- Update
  patches.suse/drm-amd-display-fix-incorrect-mpc_combine-array-size.patch
  (git-fixes CVE-2024-26914 bsc#1223205).
- Update patches.suse/drm-amdgpu-Reset-IH-OVERFLOW_CLEAR-bit.patch
  (git-fixes CVE-2024-26915 bsc#1223207).
- Update
  patches.suse/firmware-arm_scmi-Fix-double-free-in-SMC-transport-c.patch
  (git-fixes CVE-2024-26893 bsc#1223196).
- Update
  patches.suse/net-tls-fix-use-after-free-with-partial-reads-and-as.patch
  (bsc#1221858 CVE-2024-26582 bsc#1220214).
- Update
  patches.suse/wifi-ath9k-delay-all-of-ath9k_wmi_event_tasklet-unti.patch
  (git-fixes CVE-2024-26897 bsc#1223323).
- Update
  patches.suse/wifi-mt76-mt7921e-fix-use-after-free-in-free_irq.patch
  (git-fixes CVE-2024-26892 bsc#1223195).
- Update
  patches.suse/wifi-wilc1000-prevent-use-after-free-on-vif-when-cle.patch
  (git-fixes CVE-2024-26895 bsc#1223197).
- commit d9b565f
* Thu Apr 25 2024 tiwai@suse.de
- Fix missing CONFIG_SUSE_SUPPORTED for arm64/64kb flavor (bsc#1223357)
- commit 1c0959e
* Thu Apr 25 2024 denis.kirjanov@suse.com
- mlxbf_gige: stop interface during shutdown (git-fixes).
- commit f770ea3
* Thu Apr 25 2024 denis.kirjanov@suse.com
- octeontx2-af: Fix issue with loading coalesced KPU profiles
  (git-fixes).
- commit 65682db
* Thu Apr 25 2024 denis.kirjanov@suse.com
- e1000e: move force SMBUS from enable ulp function to avoid
  PHY loss issue (git-fixes).
- commit af85d1c
* Thu Apr 25 2024 denis.kirjanov@suse.com
- e1000e: Workaround for sporadic MDI error on Meteor Lake systems
  (git-fixes).
- commit 8830724
* Thu Apr 25 2024 denis.kirjanov@suse.com
- Octeontx2-af: fix pause frame configuration in GMP mode
  (git-fixes).
- commit 43722bd
* Thu Apr 25 2024 tiwai@suse.de
- bootconfig: Fix the kerneldoc of _xbc_exit() (git-fixes).
- commit e671e96
* Thu Apr 25 2024 tiwai@suse.de
- arm64: hibernate: Fix level3 translation fault in swsusp_save()
  (git-fixes).
- bootconfig: use memblock_free_late to free xbc memory to buddy
  (git-fixes).
- init/main.c: Fix potential static_command_line memory overflow
  (git-fixes).
- gpiolib: swnode: Remove wrong header inclusion (git-fixes).
- ARM: OMAP2+: fix USB regression on Nokia N8x0 (git-fixes).
- ARM: OMAP2+: fix N810 MMC gpiod table (git-fixes).
- i2c: pxa: hide unused icr_bits[] variable (git-fixes).
- driver core: Introduce device_link_wait_removal()
  (stable-fixes).
- ARM: prctl: reject PR_SET_MDWE on pre-ARMv6 (stable-fixes).
- init: open /initrd.image with O_LARGEFILE (stable-fixes).
- Fix build errors due to new UIO_MEM_DMA_COHERENT mess
  (git-fixes).
- ARM: s5pv210: fix pm.c kernel-doc warning (git-fixes).
- ARM: imx_v6_v7_defconfig: Restore CONFIG_BACKLIGHT_CLASS_DEVICE
  (git-fixes).
- kexec: do syscore_shutdown() in kernel_kexec (git-fixes).
- PM / devfreq: Synchronize devfreq_monitor_[start/stop]
  (stable-fixes).
- ida: make 'ida_dump' static (git-fixes).
- asm-generic: make sparse happy with odd-sized put_unaligned_*()
  (stable-fixes).
- ARM: imx: Check return value of devm_kasprintf in
  imx_mmdc_perf_init (git-fixes).
- bootmem: use kmemleak_free_part_phys in put_page_bootmem
  (git-fixes).
- commit b6327c9
* Thu Apr 25 2024 jlee@suse.com
- Bluetooth: hci_sync: Using hci_cmd_sync_submit when removing
  Adv Monitor (bsc#1219216).
- commit 81c5485
* Thu Apr 25 2024 tiwai@suse.de
- crypto: ccp - Add support for PCI device 0x156E (bsc#1223338).
- crypto: ccp - Add support for PCI device 0x17E0 (bsc#1223338).
- commit 9af2745
* Thu Apr 25 2024 tiwai@suse.de
- lsm: fix the logic in security_inode_getsecctx() (git-fixes).
- commit 9f85f33
* Thu Apr 25 2024 msuchanek@suse.de
- PCI: rpaphp: Error out on busy status from get-sensor-state
  (bsc#1223369 ltc#205888).
- commit 03aecd7
* Wed Apr 24 2024 tiwai@suse.de
- Update ath11k suspend patches from the latest subsystem tree (bsc#1207948).
- commit caea96a
* Wed Apr 24 2024 shung-hsi.yu@suse.com
- bpf: Fix stackmap overflow check on 32-bit arches (bsc#1223035
  CVE-2024-26883).
- bpf: Fix hashtab overflow check on 32-bit arches (bsc#1223189
  CVE-2024-26884).
- bpf: Fix DEVMAP_HASH overflow check on 32-bit arches
  (bsc#1223190 CVE-2024-26885).
- commit 98fad20
* Wed Apr 24 2024 shung-hsi.yu@suse.com
- kABI: bpf: struct xsk_buff_pool kABI workaround (bsc#1221303
  CVE-2024-26611).
- commit 764f7c3
* Tue Apr 23 2024 lduncan@suse.com
- Update
  patches.suse/scsi-target-pscsi-Fix-bio_put-for-error-case.patch
  (bsc#1222596 cve-2024-26760), fixng CVE number.
- commit 10886ae
* Tue Apr 23 2024 msuchanek@suse.de
- powerpc: Avoid nmi_enter/nmi_exit in real mode interrupt
  (bsc#1221645 ltc#205739 bsc#1223191).
- commit da2d8d3
* Mon Apr 22 2024 tiwai@suse.de
- Move out-of-tree powerpc patch to the right section
- commit ff83284
* Mon Apr 22 2024 denis.kirjanov@suse.com
- ice: use relative VSI index for VFs instead of PF VSI number
  (git-fixes).
- commit 271fd81
* Mon Apr 22 2024 denis.kirjanov@suse.com
- e1000e: Minor flow correction in e1000_shutdown function
  (git-fixes).
- commit cc5b32c
* Mon Apr 22 2024 denis.kirjanov@suse.com
- net: pcs: xpcs: Return EINVAL in the internal methods
  (git-fixes).
- commit 9b19312
* Mon Apr 22 2024 denis.kirjanov@suse.com
- net: ip_tunnel: make sure to pull inner header in
  ip_tunnel_rcv() (git-fixes CVE-2024-26882 bsc#1223034).
- commit c42f011
* Mon Apr 22 2024 denis.kirjanov@suse.com
- ionic: set adminq irq affinity (git-fixes).
- commit 7862c8a
* Mon Apr 22 2024 denis.kirjanov@suse.com
- net: add netdev_lockdep_set_classes() to virtual drivers
  (git-fixes).
- commit a8ebc57
* Mon Apr 22 2024 denis.kirjanov@suse.com
- net: ravb: Let IP-specific receive function to interrogate
  descriptors (git-fixes).
- commit d6b522e
* Mon Apr 22 2024 nik.borisov@suse.com
- x86/cpufeatures: Fix dependencies for GFNI, VAES, and VPCLMULQDQ (git-fixes).
- commit a29a0e4
* Mon Apr 22 2024 nik.borisov@suse.com
- x86/bugs: Fix BHI retpoline check (git-fixes).
- commit 00081b1
* Mon Apr 22 2024 msuchanek@suse.de
- selftests/powerpc/papr-vpd: Fix missing variable initialization
  (jsc#PED-4486 git-fixes).
- commit 8847657
* Mon Apr 22 2024 msuchanek@suse.de
- Rename patches.suse/Workaround-broken-chacha-crypto-fallback.patch to
  patches.suse/powerpc-crypto-chacha-p10-Fix-failure-on-non-Power10.patch.
- commit de47fb9
* Mon Apr 22 2024 tiwai@suse.de
- peci: linux/peci.h: fix Excess kernel-doc description warning
  (git-fixes).
- comedi: vmk80xx: fix incomplete endpoint checking (git-fixes).
- mei: me: disable RPL-S on SPS and IGN firmwares (git-fixes).
- speakup: Avoid crash on very long word (git-fixes).
- serial: stm32: Reset .throttled state in .startup() (git-fixes).
- serial/pmac_zilog: Remove flawed mitigation for rx irq flood
  (git-fixes).
- serial: mxs-auart: add spinlock around changing cts state
  (git-fixes).
- serial: 8250_dw: Revert: Do not reclock if already at correct
  rate (git-fixes).
- Revert "usb: cdc-wdm: close race between read and workqueue"
  (git-fixes).
- thunderbolt: Do not create DisplayPort tunnels on adapters of
  the same router (git-fixes).
- usb: dwc2: host: Fix dereference issue in DDMA completion flow
  (git-fixes).
- usb: typec: tcpm: Correct the PDO counting in pd_set
  (git-fixes).
- usb: typec: ucsi: Fix connector check on init (git-fixes).
- usb: xhci: correct return value in case of STS_HCE (git-fixes).
- commit 1d56577
* Sun Apr 21 2024 tiwai@suse.de
- clk: mediatek: Do a runtime PM get on controllers during probe
  (git-fixes).
- clk: Remove prepare_lock hold assertion in __clk_release()
  (git-fixes).
- commit 78e7847
* Sun Apr 21 2024 lduncan@suse.com
- scsi: sg: Avoid race in error handling & drop bogus warn
  (git-fixes).
- commit 855ebc6
* Sat Apr 20 2024 tiwai@suse.de
- Bluetooth: MGMT: Fix failing to
  MGMT_OP_ADD_UUID/MGMT_OP_REMOVE_UUID (bsc#1221504).
- commit 8ea8f78
* Sat Apr 20 2024 tiwai@suse.de
- ALSA: hda/realtek - Enable audio jacks of Haier Boyue G42 with
  ALC269VC (stable-fixes).
- ALSA: hda/realtek: Add quirks for Huawei Matebook D14 NBLB-WAX9N
  (stable-fixes).
- ALSA: hda/realtek: Fixes for Asus GU605M and GA403U sound
  (stable-fixes).
- ALSA: hda/tas2781: Add new vendor_id and subsystem_id to
  support ThinkPad ICE-1 (stable-fixes).
- ALSA: hda/realtek: Add quirk for HP SnowWhite laptops
  (stable-fixes).
- commit 2244c24
* Sat Apr 20 2024 tiwai@suse.de
- ALSA: seq: ump: Fix conversion from MIDI2 to MIDI1 UMP messages
  (git-fixes).
- ALSA: hda/realtek: Fix volumn control of ThinkBook 16P Gen4
  (git-fixes).
- ALSA: hda/tas2781: correct the register for pow calibrated data
  (git-fixes).
- drm/panel: visionox-rm69299: don't unregister DSI device
  (git-fixes).
- drm/vmwgfx: Sort primary plane formats by order of preference
  (git-fixes).
- drm/vmwgfx: Fix crtc's atomic check conditional (git-fixes).
- drm/vmwgfx: Fix prime import/export (git-fixes).
- drm/ttm: stop pooling cached NUMA pages v2 (git-fixes).
- drm: nv04: Fix out of bounds access (git-fixes).
- nouveau: fix instmem race condition around ptr stores
  (git-fixes).
- drm/amdgpu: fix visible VRAM handling during faults (git-fixes).
- drm/amdgpu: validate the parameters of bo mapping operations
  more clearly (git-fixes).
- Revert "drm/amd/display: fix USB-C flag update after enc10
  feature init" (stable-fixes).
- drm/amdkfd: Fix memory leak in create_process failure
  (git-fixes).
- drm/amdgpu: remove invalid resource->start check v2 (git-fixes).
- nilfs2: fix OOB in nilfs_set_de_type (git-fixes).
- commit de35710
* Fri Apr 19 2024 lduncan@suse.com
- scsi: qla2xxx: Fix off by one in qla_edif_app_getstats()
  (git-fixes).
- scsi: hisi_sas: Modify the deadline for ata_wait_after_reset()
  (git-fixes).
- scsi: sd: Unregister device if device_add_disk() failed in
  sd_probe() (git-fixes).
- scsi: mylex: Fix sysfs buffer lengths (git-fixes).
- scsi: core: Fix unremoved procfs host directory regression
  (git-fixes).
- scsi: sg: Avoid sg device teardown race (git-fixes).
- scsi: libsas: Fix disk not being scanned in after being removed
  (git-fixes).
- scsi: libsas: Add a helper sas_get_sas_addr_and_dev_type()
  (git-fixes).
- scsi: bfa: Fix function pointer type mismatch for hcb_qe->cbfn
  (git-fixes).
- scsi: csiostor: Avoid function pointer casts (git-fixes).
- scsi: mpt3sas: Prevent sending diag_reset when the controller
  is ready (git-fixes).
- scsi: mpi3mr: Reduce stack usage in mpi3mr_refresh_sas_ports()
  (git-fixes).
- scsi: smartpqi: Fix disable_managed_interrupts (git-fixes).
- scsi: core: Consult supported VPD page list prior to fetching
  page (git-fixes).
- commit 8d33038
* Fri Apr 19 2024 tiwai@suse.de
- pmdomain: mediatek: fix race conditions with genpd
  (CVE-2023-52645 bsc#1223033).
- commit c2656fd
* Fri Apr 19 2024 tiwai@suse.de
- Delete patches.suse/modpost-Add-.ltext-and-.ltext.-to-TEXT_SECTIONS.patch
  This caused an overflow of the table as we haven't taken other earlier
  changes.  Drop it for now.
- commit bc7d928
* Fri Apr 19 2024 colyli@suse.de
- block: Fix WARNING in _copy_from_iter (bsc#1223015,
  CVE-2024-26844).
- commit a5a381a
* Fri Apr 19 2024 tiwai@suse.de
- platform/x86: think-lmi: Fix password opcode ordering for
  workstations (CVE-2024-26836 bsc#1222968).
- platform/x86: think-lmi: Enable opcode support on BIOS settings
  (CVE-2024-26836 bsc#1222968).
- commit a97b715
* Fri Apr 19 2024 denis.kirjanov@suse.com
- net: tcp: fix unexcepted socket die when snd_wnd is 0
  (git-fixes).
- commit e8c290a
* Fri Apr 19 2024 denis.kirjanov@suse.com
- net: Use sockaddr_storage for getsockopt(SO_PEERNAME)
  (git-fixes).
- commit 0bf4249
* Fri Apr 19 2024 denis.kirjanov@suse.com
- nf_conntrack: fix -Wunused-const-variable= (git-fixes).
- commit 771e185
* Fri Apr 19 2024 denis.kirjanov@suse.com
- net: NSH: fix kernel-doc notation warning (git-fixes).
- commit ab89a9e
* Fri Apr 19 2024 denis.kirjanov@suse.com
- net: llc: fix kernel-doc notation warnings (git-fixes).
- commit a9e21ce
* Fri Apr 19 2024 denis.kirjanov@suse.com
- inet: frags: eliminate kernel-doc warning (git-fixes).
- commit 3d5b832
* Fri Apr 19 2024 denis.kirjanov@suse.com
- net: cfg802154: fix kernel-doc notation warnings (git-fixes).
- commit f9d49a1
* Fri Apr 19 2024 denis.kirjanov@suse.com
- net: bonding: remove kernel-doc comment marker (git-fixes).
- commit b25069a
* Fri Apr 19 2024 denis.kirjanov@suse.com
- net: phy: phy_device: Prevent nullptr exceptions on ISR
  (git-fixes).
- commit da73105
* Fri Apr 19 2024 denis.kirjanov@suse.com
- net: stmmac: dwmac-starfive: Add support for JH7100 SoC
  (git-fixes).
- commit 644ea8f
* Fri Apr 19 2024 denis.kirjanov@suse.com
- bnx2x: Fix firmware version string character counts (git-fixes).
- commit b005933
* Fri Apr 19 2024 denis.kirjanov@suse.com
- net: sparx5: Fix use after free inside sparx5_del_mact_entry
  (git-fixes).
- commit 3b59a03
* Fri Apr 19 2024 tiwai@suse.de
- Revert "drm/amd/amdgpu: Fix potential ioremap() memory leaks
  in amdgpu_device_init()" (stable-fixes).
- commit f7f3760
* Fri Apr 19 2024 tiwai@suse.de
- usb: typec: ucsi: Limit read size on v1.2 (stable-fixes).
- Refresh
  patches.suse/usb-typec-ucsi-Update-connector-cap-and-status.patch.
- commit e357444
* Fri Apr 19 2024 tiwai@suse.de
- wifi: mt76: mt7996: add locking for accessing mapped registers
  (stable-fixes).
- commit ac66d90
* Fri Apr 19 2024 tiwai@suse.de
- net: usb: ax88179_178a: avoid writing the mac address before
  first reading (git-fixes).
- random: handle creditable entropy from atomic process context
  (git-fixes).
- firmware: arm_scmi: Make raw debugfs entries non-seekable
  (git-fixes).
- mmc: omap: restore original power up/down steps (git-fixes).
- mmc: omap: fix deferred probe (git-fixes).
- mmc: omap: fix broken slot switch lookup (git-fixes).
- nouveau: fix function cast warning (git-fixes).
- PM: s2idle: Make sure CPUs will wakeup directly on resume
  (git-fixes).
- platform/chrome: cros_ec_uart: properly fix race condition
  (git-fixes).
- platform/x86: intel-vbtn: Update tablet mode switch at end of
  probe (git-fixes).
- nouveau: fix devinit paths to only handle display on GSP
  (git-fixes).
- gpio: cdev: fix missed label sanitizing in debounce_setup()
  (git-fixes).
- gpio: cdev: check for NULL labels when sanitizing them for irqs
  (git-fixes).
- gpio: cdev: sanitize the label before requesting the interrupt
  (stable-fixes).
- usb: sl811-hcd: only defined function checkdone if QUIRK2 is
  defined (stable-fixes).
- usb: typec: tcpci: add generic tcpci fallback compatible
  (stable-fixes).
- usb: gadget: uvc: mark incomplete frames with UVC_STREAM_ERR
  (stable-fixes).
- thermal/of: Assume polling-delay(-passive) 0 when absent
  (stable-fixes).
- Input: xpad - add support for Snakebyte GAMEPADs (stable-fixes).
- Input: imagis - use FIELD_GET where applicable (stable-fixes).
- input/touchscreen: imagis: Correct the maximum touch area value
  (stable-fixes).
- Input: synaptics-rmi4 - fail probing if memory allocation for
  "phys" fails (stable-fixes).
- media: sta2x11: fix irq handler cast (stable-fixes).
- media: cec: core: remove length check of Timer Status
  (stable-fixes).
- PCI: Disable D3cold on Asus B1400 PCI-NVMe bridge
  (stable-fixes).
- platform/x86: touchscreen_dmi: Add an extra entry for a variant
  of the Chuwi Vi8 tablet (stable-fixes).
- Input: allocate keycode for Display refresh rate toggle
  (stable-fixes).
- pinctrl: renesas: checker: Limit cfg reg enum checks to provided
  IDs (stable-fixes).
- HID: input: avoid polling stylus battery on Chromebook Pompom
  (stable-fixes).
- wifi: cfg80211: check A-MSDU format more carefully
  (stable-fixes).
- wifi: mt76: mt7996: disable AMSDU for non-data frames
  (stable-fixes).
- wifi: brcmfmac: Add DMI nvram filename quirk for ACEPC W5 Pro
  (stable-fixes).
- wifi: iwlwifi: pcie: Add the PCI device id for new hardware
  (stable-fixes).
- wifi: rtw89: pci: enlarge RX DMA buffer to consider size of
  RX descriptor (stable-fixes).
- wifi: ath9k: fix LNA selection in ath_ant_try_scan()
  (stable-fixes).
- net: phy: phy_device: Prevent nullptr exceptions on ISR
  (stable-fixes).
- wifi: rtw89: fix null pointer access when abort scan
  (stable-fixes).
- overflow: Allow non-type arg to type_max() and type_min()
  (stable-fixes).
- pstore/zone: Add a null pointer check to the psz_kmsg_read
  (stable-fixes).
- modpost: Add '.ltext' and '.ltext.*' to TEXT_SECTIONS
  (stable-fixes).
- commit 7321185
* Fri Apr 19 2024 tiwai@suse.de
- drm/msm/dp: fix typo in dp_display_handle_port_status_changed()
  (git-fixes).
- drm/msm/dpu: make error messages at
  dpu_core_irq_register_callback() more sensible (git-fixes).
- drm/msm/dpu: don't allow overriding data from catalog
  (git-fixes).
- drm/msm: Add newlines to some debug prints (git-fixes).
- drm/vmwgfx: Enable DMA mappings with SEV (git-fixes).
- drm/client: Fully protect modes[] with dev->mode_config.mutex
  (stable-fixes).
- Revert "drm/qxl: simplify qxl_fence_wait" (git-fixes).
- drm/ast: Fix soft lockup (git-fixes).
- drm/panfrost: Fix the error path in
  panfrost_mmu_map_fault_addr() (git-fixes).
- drm/amd/display: Set VSC SDP Colorimetry same way for MST and
  SST (stable-fixes).
- drm/amd/display: Program VSC SDP colorimetry for all DP sinks >=
  1.4 (stable-fixes).
- drm/amd/display: fix disable otg wa logic in DCN316
  (stable-fixes).
- drm/amdgpu: fix incorrect number of active RBs for gfx11
  (stable-fixes).
- drm/amd/pm: fixes a random hang in S4 for SMU v13.0.4/11
  (stable-fixes).
- drm/amdgpu: Reset dGPU if suspend got aborted (stable-fixes).
- drm/amdgpu: always force full reset for SOC21 (stable-fixes).
- drm/amdkfd: Reset GPU on queue preemption failure
  (stable-fixes).
- drm/i915/vrr: Disable VRR when using bigjoiner (stable-fixes).
- drm/i915: Disable port sync when bigjoiner is used
  (stable-fixes).
- drm/i915/cdclk: Fix CDCLK programming order when pipes are
  active (git-fixes).
- drm/i915: Pre-populate the cursor physical dma address
  (git-fixes).
- fbmon: prevent division by zero in fb_videomode_from_videomode()
  (stable-fixes).
- fbdev: viafb: fix typo in hw_bitblt_1 and hw_bitblt_2
  (stable-fixes).
- drm/amd/amdgpu: Fix potential ioremap() memory leaks in
  amdgpu_device_init() (stable-fixes).
- drm/amd/display: Fix nanosec stat overflow (stable-fixes).
- drm: Check polling initialized before enabling in
  drm_helper_probe_single_connector_modes (stable-fixes).
- drm: Check output polling initialized before disabling
  (stable-fixes).
- drm/ttm: return ENOSPC from ttm_bo_mem_space v3 (stable-fixes).
- drm: panel-orientation-quirks: Add quirk for GPD Win Mini
  (stable-fixes).
- firmware: tegra: bpmp: Return directly after a failed kzalloc()
  in get_filename() (stable-fixes).
- commit 2efe82e
* Fri Apr 19 2024 tiwai@suse.de
- ata: libata-core: Allow command duration limits detection for
  ACS-4 drives (git-fixes).
- amdkfd: use calloc instead of kzalloc to avoid integer overflow
  (stable-fixes).
- accel/ivpu: Fix deadlock in context_xa (git-fixes).
- ACPI: scan: Do not increase dep_unmet for already met
  dependencies (git-fixes).
- Bluetooth: l2cap: Don't double set the HCI_CONN_MGMT_CONNECTED
  bit (git-fixes).
- Bluetooth: hci_sock: Fix not validating setsockopt user input
  (git-fixes).
- Bluetooth: L2CAP: Fix not validating setsockopt user input
  (git-fixes).
- Bluetooth: RFCOMM: Fix not validating setsockopt user input
  (git-fixes).
- Bluetooth: SCO: Fix not validating setsockopt user input
  (git-fixes).
- Bluetooth: Fix memory leak in hci_req_sync_complete()
  (git-fixes).
- Bluetooth: hci_sync: Fix using the same interval and window
  for Coded PHY (git-fixes).
- Bluetooth: ISO: Don't reject BT_ISO_QOS if parameters are unset
  (git-fixes).
- batman-adv: Avoid infinite loop trying to resize local TT
  (git-fixes).
- Bluetooth: hci_event: set the conn encrypted before conn
  establishes (stable-fixes).
- ASoC: soc-core.c: Skip dummy codec when adding platforms
  (stable-fixes).
- ASoC: amd: yc: Fix non-functional mic on ASUS M7600RE
  (stable-fixes).
- ASoC: Intel: avs: Populate board selection with new I2S entries
  (stable-fixes).
- ASoC: Intel: common: DMI remap for rebranded Intel NUC M15
  (LAPRC710) laptops (stable-fixes).
- ASoC: SOF: amd: Optimize quirk for Valve Galileo (stable-fixes).
- ALSA: firewire-lib: handle quirk to calculate payload quadlets
  as data block counter (stable-fixes).
- Revert "ACPI: PM: Block ASUS B1400CEAE from suspend to idle
  by default" (stable-fixes).
- drm/vc4: don't check if plane->state->fb == state->fb
  (stable-fixes).
- ACPI: x86: Move acpi_quirk_skip_serdev_enumeration() out of
  CONFIG_X86_ANDROID_TABLETS (stable-fixes).
- Bluetooth: ISO: Align broadcast sync_timeout with connection
  timeout (stable-fixes).
- Bluetooth: Add new quirk for broken read key length on ATS2851
  (stable-fixes).
- Bluetooth: hci_sync: Use QoS to determine which PHY to scan
  (stable-fixes).
- Bluetooth: btintel: Fixe build regression (git-fixes).
- Bluetooth: btintel: Fix null ptr deref in btintel_read_version
  (stable-fixes).
- drm/i915/display: Use i915_gem_object_get_dma_address to get
  dma address (stable-fixes).
- commit 79cdb13
* Fri Apr 19 2024 osalvador@suse.de
- Update
  patches.suse/stmmac-Clear-variable-when-destroying-workqueue.patch
  (git-fixes CVE-2024-26802 bsc#1222799).
- commit a49cc37
* Fri Apr 19 2024 osalvador@suse.de
- Update
  patches.suse/0001-fs-hugetlb-fix-NULL-pointer-dereference-in-hugetlbs_.patch
  (bsc#1219264 CVE-2024-0841 CVE-2024-26688 bsc#1222482).
- Update
  patches.suse/0002-iommu-vt-d-Don-t-issue-ATS-Invalidation-request-when.patch
  (git-fixes CVE-2024-26891 bsc#1223037).
- Update
  patches.suse/ACPI-processor_idle-Fix-memory-leak-in-acpi_processo.patch
  (git-fixes CVE-2024-26894 bsc#1223043).
- Update
  patches.suse/ASoC-qcom-Fix-uninitialized-pointer-dmactl.patch
  (git-fixes CVE-2024-26799 bsc#1222415).
- Update
  patches.suse/Bluetooth-Avoid-potential-use-after-free-in-hci_erro.patch
  (git-fixes CVE-2024-26801 bsc#1222413).
- Update patches.suse/Bluetooth-af_bluetooth-Fix-deadlock.patch
  (git-fixes CVE-2024-26886 bsc#1223044).
- Update
  patches.suse/IB-hfi1-Fix-a-memleak-in-init_credit_return.patch
  (git-fixes CVE-2024-26839 bsc#1222975).
- Update
  patches.suse/RDMA-irdma-Fix-KASAN-issue-with-tasklet.patch
  (git-fixes CVE-2024-26838 bsc#1222974).
- Update
  patches.suse/RDMA-srpt-Do-not-register-event-handler-until-srpt-d.patch
  (git-fixes CVE-2024-26872 bsc#1223115).
- Update
  patches.suse/afs-Fix-endless-loop-in-directory-parsing.patch
  (git-fixes CVE-2024-26848 bsc#1223030).
- Update
  patches.suse/afs-Increase-buffer-size-in-afs_update_volume_status.patch
  (git-fixes CVE-2024-26736 bsc#1222586).
- Update
  patches.suse/btrfs-fix-double-free-of-anonymous-device-after-snap.patch
  (bsc#1219126 CVE-2024-23850 CVE-2024-26792 bsc#1222430).
- Update
  patches.suse/cachefiles-fix-memory-leak-in-cachefiles_add_cache.patch
  (bsc#1220265 CVE-2024-26840 bsc#1222976).
- Update
  patches.suse/ceph-prevent-use-after-free-in-encode_cap_msg.patch
  (bsc#1221391 CVE-2024-26689 bsc#1222503).
- Update
  patches.suse/clk-meson-Add-missing-clocks-to-axg_clk_regmaps.patch
  (git-fixes CVE-2024-26879 bsc#1223066).
- Update
  patches.suse/crypto-algif_hash-Remove-bogus-SGL-free-on-zero-leng.patch
  (git-fixes CVE-2024-26824 bsc#1223081).
- Update
  patches.suse/dmaengine-fsl-qdma-init-irq-after-reg-initialization.patch
  (git-fixes CVE-2024-26788 bsc#1222783).
- Update
  patches.suse/dmaengine-idxd-Ensure-safe-user-copy-of-completion-r.patch
  (bsc#1221428 git-fixes CVE-2024-26746 bsc#1222444).
- Update
  patches.suse/drm-amd-display-Fix-MST-Null-Ptr-for-RV.patch
  (git-fixes CVE-2024-26700 bsc#1222870).
- Update
  patches.suse/drm-amd-display-Fix-memory-leak-in-dm_sw_fini.patch
  (git-fixes CVE-2024-26833 bsc#1223036).
- Update
  patches.suse/drm-amd-display-Fix-potential-null-pointer-dereferen.patch
  (git-fixes CVE-2024-26729 bsc#1222552).
- Update
  patches.suse/drm-amd-display-Prevent-potential-buffer-overflow-in.patch
  (git-fixes CVE-2024-26797 bsc#1222425).
- Update
  patches.suse/drm-bridge-adv7511-fix-crash-on-irq-during-probe.patch
  (git-fixes CVE-2024-26876 bsc#1223119).
- Update
  patches.suse/drm-buddy-Fix-alloc_range-error-handling-code.patch
  (git-fixes CVE-2024-26911 bsc#1223055).
- Update
  patches.suse/drm-mediatek-Fix-a-null-pointer-crash-in-mtk_drm_crt.patch
  (git-fixes CVE-2024-26874 bsc#1223048).
- Update
  patches.suse/drm-nouveau-fix-several-DMA-buffer-leaks.patch
  (git-fixes CVE-2024-26912 bsc#1223064).
- Update
  patches.suse/efi-runtime-Fix-potential-overflow-of-soft-reserved-.patch
  (git-fixes CVE-2024-26843 bsc#1223014).
- Update
  patches.suse/fbcon-always-restore-the-old-font-data-in-fbcon_do_s.patch
  (git-fixes CVE-2024-26798 bsc#1222798).
- Update
  patches.suse/i40e-Do-not-allow-untrusted-VF-to-remove-administrat.patch
  (git-fixes CVE-2024-26830 bsc#1223012).
- Update
  patches.suse/iio-adc-ad4130-zero-initialize-clock-init-data.patch
  (git-fixes CVE-2024-26711 bsc#1222420).
- Update
  patches.suse/md-Don-t-suspend-the-array-for-interrupted-reshape-9e46.patch
  (git-fixes CVE-2024-26755 bsc#1222529).
- Update patches.suse/media-ir_toy-fix-a-memleak-in-irtoy_tx.patch
  (git-fixes CVE-2024-26829 bsc#1223027).
- Update
  patches.suse/media-pvrusb2-fix-uaf-in-pvr2_context_set_notify.patch
  (git-fixes CVE-2024-26875 bsc#1223118).
- Update
  patches.suse/msft-hv-2942-hv_netvsc-Register-VF-in-netvsc_probe-if-NET_DEVICE_.patch
  (git-fixes CVE-2024-26820 bsc#1223078).
- Update
  patches.suse/net-bnx2x-Prevent-access-to-a-freed-page-in-page_poo.patch
  (bsc#1215322 CVE-2024-26859 bsc#1223049).
- Update
  patches.suse/net-veth-clear-GRO-when-clearing-XDP-even-when-down.patch
  (git-fixes CVE-2024-26803 bsc#1222788).
- Update
  patches.suse/nfc-nci-free-rx_data_reassembly-skb-on-NCI-device-cl.patch
  (git-fixes CVE-2024-26825 bsc#1223065).
- Update
  patches.suse/nilfs2-fix-data-corruption-in-dsync-block-recovery-f.patch
  (git-fixes CVE-2024-26697 bsc#1222550).
- Update
  patches.suse/nilfs2-fix-hang-in-nilfs_lookup_dirty_data_buffers.patch
  (git-fixes CVE-2024-26696 bsc#1222549).
- Update
  patches.suse/powerpc-iommu-Fix-the-missing-iommu_group_put-during.patch
  (jsc#PED-7779 jsc#PED-7780 git-fixes CVE-2024-26709
  bsc#1222418).
- Update
  patches.suse/powerpc-kasan-Limit-KASAN-thread-size-increase-to-32.patch
  (bsc#1215199 CVE-2024-26710 bsc#1222419).
- Update
  patches.suse/powerpc-pseries-iommu-DLPAR-add-doesn-t-completely-i.patch
  (bsc#1215199 bsc#1219077 ltc#204477 CVE-2024-26738 bsc#1222607).
- Update
  patches.suse/powerpc-rtas-use-correct-function-name-for-resetting.patch
  (bsc#1215199 CVE-2024-26847 bsc#1223026).
- Update patches.suse/ppp_async-limit-MRU-to-64K.patch (git-fixes
  CVE-2024-26675 bsc#1222379).
- Update
  patches.suse/scsi-Revert-scsi-fcoe-Fix-potential-deadlock-on-fip-ctlr_lock.patch
  (git-fixes bsc#1219141 CVE-2024-26917 bsc#1223056).
- Update
  patches.suse/wifi-iwlwifi-mvm-fix-a-crash-when-we-run-out-of-stat.patch
  (git-fixes CVE-2024-26693 bsc#1222451).
- Update
  patches.suse/wifi-mac80211-fix-race-condition-on-enabling-fast-xm.patch
  (git-fixes CVE-2024-26779 bsc#1222772).
- Update
  patches.suse/wifi-wfx-fix-memory-leak-when-starting-AP.patch
  (git-fixes CVE-2024-26896 bsc#1223042).
- Update
  patches.suse/xen-events-close-evtchn-after-mapping-cleanup.patch
  (git-fixes CVE-2024-26687 bsc#1222435).
- commit a69636a
* Fri Apr 19 2024 osalvador@suse.de
- Update
  patches.suse/iio-core-fix-memleak-in-iio_device_register_sysfs.patch
  (git-fixes CVE-2023-52643 bsc#1222960).
- Update
  patches.suse/media-rc-bpf-attach-detach-requires-write-permission.patch
  (git-fixes CVE-2023-52642 bsc#1223031).
- Update
  patches.suse/wifi-b43-Stop-wake-correct-queue-in-DMA-Tx-path-when.patch
  (git-fixes CVE-2023-52644 bsc#1222961).
- commit 2c2d37f
* Fri Apr 19 2024 osalvador@suse.de
- Update
  patches.suse/wifi-mac80211-fix-race-condition-on-enabling-fast-xm.patch
  (git-fixes CVE-2024-26779 bsc#1222772).
- commit 463d6dd
* Fri Apr 19 2024 tiwai@suse.de
- Update patch reference of iio fix (CVE-2024-26702 bsc#1222424)
- commit 9436142
* Fri Apr 19 2024 tiwai@suse.de
- Update patch reference for interconnect patch (CVE-2024-26714 bsc#1222489)
- commit 773fbda
* Thu Apr 18 2024 jack@suse.cz
- ext4: regenerate buddy after block freeing failed if under fc
  replay (bsc#1220342 CVE-2024-26601).
- commit fec1ddc
* Thu Apr 18 2024 hare@suse.de
- nvme-tcp: strict pdu pacing to avoid send stalls on TLS
  (bsc#1221858).
- tls: fix peeking with sync+async decryption (bsc#1221858).
- tls: don't skip over different type records from the rx_list
  (bsc#1221858).
- tls: stop recv() if initial process_rx_list gave us non-DATA
  (bsc#1221858).
- tls: break out of main loop when PEEK gets a non-data record
  (bsc#1221858).
- net: tls: fix returned read length with async decrypt
  (bsc#1221858).
- net: tls: fix use-after-free with partial reads and async
  (bsc#1221858).
- net: tls, fix WARNIING in __sk_msg_free (bsc#1221858).
- nvme-tcp: strict pdu pacing to avoid send stalls on TLS
  (bsc#1221858).
- tls: fix peeking with sync+async decryption (bsc#1221858).
- tls: don't skip over different type records from the rx_list
  (bsc#1221858).
- tls: stop recv() if initial process_rx_list gave us non-DATA
  (bsc#1221858).
- tls: break out of main loop when PEEK gets a non-data record
  (bsc#1221858).
- net: tls: fix returned read length with async decrypt
  (bsc#1221858).
- net: tls: fix use-after-free with partial reads and async
  (bsc#1221858).
- net: tls, fix WARNIING in __sk_msg_free (bsc#1221858).
- commit 9d8d293
* Thu Apr 18 2024 hare@suse.de
- Refresh
  patches.suse/nvme-keyring-restrict-match-length-for-version-1-ide.patch.
- commit da3d979
* Thu Apr 18 2024 ailiop@suse.com
- Update
  patches.suse/afs-Fix-endless-loop-in-directory-parsing.patch
  (git-fixes bsc#1223030 CVE-2024-26848).
- commit 9f64be5
* Wed Apr 17 2024 jack@suse.cz
- fs/aio: Check IOCB_AIO_RW before the struct aio_kiocb conversion
  (bsc#1222721 CVE-2024-26764).
- commit 72ff5e9
* Wed Apr 17 2024 jack@suse.cz
- fs/aio: Restrict kiocb_set_cancel_fn() to I/O submitted via
  libaio (bsc#1222721 CVE-2024-26764).
- commit 241f561
* Wed Apr 17 2024 jack@suse.cz
- ext4: avoid dividing by 0 in mb_update_avg_fragment_size()
  when block bitmap corrupt (bsc#1222622 CVE-2024-26774).
- commit f7c2563
* Wed Apr 17 2024 jack@suse.cz
- ext4: avoid allocating blocks from corrupted group in
  ext4_mb_try_best_found() (bsc#1222618 CVE-2024-26773).
- commit 920069c
* Wed Apr 17 2024 jbohac@suse.cz
- Refresh
  patches.suse/kdump-implement-reserve_crashkernel_cma.patch.
  (don't print about zero-sized CMA reservation)
- commit 14e6598
* Wed Apr 17 2024 oneukum@suse.com
- Update
  patches.suse/usb-roles-fix-NULL-pointer-issue-when-put-module-s-r.patch
  (bsc#1222609 CVE-2024-26747).
  Added CVE reference
- commit 5db3e1d
* Wed Apr 17 2024 vkarasulli@suse.de
- iommu/vt-d: Fix wrong use of pasid config (git-fixes).
- commit 09ffca7
* Wed Apr 17 2024 vkarasulli@suse.de
- iommu/vt-d: Allocate local memory for page request queue
  (git-fixes).
- commit 9b67401
* Wed Apr 17 2024 msuchanek@suse.de
- powerpc/pseries/iommu: LPAR panics when rebooted with a frozen
  PE (bsc#1222011 ltc#205900).
- commit a6aad75
* Wed Apr 17 2024 mfranc@suse.cz
- Update
  patches.suse/0001-s390-cio-fix-race-condition-during-online-processing.patch
  (bsc#1219485 bsc#1219451).
- Update patches.suse/0001-s390-qdio-handle-deferred-cc1.patch
  (bsc#1219485 bsc#1219451).
- Update
  patches.suse/s390-cio-fix-invalid-EBUSY-on-ccw_device_start.patch
  (git-fixes bsc#1220360 bsc#1219485 bsc#1219451).
- Update patches.suse/s390-qeth-handle-deferred-cc1.patch
  (bsc#1219485 git-fixes bsc#1219451).
- commit 097f888
* Wed Apr 17 2024 osalvador@suse.de
- Update
  patches.suse/fbdev-savage-Error-out-if-pixclock-equals-zero.patch
  (git-fixes CVE-2024-26778 bsc#1222770).
- commit fbfa53e
* Wed Apr 17 2024 osalvador@suse.de
- Update
  patches.suse/fbdev-sis-Error-out-if-pixclock-equals-zero.patch
  (git-fixes CVE-2024-26777 bsc#1222765).
- commit 4648979
* Wed Apr 17 2024 osalvador@suse.de
- Update
  patches.suse/tls-fix-use-after-free-on-failed-backlog-decryption.patch
  (CVE-2024-26584 bsc#1220186 CVE-2024-26800 bsc#1222728).
- commit 6cb76c6
* Tue Apr 16 2024 jbohac@suse.cz
- crash: use macro to add crashk_res into iomem early for specific
  arch (jsc#PED-7249, bsc#1222742).
  Refresh patches.suse/kdump-implement-reserve_crashkernel_cma.patch.
- commit b256f70
* Tue Apr 16 2024 nik.borisov@suse.com
- x86/bugs: Fix BHI documentation (git-fixes).
- commit b981493
* Tue Apr 16 2024 denis.kirjanov@suse.com
- net/sched: taprio: proper TCA_TAPRIO_TC_ENTRY_INDEX check
  (bsc#1222635 CVE-2024-26815).
- commit 0dd110f
* Tue Apr 16 2024 iivanov@suse.de
- spi: cadence-qspi: fix pointer reference in runtime PM hooks (CVE-2024-26807 bsc#1222801)
- commit 5687920
* Tue Apr 16 2024 dwagner@suse.de
- Update
  patches.suse/nvmet-fc-avoid-deadlock-on-delete-association-path.patch
  (git-fixes CVE-2024-26769 bsc#1222727).
- commit 2dfa751
* Tue Apr 16 2024 petr.pavlu@suse.com
- kprobes: Fix double free of kretprobe_holder (bsc#1220901).
- commit 6f75bb6
* Tue Apr 16 2024 tzimmermann@suse.com
- "nouveau: offload fence uevents work to workqueue"
  Reference bug report and CVE number.
- commit 92c99bd
* Tue Apr 16 2024 jgross@suse.com
- xen/events: fix error code in xen_bind_pirq_msi_to_irq()
  (git-fixes).
- commit 05ac0c8
* Tue Apr 16 2024 shung-hsi.yu@suse.com
- xdp: reflect tail increase for MEM_TYPE_XSK_BUFF_POOL
  (bsc#1221303 CVE-2024-26611).
- xsk: fix usage of multi-buffer BPF helpers for ZC XDP
  (bsc#1221303 CVE-2024-26611).
- xsk: recycle buffer in case Rx queue was full (bsc#1221303
  CVE-2024-26611).
- commit c10f182
* Tue Apr 16 2024 nmorey@suse.com
- Update patches.suse/RDMA-srpt-Support-specifying-the-srpt_service_guid-p.patch
  (git-fixes bsc#1222449 CVE-2024-26744)
- Update patches.suse/RDMA-qedr-Fix-qedr_create_user_qp-error-flow.patch
  (git-fixes bsc#1222677 CVE-2024-26743)
- Update patches.suse/IB-hfi1-Fix-sdma.h-tx-num_descs-off-by-one-error.patch
  (git-fixes bsc#1222726 CVE-2024-26766)
- commit 3b16fea
* Tue Apr 16 2024 nmorey@suse.com
- RDMA/cm: add timeout to cm_destroy_id wait (git-fixes)
- commit e7fcab4
* Mon Apr 15 2024 jwiesner@suse.de
- Revert patches.suse/tcp-get-rid-of-sysctl_tcp_adv_win_scale.patch
  (bsc#1220419 bsc#1222656).
- Revert patches.suse/mptcp-fix-rcv-buffer-auto-tuning.patch
  (bsc#1220419 bsc#1222656).
- Refresh
  patches.suse/tcp-reorganize-tcp_sock-fast-path-variables.patch.
  Revert dfa2f0483360 ("tcp: get rid of sysctl_tcp_adv_win_scale") to
  resolve a performance regression in HTML traffic.
- commit e2e7d0b
* Mon Apr 15 2024 krisman@suse.de
- udp: Avoid call to compute_score on multiple sites
  (bsc#1220709).
- commit 78244c6
* Mon Apr 15 2024 jgross@suse.com
- xen/evtchn: avoid WARN() when unbinding an event channel
  (git-fixes).
- commit fe7eef3
* Mon Apr 15 2024 jgross@suse.com
- xen/events: increment refcnt only if event channel is refcounted
  (git-fixes).
- commit af3cb5d
* Mon Apr 15 2024 jgross@suse.com
- xen-netfront: Add missing skb_mark_for_recycle (git-fixes).
- commit 421f313
* Mon Apr 15 2024 jgross@suse.com
- x86/xen: attempt to inflate the memory balloon on PVH
  (git-fixes).
- commit df9367a
* Mon Apr 15 2024 jgross@suse.com
- x86/xen: Add some null pointer checking to smp.c (git-fixes).
- commit f502fc5
* Mon Apr 15 2024 nik.borisov@suse.com
- x86/bugs: Replace CONFIG_SPECTRE_BHI_{ON,OFF} with CONFIG_MITIGATION_SPECTRE_BHI (git-fixes).
- commit 3d18f9a
* Mon Apr 15 2024 nik.borisov@suse.com
- x86/bugs: Remove CONFIG_BHI_MITIGATION_AUTO and spectre_bhi=auto  (git-fixes).
- Update config files.
- commit b2f373b
* Mon Apr 15 2024 nik.borisov@suse.com
- x86/bugs: Fix BHI handling of RRSBA (git-fixes).
- commit 66c46fb
* Mon Apr 15 2024 nik.borisov@suse.com
- x86/bugs: Rename various 'ia32_cap' variables to 'x86_arch_cap_msr' (git-fixes).
- commit 6aec207
* Mon Apr 15 2024 jgross@suse.com
- xen/events: modify internal [un]bind interfaces (git-fixes).
- Refresh
  patches.suse/xen-events-close-evtchn-after-mapping-cleanup.patch.
- commit 77df536
* Mon Apr 15 2024 nik.borisov@suse.com
- x86/bugs: Cache the value of MSR_IA32_ARCH_CAPABILITIES (git-fixes).
- commit 1fdb38f
* Mon Apr 15 2024 nik.borisov@suse.com
- x86/bugs: Fix return type of spectre_bhi_state() (git-fixes).
- commit 13662e2
* Mon Apr 15 2024 jgross@suse.com
- xen/events: drop xen_allocate_irqs_dynamic() (git-fixes).
- commit a93b368
* Mon Apr 15 2024 nik.borisov@suse.com
- x86/bugs: Change commas to semicolons in 'spectre_v2' sysfs file (bsc#1222823).
- Refresh patches.suse/x86-bhi-Add-BHI-mitigation-knob.patch.
- commit 1bc31f7
* Mon Apr 15 2024 nik.borisov@suse.com
- KVM: x86: Add BHI_NO (bsc#1222823).
- commit 07366ce
* Mon Apr 15 2024 nik.borisov@suse.com
- x86/bhi: Mitigate KVM by default (bsc#1222823).
- commit 64cbcbe
* Mon Apr 15 2024 nik.borisov@suse.com
- x86/bhi: Add BHI mitigation knob (bsc#1222823).
- Update config files.
- commit 65ced6f
* Mon Apr 15 2024 nik.borisov@suse.com
- x86/bhi: Enumerate Branch History Injection (BHI) bug (bsc#1222823).
- commit 5ca568d
* Mon Apr 15 2024 jgross@suse.com
- xen/events: remove some simple helpers from events_base.c
  (git-fixes).
- Refresh
  patches.suse/xen-events-close-evtchn-after-mapping-cleanup.patch.
- commit faab65b
* Mon Apr 15 2024 nik.borisov@suse.com
- x86/bhi: Define SPEC_CTRL_BHI_DIS_S (bsc#1222823).
- commit 496b11d
* Mon Apr 15 2024 nik.borisov@suse.com
- x86/bhi: Add support for clearing branch history at syscall entry (bsc#1222823).
- commit dee5dff
* Mon Apr 15 2024 jgross@suse.com
- xen/events: reduce externally visible helper functions
  (git-fixes).
- commit a7834c4
* Mon Apr 15 2024 jgross@suse.com
- xen: evtchn: Allow shared registration of IRQ handers
  (git-fixes).
- commit fac6c90
* Mon Apr 15 2024 tbogendoerfer@suse.de
- Update
  patches.suse/net-pds_core-Fix-possible-double-free-in-error-handl.patch
  (git-fixes CVE-2024-26652 bsc#1222115).
  Added CVE reference.
- commit 070cd49
* Mon Apr 15 2024 tbogendoerfer@suse.de
- Update
  patches.suse/net-atlantic-Fix-DMA-mapping-for-PTP-hwts-ring.patch
  (git-fixes bsc#1222427 CVE-2024-26680).
  Added CVE reference.
- commit 97f0341
* Mon Apr 15 2024 mfranc@suse.cz
- s390/cio: fix race condition during online processing
  (bsc#1219485).
- commit 83d7614
* Mon Apr 15 2024 mfranc@suse.cz
- s390/qdio: handle deferred cc1 (bsc#1219485).
- commit aec0983
* Mon Apr 15 2024 mfranc@suse.cz
- s390/qeth: handle deferred cc1 (bsc#1219485 git-fixes).
- commit 6c10bf2
* Mon Apr 15 2024 mfranc@suse.cz
- Update
  patches.suse/s390-cio-fix-invalid-EBUSY-on-ccw_device_start.patch
  (git-fixes bsc#1220360 bsc#1219485).
- commit 174a4e8
* Mon Apr 15 2024 iivanov@suse.de
- Update patches.suse/mmc-mmci-stm32-fix-DMA-API-overlapping-mappings-warn.patch (git-fixes CVE-2024-26787 bsc#1222781)
- commit 2816ca9
* Mon Apr 15 2024 iivanov@suse.de
- Update patches.suse/dmaengine-fsl-qdma-fix-SoC-may-hang-on-16-byte-unali.patch (git-fixes CVE-2024-26790 bsc#1222784)
- commit 0d6086f
* Mon Apr 15 2024 iivanov@suse.de
- Update patches.suse/spi-hisi-sfc-v3xx-Return-IRQ_NONE-if-no-interrupts-w.patch (git-fixes CVE-2024-26776 bsc#1222764)
- commit ec068f3
* Mon Apr 15 2024 colyli@suse.de
- Delete the disabled patch which breaks KABI now,
  patches.suse/md-bitmap-don-t-use-index-for-pages-backing-the-bitm-d703.patch.
- blacklist.conf: add the above patch commit.
- commit 9b0b89b
* Sun Apr 14 2024 glass.su@suse.com
- dm-raid456, md/raid456: fix a deadlock for dm-raid456 while io concurrent with reshape (bsc#1219596)
  Also update diff context in
  patches.suse/dm-raid-fix-false-positive-for-requeue-needed-during-b25b.patch
- commit 4604cae
* Sat Apr 13 2024 colyli@suse.de
- Update to add bsc#1222531, CVE-2024-26756 references,
  patches.suse/md-Don-t-register-sync_thread-for-reshape-directly-ad39.patch
  (bsc#1219596, bsc#1222531, CVE-2024-26756).
- commit de5884e
* Sat Apr 13 2024 colyli@suse.de
- Update to add bsc#1222531, CVE-2024-26756 references,
  patches.suse/md-Don-t-register-sync_thread-for-reshape-directly-ad39.patch
  (bsc#1219596, bsc#1222531, CVE-2024-26756).
- commit 4150d19
* Sat Apr 13 2024 colyli@suse.de
- Update to add bsc#1222527, CVE-2024-26757 references,
  patches.suse/md-Don-t-ignore-read-only-array-in-md_check_recovery-55a4.patch
  (bsc#1219596, bsc#1222527, CVE-2024-26757).
- commit 67019f2
* Sat Apr 13 2024 colyli@suse.de
- Update to add bsc#1222527, CVE-2024-26757 references,
  patches.suse/md-Don-t-ignore-read-only-array-in-md_check_recovery-55a4.patch
  (bsc#1219596, bsc#1222527, CVE-2024-26757).
- commit 0b6b491
* Sat Apr 13 2024 colyli@suse.de
- Update to add bsc# and CVE tags,
  patches.suse/dm-crypt-dm-verity-disable-tasklets-0a9b.patch
  (bsc#1222416, CVE-2024-26718).
- commit 59bf5a5
* Sat Apr 13 2024 colyli@suse.de
- Update to add bsc# and CVE tags,
  patches.suse/dm-crypt-don-t-modify-the-data-when-using-authentica-50c7.patch
  (bsc#1222720, CVE-2024-26763).
- commit 710cd5e
* Sat Apr 13 2024 lduncan@suse.com
- scsi: target: pscsi: Fix bio_put() for error case (bsc#1222596
  cve-2024-267600).
- commit a67c294
* Fri Apr 12 2024 vkarasulli@suse.de
- iommufd/iova_bitmap: Bounds check mapped::pages access
  (git-fixes).
- commit b7fc473
* Fri Apr 12 2024 vkarasulli@suse.de
- iommufd: Reject non-zero data_type if no data_len is provided
  (git-fixes).
- commit ceca619
* Fri Apr 12 2024 vkarasulli@suse.de
- iommu/vt-d: Update iotlb in nested domain attach (git-fixes).
- commit e2cf9d1
* Fri Apr 12 2024 vkarasulli@suse.de
- iommu/arm-smmu-v3: Check that the RID domain is S1 in SVA
  (git-fixes).
- commit 200d970
* Fri Apr 12 2024 shung-hsi.yu@suse.com
- selftests/bpf: Test racing between bpf_timer_cancel_and_free
  and bpf_timer_cancel (bsc#1222557 CVE-2024-26737).
- bpf: Fix racing between bpf_timer_cancel_and_free and
  bpf_timer_cancel (bsc#1222557 CVE-2024-26737).
- commit 24333b7
* Fri Apr 12 2024 iivanov@suse.de
- Update patches.suse/ARM-ep93xx-Add-terminator-to-gpiod_lookup_table.patch (git-fixes CVE-2024-26751 bsc#1222724)
- commit a85b7fa
* Fri Apr 12 2024 shung-hsi.yu@suse.com
- bpf, sockmap: Fix NULL pointer dereference in
  sk_psock_verdict_data_ready() (bsc#1222371 CVE-2024-26731).
- commit 9a8765c
* Fri Apr 12 2024 denis.kirjanov@suse.com
- netlink: Fix kernel-infoleak-after-free in __skb_datagram_iter
  (bsc#1222630 CVE-2024-26805).
- commit 8e8585b
* Fri Apr 12 2024 iivanov@suse.de
- Update patches.suse/dmaengine-ti-edma-Add-some-null-pointer-checks-to-th.patch (git-fixes CVE-2024-26771 bsc#1222610)
- commit b7bab4f
* Fri Apr 12 2024 mhocko@suse.com
- Update
  patches.suse/gtp-fix-use-after-free-and-null-ptr-deref-in-gtp_gen.patch
  (git-fixes CVE-2024-26754 bsc#1222632).
- commit 0bddcea
* Fri Apr 12 2024 mhocko@suse.com
- Update
  patches.suse/crypto-arm64-neonbs-fix-out-of-bounds-access-on-shor.patch
  (git-fixes CVE-2024-26789 bsc#1222626).
- commit 9c3828e
* Fri Apr 12 2024 dfaggioli@suse.com
- KVM: arm64: pmu: Resync EL0 state on counter rotation
  (bsc#1219475).
- commit 99d8e75
* Fri Apr 12 2024 trenn@suse.com
- tools/power/turbostat: Fix uncore frequency file string
  (bsc#1221765).
- commit dfd2a8e
* Thu Apr 11 2024 dfaggioli@suse.com
- KVM: arm64: Always invalidate TLB for stage-2 permission faults
  (bsc#1219478).
- commit d1d5006
* Thu Apr 11 2024 mhocko@suse.com
- Update
  patches.suse/usb-cdns3-fixed-memory-use-after-free-at-cdns3_gadge.patch
  (git-fixes CVE-2024-26749 bsc#1222680).
- commit 25b429b
* Thu Apr 11 2024 mhocko@suse.com
- Update
  patches.suse/powerpc-pseries-iommu-IOMMU-table-is-not-initialized.patch
  (bsc#1220492 ltc#205270 CVE-2024-26745 bsc#1222678).
- commit 589b808
* Thu Apr 11 2024 mhocko@suse.com
- Update
  patches.suse/l2tp-pass-correct-message-length-to-ip6_append_data.patch
  (bsc#1220419 CVE-2024-26752 bsc#1222667).
- commit 2f09d95
* Thu Apr 11 2024 jslaby@suse.cz
- tty: n_gsm: require CAP_NET_ADMIN to attach N_GSM0710 ldisc
  (bsc#1222619).
- commit 3d5abbd
* Thu Apr 11 2024 mhocko@suse.com
- Update
  patches.suse/crypto-arm64-neonbs-fix-out-of-bounds-access-on-shor.patch
  (git-fixes CVE-2024-26789).
- commit 98918ce
* Wed Apr 10 2024 mkubecek@suse.cz
- arp: Prevent overflow in arp_req_get() (CVE-2024-26733
  bsc#1222585).
- commit 2f8c9e8
* Wed Apr 10 2024 mkubecek@suse.cz
- net/sched: act_mirred: use the backlog for mirred ingress
  (CVE-2024-26740 bsc#1222563).
- refresh:
  - patches.suse/net-sched-act_mirred-don-t-override-retval-if-we-alr.patch
- commit b1920f0
* Wed Apr 10 2024 mkubecek@suse.cz
- net/sched: act_mirred: don't override retval if we already
  lost the skb (CVE-2024-26733 bsc#1222585).
- net/sched: act_mirred: Create function tcf_mirred_to_dev and
  improve readability (CVE-2024-26733 bsc#1222585).
- commit 805fd21
* Wed Apr 10 2024 oneukum@suse.com
- Update
  patches.suse/usb-cdns3-fix-memory-double-free-when-handle-zero-pa.patch
  (bsc#1222513 CVE-2024-26748).
  Added CVE references
- commit 7c3ca16
* Wed Apr 10 2024 oneukum@suse.com
- Update
  patches.suse/usb-dwc3-gadget-Fix-NULL-pointer-dereference-in-dwc3.patch
  (bsc#1222561 CVE-2024-26715).
  Added CVE reference
- commit f58a80f
* Wed Apr 10 2024 osalvador@suse.de
- mm,page_owner: Defer enablement of static branch (bsc#1222366).
- commit a442fcd
* Wed Apr 10 2024 petr.pavlu@suse.com
- ring-buffer: Make wake once of ring_buffer_wait() more robust
  (git-fixes).
- commit 3cff1f5
* Wed Apr 10 2024 petr.pavlu@suse.com
- tracing: Have saved_cmdlines arrays all in one allocation
  (git-fixes).
- commit 8871703
* Wed Apr 10 2024 petr.pavlu@suse.com
- tracing/ring-buffer: Fix wait_on_pipe() race (git-fixes).
- kABI: Adjust trace_iterator.wait_index (git-fixes).
- commit 503fcea
* Wed Apr 10 2024 mhocko@suse.com
- Update
  patches.suse/powerpc-pseries-iommu-DLPAR-add-doesn-t-completely-i.patch
  (bsc#1215199 bsc#1219077 ltc#204477 CVE-2024-26738).
- commit d6e4ef3
* Wed Apr 10 2024 mhocko@suse.com
- Update
  patches.suse/drm-amd-display-Fix-array-index-out-of-bounds-in-dcn.patch
  (git-fixes CVE-2024-26699 bsc#1222602).
- commit f52d16e
* Wed Apr 10 2024 denis.kirjanov@suse.com
- igc: Remove stale comment about Tx timestamping (git-fixes).
- commit 83821ed
* Wed Apr 10 2024 denis.kirjanov@suse.com
- ixgbe: avoid sleeping allocation in ixgbe_ipsec_vf_add_sa()
  (git-fixes).
- commit aab4796
* Wed Apr 10 2024 mhocko@suse.com
- Update
  patches.suse/crypto-virtio-akcipher-Fix-stack-overflow-on-memcpy.patch
  (git-fixes CVE-2024-26753 bsc#1222601).
- commit 0099199
* Wed Apr 10 2024 denis.kirjanov@suse.com
- ice: fix memory corruption bug with suspend and rebuild
  (git-fixes).
- commit 5927273
* Wed Apr 10 2024 denis.kirjanov@suse.com
- ice: Refactor FW data type and fix bitmap casting issue
  (git-fixes).
- commit ddf5e8c
* Wed Apr 10 2024 denis.kirjanov@suse.com
- mlxbf_gige: call request_irq() after NAPI initialized
  (git-fixes).
- commit 39b7ae3
* Wed Apr 10 2024 denis.kirjanov@suse.com
- net: hns3: mark unexcuted loopback test result as UNEXECUTED
  (git-fixes).
- commit 88d4f13
* Wed Apr 10 2024 denis.kirjanov@suse.com
- net: hns3: fix kernel crash when devlink reload during pf
  initialization (git-fixes).
- commit 5900fb4
* Wed Apr 10 2024 denis.kirjanov@suse.com
- net: hns3: fix index limit to support all queue stats
  (git-fixes).
- commit fcda370
* Wed Apr 10 2024 denis.kirjanov@suse.com
- mlxbf_gige: stop PHY during open() error paths (git-fixes).
- commit 087df13
* Wed Apr 10 2024 denis.kirjanov@suse.com
- net: dsa: mt7530: fix handling of all link-local frames
  (git-fixes).
- commit 62930ae
* Wed Apr 10 2024 denis.kirjanov@suse.com
- net: dsa: mt7530: fix link-local frames that ingress vlan
  filtering ports (git-fixes).
- commit 7b1c501
* Wed Apr 10 2024 lhenriques@suse.de
- ceph: stop copying to iter at EOF on sync reads (bsc#1222606).
- commit 6d8bd5d
* Wed Apr 10 2024 ailiop@suse.com
- dlm: fix user space lkb refcounting (git-fixes).
- commit 26e28b8
* Wed Apr 10 2024 lhenriques@suse.de
- Update
  patches.suse/ceph-prevent-use-after-free-in-encode_cap_msg.patch
  (bsc#1221391 CVE-2024-26689).
- commit 05ffdb2
* Wed Apr 10 2024 ailiop@suse.com
- ubifs: Queue up space reservation tasks if retrying many times
  (git-fixes).
- commit 44bfcee
* Wed Apr 10 2024 ailiop@suse.com
- ubifs: dbg_check_idx_size: Fix kmemleak if loading znode failed
  (git-fixes).
- commit 9a4ebd6
* Wed Apr 10 2024 ailiop@suse.com
- ubifs: Remove unreachable code in dbg_check_ltab_lnum
  (git-fixes).
- commit f4e5ca1
* Wed Apr 10 2024 ailiop@suse.com
- ubifs: fix sort function prototype (git-fixes).
- commit f7d0a9f
* Wed Apr 10 2024 ailiop@suse.com
- ubifs: Set page uptodate in the correct place (git-fixes).
- commit aa187f8
* Wed Apr 10 2024 ailiop@suse.com
- Update
  patches.suse/afs-Increase-buffer-size-in-afs_update_volume_status.patch
  (git-fixes CVE-2024-26736 bsc#1222586).
- commit 06c0c6c
* Tue Apr  9 2024 mhocko@suse.com
- Update
  patches.suse/btrfs-do-not-ASSERT-if-the-newly-created-subvolume-a.patch
  (bsc#1219126 CVE-2024-26727 bsc#1222536).
- commit 7bb93e9
* Tue Apr  9 2024 ailiop@suse.com
- Update
  patches.suse/nilfs2-fix-hang-in-nilfs_lookup_dirty_data_buffers.patch
  (git-fixes CVE-2024-26696 bsc#1222549).
- commit 932abcf
* Tue Apr  9 2024 ailiop@suse.com
- Update
  patches.suse/nilfs2-fix-data-corruption-in-dsync-block-recovery-f.patch
  (git-fixes CVE-2024-26697 bsc#1222550).
- commit fa7ddf4
* Tue Apr  9 2024 mhocko@suse.com
- Update
  patches.suse/net-mlx5-DPLL-Fix-possible-use-after-free-after-dela.patch
  (git-fixes CVE-2024-26724 bsc#1222523).
- commit bb60edc
* Tue Apr  9 2024 mhocko@suse.com
- Update
  patches.suse/ASoC-rt5645-Fix-deadlock-in-rt5645_jack_detect_work.patch
  (git-fixes CVE-2024-26722 bsc#1222520).
- commit f0aaca0
* Tue Apr  9 2024 tbogendoerfer@suse.de
- net: stmmac: xgmac: use #define for string constants
  (bsc#1222445 CVE-2024-26684).
- net: stmmac: xgmac: fix a typo of register name in DPP safety
  handling (bsc#1222445 CVE-2024-26684).
- commit 75e180f
* Tue Apr  9 2024 jack@suse.cz
- ext4: fix double-free of blocks due to wrong extents moved_len
  (bsc#1222422 CVE-2024-26704).
- commit ff97911
* Tue Apr  9 2024 denis.kirjanov@suse.com
- Update
  patches.suse/netdevsim-avoid-potential-loop-in-nsim_dev_trap_repo.patch
  (git-fixes CVE-2024-26681 bsc#1222431).
- commit 12b3ceb
* Tue Apr  9 2024 mkoutny@suse.com
- mm: memcg: don't periodically flush stats when memcg is disabled
  (bsc#1222525).
- commit 5b28bba
* Tue Apr  9 2024 mkoutny@suse.com
- mm: memcg: use larger batches for proactive reclaim
  (bsc#1222522).
- commit b1effac
* Tue Apr  9 2024 tbogendoerfer@suse.de
- net: stmmac: xgmac: fix handling of DPP safety error for DMA
  channels (bsc#1222445 CVE-2024-26684).
- commit a8e5095
* Tue Apr  9 2024 tbogendoerfer@suse.de
- Update
  patches.suse/gtp-fix-use-after-free-and-null-ptr-deref-in-gtp_new.patch
  (bsc#1222428 CVE-2024-26793).
  Added CVE reference.
- commit 956dfa1
* Tue Apr  9 2024 mhocko@suse.com
- Update patches.suse/wifi-iwlwifi-fix-double-free-bug.patch
  (git-fixes CVE-2024-26694 bsc#1222466).
- commit 5048255
* Tue Apr  9 2024 osalvador@suse.de
- mm,page_owner: Fix printing of stack records (bsc#1222366).
- commit 18c2e4e
* Tue Apr  9 2024 osalvador@suse.de
- mm,page_owner: Fix accounting of pages when migrating
  (bsc#1222366).
- commit aaa0270
* Tue Apr  9 2024 osalvador@suse.de
- mm,page_owner: Fix refcount imbalance (bsc#1222366).
- commit f6d6769
* Tue Apr  9 2024 osalvador@suse.de
- mm,page_owner: Update metadata for tail pages (bsc#1222366).
- commit 6f3c7f1
* Tue Apr  9 2024 osalvador@suse.de
- fs,hugetlb: fix NULL pointer dereference in hugetlbs_fill_super
  (bsc#1219264 CVE-2024-0841).
- commit 440934e
* Mon Apr  8 2024 ailiop@suse.com
- Update
  patches.suse/nilfs2-fix-potential-bug-in-end_buffer_async_write.patch
  (git-fixes CVE-2024-26685 bsc#1222437).
- commit f659b7a
* Mon Apr  8 2024 jack@suse.cz
- nfsd: Fix error cleanup path in nfsd_rename() (bsc#1221044
  CVE-2023-52591).
- commit e2fc972
* Mon Apr  8 2024 denis.kirjanov@suse.com
- octeontx2-af: Use separate handlers for interrupts (git-fixes).
- commit fdf696d
* Mon Apr  8 2024 denis.kirjanov@suse.com
- octeontx2-pf: Send UP messages to VF only when VF is up
  (git-fixes).
- commit e9223ab
* Mon Apr  8 2024 denis.kirjanov@suse.com
- octeontx2-pf: Use default max_active works instead of one
  (git-fixes).
- commit e2c337f
* Mon Apr  8 2024 denis.kirjanov@suse.com
- octeontx2-pf: Wait till detach_resources msg is complete
  (git-fixes).
- commit e377bd9
* Mon Apr  8 2024 denis.kirjanov@suse.com
- octeontx2: Detect the mbox up or down message via register
  (git-fixes).
- commit 9554388
* Mon Apr  8 2024 denis.kirjanov@suse.com
- net: phy: fix phy_read_poll_timeout argument type in
  genphy_loopback (git-fixes).
- commit 0a16435
* Mon Apr  8 2024 denis.kirjanov@suse.com
- wireguard: netlink: access device through ctx instead of peer
  (git-fixes).
- commit 42d72df
* Mon Apr  8 2024 denis.kirjanov@suse.com
- wireguard: netlink: check for dangling peer via is_dead instead
  of empty list (git-fixes).
- commit a1c80d8
* Mon Apr  8 2024 denis.kirjanov@suse.com
- wireguard: receive: annotate data-race around
  receiving_counter.counter (git-fixes).
- commit 17fcb7b
* Mon Apr  8 2024 denis.kirjanov@suse.com
- net: dsa: mt7530: prevent possible incorrect XTAL frequency
  selection (git-fixes).
- commit 3804285
* Mon Apr  8 2024 oneukum@suse.com
- usb: dwc3-am62: Disable wakeup at remove (git-fixes).
- commit d52ac96
* Mon Apr  8 2024 denis.kirjanov@suse.com
- net: veth: do not manipulate GRO when using XDP (git-fixes).
- commit 15eca84
* Mon Apr  8 2024 oneukum@suse.com
- usb: dwc3-am62: fix module unload/reload behavior (git-fixes).
- commit 6f51a6a
* Mon Apr  8 2024 oneukum@suse.com
- usb: dwc3-am62: Rename private data (git-fixes).
- commit 7196cb2
* Mon Apr  8 2024 oneukum@suse.com
- net: smsc95xx: add support for SYS TEC USB-SPEmodule1
  (git-fixes).
- commit 9896f5f
* Mon Apr  8 2024 osalvador@suse.de
- mm,page_owner: fix recursion (bsc#1222366).
- commit 297023a
* Mon Apr  8 2024 petr.pavlu@suse.com
- ring-buffer: Use wait_event_interruptible() in
  ring_buffer_wait() (git-fixes).
- commit 20eed3f
* Mon Apr  8 2024 petr.pavlu@suse.com
- ring-buffer: Fix full_waiters_pending in poll (git-fixes).
- commit 76c6893
* Mon Apr  8 2024 osalvador@suse.de
- mm,page_owner: drop unnecessary check (bsc#1222366).
- commit 233b383
* Mon Apr  8 2024 osalvador@suse.de
- mm,page_owner: check for null stack_record before bumping its
  refcount (bsc#1222366).
- commit 232b11a
* Mon Apr  8 2024 petr.pavlu@suse.com
- ring-buffer: Do not set shortest_full when full target is hit
  (git-fixes).
- commit 9d2e0c0
* Mon Apr  8 2024 petr.pavlu@suse.com
- tracing: Use .flush() call to wake up readers (git-fixes).
- commit ae4cfa5
* Mon Apr  8 2024 petr.pavlu@suse.com
- ring-buffer: Fix resetting of shortest_full (git-fixes).
- commit eec6028
* Mon Apr  8 2024 iivanov@suse.de
- arm64/ptrace: Use saved floating point state type to determine SVE (git-fixes)
- commit 7892aeb
* Mon Apr  8 2024 iivanov@suse.de
- bpf, arm64: fix bug in BPF_LDX_MEMSX (git-fixes)
- commit 8894bd2
* Mon Apr  8 2024 iivanov@suse.de
- arm64: dts: broadcom: bcmbca: bcm4908: drop invalid switch cells (git-fixes)
- commit c68c0f5
* Mon Apr  8 2024 iivanov@suse.de
- arm64: dts: marvell: reorder crypto interrupts on Armada SoCs (git-fixes)
- commit 193e8cd
* Mon Apr  8 2024 iivanov@suse.de
- arm64: tegra: Set the correct PHY mode for MGBE (git-fixes)
- commit 68a4464
* Mon Apr  8 2024 iivanov@suse.de
- arm64: dts: Fix dtc interrupt_provider warnings (git-fixes)
- commit 41dcf37
* Mon Apr  8 2024 iivanov@suse.de
- arm64/sve: Lower the maximum allocation for the SVE ptrace regset (git-fixes)
- commit e1e7f29
* Mon Apr  8 2024 ohering@suse.de
- net: mana: Fix Rx DMA datasize and skb_over_panic (git-fixes).
- x86/hyperv: Use per cpu initial stack for vtl context
  (git-fixes).
- RDMA/mana_ib: Fix bug in creation of dma regions (git-fixes).
- PCI: hv: Fix ring buffer size calculation (git-fixes).
- x86/hyperv: Allow 15-bit APIC IDs for VTL platforms (git-fixes).
- commit ff0ef0f
* Mon Apr  8 2024 petr.pavlu@suse.com
- ring-buffer: Fix waking up ring buffer readers (git-fixes).
- commit 0457e87
* Mon Apr  8 2024 mgorman@suse.de
- sched/fair: Use helper functions to access root_domain::overload
  (bsc#1222173).
- sched/fair: Check root_domain::overload value before update
  (bsc#1222173).
- sched/balancing: Rename newidle_balance() =>
  sched_balance_newidle() (bsc#1222173).
- commit bfceb46
* Mon Apr  8 2024 petr.pavlu@suse.com
- tracing: Remove precision vsnprintf() check from print event
  (git-fixes).
- commit 84653fa
* Mon Apr  8 2024 petr.pavlu@suse.com
- tracing/net_sched: Fix tracepoints that save qdisc_dev()
  as a string (git-fixes).
- commit 623f97a
* Sat Apr  6 2024 tiwai@suse.de
- ALSA: hda/realtek: Add quirks for ASUS Laptops using CS35L56
  (stable-fixes).
- ALSA: hda/realtek: Add quirks for some Clevo laptops
  (stable-fixes).
- ALSA: hda/realtek: Add quirk for HP Spectre x360 14 eu0000
  (stable-fixes).
- ALSA: hda/realtek: fix the hp playback volume issue for LG
  machines (stable-fixes).
- commit dc89a62
* Sat Apr  6 2024 tiwai@suse.de
- ALSA: hda/realtek: cs35l41: Support ASUS ROG G634JYR
  (stable-fixes).
- ALSA: hda/realtek: Add sound quirks for Lenovo Legion slim 7
  16ARHA7 models (stable-fixes).
- ALSA: hda/realtek - Fix inactive headset mic jack
  (stable-fixes).
- commit 048c9fd
* Sat Apr  6 2024 tiwai@suse.de
- spi: mchp-pci1xxx: Fix a possible null pointer dereference in
  pci1xxx_spi_probe (git-fixes).
- spi: spi-fsl-lpspi: remove redundant spi_controller_put call
  (git-fixes).
- regmap: maple: Fix uninitialized symbol 'ret' warnings
  (git-fixes).
- regmap: maple: Fix cache corruption in regcache_maple_drop()
  (git-fixes).
- ata: sata_mv: Fix PCI device ID table declaration compilation
  warning (git-fixes).
- ata: sata_sx4: fix pdc20621_get_from_dimm() on 64-bit
  (git-fixes).
- ASoC: wm_adsp: Fix missing mutex_lock in wm_adsp_write_ctl()
  (git-fixes).
- ASoC: amd: acp: fix for acp_init function error handling
  (git-fixes).
- ASoC: rt722-sdca-sdw: fix locking sequence (git-fixes).
- ASoC: rt712-sdca-sdw: fix locking sequence (git-fixes).
- ASoC: rt711-sdw: fix locking sequence (git-fixes).
- ASoC: rt711-sdca: fix locking sequence (git-fixes).
- ASoC: rt5682-sdw: fix locking sequence (git-fixes).
- ASoC: ops: Fix wraparound for mask in snd_soc_get_volsw
  (git-fixes).
- ALSA: hda/realtek: Update Panasonic CF-SZ6 quirk to support
  headset with microphone (git-fixes).
- ASoC: tas2781: mark dvc_tlv with __maybe_unused (git-fixes).
- ALSA: hda: cs35l56: Add ACPI device match tables (git-fixes).
- drm/i915/mst: Reject FEC+MST on ICL (git-fixes).
- drm/i915/mst: Limit MST+DSC to TGL+ (git-fixes).
- drm/i915/dp: Fix the computation for compressed_bpp for DISPLAY
  < 13 (git-fixes).
- drm/i915/gt: Enable only one CCS for compute workload
  (git-fixes).
- drm/i915/gt: Do not generate the command streamer for all the
  CCS (git-fixes).
- drm/i915/gt: Disable HW load balancing for CCS (git-fixes).
- drm/i915/dp: Remove support for UHBR13.5 (git-fixes).
- drm/display: fix typo (git-fixes).
- drm/prime: Unbreak virtgpu dma-buf export (git-fixes).
- nouveau/uvmm: fix addr/range calcs for remap operations
  (git-fixes).
- drm/panfrost: fix power transition timeout warnings (git-fixes).
- commit 7455674
* Sat Apr  6 2024 tiwai@suse.de
- Delete patches.suse/counter-fix-privdata-alignment.patch
  This actually breaks the build when CONFIG_COUNTER=y
- commit b8cad45
* Fri Apr  5 2024 mfranc@suse.cz
- Update
  patches.suse/ALSA-sh-aica-reorder-cleanup-operations-to-avoid-UAF.patch
  (git-fixes CVE-2024-26654 bsc#1222304).
- Update patches.suse/drm-amdgpu-fix-use-after-free-bug.patch
  (stable-fixes CVE-2024-26656 bsc#1222307).
- Update
  patches.suse/drm-sched-fix-null-ptr-deref-in-init-entity.patch
  (git-fixes CVE-2024-26657 bsc#1222273).
- Update
  patches.suse/net-pds_core-Fix-possible-double-free-in-error-handl.patch
  (git-fixes CVE-2024-26652 bsc#1222115).
- Update patches.suse/ppp_async-limit-MRU-to-64K.patch (git-fixes
  CVE-2024-26675 bsc#1222379).
- commit 05edc93
* Fri Apr  5 2024 mfranc@suse.cz
- Update
  patches.suse/HID-i2c-hid-of-fix-NULL-deref-on-failed-power-up.patch
  (git-fixes CVE-2024-26717 bsc#1222360).
- Update
  patches.suse/arm64-entry-fix-ARM64_WORKAROUND_SPECULATIVE_UNPRIV_LOAD.patch
  (git-fixes CVE-2024-26670 bsc#1222356).
- Update
  patches.suse/crypto-ccp-Fix-null-pointer-dereference-in-__sev_pla.patch
  (git-fixes CVE-2024-26695 bsc#1222373).
- Update
  patches.suse/dpll-fix-possible-deadlock-during-netlink-dump-opera.patch
  (jsc#PED-6079 CVE-2024-26725 bsc#1222369).
- Update
  patches.suse/drm-amd-display-Add-NULL-test-for-timing-generator-i.patch
  (git-fixes CVE-2024-26661 bsc#1222323).
- Update
  patches.suse/drm-amd-display-Fix-panel_cntl-could-be-null-in-dcn2.patch
  (git-fixes CVE-2024-26662 bsc#1222324).
- Update
  patches.suse/drm-amd-display-Implement-bounds-check-for-stream-en.patch
  (git-fixes CVE-2024-26660 bsc#1222266).
- Update
  patches.suse/drm-amd-display-fix-null-pointer-dereference-on-edid.patch
  (git-fixes CVE-2024-26728 bsc#1222370).
- Update
  patches.suse/drm-amdgpu-Fix-variable-mca_funcs-dereferenced-befor.patch
  (git-fixes CVE-2024-26672 bsc#1222358).
- Update
  patches.suse/drm-i915-dsc-Fix-the-macro-that-calculates-DSCC_-DSC.patch
  (git-fixes CVE-2024-26721 bsc#1222365).
- Update
  patches.suse/drm-msm-dpu-check-for-valid-hw_pp-in-dpu_encoder_hel.patch
  (git-fixes CVE-2024-26667 bsc#1222331).
- Update
  patches.suse/hwmon-coretemp-Fix-out-of-bounds-memory-access.patch
  (git-fixes CVE-2024-26664 bsc#1222355).
- Update
  patches.suse/lan966x-Fix-crash-when-adding-interface-under-a-lag.patch
  (git-fixes CVE-2024-26723 bsc#1222367).
- Update
  patches.suse/mm-writeback-fix-possible-divide-by-zero-in-wb_dirty_limits-again.patch
  (git-fixes CVE-2024-26720 bsc#1222364).
- Update
  patches.suse/msft-hv-2940-hv_netvsc-Fix-race-condition-between-netvsc_probe-an.patch
  (git-fixes CVE-2024-26698 bsc#1222374).
- Update
  patches.suse/sr9800-Add-check-for-usbnet_get_endpoints.patch
  (git-fixes CVE-2024-26651 bsc#1221337).
- Update
  patches.suse/usb-core-Prevent-null-pointer-dereference-in-update_.patch
  (git-fixes CVE-2024-26716 bsc#1222359).
- Update
  patches.suse/wifi-mac80211-fix-RCU-use-in-TDLS-fast-xmit.patch
  (git-fixes CVE-2024-26666 bsc#1222293).
- Update
  patches.suse/xhci-handle-isoc-Babble-and-Buffer-Overrun-events-pr.patch
  (git-fixes CVE-2024-26659 bsc#1222317).
- commit 967a843
* Fri Apr  5 2024 mfranc@suse.cz
- Update
  patches.suse/KVM-s390-vsie-fix-race-during-shadow-creation.patch
  (git-fixes bsc#1219810 CVE-2023-52639 bsc#1222300).
- Update
  patches.suse/can-j1939-Fix-UAF-in-j1939_sk_match_filter-during-se.patch
  (git-fixes CVE-2023-52637 bsc#1222291).
- Update
  patches.suse/can-j1939-prevent-deadlock-by-changing-j1939_socks_l.patch
  (git-fixes CVE-2023-52638 bsc#1222299).
- Update
  patches.suse/drm-amd-display-Fix-disable_otg_wa-logic.patch
  (git-fixes CVE-2023-52634 bsc#1222278).
- Update
  patches.suse/drm-amd-display-Refactor-DMCUB-enter-exit-idle-inter.patch
  (git-fixes CVE-2023-52625 bsc#1222085).
- Update
  patches.suse/drm-amd-display-Wake-DMCUB-before-executing-GPINT-co.patch
  (git-fixes CVE-2023-52624 bsc#1222083).
- Update
  patches.suse/drm-amdkfd-Fix-lock-dependency-warning-with-srcu.patch
  (git-fixes CVE-2023-52632 bsc#1222274).
- Update
  patches.suse/libceph-just-wait-for-more-data-to-be-available-on-th.patch
  (bsc#1221390 CVE-2023-52636 bsc#1222247).
- Update
  patches.suse/netfilter-nftables-exthdr-fix-4-byte-stack-OOB-write.patch
  (CVE-2023-4881 bsc#1215221 CVE-2023-52628 bsc#1222117).
- commit dc877fc
* Fri Apr  5 2024 tiwai@suse.de
- net: usb: ax88179_178a: avoid the interface always configured
  as random address (git-fixes).
- net: phy: micrel: lan8814: Fix when enabling/disabling 1-step
  timestamping (git-fixes).
- r8169: fix issue caused by buggy BIOS on certain boards with
  RTL8168d (git-fixes).
- ax25: fix use-after-free bugs caused by ax25_ds_del_timer
  (git-fixes).
- net: phy: micrel: Fix potential null pointer dereference
  (git-fixes).
- Bluetooth: Fix TOCTOU in HCI debugfs implementation (git-fixes).
- Bluetooth: hci_sync: Fix not checking error on
  hci_cmd_sync_cancel_sync (git-fixes).
- Bluetooth: qca: fix device-address endianness (git-fixes).
- Bluetooth: add quirk for broken address properties (git-fixes).
- r8169: skip DASH fw status checks when DASH is disabled
  (git-fixes).
- commit 8be20da
* Fri Apr  5 2024 tiwai@suse.de
- kasan: disable kasan_non_canonical_hook() for HW tags
  (git-fixes).
- commit 0d24410
* Thu Apr  4 2024 jack@suse.cz
- selinux: saner handling of policy reloads (bsc#1222230).
- commit 35fdf2d
* Thu Apr  4 2024 tiwai@suse.de
- kabi/severities: ignore brcmfmac-specific local symbols
- commit 4492559
* Thu Apr  4 2024 ailiop@suse.com
- fs/ntfs3: Fix oob in ntfs_listxattr (bsc#1222301
  CVE-2023-52640).
- commit eaa4525
* Thu Apr  4 2024 mbrugger@suse.com
- tee: amdtee: fix use-after-free vulnerability in
  amdtee_close_session (bsc#1220915 CVE-2023-52503).
- commit 861ab74
* Thu Apr  4 2024 denis.kirjanov@suse.com
- net: ethernet: mtk_eth_soc: fix PPE hanging issue (git-fixes).
- commit 57f3e15
* Thu Apr  4 2024 denis.kirjanov@suse.com
- net: mediatek: mtk_eth_soc: clear MAC_MCR_FORCE_LINK only when
  MAC is up (git-fixes).
- commit 19afa38
* Thu Apr  4 2024 denis.kirjanov@suse.com
- octeontx2-af: Use matching wake_up API variant in CGX command
  interface (git-fixes).
- commit 4f98ac2
* Thu Apr  4 2024 denis.kirjanov@suse.com
- net: hns3: tracing: fix hclgevf trace event strings (git-fixes).
- commit 786a967
* Thu Apr  4 2024 denis.kirjanov@suse.com
- nfp: flower: handle acti_netdevs allocation failure (git-fixes).
- commit e441ee8
* Thu Apr  4 2024 denis.kirjanov@suse.com
- ice: fix stats being updated by way too large values
  (git-fixes).
- commit a2ff54d
* Thu Apr  4 2024 denis.kirjanov@suse.com
- igb: Fix missing time sync events (git-fixes).
- commit 0cd215b
* Thu Apr  4 2024 denis.kirjanov@suse.com
- igc: Fix missing time sync events (git-fixes).
- commit f2d41db
* Thu Apr  4 2024 tiwai@suse.de
- staging: vc04_services: changen strncpy() to strscpy_pad()
  (stable-fixes).
- Refresh
  patches.suse/staging-vc04_services-fix-information-leak-in-create.patch.
- commit f661a45
* Thu Apr  4 2024 tiwai@suse.de
- drm/amd/display: Remove MPC rate control logic from DCN30 and
  above (stable-fixes).
- commit 264c256
* Thu Apr  4 2024 tiwai@suse.de
- wifi: iwlwifi: pcie: fix RB status reading (stable-fixes).
- Refresh
  patches.suse/wifi-iwlwifi-pcie-add-another-missing-bh-disable-for.patch.
- commit 9937396
* Thu Apr  4 2024 tiwai@suse.de
- vboxsf: Avoid an spurious warning if load_nls_xxx() fails
  (git-fixes).
- USB: core: Fix deadlock in port "disable" sysfs attribute
  (stable-fixes).
- USB: core: Add hub_get() and hub_put() routines (stable-fixes).
- usb: typec: ucsi: Clear UCSI_CCI_RESET_COMPLETE before reset
  (stable-fixes).
- usb: typec: ucsi: Ack unsupported commands (stable-fixes).
- usb: udc: remove warning when queue disabled ep (stable-fixes).
- Revert "usb: phy: generic: Get the vbus supply" (git-fixes).
- USB: UAS: return ENODEV when submit urbs fail with device not
  attached (stable-fixes).
- drm/i915/bios: Tolerate devdata==NULL in
  intel_bios_encoder_supports_dp_dual_mode() (stable-fixes).
- drm/amd/display: Set DCN351 BB and IP the same as DCN35
  (stable-fixes).
- drm/amd/display: Fix bounds check for dcn35 DcfClocks
  (git-fixes).
- drm/amdkfd: fix TLB flush after unmap for GFX9.4.2
  (stable-fixes).
- drm/amd/display: Prevent crash when disable stream
  (stable-fixes).
- wifi: mac80211: check/clear fast rx for non-4addr sta VLAN
  changes (stable-fixes).
- drm/amd/display: Fix noise issue on HDMI AV mute (stable-fixes).
- drm/amd/display: Return the correct HDCP error code
  (stable-fixes).
- drm/amd/display: Fix idle check for shared firmware state
  (stable-fixes).
- drm/amd/display: Update odm when ODM combine is changed on an
  otg master pipe with no plane (stable-fixes).
- drm/amd/display: Init DPPCLK from SMU on dcn32 (stable-fixes).
- drm/amd/display: Allow dirty rects to be sent to dmub when
  abm is active (stable-fixes).
- drm/amd/display: Override min required DCFCLK in dml1_validate
  (stable-fixes).
- drm/amdgpu: amdgpu_ttm_gart_bind set gtt bound flag
  (stable-fixes).
- drm/amd/display: Change default size for dummy plane in DML2
  (stable-fixes).
- drm/amdgpu: fix use-after-free bug (stable-fixes).
- drm/amd/display: Use freesync when
  `DRM_EDID_FEATURE_CONTINUOUS_FREQ` found (stable-fixes).
- drm/vc4: hdmi: do not return negative values from .get_modes()
  (stable-fixes).
- drm/imx/ipuv3: do not return negative values from .get_modes()
  (stable-fixes).
- drm/exynos: do not return negative values from .get_modes()
  (stable-fixes).
- drm/panel: do not return negative error codes from
  drm_panel_get_modes() (stable-fixes).
- drm/probe-helper: warn about negative .get_modes()
  (stable-fixes).
- kbuild: Move -Wenum-{compare-conditional,enum-conversion}
  into W=1 (stable-fixes).
- USB: serial: cp210x: add pid/vid for TDK NC0110013M and
  MM0110113M (stable-fixes).
- USB: serial: option: add MeiG Smart SLM320 product
  (stable-fixes).
- USB: serial: cp210x: add ID for MGP Instruments PDS100
  (stable-fixes).
- USB: serial: add device ID for VeriFone adapter (stable-fixes).
- USB: serial: ftdi_sio: add support for GMC Z216C Adapter IR-USB
  (stable-fixes).
- ahci: asm1064: asm1166: don't limit reported ports (git-fixes).
- cxl/trace: Properly initialize cxl_poison region name
  (git-fixes).
- mtd: spinand: Add support for 5-byte IDs (stable-fixes).
- media: mc: Rename pad variable to clarify intent (stable-fixes).
- media: mc: Fix flags handling when creating pad links
  (stable-fixes).
- kasan/test: avoid gcc warning for intentional overflow
  (git-fixes).
- PCI/PM: Drain runtime-idle callbacks before driver removal
  (stable-fixes).
- PCI/DPC: Quirk PIO log size for Intel Raptor Lake Root Ports
  (stable-fixes).
- PCI/AER: Block runtime suspend when handling errors
  (stable-fixes).
- drm/amdgpu/display: Address kdoc for 'is_psr_su' in
  'fill_dc_dirty_rects' (git-fixes).
- drm/amdgpu: make damage clips support configurable
  (stable-fixes).
- drm/i915: Suppress old PLL pipe_mask checks for MG/TC/TBT PLLs
  (stable-fixes).
- drm/i915: Include the PLL name in the debug messages
  (stable-fixes).
- drm/i915: Try to preserve the current shared_dpll for fastset
  on type-c ports (stable-fixes).
- drm/i915: Replace a memset() with zero initialization
  (stable-fixes).
- hwmon: (amc6821) add of_match table (stable-fixes).
- mac802154: fix llsec key resources release in
  mac802154_llsec_key_del (git-fixes).
- wifi: rtw88: 8821cu: Fix connection failure (stable-fixes).
- wifi: rtw88: Add missing VID/PIDs for 8811CU and 8821CU
  (stable-fixes).
- wifi: brcmfmac: Demote vendor-specific attach/detach messages
  to info (git-fixes).
- wifi: brcmfmac: cfg80211: Use WSEC to set SAE password
  (stable-fixes).
- wifi: brcmfmac: add per-vendor feature detection callback
  (stable-fixes).
- docs: Restore "smart quotes" for quotes (stable-fixes).
- mei: me: add arrow lake point H DID (stable-fixes).
- mei: me: add arrow lake point S DID (stable-fixes).
- Input: xpad - add additional HyperX Controller Identifiers
  (stable-fixes).
- nouveau: lock the client object tree (stable-fixes).
- drm/amdgpu/pm: Fix the error of pwm1_enable setting
  (stable-fixes).
- drm/amd/display: handle range offsets in VRR ranges
  (stable-fixes).
- drm/amd/swsmu: modify the gfx activity scaling (stable-fixes).
- cxl/acpi: Fix load failures due to single window creation
  failure (git-fixes).
- cxl/pci: Fix disabling memory if DVSEC CXL Range does not
  match a CFMWS window (git-fixes).
- ahci: asm1064: correct count of reported ports (stable-fixes).
- interconnect: qcom: sm8550: Enable sync_state (git-fixes).
- interconnect: qcom: sc8180x: Mark CO0 BCM keepalive (git-fixes).
- nilfs2: fix potential bug in end_buffer_async_write (git-fixes).
- drm/amd/display: Add dml2 copy functions (stable-fixes).
- drm/i915: Stop printing pipe name as hex (stable-fixes).
- drm/i915: Use named initializers for DPLL info (stable-fixes).
- i915: make inject_virtual_interrupt() void (stable-fixes).
- interconnect: qcom: osm-l3: Replace custom implementation of
  COUNT_ARGS() (git-fixes).
- kasan: print the original fault addr when access invalid shadow
  (git-fixes).
- commit db0bc11
* Thu Apr  4 2024 tiwai@suse.de
- Add cherry-picked id to amdgpu patch
- commit c14e810
* Thu Apr  4 2024 tonyj@suse.de
- perf/x86/amd/core: Update and fix stalled-cycles-* events for
  Zen 2 and later (git-fixes).
- perf/x86/amd/lbr: Use freeze based on availability (git-fixes).
- perf/x86/amd/core: Avoid register reset when CPU is dead
  (git-fixes).
- powerpc/hv-gpci: Fix the H_GET_PERF_COUNTER_INFO hcall return
  value checks (git-fixes).
- commit 450ea2e
* Wed Apr  3 2024 andrea.porta@suse.com
- arm64: bpf: fix 32bit unconditional bswap (git-fixes).
- commit 9eb9b7b
* Wed Apr  3 2024 tiwai@suse.de
- selinux: avoid dereference of garbage after mount failure
  (git-fixes).
- net/x25: fix incorrect parameter validation in the
  x25_getsockopt() function (git-fixes).
- commit 7c956e3
* Wed Apr  3 2024 tiwai@suse.de
- Move upstreamed patches into sorted section
- commit ebe113d
* Wed Apr  3 2024 tiwai@suse.de
- Move upstreamed patches into sorted section
- commit f0c6082
* Wed Apr  3 2024 ailiop@suse.com
- fs/ntfs3: Fix an NULL dereference bug (bsc#1222264
  CVE-2023-52631).
- commit b468789
* Wed Apr  3 2024 ailiop@suse.com
- xfs: allow extent free intents to be retried (git-fixes).
- commit 681b677
* Wed Apr  3 2024 vkarasulli@suse.de
- Update references in
  patches.suse/media-xc4000-Fix-atomicity-violation-in-xc4000_get_f.patch
  (git-fixes bsc#1219623 CVE-2024-24861).
- commit cf893ec
* Tue Apr  2 2024 tiwai@suse.de
- drm/i915/lspcon: Separate lspcon probe and lspcon init
  (bsc#1193599).
- drm/i915/lspcon: Separate function to set expected mode
  (bsc#1193599).
- commit 3dfca11
* Tue Apr  2 2024 mkubecek@suse.cz
- netfilter: nf_tables: skip set commit for deleted/destroyed sets
  (CVE-2024-0193 bsc#1218495).
- commit e7bf1c3
* Tue Apr  2 2024 mkubecek@suse.cz
- netfilter: nf_tables: disallow anonymous set with timeout flag
  (CVE-2024-26642 bsc#1221830).
- commit 9cf0701
* Sun Mar 31 2024 tiwai@suse.de
- usb: typec: ucsi_acpi: Refactor and fix DELL quirk (git-fixes).
- usb: typec: ucsi: Check for notifications after init
  (git-fixes).
- usb: typec: ucsi: Clear EVENT_PENDING under PPM lock
  (git-fixes).
- usb: typec: Return size of buffer if pd_set operation succeeds
  (git-fixes).
- usb: dwc3: pci: Drop duplicate ID (git-fixes).
- usb: dwc3: Properly set system wakeup (git-fixes).
- usb: cdc-wdm: close race between read and workqueue (git-fixes).
- usb: dwc2: gadget: LPM flow fix (git-fixes).
- usb: dwc2: gadget: Fix exiting from clock gating (git-fixes).
- usb: dwc2: host: Fix ISOC flow in DDMA mode (git-fixes).
- usb: dwc2: host: Fix remote wakeup from hibernation (git-fixes).
- usb: dwc2: host: Fix hibernation flow (git-fixes).
- USB: core: Fix deadlock in usb_deauthorize_interface()
  (git-fixes).
- usb: typec: tcpm: Update PD of Type-C port upon pd_set
  (git-fixes).
- usb: typec: tcpm: fix double-free issue in
  tcpm_port_unregister_pd() (git-fixes).
- usb: typec: ucsi: Fix race between typec_switch and role_switch
  (git-fixes).
- usb: typec: tcpm: Correct port source pdo array in pd_set
  callback (git-fixes).
- staging: vc04_services: fix information leak in
  create_component() (git-fixes).
- commit d945fd3
* Sat Mar 30 2024 tiwai@suse.de
- drm/i915/gt: Reset queue_priority_hint on parking (git-fixes).
- drm/i915: Do not match JSL in ehl_combo_pll_div_frac_wa_needed()
  (git-fixes).
- drm/i915/hwmon: Fix locking inversion in sysfs getter
  (git-fixes).
- drm/i915/dsb: Fix DSB vblank waits when using VRR (git-fixes).
- drm/i915/vrr: Generate VRR "safe window" for DSB (git-fixes).
- drm/i915/mtl: Update workaround 14018575942 (git-fixes).
- drm/i915/dsi: Go back to the previous INIT_OTP/DISPLAY_ON order,
  mostly (git-fixes).
- drm/qxl: remove unused variable from
  `qxl_process_single_command()` (git-fixes).
- drm/qxl: remove unused `count` variable from
  `qxl_surface_id_alloc()` (git-fixes).
- drm/vmwgfx: Create debugfs ttm_resource_manager entry only if
  needed (git-fixes).
- drm/rockchip: vop2: Remove AR30 and AB30 format support
  (git-fixes).
- dma-buf: Fix NULL pointer dereference in sanitycheck()
  (git-fixes).
- drm/sched: fix null-ptr-deref in init entity (git-fixes).
- nouveau/dmem: handle kcalloc() allocation failure (git-fixes).
- drm/amdgpu: fix deadlock while reading mqd from debugfs
  (git-fixes).
- drm/amd/display: Send DTBCLK disable message on first commit
  (git-fixes).
- drm/amd: Flush GFXOFF requests in prepare stage (git-fixes).
- Revert "drm/amd/display: Fix sending VSC (+ colorimetry)
  packets for DP/eDP displays without PSR" (stable-fixes).
- thermal: devfreq_cooling: Fix perf state when calculate dfc
  res_util (git-fixes).
- Revert "thermal: core: Don't update trip points inside the
  hysteresis range" (git-fixes).
- ACPICA: debugger: check status of acpi_evaluate_object()
  in acpi_db_walk_for_fields() (git-fixes).
- commit 3764402
* Fri Mar 29 2024 mkoutny@suse.com
- README.BRANCH: Remove copy of branch name
- commit 1a0e3e3
* Fri Mar 29 2024 mkoutny@suse.com
- README.BRANCH: Remove copy of branch name
- commit 978e089
* Fri Mar 29 2024 mkoutny@suse.com
- README.BRANCH: Remove copy of branch name
- commit fc25aed
* Fri Mar 29 2024 tiwai@suse.de
- sdhci-of-dwcmshc: disable PM runtime in dwcmshc_remove()
  (git-fixes).
- mmc: sdhci-omap: re-tuning is needed after a pm transition to
  support emmc HS200 mode (git-fixes).
- mmc: core: Avoid negative index with array access (git-fixes).
- mmc: core: Initialize mmc_blk_ioc_data (git-fixes).
- ALSA: hda/tas2781: add locks to kcontrols (git-fixes).
- ALSA: hda/tas2781: remove digital gain kcontrol (git-fixes).
- ALSA: aoa: avoid false-positive format truncation warning
  (git-fixes).
- ALSA: sh: aica: reorder cleanup operations to avoid UAF bugs
  (git-fixes).
- ALSA: hda: cs35l56: Set the init_done flag before
  component_add() (git-fixes).
- net: lan743x: Add set RFE read fifo threshold for PCI1x1x chips
  (git-fixes).
- wifi: iwlwifi: mvm: include link ID when releasing frames
  (git-fixes).
- wifi: iwlwifi: fw: don't always use FW dump trig (git-fixes).
- wifi: iwlwifi: mvm: rfi: fix potential response leaks
  (git-fixes).
- selftests: vxlan_mdb: Fix failures with old libnet (git-fixes).
- net: wwan: t7xx: Split 64bit accesses to fix alignment issues
  (git-fixes).
- net: ll_temac: platform_get_resource replaced by wrong function
  (git-fixes).
- nfc: nci: Fix uninit-value in nci_dev_up and nci_ntf_packet
  (git-fixes).
- commit 699a684
* Thu Mar 28 2024 tbogendoerfer@suse.de
- ipv6: init the accept_queue's spinlocks in inet6_create
  (bsc#1221293 CVE-2024-26614).
- tcp: make sure init the accept_queue's spinlocks once
  (bsc#1221293 CVE-2024-26614).
- commit ec637cb
* Thu Mar 28 2024 dwagner@suse.de
- scsi: lpfc: Copyright updates for 14.4.0.1 patches
  (bsc#1221777).
- scsi: lpfc: Update lpfc version to 14.4.0.1 (bsc#1221777).
- scsi: lpfc: Define types in a union for generic void *context3
  ptr (bsc#1221777).
- scsi: lpfc: Define lpfc_dmabuf type for ctx_buf ptr
  (bsc#1221777).
- scsi: lpfc: Define lpfc_nodelist type for ctx_ndlp ptr
  (bsc#1221777).
- scsi: lpfc: Use a dedicated lock for ras_fwlog state
  (bsc#1221777).
- scsi: lpfc: Release hbalock before calling lpfc_worker_wake_up()
  (bsc#1221777).
- scsi: lpfc: Replace hbalock with ndlp lock in
  lpfc_nvme_unregister_port() (bsc#1221777).
- scsi: lpfc: Update lpfc_ramp_down_queue_handler() logic
  (bsc#1221777).
- scsi: lpfc: Remove IRQF_ONESHOT flag from threaded IRQ handling
  (bsc#1221777 bsc#1217958).
- scsi: lpfc: Move NPIV's transport unregistration to after
  resource clean up (bsc#1221777).
- scsi: lpfc: Remove unnecessary log message in queuecommand path
  (bsc#1221777).
- scsi: lpfc: Correct size for cmdwqe/rspwqe for memset()
  (bsc#1221777).
- scsi: lpfc: Correct size for wqe for memset() (bsc#1221777).
- commit 561883a
* Thu Mar 28 2024 dwagner@suse.de
- scsi: qla2xxx: Update version to 10.02.09.200-k (bsc#1221816).
- scsi: qla2xxx: Delay I/O Abort on PCI error (bsc#1221816).
- scsi: qla2xxx: Change debug message during driver unload
  (bsc#1221816).
- scsi: qla2xxx: Fix double free of fcport (bsc#1221816).
- scsi: qla2xxx: Fix double free of the ha->vp_map pointer
  (bsc#1221816).
- scsi: qla2xxx: Fix command flush on cable pull (bsc#1221816).
- scsi: qla2xxx: NVME|FCP prefer flag not being honored
  (bsc#1221816).
- scsi: qla2xxx: Update manufacturer detail (bsc#1221816).
- scsi: qla2xxx: Split FCE|EFT trace control (bsc#1221816).
- scsi: qla2xxx: Fix N2N stuck connection (bsc#1221816).
- scsi: qla2xxx: Prevent command send on chip reset (bsc#1221816).
- commit 5c3d977
* Thu Mar 28 2024 mgorman@suse.de
- Rename and refresh
  patches.suse/sched-fair-Combine-EAS-check-with-root_domain-overutilized-access.patch.
- commit 6ad1be8
* Thu Mar 28 2024 msuchanek@suse.de
- powerpc/crypto/chacha-p10: Fix failure on non Power10
  (bsc#1218205).
- commit 03daeb8
* Thu Mar 28 2024 tbogendoerfer@suse.de
- net/bnx2x: Prevent access to a freed page in page_pool
  (bsc#1215322).
- commit c9d3937
* Thu Mar 28 2024 svarbanov@suse.de
- usb: gadget: tegra-xudc: Fix USB3 PHY retrieval logic (bsc#1221491)
- commit 24e3b19
* Thu Mar 28 2024 svarbanov@suse.de
- phy: tegra: xusb: Add API to retrieve the port number of phy (bsc#1221491)
- commit be854b3
* Wed Mar 27 2024 pjakobsson@suse.de
- Revert "fbdev: flush deferred IO before closing (git-fixes)." (bsc#1221814)
  This reverts commit 81476d7e609a6d383f3d404542eebc93cebd0a4d.
  This fixes bsc#1221814
- commit a7a9087
* Wed Mar 27 2024 wqu@suse.com
- btrfs: qgroup: always free reserved space for extent records
  (bsc#1216196).
- commit a5aefa7
* Wed Mar 27 2024 spradhan@suse.de
- btrfs: fix stripe length calculation for non-zoned data chunk allocation (bsc#1217489).
- commit a8d6afc
* Wed Mar 27 2024 mkoutny@suse.com
- Update
  patches.suse/arm64-sme-Always-exit-sme_alloc-early-with-existing-.patch
  (git-fixes CVE-2024-26618 bsc#1221295).
- Update
  patches.suse/btrfs-don-t-abort-filesystem-when-attempting-to-snap.patch
  (bsc#1221282 CVE-2024-26644 bsc#1222072).
- Update
  patches.suse/btrfs-scrub-avoid-use-after-free-when-chunk-length-i.patch
  (bsc#1220943 CVE-2024-26616).
- Update
  patches.suse/drm-amd-display-Fix-late-derefrence-dsc-check-in-lin.patch
  (git-fixes CVE-2024-26647 bsc#1222066).
- Update
  patches.suse/drm-amd-display-Fix-variable-deferencing-before-NULL.patch
  (git-fixes CVE-2024-26648 bsc#1222067).
- Update
  patches.suse/drm-amdgpu-Fix-the-null-pointer-when-load-rlc-firmwa.patch
  (git-fixes CVE-2024-26649 bsc#1222055).
- Update
  patches.suse/net-qualcomm-rmnet-fix-global-oob-in-rmnet_policy.patch
  (git-fixes CVE-2024-26597 bsc#1220363).
- Update patches.suse/nfsd-fix-RELEASE_LOCKOWNER.patch
  (bsc#1218968 CVE-2024-26629 bsc#1221379).
- Update
  patches.suse/pwm-Fix-out-of-bounds-access-in-of_pwm_single_xlate.patch
  (git-fixes CVE-2024-26599 bsc#1220365).
- Update
  patches.suse/scsi-core-Move-scsi_host_busy-out-of-host-lock-for-waking-up-EH-handler.patch
  (git-fixes CVE-2024-26627 bsc#1221090).
- Update
  patches.suse/thermal-intel-hfi-Add-syscore-callbacks-for-system-w.patch
  (git-fixes CVE-2024-26646 bsc#1222070).
- Update
  patches.suse/tracing-Ensure-visibility-when-inserting-an-element-into-tracing_map.patch
  (git-fixes CVE-2024-26645 bsc#1222056).
- Update patches.suse/wifi-iwlwifi-fix-a-memory-corruption.patch
  (git-fixes CVE-2024-26610 bsc#1221299).
- Update
  patches.suse/x86-fpu-Stop-relying-on-userspace-for-info-to-fault-in-xsa.patch
  (bsc#1220335 CVE-2024-26603).
- commit 29c1925
* Wed Mar 27 2024 mkoutny@suse.com
- Update
  patches.suse/0002-ravb-Fix-use-after-free-issue-in-ravb_tx_timeout_wor.patch
  (bsc#1212514 CVE-2023-35827 CVE-2023-52509 bsc#1220836).
- Update
  patches.suse/Bluetooth-hci_codec-Fix-leaking-content-of-local_cod.patch
  (git-fixes CVE-2023-52518 bsc#1221056).
- Update
  patches.suse/EDAC-thunderx-Fix-possible-out-of-bounds-string-acce.patch
  (git-fixes CVE-2023-52464 bsc#1220330).
- Update
  patches.suse/FS-JFS-UBSAN-array-index-out-of-bounds-in-dbAdjTree.patch
  (git-fixes CVE-2023-52604 bsc#1221067).
- Update
  patches.suse/HID-intel-ish-hid-ipc-Disable-and-reenable-ACPI-GPE-.patch
  (git-fixes CVE-2023-52519 bsc#1220920).
- Update
  patches.suse/HID-sony-Fix-a-potential-memory-leak-in-sony_probe.patch
  (git-fixes CVE-2023-52529 bsc#1220929).
- Update patches.suse/IB-ipoib-Fix-mcast-list-locking.patch
  (jsc#PED-6864 CVE-2023-52587 bsc#1221082).
- Update
  patches.suse/PCI-switchtec-Fix-stdev_release-crash-after-surprise.patch
  (git-fixes CVE-2023-52617 bsc#1221613).
- Update
  patches.suse/PM-devfreq-Fix-buffer-overflow-in-trans_stat_show.patch
  (git-fixes CVE-2023-52614 bsc#1221617).
- Update
  patches.suse/PM-sleep-Fix-possible-deadlocks-in-core-system-wide-.patch
  (git-fixes CVE-2023-52498 bsc#1221269).
- Update
  patches.suse/RDMA-siw-Fix-connection-failure-handling.patch
  (git-fixes CVE-2023-52513 bsc#1221022).
- Update
  patches.suse/RDMA-srp-Do-not-call-scsi_done-from-srp_abort.patch
  (git-fixes CVE-2023-52515 bsc#1221048).
- Update
  patches.suse/Revert-tty-n_gsm-fix-UAF-in-gsm_cleanup_mux.patch
  (git-fixes CVE-2023-52564 bsc#1220938).
- Update
  patches.suse/SUNRPC-Fix-a-suspicious-RCU-usage-warning.patch
  (git-fixes CVE-2023-52623 bsc#1222060).
- Update
  patches.suse/UBSAN-array-index-out-of-bounds-in-dtSplitRoot.patch
  (git-fixes CVE-2023-52603 bsc#1221066).
- Update
  patches.suse/apparmor-avoid-crash-when-parsed-profile-name-is-emp.patch
  (git-fixes CVE-2023-52443 bsc#1220240).
- Update
  patches.suse/arm64-dts-qcom-sdm845-db845c-Mark-cont-splash-memory.patch
  (git-fixes CVE-2023-52561 bsc#1220935).
- Update
  patches.suse/bpf-Check-rcu_read_lock_trace_held-before-calling-bp.patch
  (bsc#1220251 CVE-2023-52447 CVE-2023-52621 bsc#1222073).
- Update
  patches.suse/bus-mhi-host-Add-alignment-check-for-event-ring-read.patch
  (git-fixes CVE-2023-52494 bsc#1221273).
- Update
  patches.suse/bus-mhi-host-Drop-chan-lock-before-queuing-buffers.patch
  (git-fixes CVE-2023-52493 bsc#1221274).
- Update
  patches.suse/cifs-Fix-UAF-in-cifs_demultiplex_thread.patch
  (bsc#1208995 CVE-2023-1192 CVE-2023-52572 bsc#1220946).
- Update
  patches.suse/class-fix-use-after-free-in-class_register.patch
  (git-fixes CVE-2023-52468 bsc#1220431).
- Update
  patches.suse/crypto-scomp-fix-req-dst-buffer-overflow.patch
  (git-fixes CVE-2023-52612 bsc#1221616).
- Update patches.suse/dccp-fix-dccp_v4_err-dccp_v6_err-again.patch
  (bsc#1220419 CVE-2023-52577 bsc#1220873).
- Update
  patches.suse/dmaengine-fix-NULL-pointer-in-channel-unregistration.patch
  (git-fixes CVE-2023-52492 bsc#1221276).
- Update
  patches.suse/drivers-amd-pm-fix-a-use-after-free-in-kv_parse_powe.patch
  (git-fixes CVE-2023-52469 bsc#1220411).
- Update
  patches.suse/drm-Don-t-unref-the-same-fb-many-times-by-mistake-du.patch
  (git-fixes CVE-2023-52486 bsc#1221277).
- Update
  patches.suse/drm-amd-display-Fix-NULL-pointer-dereference-at-hibe.patch
  (git-fixes CVE-2023-52460 bsc#1220319).
- Update
  patches.suse/drm-amdgpu-Fix-possible-NULL-dereference-in-amdgpu_r.patch
  (git-fixes CVE-2023-52585 bsc#1221080).
- Update
  patches.suse/drm-meson-fix-memory-leak-on-hpd_notify-callback.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52563
  bsc#1220937).
- Update
  patches.suse/drm-msm-dpu-Add-mutex-lock-in-control-vblank-irq.patch
  (git-fixes CVE-2023-52586 bsc#1221081).
- Update
  patches.suse/drm-radeon-check-the-alloc_workqueue-return-value-in.patch
  (git-fixes CVE-2023-52470 bsc#1220413).
- Update
  patches.suse/drm-sched-Fix-bounds-limiting-when-given-a-malformed.patch
  (git-fixes CVE-2023-52461 bsc#1220322).
- Update
  patches.suse/firmware-arm_scmi-Check-mailbox-SMT-channel-for-cons.patch
  (git-fixes CVE-2023-52608 bsc#1221375).
- Update
  patches.suse/gfs2-Fix-kernel-NULL-pointer-dereference-in-gfs2_rgrp_dump.patch
  (git-fixes CVE-2023-52448 bsc#1220253).
- Update
  patches.suse/hwrng-core-Fix-page-fault-dead-lock-on-mmap-ed-hwrng.patch
  (git-fixes CVE-2023-52615 bsc#1221614).
- Update
  patches.suse/ieee802154-ca8210-Fix-a-potential-UAF-in-ca8210_prob.patch
  (git-fixes CVE-2023-52510 bsc#1220898).
- Update
  patches.suse/iio-adc-ad7091r-Allow-users-to-configure-device-even.patch
  (git-fixes CVE-2023-52627 bsc#1222051).
- Update
  patches.suse/iommu-Don-t-reserve-0-length-IOVA-region.patch
  (git-fixes CVE-2023-52455 bsc#1220332).
- Update
  patches.suse/iommu-arm-smmu-v3-Fix-soft-lockup-triggered-by-arm_smmu_mm_invalidate_range.patch
  (bsc#1215921 CVE-2023-52484 bsc#1220797).
- Update
  patches.suse/iommu-vt-d-Avoid-memory-allocation-in-iommu_suspend
  (jsc#PED-7779 jsc#PED-7780 CVE-2023-52559 bsc#1220933).
- Update
  patches.suse/ipv4-ipv6-Fix-handling-of-transhdrlen-in-__ip-6-_app.patch
  (bsc#1220419 CVE-2023-52527 bsc#1220928).
- Update
  patches.suse/jfs-fix-array-index-out-of-bounds-in-dbAdjTree.patch
  (git-fixes CVE-2023-52601 bsc#1221068).
- Update
  patches.suse/jfs-fix-array-index-out-of-bounds-in-diNewExt.patch
  (git-fixes CVE-2023-52599 bsc#1221062).
- Update
  patches.suse/jfs-fix-slab-out-of-bounds-Read-in-dtSearch.patch
  (git-fixes CVE-2023-52602 bsc#1221070).
- Update patches.suse/jfs-fix-uaf-in-jfs_evict_inode.patch
  (git-fixes CVE-2023-52600 bsc#1221071).
- Update
  patches.suse/ksmbd-fix-slub-overflow-in-ksmbd_decode_ntlmss.patch
  (bsc#1012628 CVE-2023-52440 bsc#1220182).
- Update
  patches.suse/media-mtk-jpeg-Fix-use-after-free-bug-due-to-error-p.patch
  (git-fixes CVE-2023-52491 bsc#1221281).
- Update
  patches.suse/media-rkisp1-Fix-IRQ-disable-race-issue.patch
  (git-fixes CVE-2023-52589 bsc#1221084).
- Update patches.suse/media-uvcvideo-Fix-OOB-read.patch (git-fixes
  CVE-2023-52565 bsc#1220939).
- Update
  patches.suse/mfd-syscon-Fix-null-pointer-dereference-in-of_syscon.patch
  (git-fixes CVE-2023-52467 bsc#1220433).
- Update
  patches.suse/mm-migrate-fix-getting-incorrect-page-mapping-during-page-migration.patch
  (git-fixes CVE-2023-52490 bsc#1221325).
- Update
  patches.suse/mm-slab_common-fix-slab_caches-list-corruption-after-kmem_cache_destroy.patch
  (git-fixes CVE-2023-52562 bsc#1220936).
- Update
  patches.suse/mtd-Fix-gluebi-NULL-pointer-dereference-caused-by-ft.patch
  (git-fixes CVE-2023-52449 bsc#1220238).
- Update patches.suse/net-bridge-use-DEV_STATS_INC.patch
  (bsc#1220419 CVE-2023-52578 bsc#1220874).
- Update patches.suse/net-core-Fix-ETH_P_1588-flow-dissector.patch
  (bsc#1220419 CVE-2023-52580 bsc#1220876).
- Update
  patches.suse/net-fix-possible-store-tearing-in-neigh_periodic_wor.patch
  (bsc#1220419 CVE-2023-52522 bsc#1220924).
- Update
  patches.suse/net-mlx5e-Fix-operation-precedence-bug-in-port-times.patch
  (jsc#PED-3311 CVE-2023-52626 bsc#1222054).
- Update patches.suse/net-mlx5e-Fix-peer-flow-lists-handling.patch
  (jsc#PED-3311 CVE-2023-52487 bsc#1221341).
- Update
  patches.suse/net-nfc-fix-races-in-nfc_llcp_sock_get-and-nfc_llcp_.patch
  (git-fixes CVE-2023-52502 bsc#1220831).
- Update
  patches.suse/net-nfc-llcp-Add-lock-when-modifying-device-list.patch
  (git-fixes CVE-2023-52524 bsc#1220927).
- Update
  patches.suse/net-rds-Fix-possible-NULL-pointer-dereference.patch
  (bsc#1220419 CVE-2023-52573 bsc#1220869).
- Update
  patches.suse/net-usb-smsc75xx-Fix-uninit-value-access-in-__smsc75.patch
  (git-fixes CVE-2023-52528 bsc#1220843).
- Update
  patches.suse/netfilter-nft_set_rbtree-skip-sync-GC-for-new-elemen.patch
  (git-fixes CVE-2023-52433 bsc#1220137).
- Update
  patches.suse/nfc-nci-assert-requested-protocol-is-valid.patch
  (git-fixes CVE-2023-52507 bsc#1220833).
- Update
  patches.suse/nilfs2-fix-potential-use-after-free-in-nilfs_gccache.patch
  (git-fixes CVE-2023-52566 bsc#1220940).
- Update
  patches.suse/nvme-fc-Prevent-null-pointer-dereference-in-nvme_fc_.patch
  (bsc#1214842 CVE-2023-52508 bsc#1221015).
- Update
  patches.suse/nvmet-tcp-Fix-a-kernel-panic-when-host-sends-an-inva.patch
  (bsc#1217987 bsc#1217988 bsc#1217989 CVE-2023-6535 CVE-2023-6536
  CVE-2023-6356 CVE-2023-52454 bsc#1220320).
- Update
  patches.suse/ocfs2-Avoid-touching-renamed-directory-if-parent-doe.patch
  (bsc#1221044 CVE-2023-52591 CVE-2023-52590 bsc#1221088).
- Update
  patches.suse/perf-x86-intel-uncore-Fix-NULL-pointer-dereference-issue-in-upi_fill_topology.patch
  (bsc#1218958 CVE-2023-52450 bsc#1220237).
- Update patches.suse/perf-x86-lbr-Filter-vsyscall-addresses.patch
  (git-fixes CVE-2023-52476 bsc#1220703).
- Update
  patches.suse/phy-lynx-28g-serialize-concurrent-phy_set_mode_ext-c.patch
  (git-fixes CVE-2023-52505 bsc#1220830).
- Update
  patches.suse/pinctrl-nuvoton-wpcm450-fix-out-of-bounds-write.patch
  (git-fixes CVE-2023-52512 bsc#1221021).
- Update
  patches.suse/platform-x86-think-lmi-Fix-reference-leak.patch
  (git-fixes CVE-2023-52520 bsc#1220921).
- Update
  patches.suse/power-supply-rk817-Fix-node-refcount-leak.patch
  (git-fixes CVE-2023-52571 bsc#1220945).
- Update
  patches.suse/powerpc-lib-Validate-size-for-vector-operations.patch
  (bsc#1215199 CVE-2023-52606 bsc#1221069).
- Update
  patches.suse/powerpc-mm-Fix-null-pointer-dereference-in-pgtable_c.patch
  (bsc#1215199 CVE-2023-52607 bsc#1221061).
- Update
  patches.suse/pstore-ram-Fix-crash-when-setting-number-of-cpus-to-.patch
  (git-fixes CVE-2023-52619 bsc#1221618).
- Update
  patches.suse/ring-buffer-Do-not-attempt-to-read-past-commit.patch
  (git-fixes CVE-2023-52501 bsc#1220885).
- Update
  patches.suse/scsi-pm80xx-Avoid-leaking-tags-when-processing-OPC_INB_SET_CONTROLLER_CONFIG-command.patch
  (jsc#PED-6874 CVE-2023-52500 bsc#1220883).
- Update
  patches.suse/serial-8250_port-Check-IRQ-data-before-use.patch
  (git-fixes CVE-2023-52567 bsc#1220839).
- Update
  patches.suse/serial-sc16is7xx-convert-from-_raw_-to-_noinc_-regma.patch
  (git-fixes CVE-2023-52488 bsc#1221162).
- Update
  patches.suse/soc-qcom-pmic_glink_altmode-fix-port-sanity-check.patch
  (git-fixes CVE-2023-52495 bsc#1221271).
- Update
  patches.suse/spi-sun6i-fix-race-between-DMA-RX-transfer-completio.patch
  (git-fixes CVE-2023-52517 bsc#1221055).
- Update
  patches.suse/spi-sun6i-reduce-DMA-RX-transfer-width-to-single-byt.patch
  (git-fixes CVE-2023-52511 bsc#1221012).
- Update patches.suse/spmi-mediatek-Fix-UAF-on-device-remove.patch
  (git-fixes CVE-2023-52584 bsc#1221079).
- Update
  patches.suse/thermal-core-Fix-NULL-pointer-dereference-in-zone-re.patch
  (git-fixes CVE-2023-52473 bsc#1220430).
- Update patches.suse/uio-Fix-use-after-free-in-uio_open.patch
  (git-fixes CVE-2023-52439 bsc#1220140).
- Update
  patches.suse/wifi-ath9k-Fix-potential-array-index-out-of-bounds-r.patch
  (git-fixes CVE-2023-52594 bsc#1221045).
- Update
  patches.suse/wifi-mwifiex-Fix-oob-check-condition-in-mwifiex_proc.patch
  (git-fixes CVE-2023-52525 bsc#1220840).
- Update
  patches.suse/wifi-rt2x00-restart-beacon-queue-when-hardware-reset.patch
  (git-fixes CVE-2023-52595 bsc#1221046).
- Update
  patches.suse/wifi-rtw88-sdio-Honor-the-host-max_req_size-in-the-R.patch
  (git-fixes CVE-2023-52611 bsc#1221611).
- Update
  patches.suse/wifi-wfx-fix-possible-NULL-pointer-dereference-in-wf.patch
  (git-fixes CVE-2023-52593 bsc#1221042).
- Update
  patches.suse/x86-alternatives-disable-kasan-in-apply_alternatives.patch
  (git-fixes CVE-2023-52504 bsc#1221553).
- Update
  patches.suse/x86-srso-fix-sbpb-enablement-for-spec_rstack_overflow-off.patch
  (git-fixes CVE-2023-52575 bsc#1220871).
- commit 6296dca
* Wed Mar 27 2024 nik.borisov@suse.com
- RAS/AMD/FMPM: Fix build when debugfs is not enabled (jsc#PED-7619).
- commit 5b92ea7
* Wed Mar 27 2024 nik.borisov@suse.com
- RAS/AMD/FMPM: Safely handle saved records of various sizes (jsc#PED-7619).
- commit dbe7333
* Wed Mar 27 2024 nik.borisov@suse.com
- RAS/AMD/FMPM: Avoid NULL ptr deref in get_saved_records() (jsc#PED-7619).
- commit 6f11306
* Wed Mar 27 2024 tiwai@suse.de
- ASoC: amd: yc: Revert "Fix non-functional mic on Lenovo 21J2"
  (stable-fixes).
- commit 7817302
* Wed Mar 27 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: use correct address 3 in A-MSDU
  (stable-fixes).
- Refresh
  patches.suse/wifi-iwlwifi-mvm-use-FW-rate-for-non-data-only-on-ne.patch.
- commit 5b989e7
* Wed Mar 27 2024 tiwai@suse.de
- drm/msm/dpu: use devres-managed allocation for MDP TOP
  (stable-fixes).
- Refresh
  patches.suse/drm-msm-dpu-finalise-global-state-object.patch.
- commit d966716
* Wed Mar 27 2024 tiwai@suse.de
- pwm: img: fix pwm clock lookup (git-fixes).
- crypto: qat - fix ring to service map for dcc in 4xxx
  (git-fixes).
- clk: qcom: reset: Ensure write completion on reset de/assertion
  (git-fixes).
- clk: qcom: reset: Commonize the de/assert functions
  (stable-fixes).
- media: cadence: csi2rx: use match fwnode for media link
  (git-fixes).
- ACPI: resource: Do IRQ override on Lunnen Ground laptops
  (stable-fixes).
- Bluetooth: hci_core: Cancel request on command timeout
  (stable-fixes).
- inet_diag: annotate data-races around inet_diag_table[]
  (git-fixes).
- pstore: inode: Only d_invalidate() is needed (git-fixes).
- Input: gpio_keys_polled - suppress deferred probe error for gpio
  (stable-fixes).
- firewire: core: use long bus reset on gap count error
  (stable-fixes).
- ASoC: amd: yc: Fix non-functional mic on Lenovo 21J2
  (stable-fixes).
- ASoC: amd: yc: Add Lenovo ThinkBook 21J0 into DMI quirk table
  (stable-fixes).
- drm/amdgpu: Enable gpu reset for S3 abort cases on Raven series
  (stable-fixes).
- drm/buddy: check range allocation matches alignment
  (stable-fixes).
- Bluetooth: mgmt: Fix limited discoverable off timeout
  (stable-fixes).
- wifi: mac80211: only call drv_sta_rc_update for uploaded
  stations (stable-fixes).
- soc: microchip: Fix POLARFIRE_SOC_SYS_CTRL input prompt
  (stable-fixes).
- drm/amd/display: fix input states translation error for dcn35 &
  dcn351 (stable-fixes).
- platform/x86: x86-android-tablets: Fix acer_b1_750_goodix_gpios
  name (stable-fixes).
- media: rkisp1: Fix IRQ handling due to shared interrupts
  (stable-fixes).
- ASoC: SOF: ipc4-pcm: Workaround for crashed firmware on system
  suspend (stable-fixes).
- ASoC: rt5645: Make LattePanda board DMI match more precise
  (stable-fixes).
- spi: intel-pci: Add support for Lunar Lake-M SPI serial flash
  (stable-fixes).
- regmap: kunit: Ensure that changed bytes are actually different
  (stable-fixes).
- HID: multitouch: Add required quirk for Synaptics 0xcddc device
  (stable-fixes).
- wifi: ath12k: Update Qualcomm Innovation Center, Inc. copyrights
  (stable-fixes).
- crypto: qat - relocate and rename get_service_enabled()
  (stable-fixes).
- pstore: inode: Convert mutex usage to guard(mutex)
  (stable-fixes).
- ACPI: resource: Add Infinity laptops to
  irq1_edge_low_force_override (stable-fixes).
- commit 88eb41a
* Wed Mar 27 2024 denis.kirjanov@suse.com
- octeontx2-af: Fix devlink params (git-fixes).
- commit 4b1b7ca
* Wed Mar 27 2024 denis.kirjanov@suse.com
- net: hns3: fix port duplex configure error in IMP reset
  (git-fixes).
- commit 1e6cd3d
* Wed Mar 27 2024 denis.kirjanov@suse.com
- net: hns3: fix kernel crash when 1588 is received on HIP08
  devices (git-fixes).
- commit 1a3aae0
* Wed Mar 27 2024 denis.kirjanov@suse.com
- net: hns3: fix wrong judgment condition issue (git-fixes).
- commit 1fd3681
* Wed Mar 27 2024 denis.kirjanov@suse.com
- net: ena: Remove ena_select_queue (git-fixes).
- commit e9af613
* Wed Mar 27 2024 denis.kirjanov@suse.com
- net: pds_core: Fix possible double free in error handling path
  (git-fixes).
- commit 2613145
* Wed Mar 27 2024 denis.kirjanov@suse.com
- xdp, bonding: Fix feature flags when there are no slave devs
  anymore (git-fixes).
- commit 1154baf
* Wed Mar 27 2024 denis.kirjanov@suse.com
- intel: legacy: Partial revert of field get conversion
  (git-fixes).
- commit d4f114e
* Wed Mar 27 2024 denis.kirjanov@suse.com
- igc: avoid returning frame twice in XDP_REDIRECT (git-fixes).
- commit 75f7f5f
* Wed Mar 27 2024 denis.kirjanov@suse.com
- i40e: Fix firmware version comparison function (git-fixes).
- commit 2c37782
* Wed Mar 27 2024 denis.kirjanov@suse.com
- ice: fix typo in assignment (git-fixes).
- commit f19020e
* Wed Mar 27 2024 denis.kirjanov@suse.com
- ice: fix uninitialized dplls mutex usage (git-fixes).
- commit ff34920
* Wed Mar 27 2024 denis.kirjanov@suse.com
- net: ice: Fix potential NULL pointer dereference in
  ice_bridge_setlink() (git-fixes).
- commit 1e87fbd
* Tue Mar 26 2024 colyli@suse.de
- block: add check that partition length needs to be aligned
  with block size (bsc#1220428, CVE-2023-52458).
- commit 9530f29
* Tue Mar 26 2024 mgorman@suse.de
- Refresh series
- patches.suse/sched-fair-Add-EAS-checks-before-updating-root_domain-overutilized.patch.
- patches.suse/sched-fair-Introduce-is_rd_overutilized-helper-function-to-access-root_domain-overutilized.patch.
- patches.suse/sched-fair-Combine-EAS-check-with-overutilized-access.patch.
- commit fed9643
* Tue Mar 26 2024 jbohac@suse.cz
- Refresh patches.suse/kdump-add-crashkernel-cma-suffix.patch.
  (fix unused variable warning)
- commit c953180
* Tue Mar 26 2024 jlee@suse.com
- Update References
  patches.suse/wifi-ath10k-fix-NULL-pointer-dereference-in-ath10k_w.patch
  (git-fixes bsc#1218336 CVE-2023-7042).
- commit 5dbf535
* Tue Mar 26 2024 tiwai@suse.de
- Move upstreamed patches into sorted section
- commit 70b2e3d
* Mon Mar 25 2024 tiwai@suse.de
- mm_init kABI workaround (git-fixes).
- commit 258a68b
* Mon Mar 25 2024 colyli@suse.de
- device-dax: make dax_bus_type const (jsc#PED-5853).
- nvdimm: make nvdimm_bus_type const (jsc#PED-5853).
- libnvdimm: Fix ACPI_NFIT in BLK_DEV_PMEM help (jsc#PED-5853).
- nvdimm/pmem: Treat alloc_dax() -EOPNOTSUPP failure as non-fatal
  (jsc#PED-5853).
- dax: alloc_dax() return ERR_PTR(-EOPNOTSUPP) for CONFIG_DAX=n
  (jsc#PED-5853).
- nvdimm/pmem: fix leak on dax_add_host() failure (jsc#PED-5853).
- dax/bus.c: replace several sprintf() with sysfs_emit()
  (jsc#PED-5853).
- dax/bus.c: replace driver-core lock usage by a local rwsem
  (jsc#PED-5853).
- dm-integrity: set max_integrity_segments in
  dm_integrity_io_hints (jsc#PED-7542).
- dm: update relevant MODULE_AUTHOR entries to latest dm-devel
  mailing list (jsc#PED-7542).
- dm verity: set DM_TARGET_SINGLETON feature flag (jsc#PED-7542).
- dm crypt: remove redundant state settings after waking up
  (jsc#PED-7542).
- dm thin: add braces around conditional code that spans lines
  (jsc#PED-7542).
- md/dm-raid: don't call md_reap_sync_thread() directly
  (jsc#PED-7542).
- dm-raid: really frozen sync_thread during suspend
  (jsc#PED-7542).
- md: add a new helper reshape_interrupted() (jsc#PED-7542).
- md: export helper md_is_rdwr() (jsc#PED-7542).
- md: export helpers to stop sync_thread (jsc#PED-7542).
- md: don't clear MD_RECOVERY_FROZEN for new dm-raid until resume
  (jsc#PED-7542).
- md/raid1: factor out helpers to choose the best rdev from
  read_balance() (jsc#PED-7542).
- md/raid1: factor out the code to manage sequential IO
  (jsc#PED-7542).
- md/raid1: factor out choose_bb_rdev() from read_balance()
  (jsc#PED-7542).
- md/raid1: factor out choose_slow_rdev() from read_balance()
  (jsc#PED-7542).
- md/raid1: factor out read_first_rdev() from read_balance()
  (jsc#PED-7542).
- md/raid1-10: factor out a new helper raid1_should_read_first()
  (jsc#PED-7542).
- md/raid1-10: add a helper raid1_check_read_range()
  (jsc#PED-7542).
- md/raid1: fix choose next idle in read_balance() (jsc#PED-7542).
- commit 9ee2d7c
* Mon Mar 25 2024 colyli@suse.de
- md: preserve KABI in struct md_personality (jsc#PED-7542).
- dm-raid: add a new helper prepare_suspend() in md_personality
  (jsc#PED-7542).
- commit ee8ae3a
* Mon Mar 25 2024 colyli@suse.de
- md/raid1: record nonrot rdevs while adding/removing rdevs to
  conf (jsc#PED-7542).
- Refresh patches.suse/md-display-timeout-error.patch.
- commit 6221037
* Mon Mar 25 2024 colyli@suse.de
- md/raid1: factor out helpers to add rdev to conf (jsc#PED-7542).
- md: add a new helper rdev_has_badblock() (jsc#PED-7542).
- md: check mddev->pers before calling md_set_readonly()
  (jsc#PED-7542).
- md: clean up openers check in do_md_stop() and md_set_readonly()
  (jsc#PED-7542).
- md: sync blockdev before stopping raid or setting readonly
  (jsc#PED-7542).
- md: factor out a helper to sync mddev (jsc#PED-7542).
- md: Don't clear MD_CLOSING when the raid is about to stop
  (jsc#PED-7542).
- md: return directly before setting did_set_md_closing
  (jsc#PED-7542).
- md: clean up invalid BUG_ON in md_ioctl (jsc#PED-7542).
- md: changed the switch of RAID_VERSION to if (jsc#PED-7542).
- md: merge the check of capabilities into md_ioctl_valid()
  (jsc#PED-7542).
- md: fix kmemleak of rdev->serial (jsc#PED-7542).
- md: use RCU lock to protect traversal in md_spares_need_change()
  (jsc#PED-7542).
- md: get rdev->mddev with READ_ONCE() (jsc#PED-7542).
- md: remove redundant md_wakeup_thread() (jsc#PED-7542).
- md: remove redundant check of 'mddev->sync_thread'
  (jsc#PED-7542).
- commit ce67549
* Mon Mar 25 2024 tiwai@suse.de
- Move upstreamed uio patches into sorted section
- commit bd64fed
* Mon Mar 25 2024 tiwai@suse.de
- clocksource/drivers/arm_global_timer: Fix maximum prescaler
  value (git-fixes).
- clocksource/drivers/imx: Fix -Wunused-but-set-variable warning
  (git-fixes).
- speakup: Fix 8bit characters from direct synth (git-fixes).
- wifi: iwlwifi: fw: fix compile w/o CONFIG_ACPI (git-fixes).
- sock_diag: annotate data-races around sock_diag_handlers[family]
  (git-fixes).
- serial: core: Fix atomicity violation in uart_tiocmget
  (git-fixes).
- commit 1a369e8
* Mon Mar 25 2024 tiwai@suse.de
- Add cherry-picked id to amdgpu patch (git-fixes)
- commit 520ebef
* Mon Mar 25 2024 tiwai@suse.de
- efi: fix panic in kdump kernel (git-fixes).
- efi: disable mirror feature during crashkernel (stable-fixes).
- commit 1fa1fb0
* Mon Mar 25 2024 oneukum@suse.com
- xhci: update event ring dequeue pointer position to controller
  correctly (git-fixes).
  Altered because we cannot take the multiple interrupter code
- commit 09553b9
* Mon Mar 25 2024 oneukum@suse.com
- xhci: remove unnecessary event_ring_deq parameter from
  xhci_handle_event() (git-fixes).
- commit 9738c27
* Mon Mar 25 2024 oneukum@suse.com
- xhci: simplify event ring dequeue tracking for transfer events
  (git-fixes).
- Refresh
  patches.suse/xhci-Simplify-event-ring-dequeue-pointer-update-for-.patch.
- commit b590884
* Mon Mar 25 2024 oneukum@suse.com
- xhci: add helper that checks for unhandled events on a event
  ring (git-fixes).
- commit 14f6eb3
* Mon Mar 25 2024 oneukum@suse.com
- usb: xhci: Implement xhci_handshake_check_state() helper.
- commit f377708
* Mon Mar 25 2024 denis.kirjanov@suse.com
- kabi/severities: ignore Wangxun ethernet driver local symbols
- commit 86b4a3b
* Mon Mar 25 2024 ailiop@suse.com
- ubi: Check for too small LEB size in VTBL code (bsc#1219834
  CVE-2024-25739).
- commit 8837d83
* Mon Mar 25 2024 oneukum@suse.com
- xhci: Simplify event ring dequeue pointer update for port
  change events (git-fixes).
- commit 87ce2b5
* Mon Mar 25 2024 tiwai@suse.de
- wifi: ath11k: decrease MHI channel buffer length to 8KB
  (bsc#1207948).
- commit fa1c47a
* Mon Mar 25 2024 nik.borisov@suse.com
- x86/fpu: Keep xfd_state in sync with MSR_IA32_XFD (git-fixes).
- commit 4352288
* Mon Mar 25 2024 nik.borisov@suse.com
- x86/CPU/AMD: Update the Zenbleed microcode revisions (git-fixes).
- commit 6ea0e27
* Mon Mar 25 2024 denis.kirjanov@suse.com
- ice: virtchnl: stop pretending to support RSS over AQ or
  registers (git-fixes).
- commit 6cbf931
* Mon Mar 25 2024 denis.kirjanov@suse.com
- idpf: disable local BH when scheduling napi for marker packets
  (git-fixes).
- commit 30580cd
* Mon Mar 25 2024 denis.kirjanov@suse.com
- net: dsa: microchip: fix register write order in
  ksz8_ind_write8() (git-fixes).
- commit ed256c0
* Mon Mar 25 2024 denis.kirjanov@suse.com
- net/mlx5e: Switch to using _bh variant of of spinlock API in
  port timestamping NAPI poll context (git-fixes).
- commit 41be7c6
* Mon Mar 25 2024 denis.kirjanov@suse.com
- net: stmmac: Fix incorrect dereference in interrupt handlers
  (git-fixes).
- commit 0ab8957
* Mon Mar 25 2024 denis.kirjanov@suse.com
- net: ethernet: ti: cpsw: enable mac_managed_pm to fix mdio
  (git-fixes).
- commit 82f6a71
* Mon Mar 25 2024 denis.kirjanov@suse.com
- net: libwx: fix memory leak on free page (git-fixes).
- commit 1147e4f
* Mon Mar 25 2024 denis.kirjanov@suse.com
- Update references
- commit 2642ab1
* Mon Mar 25 2024 jslaby@suse.cz
- PCI: qcom: Disable ASPM L0s for sc8280xp, sa8540p and sa8295p
  (git-fixes).
- PCI: qcom: Add support for sa8775p SoC (git-fixes).
- PCI/ASPM: Use RMW accessors for changing LNKCTL (git-fixes).
- PCI: Make link retraining use RMW accessors for changing LNKCTL
  (git-fixes).
- commit 85600d2
* Mon Mar 25 2024 dwagner@suse.de
- nvme: fix reconnection fail due to reserved tag allocation
  (git-fixes).
- commit b4e9845
* Mon Mar 25 2024 shung-hsi.yu@suse.com
- bpf, scripts: Correct GPL license name (git-fixes).
- commit 0780a36
* Sun Mar 24 2024 tiwai@suse.de
- Move out-of-tree kexec patches into the right section
- commit 06266e2
* Sun Mar 24 2024 tiwai@suse.de
- Move upstreamed patches into sorted section
- commit d7cfbed
* Sat Mar 23 2024 tiwai@suse.de
- Drop usb gadget patch that was taken mistakenly and reverted (git-fixes)
- commit 57ae154
* Sat Mar 23 2024 tiwai@suse.de
- spi: spi-mt65xx: Fix NULL pointer access in interrupt handler
  (git-fixes).
- spi: lm70llp: fix links in doc and comments (git-fixes).
- spi: lpspi: Avoid potential use-after-free in probe()
  (git-fixes).
- ASoC: rockchip: i2s-tdm: Fix inaccurate sampling rates
  (git-fixes).
- ASoC: tlv320adc3xxx: Don't strip remove function when driver
  is builtin (git-fixes).
- commit 0e27f7b
* Fri Mar 22 2024 tiwai@suse.de
- drm/amdgpu: drop setting buffer funcs in sdma442 (git-fixes).
- drm/amdgpu/pm: Check the validity of overdiver power limit
  (git-fixes).
- drm/amdgpu/pm: Fix NULL pointer dereference when get power limit
  (git-fixes).
- drm/amdgpu: fix mmhub client id out-of-bounds access
  (git-fixes).
- nouveau/gsp: don't check devinit disable on GSP (git-fixes).
- drm: Fix drm_fixp2int_round() making it add 0.5 (git-fixes).
- nouveau: reset the bo resource bus info after an eviction
  (git-fixes).
- rtc: mt6397: select IRQ_DOMAIN instead of depending on it
  (git-fixes).
- selftests: forwarding: Fix ping failure due to short timeout
  (git-fixes).
- soc: fsl: qbman: Use raw spinlock for cgr_lock (git-fixes).
- soc: fsl: qbman: Always disable interrupts when taking cgr_lock
  (git-fixes).
- kconfig: fix infinite loop when expanding a macro at the end
  of file (git-fixes).
- slimbus: core: Remove usage of the deprecated ida_simple_xx()
  API (git-fixes).
- hwtracing: hisi_ptt: Move type check to the beginning of
  hisi_ptt_pmu_event_init() (git-fixes).
- bus: mhi: ep: check the correct variable in
  mhi_ep_register_controller() (git-fixes).
- iio: gts-helper: Fix division loop (git-fixes).
- iio: dummy_evgen: remove Excess kernel-doc comments (git-fixes).
- serial: Lock console when calling into driver before
  registration (git-fixes).
- serial: core: only stop transmit when HW fifo is empty
  (git-fixes).
- serial: 8250_exar: Don't remove GPIO device on suspend
  (git-fixes).
- tty: serial: samsung: fix tx_empty() to return TIOCSER_TEMT
  (git-fixes).
- serial: max310x: fix syntax error in IRQ error message
  (git-fixes).
- serial: max310x: fix NULL pointer dereference in I2C
  instantiation (git-fixes).
- tty: vt: fix 20 vs 0x20 typo in EScsiignore (git-fixes).
- usb: gadget: net2272: Use irqflags in the call to
  net2272_probe_fin (git-fixes).
- usb: typec: ucsi: Clean up UCSI_CABLE_PROP macros (git-fixes).
- usb: xhci: Add error handling in xhci_map_urb_for_dma
  (git-fixes).
- usb: phy: generic: Get the vbus supply (git-fixes).
- usb: audio-v2: Correct comments for struct
  uac_clock_selector_descriptor (git-fixes).
- remoteproc: stm32: Fix incorrect type assignment returned by
  stm32_rproc_get_loaded_rsc_tablef (git-fixes).
- remoteproc: virtio: Fix wdg cannot recovery remote processor
  (git-fixes).
- commit 0e293ea
* Fri Mar 22 2024 vkarasulli@suse.de
- iommufd/iova_bitmap: Switch iova_bitmap::bitmap to an u8  array
  (git-fixes).
- commit 7b0b857
* Fri Mar 22 2024 vkarasulli@suse.de
- iommufd/iova_bitmap: Consider page offset for the pages to be
  pinned (git-fixes).
- commit 0bcb37d
* Fri Mar 22 2024 vkarasulli@suse.de
- iommu/vt-d: Set SSADE when attaching to a parent with dirty
  tracking (git-fixes).
- commit 0dce02e
* Fri Mar 22 2024 vkarasulli@suse.de
- iommufd: Fix iopt_access_list_id overwrite bug (git-fixes).
- commit 393f087
* Fri Mar 22 2024 iivanov@suse.de
- Update patches.suse/dmaengine-fix-NULL-pointer-in-channel-unregistration.patch (git-fixes bsc#1221276 CVE-2023-52492)
- commit 4334575
* Fri Mar 22 2024 iivanov@suse.de
- Update patches.suse/firmware-arm_scmi-Check-mailbox-SMT-channel-for-cons.patch (git-fixes bsc#1221375 CVE-2023-52608)
- commit 9e41d96
* Thu Mar 21 2024 tonyj@suse.de
- perf tests: Skip data symbol test if buf1 symbol is missing
  (bsc#1220045).
- perf tests: Make data symbol test wait for perf to start
  (bsc#1220045).
- commit c2fa164
* Thu Mar 21 2024 jlee@suse.com
- Bluetooth: rfcomm: Fix null-ptr-deref in rfcomm_check_security
  (bsc#1219170 CVE-2024-22099).
- commit ee8d9c4
* Thu Mar 21 2024 dwagner@suse.de
- scsi: qla2xxx: Update version to 10.02.09.200-k (bsc1221816).
- scsi: qla2xxx: Delay I/O Abort on PCI error (bsc1221816).
- scsi: qla2xxx: Change debug message during driver unload
  (bsc1221816).
- scsi: qla2xxx: Fix double free of fcport (bsc1221816).
- scsi: qla2xxx: Fix double free of the ha->vp_map pointer
  (bsc1221816).
- scsi: qla2xxx: Fix command flush on cable pull (bsc1221816).
- scsi: qla2xxx: NVME|FCP prefer flag not being honored
  (bsc1221816).
- scsi: qla2xxx: Update manufacturer detail (bsc1221816).
- scsi: qla2xxx: Split FCE|EFT trace control (bsc1221816).
- scsi: qla2xxx: Fix N2N stuck connection (bsc1221816).
- scsi: qla2xxx: Prevent command send on chip reset (bsc1221816).
- commit 1d07bf4
* Thu Mar 21 2024 jlee@suse.com
- aoe: fix the potential use-after-free problem in aoecmd_cfg_pkts
  (bsc#1218562 CVE-2023-6270 CVE-2024-26898 bsc#1223016).
- aoe: fix the potential use-after-free problem in aoecmd_cfg_pkts
  (bsc#1218562 CVE-2023-6270).
- commit bd4199d
* Thu Mar 21 2024 dwagner@suse.de
- scsi: lpfc: Copyright updates for 14.4.0.1 patches
  (bsc#1221777).
- scsi: lpfc: Update lpfc version to 14.4.0.1 (bsc#1221777).
- scsi: lpfc: Define types in a union for generic void *context3
  ptr (bsc#1221777).
- scsi: lpfc: Define lpfc_dmabuf type for ctx_buf ptr
  (bsc#1221777).
- scsi: lpfc: Define lpfc_nodelist type for ctx_ndlp ptr
  (bsc#1221777).
- scsi: lpfc: Use a dedicated lock for ras_fwlog state
  (bsc#1221777).
- scsi: lpfc: Release hbalock before calling lpfc_worker_wake_up()
  (bsc#1221777).
- scsi: lpfc: Replace hbalock with ndlp lock in
  lpfc_nvme_unregister_port() (bsc#1221777).
- scsi: lpfc: Update lpfc_ramp_down_queue_handler() logic
  (bsc#1221777).
- scsi: lpfc: Remove IRQF_ONESHOT flag from threaded IRQ handling
  (bsc#1221777 bsc#1217959).
- scsi: lpfc: Move NPIV's transport unregistration to after
  resource clean up (bsc#1221777).
- scsi: lpfc: Remove unnecessary log message in queuecommand path
  (bsc#1221777).
- scsi: lpfc: Correct size for cmdwqe/rspwqe for memset()
  (bsc#1221777).
- scsi: lpfc: Correct size for wqe for memset() (bsc#1221777).
- commit eef9737
* Thu Mar 21 2024 msuchanek@suse.de
- Workaround broken chacha crypto fallback (bsc#1218205).
- commit 55f136c
* Thu Mar 21 2024 denis.kirjanov@suse.com
- net/mlx5e: Use a memory barrier to enforce PTP WQ xmit
  submission tracking occurs after populating the metadata_map
  (git-fixes).
- commit c382d3a
* Thu Mar 21 2024 denis.kirjanov@suse.com
- net/mlx5e: Fix MACsec state loss upon state update in offload
  path (git-fixes).
- commit 7293938
* Thu Mar 21 2024 denis.kirjanov@suse.com
- net/mlx5e: Change the warning when ignore_flow_level is not
  supported (git-fixes).
- commit 5274665
* Thu Mar 21 2024 denis.kirjanov@suse.com
- net/mlx5: Fix fw reporter diagnose output (git-fixes).
- commit 3377c89
* Thu Mar 21 2024 denis.kirjanov@suse.com
- net/mlx5: E-switch, Change flow rule destination checking
  (git-fixes).
- commit 1d30b46
* Thu Mar 21 2024 denis.kirjanov@suse.com
- Revert "net/mlx5e: Check the number of elements before walk
  TC rhashtable" (git-fixes).
- commit a37e618
* Thu Mar 21 2024 denis.kirjanov@suse.com
- Revert "net/mlx5: Block entering switchdev mode with ns
  inconsistency" (git-fixes).
- commit 917148d
* Thu Mar 21 2024 denis.kirjanov@suse.com
- ice: reconfig host after changing MSI-X on VF (git-fixes).
- commit f980680
* Thu Mar 21 2024 denis.kirjanov@suse.com
- ice: reorder disabling IRQ and NAPI in ice_qp_dis (git-fixes).
- commit 4099ba6
* Thu Mar 21 2024 denis.kirjanov@suse.com
- i40e: disable NAPI right after disabling irqs when handling
  xsk_pool (git-fixes).
- commit 1715806
* Thu Mar 21 2024 denis.kirjanov@suse.com
- ixgbe: {dis, en}able irqs in ixgbe_txrx_ring_{dis, en}able
  (git-fixes).
- commit fbfea47
* Thu Mar 21 2024 denis.kirjanov@suse.com
- geneve: make sure to pull inner header in geneve_rx()
  (git-fixes).
- commit 8b261ce
* Thu Mar 21 2024 denis.kirjanov@suse.com
- gtp: fix use-after-free and null-ptr-deref in gtp_newlink()
  (git-fixes).
- commit 897cd65
* Thu Mar 21 2024 denis.kirjanov@suse.com
- igb: extend PTP timestamp adjustments to i211 (git-fixes).
- commit b173908
* Thu Mar 21 2024 denis.kirjanov@suse.com
- stmmac: Clear variable when destroying workqueue (git-fixes).
- commit 94d14a9
* Thu Mar 21 2024 mfranc@suse.cz
- s390/vtime: fix average steal time calculation (git-fixes
  bsc#1221783).
- commit e044390
* Wed Mar 20 2024 jbohac@suse.cz
- kdump: wait for DMA to time out when using CMA (jsc#PED-7249).
- Refresh
  patches.suse/add-product-identifying-information-to-vmcoreinfo.patch.
- kdump: describe crashkernel ,cma in Documentaion (jsc#PED-7249).
- kdump, x86: implement crashkernel cma reservation
  (jsc#PED-7249).
- commit 99814c5
* Wed Mar 20 2024 jbohac@suse.cz
- kdump: implement reserve_crashkernel_cma (jsc#PED-7249).
- Refresh
  patches.suse/add-product-identifying-information-to-vmcoreinfo.patch.
- commit fc59052
* Wed Mar 20 2024 jbohac@suse.cz
- kdump: add crashkernel= ,cma suffix (jsc#PED-7249).
- commit 41f0c07
* Wed Mar 20 2024 jbohac@suse.cz
- kdump: defer the insertion of crashkernel resources
  (jsc#PED-7249).
- crash_core: fix the check for whether crashkernel is from high
  memory (jsc#PED-7249).
- crash_core.c: remove unneeded functions (jsc#PED-7249).
- riscv: kdump: use generic interface to simplify crashkernel
  reservation (jsc#PED-7249).
- commit 8326859
* Wed Mar 20 2024 jbohac@suse.cz
- arm64: kdump: use generic interface to simplify crashkernel
  reservation (jsc#PED-7249).
- Update config files.
- commit 7ae6d47
* Wed Mar 20 2024 jbohac@suse.cz
- x86: kdump: use generic interface to simplify crashkernel
  reservation code (jsc#PED-7249).
- Update config files.
- commit c141552
* Wed Mar 20 2024 jbohac@suse.cz
- crash_core: move crashk_*res definition into crash_core.c
  (jsc#PED-7249).
- commit 0e37e20
* Wed Mar 20 2024 jbohac@suse.cz
- crash_core: add generic function to do reservation
  (jsc#PED-7249).
- Refresh
  patches.suse/add-product-identifying-information-to-vmcoreinfo.patch.
- commit a0ccf1b
* Wed Mar 20 2024 jbohac@suse.cz
- crash_core: change parse_crashkernel() to support
  crashkernel=,high|low parsing (jsc#PED-7249).
- crash_core: change the prototype of function parse_crashkernel()
  (jsc#PED-7249).
- crash_core.c: remove unnecessary parameter of function
  (jsc#PED-7249).
- riscv: kdump: Implement crashkernel=X,[high,low] (jsc#PED-7249).
- arm64: kdump: simplify the reservation behaviour of
  crashkernel=,high (jsc#PED-7249).
- commit 9191c97
* Wed Mar 20 2024 jslaby@suse.cz
- net/smc: fix documentation of buffer sizes (git-fixes).
- bootmem: use kmemleak_free_part_phys in free_bootmem_page
  (git-fixes).
- swiotlb: use the calculated number of areas (git-fixes).
- sched/psi: Select KERNFS as needed (git-fixes).
- commit ed6834a
* Wed Mar 20 2024 denis.kirjanov@suse.com
- veth: try harder when allocating queue memory (git-fixes).
- commit fda44e7
* Wed Mar 20 2024 oneukum@suse.com
- vdpa/mlx5: Allow CVQ size changes (git-fixes).
- commit 7026f16
* Wed Mar 20 2024 oneukum@suse.com
- vdpa_sim: reset must not run (git-fixes).
- commit b05aeef
* Wed Mar 20 2024 iivanov@suse.de
- Fix patches.suse/coresight-etm4x-Add-ACPI-support-in-platform-driver.patch (bsc#1218779 bsc#1220587)
  Put back patch hunk which where missed because file rename
  drivers/acpi/acpi_amba.c -> drivers/acpi/arm64/amba.c
- commit 1eccf32
* Wed Mar 20 2024 tiwai@suse.de
- soc: fsl: dpio: fix kcalloc() argument order (git-fixes).
- cpufreq: dt: always allocate zeroed cpumask (git-fixes).
- thermal/drivers/mediatek: Fix control buffer enablement on
  MT7896 (git-fixes).
- thermal/drivers/mediatek/lvts_thermal: Fix a memory leak in
  an error handling path (git-fixes).
- commit 353a58d
* Wed Mar 20 2024 neilb@suse.de
- NFSD: Fix nfsd_clid_class use of __string_len() macro
  (git-fixes).
- nfs: fix panic when nfs4_ff_layout_prepare_ds() fails
  (git-fixes).
- NFS: Read unlock folio on nfs_page_create_from_folio() error
  (git-fixes).
- NFSv4.1/pnfs: fix NFS with TLS in pnfs (git-fixes).
- NFS: Fix an off by one in root_nfs_cat() (git-fixes).
- NFS: Fix nfs_netfs_issue_read() xarray locking for writeback
  interrupt (git-fixes).
- NFSv4.2: fix listxattr maximum XDR buffer size (git-fixes).
- NFSv4.2: fix nfs4_listxattr kernel BUG at mm/usercopy.c:102
  (git-fixes).
- net: sunrpc: Fix an off by one in rpc_sockaddr2uaddr()
  (git-fixes).
- nfsd: Fix a regression in nfsd_setattr() (git-fixes).
- nfsd: don't call locks_release_private() twice concurrently
  (git-fixes).
- NFSD: Retransmit callbacks after client reconnects (git-fixes).
- NFSD: Reschedule CB operations when backchannel rpc_clnt is
  shut down (git-fixes).
- NFSD: Convert the callback workqueue to use delayed_work
  (git-fixes).
- NFSD: Reset cb_seq_status after NFS4ERR_DELAY (git-fixes).
- NFSD: fix LISTXATTRS returning more bytes than maxcount
  (git-fixes).
- NFSD: fix LISTXATTRS returning a short list with eof=TRUE
  (git-fixes).
- NFSD: change LISTXATTRS cookie encoding to big-endian
  (git-fixes).
- NFSD: fix nfsd4_listxattr_validate_cookie (git-fixes).
- SUNRPC: fix some memleaks in gssx_dec_option_array (git-fixes).
- SUNRPC: fix a memleak in gss_import_v2_context (git-fixes).
- commit cf1cfe0
* Tue Mar 19 2024 mkoutny@suse.com
- Refresh
  patches.suse/net-sched-Add-module-alias-for-sch_fq_pie.patch.
- commit 4c6eb4e
* Tue Mar 19 2024 vkarasulli@suse.de
- iommu/dma: Trace bounce buffer usage when mapping buffers
  (git-fixes).
- commit a53df01
* Tue Mar 19 2024 nmorey@suse.com
- RDMA/rtrs-clt: Check strnlen return len in sysfs mpath_policy_store() (git-fixes)
- commit 4586f58
* Tue Mar 19 2024 nmorey@suse.com
- RDMA/device: Fix a race between mad_client and cm_client init (git-fixes)
- commit 0f4890f
* Tue Mar 19 2024 nmorey@suse.com
- RDMA/hns: Fix mis-modifying default congestion control algorithm (git-fixes)
- commit a44fff2
* Tue Mar 19 2024 nmorey@suse.com
- RDMA/srpt: Do not register event handler until srpt device is fully setup (git-fixes)
- commit faac2cb
* Tue Mar 19 2024 nmorey@suse.com
- RDMA/irdma: Remove duplicate assignment (git-fixes)
- commit 5dbeef5
* Tue Mar 19 2024 pjakobsson@suse.de
- drm/amd/display: Fix && vs || typos (git-fixes).
- commit 1a09c42
* Tue Mar 19 2024 vkarasulli@suse.de
- iommu: Map reserved memory as cacheable if device is coherent
  (git-fixes).
- Refresh
  patches.suse/iommu-Don-t-reserve-0-length-IOVA-region.patch.
- commit 3835906
* Tue Mar 19 2024 svarbanov@suse.de
- memory: tegra: Add BPMP and ICC info for DLA clients (bsc#1221330)
- commit 7fbb1f9
* Tue Mar 19 2024 svarbanov@suse.de
- memory: tegra: Correct DLA client names (bsc#1221330)
- commit 09ff68e
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/Revert-drm-amd-pm-resolve-reboot-exception-for-si-ol.patch (git-fixes)
  Alt-commit
- commit c5c0b23
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amdgpu-pm-Fix-the-power1_min_cap-value.patch (git-fixes)
  Alt-commit
- commit b9c791c
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Prevent-potential-buffer-overflow-in.patch (git-fixes)
  Alt-commit
- commit efd4bf7
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amdgpu-Fix-the-runtime-resume-failure-issue.patch (git-fixes)
  Alt-commit
- commit 6ffd9c2
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-fix-null-pointer-dereference-on-edid.patch (git-fixes)
  Alt-commit
- commit 3adc50a
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Fix-memory-leak-in-dm_sw_fini.patch (git-fixes)
  Alt-commit
- commit 1e0a8c4
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Fix-potential-null-pointer-dereferen.patch (git-fixes)
  Alt-commit
- commit e173f6f
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amdgpu-display-Initialize-gamma-correction-mode-.patch (git-fixes)
  Alt-commit
- commit 36a7865
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Fix-possible-NULL-dereference-on-dev.patch (git-fixes)
  Alt-commit
- commit c463983
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/Revert-drm-amd-display-increased-min_dcfclk_mhz-and-.patch (git-fixes)
  Alt-commit
- commit 04c948e
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/Revert-drm-amd-flush-any-delayed-gfxoff-on-suspend-e.patch (git-fixes)
  Alt-commit
- commit 30b9cb6
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-Stop-evicting-resources-on-APUs-in-suspend.patch (git-fixes)
  Alt-commit
- commit 84c8d2c
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Fix-possible-buffer-overflow-in-find.patch (git-fixes)
  Alt-commit
- commit b40ba61
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Fix-possible-use-of-uninitialized-ma.patch (git-fixes)
  Alt-commit
- commit c3f6221
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Initialize-wait_time_microsec-variab.patch (git-fixes)
  Alt-commit
- commit e48d42e
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amdkfd-Fix-L2-cache-size-reporting-in-GFX9.4.3.patch (git-fixes)
  Alt-commit
- commit 2eea2ce
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Implement-bounds-check-for-stream-en.patch (git-fixes)
  Alt-commit
- commit d676a78
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Add-NULL-test-for-timing-generator-i.patch (git-fixes)
  Alt-commit
- commit c8a379e
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Fix-panel_cntl-could-be-null-in-dcn2.patch (git-fixes)
  Alt-commit
- commit 31dbfa0
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amdkfd-reserve-the-BO-before-validating-it.patch (git-fixes)
  Alt-commit
- commit 1aea4a9
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Fix-buffer-overflow-in-get_host_rout.patch (git-fixes)
  Alt-commit
- commit 8ed7043
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Add-NULL-check-for-kzalloc-in-amdgpu.patch (git-fixes)
  Alt-commit
- commit 06e5854
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amdgpu-Fix-missing-error-code-in-gmc_v6-7-8-9_0_.patch (git-fixes)
  Alt-commit
- commit 933ecff
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-Don-t-init-MEC2-firmware-when-it-fails-to-lo.patch (git-fixes)
  Alt-commit
- commit 3901f67
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/Revert-drm-amd-pm-fix-the-high-voltage-and-temperatu.patch (git-fixes)
  Alt-commit
- commit c410dd8
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amdgpu-revert-Adjust-removal-control-flow-for-sm.patch (git-fixes)
  Alt-commit
- commit e2f8984
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Fix-a-switch-statement-in-populate_d.patch (git-fixes)
  Alt-commit
- commit fd4226b
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-bridge-sii902x-Fix-audio-codec-unregistration.patch (git-fixes)
  Alt-commit
- commit eb02c03
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-bridge-sii902x-Fix-probing-race-issue.patch (git-fixes)
  Alt-commit
- commit c6467b6
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-i915-perf-Update-handling-of-MMIO-triggered-repo.patch (git-fixes)
  Alt-commit
- commit c6bd3a5
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-i915-dp-Fix-passing-the-correct-DPCD_REV-for-drm.patch (git-fixes)
  Alt-commit
- commit 7fcb6ca
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Fix-sending-VSC-colorimetry-packets-.patch (git-fixes)
  Alt-commit
- commit 2a5c3b0
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amdgpu-re-create-idle-bo-s-PTE-during-VM-state-m.patch (git-fixes)
  Alt-commit
- commit cce0614
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Restore-guard-against-default-backli.patch (git-fixes)
  Alt-commit
- commit f6c0702
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/1958-drm-amd-display-fix-hw-rotated-modes-when-PSR-SU-is-.patch (git-fixes)
  Alt-commit
- commit e213d83
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/1936-drm-amdgpu-Restrict-extended-wait-to-PSP-v13.0.6.patch (git-fixes)
  Alt-commit
- commit ef2737c
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Increase-frame-warning-limit-with-KA.patch (git-fixes)
  Alt-commit
- commit ad4332b
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amdgpu-disable-MCBP-by-default.patch (git-fixes)
  Alt-commit
- commit 2c67e58
* Tue Mar 19 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-pm-fix-a-memleak-in-aldebaran_tables_init.patch (git-fixes)
  Alt-commit
- commit c8de278
* Tue Mar 19 2024 tiwai@suse.de
- Move upstreamed patches into sorted section
- commit 8b684d5
* Tue Mar 19 2024 tiwai@suse.de
- Move out-of-tree patches into the right sections
- commit 2aa9e6c
* Tue Mar 19 2024 tiwai@suse.de
- Move upstreamed patches into sorted section
- commit cdb27f5
* Tue Mar 19 2024 tiwai@suse.de
- drm/i915: Add missing ; to __assign_str() macros in tracepoint
  code (git-fixes).
- ALSA: hda/realtek: add in quirk for Acer Swift Go 16 - SFG16-71
  (git-fixes).
- Revert "ALSA: usb-audio: Name feature ctl using output if
  input is PCM" (git-fixes).
- ALSA: hda/realtek: Add quirk for Lenovo Yoga 9 14IMH9
  (git-fixes).
- commit fbc9b5f
* Mon Mar 18 2024 jack@suse.cz
- fs: don't assume arguments are non-NULL (bsc#1221044
  CVE-2023-52591).
- commit ec8f09d
* Mon Mar 18 2024 jack@suse.cz
- fs: Restrict lock_two_nondirectories() to non-directory inodes
  (bsc#1221044 CVE-2023-52591).
- commit b103012
* Mon Mar 18 2024 jack@suse.cz
- fs: ocfs2: check status values (bsc#1221044 CVE-2023-52591).
- commit a281985
* Mon Mar 18 2024 jack@suse.cz
- rename(): avoid a deadlock in the case of parents having no
  common ancestor (bsc#1221044 CVE-2023-52591).
- commit ea7137b
* Mon Mar 18 2024 jack@suse.cz
- kill lock_two_inodes() (bsc#1221044 CVE-2023-52591).
- commit 005222f
* Mon Mar 18 2024 jack@suse.cz
- rename(): fix the locking of subdirectories (bsc#1221044
  CVE-2023-52591).
- commit a6484cb
* Mon Mar 18 2024 jack@suse.cz
- f2fs: Avoid reading renamed directory if parent does not change
  (bsc#1221044 CVE-2023-52591).
- commit 3fb2dd8
* Mon Mar 18 2024 jack@suse.cz
- ext4: don't access the source subdirectory content on
  same-directory rename (bsc#1221044 CVE-2023-52591).
- commit ba7d1aa
* Mon Mar 18 2024 jack@suse.cz
- ext2: Avoid reading renamed directory if parent does not change
  (bsc#1221044 CVE-2023-52591).
- commit 65af3c2
* Mon Mar 18 2024 jack@suse.cz
- udf_rename(): only access the child content on cross-directory
  rename (bsc#1221044 CVE-2023-52591).
- commit a29fcb6
* Mon Mar 18 2024 jack@suse.cz
- ocfs2: Avoid touching renamed directory if parent does not
  change (bsc#1221044 CVE-2023-52591).
- Update references in
  patches.suse/reiserfs-Avoid-touching-renamed-directory-if-parent-.patch
  (git-fixes bsc#1221044 CVE-2023-52591).
- commit 0477c34
* Mon Mar 18 2024 tiwai@suse.de
- Update kabi files: adapting kABI changes for ppc64le, too
- commit bf73791
* Mon Mar 18 2024 mfranc@suse.cz
- dcssblk: handle alloc_dax() -EOPNOTSUPP failure (git-fixes
  bsc#1221626).
- commit eaf806c
* Mon Mar 18 2024 mfranc@suse.cz
- s390/cache: prevent rebuild of shared_cpu_list (git-fixes
  bsc#1221625).
- commit d9bc980
* Mon Mar 18 2024 mfranc@suse.cz
- s390/pai: fix attr_event_free upper limit for pai device drivers
  (git-fixes bsc#1221623).
- commit eac0e1f
* Mon Mar 18 2024 mfranc@suse.cz
- KVM: s390: only deliver the set service event bits (git-fixes
  bsc#1221620).
- commit 55838c8
* Mon Mar 18 2024 colyli@suse.de
- dm: treat alloc_dax() -EOPNOTSUPP failure as non-fatal
  (git-fixes).
- dm: call the resume method on internal suspend (git-fixes).
- dm raid: fix false positive for requeue needed during reshape
  (git-fixes).
- dm ioctl: update DM_DRIVER_EMAIL to new dm-devel mailing list
  (git-fixes).
- dm-raid: fix lockdep waring in "pers->hot_add_disk"
  (jsc#PED-7542).
- md/raid5: fix atomicity violation in raid5_cache_count
  (bsc#1219169, CVE-2024-23307).
- dm: dm-zoned: guard blkdev_zone_mgmt with noio scope
  (jsc#PED-7542).
- dm-integrity, dm-verity: reduce stack usage for recheck
  (jsc#PED-7542).
- dm-crypt, dm-integrity, dm-verity: bump target version
  (jsc#PED-7542).
- dm-verity, dm-crypt: align "struct bvec_iter" correctly
  (jsc#PED-7542).
- dm-crypt: recheck the integrity tag after a failure (git-fixes).
- dm-crypt: don't modify the data when using authenticated
  encryption (git-fixes).
- dm-verity: recheck the hash after a failure (git-fixes).
- dm-integrity: recheck the integrity tag after a failure
  (git-fixes).
- md: Fix missing release of 'active_io' for flush (jsc#PED-7542).
- dm-crypt, dm-verity: disable tasklets (git-fixes).
- dm writecache: allow allocations larger than 2GiB
  (jsc#PED-7542).
- dm stats: limit the number of entries (jsc#PED-7542).
- md/raid1: Use blk_opf_t for read and write operations
  (git-fixes).
- md: Fix md_seq_ops() regressions (git-fixes).
- md: Whenassemble the array, consult the superblock of the
  freshest device (git-fixes).
- md/raid1: remove unnecessary null checking (jsc#PED-7542).
- md: synchronize flush io with array reconfiguration (git-fixes).
- commit 7042e1b
* Mon Mar 18 2024 colyli@suse.de
- md/raid5: remove rcu protection to access rdev from conf
  (jsc#PED-7542).
- md/raid1: remove rcu protection to access rdev from conf
  (jsc#PED-7542).
- md/raid10: remove rcu protection to access rdev from conf
  (jsc#PED-7542).
- md: remove flag RemoveSynchronized (jsc#PED-7542).
- dm audit: fix Kconfig so DM_AUDIT depends on BLK_DEV_DM
  (git-fixes).
- dm-integrity: don't modify bio's immutable bio_vec in
  integrity_metadata() (git-fixes).
- commit 1587009
* Mon Mar 18 2024 colyli@suse.de
- raid1: fix use-after-free for original bio in
  raid1_write_request() (bsc#1221097).
- commit 296098e
* Mon Mar 18 2024 mfranc@suse.cz
- Update
  patches.suse/s390-ptrace-handle-setting-of-fpc-register-correctly.patch
  (git-fixes bsc#1219812 CVE-2023-52598 bsc#1221060).
- commit 0d496e7
* Mon Mar 18 2024 mfranc@suse.cz
- Update
  patches.suse/s390-vfio-ap-always-filter-entire-AP-matrix.patch
  (git-fixes bsc#1218988 CVE-2024-26620 bsc#1221298).
- commit b046ad1
* Mon Mar 18 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add testcases for tailcall infinite loop fixing
  (git-fixes).
- bpf, x64: Fix tailcall infinite loop (git-fixes).
- selftests/bpf: Correct map_fd to data_fd in tailcalls
  (git-fixes).
- commit 1302854
* Mon Mar 18 2024 spradhan@suse.de
- btrfs: preallocate temporary extent buffer for inode logging when needed (bsc#1217362).
- commit c7ccbf0
* Mon Mar 18 2024 tiwai@suse.de
- i3c: dw: Disable IBI IRQ depends on hot-join and SIR enabling
  (git-fixes).
- watchdog: stm32_iwdg: initialize default timeout (git-fixes).
- watchdog: starfive: Check pm_runtime_enabled() before
  decrementing usage counter (git-fixes).
- commit 357d510
* Sat Mar 16 2024 tiwai@suse.de
- of: make for_each_property_of_node() available to to !OF
  (git-fixes).
- mtd: rawnand: Constrain even more when continuous reads are
  enabled (git-fixes).
- mtd: rawnand: Fix and simplify again the continuous read
  derivations (git-fixes).
- mtd: rawnand: lpc32xx_mlc: fix irq handler prototype
  (git-fixes).
- mtd: rawnand: meson: fix scrambling mode value in command macro
  (git-fixes).
- mtd: maps: physmap-core: fix flash size larger than 32-bit
  (git-fixes).
- media: usbtv: Remove useless locks in usbtv_video_free()
  (git-fixes).
- media: ttpci: fix two memleaks in budget_av_attach (git-fixes).
- media: go7007: fix a memleak in go7007_load_encoder (git-fixes).
- media: dvb-frontends: avoid stack overflow warnings with clang
  (git-fixes).
- media: pvrusb2: fix uaf in pvr2_context_set_notify (git-fixes).
- media: i2c: imx290: Fix IMX920 typo (git-fixes).
- media: pvrusb2: fix pvr2_stream_callback casts (git-fixes).
- media: pvrusb2: remove redundant NULL check (git-fixes).
- media: go7007: add check of return value of go7007_read_addr()
  (git-fixes).
- media: imx: csc/scaler: fix v4l2_ctrl_handler memory leak
  (git-fixes).
- media: sun8i-di: Fix chroma difference threshold (git-fixes).
- media: sun8i-di: Fix power on/off sequences (git-fixes).
- media: sun8i-di: Fix coefficient writes (git-fixes).
- media: cedrus: h265: Fix configuring bitstream size (git-fixes).
- media: edia: dvbdev: fix a use-after-free (git-fixes).
- media: nxp: imx8-isi: Check whether crossbar pad is non-NULL
  before access (git-fixes).
- media: mc: Add local pad to pipeline regardless of the link
  state (git-fixes).
- net: lan78xx: fix runtime PM count underflow on link stop
  (git-fixes).
- commit 9b93c7d
* Sat Mar 16 2024 tiwai@suse.de
- clk: renesas: r8a779g0: Correct PFC/GPIO parent clocks
  (git-fixes).
- commit 0b0c529
* Sat Mar 16 2024 tiwai@suse.de
- crypto: jitter - fix CRYPTO_JITTERENTROPY help text (git-fixes).
- crypto: qat - remove double initialization of value (git-fixes).
- crypto: qat - avoid division by zero (git-fixes).
- crypto: qat - removed unused macro in adf_cnv_dbgfs.c
  (git-fixes).
- crypto: qat - remove unused macros in qat_comp_alg.c
  (git-fixes).
- crypto: ccp - Avoid discarding errors in
  psp_send_platform_access_msg() (git-fixes).
- crypto: arm/sha - fix function cast warnings (git-fixes).
- crypto: qat - resolve race condition during AER recovery
  (git-fixes).
- crypto: qat - change SLAs cleanup flow at shutdown (git-fixes).
- crypto: xilinx - call finalize with bh disabled (git-fixes).
- clk: imx: imx8mp: Fix SAI_MCLK_SEL definition (git-fixes).
- clk: samsung: exynos850: Propagate SPI IPCLK rate change
  (git-fixes).
- clk: Fix clk_core_get NULL dereference (git-fixes).
- clk: qcom: mmcc-msm8974: fix terminating of frequency table
  arrays (git-fixes).
- clk: qcom: mmcc-apq8084: fix terminating of frequency table
  arrays (git-fixes).
- clk: qcom: gcc-ipq9574: fix terminating of frequency table
  arrays (git-fixes).
- clk: qcom: gcc-ipq8074: fix terminating of frequency table
  arrays (git-fixes).
- clk: qcom: gcc-ipq6018: fix terminating of frequency table
  arrays (git-fixes).
- clk: qcom: dispcc-sdm845: Adjust internal GDSC wait times
  (git-fixes).
- clk: qcom: gcc-sdm845: Add soft dependency on rpmhpd
  (git-fixes).
- clk: meson: Add missing clocks to axg_clk_regmaps (git-fixes).
- clk: keystone: sci-clk: Adding support for non contiguous clocks
  (git-fixes).
- clk: mediatek: mt7981-topckgen: flag SGM_REG_SEL as critical
  (git-fixes).
- clk: mediatek: mt8183: Correct parent of CLK_INFRA_SSPM_32K_SELF
  (git-fixes).
- clk: mediatek: mt8135: Fix an error handling path in
  clk_mt8135_apmixed_probe() (git-fixes).
- clk: hisilicon: hi3559a: Fix an erroneous devm_kfree()
  (git-fixes).
- clk: hisilicon: hi3519: Release the correct number of gates
  in hi3519_clk_unregister() (git-fixes).
- clk: zynq: Prevent null pointer dereference caused by kmalloc
  failure (git-fixes).
- clk: renesas: r8a779f0: Correct PFC/GPIO parent clock
  (git-fixes).
- media: v4l2-mem2mem: fix a memleak in v4l2_m2m_register_entity
  (git-fixes).
- media: v4l2-tpg: fix some memleaks in tpg_alloc (git-fixes).
- media: em28xx: annotate unchecked call to
  media_device_register() (git-fixes).
- media: videobuf2: Fix doc comment (git-fixes).
- media: xc4000: Fix atomicity violation in xc4000_get_frequency
  (git-fixes).
- media: staging: ipu3-imgu: Set fields before
  media_entity_pads_init() (git-fixes).
- commit df2e5ae
* Fri Mar 15 2024 ailiop@suse.com
- xfs: shrink failure needs to hold AGI buffer (git-fixes).
- commit e670f77
* Fri Mar 15 2024 ailiop@suse.com
- xfs: fix imprecise logic in xchk_btree_check_block_owner
  (git-fixes).
- commit 24972c0
* Fri Mar 15 2024 ailiop@suse.com
- xfs: fix SEEK_HOLE/DATA for regions with active COW extents
  (git-fixes).
- commit 4197ae0
* Fri Mar 15 2024 ailiop@suse.com
- xfs: ensure submit buffers on LSN boundaries in error handlers
  (git-fixes).
- commit c23fb7a
* Fri Mar 15 2024 ailiop@suse.com
- afs: Fix endless loop in directory parsing (git-fixes).
- commit d1332b9
* Fri Mar 15 2024 ailiop@suse.com
- afs: Increase buffer size in afs_update_volume_status()
  (git-fixes).
- commit a954f43
* Fri Mar 15 2024 ailiop@suse.com
- nilfs2: fix hang in nilfs_lookup_dirty_data_buffers()
  (git-fixes).
- commit 6c3b10c
* Fri Mar 15 2024 ailiop@suse.com
- nilfs2: convert nilfs_page_mkwrite() to use a folio (git-fixes).
- commit 29291de
* Fri Mar 15 2024 ailiop@suse.com
- erofs: fix handling kern_mount() failure (git-fixes).
- commit ea16f48
* Fri Mar 15 2024 ailiop@suse.com
- erofs: Don't use certain unnecessary folio_*() functions
  (git-fixes).
- commit 021c910
* Fri Mar 15 2024 ailiop@suse.com
- erofs: fix refcount on the metabuf used for inode lookup
  (git-fixes).
- commit 0bf0150
* Fri Mar 15 2024 ailiop@suse.com
- erofs: clean up zmap.c (git-fixes).
- commit 3625a10
* Fri Mar 15 2024 ailiop@suse.com
- erofs: fix up compacted indexes for block size < 4096
  (git-fixes).
- commit 458bf09
* Fri Mar 15 2024 ailiop@suse.com
- erofs: fix memory leak on short-lived bounced pages (git-fixes).
- commit 5efbfc4
* Fri Mar 15 2024 vkarasulli@suse.de
- iommu/amd: Fix failure return from snp_lookup_rmpentry()
  (git-fixes).
- commit 536001e
* Fri Mar 15 2024 ailiop@suse.com
- erofs: allow empty device tags in flatdev mode (git-fixes).
- commit c8ff154
* Fri Mar 15 2024 vkarasulli@suse.de
- iommu/vt-d: Don't issue ATS Invalidation request when device
  is disconnected (git-fixes).
- commit 5d166d5
* Fri Mar 15 2024 mkoutny@suse.com
- net/sched: Add module alias for sch_fq_pie (bsc#1210335).
- commit 211b413
* Fri Mar 15 2024 mkoutny@suse.com
- net/sched: Remove alias of sch_clsact (bsc#1210335).
- net/sched: Load modules via their alias (bsc#1210335).
- net/sched: Add module aliases for cls_,sch_,act_ modules
  (bsc#1210335).
- net/sched: Add helper macros with module names (bsc#1210335).
- commit 2046cfc
* Fri Mar 15 2024 denis.kirjanov@suse.com
- Refresh
  patches.suse/perf-pmu-events-powerpc-Update-json-mapfile-with-Power11-PVR.patch.
- commit 42a5ace
* Fri Mar 15 2024 denis.kirjanov@suse.com
- ionic: restore netdev feature bits after reset (git-fixes).
- commit 898af71
* Fri Mar 15 2024 denis.kirjanov@suse.com
- ionic: check cmd_regs before copying in or out (git-fixes).
- commit f1dc989
* Fri Mar 15 2024 denis.kirjanov@suse.com
- ionic: check before releasing pci regions (git-fixes).
- commit 2a1c23c
* Fri Mar 15 2024 denis.kirjanov@suse.com
- net: veth: clear GRO when clearing XDP even when down (git-fixes).
- commit 553eb02
* Fri Mar 15 2024 denis.kirjanov@suse.com
- tun: Fix xdp_rxq_info's queue_index when detaching (git-fixes).
- commit b7d1001
* Fri Mar 15 2024 denis.kirjanov@suse.com
- net: dpaa: fman_memac: accept phy-interface-type = "10gbase-r" in the device tree (git-fixes).
- commit 675b36c
* Fri Mar 15 2024 denis.kirjanov@suse.com
- ice: Fix ASSERT_RTNL() warning during certain scenarios (git-fixes).
- commit 8b9399e
* Fri Mar 15 2024 denis.kirjanov@suse.com
- ice: fix pin phase adjust updates on PF reset (git-fixes).
- commit ef21fc4
* Fri Mar 15 2024 denis.kirjanov@suse.com
- ice: fix dpll periodic work data updates on PF reset (git-fixes).
- commit dc97d19
* Fri Mar 15 2024 denis.kirjanov@suse.com
- ice: fix dpll and dpll_pin data access on PF reset (git-fixes).
- commit f610e32
* Fri Mar 15 2024 denis.kirjanov@suse.com
- ice: fix dpll input pin phase_adjust value updates (git-fixes).
- commit cfb9c02
* Fri Mar 15 2024 denis.kirjanov@suse.com
- ice: fix connection state of DPLL and out pin (git-fixes).
- commit 7176021
* Fri Mar 15 2024 denis.kirjanov@suse.com
- net: sparx5: Add spinlock for frame transmission from CPU (git-fixes).
- commit 2486a16
* Fri Mar 15 2024 denis.kirjanov@suse.com
- gtp: fix use-after-free and null-ptr-deref in gtp_genl_dump_pdp() (git-fixes).
- commit 86d216d
* Fri Mar 15 2024 denis.kirjanov@suse.com
- net: ipa: don't overrun IPA suspend interrupt registers (git-fixes).
- commit 7f00d73
* Fri Mar 15 2024 denis.kirjanov@suse.com
- ethernet: cpts: fix function pointer cast warnings (git-fixes).
- commit d241bc1
* Fri Mar 15 2024 denis.kirjanov@suse.com
- net: ethernet: ti: cpsw_new: enable mac_managed_pm to fix mdio (git-fixes).
- commit 229f845
* Fri Mar 15 2024 denis.kirjanov@suse.com
- ppp_async: limit MRU to 64K (git-fixes).
- commit 463471e
* Fri Mar 15 2024 denis.kirjanov@suse.com
- nfp: enable NETDEV_XDP_ACT_REDIRECT feature flag (git-fixes).
- commit 36e79a9
* Fri Mar 15 2024 tiwai@suse.de
- ALSA: hda/tas2781: remove unnecessary runtime_pm calls
  (git-fixes).
- ALSA: hda/realtek - ALC236 fix volume mute & mic mute LED on
  some HP models (git-fixes).
- ALSA: hda/realtek: fix ALC285 issues on HP Envy x360 laptops
  (git-fixes).
- ALSA: hda: Reuse for_each_pcm_streams() (git-fixes).
- ALSA: usb-audio: Name feature ctl using output if input is PCM
  (git-fixes).
- commit fdd39ea
* Fri Mar 15 2024 tiwai@suse.de
- ALSA: hda/realtek: Add quirks for various HP ENVY models
  (git-fixes).
- commit 62207c4
* Fri Mar 15 2024 tiwai@suse.de
- ALSA: hda/realtek: Add "Intel Reference board" SSID in the
  ALC256 (git-fixes).
- ALSA: hda/realtek: Remove two HP Laptops using CS35L41
  (git-fixes).
- ALSA: hda: cs35l41: Support HP models without _DSD using dual
  Speaker ID (git-fixes).
- ALSA: hda: cs35l41: Support additional HP Envy Models
  (git-fixes).
- ALSA: hda/realtek: Add quirks for HP G11 Laptops using CS35L56
  (git-fixes).
- ALSA: hda: realtek: Re-work CS35L41 fixups to re-use for other
  amps (git-fixes).
- commit c4f7d5a
* Fri Mar 15 2024 tiwai@suse.de
- nilfs2: prevent kernel bug at submit_bh_wbc() (git-fixes).
- nilfs2: fix failure to detect DAT corruption in btree and
  direct mappings (git-fixes).
- selftests/mm: protection_keys: save/restore nr_hugepages
  settings (git-fixes).
- selftests/mm: hugetlb_reparenting_test: do not unmount
  (git-fixes).
- selftests/mm: dont fail testsuite due to a lack of hugepages
  (git-fixes).
- modules: wait do_free_init correctly (git-fixes).
- PCI: qcom: Enable BDF to SID translation properly (git-fixes).
- PCI: dwc: endpoint: Fix advertised resizable BAR size
  (git-fixes).
- PCI: brcmstb: Fix broken brcm_pcie_mdio_write() polling
  (git-fixes).
- PCI: switchtec: Fix an error handling path in
  switchtec_pci_probe() (git-fixes).
- PCI/P2PDMA: Fix a sleeping issue in a RCU read section
  (git-fixes).
- PCI: Mark 3ware-9650SE Root Port Extended Tags as broken
  (git-fixes).
- PCI/DPC: Print all TLP Prefixes, not just the first (git-fixes).
- pci_iounmap(): Fix MMIO mapping leak (git-fixes).
- PCI/AER: Fix rootport attribute paths in ABI docs (git-fixes).
- platform/mellanox: mlxreg-hotplug: Remove redundant NULL-check
  (git-fixes).
- platform/x86/intel/tpmi: Change vsec offset to u64 (git-fixes).
- Revert "platform/x86: asus-wmi: Support WMI event queue"
  (git-fixes).
- leds: sgm3140: Add missing timer cleanup and flash gpio control
  (git-fixes).
- Revert "leds: Only descend into leds directory when
  CONFIG_NEW_LEDS is set" (git-fixes).
- leds: aw2013: Unlock mutex before destroying it (git-fixes).
- mfd: altera-sysmgr: Call of_node_put() only when
  of_parse_phandle() takes a ref (git-fixes).
- mfd: syscon: Call of_node_put() only when of_parse_phandle()
  takes a ref (git-fixes).
- pinctrl: renesas: r8a779g0: Add missing SCIF_CLK2 pin
  group/function (git-fixes).
- pinctrl: mediatek: Drop bogus slew rate register range for
  MT8192 (git-fixes).
- pinctrl: mediatek: Drop bogus slew rate register range for
  MT8186 (git-fixes).
- HID: lenovo: Add middleclick_workaround sysfs knob for cptkbd
  (git-fixes).
- HID: amd_sfh: Avoid disabling the interrupt (git-fixes).
- commit a95f20c
* Fri Mar 15 2024 tiwai@suse.de
- ALSA: usb-audio: Stop parsing channels bits when all channels
  are found (git-fixes).
- ALSA: aaci: Delete unused variable in aaci_do_suspend
  (git-fixes).
- ASoC: meson: axg-tdm-interface: add frame rate constraint
  (git-fixes).
- ASoC: meson: axg-tdm-interface: fix mclk setup without mclk-fs
  (git-fixes).
- ASoC: SOF: Add some bounds checking to firmware data
  (git-fixes).
- ASoC: meson: t9015: fix function pointer type mismatch
  (git-fixes).
- ASoC: meson: aiu: fix function pointer type mismatch
  (git-fixes).
- ASoC: sh: rz-ssi: Fix error message print (git-fixes).
- ASoC: SOF: amd: Fix memory leak in amd_sof_acp_probe()
  (git-fixes).
- ASoC: amd: acp: Add missing error handling in sof-mach
  (git-fixes).
- ALSA: hda/tas2781: restore power state after system_resume
  (git-fixes).
- ALSA: hda/tas2781: do not call pm_runtime_force_* in
  system_resume/suspend (git-fixes).
- ALSA: hda/tas2781: do not reset cur_* values in runtime_suspend
  (git-fixes).
- ALSA: hda/tas2781: add lock to system_suspend (git-fixes).
- ALSA: hda/tas2781: use dev_dbg in system_resume (git-fixes).
- ALSA: seq: fix function cast warnings (git-fixes).
- ALSA: aw2: avoid casting function pointers (git-fixes).
- ALSA: ctxfi: avoid casting function pointers (git-fixes).
- ALSA: hda: cs35l41: Set Channel Index correctly when system
  is missing _DSD (git-fixes).
- backlight: lp8788: Fully initialize backlight_properties during
  probe (git-fixes).
- backlight: lm3639: Fully initialize backlight_properties during
  probe (git-fixes).
- backlight: da9052: Fully initialize backlight_properties during
  probe (git-fixes).
- backlight: lm3630a: Don't set bl->props.brightness in
  get_brightness (git-fixes).
- backlight: lm3630a: Initialize backlight_properties on init
  (git-fixes).
- backlight: ktz8866: Correct the check for of_property_read_u32
  (git-fixes).
- backlight: hx8357: Fix potential NULL pointer dereference
  (git-fixes).
- gpio: nomadik: fix offset bug in nmk_pmx_set() (git-fixes).
- HID: amd_sfh: Update HPD sensor structure elements (git-fixes).
- commit 428d278
* Fri Mar 15 2024 ohering@suse.de
- Drivers: hv: vmbus: Update indentation in create_gpadl_header()
  (git-fixes).
- Drivers: hv: vmbus: Remove duplication and cleanup code in
  create_gpadl_header() (git-fixes).
- Drivers: hv: vmbus: Calculate ring buffer size for more
  efficient use of memory (git-fixes).
- hv_utils: Allow implicit ICTIMESYNCFLAG_SYNC (git-fixes).
- minmax: relax check to allow comparison between unsigned
  arguments (git-fixes).
- minmax: allow comparisons of 'int' against 'unsigned char/short'
  (git-fixes).
- minmax: fix indentation of __cmp_once() and __clamp_once()
  (git-fixes).
- minmax: allow min()/max()/clamp() if the arguments have the same
  (git-fixes).
- minmax: add umin(a, b) and umax(a, b) (git-fixes).
- minmax: fix header inclusions (git-fixes).
- minmax: deduplicate __unconst_integer_typeof() (git-fixes).
- minmax: Introduce {min,max}_array() (git-fixes).
- commit 7632d3b
* Thu Mar 14 2024 tiwai@suse.de
- Update patch reference for IDXD fix (bsc#1221428)
- commit 20b42d0
* Thu Mar 14 2024 nik.borisov@suse.com
- KVM/x86: Export RFDS_NO and RFDS_CLEAR to guests (bsc#1213456 CVE-2023-28746).
- commit a59ffeb
* Thu Mar 14 2024 nik.borisov@suse.com
- x86/rfds: Mitigate Register File Data Sampling (RFDS) (bsc#1213456 CVE-2023-28746).
- commit c210394
* Thu Mar 14 2024 nik.borisov@suse.com
- Documentation/hw-vuln: Add documentation for RFDS (bsc#1213456 CVE-2023-28746).
- commit 0f1938a
* Thu Mar 14 2024 nik.borisov@suse.com
- x86/mmio: Disable KVM mitigation when X86_FEATURE_CLEAR_CPU_BUF is set (bsc#1213456 CVE-2023-28746).
- commit 52997cc
* Thu Mar 14 2024 vkarasulli@suse.de
- iommu/amd: Mark interrupt as managed (git-fixes).
- commit 5ef4be8
* Thu Mar 14 2024 iivanov@suse.de
- arm64: dts: imx8mm-kontron: Refactor devicetree for OSM-S module and (git-fixes)
- commit 0049d8d
* Thu Mar 14 2024 msuchanek@suse.de
- Update ppc64le kabi files.
- commit 5c9702d
* Thu Mar 14 2024 iivanov@suse.de
- arm64: dts: sprd: Change UMS512 idle-state nodename to match bindings (git-fixes)
- commit 58013ba
* Thu Mar 14 2024 iivanov@suse.de
- arm64: dts: rockchip: drop rockchip,trcm-sync-tx-only from rk3588 i2s (git-fixes)
- commit b287ab6
* Thu Mar 14 2024 iivanov@suse.de
- arm64: dts: rockchip: fix reset-names for rk356x i2s2 controller (git-fixes)
- commit bfdd563
* Thu Mar 14 2024 iivanov@suse.de
- arm64: dts: rockchip: add missing interrupt-names for rk356x vdpu (git-fixes)
- commit b9c1de2
* Thu Mar 14 2024 iivanov@suse.de
- arm64: dts: imx8mp: Set SPI NOR to max 40 MHz on Data Modul i.MX8M (git-fixes)
- commit 5a00002
* Thu Mar 14 2024 iivanov@suse.de
- arm64: dts: imx8mm-venice-gw71xx: fix USB OTG VBUS (git-fixes)
- commit a9642be
* Thu Mar 14 2024 iivanov@suse.de
- arm64: dts: imx8mm-kontron: Fix OSM-S devicetrees to match latest (git-fixes)
- commit d17e1b2
* Thu Mar 14 2024 iivanov@suse.de
- arm64: dts: imx8mm-kontron: Fix interrupt for RTC on OSM-S i.MX8MM (git-fixes)
- commit 63e3e05
* Thu Mar 14 2024 iivanov@suse.de
- arm64: dts: imx8mm-kontron: Disable pull resistors for SD card (git-fixes)
- commit 645b123
* Thu Mar 14 2024 iivanov@suse.de
- arm64: dts: imx8mm-kontron: Disable pull resistors for SD card (git-fixes)
- commit 63490f6
* Thu Mar 14 2024 iivanov@suse.de
- arm64: dts: imx8mm-kontron: Disable pullups for onboard UART signals (git-fixes)
- commit 980bc4a
* Thu Mar 14 2024 iivanov@suse.de
- arm64: dts: imx8mm-kontron: Disable pullups for onboard UART signals (git-fixes)
- commit 3a04f44
* Thu Mar 14 2024 iivanov@suse.de
- arm64: dts: imx8mm-kontron: Disable pullups for I2C signals on SL/BL (git-fixes)
- commit d23e2ff
* Thu Mar 14 2024 iivanov@suse.de
- arm64: dts: imx8mm-kontron: Disable pullups for I2C signals on OSM-S (git-fixes)
- commit e658d8c
* Thu Mar 14 2024 iivanov@suse.de
- arm64: dts: allwinner: h6: Add RX DMA channel for SPDIF (git-fixes)
- commit 8098072
* Thu Mar 14 2024 iivanov@suse.de
- arm64: tegra: Fix Tegra234 MGBE power-domains (git-fixes)
- commit 58db13b
* Thu Mar 14 2024 iivanov@suse.de
- arm64: dts: imx8mp: Fix LDB clocks property (git-fixes)
- commit 8815925
* Thu Mar 14 2024 iivanov@suse.de
- arm64: dts: rockchip: set num-cs property for spi on px30 (git-fixes)
- commit ac8cd44
* Thu Mar 14 2024 iivanov@suse.de
- arm64: dts: imx8mp: Disable UART4 by default on Data Modul i.MX8M (git-fixes)
- commit d39bc86
* Thu Mar 14 2024 iivanov@suse.de
- arm64: dts: sprd: Add clock reference for pll2 on UMS512 (git-fixes)
- commit 8ef3da3
* Thu Mar 14 2024 iivanov@suse.de
- arm64: zynqmp: Fix clock node name in kv260 cards (git-fixes)
- commit 49dfade
* Thu Mar 14 2024 iivanov@suse.de
- arm64: zynqmp: Move fixed clock to / for kv260 (git-fixes)
- commit 8a08b0f
* Thu Mar 14 2024 lhenriques@suse.de
- libceph: init the cursor when preparing sparse read in msgr2
  (bsc#1221393).
- ceph: switch to corrected encoding of max_xattr_size in mdsmap
  (bsc#1221392).
- ceph: prevent use-after-free in encode_cap_msg() (bsc#1221391).
- libceph: just wait for more data to be available on the socket
  (bsc#1221390).
- libceph: rename read_sparse_msg_*() to
  read_partial_sparse_msg_*() (bsc#1221389).
- libceph: fail sparse-read if the data length doesn't match
  (bsc#1221388).
- commit 088fe3e
* Thu Mar 14 2024 iivanov@suse.de
- Make NVIDIA Grace-Hopper TPM related drivers build-ins (bsc#1221156)
- commit 32745a0
* Thu Mar 14 2024 tiwai@suse.de
- kabi/severities: ignore intel_tcc_get_temp() change (git-fixes)
- commit 62d327d
* Thu Mar 14 2024 tiwai@suse.de
- thermal/intel: Fix intel_tcc_get_temp() to support negative
  CPU temperature (git-fixes).
- commit 6dc4a23
* Thu Mar 14 2024 tiwai@suse.de
- memfd: drop warning for missing exec-related flags
  (bsc#1221161).
- commit 68995fe
* Thu Mar 14 2024 tiwai@suse.de
- gpiolib: Pass consumer device through to core in
  devm_fwnode_gpiod_get_index() (git-fixes).
- commit 446d465
* Thu Mar 14 2024 tiwai@suse.de
- drm/msm/dpu: add division of drm_display_mode's hskew parameter
  (git-fixes).
- media: tc358743: register v4l2 async device only after
  successful setup (git-fixes).
- tpm,tpm_tis: Avoid warning splat at shutdown (git-fixes).
- powercap: dtpm_cpu: Fix error check against
  freq_qos_add_request() (git-fixes).
- powercap: intel_rapl_tpmi: Fix a register bug (git-fixes).
- powercap: intel_rapl: Fix a NULL pointer dereference
  (git-fixes).
- PM: sleep: wakeirq: fix wake irq warning in system suspend
  (git-fixes).
- PM: suspend: Set mem_sleep_current during kernel command line
  setup (git-fixes).
- selftest: gpio: remove obsolete gpio-mockup test (git-fixes).
- gpio: vf610: allow disabling the vf610 driver (git-fixes).
- regulator: userspace-consumer: add module device table
  (git-fixes).
- mmc: core: Fix switch on gp3 partition (git-fixes).
- mmc: wmt-sdmmc: remove an incorrect release_mem_region()
  call in the .remove function (git-fixes).
- mmc: tmio: avoid concurrent runs of mmc_request_done()
  (git-fixes).
- pwm: mediatek: Update kernel doc for struct pwm_mediatek_of_data
  (git-fixes).
- pwm: sti: Fix capture for st,pwm-num-chan < st,capture-num-chan
  (git-fixes).
- commit 7ae9bb9
* Thu Mar 14 2024 tiwai@suse.de
- Add cherry-picked id to amdgpu patch
- commit 1ec0805
* Thu Mar 14 2024 tiwai@suse.de
- drm/etnaviv: Restore some id values (git-fixes).
- drm/amd/pm: Fix esm reg mask use to get pcie speed (git-fixes).
- drm/amdgpu: Fix missing break in ATOM_ARG_IMM Case of
  atom_get_src_int() (git-fixes).
- Revert "drm/amdgpu: Add pcie usage callback to nbio"
  (git-fixes).
- Revert "drm/amdgpu: Add pci usage to nbio v7.9" (git-fixes).
- drm/msm/a7xx: Fix LLC typo (git-fixes).
- drm/msm/dpu: finalise global state object (git-fixes).
- drm/msm/dpu: Only enable DSC_MODE_MULTIPLEX if dsc_merge is
  enabled (git-fixes).
- drm/msm/dpu: fix the programming of INTF_CFG2_DATA_HCTL_EN
  (git-fixes).
- drm/msm/dpu: improve DSC allocation (git-fixes).
- drm/mediatek: Fix a null pointer crash in
  mtk_drm_crtc_finish_page_flip (git-fixes).
- drm/mediatek: dsi: Fix DSI RGB666 formats and definitions
  (git-fixes).
- drm/tests: helpers: Include missing drm_drv header (git-fixes).
- drm/tidss: Fix sync-lost issue with two displays (git-fixes).
- drm/tidss: Fix initial plane zpos values (git-fixes).
- drm/tegra: put drm_gem_object ref on error in tegra_fb_create
  (git-fixes).
- drm/bridge: adv7511: fix crash on irq during probe (git-fixes).
- drm/panel: boe-tv101wum-nl6: make use of prepare_prev_first
  (git-fixes).
- drm/amd/display: Add 'replay' NULL check in
  'edp_set_replay_allow_active()' (git-fixes).
- drm/amd/display: fix NULL checks for adev->dm.dc in
  amdgpu_dm_fini() (git-fixes).
- drm/radeon/ni: Fix wrong firmware size logging in
  ni_init_microcode() (git-fixes).
- drm: ci: use clk_ignore_unused for apq8016 (git-fixes).
- Revert "drm/i915/xe2lpd: Treat cursor plane as regular plane
  for DDB allocation" (git-fixes).
- drm/amdgpu: Fix potential out-of-bounds access in
  'amdgpu_discovery_reg_base_init()' (git-fixes).
- drm/amd/display: Fix potential NULL pointer dereferences in
  'dcn10_set_output_transfer_func()' (git-fixes).
- drm/amd/display: Fix a potential buffer overflow in
  'dp_dsc_clock_en_read()' (git-fixes).
- drm/radeon/ni_dpm: remove redundant NULL check (git-fixes).
- drm/radeon: remove dead code in ni_mc_load_microcode()
  (git-fixes).
- drm/vmwgfx: Fix the lifetime of the bo cursor memory
  (git-fixes).
- drm/vmwgfx: Fix vmw_du_get_cursor_mob fencing of newly-created
  MOBs (git-fixes).
- drm/vmwgfx: Fix possible null pointer derefence with invalid
  contexts (git-fixes).
- drm/lima: fix a memleak in lima_heap_alloc (git-fixes).
- drm/panel-edp: use put_sync in unprepare (git-fixes).
- drm/rockchip: lvds: do not print scary message when probing
  defer (git-fixes).
- drm/rockchip: lvds: do not overwrite error code (git-fixes).
- drm/vmwgfx: Unmap the surface before resetting it on a plane
  state (git-fixes).
- drm/vmwgfx: fix a memleak in vmw_gmrid_man_get_node (git-fixes).
- drm/vkms: Avoid reading beyond LUT array (git-fixes).
- drm: Don't treat 0 as -1 in drm_fixp2int_ceil (git-fixes).
- drm/rockchip: inno_hdmi: Fix video timing (git-fixes).
- drm/tegra: output: Fix missing i2c_put_adapter() in the error
  handling paths of tegra_output_probe() (git-fixes).
- drm/tegra: rgb: Fix missing clk_put() in the error handling
  paths of tegra_dc_rgb_probe() (git-fixes).
- drm/tegra: rgb: Fix some error handling paths in
  tegra_dc_rgb_probe() (git-fixes).
- drm/tegra: hdmi: Fix some error handling paths in
  tegra_hdmi_probe() (git-fixes).
- drm/tegra: dsi: Fix missing pm_runtime_disable() in the error
  handling path of tegra_dsi_probe() (git-fixes).
- drm/tegra: dsi: Fix some error handling paths in
  tegra_dsi_probe() (git-fixes).
- drm/tegra: dpaux: Fix PM disable depth imbalance in
  tegra_dpaux_probe (git-fixes).
- drm/tegra: dsi: Add missing check for of_find_device_by_node
  (git-fixes).
- ACPI: processor_idle: Fix memory leak in
  acpi_processor_power_exit() (git-fixes).
- ACPI: resource: Add MAIBENBEN X577 to
  irq1_edge_low_force_override (git-fixes).
- ACPI: scan: Fix device check notification handling (git-fixes).
- ACPI: CPPC: enable AMD CPPC V2 support for family 17h processors
  (git-fixes).
- cpufreq: qcom-hw: add CONFIG_COMMON_CLK dependency (git-fixes).
- cpufreq: brcmstb-avs-cpufreq: add check for cpufreq_cpu_get's
  return value (git-fixes).
- cpufreq: Limit resolving a frequency to policy min/max
  (git-fixes).
- cpufreq: amd-pstate: Fix min_perf assignment in
  amd_pstate_adjust_perf() (git-fixes).
- commit 451635c
* Thu Mar 14 2024 nik.borisov@suse.com
- RAS: Export helper to get ras_debugfs_dir (jsc#PED-7619).
- commit ddeebbf
* Wed Mar 13 2024 msuchanek@suse.de
- powerpc/64s: Fix get_hugepd_cache_index() build failure
  (bsc#1215199).
- powerpc: Remove cpu-as-y completely (bsc#1215199).
- powerpc/64s: Use .machine power4 around dcbt (bsc#1215199).
- powerpc/64s: Move dcbt/dcbtst sequence into a macro
  (bsc#1215199).
- powerpc/pseries: Fix potential memleak in papr_get_attr()
  (bsc#1215199).
- powerpc/kprobes: Handle error returned by set_memory_rox()
  (bsc#1215199).
- powerpc: Implement set_memory_rox() (bsc#1215199).
- powerpc: Use user_mode() macro when possible (bsc#1215199).
- powerpc/rtas: use correct function name for resetting TCE tables
  (bsc#1215199).
- commit 35dba53
* Wed Mar 13 2024 fdmanana@suse.com
- btrfs: avoid copying BTRFS_ROOT_SUBVOL_DEAD flag to snapshot
  of subvolume being deleted (bsc#1221282).
- commit adc8e1b
* Wed Mar 13 2024 fdmanana@suse.com
- btrfs: don't abort filesystem when attempting to snapshot
  deleted subvolume (bsc#1221282).
- commit 7de0be8
* Wed Mar 13 2024 tiwai@suse.de
- Fix missing initial value for tcp pingpong threshold (bsc#1221339,bsc#1221305,bsc#1221032,bsc#1221261)
  This caused high latencies leading to various network issues
- commit de6f6b8
* Wed Mar 13 2024 nik.borisov@suse.com
- RAS/AMD/FMPM: Fix off by one when unwinding on error (jsc#PED-7619).
- commit 083602e
* Wed Mar 13 2024 nik.borisov@suse.com
- RAS/AMD/FMPM: Add debugfs interface to print record entries (jsc#PED-7619).
- commit 1a5e647
* Wed Mar 13 2024 nik.borisov@suse.com
- RAS/AMD/FMPM: Save SPA values (jsc#PED-7619).
- commit 4072c0c
* Wed Mar 13 2024 tiwai@suse.de
- Bluetooth: Fix eir name length (git-fixes).
- wifi: mac80211: update scratch_pos after defrag (git-fixes).
- wifi: mac80211: track capability/opmode NSS separately
  (git-fixes).
- wifi: mt76: mt792x: fix a potential loading failure of the
  6Ghz channel config from ACPI (git-fixes).
- wifi: mt76: mt7921e: fix use-after-free in free_irq()
  (git-fixes).
- wifi: iwlwifi: mvm: fix warnings from dmi_get_system_info()
  (git-fixes).
- wifi: wilc1000: fix RCU usage in connect path (git-fixes).
- commit 76a6eff
* Wed Mar 13 2024 tiwai@suse.de
- gpu/host1x kABI workaround (git-fixes).
- commit 86a9dbb
* Wed Mar 13 2024 tiwai@suse.de
- gpu: host1x: Skip reset assert on Tegra186 (git-fixes).
- commit 88887cf
* Wed Mar 13 2024 tiwai@suse.de
- drm/nouveau: don't fini scheduler before entity flush
  (git-fixes).
- commit 3d3c54d
* Wed Mar 13 2024 mgorman@suse.de
- futex: Prevent the reuse of stale pi_state (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit ba092a4
* Wed Mar 13 2024 mgorman@suse.de
- srcu: Use try-lock lockdep annotation for NMI-safe access
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- futex/pi: Fix recursive rt_mutex waiter state (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- srcu: Remove extraneous parentheses from srcu_read_lock() etc
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit e04ae5b
* Wed Mar 13 2024 tiwai@suse.de
- Update config files: refresh for x86_64 and armv7hl
- commit 8a3dfcc
* Wed Mar 13 2024 oneukum@suse.com
- r8152: fix unknown device for choose_configuration (git-fixes).
- commit 71e2f25
* Wed Mar 13 2024 iivanov@suse.de
- Update patches.suse/arm64-sme-Always-exit-sme_alloc-early-with-existing-.patch (git-fixes, CVE-2024-26618)
  Add reference to CVE-2024-26618.
- commit 50882e3
* Wed Mar 13 2024 tiwai@suse.de
- bluetooth hci_uart_register_device() kABI workaround
  (git-fixes).
- commit 2fcc10e
* Wed Mar 13 2024 tiwai@suse.de
- net: phy: dp83822: Fix RGMII TX delay configuration (git-fixes).
- net: phy: fix phy_get_internal_delay accessing an empty array
  (git-fixes).
- Bluetooth: btnxpuart: Fix btnxpuart_close (git-fixes).
- Bluetooth: af_bluetooth: Fix deadlock (git-fixes).
- Bluetooth: hci_core: Fix possible buffer overflow (git-fixes).
- Bluetooth: btrtl: fix out of bounds memory access (git-fixes).
- Bluetooth: hci_h5: Add ability to allocate memory for private
  data (git-fixes).
- Bluetooth: hci_qca: don't use IS_ERR_OR_NULL() with
  gpiod_get_optional() (git-fixes).
- Bluetooth: hci_event: Fix not indicating new connection for
  BIG Sync (git-fixes).
- Bluetooth: Remove superfluous call to hci_conn_check_pending()
  (git-fixes).
- Bluetooth: mgmt: Remove leftover queuing of power_off work
  (git-fixes).
- Bluetooth: Remove HCI_POWER_OFF_TIMEOUT (git-fixes).
- wifi: brcm80211: handle pmk_op allocation failure (git-fixes).
- wifi: rtw88: 8821c: Fix false alarm count (git-fixes).
- wifi: rtw88: 8821c: Fix beacon loss and disconnect (git-fixes).
- wifi: rtw88: 8821cu: Fix firmware upload fail (git-fixes).
- wifi: mt76: mt7921: fix incorrect type conversion for CLC
  command (git-fixes).
- wifi: mt76: mt7996: fix HIF_TXD_V2_1 value (git-fixes).
- wifi: mt76: mt7996: fix efuse reading issue (git-fixes).
- wifi: mt76: mt7996: fix HE beamformer phy cap for station vif
  (git-fixes).
- wifi: mt76: mt7996: fix incorrect interpretation of EHT MCS caps
  (git-fixes).
- wifi: mt76: mt7996: fix TWT issues (git-fixes).
- sr9800: Add check for usbnet_get_endpoints (git-fixes).
- wifi: ath12k: fix incorrect logic of calculating vdev_stats_id
  (git-fixes).
- wifi: ath11k: initialize rx_mcs_80 and rx_mcs_160 before use
  (git-fixes).
- wifi: ath11k: change to move WMI_VDEV_PARAM_SET_HEMU_MODE
  before WMI_PEER_ASSOC_CMDID (git-fixes).
- wifi: ath9k: delay all of ath9k_wmi_event_tasklet() until init
  is complete (git-fixes).
- wifi: wilc1000: revert reset line logic flip (git-fixes).
- wifi: brcmsmac: avoid function pointer casts (git-fixes).
- wifi: wilc1000: prevent use-after-free on vif when cleaning
  up all interfaces (git-fixes).
- wifi: iwlwifi: mvm: Fix the listener MAC filter flags
  (git-fixes).
- wifi: iwlwifi: mvm: don't set replay counters to 0xff
  (git-fixes).
- wifi: iwlwifi: mvm: don't set the MFP flag for the GTK
  (git-fixes).
- wifi: iwlwifi: mvm: fix erroneous queue index mask (git-fixes).
- wifi: iwlwifi: support EHT for WH (git-fixes).
- wifi: wfx: fix memory leak when starting AP (git-fixes).
- wifi: brcmsmac: Drop legacy header (git-fixes).
- wifi: libertas: fix some memleaks in lbs_allocate_cmd_buffer()
  (git-fixes).
- wifi: iwlwifi: read BIOS PNVM only for non-Intel SKU
  (git-fixes).
- wifi: iwlwifi: mvm: fix the TLC command after ADD_STA
  (git-fixes).
- wifi: iwlwifi: mvm: use FW rate for non-data only on new devices
  (git-fixes).
- wifi: iwlwifi: mvm: d3: fix IPN byte order (git-fixes).
- wifi: iwlwifi: fix EWRD table validity check (git-fixes).
- wifi: iwlwifi: mvm: initialize rates in FW earlier (git-fixes).
- wifi: iwlwifi: acpi: fix WPFC reading (git-fixes).
- wifi: iwlwifi: dbg-tlv: ensure NUL termination (git-fixes).
- wifi: iwlwifi: mvm: report beacon protection failures
  (git-fixes).
- wifi: brcmfmac: fix copyright year mentioned in platform_data
  header (git-fixes).
- wifi: ath12k: Fix issues in channel list update (git-fixes).
- wifi: ath10k: fix NULL pointer dereference in
  ath10k_wmi_tlv_op_pull_mgmt_tx_compl_ev() (git-fixes).
- can: softing: remove redundant NULL check (git-fixes).
- wifi: brcmfmac: avoid invalid list operation when vendor attach
  fails (git-fixes).
- wifi: mwifiex: debugfs: Drop unnecessary error check for
  debugfs_create_dir() (git-fixes).
- wifi: wilc1000: fix multi-vif management when deleting a vif
  (git-fixes).
- wifi: wilc1000: do not realloc workqueue everytime an interface
  is added (git-fixes).
- wifi: rtl8xxxu: add cancel_work_sync() for c2hcmd_work
  (git-fixes).
- wifi: b43: Disable QoS for bcm4331 (git-fixes).
- wifi: b43: Stop correct queue in DMA worker when QoS is disabled
  (git-fixes).
- wifi: b43: Stop/wake correct queue in PIO Tx path when QoS is
  disabled (git-fixes).
- wifi: b43: Stop/wake correct queue in DMA Tx path when QoS is
  disabled (git-fixes).
- doc-guide: kernel-doc: tell about object-like macros
  (git-fixes).
- soc: qcom: llcc: Check return value on Broadcast_OR reg read
  (git-fixes).
- soc: qcom: socinfo: rename PM2250 to PM4125 (git-fixes).
- bus: tegra-aconnect: Update dependency to ARCH_TEGRA
  (git-fixes).
- firmware: arm_scmi: Fix double free in SMC transport cleanup
  path (git-fixes).
- commit d454c2c
* Wed Mar 13 2024 tiwai@suse.de
- Move upstreamed patches into sorted section
- commit 5709f5a
* Wed Mar 13 2024 tiwai@suse.de
- Move upstreamed patches into sorted section
- commit 612fa2e
* Wed Mar 13 2024 iivanov@suse.de
- arm_pmu: acpi: Add a representative platform device for TRBE (bsc#1220587)
- commit e433e12
* Wed Mar 13 2024 iivanov@suse.de
- arm_pmu: acpi: Refactor arm_spe_acpi_register_device() (bsc#1220587)
- commit c36cae4
* Wed Mar 13 2024 iivanov@suse.de
- coresight: trbe: Enable ACPI based TRBE devices (bsc#1220587)
- commit 0aa88dd
* Wed Mar 13 2024 iivanov@suse.de
- coresight: trbe: Add a representative coresight_platform_data for (bsc#1220587)
- commit 4d64f51
* Wed Mar 13 2024 iivanov@suse.de
- coresight: trbe: Allocate platform data per device (bsc#1220587)
- commit fd3964b
* Wed Mar 13 2024 ddiss@suse.de
- selinux: only filter copy-up xattrs following initialization
  (bsc#1210690).
- commit f42baec
* Wed Mar 13 2024 neilb@suse.de
- NFS: Fix data corruption caused by congestion (git-fixes).
- pNFS: Fix the pnfs block driver's calculation of layoutget size
  (git-fixes).
- NFSv4.1: fixup use EXCHGID4_FLAG_USE_PNFS_DS for DS server
  (git-fixes).
- NFS: Fix O_DIRECT locking issues (git-fixes).
- commit b64b15f
* Wed Mar 13 2024 neilb@suse.de
- nfsd: don't take fi_lock in nfsd_break_deleg_cb() (git-fixes).
- SUNRPC: fix _xprt_switch_find_current_entry logic (git-fixes).
- NFSv4.1/pnfs: Ensure we handle the error NFS4ERR_RETURNCONFLICT
  (git-fixes).
- NFS: Use parent's objective cred in nfs_access_login_time()
  (git-fixes).
- blocklayoutdriver: Fix reference leak of pnfs_device_node
  (git-fixes).
- SUNRPC: Fix a suspicious RCU usage warning (git-fixes).
- NFSD: Fix "start of NFS reply" pointer passed to
  nfsd_cache_update() (git-fixes).
- NFSD: Update nfsd_cache_append() to use xdr_stream (git-fixes).
- nfsd: fix file memleak on client_opens_release (git-fixes).
- SUNRPC: Fix RPC client cleaned up the freed pipefs dentries
  (git-fixes).
- NFSv4.1: fix SP4_MACH_CRED protection for pnfs IO (git-fixes).
- SUNRPC: Add an IS_ERR() check back to where it was (git-fixes).
- NFSv4.1: fix handling NFS4ERR_DELAY when testing for session
  trunking (git-fixes).
- SUNRPC: ECONNRESET might require a rebind (git-fixes).
- svcrdma: Drop connection after an RDMA Read error (git-fixes).
- nfsd: Handle EOPENSTALE correctly in the filecache (git-fixes).
- nfsd: lock_rename() needs both directories to live on the same
  fs (git-fixes).
- pNFS/flexfiles: Check the layout validity in
  ff_layout_mirror_prepare_stats (git-fixes).
- pNFS: Fix a hang in nfs4_evict_inode() (git-fixes).
- NFS: Fix potential oops in nfs_inode_remove_request()
  (git-fixes).
- nfs42: client needs to strip file mode's suid/sgid bit after
  ALLOCATE op (git-fixes).
- nfs: decrement nrequests counter before releasing the req
  (git-fixes).
- SUNRPC/TLS: Lock the lower_xprt during the tls handshake
  (git-fixes).
- Revert "SUNRPC dont update timeout value on connection reset"
  (git-fixes).
- NFSv4: Fix a state manager thread deadlock regression
  (git-fixes).
- NFSv4: Fix a nfs4_state_manager() race (git-fixes).
- SUNRPC: Fail quickly when server does not recognize TLS
  (git-fixes).
- NFSv4.1: fix zero value filehandle in post open getattr
  (git-fixes).
- NFS: More fixes for nfs_direct_write_reschedule_io()
  (git-fixes).
- NFS: Use the correct commit info in nfs_join_page_group()
  (git-fixes).
- NFS: More O_DIRECT accounting fixes for error paths (git-fixes).
- NFS: Fix error handling for O_DIRECT write scheduling
  (git-fixes).
- nfsd: fix change_info in NFSv4 RENAME replies (git-fixes).
- NFSv4.1: use EXCHGID4_FLAG_USE_PNFS_DS for DS server
  (git-fixes).
- NFS: Fix a potential data corruption (git-fixes).
- NFSv4/pnfs: minor fix for cleanup path in nfs4_get_device_info
  (git-fixes).
- commit e298a32
* Tue Mar 12 2024 lhenriques@suse.de
- Update
  patches.suse/ceph-fix-deadlock-or-deadcode-of-misusing-dget.patch
  (bsc#1220453 bsc#1221058 CVE-2023-52583).
- commit 25befcc
* Tue Mar 12 2024 mgorman@suse.de
- sched/fair: Combine EAS check with overutilized access
  (bsc#1221157).
- sched/fair: Use helper function to access rd->overutilized
  (bsc#1221157).
- sched/fair: Add EAS checks before updating overutilized
  (bsc#1221157).
- commit c66ccdb
* Tue Mar 12 2024 lhenriques@suse.de
- netfs, fscache: Prevent Oops in fscache_put_cache() (bsc#1221291
  CVE-2024-26612).
- commit f4e9666
* Tue Mar 12 2024 vbabka@suse.cz
- mm, vmscan: prevent infinite loop for costly GFP_NOIO |
  __GFP_RETRY_MAYFAIL allocations (git-fixes).
- commit 36fac6a
* Tue Mar 12 2024 vbabka@suse.cz
- mm: migrate high-order folios in swap cache correctly
  (git-fixes).
- commit 46a5bb6
* Tue Mar 12 2024 vbabka@suse.cz
- mm/mempolicy: fix set_mempolicy_home_node() previous VMA pointer
  (git-fixes).
- commit 436bfc9
* Tue Mar 12 2024 vbabka@suse.cz
- Refresh patches.suse/mm-mmap-fix-vma_merge-case-7.patch.
- commit 442a3e7
* Tue Mar 12 2024 denis.kirjanov@suse.com
- bonding: return -ENOMEM instead of BUG in alb_upper_dev_walk
  (git-fixes).
- commit bffce9c
* Tue Mar 12 2024 denis.kirjanov@suse.com
- nfp: flower: prevent re-adding mac index for bonded port (git-fixes).
- commit 6661999
* Tue Mar 12 2024 denis.kirjanov@suse.com
- nfp: use correct macro for LengthSelect in BAR config (git-fixes).
- commit 7d0aeec
* Tue Mar 12 2024 denis.kirjanov@suse.com
- tsnep: Fix mapping for zero copy XDP_TX action (git-fixes).
- commit 3345825
* Tue Mar 12 2024 denis.kirjanov@suse.com
- net: atlantic: Fix DMA mapping for PTP hwts ring (git-fixes).
- commit b00604d
* Tue Mar 12 2024 denis.kirjanov@suse.com
- netdevsim: avoid potential loop in nsim_dev_trap_report_work() (git-fixes).
- commit 57a7091
* Tue Mar 12 2024 denis.kirjanov@suse.com
- net: stmmac: Prevent DSA tags from breaking COE (git-fixes).
- commit e8cc0c0
* Tue Mar 12 2024 tiwai@suse.de
- Move out-of-tree patches into the right section
- commit 6624840
* Tue Mar 12 2024 tiwai@suse.de
- Documentation: virt: Fix up pre-formatted text block for SEV
  ioctls (git-fixes).
- commit b6867f0
* Tue Mar 12 2024 tiwai@suse.de
- Move upstreamed patches into sorted section
- commit 489fc6e
* Tue Mar 12 2024 tiwai@suse.de
- crypto: ccp - Have it depend on AMD_IOMMU (git-fixes).
- rtc: test: Fix invalid format specifier (git-fixes).
- lib: memcpy_kunit: Fix an invalid format specifier in an
  assertion msg (git-fixes).
- lib/cmdline: Fix an invalid format specifier in an assertion
  msg (git-fixes).
- selftests/mqueue: Set timeout to 180 seconds (git-fixes).
- Documentation: coresight: fix `make refcheckdocs` warning
  (git-fixes).
- commit 2c8fcdc
* Tue Mar 12 2024 neilb@suse.de
- Refresh patches.suse/nfsd-fix-RELEASE_LOCKOWNER.patch.
  update mainline commit info
- commit 2c149c7
* Mon Mar 11 2024 denis.kirjanov@suse.com
- amt: do not use overwrapped cb area (git-fixes).
- commit 1372aac
* Mon Mar 11 2024 denis.kirjanov@suse.com
- bonding: remove print in bond_verify_device_path (git-fixes).
- commit 7a54f95
* Mon Mar 11 2024 denis.kirjanov@suse.com
- stmmac: preserve KABI in stmmac_txq_cfg (git-fixes).
- commit 034b0ac
* Mon Mar 11 2024 denis.kirjanov@suse.com
- net: stmmac: Tx coe sw fallback (git-fixes).
- commit d5cf563
* Mon Mar 11 2024 msuchanek@suse.de
- powerpc/pseries/iommu: IOMMU table is not initialized for
  kdump over SR-IOV (bsc#1220492 ltc#205270).
- commit 2026089
* Mon Mar 11 2024 oneukum@suse.com
- Update
  patches.suse/usb-hub-Guard-against-accesses-to-uninitialized-BOS-.patch
  (bsc#1220790 CVE-2023-52477).
  Added CVE
- commit 61b1ebd
* Mon Mar 11 2024 dwagner@suse.de
- nvmet-fc: take ref count on tgtport before delete assoc
  (git-fixes).
- nvmet-fc: avoid deadlock on delete association path (git-fixes).
- nvmet-fc: abort command when there is no binding (git-fixes).
- nvmet-fc: hold reference on hostport match (git-fixes).
- nvmet-fc: defer cleanup using RCU properly (git-fixes).
- nvmet-fc: release reference on target port (git-fixes).
- nvmet-fcloop: swap the list_add_tail arguments (git-fixes).
- nvme-fc: do not wait in vain when unloading module (git-fixes).
- nvmet-tcp: fix nvme tcp ida memory leak (git-fixes).
- commit 53c6a83
* Sun Mar 10 2024 tiwai@suse.de
- i2c: aspeed: Fix the dummy irq expected print (git-fixes).
- i2c: wmt: Fix an error handling path in wmt_i2c_probe()
  (git-fixes).
- i2c: i801: Avoid potential double call to
  gpiod_remove_lookup_table (git-fixes).
- commit 5a2966b
* Sun Mar 10 2024 dfaggioli@suse.com
- s390/vfio-ap: wire in the vfio_device_ops request callback
  (bsc#1205316).
- Refresh
  patches.suse/vfio-iommufd-Add-detach_ioas-support-for-emulated-VFIO-devices.
- commit c62972b
* Sat Mar  9 2024 lduncan@suse.com
- scsi: target: iscsi: don't warn of R/W when no data
  (bsc#1215541).
- scsi: target: iscsi: handle SCSI immediate commands
  (bsc#1215541).
- commit ed0e112
* Sat Mar  9 2024 tiwai@suse.de
- Fix missing initialization in mt7921* drivers (bsc#1221114)
  Refresh patches.suse/wifi-mt76-move-struct-ieee80211_chanctx_conf-up-to-s.patch
- commit ecd5297
* Sat Mar  9 2024 tiwai@suse.de
- ASoC: wm8962: Fix up incorrect error message in wm8962_set_fll
  (git-fixes).
- ASoC: wm8962: Enable both SPKOUTR_ENA and SPKOUTL_ENA in mono
  mode (git-fixes).
- ASoC: wm8962: Enable oscillator if selecting WM8962_FLL_OSC
  (git-fixes).
- ASoC: amd: yc: Add HP Pavilion Aero Laptop 13-be2xxx(8BD6)
  into DMI quirk table (git-fixes).
- ASoC: Intel: bytcr_rt5640: Add an extra entry for the Chuwi
  Vi8 tablet (git-fixes).
- ALSA: hda: cs35l41: Overwrite CS35L41 configuration for ASUS
  UM5302LA (git-fixes).
- ALSA: hda/realtek: Add quirks for Lenovo Thinkbook 16P laptops
  (git-fixes).
- ALSA: hda: cs35l41: Support Lenovo Thinkbook 16P (git-fixes).
- ALSA: hda: optimize the probe codec process (git-fixes).
- commit 5c5002a
* Sat Mar  9 2024 tiwai@suse.de
- ALSA: hda/realtek: fix mute/micmute LEDs for HP EliteBook
  (git-fixes).
- ALSA: hda/realtek - Add Headset Mic supported Acer NB platform
  (git-fixes).
- commit 0303741
* Sat Mar  9 2024 tiwai@suse.de
- mei: gsc_proxy: match component when GSC is on different bus
  (git-fixes).
- misc: fastrpc: Pass proper arguments to scm call (git-fixes).
- comedi: comedi_test: Prevent timers rescheduling during deletion
  (git-fixes).
- misc: lis3lv02d_i2c: Fix regulators getting en-/dis-abled
  twice on suspend/resume (git-fixes).
- iio: accel: adxl367: fix I2C FIFO data register (git-fixes).
- iio: accel: adxl367: fix DEVID read after reset (git-fixes).
- iio: pressure: dlhl60d: Initialize empty DLH bytes (git-fixes).
- counter: fix privdata alignment (git-fixes).
- Revert "tty: serial: simplify
  qcom_geni_serial_send_chunk_fifo()" (git-fixes).
- tty: serial: fsl_lpuart: avoid idle preamble pending if CTS
  is enabled (git-fixes).
- vt: fix unicode buffer corruption when deleting characters
  (git-fixes).
- serial: 8250_dw: Do not reclock if already at correct rate
  (git-fixes).
- tty: serial: imx: Fix broken RS485 (git-fixes).
- xhci: Fix failure to detect ring expansion need (git-fixes).
- usb: port: Don't try to peer unused USB ports based on location
  (git-fixes).
- usb: gadget: ncm: Fix handling of zero block length packets
  (git-fixes).
- usb: typec: altmodes/displayport: create sysfs nodes as driver's
  default device attribute group (git-fixes).
- usb: typec: tpcm: Fix PORT_RESET behavior for self powered
  devices (git-fixes).
- USB: usb-storage: Prevent divide-by-0 error in
  isd200_ata_command (git-fixes).
- thunderbolt: Fix NULL pointer dereference in
  tb_port_update_credits() (git-fixes).
- Input: synaptics-rmi4 - fix UAF of IRQ domain on driver removal
  (git-fixes).
- ASoC: rcar: adg: correct TIMSEL setting for SSI9 (git-fixes).
- ASoC: madera: Fix typo in madera_set_fll_clks shift value
  (git-fixes).
- ALSA: hda/realtek - Fix headset Mic no show at resume back
  for Lenovo ALC897 platform (git-fixes).
- drm/nouveau: fix stale locked mutex in nouveau_gem_ioctl_pushbuf
  (git-fixes).
- drm/panel: boe-tv101wum-nl6: Fine tune Himax83102-j02 panel
  HFP and HBP (again) (git-fixes).
- drm: Fix output poll work for drm_kms_helper_poll=n (git-fixes).
- drm/amd/display: check dc_link before dereferencing (git-fixes).
- drm/i915/selftests: Fix dependency of some timeouts on HZ
  (git-fixes).
- drm/i915: Don't explode when the dig port we don't have an
  AUX CH (git-fixes).
- drm/i915: Check before removing mm notifier (git-fixes).
- drm/i915/hdcp: Extract hdcp structure from correct connector
  (git-fixes).
- drm/i915/hdcp: Remove additional timing for reading mst hdcp
  message (git-fixes).
- drm/i915/hdcp: Move to direct reads for HDCP (git-fixes).
- commit e4dbdb4
* Sat Mar  9 2024 ailiop@suse.com
- erofs: apply proper VMA alignment for memory mapped files on
  THP (git-fixes).
- commit f883467
* Fri Mar  8 2024 msuchanek@suse.de
- powerpc: Add PVN support for HeXin C2000 processor
  (jsc#PED-7970).
- Refresh patches.suse/powerpc-Add-Power11-architected-and-raw-mode.patch
- commit 840aeb4
* Fri Mar  8 2024 jbohac@suse.cz
- Refresh
  patches.suse/x86-e820-Don-t-reserve-SETUP_RNG_SEED-in-e820.patch
- commit cca30de
* Thu Mar  7 2024 tonyj@suse.de
- perf/pmu-events/powerpc: Update json mapfile with Power11 PVR
  (jsc#PED-7970 jsc#PED-8065).
- powerpc/perf: Power11 Performance Monitoring support
  (jsc#PED-7970 jsc#PED-8065).
- perf vendor events powerpc: Add PVN for HX-C2000 CPU with
  Power8 Architecture (jsc#PED-7970 jsc#PED-8065).
- commit b9d5dfb
* Thu Mar  7 2024 msuchanek@suse.de
- group-source-files.pl: Quote filenames (boo#1221077).
  The kernel source now contains a file with a space in the name.
  Add quotes in group-source-files.pl to avoid splitting the filename.
  Also use -print0 / -0 when updating timestamps.
- commit a005e42
* Thu Mar  7 2024 msuchanek@suse.de
- Revert "git-sort: Add io_uring 6.3 fixes remote"
  This reverts commit 6392287eb4bd8f99419025c617f5a9b7ce323a79.
  Remove version-specific branch.
- commit e463564
* Thu Mar  7 2024 tiwai@suse.de
- gpio: fix resource unwinding order in error path (git-fixes).
- commit 6156605
* Thu Mar  7 2024 tiwai@suse.de
- gpiolib: Fix the error path order in
  gpiochip_add_data_with_key() (git-fixes).
- commit e072cb0
* Thu Mar  7 2024 tiwai@suse.de
- gpio: 74x164: Enable output pins after registers are reset
  (git-fixes).
- kbuild: Add -Wa,--fatal-warnings to as-instr invocation
  (git-fixes).
- efivarfs: Request at most 512 bytes for variable names
  (git-fixes).
- ASoC: qcom: Fix uninitialized pointer dmactl (git-fixes).
- drm/amd/display: Add monitor patch for specific eDP (git-fixes).
- soc: qcom: pmic_glink: Fix boot when QRTR=m (git-fixes).
- commit 43e9ac3
* Thu Mar  7 2024 iivanov@suse.de
- Update patches.suse/PCI-MSI-Prevent-MSI-hardware-interrupt-number-trunca.patch (git-fixes,bsc#1218777)
- commit 7d27d0e
* Thu Mar  7 2024 iivanov@suse.de
- Update patches.suse/phy-ti-phy-omap-usb2-Fix-NULL-pointer-dereference-fo.patch (git-fixes,bsc#1220340,CVE-2024-26600)
- commit 6950641
* Wed Mar  6 2024 msuchanek@suse.de
- powerpc: Add Power11 architected and raw mode (jsc#PED-7970).
- powerpc: Annotate endianness of various variables and functions
  (jsc#PED-7970).
- commit 1346447
* Wed Mar  6 2024 iivanov@suse.de
- Update patches.suse/arm64-errata-Add-Cortex-A520-speculative-unprivilege.patch (git-fixes, bsc#1219443, bsc#1220887, CVE-2023-52481)
- commit f753e1f
* Wed Mar  6 2024 msuchanek@suse.de
- kernel-binary: Fix i386 build
  Fixes: 89eaf4cdce05 ("rpm templates: Move macro definitions below buildrequires")
- commit f7c6351
* Wed Mar  6 2024 jslaby@suse.cz
- x86/sgx: Resolves SECS reclaim vs. page fault for EAUG race
  (bsc#1220941 CVE-2023-52568).
- x86/mm, kexec, ima: Use memblock_free_late() from
  ima_free_kexec_buffer() (bsc#1220872 CVE-2023-52576).
- commit 94e020b
* Wed Mar  6 2024 mfranc@suse.cz
- Revert "Update config files.  Deactivate CONFIG_QETH_OSX on s390x.  (jsc#PED-3317)"
  This reverts commit 84140c6f0d4586d5df743a4b87554fe794b51392.
  IBM wants to disable CONFIG_QETH_OSX only for ALP and SLE16 while
  keeping it enabled on SLE15-SP6.
- commit 0cf6eff
* Wed Mar  6 2024 mfranc@suse.cz
- Update patches.suse/KVM-s390-fix-setting-of-fpc-register.patch
  (git-fixes bsc#1219809 bsc#1221040 CVE-2023-52597).
- commit b4fa9cc
* Wed Mar  6 2024 msuchanek@suse.de
- kernel-binary: vdso: fix filelist for non-usrmerged kernel
  Fixes: a6ad8af207e6 ("rpm templates: Always define usrmerged")
- commit fb3f221
* Wed Mar  6 2024 lhenriques@suse.de
- Update
  patches.suse/netfs-Only-call-folio_start_fscache-one-time-for-each-folio.patch
  (bsc#1216954 CVE-2023-52582 bsc#1220878).
- commit 87168e9
* Wed Mar  6 2024 shung-hsi.yu@suse.com
- Update reference of bpf-sockmap-Reject-sk_msg-egress-redirects-to-non-TC.patch
  (jsc#PED-6811 bsc#1220926 CVE-2023-52523).
- commit f24dbf6
* Wed Mar  6 2024 lhenriques@suse.de
- Update
  patches.suse/ceph-drop-messages-from-MDS-when-unmounting.patch
  (jsc#SES-1880 CVE-2022-48628 bsc#1220848).
- commit 4c5beb1
* Wed Mar  6 2024 tiwai@suse.de
- rpm/kernel-binary.spec.in: Fix the build error without usrmerged
- commit d396cc8
* Wed Mar  6 2024 tiwai@suse.de
- integrity: eliminate unnecessary "Problem loading X.509
  certificate" msg (git-fixes).
- commit f764d63
* Wed Mar  6 2024 ailiop@suse.com
- erofs: fix memory leak of LZMA global compressed deduplication
  (bsc#1220897 CVE-2023-52526).
- commit ff061f8
* Wed Mar  6 2024 tonyj@suse.de
- perf: Fix the nr_addr_filters fix (git-fixes).
- commit 4903a69
* Tue Mar  5 2024 wqu@suse.com
- btrfs: scrub: avoid use-after-free when chunk length is not
  64K aligned (bsc#1220943 CVE-2024-26616).
- commit d7e7877
* Tue Mar  5 2024 tonyj@suse.de
- perf/core: Fix narrow startup race when creating the perf
  nr_addr_filters sysfs file (git-fixes).
- commit 6f5ad58
* Tue Mar  5 2024 fdmanana@suse.com
- btrfs: remove BUG() after failure to insert delayed dir index
  item (bsc#1220918 CVE-2023-52569).
- commit 898c18d
* Tue Mar  5 2024 fdmanana@suse.com
- btrfs: improve error message after failure to add delayed dir
  index item (bsc#1220918 CVE-2023-52569).
- commit d4e730e
* Tue Mar  5 2024 tbogendoerfer@suse.de
- Update
  patches.suse/ice-Fix-some-null-pointer-dereference-issues-in-ice_.patch
  (jsc#PED-4876 bsc#1220424 CVE-2023-52471).
- Update
  patches.suse/msft-hv-2888-net-mana-Fix-TX-CQE-error-handling.patch
  (bsc#1220932 CVE-2023-52532).
- Update
  patches.suse/team-fix-null-ptr-deref-when-team-device-type-is-cha.patch
  (bsc#1220870 CVE-2023-52574).
  Added CVE references.
- commit cdd1907
* Tue Mar  5 2024 msuchanek@suse.de
- Update patches.suse/powerpc-pseries-memhp-Fix-access-beyond-end-of-drmem.patch
  (bsc#1065729 bsc#1220250 CVE-2023-52451).
- commit e456ff0
* Tue Mar  5 2024 tiwai@suse.de
- vfio/mdev: Fix a null-ptr-deref bug for mdev_unregister_parent()
  (CVE-2023-52570 bsc#1220925).
- commit 8dc5811
* Tue Mar  5 2024 shung-hsi.yu@suse.com
- bpf: fix check for attempt to corrupt spilled pointer
  (bsc#1220325 CVE-2023-52462).
- commit eb74527
* Tue Mar  5 2024 tiwai@suse.de
- Update patch referece for wifi fix (CVE-2023-52530 bsc#1220930)
- commit 04f251c
* Tue Mar  5 2024 tiwai@suse.de
- Update patch reference for iwlwifi fix (CVE-2023-52531 bsc#1220931)
- commit 3e108ac
* Tue Mar  5 2024 shung-hsi.yu@suse.com
- kABI: bpf: struct bpf_prog_aux kABI workaround (jsc#PED-6811
  bsc#1220251).
- commit a7547b0
* Tue Mar  5 2024 shung-hsi.yu@suse.com
- selftests/bpf: Test re-attachment fix for
  bpf_tracing_prog_attach (jsc#PED-6811 bsc#1220254).
- bpf: Fix re-attachment branch in bpf_tracing_prog_attach
  (bsc#1220254 CVE-2024-26591).
- selftests/bpf: Add test for recursive attachment of tracing
  progs (bsc#1220254 CVE-2024-26591).
- bpf: Relax tracing prog recursive attach rules (jsc#PED-6811
  bsc#1220254).
- commit aba9ef6
* Tue Mar  5 2024 tiwai@suse.de
- drm/i915/dp: Limit SST link rate to <=8.1Gbps (git-fixes).
- drm/nouveau: nvkm_gsp_radix3_sg() should use nvkm_gsp_mem_ctor()
  (git-fixes).
- nouveau/gsp: handle engines in runl without nonstall interrupts
  (git-fixes).
- drm/msm/dpu: Add mutex lock in control vblank irq (git-fixes).
- drm/msm/dpu: populate SSPP scaler block version (git-fixes).
- drm/msm/dpu: Correct UBWC settings for sc8280xp (git-fixes).
- drm/msm/dpu: enable SmartDMA on SM8450 (git-fixes).
- drm/msm/a690: Fix reg values for a690 (git-fixes).
- drm/i915/display: Move releasing gem object away from fb
  tracking (git-fixes).
- commit ca552ce
* Tue Mar  5 2024 tiwai@suse.de
- drm/amd/display: Fix DPSTREAM CLK on and off sequence
  (git-fixes).
- commit d79529f
* Tue Mar  5 2024 jslaby@suse.cz
- x86/srso: Add SRSO mitigation for Hygon processors (bsc#1220735
  CVE-2023-52482).
- commit 1d10b80
* Tue Mar  5 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-sii902x-Fix-probing-race-issue.patch (git-fixes bsc#1220736 CVE-2024-26607).
- commit 8bc333c
* Tue Mar  5 2024 tiwai@suse.de
- drm/amd/display: Refactor DMCUB enter/exit idle interface
  (git-fixes).
- Refresh
  patches.suse/drm-amd-display-Fix-potential-null-pointer-dereferen.patch.
- commit 3154e27
* Tue Mar  5 2024 tiwai@suse.de
- drm/amd/display: Only allow dig mapping to pwrseq in new asic
  (git-fixes).
- drm/amd/display: Fix array-index-out-of-bounds in dcn35_clkmgr
  (git-fixes).
- drm/amd/display: Implement bounds check for stream encoder
  creation in DCN301 (git-fixes).
- drm/amdgpu: Avoid fetching VRAM vendor info (git-fixes).
- drm/amd/display: Fix dcn35 8k30 Underflow/Corruption Issue
  (git-fixes).
- drm/amd/display: fix incorrect mpc_combine array size
  (git-fixes).
- drm/amd/display: fix USB-C flag update after enc10 feature init
  (git-fixes).
- drm/amd/display: Disable ips before dc interrupt setting
  (git-fixes).
- drm/amdgpu/gfx11: set UNORD_DISPATCH in compute MQDs
  (git-fixes).
- drm/amdgpu/gfx10: set UNORD_DISPATCH in compute MQDs
  (git-fixes).
- drm/amd/amdgpu: Assign GART pages to AMD device mapping
  (git-fixes).
- drm/amd/pm: Fetch current power limit from FW (git-fixes).
- drm/amdgpu: Show vram vendor only if available (git-fixes).
- drm/amd/pm: update the power cap setting (git-fixes).
- drm/amdgpu: Avoid fetching vram vendor information (git-fixes).
- drm/amdgpu: Enable GFXOFF for Compute on GFX11 (git-fixes).
- drm/amd/display: Fix DML2 watermark calculation (git-fixes).
- drm/amd/display: Clear OPTC mem select on disable (git-fixes).
- drm/amd/display: Add logging resource checks (git-fixes).
- drm/amd/display: Init link enc resources in dc_state only if
  res_pool presents (git-fixes).
- drm/amd/pm: Fix smuv13.0.6 current clock reporting (git-fixes).
- drm/amd/pm: Add error log for smu v13.0.6 reset (git-fixes).
- drm/amdgpu: drop exp hw support check for GC 9.4.3 (git-fixes).
- drm/amdgpu: update regGL2C_CTRL4 value in golden setting
  (git-fixes).
- Revert "drm/amd/display: Fix conversions between bytes and KB"
  (git-fixes).
- drm/amd/display: Disconnect phantom pipe OPP from OPTC being
  disabled (git-fixes).
- drm/amd/display: To adjust dprefclk by down spread percentage
  (git-fixes).
- drm/amdgpu: Fix variable 'mca_funcs' dereferenced before NULL
  check in 'amdgpu_mca_smu_get_mca_entry()' (git-fixes).
- drm/amdgpu: Fix possible NULL dereference in
  amdgpu_ras_query_error_status_helper() (git-fixes).
- drm/amd/display: Fix hang/underflow when transitioning to ODM4:1
  (git-fixes).
- drm/amd/display: Fix lightup regression with DP2 single display
  configs (git-fixes).
- drm/amd/display: Wake DMCUB before executing GPINT commands
  (git-fixes).
- drm/amd/display: Wake DMCUB before sending a command
  (CVE-2023-52485 bsc#1220835 git-fixes).
- drm/amd/display: fix usb-c connector_type (git-fixes).
- drm/amd/display: do not send commands to DMUB if DMUB is
  inactive from S3 (git-fixes).
- drm/amdgpu: Enable tunneling on high-priority compute queues
  (git-fixes).
- drm/amd/display: Check writeback connectors in
  create_validate_stream_for_sink (git-fixes).
- drm/amd/display: Use drm_connector in create_stream_for_sink
  (git-fixes).
- drm/amd/display: Return drm_connector from
  find_first_crtc_matching_connector (git-fixes).
- drm/amd/display: add support for DTO genarated dscclk
  (git-fixes).
- drm/amd/display: Fix Replay Desync Error IRQ handler
  (git-fixes).
- drm/amd/display: Fix disable_otg_wa logic (git-fixes).
- drm/amd/display: Fix conversions between bytes and KB
  (git-fixes).
- drm/amd/display: update pixel clock params after stream slice
  count change in context (git-fixes).
- drm/amd/display: Fix a debugfs null pointer error (git-fixes).
- commit 36bc980
* Tue Mar  5 2024 nstange@suse.de
- crypto: jitter - use permanent health test storage
  (bsc#1220682).
- commit 7d19449
* Tue Mar  5 2024 nstange@suse.de
- crypto: jitter - reuse allocated entropy collector
  (bsc#1220684).
- commit 5e1fcb3
* Tue Mar  5 2024 nstange@suse.de
- crypto: jitter - Allow configuration of memory size
  (bsc#1220684).
- Update config files.
- commit b193722
* Tue Mar  5 2024 nstange@suse.de
- crypto: jitter - add RCT/APT support for different OSRs
  (bsc#1220682 bsc#1220684).
- commit a0d26ea
* Tue Mar  5 2024 nstange@suse.de
- crypto: jitter - Add clarifying comments to Jitter Entropy
  RCT cutoff values (bsc#1220682 bsc#1220684).
- commit 94bdba9
* Tue Mar  5 2024 mhocko@suse.com
- mm/mremap: allow moves within the same VMA for stack moves
  (bsc#1220914).
- mm/mremap: optimize the start addresses in move_page_tables()
  (bsc#1220914).
- commit 3c1f239
* Tue Mar  5 2024 mkubecek@suse.cz
- tls: fix use-after-free on failed backlog decryption
  (CVE-2024-26584 bsc#1220186).
- tls: separate no-async decryption request handling from async
  (CVE-2024-26584 bsc#1220186).
- tls: decrement decrypt_pending if no async completion will be
  called (CVE-2024-26584 bsc#1220186).
- net: tls: handle backlogging of crypto requests (CVE-2024-26584
  bsc#1220186).
- commit 2199323
* Tue Mar  5 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add test for alu on PTR_TO_FLOW_KEYS (bsc#1220255
  CVE-2024-26589).
- bpf: Reject variable offset alu on PTR_TO_FLOW_KEYS (bsc#1220255
  CVE-2024-26589).
- commit da059bb
* Tue Mar  5 2024 ddiss@suse.de
- ovl: fix failed copyup of fileattr on a symlink (bsc#1220827).
- commit c247a4e
* Tue Mar  5 2024 mkubecek@suse.cz
- tls: fix race between tx work scheduling and socket close
  (CVE-2024-26585 bsc#1220187).
- commit 98f57ea
* Tue Mar  5 2024 mkubecek@suse.cz
- tls: fix race between async notify and socket close
  (CVE-2024-26583 bsc#1220185).
- net: tls: factor out tls_*crypt_async_wait() (CVE-2024-26583
  bsc#1220185).
- commit ebb58c6
* Mon Mar  4 2024 mkubecek@suse.cz
- netfilter: nf_tables: fix 64-bit load issue in
  nft_byteorder_eval() (CVE-2024-0607 bsc#1218915).
- netfilter: nf_tables: fix pointer math issue in
  nft_byteorder_eval() (CVE-2024-0607 bsc#1218915).
- commit d0b1efb
* Mon Mar  4 2024 ailiop@suse.com
- erofs: fix lz4 inplace decompression (bsc#1220879
  CVE-2023-52497).
- commit 1ab6d98
* Mon Mar  4 2024 ailiop@suse.com
- erofs: get rid of the remaining kmap_atomic() (git-fixes).
- commit 17e3c9c
* Mon Mar  4 2024 mkubecek@suse.cz
- netfilter: nft_set_pipapo: skip inactive elements during set
  walk (CVE-2023-6817 bsc#1218195).
- commit 20cd5f2
* Mon Mar  4 2024 nstange@suse.de
- crypto: jitter - replace LFSR with SHA3-256 (bsc#1220331).
- Update config files.
- commit 586f7f5
* Mon Mar  4 2024 tiwai@suse.de
- Update patch reference for tomoyo fix (CVE-2024-26622 bsc#1220825)
- commit 1d9cb5b
* Mon Mar  4 2024 petr.pavlu@suse.com
- doc/README.SUSE: Update information about module support status
  (jsc#PED-5759)
  Following the code change in SLE15-SP6 to have externally supported
  modules no longer taint the kernel, update the respective documentation
  in README.SUSE:
  * Describe that support status can be obtained at runtime for each
  module from /sys/module/$MODULE/supported and for the entire system
  from /sys/kernel/supported. This provides a way how to now check that
  the kernel has any externally supported modules loaded.
  * Remove a mention that externally supported modules taint the kernel,
  but keep the information about bit 16 (X) and add a note that it is
  still tracked per module and can be read from
  /sys/module/$MODULE/taint. This per-module information also appears in
  Oopses.
- commit 9ed8107
* Mon Mar  4 2024 nstange@suse.de
- Refresh patches.suse/0002-crypto-populate-downstream-list-of-drivers-unapprove.patch.
  Enable and refresh
    patches.suse/0002-crypto-populate-downstream-list-of-drivers-unapprove.patch
- commit 46942fd
* Mon Mar  4 2024 tiwai@suse.de
- Bluetooth: btmtk: Add MODULE_FIRMWARE() for MT7922
  (bsc#1214133).
- commit abbbfc6
* Mon Mar  4 2024 fdmanana@suse.com
- btrfs: fix race between reading a directory and adding entries
  to it (bsc#1219315).
- commit a8cff4f
* Mon Mar  4 2024 shung-hsi.yu@suse.com
- bpf: Minor cleanup around stack bounds (bsc#1220257
  CVE-2023-52452).
- bpf: Fix accesses to uninit stack slots (bsc#1220257
  CVE-2023-52452).
- bpf: Add some comments to stack representation (bsc#1220257
  CVE-2023-52452).
- bpf: Guard stack limits against 32bit overflow (git-fixes).
- bpf: Fix verification of indirect var-off stack access
  (git-fixes).
- bpf: Minor logging improvement (bsc#1220257).
- commit f480bf8
* Mon Mar  4 2024 fdmanana@suse.com
- btrfs: refresh dir last index during a rewinddir(3) call
  (bsc#1219315).
- commit 5fd0a18
* Mon Mar  4 2024 fdmanana@suse.com
- btrfs: set last dir index to the current last index when
  opening dir (bsc#1219315).
- commit 21aedc5
* Mon Mar  4 2024 jslaby@suse.cz
- Update
  patches.suse/PCI-ASPM-Fix-deadlock-when-enabling-ASPM.patch
  (git-fixes bsc#1220336 CVE-2024-26605).
- Update
  patches.suse/serial-8250-omap-Don-t-skip-resource-freeing-if-pm_r.patch
  (git-fixes bsc#1220350 CVE-2023-52457).
- Update
  patches.suse/serial-imx-fix-tx-statemachine-deadlock.patch
  (git-fixes bsc#1220364 CVE-2023-52456).
  Add CVE references.
- commit 7801f75
* Mon Mar  4 2024 tiwai@suse.de
- Refresh patches.suse/bpf-Fix-a-race-condition-between-btf_put-and-map_fre.patch
  Fix a build error caused by the patch context embeded in the description
- commit 3c4ea38
* Mon Mar  4 2024 shung-hsi.yu@suse.com
- selftests/bpf: Remove flaky test_btf_id test (bsc#1220247 CVE-2023-52446).
- bpf: Fix a race condition between btf_put() and map_free()
  (bsc#1220247 CVE-2023-52446).
- commit 1878e7b
* Mon Mar  4 2024 tiwai@suse.de
- phy: freescale: phy-fsl-imx8-mipi-dphy: Fix alias name to use
  dashes (git-fixes).
- dmaengine: ptdma: use consistent DMA masks (git-fixes).
- dmaengine: idxd: Ensure safe user copy of completion record
  (git-fixes).
- dmaengine: fsl-qdma: init irq after reg initialization
  (git-fixes).
- dmaengine: fsl-qdma: fix SoC may hang on 16 byte unaligned read
  (git-fixes).
- commit 6051aa0
* Mon Mar  4 2024 jlee@suse.com
- efivarfs: Free s_fs_info on unmount (bsc#1220328
  CVE-2023-52463).
- commit 855de3c
* Mon Mar  4 2024 jlee@suse.com
- efivarfs: Move efivar availability check into FS context init
  (bsc#1220328 CVE-2023-52463).
- commit 9aa65d5
* Mon Mar  4 2024 jlee@suse.com
- efivarfs: force RO when remounting if SetVariable is not
  supported (bsc#1220328 CVE-2023-52463).
- commit f4334b6
* Mon Mar  4 2024 jlee@suse.com
- efivarfs: Add uid/gid mount options (bsc#1220328
  CVE-2023-52463).
- commit f803582
* Sun Mar  3 2024 tiwai@suse.de
- Update kabi files: initial import for ALP-current branch
  Based on the commit b599b6792b5e73264ffa33bdae47b19dc43f9401
- commit 691a54e
* Sun Mar  3 2024 tiwai@suse.de
- ALSA: hda/realtek - ALC285 reduce pop noise from Headphone port
  (git-fixes).
- commit faab4df
* Sun Mar  3 2024 tiwai@suse.de
- ALSA: hda/realtek: fix mute/micmute LED For HP mt440
  (git-fixes).
- ALSA: hda/realtek: Enable Mute LED on HP 840 G8 (MB 8AB8)
  (git-fixes).
- ALSA: hda/realtek: Fix top speaker connection on Dell Inspiron
  16 Plus 7630 (git-fixes).
- commit 514a46e
* Sun Mar  3 2024 tiwai@suse.de
- power: supply: bq27xxx-i2c: Do not free non existing IRQ
  (git-fixes).
- mmc: sdhci-xenon: add timeout for PHY init complete (git-fixes).
- mmc: sdhci-xenon: fix PHY init clock stability (git-fixes).
- mmc: mmci: stm32: fix DMA API overlapping mappings warning
  (git-fixes).
- mmc: core: Fix eMMC initialization with 1-bit bus connection
  (git-fixes).
- efi/capsule-loader: fix incorrect allocation size (git-fixes).
- fbcon: always restore the old font data in fbcon_do_set_font()
  (git-fixes).
- tomoyo: fix UAF write bug in tomoyo_write_control() (git-fixes).
- firewire: core: send bus reset promptly on gap count error
  (git-fixes).
- efi: Don't add memblocks for soft-reserved memory (git-fixes).
- efi: runtime: Fix potential overflow of soft-reserved region
  size (git-fixes).
- hwmon: (coretemp) Enlarge per package core count limit
  (git-fixes).
- wifi: iwlwifi: do not announce EPCS support (git-fixes).
- wifi: mac80211: accept broadcast probe responses on 6 GHz
  (git-fixes).
- wifi: mac80211: adding missing drv_mgd_complete_tx() call
  (git-fixes).
- wifi: mac80211: set station RX-NSS on reconfig (git-fixes).
- Input: i8042 - add Fujitsu Lifebook U728 to i8042 quirk table
  (git-fixes).
- Input: xpad - add Lenovo Legion Go controllers (git-fixes).
- Input: goodix - accept ACPI resources with gpio_count == 3 &&
  gpio_int_idx == 0 (git-fixes).
- spi: sh-msiof: avoid integer overflow in constants (git-fixes).
- regulator: pwm-regulator: Add validity checks in continuous
  .get_voltage (git-fixes).
- platform/x86: touchscreen_dmi: Add info for the TECLAST X16
  Plus tablet (git-fixes).
- spi: hisi-sfc-v3xx: Return IRQ_NONE if no interrupts were
  detected (git-fixes).
- spi: intel-pci: Add support for Arrow Lake SPI serial flash
  (git-fixes).
- wifi: mac80211: fix race condition on enabling fast-xmit
  (git-fixes).
- wifi: cfg80211: fix missing interfaces when dumping (git-fixes).
- fbdev: sis: Error out if pixclock equals zero (git-fixes).
- fbdev: savage: Error out if pixclock equals zero (git-fixes).
- commit 87f4ce4
* Sun Mar  3 2024 tiwai@suse.de
- drm/nouveau: keep DMA buffers required for suspend/resume
  (git-fixes).
- Revert "drm/amd/pm: resolve reboot exception for si oland"
  (git-fixes).
- drm/amdgpu/pm: Fix the power1_min_cap value (git-fixes).
- drm/amd/display: Prevent potential buffer overflow in
  map_hw_resources (git-fixes).
- drm/buddy: fix range bias (git-fixes).
- drm/tegra: Remove existing framebuffer only if we support
  display (git-fixes).
- docs: Instruct LaTeX to cope with deeper nesting (git-fixes).
- drm/amd/display: adjust few initialization order in dm
  (git-fixes).
- drm/amd/display: fixed integer types and null check locations
  (git-fixes).
- Revert "drm/amd/display: increased min_dcfclk_mhz and
  min_fclk_mhz" (git-fixes).
- drm/amdgpu: Fix HDP flush for VFs on nbio v7.9 (git-fixes).
- drm/amdgpu: Fix shared buff copy to user (git-fixes).
- drm/amdgpu: reset gpu for s3 suspend abort case (git-fixes).
- drm/amdgpu: skip to program GFXDEC registers for suspend abort
  (git-fixes).
- drm/amd/display: Fix buffer overflow in
  'get_host_router_total_dp_tunnel_bw()' (git-fixes).
- drm/amd/display: increased min_dcfclk_mhz and min_fclk_mhz
  (git-fixes).
- drm/amdkfd: Use correct drm device for cgroup permission check
  (git-fixes).
- ahci: Extend ASM1061 43-bit DMA address quirk to other ASM106x
  parts (git-fixes).
- drm/amd/display: Avoid enum conversion warning (git-fixes).
- drm/amd/display: Request usb4 bw for mst streams (git-fixes).
- drm/amd/display: Add dpia display mode validation logic
  (git-fixes).
- commit 515b84e
* Sun Mar  3 2024 tiwai@suse.de
- ASoC: cs35l56: Must clear HALO_STATE before issuing SYSTEM_RESET
  (git-fixes).
- ALSA: hda/realtek: Add special fixup for Lenovo 14IRP8
  (git-fixes).
- ALSA: hda/realtek: tas2781: enable subwoofer volume control
  (git-fixes).
- ALSA: Drop leftover snd-rtctimer stuff from Makefile
  (git-fixes).
- ALSA: ump: Fix the discard error code from snd_ump_legacy_open()
  (git-fixes).
- ALSA: firewire-lib: fix to check cycle continuity (git-fixes).
- dmaengine: ti: edma: Add some null pointer checks to the
  edma_probe (git-fixes).
- ASoC: wm_adsp: Don't overwrite fwf_name with the default
  (git-fixes).
- ALSA: usb-audio: Ignore clock selector errors for single
  connection (git-fixes).
- ASoC: sunxi: sun4i-spdif: Add support for Allwinner H616
  (git-fixes).
- ASoC: amd: acp: Add check for cpu dai link initialization
  (git-fixes).
- ALSA: usb-audio: Check presence of valid altsetting control
  (git-fixes).
- ahci: add 43-bit DMA address quirk for ASMedia ASM1061
  controllers (git-fixes).
- ahci: asm1166: correct count of reported ports (git-fixes).
- dmaengine: fsl-qdma: increase size of 'irq_name' (git-fixes).
- dmaengine: shdma: increase size of 'dev_id' (git-fixes).
- dmaengine: apple-admac: Keep upper bits of REG_BUS_WIDTH
  (git-fixes).
- ata: ahci: add identifiers for ASM2116 series adapters
  (git-fixes).
- commit 9457359
* Sat Mar  2 2024 wqu@suse.com
- btrfs: fix double free of anonymous device after snapshot
  creation failure (bsc#1219126 CVE-2024-23850).
- commit 684803d
* Sat Mar  2 2024 tonyj@suse.de
- Add initial kabi reference files (commit 8f19d4869160).
  KABI checking now enabled for default (all) and 64kb (aarch64) flavors.
- commit 892d9b5
* Fri Mar  1 2024 jbohac@suse.cz
- x86/e820: Don't reserve SETUP_RNG_SEED in e820 (bsc#1218709).
- commit 15d874c
* Fri Mar  1 2024 tiwai@suse.de
- Update patch reference for input fix (CVE-2023-52475 bsc#1220649)
- commit 2e7f958
* Fri Mar  1 2024 tiwai@suse.de
- Update patch reference for HID fix (CVE-2023-52478 bsc#1220796)
- commit 9f5b99e
* Fri Mar  1 2024 shung-hsi.yu@suse.com
- selftests/bpf: Test outer map update operations in syscall
  program (bsc#1220251 CVE-2023-52447).
- selftests/bpf: Add test cases for inner map (bsc#1220251
  CVE-2023-52447).
- bpf: Optimize the free of inner map (bsc#1220251
  CVE-2023-52447).
- Refresh patches.suse/kABI-padding-for-bpf.patch
- bpf: Defer the free of inner map when necessary (bsc#1220251
  CVE-2023-52447).
- Refresh patches.suse/kABI-padding-for-bpf.patch
- bpf: Set need_defer as false when clearing fd array during
  map free (bsc#1220251 CVE-2023-52447).
- bpf: Add map and need_defer parameters to .map_fd_put_ptr()
  (bsc#1220251 CVE-2023-52447).
- bpf: Check rcu_read_lock_trace_held() before calling bpf map
  helpers (bsc#1220251 CVE-2023-52447).
- commit 5323b3a
* Fri Mar  1 2024 jgross@suse.com
- KVM: arm64: vgic-its: Avoid potential UAF in LPI translation
  cache (bsc#1220326, CVE-2024-26598).
- commit 49fb765
* Fri Mar  1 2024 dwagner@suse.de
- scsi: lpfc: Replace deprecated strncpy() with strscpy()
  (bsc#1220021).
- scsi: lpfc: Copyright updates for 14.4.0.0 patches
  (bsc#1220021).
- scsi: lpfc: Update lpfc version to 14.4.0.0 (bsc#1220021).
- scsi: lpfc: Change lpfc_vport load_flag member into a bitmask
  (bsc#1220021).
- scsi: lpfc: Change lpfc_vport fc_flag member into a bitmask
  (bsc#1220021).
- scsi: lpfc: Protect vport fc_nodes list with an explicit spin
  lock (bsc#1220021).
- scsi: lpfc: Change nlp state statistic counters into atomic_t
  (bsc#1220021).
- scsi: lpfc: Remove shost_lock protection for fc_host_port
  shost APIs (bsc#1220021).
- scsi: lpfc: Move handling of reset congestion statistics events
  (bsc#1220021).
- scsi: lpfc: Save FPIN frequency statistics upon receipt of
  peer cgn notifications (bsc#1220021).
- scsi: lpfc: Add condition to delete ndlp object after sending
  BLS_RJT to an ABTS (bsc#1220021).
- scsi: lpfc: Fix failure to delete vports when discovery is in
  progress (bsc#1220021).
- scsi: lpfc: Remove NLP_RCV_PLOGI early return during RSCN
  processing for ndlps (bsc#1220021).
- scsi: lpfc: Allow lpfc_plogi_confirm_nport() logic to execute
  for Fabric nodes (bsc#1220021).
- scsi: lpfc: Remove D_ID swap log message from trace event logger
  (bsc#1220021).
- scsi: lpfc: Use sg_dma_len() API to get struct scatterlist's
  length (bsc#1220021).
- scsi: lpfc: Fix possible memory leak in lpfc_rcv_padisc()
  (bsc#1220021).
- scsi: lpfc: Initialize status local variable in
  lpfc_sli4_repost_sgl_list() (bsc#1220021).
- scsi: lpfc: Use PCI_HEADER_TYPE_MFD instead of literal
  (bsc#1220021).
- PCI: Add PCI_HEADER_TYPE_MFD definition (bsc#1220021).
- commit 9a9c9b2
* Fri Mar  1 2024 nik.borisov@suse.com
- x86/fpu: Stop relying on userspace for info to fault in xsave buffer (bsc#1220335).
- commit 8c37586
* Fri Mar  1 2024 nik.borisov@suse.com
- RAS/AMD/ATL: Fix bit overflow in denorm_addr_df4_np2() (git-fixes).
- commit a8f6b18
* Fri Mar  1 2024 tiwai@suse.de
- Bluetooth: qca: Fix wrong event type for patch config command
  (git-fixes).
- Bluetooth: Enforce validation on max value of connection
  interval (git-fixes).
- Bluetooth: hci_event: Fix handling of HCI_EV_IO_CAPA_REQUEST
  (git-fixes).
- Bluetooth: hci_event: Fix wrongly recorded wakeup BD_ADDR
  (git-fixes).
- Bluetooth: hci_sync: Fix accept_list when attempting to suspend
  (git-fixes).
- Bluetooth: Avoid potential use-after-free in hci_error_reset
  (git-fixes).
- Bluetooth: hci_sync: Check the correct flag before starting
  a scan (git-fixes).
- Bluetooth: hci_bcm4377: do not mark valid bd_addr as invalid
  (git-fixes).
- wifi: nl80211: reject iftype change with mesh ID change
  (git-fixes).
- net: lan78xx: fix "softirq work is pending" error (git-fixes).
- net: usb: dm9601: fix wrong return value in dm9601_mdio_read
  (git-fixes).
- lan78xx: enable auto speed configuration for LAN7850 if no
  EEPROM is detected (git-fixes).
- commit ae3aae7
* Fri Mar  1 2024 tiwai@suse.de
- Update patch reference for media usb fix (CVE-2023-52445 bsc#1220241)
- commit e6dd958
* Fri Mar  1 2024 nik.borisov@suse.com
- RAS: Introduce a FRU memory poison manager (jsc#PED-7618).
- commit 8f0ee79
* Fri Mar  1 2024 iivanov@suse.de
- hisi_acc_vfio_pci: Update migration data pointer correctly on (bsc#1220337,CVE-2023-52453)
- commit d659d2d
* Fri Mar  1 2024 nik.borisov@suse.com
- RAS/AMD/ATL: Add MI300 row retirement support (jsc#PED-7618).
- Delete patches.suse/EDAC-amd64-Add-MI300-row-retirement-support.patch.
- commit 50130ed
* Fri Mar  1 2024 wqu@suse.com
- btrfs: do not ASSERT() if the newly created subvolume already
  got read (bsc#1219126).
- commit a427c9b
* Fri Mar  1 2024 tonyj@suse.de
- perf vendor events: Update metric events for power10 platform
  (bsc#1220502 perf-v6.7).
- commit c37d66c
* Thu Feb 29 2024 krisman@suse.de
- io_uring/net: fix multishot accept overflow handling
  (git-fixes).
- io_uring/net: fix sr->len for IORING_OP_RECV with MSG_WAITALL
  and buffers (git-fixes).
- io_uring/net: limit inline multishot retries (git-fixes).
- io_uring/poll: add requeue return code from poll multishot
  handling (git-fixes).
- io_uring/net: un-indent mshot retry path in io_recv_finish()
  (git-fixes).
- io_uring/poll: move poll execution helpers higher up
  (git-fixes).
- io_uring/rw: ensure poll based multishot read retries
  appropriately (git-fixes).
- io_uring: combine cq_wait_nr checks (git-fixes).
- io_uring: clean *local_work_add var naming (git-fixes).
- io_uring: clean up local tw add-wait sync (git-fixes).
- io_uring: adjust defer tw counting (git-fixes).
- io_uring: ensure local task_work is run on wait timeout
  (git-fixes).
- io_uring/rw: ensure io->bytes_done is always initialized
  (git-fixes).
- io_uring: optimise ltimeout for inline execution (git-fixes).
- io_uring: don't check iopoll if request completes (git-fixes).
- commit 79dd332
* Thu Feb 29 2024 mhocko@suse.com
- Update
  patches.suse/sched-membarrier-reduce-the-ability-to-hammer-on-sys.patch
  (git-fixes, bsc#1220398, CVE-2024-26602).
- commit 2095c13
* Thu Feb 29 2024 petr.pavlu@suse.com
- Update patches.suse/add-suse-supported-flag.patch
  (jsc#PED-5759).
- Refresh
  patches.suse/kernel-add-release-status-to-kernel-build.patch.
  * Don't mark the kernel as tainted when an "externally supported" module
  is loaded. It mostly lead to confusion. Aggregate
  TAINT_EXTERNAL_SUPPORT instead into a separate variable
  support_taint_mask which only affects /sys/kernel/supported but
  doesn't contribute to /proc/sys/kernel/tainted
  * Expand the commit description to explain a bit more what the patch
  does.
- commit 5db57bc
* Thu Feb 29 2024 vbabka@suse.cz
- kabi padding for vmstat items (bsc#1220507).
- commit 01c42de
* Thu Feb 29 2024 jdelvare@suse.de
- Update
  patches.suse/i2c-i801-Fix-block-process-call-transactions.patch
  (git-fixes bsc#1220009 CVE-2024-26593).
  Add bug and CVE references.
- commit bdc6d34
* Thu Feb 29 2024 denis.kirjanov@suse.com
- net: stmmac: Wait a bit for the reset to take effect
  (git-fixes).
- commit 4b63f4d
* Thu Feb 29 2024 denis.kirjanov@suse.com
- net: stmmac: remove unneeded stmmac_poll_controller (git-fixes).
- commit c687b16
* Thu Feb 29 2024 denis.kirjanov@suse.com
- netfilter: nf_tables: disallow rule removal from chain binding
  (CVE-2023-5197 bsc#1218216).
- commit d6bd29e
* Thu Feb 29 2024 petr.pavlu@suse.com
- Revert "arm64: Prevent misaligned patch-site warnings (bsc#1214934)."
  This reverts commit 0db2d146c3e483a58fb6c09052b3f887174aa09a.
  Restore also CONFIG_HID_BPF=y which depends on
  CONFIG_DYNAMIC_FTRACE_WITH_DIRECT_CALLS=y and was disabled only later in
  329a3560cae5a3e24169b34ab6a21fa8964e3ff6 as a result of
  run_oldconfig.sh.
- commit 0a8158f
* Thu Feb 29 2024 petr.pavlu@suse.com
- kbuild: Use -fmin-function-alignment when available
  (bsc#1214934).
- Update config files.
- Refresh patches.suse/livepatch-dump-ipa-clones.patch.
- commit d057405
* Thu Feb 29 2024 tiwai@suse.de
- crypto: arm64/neonbs - fix out-of-bounds access on short input
  (git-fixes).
- commit 6358106
* Wed Feb 28 2024 msuchanek@suse.de
- blk-mq: don't change nr_hw_queues and nr_maps for kdump kernel
  (bsc#1218180 ltc#204476).
- commit ab6899d
* Wed Feb 28 2024 tbogendoerfer@suse.de
- Update
  patches.suse/mlxsw-spectrum_acl_tcam-Fix-NULL-pointer-dereference.patch
  (bsc#1220344 CVE-2024-26595).
  Added CVE reference.
- commit 63c44b2
* Wed Feb 28 2024 tbogendoerfer@suse.de
- Update
  patches.suse/mlxsw-spectrum_acl_tcam-Fix-stack-corruption.patch
  (bsc#1220243 CVE-2024-26586).
  Added CVE reference.
- commit 4835385
* Wed Feb 28 2024 jwiesner@suse.de
- net-device: move lstats in net_device_read_txrx (bsc#1220419).
- commit 6f1b7cd
* Wed Feb 28 2024 jwiesner@suse.de
- tcp: move tp->tcp_usec_ts to tcp_sock_read_txrx group
  (bsc#1220419).
- commit 5c7c981
* Wed Feb 28 2024 jwiesner@suse.de
- tcp: move tp->scaling_ratio to tcp_sock_read_txrx group
  (bsc#1220419).
- commit 6371144
* Wed Feb 28 2024 jwiesner@suse.de
- tcp: reorganize tcp_sock fast path variables (bsc#1220419).
- commit 8b11557
* Wed Feb 28 2024 jwiesner@suse.de
- netns-ipv4: reorganize netns_ipv4 fast path variables
  (bsc#1220419).
- commit b94aca8
* Wed Feb 28 2024 iivanov@suse.de
- mmu_notifiers: rename invalidate_range notifier (bsc#1220287)
- Refresh patches.suse/iommu-amd-Remove-iommu_v2-module.
- Refresh patches.suse/iommu-arm-smmu-v3-Fix-soft-lockup-triggered-by-arm_smmu_mm_invalidate_range.patch.
- Refresh patches.suse/iommu-vt-d-Fix-incorrect-cache-invalidation-for-mm-notification.
- Refresh patches.suse/iommu-vt-d-Remove-pasid_mutex.
- commit b3f3b3e
* Wed Feb 28 2024 oneukum@suse.com
- new paddings for the new features of TB (bsc#1220369).
- commit 202f364
* Wed Feb 28 2024 oneukum@suse.com
- padding: ehci core structures (bsc#1220369).
- commit be61d2c
* Wed Feb 28 2024 oneukum@suse.com
- padding: ohci core structure padding (bsc#1220369).
- commit 232e16e
* Wed Feb 28 2024 oneukum@suse.com
- padding: XHCI additional padding (bsc#1220369).
- commit 8d1ff6f
* Wed Feb 28 2024 oneukum@suse.com
- paddings: add paddings to TypeC stuff (bsc#1220369).
- commit 8b36dec
* Wed Feb 28 2024 jgross@suse.com
- kABI placeholders for coco host support (jsc#PED-6143).
- commit 25ae613
* Wed Feb 28 2024 iivanov@suse.de
- mmu_notifiers: don't invalidate secondary TLBs as part of (bsc#1220287)
- commit 484eb1e
* Wed Feb 28 2024 tiwai@suse.de
- kABI padding for wireless (kABI padding).
- kABI padding for soundwire (kABI padding).
- kABI padding for media drivers (kABI padding).
- commit ad23733
* Wed Feb 28 2024 tiwai@suse.de
- Update patches.suse/asoc-suse-kabi-padding.patch to cover more
- commit b2fee7e
* Wed Feb 28 2024 tiwai@suse.de
- drm/amd/display: Fix possible use of uninitialized
  'max_chunks_fbc_mode' in 'calculate_bandwidth()' (git-fixes).
- drm/amd/display: Add NULL test for 'timing generator' in
  'dcn21_set_pipe()' (git-fixes).
- drm/amd/display: Fix 'panel_cntl' could be null in
  'dcn21_set_backlight_level()' (git-fixes).
- drm/amd/display: Only clear symclk otg flag for HDMI
  (git-fixes).
- drm/amd/display: Force p-state disallow if leaving no plane
  config (git-fixes).
- drm/amd/display: Pass pwrseq inst for backlight and ABM
  (git-fixes).
- commit 94d0571
* Wed Feb 28 2024 tiwai@suse.de
- Add cherry-picked IDs to i915 patches
- commit c928c61
* Wed Feb 28 2024 iivanov@suse.de
- mmu_notifiers: call invalidate_range() when invalidating TLBs (bsc#1220287)
  Fix one of the hunks.
  - +      mmu_notifier_invalidate_range(mm, uaddr & PAGE_MASK,
  ++      mmu_notifier_invalidate_range(vma->vm_mm, uaddr & PAGE_MASK,
- commit 9929817
* Wed Feb 28 2024 iivanov@suse.de
- mmu_notifiers: fixup comment in mmu_interval_read_begin() (bsc#1220287)
- commit 70dae1e
* Wed Feb 28 2024 jgross@suse.com
- KVM: x86: Make gtod_is_based_on_tsc() return 'bool' (git-fixes).
- commit 2f18be2
* Wed Feb 28 2024 jwiesner@suse.de
- l2tp: pass correct message length to ip6_append_data
  (bsc#1220419).
- commit a162ea9
* Wed Feb 28 2024 jwiesner@suse.de
- udp: fix busy polling (bsc#1220419).
- commit 327b013
* Wed Feb 28 2024 jwiesner@suse.de
- tcp: use tp->total_rto to track number of linear timeouts in
  SYN_SENT state (bsc#1220419).
- commit b36a7cd
* Wed Feb 28 2024 jwiesner@suse.de
- inet: shrink struct flowi_common (bsc#1220419).
- commit f71704b
* Wed Feb 28 2024 jwiesner@suse.de
- net: sock_dequeue_err_skb() optimization (bsc#1220419).
- commit 9918376
* Wed Feb 28 2024 jwiesner@suse.de
- net: skb_queue_purge_reason() optimizations (bsc#1220419).
- commit 2897c0b
* Wed Feb 28 2024 jwiesner@suse.de
- tcp_metrics: do not create an entry from tcp_init_metrics()
  (bsc#1220419).
- commit 8498422
* Wed Feb 28 2024 jwiesner@suse.de
- tcp_metrics: properly set tp->snd_ssthresh in tcp_init_metrics()
  (bsc#1220419).
- commit d316e8b
* Wed Feb 28 2024 jwiesner@suse.de
- tcp_metrics: add missing barriers on delete (bsc#1220419).
- commit 88a0218
* Wed Feb 28 2024 jwiesner@suse.de
- openvswitch: reduce stack usage in do_execute_actions
  (bsc#1220419).
- commit 5d2ba35
* Wed Feb 28 2024 jwiesner@suse.de
- net_sched: sch_fq: struct sched_data reorg (bsc#1220419).
- commit ddafedf
* Wed Feb 28 2024 jwiesner@suse.de
- tipc: Use size_add() in calls to struct_size() (bsc#1220419).
- commit cab0062
* Wed Feb 28 2024 jwiesner@suse.de
- tcp: new TCP_INFO stats for RTO events (bsc#1220419).
- commit 25c897a
* Wed Feb 28 2024 jwiesner@suse.de
- tcp: call tcp_try_undo_recovery when an RTOd TFO SYNACK is ACKed
  (bsc#1220419).
- commit 3684a1c
* Wed Feb 28 2024 jwiesner@suse.de
- net: use indirect call helpers for sk->sk_prot->release_cb()
  (bsc#1220419).
- commit ed95efb
* Wed Feb 28 2024 jwiesner@suse.de
- ipv6: mcast: Remove redundant comparison in igmp6_mcf_get_next()
  (bsc#1220419).
- commit 4d11e24
* Wed Feb 28 2024 jwiesner@suse.de
- ipv4: igmp: Remove redundant comparison in igmp_mcf_get_next()
  (bsc#1220419).
- commit 8a1a119
* Wed Feb 28 2024 jwiesner@suse.de
- udplite: fix various data-races (bsc#1220419).
- commit bf316d4
* Wed Feb 28 2024 jwiesner@suse.de
- udplite: remove UDPLITE_BIT (bsc#1220419).
- commit 0660783
* Wed Feb 28 2024 jwiesner@suse.de
- udp: annotate data-races around udp->encap_type (bsc#1220419).
- commit 536dc63
* Wed Feb 28 2024 jwiesner@suse.de
- udp: lockless UDP_ENCAP_L2TPINUDP / UDP_GRO (bsc#1220419).
- commit c2f856e
* Wed Feb 28 2024 jwiesner@suse.de
- udp: move udp->accept_udp_{l4|fraglist} to udp->udp_flags
  (bsc#1220419).
- commit a3f7d91
* Wed Feb 28 2024 jwiesner@suse.de
- udp: add missing WRITE_ONCE() around up->encap_rcv
  (bsc#1220419).
- commit dae5278
* Wed Feb 28 2024 jwiesner@suse.de
- udp: move udp->gro_enabled to udp->udp_flags (bsc#1220419).
- commit ebea7a9
* Wed Feb 28 2024 jwiesner@suse.de
- udp: move udp->no_check6_rx to udp->udp_flags (bsc#1220419).
- commit dfe24f3
* Wed Feb 28 2024 jwiesner@suse.de
- udp: move udp->no_check6_tx to udp->udp_flags (bsc#1220419).
- commit 51e592b
* Wed Feb 28 2024 jwiesner@suse.de
- udp: introduce udp->udp_flags (bsc#1220419).
- commit 4a1ad0f
* Wed Feb 28 2024 jwiesner@suse.de
- tcp: defer regular ACK while processing socket backlog
  (bsc#1220419).
- Refresh
  patches.suse/tcp-Set-pingpong-threshold-via-sysctl.patch.
- commit 72b8890
* Wed Feb 28 2024 jwiesner@suse.de
- net: call prot->release_cb() when processing backlog
  (bsc#1220419).
- commit 279e360
* Wed Feb 28 2024 jwiesner@suse.de
- net: sock_release_ownership() cleanup (bsc#1220419).
- commit adb648a
* Wed Feb 28 2024 jwiesner@suse.de
- tcp: no longer release socket ownership in tcp_release_cb()
  (bsc#1220419).
- commit a9b01e1
* Wed Feb 28 2024 jwiesner@suse.de
- net/handshake: fix file ref count in handshake_nl_accept_doit()
  (bsc#1220419).
- commit b0749d0
* Wed Feb 28 2024 jwiesner@suse.de
- tcp: fix wrong RTO timeout when received SACK reneging
  (bsc#1220419).
- commit 9e002c1
* Wed Feb 28 2024 jwiesner@suse.de
- neighbour: fix various data-races (bsc#1220419).
- commit 669dde6
* Wed Feb 28 2024 jwiesner@suse.de
- net: do not leave an empty skb in write queue (bsc#1220419).
- commit c339b74
* Wed Feb 28 2024 jwiesner@suse.de
- net/sched: sch_hfsc: upgrade 'rt' to 'sc' when it becomes a
  inner curve (bsc#1220419).
- commit a07a92a
* Wed Feb 28 2024 jwiesner@suse.de
- tcp: tsq: relax tcp_small_queue_check() when rtx queue contains
  a single skb (bsc#1220419).
- commit 4c2f293
* Wed Feb 28 2024 jwiesner@suse.de
- xfrm: fix a data-race in xfrm_lookup_with_ifid() (bsc#1220419).
- commit 6b1e049
* Wed Feb 28 2024 jwiesner@suse.de
- net: ipv4: fix return value check in esp_remove_trailer
  (bsc#1220419).
- commit 0a2d321
* Wed Feb 28 2024 jwiesner@suse.de
- net: ipv6: fix return value check in esp_remove_trailer
  (bsc#1220419).
- commit e3ec248
* Wed Feb 28 2024 jwiesner@suse.de
- xfrm6: fix inet6_dev refcount underflow problem (bsc#1220419).
- commit c2cae82
* Wed Feb 28 2024 jwiesner@suse.de
- xfrm: fix a data-race in xfrm_gen_index() (bsc#1220419).
- commit 2704726
* Wed Feb 28 2024 jwiesner@suse.de
- xfrm: interface: use DEV_STATS_INC() (bsc#1220419).
- commit 25fe10c
* Wed Feb 28 2024 jwiesner@suse.de
- net: xfrm: skip policies marked as dead while reinserting
  policies (bsc#1220419).
- commit df5b96d
* Wed Feb 28 2024 jwiesner@suse.de
- tcp: fix excessive TLP and RACK timeouts from HZ rounding
  (bsc#1220419).
- commit 6f9857f
* Wed Feb 28 2024 jwiesner@suse.de
- netlink: Correct offload_xstats size (bsc#1220419).
- commit f1d7b6f
* Wed Feb 28 2024 jwiesner@suse.de
- sctp: update hb timer immediately after users change hb_interval
  (bsc#1220419).
- commit 5c729f7
* Wed Feb 28 2024 jwiesner@suse.de
- sctp: update transport state when processing a dupcook packet
  (bsc#1220419).
- commit b0329fd
* Wed Feb 28 2024 jwiesner@suse.de
- tcp: fix delayed ACKs for MSS boundary condition (bsc#1220419).
- commit 6b1162c
* Wed Feb 28 2024 jwiesner@suse.de
- tcp: fix quick-ack counting to count actual ACKs of new data
  (bsc#1220419).
- commit 438bff4
* Wed Feb 28 2024 jwiesner@suse.de
- ipv4: Set offload_failed flag in fibmatch results (bsc#1220419).
- commit 2d4e4b3
* Wed Feb 28 2024 jwiesner@suse.de
- ipv6: tcp: add a missing nf_reset_ct() in 3WHS handling
  (bsc#1220419).
- commit b60c3ab
* Wed Feb 28 2024 jwiesner@suse.de
- ipv4, ipv6: Fix handling of transhdrlen in
  __ip{,6}_append_data() (bsc#1220419).
- commit 65544e5
* Wed Feb 28 2024 jwiesner@suse.de
- neighbour: fix data-races around n->output (bsc#1220419).
- commit c87f845
* Wed Feb 28 2024 jwiesner@suse.de
- net: fix possible store tearing in neigh_periodic_work()
  (bsc#1220419).
- commit 88cba7d
* Wed Feb 28 2024 jwiesner@suse.de
- vxlan: Add missing entries to vxlan_get_size() (bsc#1220419).
- commit 7f45e12
* Wed Feb 28 2024 jwiesner@suse.de
- net: rds: Fix possible NULL-pointer dereference (bsc#1220419).
- commit 9187170
* Wed Feb 28 2024 jwiesner@suse.de
- net: bridge: use DEV_STATS_INC() (bsc#1220419).
- commit 8a4eadf
* Wed Feb 28 2024 jwiesner@suse.de
- net: hsr: Add __packed to struct hsr_sup_tlv (bsc#1220419).
- commit 410e45b
* Wed Feb 28 2024 jwiesner@suse.de
- net: hsr: Properly parse HSRv1 supervisor frames (bsc#1220419).
- commit 0a5895e
* Wed Feb 28 2024 jwiesner@suse.de
- dccp: fix dccp_v4_err()/dccp_v6_err() again (bsc#1220419).
- commit 52d3a91
* Tue Feb 27 2024 jwiesner@suse.de
- net/core: Fix ETH_P_1588 flow dissector (bsc#1220419).
- commit f49c1ee
* Tue Feb 27 2024 jwiesner@suse.de
- kcm: Fix error handling for SOCK_DGRAM in kcm_sendmsg()
  (bsc#1220419).
- commit 921c688
* Tue Feb 27 2024 jwiesner@suse.de
- ipv6: fix ip6_sock_set_addr_preferences() typo (bsc#1220419).
- commit ab7f29c
* Tue Feb 27 2024 jwiesner@suse.de
- kcm: Fix memory leak in error path of kcm_sendmsg()
  (bsc#1220419).
- commit 1fd0d5f
* Tue Feb 27 2024 jwiesner@suse.de
- hsr: Fix uninit-value access in fill_frame_info() (bsc#1220419).
- commit 45fafac
* Tue Feb 27 2024 jwiesner@suse.de
- net: ipv4: fix one memleak in __inet_del_ifa() (bsc#1220419).
- commit ec350a9
* Tue Feb 27 2024 jwiesner@suse.de
- ip_tunnels: use DEV_STATS_INC() (bsc#1220419).
- commit 6bebab0
* Tue Feb 27 2024 jwiesner@suse.de
- net/ipv6: SKB symmetric hash should incorporate transport ports
  (bsc#1220419).
- commit c0fd32f
* Tue Feb 27 2024 jwiesner@suse.de
- kcm: Destroy mutex in kcm_exit_net() (bsc#1220419).
- commit 6c21d3e
* Tue Feb 27 2024 jwiesner@suse.de
- net: ipv6/addrconf: avoid integer underflow in
  ipv6_create_tempaddr (bsc#1220419).
- commit a9d652e
* Tue Feb 27 2024 jwiesner@suse.de
- ipv6: ignore dst hint for multipath routes (bsc#1220419).
- commit fe7964f
* Tue Feb 27 2024 jwiesner@suse.de
- ipv4: ignore dst hint for multipath routes (bsc#1220419).
- commit 43db5ed
* Tue Feb 27 2024 jwiesner@suse.de
- skbuff: skb_segment, Call zero copy functions before using
  skbuff frags (bsc#1220419).
- commit 4efb5a5
* Tue Feb 27 2024 jwiesner@suse.de
- net: use sk_forward_alloc_get() in sk_get_meminfo()
  (bsc#1220419).
- commit c07b5dd
* Tue Feb 27 2024 jwiesner@suse.de
- net/handshake: fix null-ptr-deref in handshake_nl_done_doit()
  (bsc#1220419).
- Refresh
  patches.suse/handshake-Fix-sign-of-socket-file-descriptor-fields.patch.
- commit 79705ac
* Tue Feb 27 2024 jwiesner@suse.de
- xsk: Fix xsk_diag use-after-free error during socket cleanup
  (bsc#1220419).
- commit 8608f36
* Tue Feb 27 2024 jwiesner@suse.de
- net: fib: avoid warn splat in flow dissector (bsc#1220419).
- commit 061e521
* Tue Feb 27 2024 jwiesner@suse.de
- net: read sk->sk_family once in sk_mc_loop() (bsc#1220419).
- commit 11672a5
* Tue Feb 27 2024 jwiesner@suse.de
- net/sched: fq_pie: avoid stalls in fq_pie_timer() (bsc#1220419).
- commit ff72fe3
* Tue Feb 27 2024 jwiesner@suse.de
- netfilter: nft_exthdr: Fix non-linear header modification
  (bsc#1220419).
- commit 6941a9c
* Tue Feb 27 2024 jwiesner@suse.de
- net: ipv4, ipv6: fix IPSTATS_MIB_OUTOCTETS increment duplicated
  (bsc#1220419).
- commit 896e3a8
* Tue Feb 27 2024 jwiesner@suse.de
- dccp: Fix out of bounds access in DCCP error handler
  (bsc#1220419).
- commit db678bf
* Tue Feb 27 2024 jwiesner@suse.de
- netrom: Deny concurrent connect() (bsc#1220419).
- commit 6ccc04e
* Tue Feb 27 2024 jwiesner@suse.de
- net: Make consumed action consistent in sch_handle_egress
  (bsc#1220419).
- commit 229f87f
* Tue Feb 27 2024 jwiesner@suse.de
- vxlan: vnifilter: Use GFP_KERNEL instead of GFP_ATOMIC
  (bsc#1220419).
- commit ad1578f
* Tue Feb 27 2024 jwiesner@suse.de
- ipv6: do not match device when remove source route
  (bsc#1220419).
- commit d5deb22
* Tue Feb 27 2024 jwiesner@suse.de
- net: add skb_queue_purge_reason and __skb_queue_purge_reason
  (bsc#1220419).
- commit 1113f0f
* Tue Feb 27 2024 jwiesner@suse.de
- net: warn about attempts to register negative ifindex
  (bsc#1220419).
- commit af9d6cf
* Tue Feb 27 2024 jwiesner@suse.de
- net: openvswitch: add misc error drop reasons (bsc#1220419).
- commit f3a2f02
* Tue Feb 27 2024 jwiesner@suse.de
- net: openvswitch: add meter drop reason (bsc#1220419).
- commit 80ed278
* Tue Feb 27 2024 jwiesner@suse.de
- net: openvswitch: add explicit drop action (bsc#1220419).
- commit e866f58
* Tue Feb 27 2024 jwiesner@suse.de
- net: openvswitch: add action error drop reason (bsc#1220419).
- commit cfd5e8c
* Tue Feb 27 2024 jwiesner@suse.de
- net: openvswitch: add last-action drop reason (bsc#1220419).
- commit c8655d9
* Tue Feb 27 2024 jwiesner@suse.de
- netlink: convert nlk->flags to atomic flags (bsc#1220419).
- commit bd39488
* Tue Feb 27 2024 jwiesner@suse.de
- bonding: remove redundant NULL check in debugfs function
  (bsc#1220419).
- commit 0b9d7f8
* Tue Feb 27 2024 jwiesner@suse.de
- bonding: use IS_ERR instead of NULL check in bond_create_debugfs
  (bsc#1220419).
- commit 3f04290
* Tue Feb 27 2024 jwiesner@suse.de
- tun: avoid high-order page allocation for packet header
  (bsc#1220419).
- commit 94b6182
* Tue Feb 27 2024 jwiesner@suse.de
- net/ipv4: return the real errno instead of -EINVAL
  (bsc#1220419).
- commit a7c5cf7
* Tue Feb 27 2024 jwiesner@suse.de
- net: skbuff: always try to recycle PP pages directly when in
  softirq (bsc#1220419).
- commit e2c004f
* Tue Feb 27 2024 jwiesner@suse.de
- net: skbuff: avoid accessing page_pool if !napi_safe when
  returning page (bsc#1220419).
- commit 9d63308
* Tue Feb 27 2024 jwiesner@suse.de
- tcp/dccp: cache line align inet_hashinfo (bsc#1220419).
- commit 4f13a40
* Tue Feb 27 2024 jwiesner@suse.de
- bonding: support balance-alb with openvswitch (bsc#1220419).
- commit d8c4fd8
* Tue Feb 27 2024 jwiesner@suse.de
- net: tap: change tap_alloc_skb() to allow bigger paged
  allocations (bsc#1220419).
- commit 3d249a7
* Tue Feb 27 2024 jwiesner@suse.de
- net/packet: change packet_alloc_skb() to allow bigger paged
  allocations (bsc#1220419).
- commit 3eba2c8
* Tue Feb 27 2024 jwiesner@suse.de
- net: tun: change tun_alloc_skb() to allow bigger paged
  allocations (bsc#1220419).
- commit 8de3283
* Tue Feb 27 2024 jwiesner@suse.de
- net: allow alloc_skb_with_frags() to allocate bigger packets
  (bsc#1220419).
- commit 1c497fc
* Tue Feb 27 2024 jwiesner@suse.de
- mptcp: fix rcv buffer auto-tuning (bsc#1220419).
- commit 73668af
* Tue Feb 27 2024 jwiesner@suse.de
- tcp: add TCP_OLD_SEQUENCE drop reason (bsc#1220419).
- commit 0800d57
* Tue Feb 27 2024 jwiesner@suse.de
- udp: use indirect call wrapper for data ready() (bsc#1220419).
- commit e5e9533
* Tue Feb 27 2024 jwiesner@suse.de
- xfrm: delete not-needed clear to zero of encap_oa (bsc#1220419).
- commit bc01278
* Tue Feb 27 2024 jwiesner@suse.de
- tcp: get rid of sysctl_tcp_adv_win_scale (bsc#1220419).
- commit 1f0b2f3
* Tue Feb 27 2024 jwiesner@suse.de
- net: qrtr: Handle IPCR control port format of older targets
  (bsc#1220419).
- commit 817f648
* Tue Feb 27 2024 jwiesner@suse.de
- net: qrtr: ns: Change nodes radix tree to xarray (bsc#1220419).
- commit 296fea9
* Tue Feb 27 2024 jwiesner@suse.de
- net: qrtr: ns: Change servers radix tree to xarray
  (bsc#1220419).
- commit 0830a6d
* Tue Feb 27 2024 jwiesner@suse.de
- ipv6: rpl: Remove redundant skb_dst_drop() (bsc#1220419).
- commit 3e224b0
* Tue Feb 27 2024 jwiesner@suse.de
- tcp: add a scheduling point in established_get_first()
  (bsc#1220419).
- commit b802915
* Tue Feb 27 2024 jwiesner@suse.de
- net: annotate data-races around sk->sk_{rcv|snd}timeo
  (bsc#1220419).
- commit ead1412
* Tue Feb 27 2024 jwiesner@suse.de
- Revert "bridge: Add extack warning when enabling STP in
  netns." (bsc#1220419).
- commit 9e290a8
* Tue Feb 27 2024 jwiesner@suse.de
- llc: Check netns in llc_estab_match() and llc_listener_match()
  (bsc#1220419).
- commit 07a4719
* Tue Feb 27 2024 jwiesner@suse.de
- llc: Check netns in llc_dgram_match() (bsc#1220419).
- commit 3a7b96a
* Tue Feb 27 2024 jwiesner@suse.de
- ipv4: ip_gre: fix return value check in erspan_xmit()
  (bsc#1220419).
- commit 5fda0d9
* Tue Feb 27 2024 jwiesner@suse.de
- ipv4: ip_gre: fix return value check in erspan_fb_xmit()
  (bsc#1220419).
- commit 5679e1c
* Tue Feb 27 2024 jwiesner@suse.de
- net: sched: cls_flower: Undo tcf_bind_filter in case of an error
  (bsc#1220419).
- commit ed4275f
* Tue Feb 27 2024 jwiesner@suse.de
- netfilter: nf_tables: limit allowed range via nla_policy
  (bsc#1220419).
- commit 4953198
* Tue Feb 27 2024 jwiesner@suse.de
- ipvs: dynamically limit the connection hash table (bsc#1220419).
- commit 79ed1db
* Tue Feb 27 2024 jwiesner@suse.de
- net/tcp: optimise locking for blocking splice (bsc#1220419).
- commit ff225a7
* Tue Feb 27 2024 jwiesner@suse.de
- net: fix net device address assign type (bsc#1220419).
- commit e3fc0bd
* Tue Feb 27 2024 jwiesner@suse.de
- inet: Cleanup on charging memory for newly accepted sockets
  (bsc#1220419).
- commit 5cde3da
* Tue Feb 27 2024 jwiesner@suse.de
- netlabel: Reorder fields in 'struct netlbl_domaddr6_map'
  (bsc#1220419).
- commit aa8d809
* Tue Feb 27 2024 jwiesner@suse.de
- mptcp: Reorder fields in 'struct mptcp_pm_add_entry'
  (bsc#1220419).
- commit 15f81e2
* Tue Feb 27 2024 jwiesner@suse.de
- mctp: Reorder fields in 'struct mctp_route' (bsc#1220419).
- commit b48bed3
* Tue Feb 27 2024 jwiesner@suse.de
- tcp: enforce receive buffer memory limits by allowing the tcp
  window to shrink (bsc#1220419).
- Refresh
  patches.suse/tcp-Set-pingpong-threshold-via-sysctl.patch.
- commit e635b78
* Tue Feb 27 2024 jwiesner@suse.de
- net: add check for current MAC address in dev_set_mac_address
  (bsc#1220419).
- commit 1cc2c85
* Tue Feb 27 2024 jwiesner@suse.de
- netpoll: allocate netdev tracker right away (bsc#1220419).
- commit b1f824d
* Tue Feb 27 2024 jwiesner@suse.de
- lib/ref_tracker: remove warnings in case of allocation failure
  (bsc#1220419).
- commit 6db841f
* Tue Feb 27 2024 jwiesner@suse.de
- lib/ref_tracker: add printing to memory buffer (bsc#1220419).
- commit 13f3245
* Tue Feb 27 2024 jwiesner@suse.de
- lib/ref_tracker: improve printing stats (bsc#1220419).
- commit 9e98006
* Tue Feb 27 2024 jwiesner@suse.de
- lib/ref_tracker: add unlocked leak print helper (bsc#1220419).
- commit 7ec14f7
* Tue Feb 27 2024 jwiesner@suse.de
- ipv6: lower "link become ready"'s level message (bsc#1220419).
- commit 6457477
* Tue Feb 27 2024 jwiesner@suse.de
- net: don't set sw irq coalescing defaults in case of PREEMPT_RT
  (bsc#1220419).
- commit 2b68076
* Tue Feb 27 2024 jwiesner@suse.de
- net: Make gro complete function to return void (bsc#1220419).
- commit 46956ab
* Tue Feb 27 2024 jwiesner@suse.de
- net: tcp: make the txhash available in TIME_WAIT sockets for
  IPv4 too (bsc#1220419).
- commit f3a6292
* Tue Feb 27 2024 jwiesner@suse.de
- netfilter: Reorder fields in 'struct nf_conntrack_expect'
  (bsc#1220419).
- commit f2ceea9
* Tue Feb 27 2024 jwiesner@suse.de
- seg6: Cleanup duplicates of skb_dst_drop calls (bsc#1220419).
- commit 87c3750
* Tue Feb 27 2024 jwiesner@suse.de
- xsk: Use pool->dma_pages to check for DMA (bsc#1220419).
- commit e5d7657
* Tue Feb 27 2024 jwiesner@suse.de
- bonding: Always assign be16 value to vlan_proto (bsc#1220419).
- commit 9879d29
* Tue Feb 27 2024 jwiesner@suse.de
- net/handshake: Unpin sock->file if a handshake is cancelled
  (bsc#1220419).
- commit 99a6456
* Tue Feb 27 2024 jwiesner@suse.de
- ipvlan: Remove NULL check before dev_{put, hold} (bsc#1220419).
- commit 1afbc6c
* Tue Feb 27 2024 jwiesner@suse.de
- tcp: make the first N SYN RTO backoffs linear (bsc#1220419).
- tcp: fix formatting in sysctl_net_ipv4.c (bsc#1220419).
- Refresh
  patches.suse/net-fix-the-RTO-timer-retransmitting-skb-every.patch.
- Refresh
  patches.suse/tcp-Set-pingpong-threshold-via-sysctl.patch.
- commit 6dd44f7
* Tue Feb 27 2024 jwiesner@suse.de
- sctp: fix a potential OOB access in sctp_sched_set_sched()
  (bsc#1220419).
- commit c89c096
* Tue Feb 27 2024 jwiesner@suse.de
- net: veth: rely on napi_build_skb in
  veth_convert_skb_to_xdp_buff (bsc#1220419).
- commit f283d10
* Tue Feb 27 2024 jwiesner@suse.de
- netfilter: ipset: Replace strlcpy with strscpy (bsc#1220419).
- commit ad7e7c6
* Tue Feb 27 2024 oneukum@suse.com
- usb: typec: ucsi: Update connector cap and status
  (jsc#PED-6054).
- commit c47d65e
* Tue Feb 27 2024 vbabka@suse.cz
- Refresh
  patches.suse/kabi-Add-placeholders-to-a-couple-of-important-struc.patch.
  Add suse_kabi_padding to pg_data_t.
- commit d59d937
* Tue Feb 27 2024 lhenriques@suse.de
- ceph: fix invalid pointer access if get_quota_realm return
  ERR_PTR (bsc#1220454).
- ceph: fix deadlock or deadcode of misusing dget() (bsc#1220453).
- ceph: reinitialize mds feature bit even when session in open
  (bsc#1220452).
- rcu: kmemleak: Ignore kmemleak false positives when RCU-freeing
  objects (bsc#1220451).
- commit bc9efd4
* Tue Feb 27 2024 tiwai@suse.de
- Update ath11k hibernation patches for v2 series (bsc#1207948)
- commit 8a26dfa
* Tue Feb 27 2024 denis.kirjanov@suse.com
- mlxsw: spectrum_acl_tcam: Fix stack corruption (git-fixes).
- commit 122d131
* Tue Feb 27 2024 denis.kirjanov@suse.com
- mlxsw: spectrum_acl_tcam: Fix NULL pointer dereference in
  error path (git-fixes).
- commit 08e89d9
* Tue Feb 27 2024 denis.kirjanov@suse.com
- mlxsw: spectrum_acl_erp: Fix error flow of pool allocation
  failure (git-fixes).
- commit 500b87b
* Tue Feb 27 2024 denis.kirjanov@suse.com
- net: sfp-bus: fix SFP mode detect from bitrate (git-fixes).
- commit 71fbb68
* Tue Feb 27 2024 denis.kirjanov@suse.com
- net: dsa: vsc73xx: Add null pointer check to vsc73xx_gpio_probe
  (git-fixes).
- commit 7c99f2b
* Tue Feb 27 2024 denis.kirjanov@suse.com
- net: stmmac: ethtool: Fixed calltrace caused by unbalanced
  disable_irq_wake calls (git-fixes).
- commit 76ca33a
* Tue Feb 27 2024 denis.kirjanov@suse.com
- net: ravb: Fix dma_addr_t truncation in error case (git-fixes).
- commit 9e2020d
* Tue Feb 27 2024 denis.kirjanov@suse.com
- net: micrel: Fix PTP frame parsing for lan8841 (git-fixes).
- commit 8e04e0d
* Tue Feb 27 2024 denis.kirjanov@suse.com
- net: dsa: qca8k: put MDIO bus OF node on qca8k_mdio_register()
  failure (git-fixes).
- commit 1355c14
* Tue Feb 27 2024 denis.kirjanov@suse.com
- net: dsa: mv88e6xxx: Fix mv88e6352_serdes_get_stats error path
  (git-fixes).
- commit 736a4b6
* Tue Feb 27 2024 denis.kirjanov@suse.com
- net: atlantic: eliminate double free in error handling logic
  (git-fixes).
- commit f1c0473
* Tue Feb 27 2024 denis.kirjanov@suse.com
- net: mvmdio: Avoid excessive sleeps in polled mode (git-fixes).
- commit a1c3018
* Tue Feb 27 2024 denis.kirjanov@suse.com
- net/qla3xxx: fix potential memleak in ql_alloc_buffer_queues
  (git-fixes).
- commit 3f4de86
* Tue Feb 27 2024 denis.kirjanov@suse.com
- veth: Use tstats per-CPU traffic counters (git-fixes).
- commit 468b7e0
* Tue Feb 27 2024 denis.kirjanov@suse.com
- veth: Avoid NAPI scheduling on failed SKB forwarding
  (git-fixes).
- Refresh
  patches.suse/veth-Fixing-transmit-return-status-for-dropped-packe.patch.
- commit 8219306
* Tue Feb 27 2024 denis.kirjanov@suse.com
- net: sfp: add quirk for Fiberstone GPON-ONU-34-20BI (git-fixes).
- commit 71f6425
* Tue Feb 27 2024 tbogendoerfer@suse.de
- octeontx2-af: Consider the action set by PF (jsc#PED-6931).
- ionic: use pci_is_enabled not open code (jsc#PED-6953).
- RDMA/mlx5: Relax DEVX access upon modify commands
  (jsc#PED-3311).
- RDMA/mlx5: Fix fortify source warning while accessing Eth
  segment (jsc#PED-3311).
- dpll: fix possible deadlock during netlink dump operation
  (jsc#PED-6079).
- commit e125dc2
* Tue Feb 27 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-Add-kabi-placeholders-to-commonly-used-structs.patch.
  Add a few more DRM related kabi paddings
- commit c57370e
* Tue Feb 27 2024 mkoutny@suse.com
- Update config files (bsc#1214883)
  Disable CONFIG_BLK_CGROUP_IOPRIO
- commit 2843ec9
* Tue Feb 27 2024 tiwai@suse.de
- Add already cherry-picked and reverted commits
- commit 78b5638
* Tue Feb 27 2024 tiwai@suse.de
- drm/amd/display: Fix memory leak in dm_sw_fini() (git-fixes).
- drm/i915/tv: Fix TV mode (git-fixes).
- drm/syncobj: handle NULL fence in syncobj_eventfd_entry_func
  (git-fixes).
- drm/syncobj: call drm_syncobj_fence_add_wait when WAIT_AVAILABLE
  flag is set (git-fixes).
- drm/ttm: Fix an invalid freeing on already freed page in error
  path (git-fixes).
- drm/meson: Don't remove bridges which are created by other
  drivers (git-fixes).
- nouveau: fix function cast warnings (git-fixes).
- drm/msm: Wire up tlb ops (git-fixes).
- Revert "drm/msm/gpu: Push gpu lock down past runpm" (git-fixes).
- drm/msm/gem: Fix double resv lock aquire (git-fixes).
- drm/amdgpu/display: Initialize gamma correction mode variable
  in dcn30_get_gamcor_current() (git-fixes).
- drm/amdgpu/soc21: update VCN 4 max HEVC encoding resolution
  (git-fixes).
- drm/amd/display: Preserve original aspect ratio in create stream
  (git-fixes).
- drm/amd/display: Fix possible NULL dereference on device
  remove/driver unload (git-fixes).
- drm/amd/display: Add align done check (git-fixes).
- Revert "drm/amd: flush any delayed gfxoff on suspend entry"
  (git-fixes).
- drm/amd/display: Fix possible buffer overflow in
  'find_dcfclk_for_voltage()' (git-fixes).
- drm/amd/display: Initialize 'wait_time_microsec' variable in
  link_dp_training_dpia.c (git-fixes).
- drm/crtc: fix uninitialized variable use even harder
  (git-fixes).
- drm/prime: Support page array >= 4GB (git-fixes).
- nouveau/svm: fix kvcalloc() argument order (git-fixes).
- drm/msm/dpu: check for valid hw_pp in
  dpu_encoder_helper_phys_cleanup (git-fixes).
- drm/msm/dp: return correct Colorimetry for
  DP_TEST_DYNAMIC_RANGE_CEA case (git-fixes).
- drm/msms/dp: fixed link clock divider bits be over written in
  BPC unknown case (git-fixes).
- drm/msm/dpu: fix kernel-doc warnings (git-fixes).
- drm/amd/display: Increase frame-larger-than for all
  display_mode_vba files (git-fixes).
- drm/amd/display: Fix MST Null Ptr for RV (git-fixes).
- nouveau: offload fence uevents work to workqueue (git-fixes).
- drm/amdgpu: Reset IH OVERFLOW_CLEAR bit (git-fixes).
- drm/virtio: Set segment size for virtio_gpu device (git-fixes).
- commit 667862a
* Tue Feb 27 2024 tiwai@suse.de
- mtd: rawnand: marvell: fix layouts (git-fixes).
- mtd: spinand: gigadevice: Fix the get ecc status issue
  (git-fixes).
- commit e3c1e9b
* Tue Feb 27 2024 tonyj@suse.de
- uprobes: use pagesize-aligned virtual address when replacing
  pages (git-fixes).
- powerpc/imc-pmu: Add a null pointer check in
  update_events_in_group() (git-fixes).
- KVM: x86/pmu: fix masking logic for MSR_CORE_PERF_GLOBAL_CTRL
  (git-fixes).
- perf/core: Bail out early if the request AUX area is out of
  bound (git-fixes).
- perf/x86/lbr: Filter vsyscall addresses (git-fixes).
- commit ae1cfdb
* Tue Feb 27 2024 colyli@suse.de
- md: Don't suspend the array for interrupted reshape (git-fixes).
- commit 3e40c5d
* Tue Feb 27 2024 krisman@suse.de
- tcp: Set pingpong threshold via sysctl (bsc#1217908).
- commit 4fa5178
* Mon Feb 26 2024 iivanov@suse.de
- Refresh patches.suse/kabi-arm64-reserve-space-in-cpu_hwcaps-and-cpu_hwcap.patch
  Add few more entries. Prepare for SLE15-SP6 kABI freeze.
- commit 49a3650
* Mon Feb 26 2024 duwe@suse.de
- kabi/severities: join intel accelerators QAT and IAA under
  drivers/crypto/intel/
- commit 114be8b
* Mon Feb 26 2024 iivanov@suse.de
- arm64/sme: Restore SMCR_EL1.EZT0 on exit from suspend (git-fixes)
- commit 7f70810
* Mon Feb 26 2024 iivanov@suse.de
- arm64/sme: Restore SME registers on exit from suspend (git-fixes)
- commit 022bd78
* Mon Feb 26 2024 iivanov@suse.de
- arm64: Subscribe Microsoft Azure Cobalt 100 to ARM Neoverse N2 errata (git-fixes)
- commit 76ae43c
* Mon Feb 26 2024 iivanov@suse.de
- arm64/signal: Don't assume that TIF_SVE means we saved SVE state (git-fixes)
- commit 09cd4e0
* Mon Feb 26 2024 iivanov@suse.de
- arm64: irq: set the correct node for shadow call stack (git-fixes)
- commit a50e173
* Mon Feb 26 2024 iivanov@suse.de
- arm64: irq: set the correct node for VMAP stack (git-fixes)
- commit 61a9e16
* Mon Feb 26 2024 fweisbecker@suse.de
- kABI padding for context tracking (bsc#1220369).
- commit e722a7d
* Mon Feb 26 2024 oneukum@suse.com
- Update config files.
  Revert CRC helpers to modular build to match SP6
  Change CONFIG_CRC_T10DIF to modular to increase modularity
- commit 62c02b0
* Mon Feb 26 2024 pjakobsson@suse.de
- drm/amdgpu: Fix the runtime resume failure issue (git-fixes).
- commit 7cec932
* Mon Feb 26 2024 pjakobsson@suse.de
- drm/buddy: Modify duplicate list_splice_tail call (git-fixes).
- commit 5275939
* Mon Feb 26 2024 pjakobsson@suse.de
- Refresh patches.suse/1956-drm-amdgpu-fix-buffer-funcs-setting-order-on-suspend.patch (git-fixes)
  Alt-commit
- commit ba07b04
* Mon Feb 26 2024 mfranc@suse.cz
- s390/cio: fix invalid -EBUSY on ccw_device_start (git-fixes
  bsc#1220360).
- commit 59c3bc5
* Mon Feb 26 2024 mfranc@suse.cz
- s390: use the correct count for __iowrite64_copy() (git-fixes
  bsc#1220359).
- commit 653b04f
* Mon Feb 26 2024 mfranc@suse.cz
- Update config files.  Deactivate CONFIG_QETH_OSX on s390x.  (jsc#PED-3317)
- commit 84140c6
* Mon Feb 26 2024 msuchanek@suse.de
- Update patches.suse/powerpc-pseries-iommu-DLPAR-add-doesn-t-completely-i.patch
  (bsc#1215199 bsc#1219077 ltc#204477).
- commit 5580eda
* Mon Feb 26 2024 tiwai@suse.de
- wifi: ath11k: support hibernation (bsc#1207948).
- net: qrtr: support suspend/hibernation (bsc#1207948).
- bus: mhi: host: add mhi_power_down_no_destroy() (bsc#1207948).
- commit f8c43ef
* Mon Feb 26 2024 tiwai@suse.de
- wifi: ath11k: thermal: don't try to register multiple times
  (bsc#1207948).
- wifi: ath11k: fix warning on DMA ring capabilities event
  (bsc#1207948).
- wifi: ath11k: do not dump SRNG statistics during resume
  (bsc#1207948).
- wifi: ath11k: remove MHI LOOPBACK channels (bsc#1207948).
- wifi: ath11k: rearrange IRQ enable/disable in reset path
  (bsc#1207948).
- commit 7125b14
* Mon Feb 26 2024 msuchanek@suse.de
- powerpc/pseries: Set CPU_FTR_DBELL according to ibm,pi-features
  (bsc#1220348).
- powerpc/pseries: Add a clear modifier to ibm,pa/pi-features
  parser (bsc#1220348).
- commit 675d4c1
* Mon Feb 26 2024 msuchanek@suse.de
- Refresh sorted patches.
- commit 1e0228f
* Mon Feb 26 2024 tiwai@suse.de
- Drop ath11k hibernation patches for refreshing to the new patch set (bsc#1207948)
- commit f6e50f6
* Mon Feb 26 2024 pjakobsson@suse.de
- drm/amd/display: Fix potential null pointer dereference in
  dc_dmub_srv (git-fixes).
- commit 351cd92
* Mon Feb 26 2024 pjakobsson@suse.de
- drm/amd/display: fix null-pointer dereference on edid reading
  (git-fixes).
- commit bfbfdff
* Mon Feb 26 2024 pjakobsson@suse.de
- drm/nouveau/mmu/r535: uninitialized variable in r535_bar_new_()
  (git-fixes).
- commit 0d45808
* Mon Feb 26 2024 pjakobsson@suse.de
- drm/amd: Stop evicting resources on APUs in suspend (git-fixes).
- commit 209f4ad
* Mon Feb 26 2024 pjakobsson@suse.de
- drm/amdkfd: Fix L2 cache size reporting in GFX9.4.3 (git-fixes).
- commit 93ef60d
* Mon Feb 26 2024 pjakobsson@suse.de
- drm/buddy: Fix alloc_range() error handling code (git-fixes).
- commit ef3c1f0
* Mon Feb 26 2024 pjakobsson@suse.de
- drm/i915/dsc: Fix the macro that calculates DSCC_/DSCA_ PPS
  reg address (git-fixes).
- commit b61d0fb
* Mon Feb 26 2024 pjakobsson@suse.de
- drm/nouveau: fix several DMA buffer leaks (git-fixes).
- commit f1bf188
* Mon Feb 26 2024 pjakobsson@suse.de
- Refresh patches.suse/nouveau-gsp-use-correct-size-for-registry-rpc.patch (git-fixes)
  Alt-commit
- commit 8c79845
* Mon Feb 26 2024 pjakobsson@suse.de
- nouveau/gsp: use correct size for registry rpc (git-fixes).
- commit 37e1a96
* Mon Feb 26 2024 pjakobsson@suse.de
- drm/amdkfd: reserve the BO before validating it (git-fixes).
- commit f8fa1e7
* Mon Feb 26 2024 pjakobsson@suse.de
- Revert "drm/amd/pm: fix the high voltage and temperature issue"
  (git-fixes).
- commit 24e4e0f
* Mon Feb 26 2024 pjakobsson@suse.de
- Revert "nouveau: push event block/allowing out of the fence
  context" (git-fixes).
- commit 199f79d
* Mon Feb 26 2024 pjakobsson@suse.de
- drm/amd/display: Fix a switch statement in
  populate_dml_output_cfg_from_stream_state() (git-fixes).
- commit 3737a53
* Mon Feb 26 2024 pjakobsson@suse.de
- drm/i915: Drop -Wstringop-overflow (git-fixes).
- commit 1f6435f
* Mon Feb 26 2024 pjakobsson@suse.de
- drm/panel/raydium-rm692e5: select CONFIG_DRM_DISPLAY_DP_HELPER
  (git-fixes).
- commit 20cbb93
* Mon Feb 26 2024 pjakobsson@suse.de
- drm/i915/dp: Fix the max DSC bpc supported by source
  (git-fixes).
- commit 9a2c8c5
* Mon Feb 26 2024 denis.kirjanov@suse.com
- pds_core: Use struct pdsc for the pdsc_adminq_isr (git-fixes).
- commit 36eb1a2
* Mon Feb 26 2024 pjakobsson@suse.de
- drm/msm/a6xx: add QMP dependency (git-fixes).
- commit d7f2ae5
* Mon Feb 26 2024 pjakobsson@suse.de
- drm/amd/display: Fix NULL pointer dereference at hibernate
  (git-fixes).
- commit 4e87aee
* Mon Feb 26 2024 pjakobsson@suse.de
- fbdev/sm712fb: Use correct initializer macros for struct fb_ops
  (git-fixes).
- commit 03969f2
* Mon Feb 26 2024 denis.kirjanov@suse.com
- pds_core: Cancel AQ work on teardown (git-fixes).
- commit 3f05f5a
* Mon Feb 26 2024 pjakobsson@suse.de
- Revert "drm/bridge: Add 200ms delay to wait FW HPD status
  stable" (git-fixes).
- commit 10dece3
* Mon Feb 26 2024 pjakobsson@suse.de
- drm/bridge: imx93-mipi-dsi: Fix a couple of building warnings
  (git-fixes).
- commit 43267c0
* Mon Feb 26 2024 pjakobsson@suse.de
- drm/sched: Fix bounds limiting when given a malformed entity
  (git-fixes).
- commit 868d6d8
* Mon Feb 26 2024 denis.kirjanov@suse.com
- net: dsa: mv88e6xxx: Fix failed probe due to (git-fixes).
- commit 0eb880f
* Mon Feb 26 2024 denis.kirjanov@suse.com
- net: stmmac: do not clear TBS enable bit on link (git-fixes).
- commit e611caf
* Mon Feb 26 2024 denis.kirjanov@suse.com
- net: dsa: qca8k: fix illegal usage of GPIO (git-fixes).
- commit 0e558af
* Mon Feb 26 2024 denis.kirjanov@suse.com
- net: lan966x: Fix port configuration when using SGMII
  (git-fixes).
- commit 2844986
* Mon Feb 26 2024 denis.kirjanov@suse.com
- net: dsa: mt7530: fix 10M/100M speed on MT7988 switch
  (git-fixes).
- commit 56a7fea
* Mon Feb 26 2024 pjakobsson@suse.de
- Refresh patches.suse/1977-drm-amd-display-disable-FPO-and-SubVP-for-older-DMUB.patch (git-fixes)
  Alt-commit
- commit 430c8cb
* Mon Feb 26 2024 pjakobsson@suse.de
- Refresh patches.suse/1965-drm-amd-Fix-a-probing-order-problem-on-SDMA-2.4.patch (git-fixes)
  Alt-commit
- commit 9fefc0e
* Mon Feb 26 2024 pjakobsson@suse.de
- Refresh patches.suse/1982-drm-i915-display-Get-bigjoiner-config-before-dsc-con.patch (git-fixes)
  Alt-commit
- commit 50f74bf
* Mon Feb 26 2024 pjakobsson@suse.de
- Refresh patches.suse/1957-drm-amd-pm-fix-pp_-clk_od-typo.patch (git-fixes)
  Alt-commit
- commit 119bd8a
* Mon Feb 26 2024 pjakobsson@suse.de
- Refresh patches.suse/1940-drm-amdgpu-fix-buffer-funcs-setting-order-on-suspend.patch (git-fixes)
  Alt-commit
- commit 4f87896
* Mon Feb 26 2024 denis.kirjanov@suse.com
- nfp: flower: fix hardware offload for the transfer (git-fixes).
- commit 7376685
* Mon Feb 26 2024 pjakobsson@suse.de
- Refresh patches.suse/1906-drm-amdgpu-fix-AGP-addressing-when-GART-is-not-at-0.patch (git-fixes)
  Alt-commit
- commit 3da2260
* Mon Feb 26 2024 pjakobsson@suse.de
- Refresh patches.suse/1920-drm-i915-correct-the-input-parameter-on-_intel_dsb_c.patch (git-fixes)
  Alt-commit
- commit afd3ce2
* Mon Feb 26 2024 denis.kirjanov@suse.com
- nfp: flower: add hardware offload check for post ct (git-fixes).
- commit f9eb41e
* Mon Feb 26 2024 pjakobsson@suse.de
- Refresh patches.suse/1863-drm-i915-dp_mst-Fix-race-between-connector-registrat.patch (git-fixes)
  Alt-commit
- commit bad2e9c
* Mon Feb 26 2024 pjakobsson@suse.de
- Refresh patches.suse/1715-drm-i915-mtl-Apply-notify_guc-to-all-GTs.patch (git-fixes)
  Alt-commit
- commit f2361dc
* Mon Feb 26 2024 pjakobsson@suse.de
- Refresh patches.suse/1670-drm-ssd130x-Fix-possible-uninitialized-usage-of-crtc.patch (git-fixes)
  Alt-commit
- commit bc5e5ee
* Mon Feb 26 2024 denis.kirjanov@suse.com
- tsnep: Fix XDP_RING_NEED_WAKEUP for empty fill ring (git-fixes).
- commit 4caaa03
* Mon Feb 26 2024 denis.kirjanov@suse.com
- tsnep: Remove FCS for XDP data path (git-fixes).
- commit d20de7c
* Mon Feb 26 2024 denis.kirjanov@suse.com
- net: fec: fix the unhandled context fault from smmu (git-fixes).
- commit 2b9f00c
* Mon Feb 26 2024 denis.kirjanov@suse.com
- net: mvpp2: clear BM pool before initialization (git-fixes).
- commit 54d27e6
* Mon Feb 26 2024 denis.kirjanov@suse.com
- Update metadata
- commit 8028d46
* Mon Feb 26 2024 tiwai@suse.de
- usb: typec: tpcm: Fix issues with power being removed during
  reset (git-fixes).
- usb: gadget: ncm: Avoid dropping datagrams of properly parsed
  NTBs (git-fixes).
- Revert "usb: typec: tcpm: reset counter when enter into
  unattached state after try role" (git-fixes).
- usb: gadget: omap_udc: fix USB gadget regression on Palm TE
  (git-fixes).
- usb: dwc3: gadget: Don't disconnect if not started (git-fixes).
- usb: cdns3: fix memory double free when handle zero packet
  (git-fixes).
- usb: cdns3: fixed memory use after free at
  cdns3_gadget_ep_disable() (git-fixes).
- usb: roles: don't get/set_role() when usb_role_switch is
  unregistered (git-fixes).
- usb: roles: fix NULL pointer issue when put module's reference
  (git-fixes).
- usb: cdnsp: fixed issue with incorrect detecting CDNSP family
  controllers (git-fixes).
- usb: cdnsp: blocked some cdns3 specific code (git-fixes).
- serial: amba-pl011: Fix DMA transmission in RS485 mode
  (git-fixes).
- PCI/MSI: Prevent MSI hardware interrupt number truncation
  (git-fixes).
- commit 435b79c
* Mon Feb 26 2024 pjakobsson@suse.de
- PCI: Add pci_is_vga() helper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 81c9fa5
* Mon Feb 26 2024 shung-hsi.yu@suse.com
- selftests/bpf: trace_helpers.c: do not use poisoned type
  (jsc#PED-6811 bsc#1219825).
- commit ac0f9ba
* Mon Feb 26 2024 colyli@suse.de
- md: bypass block throttle for superblock update (bsc#1220154,
  CVE-2023-52437).
- commit ebe787f
* Mon Feb 26 2024 colyli@suse.de
- md: Don't register sync_thread for reshape directly
  (bsc#1219596).
- md: Make sure md_do_sync() will set MD_RECOVERY_DONE
  (bsc#1219596).
- md: Don't ignore read-only array in md_check_recovery()
  (bsc#1219596).
- md: Don't ignore suspended array in md_check_recovery()
  (bsc#1219596).
- commit b5edf3d
* Sun Feb 25 2024 tiwai@suse.de
- i2c: imx: when being a target, mark the last read as processed
  (git-fixes).
- bus: imx-weim: fix valid range check (git-fixes).
- ARM: ep93xx: Add terminator to gpiod_lookup_table (git-fixes).
- ata: ahci_ceva: fix error handling for Xilinx GT PHY support
  (git-fixes).
- ata: libata-core: Do not try to set sleeping devices to standby
  (git-fixes).
- iio: hid-sensor-als: Return 0 for
  HID_USAGE_SENSOR_TIME_TIMESTAMP (git-fixes).
- serial: mxs-auart: fix tx (git-fixes).
- serial: core: introduce uart_port_tx_flags() (git-fixes).
- media: rc: bpf attach/detach requires write permission
  (git-fixes).
- can: j1939: prevent deadlock by changing j1939_socks_lock to
  rwlock (git-fixes).
- connector/cn_proc: revert "connector: Fix
  proc_event_num_listeners count not cleared" (git-fixes).
- nilfs2: fix data corruption in dsync block recovery for small
  block sizes (git-fixes).
- mmc: slot-gpio: Allow non-sleeping GPIO ro (git-fixes).
- usb: f_mass_storage: forbid async queue when shutdown happen
  (git-fixes).
- ata: libata-scsi: Cleanup ata_scsi_start_stop_xlat()
  (git-fixes).
- selftests: bridge_mdb: Use MDB get instead of dump (git-fixes).
- commit fcefe0f
* Sun Feb 25 2024 pjakobsson@suse.de
- Update config files.
  Set CONFIG_DUMMY_CONSOLE_COLUMNS and CONFIG_DUMMY_CONSOLE_ROWS for
  armv7hl. Use same values as other architectures.
- commit d18c55c
* Fri Feb 23 2024 mwilck@suse.com
- Refresh
  patches.suse/dm_blk_ioctl-implement-path-failover-for-SG_IO.patch. (bsc#1216776, bsc#1220277)
- commit 92057e0
* Fri Feb 23 2024 tiwai@suse.de
- supported.conf: Mark adin driver as supported (jsc#PED-4736 bsc#1220218)
- commit ea21e8c
* Fri Feb 23 2024 vbabka@suse.cz
- mm: move vma locking out of vma_prepare and dup_anon_vma
  (bsc#1219558).
- Refresh patches.suse/mm-mmap-fix-vma_merge-case-7.patch.
- commit ce51ec9
* Fri Feb 23 2024 vbabka@suse.cz
- mmap: fix error paths with dup_anon_vma() (bsc#1219558).
- Refresh patches.suse/mm-mmap-fix-vma_merge-case-7.patch.
- commit 04c8742
* Fri Feb 23 2024 andrea.porta@suse.com
- Updated config files to fix divergences between ALP and SP6 (arm64)
- commit 09b8463
* Fri Feb 23 2024 lhenriques@suse.de
- cachefiles: fix memory leak in cachefiles_add_cache()
  (bsc#1220265).
- commit a58dc4c
* Fri Feb 23 2024 tiwai@suse.de
- selftests/iommu: fix the config fragment (git-fixes).
- platform/x86: thinkpad_acpi: Only update profile if successfully
  converted (git-fixes).
- platform/x86: intel-vbtn: Stop calling "VBDL" from
  notify_handler (git-fixes).
- platform/x86: touchscreen_dmi: Allow partial (prefix) matches
  for ACPI names (git-fixes).
- net: phy: realtek: Fix rtl8211f_config_init() for
  RTL8211F(D)(I)-VD-CG PHY (git-fixes).
- selftests: bonding: set active slave to primary eth1
  specifically (git-fixes).
- crypto: virtio/akcipher - Fix stack overflow on memcpy
  (git-fixes).
- can: netlink: Fix TDCO calculation using the old data bittiming
  (git-fixes).
- can: j1939: Fix UAF in j1939_sk_match_filter during
  setsockopt(SO_J1939_FILTER) (git-fixes).
- wifi: iwlwifi: mvm: fix a crash when we run out of stations
  (git-fixes).
- wifi: iwlwifi: uninitialized variable in
  iwl_acpi_get_ppag_table() (git-fixes).
- wifi: iwlwifi: Fix some error codes (git-fixes).
- wifi: mac80211: reload info pointer in ieee80211_tx_dequeue()
  (git-fixes).
- spi-mxs: Fix chipselect glitch (git-fixes).
- spi: ppc4xx: Drop write-only variable (git-fixes).
- HID: wacom: generic: Avoid reporting a serial of '0' to
  userspace (git-fixes).
- HID: wacom: Do not register input devices until after
  hid_hw_start (git-fixes).
- commit aa892f5
* Fri Feb 23 2024 petr.pavlu@suse.com
- tracing: Inform kmemleak of saved_cmdlines allocation
  (git-fixes).
- commit 97eea7e
* Fri Feb 23 2024 lduncan@suse.com
- scsi: core: Move scsi_host_busy() out of host lock if it is
  for per-command (git-fixes).
- commit 86e9b65
* Thu Feb 22 2024 vbabka@suse.cz
- mm, mmap: fix vma_merge() case 7 with vma_ops->close
  (bsc#1217313).
- commit 3278f37
* Thu Feb 22 2024 lduncan@suse.com
- uio_dmem_genirq: UIO_MEM_DMA_COHERENT conversion (bsc#1217698).
- uio_pruss: UIO_MEM_DMA_COHERENT conversion (bsc#1217698).
- cnic,bnx2,bnx2x: use UIO_MEM_DMA_COHERENT (bsc#1217698).
- uio: introduce UIO_MEM_DMA_COHERENT type (bsc#1217698).
- commit 44f64b0
* Thu Feb 22 2024 lduncan@suse.com
- scsi: core: Move scsi_host_busy() out of host lock for waking
  up EH handler (git-fixes).
- scsi: isci: Fix an error code problem in isci_io_request_build()
  (git-fixes).
- scsi: core: Kick the requeue list after inserting when flushing
  (git-fixes).
- scsi: hisi_sas: Correct the number of global debugfs registers
  (git-fixes).
- scsi: hisi_sas: Rollback some operations if FLR failed
  (git-fixes).
- commit 02cf67a
* Thu Feb 22 2024 mwilck@suse.com
- Refresh
  patches.suse/dm_blk_ioctl-implement-path-failover-for-SG_IO.patch.
- commit 5d036a3
* Thu Feb 22 2024 msuchanek@suse.de
- rpm templates: Always define usrmerged
  usrmerged is now defined in kernel-spec-macros and not the distribution.
  Only check if it's defined in kernel-spec-macros, not everywhere where
  it's used.
- commit a6ad8af
* Thu Feb 22 2024 petr.pavlu@suse.com
- tracing/synthetic: Fix trace_string() return value (git-fixes).
- commit 07b4940
* Thu Feb 22 2024 petr.pavlu@suse.com
- tracing: Fix wasted memory in saved_cmdlines logic (git-fixes).
- commit 575185b
* Thu Feb 22 2024 petr.pavlu@suse.com
- tracing: Fix HAVE_DYNAMIC_FTRACE_WITH_REGS ifdef (git-fixes).
- commit 4312194
* Thu Feb 22 2024 petr.pavlu@suse.com
- ftrace: Fix DIRECT_CALLS to use SAVE_REGS by default
  (git-fixes).
- commit 04f6845
* Thu Feb 22 2024 petr.pavlu@suse.com
- tracing/probes: Fix to show a parse error for bad type for $comm
  (git-fixes).
- commit 434ceb4
* Thu Feb 22 2024 petr.pavlu@suse.com
- ring-buffer: Clean ring_buffer_poll_wait() error return
  (git-fixes).
- commit 78cfe32
* Thu Feb 22 2024 mgorman@suse.de
- Rename and refresh
  patches.suse/cpufreq-ondemand-Set-default-up_threshold-to-30-on-multi-core-systems.patch.
- commit c52e450
* Thu Feb 22 2024 denis.kirjanov@suse.com
- netfilter: nft_set_rbtree: skip end interval element from gc
  (bsc#1220144 CVE-2024-26581).
- commit 66ac4ca
* Thu Feb 22 2024 denis.kirjanov@suse.com
- netfilter: nf_tables: nft_set_rbtree: fix spurious insertion
  failure (git-fixes).
- commit 1616b86
* Thu Feb 22 2024 denis.kirjanov@suse.com
- netfilter: nft_set_rbtree: skip sync GC for new elements in
  this transaction (git-fixes).
- commit fe02f5f
* Thu Feb 22 2024 denis.kirjanov@suse.com
- net: micrel: Fix PTP frame parsing for lan8814 (git-fixes).
- commit fdde0d3
* Thu Feb 22 2024 denis.kirjanov@suse.com
- tun: add missing rx stats accounting in tun_xdp_act (git-fixes).
- commit 54ceabf
* Thu Feb 22 2024 denis.kirjanov@suse.com
- tun: fix missing dropped counter in tun_xdp_act (git-fixes).
- commit 81acbf0
* Wed Feb 21 2024 lduncan@suse.com
- scsi: hisi_sas: Check before using pointer variables
  (git-fixes).
- scsi: hisi_sas: Replace with standard error code return value
  (git-fixes).
- scsi: hisi_sas: Set .phy_attached before notifing phyup event
  HISI_PHYE_PHY_UP_PM (git-fixes).
- scsi: mpi3mr: Fix printk() format strings (git-fixes).
- scsi: libfc: Fix up timeout error in fc_fcp_rec_error()
  (git-fixes).
- scsi: libfc: Don't schedule abort twice (git-fixes).
- scsi: fnic: Return error if vmalloc() failed (git-fixes).
- scsi: arcmsr: Support new PCI device IDs 1883 and 1886
  (git-fixes).
- scsi: bfa: Use the proper data type for BLIST flags (git-fixes).
- scsi: sd: Fix sshdr use in sd_suspend_common() (git-fixes).
- scsi: libfc: Fix potential NULL pointer dereference in
  fc_lport_ptp_setup() (git-fixes).
- scsi: hisi_sas: Set debugfs_dir pointer to NULL after removing
  debugfs (git-fixes).
- scsi: sd: Do not issue commands to suspended disks on shutdown
  (git-fixes).
- commit fa5f13f
* Wed Feb 21 2024 msuchanek@suse.de
- rpm templates: Move macro definitions below buildrequires
  Many of the rpm macros defined in the kernel packages depend directly or
  indirectly on script execution. OBS cannot execute scripts which means
  values of these macros cannot be used in tags that are required for OBS
  to see such as package name, buildrequires or buildarch.
  Accumulate macro definitions that are not directly expanded by mkspec
  below buildrequires and buildarch to make this distinction clear.
- commit 89eaf4c
* Wed Feb 21 2024 lduncan@suse.com
- Rename to
  patches.suse/scsi-fnic-Move-fnic_fnic_flush_tx-to-a-work-queue.patch.
- commit 1a9d435
* Wed Feb 21 2024 lduncan@suse.com
- Rename to
  patches.suse/scsi-Revert-scsi-fcoe-Fix-potential-deadlock-on-fip-ctlr_lock.patch.
- commit 2101c2a
* Wed Feb 21 2024 msuchanek@suse.de
- Update patches.suse/powerpc-pseries-fix-accuracy-of-stolen-time.patch
  (bsc#1215199 bsc#1220129 ltc#205683).
- commit 3a6e250
* Wed Feb 21 2024 jgross@suse.com
- x86/xen: add CPU dependencies for 32-bit build (git-fixes).
- commit 3c2a9ae
* Wed Feb 21 2024 svarbanov@suse.de
- power: reset: pwr-mlxbf: support graceful reboot instead of emergency (jsc#PED-8032)
- commit 7221104
* Wed Feb 21 2024 svarbanov@suse.de
- platform/mellanox: mlxbf-tmfifo: Drop Tx network packet when Tx (jsc#PED-8032)
- commit 0fc3eb8
* Wed Feb 21 2024 svarbanov@suse.de
- platform/mellanox: mlxbf-tmfifo: Remove unnecessary bool conversion (jsc#PED-8032)
- commit 53a0f30
* Wed Feb 21 2024 svarbanov@suse.de
- platform/mellanox: mlxbf-tmfifo: Fix a warning message (jsc#PED-8032)
- commit 8a9b17e
* Wed Feb 21 2024 svarbanov@suse.de
- platform/mellanox: mlxbf-pmc: Fix offset calculation for crspace (jsc#PED-8032)
- commit 2307ef6
* Wed Feb 21 2024 svarbanov@suse.de
- platform/mellanox: Check devm_hwmon_device_register_with_groups() (jsc#PED-8032)
- commit e1cd31d
* Wed Feb 21 2024 svarbanov@suse.de
- platform/mellanox: Add null pointer checks for devm_kasprintf() (jsc#PED-8032)
- commit bda53cc
* Wed Feb 21 2024 svarbanov@suse.de
- platform/mellanox: mlxbf-pmc: Add support for BlueField-3 (jsc#PED-8032)
- commit bbdb7cd
* Wed Feb 21 2024 svarbanov@suse.de
- mlxbf-bootctl: correctly identify secure boot with development keys (jsc#PED-8032)
- commit 7f706aa
* Wed Feb 21 2024 svarbanov@suse.de
- platform/mellanox: mlxbf-bootctl: Convert to platform remove callback (jsc#PED-8032)
- commit 55906a9
* Wed Feb 21 2024 svarbanov@suse.de
- mlxbf-bootctl: Support sysfs entries for MFG fields (jsc#PED-8032)
- commit ed7de29
* Wed Feb 21 2024 svarbanov@suse.de
- mlxbf-bootctl: Support setting the ARM boot state to "OS up" (jsc#PED-8032)
- commit c648b6e
* Wed Feb 21 2024 svarbanov@suse.de
- mlxbf-bootctl: Support the large icmc write/read (jsc#PED-8032)
- commit 3f27c32
* Wed Feb 21 2024 svarbanov@suse.de
- mlxbf-bootctl: Add sysfs file for BlueField boot log (jsc#PED-8032)
- commit 2f2dfde
* Wed Feb 21 2024 svarbanov@suse.de
- mmc: sdhci-of-dwcmshc: Add runtime PM operations (jsc#PED-8032)
- commit 8cc192b
* Wed Feb 21 2024 svarbanov@suse.de
- mmc: sdhci-of-dwcmshc: Add error handling in dwcmshc_resume (jsc#PED-8032)
- commit 9fc0dca
* Wed Feb 21 2024 svarbanov@suse.de
- mmc: sdhci-of-dwcmshc: Convert to platform remove callback returning (jsc#PED-8032)
- commit 1b18d2f
* Wed Feb 21 2024 svarbanov@suse.de
- i2c: mlxbf: Use devm_platform_get_and_ioremap_resource() (jsc#PED-8032)
- commit b7e1af1
* Wed Feb 21 2024 svarbanov@suse.de
- i2c: mlxbf: Use dev_err_probe in probe function (jsc#PED-8032)
- commit c1c0d6f
* Wed Feb 21 2024 hare@suse.de
- nvme-fabrics: typo in nvmf_parse_key() (bsc#1219670).
- commit aaaca39
* Wed Feb 21 2024 svarbanov@suse.de
- supported.conf: Add few drivers for BF3 (jsc#PED-8032)
  Add gpio-mlxbf3, sdhci-of-dwcmshc, pinctrl-mlxbf3 and
  pwr-mlxbf drivers in kernel-default.
- commit dd06563
* Wed Feb 21 2024 svarbanov@suse.de
- gpio: mlxbf3: add an error code check in mlxbf3_gpio_probe (jsc#PED-8032)
- commit 6e4d90e
* Wed Feb 21 2024 svarbanov@suse.de
- gpio: mlxbf3: use capital "OR" for multiple licenses in SPDX (jsc#PED-8032)
- commit 62fd912
* Wed Feb 21 2024 svarbanov@suse.de
- gpio: mlxbf3: Support add_pin_ranges() (jsc#PED-8032)
- commit f0d8a10
* Wed Feb 21 2024 svarbanov@suse.de
- config/arm64: Enable BF3 GPIO driver (jsc#PED-8032)
  Add config to enable Bluefield3 GPIO driver as module.
- commit cae28d7
* Wed Feb 21 2024 svarbanov@suse.de
- gpio: mlxbf3: Add gpio driver support (jsc#PED-8032)
- commit 305cf5b
* Wed Feb 21 2024 msuchanek@suse.de
- scsi: ibmvfc: Open-code reset loop for target reset
  (bsc#1220106).
- commit d127e55
* Wed Feb 21 2024 msuchanek@suse.de
- scsi: ibmvfc: Limit max hw queues by num_online_cpus()
  (bsc#1220106).
- commit 3ef410b
* Wed Feb 21 2024 jslaby@suse.cz
- sched/membarrier: reduce the ability to hammer on sys_membarrier
  (git-fixes).
- commit 55d8e46
* Wed Feb 21 2024 nmorey@suse.com
- RDMA/srpt: fix function pointer cast warnings (git-fixes)
- commit ddb0ea4
* Wed Feb 21 2024 nmorey@suse.com
- RDMA/qedr: Fix qedr_create_user_qp error flow (git-fixes)
- commit f6e1202
* Wed Feb 21 2024 nmorey@suse.com
- RDMA/srpt: Support specifying the srpt_service_guid parameter (git-fixes)
- commit 118994c
* Wed Feb 21 2024 nmorey@suse.com
- IB/hfi1: Fix sdma.h tx->num_descs off-by-one error (git-fixes)
- commit 86d2329
* Wed Feb 21 2024 nmorey@suse.com
- RDMA/irdma: Add AE for too many RNRS (git-fixes)
- commit 39a8fd9
* Wed Feb 21 2024 nmorey@suse.com
- RDMA/irdma: Set the CQ read threshold for GEN 1 (git-fixes)
- commit d6a78b2
* Wed Feb 21 2024 nmorey@suse.com
- RDMA/irdma: Validate max_send_wr and max_recv_wr (git-fixes)
- commit 4ad24ee
* Wed Feb 21 2024 nmorey@suse.com
- RDMA/irdma: Fix KASAN issue with tasklet (git-fixes)
- commit 3d431c6
* Wed Feb 21 2024 nmorey@suse.com
- IB/mlx5: Don't expose debugfs entries for RRoCE general parameters if not supported (git-fixes)
- commit 5cf010f
* Wed Feb 21 2024 nmorey@suse.com
- RDMA/bnxt_re: Add a missing check in bnxt_qplib_query_srq (git-fixes)
- commit e1fcbb3
* Wed Feb 21 2024 nmorey@suse.com
- RDMA/bnxt_re: Return error for SRQ resize (git-fixes)
- commit 154ab68
* Wed Feb 21 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix unconditional fence for newer adapters (git-fixes)
- commit f16dc69
* Wed Feb 21 2024 nmorey@suse.com
- RDMA/bnxt_re: Remove a redundant check inside bnxt_re_vf_res_config (git-fixes)
- commit ec51b18
* Wed Feb 21 2024 nmorey@suse.com
- RDMA/bnxt_re: Avoid creating fence MR for newer adapters (git-fixes)
- commit 1e41e8f
* Wed Feb 21 2024 nmorey@suse.com
- IB/hfi1: Fix a memleak in init_credit_return (git-fixes)
- commit 6060765
* Wed Feb 21 2024 osalvador@suse.de
- mm,page_owner: Update Documentation regarding page_owner_stacks
  (jsc-PED#7423).
- commit 84eb808
* Wed Feb 21 2024 heming.zhao@suse.com
- series.conf: temporarily disable upstream patch
  patches.suse/md-bitmap-don-t-use-index-for-pages-backing-the-bitm-d703.patch
  (bsc#1219261)
- commit 57020cb
* Wed Feb 21 2024 jslaby@suse.cz
- rpm/check-for-config-changes: add GCC_ASM_GOTO_OUTPUT_WORKAROUND to IGNORED_CONFIGS_RE
  Introduced by commit 68fb3ca0e408 ("update workarounds for gcc "asm
  goto" issue").
- commit be1bdab
* Wed Feb 21 2024 wqu@suse.com
- btrfs: don't clear qgroup reserved bit in release_folio
  (bsc#1216196).
- commit 3546ef4
* Wed Feb 21 2024 wqu@suse.com
- btrfs: free qgroup pertrans reserve on transaction abort
  (bsc#1216196).
- commit 48e3e79
* Wed Feb 21 2024 wqu@suse.com
- btrfs: fix qgroup_free_reserved_data int overflow (bsc#1216196).
- commit 56f38ab
* Wed Feb 21 2024 wqu@suse.com
- btrfs: free qgroup reserve when ORDERED_IOERR is set
  (bsc#1216196).
- commit c0918a8
* Tue Feb 20 2024 denis.kirjanov@suse.com
- net: openvswitch: limit the number of recursions from action
  sets (bsc#1219835 CVE-2024-1151).
- commit af45645
* Tue Feb 20 2024 jgross@suse.com
- KVM: x86: Fix KVM_GET_MSRS stack info leak (git-fixes).
- commit 9c73ba1
* Tue Feb 20 2024 jgross@suse.com
- KVM: x86/pmu: Fix type length error when reading
  pmu->fixed_ctr_ctrl (git-fixes).
- commit 9f3dd74
* Tue Feb 20 2024 oneukum@suse.com
- Update config files.
  PHONET makes no sense for PPC either
- commit f546449
* Tue Feb 20 2024 jgross@suse.com
- KVM: x86: make KVM_REQ_NMI request iff NMI pending for vcpu
  (git-fixes).
- commit 00a662c
* Tue Feb 20 2024 jgross@suse.com
- net: add more sanity check in virtio_net_hdr_to_skb()
  (git-fixes).
- commit 6f87770
* Tue Feb 20 2024 jgross@suse.com
- virtio_net: Fix "%%d directive writing between 1 and 11 bytes into a
  region of size 10" warnings (git-fixes).
- commit 26fc666
* Tue Feb 20 2024 osalvador@suse.de
- lib/stackdepot: add depot_fetch_stack helper (jsc-PED#7423).
- commit 1be3e14
* Tue Feb 20 2024 jgross@suse.com
- rpmsg: virtio: Free driver_override when rpmsg_remove()
  (git-fixes).
- commit 0617fb4
* Tue Feb 20 2024 jgross@suse.com
- virtio_blk: remove the broken zone revalidation support
  (git-fixes).
- commit ffc9138
* Tue Feb 20 2024 jgross@suse.com
- virtio_blk: fix snprintf truncation compiler warning
  (git-fixes).
- commit 245e0da
* Tue Feb 20 2024 jgross@suse.com
- virtio-blk: fix implicit overflow on virtio_max_dma_size
  (git-fixes).
- commit b4c31dd
* Tue Feb 20 2024 msuchanek@suse.de
- powerpc/pseries/iommu: DLPAR add doesn't completely initialize
  pci_controller (bsc#1215199).
- commit 5fb603b
* Tue Feb 20 2024 denis.kirjanov@suse.com
- igc: Remove temporary workaround (git-fixes).
- commit eb132b5
* Tue Feb 20 2024 denis.kirjanov@suse.com
- igb: Fix string truncation warnings in igb_set_fw_version
  (git-fixes).
- commit 605f8bb
* Tue Feb 20 2024 jgross@suse.com
- virtio_balloon: Fix endless deflation and inflation on arm64
  (git-fixes).
- commit 2b66f82
* Tue Feb 20 2024 denis.kirjanov@suse.com
- net: ravb: Count packets instead of descriptors in GbEth RX path
  (git-fixes).
- commit 2d0b099
* Tue Feb 20 2024 denis.kirjanov@suse.com
- pppoe: Fix memory leak in pppoe_sendmsg() (git-fixes).
- commit 65a997a
* Tue Feb 20 2024 denis.kirjanov@suse.com
- ice: Add check for lport extraction to LAG init (git-fixes).
- commit 5cd2e68
* Tue Feb 20 2024 duwe@suse.de
- supported.conf:
  * add iaa_crypto (compression accelerator), supported
  by intel. (jsc#PED-7793)
  * QAT and IAA are now in an "intel" subdir.
  Update and reshuffle.
- commit 846c769
* Tue Feb 20 2024 denis.kirjanov@suse.com
- bnad: fix work_queue type mismatch (git-fixes).
- commit 1a2a9a7
* Tue Feb 20 2024 denis.kirjanov@suse.com
- i40e: take into account XDP Tx queues when stopping rings
  (git-fixes).
- commit f377fcb
* Tue Feb 20 2024 denis.kirjanov@suse.com
- i40e: avoid double calling i40e_pf_rxq_wait() (git-fixes).
- commit 925c60c
* Tue Feb 20 2024 denis.kirjanov@suse.com
- i40e: Fix wrong mask used during DCB config (git-fixes).
- commit 498f506
* Tue Feb 20 2024 denis.kirjanov@suse.com
- i40e: Fix waiting for queues of all VSIs to be disabled
  (git-fixes).
- commit 4a4e88c
* Tue Feb 20 2024 denis.kirjanov@suse.com
- octeontx2-af: Remove the PF_FUNC validation for NPC transmit
  rules (git-fixes).
- commit 02c2bca
* Tue Feb 20 2024 denis.kirjanov@suse.com
- ionic: minimal work with 0 budget (git-fixes).
- commit c0e1f7f
* Tue Feb 20 2024 denis.kirjanov@suse.com
- i40e: Do not allow untrusted VF to remove administratively
  set MAC (git-fixes).
- commit 530701b
* Tue Feb 20 2024 denis.kirjanov@suse.com
- lan966x: Fix crash when adding interface under a lag
  (git-fixes).
- commit 4cc5718
* Tue Feb 20 2024 denis.kirjanov@suse.com
- bonding: do not report NETDEV_XDP_ACT_XSK_ZEROCOPY (git-fixes).
- commit 905320f
* Tue Feb 20 2024 denis.kirjanov@suse.com
- net/mlx5: DPLL, Fix possible use after free after delayed work
  timer triggers (git-fixes).
- commit 8d225a2
* Tue Feb 20 2024 jgross@suse.com
- x86/xen: fix percpu vcpu_info allocation (git-fixes).
- commit 7e63a00
* Tue Feb 20 2024 duwe@suse.de
- Update config files.
- commit 9e4b975
* Tue Feb 20 2024 jgross@suse.com
- acpi/processor: sanitize _OSC/_PDC capabilities for Xen dom0
  (git-fixes).
- commit fb286cc
* Tue Feb 20 2024 jgross@suse.com
- xen/events: close evtchn after mapping cleanup (git-fixes).
- commit dfc538e
* Tue Feb 20 2024 jgross@suse.com
- xen-netback: properly sync TX responses (git-fixes).
- commit ec08947
* Tue Feb 20 2024 oneukum@suse.com
- timers: Tag (hr)timer softirq as hotplug safe (git-fixes).
- commit 37f54ca
* Tue Feb 20 2024 jgross@suse.com
- xen/gntdev: Fix the abuse of underlying struct page in DMA-buf
  import (git-fixes).
- commit 559fc95
* Tue Feb 20 2024 oneukum@suse.com
- Documentation: arm64: Correct SME ZA macros name (git-fixes).
- commit 2f32046
* Tue Feb 20 2024 oneukum@suse.com
- docs: arm64: Move arm64 documentation under Documentation/arch/
  (git-fixes).
- Refresh
  patches.suse/arm64-errata-Add-Cortex-A520-speculative-unprivilege.patch.
- Refresh
  patches.suse/arm64-errata-Mitigate-Ampere1-erratum-AC03_CPU_.patch.
- Refresh
  patches.suse/iommu-arm-smmu-v3-Document-MMU-700-erratum-281.patch.
- Refresh
  patches.suse/iommu-arm-smmu-v3-Document-nesting-related-err.patch.
- Refresh
  patches.suse/iommu-arm-smmu-v3-Work-around-MMU-600-erratum-.patch.
- commit dbd8870
* Tue Feb 20 2024 pmladek@suse.com
- Delete
  patches.suse/workqueue-Override-implicit-ordered-attribute-in-wor.patch.
- blacklist.conf: the patch caused a regression and has been reverted
  upstream (bsc#1219509)
- commit 24b5f0d
* Tue Feb 20 2024 tiwai@suse.de
- Drop bcm5974 input patch causing a regression (bsc#1220030)
- commit 63d5a46
* Tue Feb 20 2024 osalvador@suse.de
- lib/stackdepot: add refcount for records (jsc-PED#7423).
- commit 150e517
* Tue Feb 20 2024 denis.kirjanov@suse.com
- net: qualcomm: rmnet: fix global oob in rmnet_policy
  (git-fixes).
- commit 890ecf9
* Tue Feb 20 2024 denis.kirjanov@suse.com
- Refresh
  patches.suse/powerpc-pseries-papr-sysparm-use-u8-arrays-for-paylo.patch.
- commit ee4a898
* Tue Feb 20 2024 jgross@suse.com
- swiotlb-xen: provide the "max_mapping_size" method (git-fixes).
- commit b256918
* Mon Feb 19 2024 msuchanek@suse.de
- powerpc/64: Set task pt_regs->link to the LR value on scv entry
  (bsc#1194869).
- powerpc: add crtsavres.o to always-y instead of extra-y
  (bsc#1194869).
- powerpc/watchpoints: Annotate atomic context in more places
  (bsc#1194869).
- powerpc/watchpoint: Disable pagefaults when getting user
  instruction (bsc#1194869).
- powerpc/watchpoints: Disable preemption in thread_change_pc()
  (bsc#1194869).
- powerpc/pseries: Rework lppaca_shared_proc() to avoid
  DEBUG_PREEMPT (bsc#1194869).
- powerpc: Don't include lppaca.h in paca.h (bsc#1194869).
- powerpc/powernv: Fix fortify source warnings in opal-prd.c
  (bsc#1194869).
- commit 72b942a
* Mon Feb 19 2024 lhruska@suse.cz
- rpm/scripts: Remove obsolete Symbols.list
  Symbols.list is not longer needed by the new klp-convert implementation. (bsc#1218644)
- commit 596cf9f
* Mon Feb 19 2024 msuchanek@suse.de
- powerpc/kasan: Limit KASAN thread size increase to 32KB
  (bsc#1215199).
- commit a664cb1
* Mon Feb 19 2024 duwe@suse.de
- dmaengine: idxd: Add support for device/wq defaults
  (jsc#PED-7793).
- crypto: iaa - Add IAA Compression Accelerator stats
  (jsc#PED-7793).
- crypto: iaa - Add irq support for the crypto async interface
  (jsc#PED-7793).
- crypto: iaa - Add support for deflate-iaa compression algorithm
  (jsc#PED-7793).
- crypto: iaa - Add compression mode management along with fixed
  mode (jsc#PED-7793).
- crypto: iaa - Add per-cpu workqueue table with rebalancing
  (jsc#PED-7793).
- crypto: iaa - Add Intel IAA Compression Accelerator crypto
  driver core (jsc#PED-7793).
- crypto: iaa - Add IAA Compression Accelerator Documentation
  (jsc#PED-7793).
- dmaengine: idxd: add callback support for iaa crypto
  (jsc#PED-7793).
- dmaengine: idxd: Add wq private data accessors (jsc#PED-7793).
- dmaengine: idxd: Export wq resource management functions
  (jsc#PED-7793).
- dmaengine: idxd: Export descriptor management functions
  (jsc#PED-7793).
- dmaengine: idxd: Rename drv_enable/disable_wq to
  idxd_drv_enable/disable_wq, and export (jsc#PED-7793).
- dmaengine: idxd: add external module driver support for
  dsa_bus_type (jsc#PED-7793).
- dmaengine: idxd: add wq driver name support for accel-config
  user tool (jsc#PED-7793).
- dmaengine: idxd: Remove unused declarations (jsc#PED-7793).
- commit 698723a
* Mon Feb 19 2024 mkoutny@suse.com
- Update config files.
  Only run_oldconfig.sh
- commit de91fa9
* Mon Feb 19 2024 oneukum@suse.com
- leds: Change led_trigger_blink[_oneshot]() delay parameters
  to pass-by-value (git-fixes).
- commit a5e7aeb
* Mon Feb 19 2024 oneukum@suse.com
- usb: ucsi_acpi: Quirk to ack a connector change ack cmd
  (git-fixes).
- commit 3843488
* Mon Feb 19 2024 mkoutny@suse.com
- Update config files.
  Disable CONFIG_RT_GROUP_SCHED (jsc#SLE-10427) on arm64 too.
- commit dffd692
* Mon Feb 19 2024 hare@suse.de
- nvme-keyring: restrict match length for version '1' identifiers
  (bsc#1219670).
- commit 131550a
* Mon Feb 19 2024 msuchanek@suse.de
- Refresh sorted patches.
- commit 6f4c0b8
* Mon Feb 19 2024 msuchanek@suse.de
- block: sed-opal: handle empty atoms when parsing response
  (jsc#PED-3545 git-fixes bsc#1220089 ltc#205305).
- commit c7fe618
* Mon Feb 19 2024 denis.kirjanov@suse.com
- net: ravb: Wait for operating mode to be applied (git-fixes).
- commit 40520b1
* Mon Feb 19 2024 msuchanek@suse.de
- powerpc/pseries: fix accuracy of stolen time (bsc#1215199).
- powerpc/64s: Increase default stack size to 32KB (bsc#1215199).
- powerpc/mm: Fix null-pointer dereference in pgtable_cache_add
  (bsc#1215199).
- powerpc/lib: Validate size for vector operations (bsc#1215199).
- commit b3e0008
* Mon Feb 19 2024 msuchanek@suse.de
- powerpc/iommu: Fix the missing iommu_group_put() during platform
  domain attach (jsc#PED-7779 jsc#PED-7780 git-fixes).
- commit 06cae39
* Mon Feb 19 2024 msuchanek@suse.de
- compute-PATCHVERSION: Do not produce output when awk fails
  compute-PATCHVERSION uses awk to produce a shell script that is
  subsequently executed to update shell variables which are then printed
  as the patchversion.
  Some versions of awk, most notably bysybox-gawk do not understand the
  awk program and fail to run. This results in no script generated as
  output, and printing the initial values of the shell variables as
  the patchversion.
  When the awk program fails to run produce 'exit 1' as the shell script
  to run instead. That prevents printing the stale values, generates no
  output, and generates invalid rpm spec file down the line. Then the
  problem is flagged early and should be easier to diagnose.
- commit 8ef8383
* Mon Feb 19 2024 osalvador@suse.de
- mm,page_owner: Filter out stacks by a threshold (jsc-PED#7423).
- commit 4b9a1a9
* Mon Feb 19 2024 denis.kirjanov@suse.com
- net: bcmgenet: Fix FCS generation for fragmented skbuffs (git-fixes).
- commit 15da81c
* Mon Feb 19 2024 osalvador@suse.de
- mm,page_owner: Display all stacks and their count
  (jsc-PED#7423).
- commit 582b35c
* Mon Feb 19 2024 osalvador@suse.de
- mm,page_owner: Implement the tracking of the stacks count
  (jsc-PED#7423).
- commit 9af4176
* Mon Feb 19 2024 osalvador@suse.de
- mm,page_owner: Maintain own list of stack_records structs
  (jsc-PED#7423).
- commit 332036c
* Mon Feb 19 2024 osalvador@suse.de
- lib/stackdepot: Move stack_record struct definition into the
  header (jsc-PED#7423).
- commit 19fef81
* Mon Feb 19 2024 osalvador@suse.de
- lib/stackdepot: Fix first entry having a 0-handle
  (jsc-PED#7423).
- commit 3666049
* Mon Feb 19 2024 tiwai@suse.de
- kallsyms: ignore ARMv4 thunks along with others (git-fixes).
- modpost: trim leading spaces when processing source files list
  (git-fixes).
- kbuild: Fix changing ELF file type for output of gen_btf for
  big endian (git-fixes).
- irqchip/gic-v3-its: Fix GICv4.1 VPE affinity update (git-fixes).
- irqchip/irq-brcmstb-l2: Add write memory barrier before exit
  (git-fixes).
- i2c: i801: Fix block process call transactions (git-fixes).
- i2c: qcom-geni: Correct I2C TRE sequence (git-fixes).
- commit 65eebf2
* Mon Feb 19 2024 dwagner@suse.de
- nvme-fabrics: fix I/O connect error handling (git-fixes).
- commit b81dbf7
* Sun Feb 18 2024 ailiop@suse.com
- xfs: reset XFS_ATTR_INCOMPLETE filter on node removal
  (git-fixes).
- commit 387ed3b
* Sun Feb 18 2024 ailiop@suse.com
- xfs: ensure logflagsp is initialized in xfs_bmap_del_extent_real
  (git-fixes).
- commit 73bc52b
* Sun Feb 18 2024 ailiop@suse.com
- xfs: don't leak recovered attri intent items (git-fixes).
- commit 3311908
* Sun Feb 18 2024 ailiop@suse.com
- xfs: dquot recovery does not validate the recovered dquot
  (git-fixes).
- commit 11dd393
* Sun Feb 18 2024 ailiop@suse.com
- xfs: clean up dqblk extraction (git-fixes).
- commit 2a55daa
* Sun Feb 18 2024 ailiop@suse.com
- xfs: inode recovery does not validate the recovered inode
  (git-fixes).
- commit eb71955
* Sun Feb 18 2024 ailiop@suse.com
- xfs: handle nimaps=0 from xfs_bmapi_write in
  xfs_alloc_file_space (git-fixes).
- commit a21b8a6
* Sun Feb 18 2024 ailiop@suse.com
- xfs: introduce protection for drop nlink (git-fixes).
- commit c20e066
* Sun Feb 18 2024 ailiop@suse.com
- xfs: rt stubs should return negative errnos when rt disabled
  (git-fixes).
- commit 3d89caf
* Sun Feb 18 2024 ailiop@suse.com
- xfs: prevent rt growfs when quota is enabled (git-fixes).
- commit fff2e4b
* Sun Feb 18 2024 ailiop@suse.com
- xfs: hoist freeing of rt data fork extent mappings (git-fixes).
- commit 44ca58e
* Sun Feb 18 2024 ailiop@suse.com
- xfs: bump max fsgeom struct version (git-fixes).
- commit 7d7701a
* Sun Feb 18 2024 tiwai@suse.de
- driver core: fw_devlink: Improve detection of overlapping cycles
  (git-fixes).
- driver core: Fix device_link_flag_is_sync_state_only()
  (git-fixes).
- iio: adc: ad4130: only set GPIO_CTRL if pin is unused
  (git-fixes).
- iio: adc: ad4130: zero-initialize clock init data (git-fixes).
- iio: accel: bma400: Fix a compilation problem (git-fixes).
- iio: commom: st_sensors: ensure proper DMA alignment
  (git-fixes).
- staging: iio: ad5933: fix type mismatch regression (git-fixes).
- iio: adc: ad_sigma_delta: ensure proper DMA alignment
  (git-fixes).
- iio: imu: adis: ensure proper DMA alignment (git-fixes).
- iio: imu: bno055: serdev requires REGMAP (git-fixes).
- iio: magnetometer: rm3100: add boundary check for the value
  read from RM3100_REG_TMRC (git-fixes).
- iio: pressure: bmp280: Add missing bmp085 to SPI id table
  (git-fixes).
- iio: core: fix memleak in iio_device_register_sysfs (git-fixes).
- thunderbolt: Fix setting the CNS bit in ROUTER_CS_5 (git-fixes).
- media: ir_toy: fix a memleak in irtoy_tx (git-fixes).
- media: Revert "media: rkisp1: Drop IRQF_SHARED" (git-fixes).
- commit 7fba7be
* Sat Feb 17 2024 tiwai@suse.de
- ASoC: amd: yc: Fix non-functional mic on Lenovo 82UU
  (git-fixes).
- ALSA: hda/realtek: cs35l41: Add internal speaker support for
  ASUS UM3402 with missing DSD (git-fixes).
- ALSA: hda: cs35l41: Support ASUS Zenbook UM3402YAR (git-fixes).
- ALSA: hda: cs35l41: Support additional ASUS Zenbook UX3402VA
  (git-fixes).
- ALSA: hda: Increase default bdl_pos_adj for Apollo Lake
  (git-fixes).
- ALSA: hda: Replace numeric device IDs with constant values
  (git-fixes).
- ALSA: hda: generic: Remove obsolete call to ledtrig_audio_get
  (git-fixes).
- ALSA: hda: Properly setup HDMI stream (git-fixes).
- commit 65b7327
* Sat Feb 17 2024 tiwai@suse.de
- ALSA: hda: Add Lenovo Legion 7i gen7 sound quirk (git-fixes).
- commit 2ab077c
* Sat Feb 17 2024 tiwai@suse.de
- ALSA: hda/realtek: fix mute/micmute LED For HP mt645
  (git-fixes).
- ASoC: amd: yc: Add DMI quirk for Lenovo Ideapad Pro 5 16ARP8
  (git-fixes).
- ALSA: hda/realtek: add IDs for Dell dual spk platform
  (git-fixes).
- ALSA: hda/conexant: Add quirk for SWS JS201D (git-fixes).
- commit 96b23dc
* Sat Feb 17 2024 tiwai@suse.de
- ALSA: usb-audio: More relaxed check of MIDI jack names
  (git-fixes).
- ASoC: SOF: IPC3: fix message bounds on ipc ops (git-fixes).
- ASoC: q6dsp: fix event handler prototype (git-fixes).
- ASoC: rt5645: Fix deadlock in rt5645_jack_detect_work()
  (git-fixes).
- ASoC: SOF: ipc3-topology: Fix pipeline tear down logic
  (git-fixes).
- ASoC: cs35l56: Fix deadlock in ASP1 mixer register
  initialization (git-fixes).
- ASoC: tas2781: add module parameter to tascodec_init()
  (git-fixes).
- ASoC: cs35l56: fix reversed if statement in
  cs35l56_dspwait_asp1tx_put() (git-fixes).
- ALSA: hda/realtek: cs35l41: Fix order and duplicates in quirks
  table (git-fixes).
- ALSA: hda/realtek: cs35l41: Fix device ID / model name
  (git-fixes).
- ALSA: hda/cs35l56: select intended config FW_CS_DSP (git-fixes).
- wifi: brcmfmac: Adjust n_channels usage for __counted_by
  (git-fixes).
- USB: serial: option: add Fibocom FM101-GL variant (git-fixes).
- USB: serial: qcserial: add new usb-id for Dell Wireless DW5826e
  (git-fixes).
- USB: serial: cp210x: add ID for IMST iM871A-USB (git-fixes).
- usb: dwc3: pci: add support for the Intel Arrow Lake-H
  (git-fixes).
- xhci: handle isoc Babble and Buffer Overrun events properly
  (git-fixes).
- xhci: process isoc TD properly when there was a transaction
  error mid TD (git-fixes).
- usb: dwc3: host: Set XHCI_SG_TRB_CACHE_SIZE_QUIRK (git-fixes).
- Input: i8042 - fix strange behavior of touchpad on Clevo NS70PU
  (git-fixes).
- selftests/net: change shebang to bash to support "source"
  (git-fixes).
- selftests/net: convert pmtu.sh to run it in unique namespace
  (git-fixes).
- selftests/net: convert unicast_extensions.sh to run it in
  unique namespace (git-fixes).
- commit 1f8c296
* Sat Feb 17 2024 pjakobsson@suse.de
- drm/bridge: imx: Add i.MX93 MIPI DSI support (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Update config files.
  DRM_IMX93_MIPI_DSI not set
- commit a2123b2
* Sat Feb 17 2024 pjakobsson@suse.de
- drm/panel: ili9882t: Break out as separate driver (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Update config files.
  CONFIG_DRM_PANEL_ILITEK_ILI9882T not set
- commit a8ac974
* Sat Feb 17 2024 pjakobsson@suse.de
- drm/panel: Add driver for BOE RM692E5 AMOLED panel (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Update config files.
  DRM_PANEL_RAYDIUM_RM692E5 not set
- commit 5df9197
* Sat Feb 17 2024 pjakobsson@suse.de
- fbdev: Provide I/O-memory helpers as module (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Update config files.
  CONFIG_FB_IOMEM_FOPS=m
- supported.conf: Add fb_io_fops as supported
- commit 513f33f
* Sat Feb 17 2024 pjakobsson@suse.de
- drm/gpuvm: allow building as module (jsc#PED-3527 jsc#PED-5475
  jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Update config files.
  CONFIG_DRM_GPUVM=m
- supported.conf: Add DRM_GPUVM as supported
- drm/gpuvm: rename struct drm_gpuva_manager to struct
  drm_gpuvm (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 6497d38
* Sat Feb 17 2024 pjakobsson@suse.de
- drm/panel: Add driver for JDI LPM102A188A (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Update config files.
  CONFIG_DRM_PANEL_JDI_LPM102A188A not set
- commit 60812f3
* Fri Feb 16 2024 mwilck@suse.com
- scsi: smartpqi: Bump driver version to 2.1.26-030 (bsc#1219987).
- scsi: smartpqi: Fix logical volume rescan race condition
  (bsc#1219987).
- scsi: smartpqi: Add new controller PCI IDs (bsc#1219987).
- commit 343b48a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ci: clean up xfails (specially flakes list) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 01bf355
* Fri Feb 16 2024 mwilck@suse.com
- scsi: mpt3sas: Reload SBR without rebooting HBA (bsc#1219551).
- scsi: mpt3sas: Suppress a warning in debug kernel (bsc#1219551).
- scsi: mpt3sas: Replace dynamic allocations with local variables
  (bsc#1219551).
- scsi: mpt3sas: Replace a dynamic allocation with a local
  variable (bsc#1219551).
- scsi: mpt3sas: Fix typo of "TRIGGER" (bsc#1219551).
- scsi: mpt3sas: Fix an outdated comment (bsc#1219551).
- scsi: mpt3sas: Remove the iounit_pg8 member of the per-adapter
  struct (bsc#1219551).
- scsi: mpt3sas: Use struct_size() for struct size calculations
  (bsc#1219551).
- scsi: mpt3sas: Make MPI26_CONFIG_PAGE_PIOUNIT_1::PhyData a
  flexible array (bsc#1219551).
- scsi: mpt3sas: Make MPI2_CONFIG_PAGE_SASIOUNIT_1::PhyData a
  flexible array (bsc#1219551).
- scsi: mpt3sas: Make MPI2_CONFIG_PAGE_SASIOUNIT_0::PhyData a
  flexible array (bsc#1219551).
- scsi: mpt3sas: Make MPI2_CONFIG_PAGE_RAID_VOL_0::PhysDisk a
  flexible array (bsc#1219551).
- scsi: mpt3sas: Make MPI2_CONFIG_PAGE_IO_UNIT_8::Sensor a
  flexible array (bsc#1219551).
- scsi: mpt3sas: Use flexible arrays when obviously possible
  (bsc#1219551).
- commit 472a48e
* Fri Feb 16 2024 lhenriques@suse.de
- ext4: prevent the normalized size from exceeding EXT_MAX_BLOCKS
  (bsc#1220174).
- commit 6b2b7ed
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/dp: Honor GSP link training retry timeouts (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6f1c533
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau: push event block/allowing out of the fence context (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 983056c
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau/gsp: always free the alloc messages on r535 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5c8ea4c
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau/gsp: don't free ctrl messages on errors (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5511cbc
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau/gsp: convert gsp errors to generic errors (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 94f5fc8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/gsp: Fix ACPI MXDM/MXDS method invocations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a2467cb
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau/gsp: free userd allocation. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 065397b
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau/gsp: free acpi object after use (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2b4fd91
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau: fix disp disabling with GSP (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ae68469
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau/gsp: drop some acpi related debug (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 92867eb
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau/gsp: add three notifier callbacks that we see in normal (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 09d15aa
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Use gpu_metrics_v1_5 for SMUv13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1b5903d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Add gpu_metrics_v1_5 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 30e8919
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Add mem_busy_percent for GCv9.4.3 apu (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6e21708
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Update metric table for jpeg/vcn data (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 419b696
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Use separate metric table for APU (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 88685a3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: Get bigjoiner config before dsc config during (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cf3b0e1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: dereference variable before checking for zero (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f60628b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: disable FPO and SubVP for older DMUB versions on (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0da91df
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Revert " drm/amd/display: Use channel_width = 2 for (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 04213eb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/kms/nv50-: Don't allow inheritance of headless iors (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5b22958
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau: Fixup gk20a instobj hierarchy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e12de7c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panel: ltk050h3146w: Set burst mode for ltk050h3148w (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 227f279
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: warn when there are still mappings when a BO is destroyed (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 45b2581
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Fix a probing order problem on SDMA 2.4 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7c8e922
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Populate dtbclk from bounding box (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eba3852
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Revert "Fix conversions between bytes and KB" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fc8d63d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/jpeg: configure doorbell for each playback (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 489af49
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: fix hw rotated modes when PSR-SU is enabled (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0e33036
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: fix pp_*clk_od typo (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 846c80b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: fix buffer funcs setting order on suspend harder (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 60ded2a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: mtk_disp_gamma: Fix breakage due to merge issue (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c4b6d76
* Fri Feb 16 2024 pjakobsson@suse.de
- mei: pxp: fix mei_pxp_send_message return value (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d83417c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: fix buffer funcs setting order on suspend (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3292583
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Avoid querying DRM MGCG status (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ee39ec6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Update HDP 4.4.2 clock gating flags (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 066f3b2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Restrict extended wait to PSP v13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 58b9a57
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: optimize the printing order of error data (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d9a7646
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Update fw version for boot time error query (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7d7fdb4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: support new mca smu error code decoding (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d79039e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/swsmu: update smu v14_0_0 driver if version and metrics table (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c101f43
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix array-index-out-of-bounds in dml2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a784746
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Use channel_width = 2 for vram table 3.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d35a295
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panfrost: Fix incorrect updating of current device frequency (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6eb00f8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panfrost: Consider dma-buf imported objects as resident (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9b8c3c3
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau/gsp: document some aspects of GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d331b9c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: correct the input parameter on _intel_dsb_commit() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2bf23fe
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Check pipe active state in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 015f301
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix some HostVM parameters in DML (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f19df3a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Allow DTBCLK disable for DCN35 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ca48e6b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: fix AGP addressing when GART is not at 0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7a07b43
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix black screen on video playback with embedded (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 585ccb0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix conversions between bytes and KB (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5cc1aee
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Remove config update (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9b869bb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update DCN35 clock table policy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 474c4c8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add init_registers for nbio v7.11 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4f1ac78
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Do not read DPREFCLK spread info from LUT on DCN35 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 57c43f1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix MPCC 1DLUT programming (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bce1e89
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Feed SR and Z8 watermarks into DML2 for DCN35 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 340e395
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add Z8 watermarks for DML2 bbox overrides (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit effcb2b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: optimize RLC powerdown notification on Vangogh (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 99b7a01
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: fix a pipe mapping error in dcn32_fpu (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d5d56b6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update DCN35 watermarks (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 23a8809
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: update xgmi num links info post gc9.4.2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 27c550f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add z-state support policy for dcn35 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d9c6ded
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau/gsp: replace zero-length array with flex-array member and use (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a9af727
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau/gsp/r535: remove a stray unlock in r535_gsp_rpc_send() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e54c783
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/gpuvm: Fix deprecated license identifier (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8a48e05
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/bridge: panel: Add a device link between drm device and (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3064382
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/bridge: panel: Check device dependency before managing (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5bb3979
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: panel: Check device dependency before managing device (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ab3cb7e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Fix race between connector registration and setup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a1725b5
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau/gsp: allocate enough space for all channel ids. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d92ed03
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm: remove unnecessary NULL check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 42f20b9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dp: attach the DP subconnector property (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5e0574d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dp: don't touch DP subconnector property in eDP case (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 29868de
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm: remove exra drm_kms_helper_poll_init() call (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0964707
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/gmc9: disable AGP aperture (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2a16255
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/gmc10: disable AGP aperture (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 552d4fa
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/gmc11: disable AGP aperture (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f545dfe
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add a module parameter to control the AGP aperture (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 641bbb7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/gmc11: fix logic typo in AGP check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1842e7a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix encoder disable logic (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 461952e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add and populate the port num into xgmi topology info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3261c67
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Negate IPS allow and commit bits (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 02c359f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Don't send unload message for reset (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit afa6b4f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: fix ras err_data null pointer issue in amdgpu_ras.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 481e246
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: fix NULL dereference (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1246314
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add null checks for 8K60 lightup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1b7d41c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Fill pcie error counters for gpu v1_4 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ce78527
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Update metric table for smu v13_0_6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1c3fff6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Address member 'ring' not described in 'amdgpu_ vce, (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 31b3fbe
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau: don't fail driver load if no display hw present. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 43adc14
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: panel-orientation-quirks: Add quirk for Lenovo Legion Go (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fd1f874
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau/gsp/r535: Fix a NULL vs error pointer bug (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d7cad37
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau/gsp/r535: uninitialized variable in r535_gsp_acpi_mux_id() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a448103
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ci: make github dependabot happy again (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8324a2d
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: amifb: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 437efee
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: amifb: Mark driver struct with __refdata to prevent section (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7b2956e
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: hyperv_fb: fix uninitialized local variable use (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 55001fe
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: omapfb/tpd12s015: Convert to platform remove callback (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5dd61b7
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: omapfb/tfp410: Convert to platform remove callback returning (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4f18038
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: omapfb/sharp-ls037v7dw01: Convert to platform remove callback (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d6a9841
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: omapfb/opa362: Convert to platform remove callback returning (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 44ec1aa
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: omapfb/hdmi: Convert to platform remove callback returning (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6ea982d
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: omapfb/dvi: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ea32002
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: omapfb/dsi-cm: Convert to platform remove callback returning (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit de05f91
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: omapfb/dpi: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 505b7b3
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: omapfb/analog-tv: Convert to platform remove callback (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3527522
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: atmel_lcdfb: Convert to platform remove callback returning (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c99049a
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: omapfb/tpd12s015: Don't put .remove() in .exit.text and drop (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ded8d0e
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: omapfb/tfp410: Don't put .remove() in .exit.text and drop (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 44eb5a7
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: omapfb/sharp-ls037v7dw01: Don't put .remove() in .exit.text (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit da679c9
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: omapfb/opa362: Don't put .remove() in .exit.text and drop (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dd6db02
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: omapfb/hdmi: Don't put .remove() in .exit.text and drop (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 97db389
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: omapfb/dvi: Don't put .remove() in .exit.text and drop (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 24535d3
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: omapfb/dsi-cm: Don't put .remove() in .exit.text and drop (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7d2c172
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: omapfb/dpi: Don't put .remove() in .exit.text and drop (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6896d5f
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: omapfb/analog-tv: Don't put .remove() in .exit.text and drop (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9afdc42
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: atmel_lcdfb: Stop using platform_driver_probe() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ba988f0
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: viafb: use new array-copying-wrapper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eceeb33
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: offb: Simplify offb_init_fb() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a7f923c
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: omapfb: Replace custom memparse() implementation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b9e1e25
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: omapfb: Do not shadow error code from platform_get_irq() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 313aed2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: move UVD and VCE sched entity init after sched init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 32ad076
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: move kfd_resume before the ip late init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 75bd33b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Explicitly check for GFXOFF to be enabled for s0ix (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fe38f21
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Change WREG32_RLC to WREG32_SOC15_RLC where inst != 0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 29e3871
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Use correct KIQ MEC engine for gfx9.4.3 (v5) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5965c95
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add smu v13.0.6 pcs xgmi ras error query support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 113f264
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: remove duplicated argument (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bfeb35e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: correct mca debugfs dump reg list (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bb57bec
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: correct acclerator check architecutre dump (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6942085
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add pcs xgmi v6.4.0 ras support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8a20378
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Change extended-scope MTYPE on GC 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2e537aa
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: disable smu v13.0.6 mca debug mode by default (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7debbb3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Support multiple error query modes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ba0fb70
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: refine smu v13.0.6 mca dump driver (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f2b637
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Do not program PF-only regs in hdp_v4_0.c under SRIOV (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit be5761c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Skip PCTL0_MMHUB_DEEPSLEEP_IB write in jpegv4.0.3 under (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ab2c7a3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: amd: Resolve Sphinx unexpected indentation warning (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 308c013
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: correct smu v13.0.6 umc ras error check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ff2d8f4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Add xcc param to SRIOV kiq write and (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 04dd98a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Add flag to enable indirect RLCG access for gfx v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit acc5e7e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: raise the deep sleep clock threshold for smu 13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 55b5f29
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: correct amdgpu ip block rev info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d144ebf
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Hide pp_dpm_pcie device attribute (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2d96d22
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Don't warn for unsupported set_xgmi_plpd_mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b2e71ef
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: fix AGP init order (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 342a4a1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add RAS reset/query operations for XGMI v6_4 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9a4fb50
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: handle extra UE register entries for gfx v9_4_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 618f901
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: not stop rlc for IMU enabled APUs when suspend (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7e4f372
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: avoid variable reinitialization (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 14bd35e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Hide irrelevant pm device attributes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b3c76e9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Fix sdma 4.4.2 doorbell rptr/wptr init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4bc5a43
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/soc21: add mode2 asic reset for SMU IP v14.0.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e056116
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Set stream's DP test pattern upon test request (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e76f252
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix handling duplicate planes on one stream (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9f8d58a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: For cursor P-State allow for SubVP (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 88a768c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Enable physymclk RCO (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 24e2639
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Remove references to unused dml arch version (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d434ee8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Promote DAL to 3.2.259 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 362f63c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: save and restore mall state when applying minimal (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 787f58d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Remove unused duplicate register definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 63ae58b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Create optc.h file (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 60e0880
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Disable OTG for mode timing switch on DCN35 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1cb589d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Revise Replay Desync Error IRQ handle (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 515181b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.190.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 196755a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.258 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b0dd968
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add missing dml2 init value for dcn35 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 67e6bb9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix OTG disable workaround logic (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 407af4a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: amend HPD handler for Replay (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8effe0a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Introduce flag for disabling Replay desync recovery (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4e78171
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: DCN35 Disable cm power optimization (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 45def98
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update DP HPO MSA with colorimetry from test request (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0e8205e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update test link rate DPCD bit field to match spec (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eabbcc3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Allow 16 max_slices for DP2 DSC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8800763
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Enable more IPS options (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b177a6e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Enable RCO options for dcn35 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c8e4b3f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix FRL assertion on boot (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1febae0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix missing blendTF programming (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8e3171e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.257 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit af3e1f6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: decouple dmcub execution to reduce lock granularity (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c211126
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.189.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 640d7d9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: On boot disable domain22 force power on (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3b444c0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Disable XNACK on SRIOV environment (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e9733b6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/mtl: Apply notify_guc to all GTs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c078fbd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Enable fast update on blendTF change (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 53591e4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix blend LUT programming (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 55c5aeb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Program plane color setting correctly (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c764568
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Query and report boot status (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 12c9dfc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Add psp v13 function to query boot status (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 59d683c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/swsmu: remove fw version check in sw_init. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 23c4d42
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/swsmu: update smu v14_0_0 driver if and metrics table (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 07ec4b7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Add C2PMSG_109/126 reg field shift/masks (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ddc4911
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Optimize the asic type fix code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e7c9919
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: check recovery status of xgmi hive in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f7f964b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: only check sriov vf flag once when creating hwmon sysfs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 90e8477
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Attach eviction fence on alloc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3c6a830
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdkfd: Improve amdgpu_vm_handle_moved (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bdb107b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Increase frame warning limit with KASAN or KCSAN in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a2fad8d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdkfd: Update cache info for GFX 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cefe700
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdkfd: Populate cache info for GFX 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 39b776d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: don't put MQDs in VRAM on ARM | ARM64 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 29d4458
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: ungate power gating when system suspend (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 08dd1c9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/radeon: replace 1-element arrays with flexible-array members (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 73d9467
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Fix UBSAN array-index-out-of-bounds for Powerplay headers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 81c94b6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: don't use ATRM for external devices (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e0a5c4e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: use mode-2 reset for RAS poison consumption (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dc27bc1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu doorbell range should be set when gpu recovery
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/drm-amdgpu-gfx10-11-use-memcpy_to-fromio-for-MQDs.patch.
- commit 2791dcf
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Return 0 as default min power limit for legacy asics (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4813352
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: remove unused macro HW_REV (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0fbbc0b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Fix the vram base start address (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 39c6505
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: set XGMI IP version manually for v6_4 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5bd5de5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add unmap latency when gfx11 set kiq resources (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f54612b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: fix the high voltage and temperature issue (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 86474f9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: remove amdgpu_mes_self_test in gpu recover (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 099d02a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Drop deferred error in uncorrectable error check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f6b2d3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Fix warnings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 908dc19
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: check RAS supported first in ras_reset_error_count (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f972ac
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ssd130x: Fix possible uninitialized usage of crtc_state variable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1865c01
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Add DT support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a398605
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Atomic conversion part 3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ae03c75
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Remove internal CRTC state tracking (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7af2998
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Use suspend/resume helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1536609
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Atomic conversion part 2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5981a6c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Atomic conversion part 1 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cf48fe5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Cleanup encoder (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0d89ba4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Shutdown the display on remove (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 81d2c53
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Turn vblank on/off when enabling/disabling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a90752e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Wait for page flip when turning CRTC off (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fe81575
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Move shmob_drm_crtc_finish_page_flip() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 26e5993
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Use drm_crtc_handle_vblank() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 031b40a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Rename shmob_drm_plane.plane (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 23fa3bb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Rename shmob_drm_connector.connector (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aeec558
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Rename shmob_drm_crtc.crtc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 84c95c8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Unify plane allocation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3fe00c3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Move interface handling to connector setup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5380f33
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Use media bus formats in platform data (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 32a7fa4
* Fri Feb 16 2024 pjakobsson@suse.de
- media: uapi: Add MEDIA_BUS_FMT_RGB666_2X9_BE format (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8d1b159
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Use struct videomode in platform data (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 065a828
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Replace .dev_private with container_of() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 54f3a1d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Convert container helpers to static inline (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 21fb2cd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Embed drm_device in shmob_drm_device (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e639805
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Use drmm_universal_plane_alloc() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 461b95c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Remove custom plane destroy callback (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cf1913a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Convert to use devm_request_irq() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 87a7ef5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Improve error handling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aea0b10
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Remove support for SYS panels (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 699ed30
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Rename input clocks (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f4a2341
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Don't set display info width and height twice (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eb9bddc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Remove backlight support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c035a82
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Improve shmob_drm_format_info table (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d1b69d6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Add missing YCbCr formats (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a1c67b6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Use %%p4cc to print fourcc code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2f706d5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Restore indentation of (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 312acbd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Add support for Runtime PM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 15ec50a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Correct encoder/connector types (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a670b53
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Fix ARGB32 overlay format typo (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4b4fb9b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Fix overlay plane disable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4227c66
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau/gsp: add some basic registry entries. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ffb9709
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau/gsp: fix message signature. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 94ef5a1
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau/gsp: move to 535.113.01 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 180ef97
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau/disp: fix post-gsp build on 32-bit arm. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 968d4e8
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau: fix r535 build on 32-bit arm. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9a915c9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/ofa/r535: initial support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c63c9e2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/nvjpg/r535: initial support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c6ac3de
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/nvenc/r535: initial support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7dd6e90
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/nvdec/r535: initial support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 173fb7c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/gr/r535: initial support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1261a7b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/ce/r535: initial support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 92b41d6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/fifo/r535: initial support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dd383d9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp/r535: initial support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 71e2fcc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/mmu/r535: initial support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3effade
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/gsp/r535: add interrupt handling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6df52fe
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/gsp/r535: add support for rm alloc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 243a362
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/gsp/r535: add support for rm control (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 387e20e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/gsp/r535: add support for booting GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 48a5e06
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/nvkm: support loading fws into sg_table (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9b0eec4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/kms/tu102-: disable vbios parsing when running on RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c4d1c8c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/sec2/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d16188d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/nvenc/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3013dff
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/nvdec/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 79f6bc2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/gr/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f357460
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/fifo/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5b1ad86
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 33d7df5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/ce/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aac5287
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/vfn/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3b10df1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/top/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 869a383
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/therm/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e27d7d9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/privring/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e2cac84
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/pmu/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 942cf92
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/mmu/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3dbaebd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/mc/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 348bcb8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/ltc/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b567822
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/imem/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7d980d7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/i2c/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9538e4b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/gpio/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0283e96
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/fuse/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dcebadb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/fb/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 50c7b14
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/fault/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6c6a2a5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/devinit/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8de6a3b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/bus/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b712e58
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/bar/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2642882
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/acr/tu102-: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fa95246
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/gsp: prepare for GSP-RM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 30bd8f3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/nvkm: bump maximum number of NVJPG (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5e69366
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/nvkm: bump maximum number of NVDEC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bb557e2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/mmu/tu102-: remove write to 0x100e68 during tlb (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b271879
* Fri Feb 16 2024 pjakobsson@suse.de
- hyperv: avoid dependency on screen_info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 63e171c
* Fri Feb 16 2024 pjakobsson@suse.de
- vgacon: remove screen_info dependency (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 138a609
* Fri Feb 16 2024 pjakobsson@suse.de
- dummycon: limit Arm console size hack to footbridge (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dea6107
* Fri Feb 16 2024 pjakobsson@suse.de
- vgacon: rework Kconfig dependencies (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a463e9c
* Fri Feb 16 2024 pjakobsson@suse.de
- mei: me: emit error only if reset was unexpected (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 639ccd0
* Fri Feb 16 2024 pjakobsson@suse.de
- misc: mei: main.c: fix kernel-doc warnings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 36ea187
* Fri Feb 16 2024 pjakobsson@suse.de
- misc: mei: interrupt.c: fix kernel-doc warnings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1274df0
* Fri Feb 16 2024 pjakobsson@suse.de
- misc: mei: hw-me.c: fix kernel-doc warnings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b8d7f52
* Fri Feb 16 2024 pjakobsson@suse.de
- misc: mei: hbm.c: fix kernel-doc warnings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 571a7cb
* Fri Feb 16 2024 pjakobsson@suse.de
- misc: mei: dma-ring.c: fix kernel-doc warnings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 211f11a
* Fri Feb 16 2024 pjakobsson@suse.de
- misc: mei: client.c: fix kernel-doc warnings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3452a20
* Fri Feb 16 2024 pjakobsson@suse.de
- misc: mei: hw.h: fix kernel-doc warnings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6c8ace5
* Fri Feb 16 2024 pjakobsson@suse.de
- mei: docs: fix spelling errors (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit df8b19c
* Fri Feb 16 2024 pjakobsson@suse.de
- mei: docs: add missing entries to kdoc in struct mei_cfg_idx (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eb85504
* Fri Feb 16 2024 pjakobsson@suse.de
- mei: docs: use correct structures name in kdoc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7a63bf0
* Fri Feb 16 2024 pjakobsson@suse.de
- mei: update mei-pxp's component interface with timeouts (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 75486af
* Fri Feb 16 2024 pjakobsson@suse.de
- mei: pxp: re-enable client on errors (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3f191b4
* Fri Feb 16 2024 pjakobsson@suse.de
- mei: pxp: recover from recv fail under memory pressure (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 30d4598
* Fri Feb 16 2024 pjakobsson@suse.de
- mei: bus: add send and recv api with timeout (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 95c9cf8
* Fri Feb 16 2024 pjakobsson@suse.de
- mei: fix doc typos (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a0116d9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/qxl: Use pci_is_vga() to identify VGA devices (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 872d23a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/virtio: Use pci_is_vga() to identify VGA devices (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6aa20a7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/radeon: Use pci_get_base_class() to reduce duplicated code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 229bb15
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Use pci_get_base_class() to reduce duplicated code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit acbdb10
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau: Use pci_get_base_class() to reduce duplicated code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1f88c5b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/amdgpu: avoid to disable gfxhub interrupt when driver is (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f1ebff4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Add EXT_COHERENT support for APU and NUMA systems (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fdc2397
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Retrieve CE count from ce_count_lo_chip in EccInfo table (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a62eae4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Identify data parity error corrected in replay mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a96b367
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Fix typo in IP discovery parsing (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 209a4ef
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: fix S/G display enablement (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit feddebe
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdxcp: fix amdxcp unloads incompletely (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7458056
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/amdgpu: fix the GPU power print error in pm info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 528ed7c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Use pcie domain of xcc acpi objects (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 85463d2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Add a read to GFX v9.4.3 ring test (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 35eb2ed
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: call smu_cmn_get_smc_version in is_mode1_reset_supported. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dd85096
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: get RAS poison status from DF v4_6_2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a0eeca6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Use discovery table's subrevision (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3b25ece
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.256 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4936c07
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: add interface to query SubVP status (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c793771
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Read before writing Backlight Mode Set Register (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e7c7a2b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Disable SYMCLK32_SE RCO on DCN314 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e5c9b57
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix shaper using bad LUT params (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7e2925e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: add null check for invalid opps (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d5ed5f9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update FAMS sequence for DCN30 & DCN32 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 23b8830
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: fix num_ways overflow error (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 12f1a5a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add prefix for plane functions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 125ad35
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add prefix to amdgpu crtc functions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 572915e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Correct enum typo (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 36b855b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Set emulated sink type to HDMI accordingly. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c609b4d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Revert "drm/amd/display: allow edp updates for (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3710207
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix HDMI framepack 3D test issue (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8b628a7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix IPS handshake for idle optimizations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 261884b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: implement map dc pipe with callback in DML2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6eec916
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: add pipe resource management callbacks to DML2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d057e62
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update SDP VSC colorimetry from DP test automation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 62ae635
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add a check for idle power optimization (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d4cd73d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Revert "Improve x86 and dmub ips handshake" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cb14f3c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix MST Multi-Stream Not Lighting Up on dcn35 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8a795c1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Explicitly disable ASPM when dynamic switching disabled (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c74f4e7
* Fri Feb 16 2024 dwagner@suse.de
- nvme: enable retries for authentication commands (bsc#1186716).
- nvme: change __nvme_submit_sync_cmd() calling conventions
  (bsc#1186716).
- nvme-auth: open-code single-use macros (bsc#1186716).
- nvme: use ctrl state accessor (bsc#1186716).
- commit f8cc1d3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Move AMD_IS_APU check for ASPM into top level function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c3bce11
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/amdkfd: Use partial migrations in GPU page faults" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 38c49d0
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/amdkfd:remove unused code" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7e4263e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix copyright notice in DC code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 527c4a2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix copyright notice in DML2 code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6ecb70e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add missing copyright notice in DMUB (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f96c8f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu remove restriction of sriov max_pfn on Vega10 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 810cee0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdkfd: Address 'remap_list' not described in 'svm_range_add' (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 47ddcd9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: bypass RAS error reset in some conditions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d866d32
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: enable RAS poison mode for APU (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ea9f177
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/vpe: correct queue stop programing (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ff8e0df
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix DMUB errors introduced by DML2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4fb02c6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Set the DML2 attribute to false in all DCNs older (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6c96577
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Fix the return value in default case (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 657bc27
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Add API to get full IP version (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 494526f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add tmz support for GC IP v11.5.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8e98ade
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: drop unneeded dpm features disablement for SMU 14.0.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 15fd7cf
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: modify if condition in nbio_v7_7.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 57afcdd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: refine ras error kernel log print (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1cbaceb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: fix find ras error node error (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 46a75c8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: reprogram det size while seamless boot (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 264d394
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: record mca debug mode in RAS (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 594e9ba
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: move buffer funcs setting up a level (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0fea648
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/sched: Convert the GPU scheduler to variable number of run-queues (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 695984d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ci: docs: add step about how to request privileges (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b91fa8d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ci: do not automatically retry on error (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3121220
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ci: export kernel config (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 93f905f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ci: increase i915 job timeout to 1h30m (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 59e1148
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ci: add subset-1-gfx to LAVA_TAGS and adjust shards (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6badf12
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ci: uprev IGT and make sure core_getversion is run (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6a57584
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ci: add helper script update-xfails.py (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d58a660
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ci: fix DEBIAN_ARCH and get amdgpu probing (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 35de0dc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ci: uprev mesa version: fix container build & crosvm (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3454243
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ci: Enable CONFIG_BACKLIGHT_CLASS_DEVICE (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9205c61
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ci: force-enable CONFIG_MSM_MMCC_8996 as built-in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9eb8f1f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ci: pick up -external-fixes from the merge target repo (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f5f25de
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/doc: ci: Require more context for flaky tests (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cd53377
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/doc: document DRM_IOCTL_MODE_CREATE_DUMB (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 103a902
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/rockchip: vop: Add NV15, NV20 and NV30 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3a84c97
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/fourcc: Add NV20 and NV30 YUV formats (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3238b6d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/rockchip: vop2: rename window formats to show window type using (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b2bbf07
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/rockchip: vop2: Add more supported 10bit formats (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e3788bd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/rockchip: vop: fix format bpp calculation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9b1e50c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: synopsys: dw-mipi-dsi: Fix hcomponent lbcc for burst mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 47d375a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/client: Convert drm_client_buffer_addfb() to drm_mode_addfb2() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5f5a6e8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/doc: use cross-references for macros (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bb5ab1d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panel: ili9882t: Avoid blurred screen from fast sleep (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c0df107
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ast: Move register constants to ast_reg.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dc73b99
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ast: Rename AST_IO_MISC_PORT_READ to AST_IO_VGAMR_R (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 26a6753
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ast: Rename AST_IO_INPUT_STATUS1_READ to AST_IO_VGAIR1_R (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 77f0baf
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ast: Rename AST_IO_CRTC_PORT to AST_IO_VGACRI (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e488635
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ast: Rename AST_IO_GR_PORT to AST_IO_VGAGRI (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6cea9aa
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ast: Rename AST_IO_DAC_DATA to AST_IO_VGAPDR (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aecc26b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ast: Rename AST_IO_DAC_INDEX_WRITE to AST_IO_VGADWR (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fc7d8f8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ast: Rename AST_IO_DAC_INDEX_READ to AST_IO_VGADRR (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e542f42
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ast: Rename AST_IO_SEQ_PORT to AST_IO_VGASRI (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9655e97
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ast: Rename AST_IO_VGA_ENABLE_PORT to AST_IO_VGAER (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aa0a5b2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ast: Rename AST_IO_MISC_PORT_WRITE to AST_IO_VGAMR_W (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 75127e7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ast: Rename AST_IO_AR_PORT_WRITE to AST_IO_VGAARI_W (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5469f71
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/vt8623fb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 89d6ecb
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/viafb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7363b33
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/vga16fb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 04bce5e
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/vermilionfb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4b1cbc6
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/tridentfb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a524b13
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/tgafb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3e46fbe
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/tdfxfb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7ab2130
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/sunxvr500: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 270fedb
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/stifb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6fed3d6
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/sm712fb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f4685fb
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/sm501fb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5d238f4
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/sisfb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 462b792
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/savagefb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3bce7da
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/sa1100fb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ce0da22
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/s3fb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 41ed02e
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/s1d13xxxfb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cd82960
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/rivafb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e6bf2bb
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/radeon: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 54d13c9
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/pvr2fb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 934366a
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/pm3fb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 43ab478
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/pm2fb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c161dd4
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/omapfb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b4f4888
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/nvidiafb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2f7065e
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/neofb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 00d946a
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/matroxfb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bc42078
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/intelfb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 98f7aed
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/imsttfb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit de44f73
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/i810fb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b661486
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/hpfb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 20c24fe
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/hitfb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 81bddca
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/hgafb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 75fc2e3
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/gbefb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fc61cc4
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/ep93xx-fb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c78e671
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/dnfb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1785122
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/cyber2000fb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e8de30e
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/controlfb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3418f44
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/cobalt-lcd: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 85fb85a
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/cirrusfb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 669985c
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/au1100fb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 662ab91
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/atyfb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cfe5544
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/atafb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a73d00f
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/arkfb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0e3d305
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/amifb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 649eac5
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/amba-clcd: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d43048a
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/68328fb: Initialize fb_ops to fbdev I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f47d8ca
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ssd130x: Add support for the SSD132x OLED controller family (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cfa58ed
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ssd130x: Rename commands that are shared across chip families (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5c5005b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ssd130x: Add a controller family id to the device info data (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 088d682
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ssd130x: Replace .page_height field in device info with a (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 864a885
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/gpuvm: Dual-licence the drm_gpuvm code GPL-2.0 OR MIT (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0780e78
* Fri Feb 16 2024 pjakobsson@suse.de
- Documentation/gpu: Add a VM_BIND async document (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 145a148
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panel: st7703: Add Powkiddy RGB30 Panel Support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f720192
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/rockchip: remove NR_LAYERS macro on vop2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fa2bbbe
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: synopsys: dw-mipi-dsi: Disable HSTX and LPRX timeout (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 733e375
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: synopsys: dw-mipi-dsi: Set minimum lane byte clock cycles (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 18e2c06
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: synopsys: dw-mipi-dsi: Use pixel clock rate to calculate (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 77298e3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: synopsys: dw-mipi-dsi: Add mode fixup support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2b331ba
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: synopsys: dw-mipi-dsi: Force input bus flags (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 278dc9d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: synopsys: dw-mipi-dsi: Add input bus format negotiation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7ade4c9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: synopsys: dw-mipi-dsi: Add dw_mipi_dsi_get_bridge() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bb6c19f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: adv7511: Add hpd_override_enable variable to struct (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5c67239
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: adv7511: Add link_config variable to struct adv7511_chip_info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fff0272
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: adv7511: Add has_dsi variable to struct adv7511_chip_info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 00732d3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: adv7511: Add reg_cec_offset variable to struct adv7511_chip_info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0b36b6d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: adv7511: Add supply_names and num_supplies variables to struct (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 82c3682
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: adv7511: Add max_lane_freq_khz variable to struct (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8388c0b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: adv7511: Add max_mode_clock_khz variable to struct (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a219cab
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: adv7511: Add struct adv7511_chip_info and use (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b1a9900
* Fri Feb 16 2024 pjakobsson@suse.de
- i2c: Add i2c_get_match_data() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2867b3c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panel: st7703: Fix timings when entering/exiting sleep (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit afaf792
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ssd130x: Fix atomic_check for disabled planes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 55d3bbf
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: megachips-stdpxxxx-ge-b850v3-fw: switch to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8ace989
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix stack size issue on DML2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0b87651
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Reduce stack size by splitting function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0371624
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdkfd: remap unaligned svm ranges that have split (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dc06f24
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Create version number for coredumps (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 51da4e7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Move coredump code to amdgpu_reset file (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4051528
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Encapsulate all device reset info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c68e09a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: support the port num info based on the capability flag (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f8e1b14
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: prepare the output buffer for GET_PEER_LINKS command (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 57e54db
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: drop status query/reset for GCEA 9.4.3 and MMEA 1.8 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9c912bc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: update the xgmi ta interface header (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8453818
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add set/get mca debug mode operations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit db341f0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: replace reset_error_count with (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b5fa5d4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add clockgating support for NBIO v7.7.1 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 927066f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: fix missing stuff in NBIO v7.11 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d1d7d72
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Enable RAS feature by default for APU (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a204bd6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: fix typo for amdgpu ras error data print (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 955d82d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/amdgpu/vcn: Add RB decouple feature under SRIOV - P4 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 439ddb1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/amdgpu/vcn: Add RB decouple feature under SRIOV - P3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a26b24b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/amdgpu/vcn: Add RB decouple feature under SRIOV - P2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 321544b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/amdgpu/vcn: Add RB decouple feature under SRIOV - P1 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4df53ec
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Fix delete nodes that have been relesed (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cdf535f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Enable mca debug mode mode when ras enabled (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ff35ab1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Add UVD_VCPU_INT_EN2 to dpg sram (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit caa018c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Respect CONFIG_FRAME_WARN=0 in DML2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 17ace02
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: clean up some inconsistent indenting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6e21eaf
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Simplify bool conversion (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 12b96ec
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Remove unneeded semicolon (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 91b4de4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Remove duplicated include in dce110_hwseq.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 65f6f7a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: clean up some inconsistent indentings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d548ffa
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Enable software RAS in vcn v4_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 67e93fb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: define ras_reset_error_count function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3140167
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdkfd:remove unused code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1b0d524
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Support for getting power1_cap_min value (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4213bd7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Log UE corrected by replay as correctable error (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a3117a6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Workaround to skip kiq ring test during ras gpu recovery (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0b4a922
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix a handful of spelling mistakes in dml_print (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3725b5b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdkfd: clean up some inconsistent indenting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3489484
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Remove brackets in macro to conform to coding style (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 983878b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Read IMU FW version from scratch register during hw_init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aea7a59
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Don't parse IMU ucode version if it won't be loaded (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 344527c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Move microcode init step to early_init() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a8beac0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Add missing kernel doc for prepare_suspend() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 555697f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: update to the latest GC 11.5 headers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1229d12
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/mes11: remove aggregated doorbell code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 720720d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu : Add hive ras recovery check (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/drm-amdgpu-revert-Adjust-removal-control-flow-for-sm.patch.
- commit 813e00b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add missing lines of code in dc.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 63a8020
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/umsch: add suspend and resume callback (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a1759d3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/pm: update SMU 13.0.0 PMFW version check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8c824cd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/a7xx: actually use a7xx state registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2b03fd6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: enable writeback on SM8550 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8b74433
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: sm8550: remove unused VIG and DMA clock controls entries (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 04877d5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: move setup_force_clk_ctrl handling into plane and wb (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 36b488c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: add setup_clk_force_ctrl() op to sspp & wb (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c7393e4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: create a dpu_hw_clk_force_ctrl() helper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 06b785a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/a6xx: Fix up QMP handling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c2ac654
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dp: use correct lifetime device for devm_drm_bridge_add (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 78ad53c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/hdmi: use correct lifetime device for devm_drm_bridge_add (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 93ed4dc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dsi: use correct lifetime device for devm_drm_bridge_add (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c0bcee1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm: fix fault injection support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bc57c89
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm: carve out KMS code from msm_drv.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 40e178e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm: make fb debugfs file available only in KMS case (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bdd0e70
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm: only register 'kms' debug file if KMS is used (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b3f2ba1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm: switch to drmm_mode_config_init() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dd85b2d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm: rename msm_drv_shutdown() to msm_kms_shutdown() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 79253e5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm: remove shutdown callback from msm_platform_driver (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 985c23b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm: rename msm_pm_prepare/complete to note the KMS nature (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2bf0c57
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm: drop pm ops from the headless msm driver (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 693750f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm: remove msm_drm_private::bridges field (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit be5c5fa
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dp: switch to devm_drm_bridge_add() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f64ce18
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dp: move pdev from struct dp_display_private to struct msm_dp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b653a7b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/hdmi: switch to devm_drm_bridge_add() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit df56700
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dsi: switch to devm_drm_bridge_add() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 022b958
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/mdp5: move resource allocation to the _probe function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5ab138d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/mdp4: move resource allocation to the _probe function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a5622e5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: move resource allocation to the _probe function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5b98e03
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm: allow passing struct msm_kms to msm_drv_probe() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 963e621
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/adreno: Add A635 speedbin 0xac (A643) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 68e8291
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/adreno: Add ZAP firmware name to A635 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8b87e4b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/a6xx: Poll for GBIF unhalt status in hw_init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1995af6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/a6xx: Add A740 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9328a8c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/a6xx: Add A730 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 53349fd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/a6xx: Mostly implement A7xx gpu_state (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3566b82
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/a6xx: Send ACD state to QMP at GMU resume (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 21e2338
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/a6xx: Add skeleton A7xx support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ae8cedf
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/a6xx: Add missing regs for A7XX (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1f02a2c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dp: support setting the DP subconnector type (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 91c1ea2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dp: Remove error message when downstream port not connected (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1e4d4db
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dp: Inline dp_display_is_sink_count_zero() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9eb4a15
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: move INTF tearing checks to dpu_encoder_phys_cmd_init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3453c07
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: drop useless check from (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 94d99df
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: drop DPU_INTF_TE feature flag (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7358973
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: enable INTF TE operations only when supported by HW (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c4828fc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: inline _setup_intf_ops() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3b35eea
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: drop the DPU_PINGPONG_TE flag (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 16de872
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: enable PINGPONG TE operations only when supported by HW (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 295c7ff
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: inline _setup_pingpong_ops() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d8afa98
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dp: Remove dp_display_is_ds_bridge() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e52828a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dp: Inline dp_link_parse_sink_count() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1498681
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dp: Simplify with drm_dp_{max_link_rate, max_lane_count}() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit de38c2f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dp: Remove aux_cfg_update_done and related code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bcfa4d4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dp: Remove dead code related to downstream cap info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f9923c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dp: Use drm_dp_read_sink_count() helper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4c7f211
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dp: Replace open-coded drm_dp_read_dpcd_caps() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4aecb68
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dsi: Enable widebus for DSI (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 251ffc6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dsi: Add DATABUS_WIDEN MDP_CTRL2 bit (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4e535ad
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: Enable widebus for DSI INTF (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7ebb93d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: Move setting of dpu_enc::wide_bus_en to atomic enable() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 284af1b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm: Remove unnecessary NULL values (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ddc2f1e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: shift IRQ indices by 1 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a9ae3bb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: stop using raw IRQ indices in the kernel traces (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 33fd989
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: stop using raw IRQ indices in the kernel output (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a162f76
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: make the irq table size static (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dec0ef6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: add helper to get IRQ-related data (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 71e6005
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: extract dpu_core_irq_is_valid() helper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 69dc65b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: remove irq_idx argument from IRQ callbacks (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a90b971
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: aal: Compress of_device_id entries and add sentinel (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9496ffe
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: gamma: Add kerneldoc for struct mtk_disp_gamma (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 71df03e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: aal: Add kerneldoc for struct mtk_disp_aal (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 85f7d6e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: gamma: Program gamma LUT type for descending or rising (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 46ec84f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: gamma: Make sure relay mode is disabled (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 87431e5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: gamma: Add support for MT8195 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e8a4390
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: gamma: Add support for 12-bit LUT (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0f8ca48
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: gamma: Support multi-bank gamma LUT (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 862655d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: De-commonize disp_aal/disp_gamma gamma_set functions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 33bd930
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: aal: Use bitfield macros (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aed2727
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: gamma: Use bitfield macros (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 79c0b3c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: gamma: Enable the Gamma LUT table only after (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 490ab52
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: gamma: Improve and simplify HW LUT calculation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 767a4a7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: gamma: Support SoC specific LUT size (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d592935
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: gamma: Reduce indentation in mtk_gamma_set_common() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8cd76ea
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: gamma: Adjust mtk_drm_gamma_set_common parameters (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ae1a883
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: Support dynamic selection of MT8188 VDOSYS0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d4a9358
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: dsi: Support dynamic connector selection (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 56c807f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: dpi: Support dynamic connector selection (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e8edf2c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: Add connector dynamic selection capability (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 508368c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: Add encoder_index interface for mtk_ddp_comp_funcs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d25444e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: dsi: Add mode_valid callback to DSI bridge (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 31d1763
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: dp: Add support MT8188 dp/edp function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 03b83dd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: dp: Add the audio divider to mtk_dp_data struct (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cb570e9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: dp: Add the audio packet flag to mtk_dp_data struct (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 60d9188
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: Add mt8188 dsi compatible to mtk_dsi.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 43f0347
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mediatek: dsi: Add dsi cmdq_ctl to send panel initial code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e7d23b5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/mtl: Don't set PIPE_CONTROL_FLUSH_L3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 58650a1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Prevent potential null-ptr-deref in engine_init_common (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2c37a30
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Enable GuC TLB invalidations for MTL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 42deddb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/gt: Increase sleep in gt_tlb selftest sanitycheck (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0b57ee4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: No TLB invalidation on wedged GT (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1eb7b28
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: No TLB invalidation on suspended GT (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 19d80a2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Define and use GuC and CTB TLB invalidation
  routines (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/drm-i915-Flush-WC-GGTT-only-on-required-platforms.patch.
- commit e4446a6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/guc: Add CT size delay helper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ee9b832
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Add GuC TLB Invalidation device info flags (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 996f028
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/pxp: Clean up zero initializers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 83f2656
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/guc: Clean up zero initializers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e1752d0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/mtl: Remove the 'force_probe' requirement for Meteor Lake (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 jsc#PED-6113 jsc#PED-6124 jsc#PED-6037 jsc#PED-6008 jsc#PED-6007 jsc#PED-6105)
- commit f4f6528
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/pci: Clean up zero initializers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0aceffc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/hdcp: Clean up zero initializers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7d5480f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: Clean up zero initializers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1351103
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Remove unused DSC caps from intel_dp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e779542
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Use connector DSC DPCD in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 71cfa1d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Use connector DSC DPCD in intel_dp_dsc_compute_config() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8370287
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Use connector DSC DPCD in intel_dp_mode_valid() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8393516
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Use connector DSC DPCD in intel_dp_dsc_get_slice_count() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8ec04ed
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Use connector DSC DPCD in intel_dp_dsc_supports_format() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d87a544
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Use connector DSC DPCD in intel_dp_dsc_compute_params() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0d1cf43
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Pass only the required DSC DPCD to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f8e438b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Pass only the required i915 to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 73d51ed
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Pass connector DSC DPCD to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f42c609
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Use connector DSC DPCD in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 14d3426
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Use connector DSC DPCD in intel_dp_supports_dsc() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b61cc04
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Use connector DSC DPCD in intel_dp_supports_fec() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit de3df3a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Use connector DSC DPCD in intel_dp_dsc_compute_max_bpp() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9301bf0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Use connector DSC DPCD in i915_dsc_fec_support_show() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 159b2d9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Use i915/intel connector local variables in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1075b0d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Set connector DSC capabilities and decompression AUX (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 360e8aa
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Store DSC DPCD capabilities in the connector (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 19b3c2a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Sanitize DPCD revision check in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 62bac33
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsb: Re-instate DSB for LUT updates (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bdc478b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsb: Correct DSB command buffer cache coherency settings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8f475ef
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsb: Allocate command buffer from local memory (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e9bfb7a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/lnl: Remove watchdog timers for PSR (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/drm-i915-psr-Only-allow-PSR-in-LPSP-mode-on-HSW-non-.patch.
- commit 56718db
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Add new DG2 PCI IDs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7c487b5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/swsmu: update smu v14_0_0 header files and metrics table (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1a47d93
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add RAS error info support for umc_v12_0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 88724fd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add RAS error info support for mmhub_v1_8 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 93f51db
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add RAS error info support for gfx_v9_4_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b4bf4ce
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add RAS error info support for sdma_v4_4_2. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7594c2f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add ras_err_info to identify RAS error source
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/drm-amdgpu-Do-not-issue-gpu-reset-from-nbio-v7_9-bif.patch.
- commit 5d58bd0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: flush the correct vmid tlb for specific pasid (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7958829
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: make err_data structure built-in for ras_manager (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b7bee8b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: disable GFXOFF and PG during compute for GFX9 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f602552
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/umsch: fix missing stuff during rebase (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 628a52c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/umsch: correct IP version format (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit edbebb2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: don't use legacy invalidation on MMHUB v3.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit db699e8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: correct NBIO v7.11 programing (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e286fca
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Correctly use bo_va->ref_count in compute VMs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6c4d1e2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Add P2S tables for SMU v13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a1c8b47
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Add support to load P2S tables (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f4dbd26
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Update PSP interface header (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b04ed91
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Avoid FRU EEPROM access on APU (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9a6a6b4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: save VCN instances init info before jpeg init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 816f72c
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Skip entire amdgpu_dm build if (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 23ccb13
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Create one virtual connector in DC" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 17b5ef5
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Disable virtual links" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5858702
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Initialize writeback connector" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 76e418c
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Skip writeback connector when we get (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 305cd28
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Return drm_connector from (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 275654a
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Use drm_connector in create_stream_for_sink" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 61a274e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: drop most smu_cmn_get_smc_version in smu (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c87a595
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Add reset option for fan_ctrl on smu 13.0.7 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 039a85f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Add reset option for fan_ctrl interfaces (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 58518d5
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Create amdgpu_dm_wb_connector" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 069b792
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Create fake sink and stream for writeback (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7dd37eb
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Hande writeback request from userspace" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8acc920
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Add writeback enable/disable in dc" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 64dae81
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Fix writeback_info never got updated" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a93275
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Validate hw_points_num before using it" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1188701
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Fix writeback_info is not removed" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 192b0c0
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Add writeback enable field (wb_enabled)" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2bae018
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Setup for mmhubbub3_warmup_mcif with big (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f0b5192
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Add new set_fc_enable to struct dwbc_funcs" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c5f33bc
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Disable DWB frame capture to emulate (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 30823fb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Revert "drm/amd/display: Use drm_connector in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6b9168d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Expose ras version & schema info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f97ca72
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Read PSPv13 OS version from register (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f8e2e74
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: add missing NULL check for DML2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6e8094f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/umsch: enable doorbell for umsch (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2d58e4d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: make dc_set_power_state() return type `void` again (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0824918
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Destroy DC context while keeping DML and DML2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9258c51
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Catch errors from drm_atomic_helper_suspend() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 37a994c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Split up UVD suspend into prepare and suspend steps (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f9fc31a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Add concept of running prepare_suspend() sequence for IP (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5cec749
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Evict resources during PM ops prepare() callback (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fa1b0ba
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: enable GFX IP v11.5.0 CG and PG support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 446782b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add support to power up/down UMSCH by SMU (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7da10d9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add power up/down UMSCH ppt callback (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c16e13b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add support to powerup VPE by SMU (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 93889f2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/discovery: add SMU 14 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9041b19
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/swsmu: add smu14 ip support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 99771e4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/swsmu: add smu v14_0_0 pmfw if file (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dd6c6b5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/swsmu: add smu v14_0_0 ppsmc file (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 79187c1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/swsmu: add smu v14_0_0 driver if file (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3a5fbeb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/umsch: power on/off UMSCH by DLDO (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c4580d3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/umsch: fix psp frontdoor loading (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 12dbe53
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Increase IP discovery region size (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bd8199b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Use gpu_metrics_v1_4 for SMUv13.0.6 (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/drm-amd-pm-Fix-a-memory-leak-on-an-error-path.patch.
- commit d1f7bde
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Add gpu_metrics_v1_4 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4110a79
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Update metric table for smu v13_0_6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b33835e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Return -EINVAL when MMSCH init status incorrect (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 32e5d3b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: wait for completion of the EnableGfxImu command (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 091cdf6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/vpe: fix insert_nop ops (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a4d4b8b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Address member 'gart_placement' not described in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0138257
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/vpe: align with mcbp changes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bdfa034
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/vpe: remove IB end boundary requirement (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1ba20ba
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Improve MES responsiveness during oversubscription (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e05d384
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/discovery: enable DCN 3.5.0 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3e15261
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.255 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2470123
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Disable virtual links (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 842ca6c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Disable SubVP if test pattern is enabled (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f33fd37
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Refactor DPG test pattern logic for ODM cases (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8d1be25
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Don't set dpms_off for seamless boot (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2c3f610
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Refactor HWSS into component folder (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3461e9a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Revert "drm/amd/display: Add a check for idle power (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 18bfd27
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add hub->ctx_distance in setup_vmid_config (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3a0a854
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update cursor limits based on SW cursor fallback (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2232063
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update dml ssb from pmfw clock table (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4e1e813
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update stream mask (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c171862
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Revert "drm/amd/display: remove duplicated edp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 036f44f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Modify Vmin default value (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 197bc1a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update pmfw_driver_if new structure (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f3ad633
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: VSIF v3 set Max Refresh Rate (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2a01d41
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Modify SMU message logs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5f8c47c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: enable S/G display for for recent APUs by default (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2186883
* Fri Feb 16 2024 pjakobsson@suse.de
- Documentation/amdgpu: Add FRU attribute details (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b96aaff
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Add more FRU field information (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bc0e69c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Refactor FRU product information (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6c8a81f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: enable FRU device for SMU v13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e63b695
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: update ib start and size alignment (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 16aedec
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: add check in validate_only in dml2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0b67913
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Port replay vblank logic to DML2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 433819d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Modify Pipe Selection for Policy for ODM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5104213
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: correct dml2 input and dlg_refclk (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b0e5032
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix Chroma Surface height/width initialization (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2531f32
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Move stereo timing check to helper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3ec9c52
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Split pipe for stereo timings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c0e10ef
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Use fixed DET Buffer Size (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8be7909
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Handle multiple streams sourcing same surface (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 615772f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add z8_marks in dml (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3ffd3bf
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 DML2 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 08a99b8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Introduce DML2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cb532bb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Move dml code under CONFIG_DRM_AMD_DC_FP guard (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 846dda3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Move bw_fixed from DML folder (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0fbbc5c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Move custom_float from DML folder (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8ed5b03
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Move dce_calcs from DML folder (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 45fe3e9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Enable SMU 13.0.0 optimizations when ROCm is active (v2) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9f32cfc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Move the memory allocation out of (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0979c39
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Move the memory allocation out of (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e32f467
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add a warning if the FPU is used outside from task (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4175398
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/radeon: Fix UBSAN array-index-out-of-bounds for Radeon HD 5430 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cd53ea5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Annotate struct amdgpu_bo_list with __counted_by (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 09866e6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Drop unnecessary return statements (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 746054c
* Fri Feb 16 2024 pjakobsson@suse.de
- Documentation/amdgpu: Add board info details (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 69160f0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Add sysfs attribute to get board info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5a5d8d6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Get package types for smuio v13.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 23d6545
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Add more smuio v13.0.3 package types (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ba433f6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: fix ip count query for xcp partitions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2bf8924
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Remove set df cstate for SMUv13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e39de3d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Move package type enum to amdgpu_smuio (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ce01a29
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Fix complex macros error (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3c20e9a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdkfd: Use partial migrations in GPU page faults (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5eb6f61
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Simplify the per-CPU usage. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4b006c5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Remove migrate_en/dis from dc_fpu_begin(). (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cc4c1d8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: amdgpu_drm.h: fix comment typos (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3c99939
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: refine fault cache updates (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 61687fb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add new INFO ioctl query for the last GPU page fault (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e4008cd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Add GC v9.4.3 thermal limits to hwmon (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8ec0f1d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Add throttle limit for SMU v13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 27eec56
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.254 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dd1b787
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Adjust code style for hw_sequencer.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d4d77f2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Adjust code style for dmub_cmd.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fdc009a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update DMUB cmd header (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f1681a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add a check for idle power optimization (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6f92140
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Clean up code warnings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8871a50
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Make driver backwards-compatible with non-IPS PMFW (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 25e73e6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: remove duplicated edp relink to fastboot (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 96b0881
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: enable dsc_clk even if dsc_pg disabled
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/drm-amd-display-Fix-tiled-display-misalignment.patch.
- commit f193ba3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdkfd: Fix EXT_COHERENT memory allocation crash (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0e40c63
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: ratelimited override pte flags messages (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7c8529d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Drop all hand-built MIN and MAX macros in the amdgpu base (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 57a7917
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: cache gpuvm fault information for gmc7+ (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 96bc4fd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add cached GPU fault structure to vm struct (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 52cc32a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Use ttm_pages_limit to override vram reporting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 02aa7c0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Rework KFD memory max limits (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9be29d5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/gmc11: set gart placement GC11 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fb600ec
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/gmc: add a way to force a particular placement for GART (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 13fbb99
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: fix problems in power_helper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ddb2f05
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: correct gpu clock counter query on cyan skilfish (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d524c0e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Disable DWB frame capture to emulate oneshot (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f21b648
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add new set_fc_enable to struct dwbc_funcs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 73ccf4e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Setup for mmhubbub3_warmup_mcif with big buffer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 824dc58
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add writeback enable field (wb_enabled) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fd0a727
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix writeback_info is not removed (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e941a01
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Validate hw_points_num before using it (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8f19049
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix writeback_info never got updated (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0d2fbb1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add writeback enable/disable in dc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b9d213e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Hande writeback request from userspace (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3a304d4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Create fake sink and stream for writeback connector (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 73700bd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Create amdgpu_dm_wb_connector (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e4d367d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Use drm_connector in create_validate_stream_for_sink (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 96565ae
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Address 'srf_updates' not described in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f0f5d63
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: delete dead code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 876ea1d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Use drm_connector in create_stream_for_sink (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 05ec245
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdkfd: drop struct kfd_cu_info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7564e5d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Return drm_connector from (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6dca2ee
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdkfd: reduce stack size in kfd_topology_add_device() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 48a4e03
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Skip writeback connector when we get (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 07ac420
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: exit directly if gpu reset fails (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fdb86e6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Disallow managing power profiles on SRIOV for gc11.0.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e75c850
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Initialize writeback connector (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eb5a26e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Move microcode init from sw_init to early_init for CIK SDMA (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ba7de43
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Move microcode init from sw_init to early_init for SDMA v2.4 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d0b0ab0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Move microcode init from sw_init to early_init for SDMA v3.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d4e9266
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Move microcode init from sw_init to early_init for SDMA v5.2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 01228c3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Move microcode init from sw_init to early_init for SDMA v6.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 89671c7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Move microcode init from sw_init to early_init for SDMA v5.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c74d856
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Create one virtual connector in DC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ec10a40
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Drop error message about failing to load SDMA firmware (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 98402d9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: fix the print_clk_levels issue for SMU v13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1f6e154
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: deprecate allow_xgmi_power_down interface (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 30bb64d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: integrate plpd allow/disallow into (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cdc22c8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: init plpd_mode properly for different asics (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bc8cf4d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Remove unused DPCD declarations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d168780
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Skip entire amdgpu_dm build if !CONFIG_DRM_AMD_DC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3ac2aab
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Limit seamless boot by default to APUs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 91de247
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Drop error message about failing to load DMUB firmware (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cbf61ea
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: add xgmi_plpd_policy sysfs node for user to change plpd (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d2c8391
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: add xgmi plpd mode selecting interface for smu v13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 080bb30
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: add plpd_mode in smu_context to indicate current mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c6bf80b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: update pmfw headers for version 85.73.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d1be987
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Add description for AMD_IP_BLOCK_TYPE_VPE (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit be6e866
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Change dc_set_power_state() to bool instead of int (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0bb1a03
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/gmc11: disable AGP on GC 11.5 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 619eb0e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Propagate failures in dc_set_power_state() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0393b45
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: set stream gamut remap matrix to MPC for DCN3+ (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 207deb3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/gmc: set a default disable value for AGP
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/drm-amdgpu-apply-the-RV2-system-aperture-fix-to-RN-C.patch.
- commit 0fb46f4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/gmc6-8: properly disable the AGP aperture (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d838bf7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu:Expose physical id of device in XGMI hive (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 993b965
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Break after finding supported vlevel for repopulate (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 35b0881
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update OPP counter from new interface (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit df281de
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: augment display clock in dc_cap structure (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4e6d7f3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.253 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f4e5421
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: fix incorrect odm change detection logic (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c176add
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: add primary pipe check when building slice table for (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8d7626b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: add get primary dpp pipe resource interface (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ad9a2f1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: add missing function pointer for DCN321 resource (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bde1371
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Rename DisableMinDispClkODM in dc_config (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c2677c9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/vpe: fix truncation warnings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3ef7d29
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Improve code style on bios_parser2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9583f74
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Remove unwanted drm edid references (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 60f11f0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: switch DC over to the new DRM logging macros (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f8a263
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: skip audio config for virtual signal (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8eccc1c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Add reset option for fan_curve on smu13_0_0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit df70e9e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: block MPO if it prevents pstate support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f89e66d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix DP2.0 timing sync (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 763ee0d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Improve x86 and dmub ips handshake (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c8a8d7a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: remove guaranteed viewports limitation for odm (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 297657d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: add new windowed mpo odm minimal transition sequence (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c30f58c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: reset stream slice count for new ODM policy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5f2acc4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: determine fast update only before commit minimal (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ebb906f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: remove unused mmhub_reg_offsets (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c29a866
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdkfd: Move dma unmapping after TLB flush (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5e7d881
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: further move TLB hw workarounds a layer up (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b9076c1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: rework lock handling for flush_tlb v2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c6c3228
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: drop error return from flush_gpu_tlb_pasid (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2ac898c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: fix and cleanup gmc_v11_0_flush_gpu_tlb_pasid (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 27f81f2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: cleanup gmc_v10_0_flush_gpu_tlb_pasid (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 01955ec
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: fix and cleanup gmc_v9_0_flush_gpu_tlb_pasid (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6606653
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: fix and cleanup gmc_v8_0_flush_gpu_tlb_pasid (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f54092c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: fix and cleanup gmc_v7_0_flush_gpu_tlb_pasid (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a38b3ee
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: cleanup gmc_v11_0_flush_gpu_tlb (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c25f594
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: rework gmc_v10_0_flush_gpu_tlb v2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 74914d7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: change if condition for bad channel bitmap update (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ff1a8c7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: fix value of some UMC parameters for UMC v12 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7a0569a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: fix some style issues (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 54f76fb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdkfd: Don't use sw fault filter if retry cam enabled (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9fbc53f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: fix and cleanup gmc_v9_0_flush_gpu_tlb (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a6d11a
* Fri Feb 16 2024 pjakobsson@suse.de
- gpu: drm: amd: display: fix kernel-doc warnings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 188126b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Restore partition mode after reset (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1783689
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.252 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 54757db
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Drop unused link FPGA code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6f5d2d0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Enable DCN low mem power by default (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5ad9e63
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Expand DML to better support replay (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3f788b3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Use optc32 instead of optc30 in DC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5a69103
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Optimize OLED T7 delay (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9cd27d1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Add more fields to IP version (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1661623
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: print channel index for UMC bad page (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dedd311
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdkfd: Separate dma unmap and free of dma address array (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f53c63
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Remove SMUv13.0.6 unsupported feature (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e9c1e0e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Round Q10 format values in SMU v13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f54077d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: update IP count INFO query (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8d164e0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Fix false positive error log (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 679d690
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/jpeg: skip set pg for sriov (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d508fe4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.251 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7052087
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.183.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ddebb0e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix MST recognizes connected displays as one (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 597b5d4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: fix some non-initialized register mask and setting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0fbf956
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Enable replay for dcn35 (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/Revert-drm-amd-display-Enable-Replay-for-static-scre.patch.
- commit 37ba9ab
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add option to flip ODM optimization (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7ceb079
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: disable IPS (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7a377a9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add IPS control flag (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6051c7c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update driver and IPS interop (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9b1f806
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Correct z8 watermark mask (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit af2c1a9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: STREAM_MAPPER_CONTROL register offset on DCN35 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fa588ae
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update pipe resource interfaces for DCN35 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bb262b2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DPIA Link Encoder Assignment Fix for DCN35 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0d30379
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: fix static screen detection setting for DCN35 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e2614af
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add pointer check before function call (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0a1df85
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Enable DCLK_DS from driver by default (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9d028a7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 case for dc_clk_mgr_create (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3ce6dfa
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add z8_marks related in dml for DCN35 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ebc3959
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix dig register undefined (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 56ca6cc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Temporarily disable clock gating (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 44392f1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: disable clock gating logic (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c72ce86
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add reset for SYMCLKC_FE_SRC_SEL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0dcccc0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Rework coredump to use memory dynamically (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9c5f15a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Remove unused display_content_support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4cd3997
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Hook up 'content type' property for HDMI (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 20097dc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Fix vbios version string search (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a5c9d1b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: add smu_13_0_6 mca dump support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 46bbd36
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: update smu_v13_0_6 ppsmc header (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ec36b61
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Add EXT_COHERENT memory allocation flags (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 21eaee0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdkfd: fix add queue process context clear without runtime (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2ee5a04
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add amdgpu mca debug sysfs support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9d1ffa3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add VPE IP discovery info to HW IP info query (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 41c8eed
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add amdgpu smu mca dump feature support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a83360b
* Fri Feb 16 2024 pjakobsson@suse.de
- Documentation/amdgpu: Modify pp_dpm_*clk details (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6338d25
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Enable seamless boot by default on newer ASICs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3759c57
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Add a module parameter for seamless boot (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c8bf214
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Add HDP flush during jpeg init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 87c5d06
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Move seamless boot check out of display (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bf41589
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Drop special case for yellow carp without discovery (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 627f2f2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm:Fix GFX deep sleep clock reporting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 20d51dc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Fix clock reporting for SMUv13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d60958a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Use function for IP version check (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/Revert-drm-amd-display-Enable-Replay-for-static-scre.patch.
- Refresh
  patches.suse/drm-amdgpu-Add-NULL-checks-for-function-pointers.patch.
- Refresh patches.suse/drm-amdgpu-disable-MCBP-by-default.patch.
- Refresh
  patches.suse/drm-amdgpu-finalizing-mem_partitions-at-the-end-of-G.patch.
- Refresh
  patches.suse/drm-amdgpu-pm-Fix-the-power-source-flag-error.patch.
- Refresh
  patches.suse/drm-amdgpu-revert-Adjust-removal-control-flow-for-sm.patch.
- commit 86396b9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add remap_hdp_registers callback for nbio 7.11 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 86be0c4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add vcn_doorbell_range callback for nbio 7.11 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 474edca
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Create an option to disable soft recovery (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 309a121
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Merge debug module parameters (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8bb6a62
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: clean up some inconsistent indenting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d487d53
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: add skip_implict_edp_power_control flag for dcn32 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c1c5370
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: minior logging improvements (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7abb174
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: do not skip ODM minimal transition based on new (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a80fe7b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: move odm power optimization decision after subvp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8cfec03
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.250 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6dcbb92
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: fix some non-initialized register mask and setting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 10b0a1f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add check for vrr_active_fixed (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 056d5c6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: dc cleanup for tests (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ed6c706
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add type conversion for gc info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fcbfe8b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Drop unused registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b20c6b8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: add dp dto programming function to dccg (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 55c350a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: only allow ODM power optimization if surface is (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4c0bc3a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: do not attempt ODM power optimization if minimal (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e554d88
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: remove a function that does complex calculation in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c4434c7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCHUBBUB callback to report MALL status (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 92eed37
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add new logs for AutoDPMTest (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fd66169
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: support main link off before specific vertical line (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 34d9a21
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Rename KGD_MAX_QUEUES to AMDGPU_MAX_QUEUES (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f2e3ec5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: do not block ODM + OPM on one side of the screen (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0010750
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix DML calculation errors (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 99a789b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: print more address info of UMC bad page (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3c6a456
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.181.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 76eddf9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: set default return value for ODM Combine debugfs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eaa6709
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add channel index table for UMC v12 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 430e006
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: enable smu_v13_0_6 mca debug mode when UMC RAS feature is (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0eb431a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: update smu_v13_0_6 smu header (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f55b1c5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add address conversion for UMC v12 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4dbe595
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Use default reset method handler (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 263f0bd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Fix the flag setting code for interrupt request (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4366ea7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: fix unsigned error codes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 81bdba0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: clean up one inconsistent indenting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2041b62
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Add umc v12_0 ras functions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ff2da4c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Correct se_num and reg_inst for gfx v9_4_3 ras counters (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 443ea11
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Add only valid firmware version nodes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 22f863b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: fix incompatible types in conditional expression (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9bc5ec0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Use min_t to replace min (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cc748e0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Add umc v12_0_0 ip headers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c160f39
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Update amdgpu_device_indirect_r/wreg_ext (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c572c40
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Add RREG64_PCIE_EXT/WREG64_PCIE_EXT functions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 519ace0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Declare array with strings as pointers constant (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 57eec3d
* Fri Feb 16 2024 pjakobsson@suse.de
- amdgpu/pm: Optimize emit_clock_levels for aldebaran - part 3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d64fbc7
* Fri Feb 16 2024 pjakobsson@suse.de
- amdgpu/pm: Optimize emit_clock_levels for aldebaran - part 2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1da5b66
* Fri Feb 16 2024 pjakobsson@suse.de
- amdgpu/pm: Optimize emit_clock_levels for aldebaran - part 1 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 501e514
* Fri Feb 16 2024 pjakobsson@suse.de
- amdgpu/pm: Replace print_clock_levels with emit_clock_levels for (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3624177
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: clean up some inconsistent indentings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 666262b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: clean up some inconsistent indentings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0f01ab8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: clean up one inconsistent indenting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b5f34fb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: clean up one inconsistent indenting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aca0c46
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Remove duplicated include in dcn35_clk_mgr.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 77dee7c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Remove duplicated include in dcn35_hwseq.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 09f65f7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Remove duplicated include in dcn35_optc.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ce99f73
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Remove duplicated include in dcn35_resource.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cbe27f9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: clean up some inconsistent indenting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6882f96
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: calling address translation functions to simplify codes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ea3e5ab
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: only poweron/off vcn/jpeg when they are valid. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9aaa556
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/amd/pm: disable the SMU13 OD feature support
  temporarily" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068
  jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/drm-amd-pm-Fix-error-of-MACO-flag-setting-code.patch.
- commit a3f68e3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: add fan minimum pwm OD setting support for SMU13 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e3508f8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: add fan target temperature OD setting support for SMU13 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2221c15
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: add fan acoustic target OD setting support for SMU13 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 602c01c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: update SET_HW_RESOURCES definition for UMSCH (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2447e3c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add amdgpu_umsch_mm module parameter (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 373b85a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/discovery: enable UMSCH 4.0 in IP discovery (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e06576b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add PSP loading support for UMSCH (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 643ef86
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: reserve mmhub engine 3 for UMSCH FW (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 57b6a6a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add VPE queue submission test (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e22a9cc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add selftest framework for UMSCH (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d13cf85
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: enable UMSCH scheduling for VPE (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0764e6b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add initial support for UMSCH (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3fc2999
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add UMSCH 4.0 api definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 893d74e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add UMSCH firmware header definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f6e3eba
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add UMSCH RING TYPE definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c7e61ca
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: add fan acoustic limit OD setting support for SMU13 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1b1d9fc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: add fan temperature/pwm curve OD setting support for (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2229fc0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/jpeg: initialize number of jpeg ring (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 43069a0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: revise the device initialization sequences (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ec8786e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: introduce a new set of OD interfaces (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 19c14ef
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add UMSCH IP BLOCK TYPE definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9a1392d
* Fri Feb 16 2024 pjakobsson@suse.de
- amdgpu/pm: Optimize emit_clock_levels for arcturus - part 3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f9040a9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add UMSCH 4.0 register headers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f922c54
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: enable PG flags for VCN (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 58b36af
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/discovery: add VCN 4.0.5 Support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f70ef57
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/soc21: Add video cap query support for VCN_4_0_5 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e601309
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu:enable CG and PG flags for VCN (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e3b175a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add VCN_4_0_5 firmware support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 991d978
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/jpeg: add jpeg support for VCN4_0_5 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7c85466
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add VCN4 ip block support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 81082ff
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add vcn 4_0_5 header files (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit da9a616
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: fix VPE front door loading issue (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8c072b7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add VPE FW version query support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c61a1ac
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: enable VPE for VPE 6.1.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c0981e2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add user space CS support for VPE (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b8f17eb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add PSP loading support for VPE (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9c78f47
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add VPE 6.1.0 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f34e7b1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add nbio 7.11 callback for VPE (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8e49c0f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add nbio callback for VPE (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 96e8034
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add PSP FW TYPE for VPE (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0287cac
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add UCODE ID for VPE (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f882aa
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add support for VPE firmware name decoding (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a71c1a5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add doorbell index for VPE (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d050e8b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add irq src id definitions for VPE (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ec755c3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add IH CLIENT ID for VPE (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a50534
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add HWID for VPE (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bc66900
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add VPE firmware interface (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 823c36f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add VPE firmware header definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5862673
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add VPE HW IP BLOCK definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b25648e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add VPE IP BLOCK definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 061de72
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add VPE RING TYPE definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fac54c0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add VPE HW IP definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a248e6c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add VPE 6.1.0 header files (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c336640
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Fix printk_ratelimit() with DRM_ERROR_RATELIMITED in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e4a077d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Use READ_ONCE() when reading the values in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cd5c98c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: remove unused parameter in amdgpu_vmid_grab_idle (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ae1bbad
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdkfd: Replace pr_err with dev_err (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b51148b
* Fri Feb 16 2024 pjakobsson@suse.de
- amdgpu/pm: Optimize emit_clock_levels for arcturus - part 2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bc1c943
* Fri Feb 16 2024 pjakobsson@suse.de
- amdgpu/pm: Optimize emit_clock_levels for arcturus - part 1 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1b247d4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Adjust kdoc for 'optc35_set_odm_combine' (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 936122c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Simplify the bo size check funciton (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3489cf3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: access RLC_SPM_MC_CNTL through MMIO in SRIOV runtime (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 798ce35
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/amdgpu/sdma_v6_0: Demote a bunch of half-completed function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4fdcb15
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 DM Support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9c702d2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 CORE (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4866d89
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 blocks to Makefile (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c34f59f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 DML (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 592bb6f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 Resource (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2c372d5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5d4f248
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 DMUB (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit da4ec23
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 IRQ (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6633dc0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 CLK_MGR (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6e899ea
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 HWSEQ (jsc#PED-3527 jsc#PED-5475
  jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/drm-amd-display-add-seamless-pipe-topology-transitio.patch.
- commit d820baa
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 DSC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7381a01
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 MMHUBBUB (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e537b3b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 HUBBUB (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b8fc622
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 HUBP (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3c0fbdc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 DWB (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 947906e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 DPP (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f459e45
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 OPP (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a8f46e3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 OPTC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 30eaded
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 PG_CNTL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a52f9f8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 DIO (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e399c02
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 DCCG (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9999cb8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 GPIO (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 25a5d39
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 BIOS command table support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 581cf5d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update dc.h for DCN35 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 09719b6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update DCN32 for DCN35 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0d941e8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update DCN314 for DCN35 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 908fcea
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update DCN31 for DCN35 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 39aa980
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update DCN30 for DCN35 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ac258a2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update DCN20 for DCN35 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 33aaa04
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update DCN10 for DCN35 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c3869b0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Update DCE for DCN35 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 24fc6e3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN35 family information (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9cdb7c1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add dcn35 register header files (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit da50ca6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix up kdoc format for 'dc_set_edp_power' (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a54bf5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.249 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7b0f153
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: fix pipe topology logging error (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bea54bd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add debugfs interface for ODM combine info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4600c75
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: correct z8_watermark 16bit to 20bit mask (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5f92e00
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix incorrect comment (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 69de9a9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Skip dmub memory flush when not needed (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ef755e0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: add pipe topology update log (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 92d327c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: switch to new ODM policy for windowed MPO ODM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fab917e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: use new pipe allocation interface in dcn32 fpu (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 07cbdbc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: add more pipe resource interfaces (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b42fbe4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: add new resource interfaces to update odm mpc slice (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e71893e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: add new resource interface for acquiring sec opp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bc4d26f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: rename function to add otg master for stream (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7632fe4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: add comments to add plane functions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c5065fb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Add support for 1080p SubVP to reduce idle power (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0e05491
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add header files for MP 14.0.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a543031
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/amdgpu/imu_v11_0: Increase buffer size to ensure all possible (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e76513e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/amdgpu/amdgpu_sdma: Increase buffer size to account for all (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2ead3c0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/amdgpu/amdgpu_ras: Increase buffer size to account for all (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f08580a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/amdgpu/amdgpu_device: Provide suitable description for param (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 432187a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/radeon/radeon_ttm: Remove unused variable 'rbo' from (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9976a7c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd: Fix spelling mistake "throtting" -> "throttling" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7dee8d9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Use kvzalloc() to simplify code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 07bf1cf
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Remove amdgpu_bo_list_array_entry() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f9a9c98
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Remove a redundant sanity check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 07e1a8c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Explicitly add a flexible array at the end of 'struct (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7bf0ba2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Allow issue disable gfx ras cmd to firmware (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 20e2493
* Fri Feb 16 2024 pjakobsson@suse.de
- amdgpu/pm: Replace print_clock_levels with emit_clock_levels for (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fd9817c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: fulfill the support for SMU13 `pp_dpm_dcefclk` interface (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 00a9e5e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: correct SMU13 gfx voltage related OD settings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 972d80d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/pm: Remove the duplicate dpm status check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ae9312d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Vangogh: Get average_* from average field of (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4041c42
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Fixes incorrect type in 'amdgpu_hwmon_show_power_avg() & (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bb9f5b3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: fix error flow in sensor fetching (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dada6d1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Fix kcalloc over kzalloc in 'gmc_v9_0_init_mem_ranges' (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 47297cb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdkfd: Share the original BO for GTT mapping (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 245d104
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.248 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a863d5a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.180.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 667ac11
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: ensure FS is enabled before sending request to DMUB (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a9a94fa
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: add check for PMFW hard min request complete (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 92529a7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Save addr update in scratch before flip (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d473108
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add gfxhub 11.5.0 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ccdc704
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: enable gmc11 for GC 11.5.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0723143
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add mmhub 3.3.0 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4e024e6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add mmhub 3.3.0 headers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f43d7c2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/discovery: enable gfx11 for GC 11.5.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 23f85bc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/discovery: enable mes block for gc 11.5.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3c6ac21
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add mes firmware support for gc_11_5_0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c7868c5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add imu firmware support for gc_11_5_0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 09fae5e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdkfd: add KFD support for GC 11.5.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7ed27e5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add golden setting for gc_11_5_0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5cff005
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/gfx11: initialize gfx11.5.0 (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/drm-amdgpu-Force-order-between-a-read-and-write-to-t.patch.
- commit 2a2ab95
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/gmc11: initialize GMC for GC 11.5.0 memory support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9ff86e6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add gc headers for gc 11.5.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d58abbe
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/discovery: add nbio 7.11.0 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fdeecdf
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add nbio 7.11 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a9f42f1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add nbio 7.11 registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8097a0d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/discovery: enable soc21 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a950ca8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/soc21: add initial GC 11.5.0 soc21 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 762d470
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: add new AMDGPU_FAMILY definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d901781
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: use 6.1.0 register offset for HDP CLK_CNTL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bb58b51
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Write flip addr to scratch reg for subvp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 86ed573
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Enable runtime register offset init for DCN32 DMUB (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 730d323
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: PQ regamma end point (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b6c4dff
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: PQ tail accuracy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ca38551
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Expose mall capability (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2927d95
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix useless else if in display_mode_vba_util_32.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8c56864
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/radeon: Cleanup radeon/radeon_fence.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9fed39f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix unnecessary conversion to bool in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 60e7b11
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Keep reset handlers shared (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 724b5c4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/amdgpu: Use kmemdup to simplify kmalloc and memcpy logic (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0b33585
* Fri Feb 16 2024 pjakobsson@suse.de
- accel/habanalabs: change Greco to Gaudi2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 789f1db
* Fri Feb 16 2024 pjakobsson@suse.de
- accel/habanalabs: add tsc clock sampling to clock sync info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 215e434
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: More use of GT specific print helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 357e685
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/gt: More use of GT specific print helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5277695
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/guc: Enable WA 14018913170 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d4a171d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/guc: Annotate struct ct_incoming_msg with __counted_by (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7b2052c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/guc: Update 'recommended' version to 70.12.1 for (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 81a3841
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/guc: Suppress 'ignoring reset notification' message (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1879e80
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Clarify type evolution of uabi_node/uabi_engines
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/drm-i915-gsc-Mark-internal-GSC-engine-with-reserved-.patch.
- commit 3ea9fd5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Enable GGTT updates with binder in MTL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f9652a4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Toggle binder context ready status (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dcecb34
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Implement GGTT update method with MI_UPDATE_GTT (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b5b9e58
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Parameterize binder context creation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fc43d24
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Implement for_each_sgt_daddr_next (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 50d618b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Create a kernel context for GGTT updates (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5ff4527
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Lift runtime-pm acquire callbacks out of (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a5f4cb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/gem: Make i915_gem_shrinker multi-gt aware (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7154125
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/mtl: Skip MCR ops for ring fault register (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 924f3c6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Clean steer semaphore on resume (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a852354
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Introduce the intel_gt_resume_early() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9e7dfa7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Introduce intel_gt_mcr_lock_sanitize() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3b6af18
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsi: Add some debug logging to mipi_exec_i2c (v2) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0d7bb66
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/vlv_dsi: Add DMI quirk for backlight control issues on (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9e7be01
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/vlv_dsi: Add DMI quirk for wrong I2C bus and panel size on (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cfcb9fe
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/vlv_dsi: Add DMI quirk for wrong panel modeline in BIOS on (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e83d0f7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Remove the module parameter 'fastboot' (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 311aa21
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/hdcp: Move common message filling function to its own file (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d1c7d18
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/hdcp: Move checks for gsc health status (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dc2e11d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: Use correct method to free crtc_state (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b36d59f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: Use intel_crtc_destroy_state instead kfree (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6b768a5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: enable W=1 warnings by default (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5626a4d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: drop -Wall and related disables from cflags as redundant (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fb3c5bb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/gvt: move structs intel_gvt_irq_info and intel_gvt_irq_map (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5416ae8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/gvt: move struct engine_mmio to mmio_context.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5b364fd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/gvt: don't include gvt.h from intel_gvt_mmio_table.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d47f68c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/gvt: remove unused to_gvt() and reduce includes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4acaeac
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: update the scaler feature capability (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cc09513
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: update the dsc feature capability (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit afd28df
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: display capability register definitions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6d1b64f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Add wrapper for getting display step (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 90007bd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: Free crtc_state in verify_crtc_state (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 38f59de
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Fix VLV color state readout (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d3ce1a6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/uapi: fix doc typos (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit caf99db
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/ddi: Remove redundant intel_connector NULL check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 684045f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: s/dev_priv/i915/ in the state checker (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 212ff61
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: s/pipe_config/crtc_state/ in the state checker (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f6a0fad
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Simplify the state checker calling convetions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ff0a710
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Constify remainder of the state checker (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5784d73
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Simplify snps/c10x DPLL state checker calling convetion (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2e0fe2f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Constify the snps/c10x PLL state checkers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f1c91a2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Simplify watermark state checker calling convention (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9acbc0e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Constify watermark state checker (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7446df3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Simplify DPLL state checker calling convention (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7b5f2ad
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Constify the crtc states in the DPLL checker (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 818c3e6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Stop clobbering old crtc state during state check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c5b25ce
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/psr: Unify PSR pre/post plane update hooks (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5d3604f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/fbc: Remove pointless "stride is multiple of 64 bytes" check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9788566
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/fbc: Split plane pixel format checks per-platform (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b1b5214
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/fbc: Split plane rotation checks per-platform (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 33b648b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/fbc: Split plane tiling checks per-platform (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0cb5e95
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/fbc: Split plane stride checks per-platform (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a7edc65
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/fbc: Remove ancient 16k plane stride limit (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f9a3344
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/pmu: Use local64_try_cmpxchg in i915_pmu_event_read (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0e870ed
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: Created exclusive version of vga decode setup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 38e38f6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Make sure pbn_div is up-to-date after sink reconnect (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6cc0e78
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display/lspcon: Increase LSPCON mode settle timeout (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 751cb3f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/gt: remove i915->gt0 in favour of i915->gt[0] (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a97a051
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: allocate i915->gt0 dynamically (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 881045b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/mocs: use to_gt() instead of direct &i915->gt (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 14c5ad7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: s/dev_priv/i915/ in the shared_dpll code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 81d03de
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Introduce for_each_shared_dpll() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1c681eb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Decouple I915_NUM_PLLS from PLL IDs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 17c9be0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Stop requiring PLL index == PLL ID (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4c2aed2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: separate subplatform init and runtime feature init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 139b4c6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: separate display runtime info init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e7ad902
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: move display info related macros to display (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0198495
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: convert INTEL_DISPLAY_ENABLED() into a function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 661e0a6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/lnl: update the supported plane formats with FBC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 06a680a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/lnl: possibility to enable FBC on first three planes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 19b1661
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Abstract display info away during probe (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 94c80c5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: Include i915_active header in frontbuffer tracking (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e9a8da8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: add I915 conditional build to vlv_dsi_pll.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8419ce6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: add I915 conditional build to intel_tv.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4bc1860
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: add I915 conditional build to intel_sdvo.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4141346
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: add I915 conditional build to intel_dvo.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 38fe40f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: add I915 conditional build to g4x_hdmi.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 577bf74
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: add I915 conditional build to i9xx_wm.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 65c6c9e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: add I915 conditional build to vlv_dsi.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 30242af
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: add I915 conditional build to intel_crt.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d287f13
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: add I915 conditional build to intel_dpio_phy.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2f1850e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: add I915 conditional build to g4x_dp.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 38c6a50
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: add I915 conditional build to intel_overlay.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 076a85b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: add I915 conditional build to intel_sprite.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6437e3f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: add I915 conditional build to intel_pch_display.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 00a5d6a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: add I915 conditional build to intel_pch_refclk.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7616ee7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: add I915 conditional build to intel_lpe_audio.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2697089
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: add I915 conditional build to i9xx_plane.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7ba94ba
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: add I915 conditional build to hsw_ips.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6893fae
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: add I915 conditional build to intel_lvds.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 89fe0ec
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: define I915 during i915 driver build (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 86e10aa
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/simpledrm: Fix power domain device link validity check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2871938
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: Replace drm_framebuffer plane size functions with its (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5f8909f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: Remove plane hsub/vsub alignment requirement for core helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0db5150
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/tegra: gem: Do not return NULL in tegra_bo_mmap() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2ce6e97
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/tegra: Zero-initialize iosys_map (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5e3d2dc
* Fri Feb 16 2024 pjakobsson@suse.de
- gpu: host1x: Syncpoint interrupt sharding (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b00706e
* Fri Feb 16 2024 pjakobsson@suse.de
- gpu: host1x: Enable system suspend callbacks (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a2df001
* Fri Feb 16 2024 pjakobsson@suse.de
- gpu: host1x: Stop CDMA before suspending (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0fced49
* Fri Feb 16 2024 pjakobsson@suse.de
- gpu: host1x: Add locking in channel allocation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 74f0f7d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/tegra: hub: Increase buffer size to ensure all possible values (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 46af161
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/tegra: Remove two unused function declarations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c756ab0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/tegra: Remove surplus else after return (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b50b741
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge_connector: implement oob_hotplug_event (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c71b878
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge_connector: stop filtering events in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3da6321
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Update DRIVER_DATE to 20230929 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0d3685b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Warn on if set frontbuffer return value is not NULL on (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 72a1fe2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/fdi: Recompute state for affected CRTCs on FDI links (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit de895c3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/fdi: Improve FDI BW sharing between pipe B and C (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e026cd1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Add helpers for BW management on shared display links (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8937098
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Factor out a helper to check/compute all the CRTC states (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0a4572c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Rename intel_modeset_all_pipes() to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a964eda
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Add helper to modeset a set of pipes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bb77164
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Limit the output link bpp in DSC mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3df7ad5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Update the link bpp limits for DSC mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d9784d8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Skip computing a non-DSC link config if DSC is needed (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f8776c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Track the pipe and link bpp limits separately (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4d1cef7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Factor out helpers to compute the link limits (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3824482
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsb: Use DEwake to combat PkgC latency (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 54d1a1c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Introduce intel_crtc_scanline_to_hw() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d0006d5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Introduce skl_watermark_max_latency() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2d64c3b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsb: Evade transcoder undelayed vblank when using DSB (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3b1ce29
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsb: Use non-posted register writes for legacy LUT (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 68c1743
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsb: Load LUTs using the DSB during vblank (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aec12e2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsb: Don't use DSB to load the LUTs during full modeset (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3540c35
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsb: Add support for non-posted DSB registers writes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6ee63c1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsb: Introduce intel_dsb_reg_write_masked() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f483679
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsb: Introduce intel_dsb_noop() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7e76cda
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsb: Define the contents of some intstructions bit better (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e0b7ba6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsb: Define more DSB bits (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4e47f1b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsb: Use non-locked register access (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d640a44
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/cx0: prefer forward declarations over includes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ba38894
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: refactor aux_ch_name() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 38b9880
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/irq: Clear GFX_MSTR_IRQ as part of IRQ reset (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a68543
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: Print display info inside driver display (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit da06446
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/bios: Fixup h/vsync_end instead of h/vtotal (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 970c0b1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/lnl: Start using CDCLK through PLL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b14b8fd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: Add DC state support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c14e5f6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: Add display power well (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4ffc817
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/lnl: Add CDCLK table (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b443ba1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/lnl: Add gmbus/ddc support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f30e49f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: Extend Wa_15010685871 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1cfcaa8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: Add support for HPD (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3e7a994
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: Enable odd size and panning for planar yuv (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 52b9e3e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: Read pin assignment from IOM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9628813
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: Handle port AUX interrupts (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c25a99f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: Re-order DP AUX regs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit acf5bff
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: Use _PICK_EVEN_2RANGES() in DP AUX regs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 490b35c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: Fix style and conventions for DP AUX regs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5f2c2de
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: Register DE_RRMR has been removed (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 76007b6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: Don't try to program PLANE_AUX_DIST (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c7b7cd3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: Treat cursor plane as regular plane for DDB (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 636e39a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: Add fake PCH (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c817bcd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Re-order if/else ladder in intel_detect_pch() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 70b794b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: Remove FBC capability from fused off pipes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4af8a75
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: FBC is now supported on all pipes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5771ff2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/lnl: Add display definitions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f7fe072
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/xelpdp: Add XE_LPDP_FEATURES (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 956048f
* Fri Feb 16 2024 pjakobsson@suse.de
- Revert "drm/i915/mst: Populate connector->ddc" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6e581e9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: add a note about fec_enable with 128b/132b (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f90ce98
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Implement transcoder LRR for TGL+ (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7650e0f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Assert that VRR is off during vblank evasion if necessary (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 506093f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Update VRR parameters in fastset (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 31295f2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Disable VRR during seamless M/N changes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f8e3d60
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Validate that the timings are within the VRR range (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3611352
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Relocate is_in_vrr_range() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 13280d7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Optimize out redundant M/N updates (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ec1a67b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Adjust seamless_m_n flag behaviour (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fb34e57
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Enable VRR later during fastsets (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eb47ab7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Extract intel_crtc_vblank_evade_scanlines() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 26aee2b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Change intel_pipe_update_{start,end}() calling convention (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 066f670
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Move psr unlock out from the pipe update critical section (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a23cff
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsi: let HW maintain CLK_POST (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 90a0739
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/cx0: Add step for programming msgbus timer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a974383
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Tune down error message during payload addition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 22796a7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Remove runtime suspended boolean from intel_runtime_pm (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3fecfe4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: move intel_display_device_probe() one level higher (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5bbf1c3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: call gmdid display probe at a higher level (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f57e7c8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: move more of the display probe to display code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 80d81a2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dpt: replace GEM_BUG_ON() with drm_WARN_ON() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 680ca08
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/fb: replace GEM_WARN_ON() with drm_WARN_ON() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6a230a3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/fbc: replace GEM_BUG_ON() to drm_WARN_ON() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 254bad3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/sdvo: Constify mapping structs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c4cbd1d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/hdmi: Remove old i2c symlink (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit db1aae0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/hdmi: Nuke hdmi->ddc_bus (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c66e53c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/hdmi: Use connector->ddc everwhere (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6d16f20
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/mst: Populate connector->ddc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 238daf9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Populate connector->ddc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 929f870
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dvo: Populate connector->ddc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ccb6e5e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/crt: Populate connector->ddc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cd36ec1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/lvds: Populate connector->ddc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b5129f7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Call the DDC bus i2c adapter "ddc" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c922bf5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/sysfs: Register "ddc" symlink later (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 250d382
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: Reorder drm_sysfs_connector_remove() vs. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit db36840
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsc: Fix pic_width readout (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 18cbeff
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Reduce combo PHY log spam (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f38b8d4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Stop spamming the logs with PLL state (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3ca5f2c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Split some long lines in hsw_fdi_link_train() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f0d3587
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Fix FEC pipe A vs. DDI A mixup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2f1ef4a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/mst: Read out FEC state (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 93f7df3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/gt: rename DBG() to GTT_TRACE() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 57d82c6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsc: use REG_BIT, REG_GENMASK, and friends for PPS0 and PPS1 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit baa8508
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsc: add the PPS number to the register content macros (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 243c744
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsc: clean up pps comments (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2646713
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsc: drop redundant = 0 assignments (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c9e486d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsc: rename pps write to intel_dsc_pps_write() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d671d98
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsc: have intel_dsc_pps_read() return the value (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 77c79c9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsc: have intel_dsc_pps_read_and_verify() return the value (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2b8c1f1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsc: improve clarity of the pps reg read/write helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 349f53d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: Apply workarounds during display init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8c8db0b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: Extract display workarounds from clock gating init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a5e6a47
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/adlp: Stop calling gen12lp_init_clock_gating() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a1f6659
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Stop forcing clock gating init for future platforms (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8e63482
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsb: Don't use indexed writes when byte enables are not all (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 61da366
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsb: Avoid corrupting the first register write (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8cf0e7f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dsb: Dump the DSB command buffer when DSB fails (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 85e87d2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Constify LUT entries in checker (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 399d50d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/cx0: Check and increase msgbus timeout threshold (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1d89f3e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: add trailing newlines to msgs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2910715
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/psr: Add psr sink error status into sink status debugfs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 88ab1e0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/tc: remove "fia" from intel_tc_port_fia_max_lane_count() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f1bf545
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/tc: move legacy code out of the main _max_lane_count() func (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 05fa473
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/tc: make intel_tc_port_get_lane_mask() static (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1e4ac1b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/tc: rename mtl_tc_port_get_pin_assignment_mask() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9263ecc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: Compare the readout dsc pps params (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 09f2b2f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/vdsc: Fill the intel_dsc_get_pps_config function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6692753
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/vdsc: Remove unused dsc registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8b62195
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/vdsc: Add function to write in PPS register (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b09e32a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/vdsc: Add function to read any PPS register (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5358ad9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/vdsc: Add func to get no. of vdsc instances per pipe (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1909e2b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/vdsc: Add a check for dsc split cases (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6358240
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/vdsc: Refactor dsc register field macro (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1a6e0de
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Handle dma fences in dirtyfb callback (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a990719
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Add new frontbuffer tracking interface to queue flush (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f433ccd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/psr: Clear frontbuffer busy bits on flip (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 47ca62b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/fbc: Clear frontbuffer busy bits on flip (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit adbbf12
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/cec: switch to setting physical address directly (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 017d38e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/cec: add drm_dp_cec_attach() as the non-edid version of set edid (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7d6227d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/edid: parse source physical address (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 67052bc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: use drm_edid_is_digital() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6aa2d28
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/edid: add drm_edid_is_digital() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8b4408e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/hdcp: Use correct aux for capability check scenario (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0170cf2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/hdcp: Use intel_connector as argument for hdcp_2_2_capable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a533d7d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: add minimal i915_gem_object_frontbuffer.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0b03e42
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/mtl: Add TC port lockdep assert to AUX power well enabling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bdd112f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Drop redundant AUX power get/put in intel_dp_force() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b57f2db
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dg2: Add support for new DG2-G12 revid 0x1 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 563fc2c
* Fri Feb 16 2024 pjakobsson@suse.de
- drivers/drm/i915: Honor limits->max_bpp while computing DSC max input (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fb93c20
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/display/dp: Assume 8 bpc support when DSC is supported (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7a5e76e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/psr: Apply Wa_14015648006 for all display 14 steppings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3378f8b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/sdvo: Print out the i2c pin and slave address (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4fa4922
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/sdvo: Rework DDC bus handling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b1926f5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/sdvo: Get rid of the per-connector i2c symlink (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b98acc7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/sdvo: Nuke the duplicate sdvo->port (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit baece1e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/sdvo: Initialize the encoder earlier (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 304a49e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/sdvo: Nuke attached_output tracking (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 21507e9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/hdcp: Adjust timeout for read in DPMST Scenario (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c3dd75d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/hdcp: Send the correct aux for DPMST HDCP scenario (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 04d5b07
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/hdcp: Propagate aux info in DP HDCP functions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1296104
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/hdcp: Use intel_connector argument in intel_hdcp_shim (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 17e49ed
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/color: move pre-SKL gamma and CSC enable read to intel_color (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9c879d0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/color: move SKL+ gamma and CSC enable read to intel_color (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5ec92fe
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: move ILK+ CSC mode read to intel_color (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 31a2dae
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: move HSW+ gamma mode read to intel_color (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 84a64a5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/color: move CHV CGM pipe mode read to intel_color (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c8cce95
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/regs: split out intel_color_regs.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bfb884e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: configure SDP split for DP-MST (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9b60660
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: update intel_dp_has_audio to support MST (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a6f10ff
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/vma: constify unbind_fence_ops (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4d88770
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/rpl: Update pci ids for RPL P/U (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6d04aae
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/sdvo: Fail gracefully if the TV dotclock is out of range (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 975c19e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/sdvo: Pick the TV dotclock from adjusted_mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e5e0b0b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Fully populate crtc_state->dpll (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 369f2df
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Don't warn about zero N/P in *_calc_dpll_params() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 155fb9d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/sdvo: s/sdvo_inputs_mask/sdvo_num_inputs/ (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8a4b724
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/sdvo: Protect macro args (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d6a73b0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/sdvo: Issue SetTargetOutput prior to GetAttachedDisplays (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d607072
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: add lock while printing frontbuffer tracking bits (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9296c63
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: combine DP audio compute config steps (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 435fb0a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: remove redundant parameter from sdp split update (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2a4c20c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: Remove unused POWER_DOMAIN_MODESET (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9788f88
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Check if force_dsc_output_format is possible (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 81ab4fb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Check src/sink compressed bpp limit for edp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7d64aae
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Get optimal link config to have best compressed bpp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3d56cb5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Separate out function to get compressed bpp with joiner (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7662480
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Add DSC BPC/BPP constraints while selecting pipe bpp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d4b59da
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Separate out functions for edp/DP for computing DSC bpp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 19c7953
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Rename helper to get DSC max pipe_bpp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a204975
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Avoid left shift of DSC output bpp by 4 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b2a9b0e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Check min bpc DSC limits for dsc_force_bpc also (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 50a461f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Add functions to get min/max src input bpc with DSC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cc9edbb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Avoid forcing DSC BPC for MST case (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1d08529
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Remove extra logs for printing DSC info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 51dbba2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/intel_cdclk: Add vdsc with bigjoiner constraints on (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 653fbe4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Update Bigjoiner interface bits for computing compressed (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 567dcfc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Use consistent name for link bpp and compressed
  bpp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/drm-i915-Introduce-crtc_state-enhanced_framing.patch.
- commit fce2b01
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Use output_format to get the final link bpp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0973c99
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Move compressed bpp check with 420 format inside the (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 587ff24
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Consider output_format while computing dsc bpp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 735b6f4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Eliminate has_4tile feature flag (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 44082aa
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/selftest: Simplify Y-major tiling in blit selftest (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 65b68b0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/cx0: Program vswing only for owned lanes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dfbe8de
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/cx0: Enable/disable TX only for owned PHY lanes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 024fe6b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Simplify intel_cx0_program_phy_lane() with loop (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1d8a4f0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/cx0: Add intel_cx0_get_owned_lane_mask() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4821e04
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/display: Remove unused POWER_DOMAIN_MASK (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b85caee
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/pxp: Optimize GET_PARAM:PXP_STATUS (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e4899fb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/pxp/mtl: intel_pxp_init_hw needs runtime-pm inside (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0fd1d49
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dp: Fix LT debug print in SDP CRC enable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8a0c1d3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/vdsc: Fix first_line_bpg_offset calculation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3f880f6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Don't change the status of forced connectors during HPD (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ccbfc0a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Don't change the status of forced connectors during hotplug (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 55af8cf
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Avoid endless HPD poll detect loop via runtime (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2aeea69
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Do not disable preemption for resets (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8b1861c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/perf: Remove gtt_offset from stream->oa_buffer.head/.tail (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 02b73f3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Add Wa_18028616096 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7cee125
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/gem: remove inlines from i915_gem_execbuffer.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit beba8a6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/gt: remove a static inline that requires including (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5a28ee6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/gt: Update RC6 mask for mtl_drpc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4829227
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: refactor deprecated strncpy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2dfda9f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/lrc: User PXP contexts requires runalone bit in lrc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f412db
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/pxp/mtl: Update pxp-firmware packet size (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 464907b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/pxp/mtl: Update pxp-firmware response timeout (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 48e0b97
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/huc: silence injected failure in the load via GSC path (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 55b8a86
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Add Wa_18022495364 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7a68688
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/gt: skip WA verification for GEN7_MISCCPCTL on DG2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2036689
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Run relevant bits of debugfs drop_caches per GT (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8947254
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/mtl: Drop Wa_14017240301 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit df5eda5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Add Wa_14015150844 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d3e9a5a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/gt: Wait longer for tasks in migrate selftest (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0f6e240
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/gsc: define gsc fw (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6e25237
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/mtl: Adding DeviceID for Arrowlake-S under MTL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7bf8d76
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/guc: Force a reset on internal GuC error (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b70a904
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/selftests: Align igt_spinner_create_request with hangcheck (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fe1afca
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/dg2: Remove Wa_15010599737 (jsc#PED-3527 jsc#PED-5475
  jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/drm-i915-dg2-Drop-pre-production-GT-workarounds.patch.
- commit 7a60723
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panel: ltk050h3146w: add support for Leadtek LTK050H3148W-CTA6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8a6835e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panel: ltk050h3146w: add mipi_dsi_device.mode_flags to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 332d0bb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/rockchip: dsi: Use devm_platform_get_and_ioremap_resource() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7d5bc27
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/rockchip: remove redundant of_match_ptr (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f166d3e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/rockchip: vop2: Convert to use maple tree register cache (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7770fe5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/rockchip: vop2: Demote message in mod_supported to drm_dbg_kms (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e65069c
* Fri Feb 16 2024 pjakobsson@suse.de
- Documentation/gpu: fix Panfrost documentation build warnings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 44a84b7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panel-simple: allow LVDS format override (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6033026
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: samsung-dsim: calculate porches in Hz (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ccc53fb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: samsung-dsim: adjust porches by rounding up (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 016421e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: samsung-dsim: update PLL reference clock (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 91741f4
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: samsung-dsim: reread ref clock before configuring PLL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 865a27b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: samsung-dsim: add more mipi-dsi device debug information (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aa4cc9c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: exynos: dsi: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 94c9916
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix mst hub unplug warning (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8f23482
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panel: nv3051d: Add Support for Anbernic 351V (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5b17a23
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/dp: switch drm_dp_downstream_*() helpers to struct drm_edid (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 584e755
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/v3d: Annotate struct v3d_perfmon with __counted_by (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a56bfb3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/vmwgfx: Annotate struct vmw_surface_dirty with __counted_by (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 74260a9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/virtio: Annotate struct virtio_gpu_object_array with __counted_by (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a7f342a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/vc4: Annotate struct vc4_perfmon with __counted_by (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cc57f75
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/pm: Annotate struct nvkm_perfdom with __counted_by (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 421aa22
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm/dpu: Annotate struct dpu_hw_intr with __counted_by (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7279d3d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915/selftests: Annotate struct perf_series with __counted_by (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1edeea1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu/discovery: Annotate struct ip_hw_instance with (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ac149fc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/pm: Annotate struct smu10_voltage_dependency_table with (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2e8a186
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panfrost: Implement generic DRM object RSS reporting function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0c5f128
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/drm_file: Add DRM obj's RSS reporting function for fdinfo (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 160680f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panfrost: Add fdinfo support for memory stats (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 30523e0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panfrost: Add fdinfo support GPU load metrics (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/drm-panfrost-Ignore-core_mask-for-poweroff-and-disab.patch.
- Refresh
  patches.suse/drm-panfrost-Really-power-off-GPU-cores-in-panfrost_.patch.
- commit c25d505
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panfrost: Add cycle count GPU register definitions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0a8462e
* Fri Feb 16 2024 msuchanek@suse.de
- Delete patches.suse/scsi-lpfc-limit-irq-vectors-to-online-cpus-if-kdump-kernel.patch.
  Should be addressed by the previously merged upstream solution (bsc#1218180 ltc#204476).
- commit ebf5676
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/vblank: Warn when silently cancelling vblank works (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0ea87ae
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/doc: Document DRM device reset expectations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4833bdb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panel: ili9322: Convert to use maple tree register cache (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2a6a568
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panel: ili9322: Remove redundant volatle_reg() operation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0c1d38c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: sn65dsi83: Convert to use maple tree register cache (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 683fba2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: lt9211: Convert to use maple tree register cache (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2cda034
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: icn6211: Convert to use maple tree register cache (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a7e0aed
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: tc358767: Convert to use maple tree register cache (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 381473f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: dpc3433: Convert to use maple tree register cache (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 856e7bb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: adv7511: Convert to use maple tree register cache (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ae1b40f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/tests: Add new format conversion tests to better cover (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7ffbd0c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/tests: Add calls to drm_fb_blit() on supported format conversion (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 31de742
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: lt9611uxc: use drm_bridge_get_edid() instead of using (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ebb69d6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: use drm_bridge_get_edid() instead of using ->get_edid (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c715ca7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/kms/nv50: hide unused variables (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d501b3a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/gpuvm: doc: fix filename references (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 956420e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/gma500: refactor deprecated strncpy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 991a3b3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau: uvmm: rename 'umgr' to 'base' (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 629934a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/imx/dcss: Call drm_atomic_helper_shutdown() at shutdown time (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2dbc56b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: Add 200ms delay to wait FW HPD status stable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d1696eb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/simpledrm: Add support for multiple "power-domains" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b534ec3
* Fri Feb 16 2024 pjakobsson@suse.de
- accel/qaic: Remove ->size field from struct qaic_bo (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3ff2dfd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ssd130x: Drop _helper prefix from struct drm_*_helper_funcs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1e71905
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/hisilicon/kirin: Call drm_atomic_helper_shutdown() at (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ff0b9db
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ssd130x: Call drm_atomic_helper_shutdown() at remove time (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit db88ed6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/vc4: Call drm_atomic_helper_shutdown() at shutdown time (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 47359c1
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: Call drm_atomic_helper_shutdown() at shutdown time for misc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a7d4979
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/armada: Call drm_atomic_helper_shutdown() at shutdown time (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 241cb62
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: panel: Fix device link for DRM_BRIDGE_ATTACH_NO_CONNECTOR (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 315a06e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: tc358768: Attempt to fix DSI horizontal timings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2e77bdc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: tc358768: Cleanup PLL calculations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ac740d3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: tc358768: Default to positive h/v syncs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d1f2f7b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/tegra: rgb: Parameterize V- and H-sync polarities (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b452fae
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge/analogix/anx78xx: Add missing definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 289dc90
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/kms/nv50-: disable dcb parsing (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ecbb4bc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/kms/nv50-: create outputs based on nvkm info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit de05dad
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/kms/nv50-: create connectors based on nvkm info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c4081cc
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/kms/nv50-: name aux channels after their connector (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3244880
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/kms/nv50-: create heads after outps/conns (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a014bf5
* Fri Feb 16 2024 msuchanek@suse.de
- powerpc/smp: Remap boot CPU onto core 0 if >= nr_cpu_ids
  (bsc#1218180 ltc#204476).
- powerpc/smp: Factor out assign_threads() (bsc#1218180
  ltc#204476).
- powerpc/smp: Lookup avail once per device tree node (bsc#1218180
  ltc#204476).
- powerpc/smp: Increase nr_cpu_ids to include the boot CPU
  (bsc#1218180 ltc#204476).
- powerpc/smp: Adjust nr_cpu_ids to cover all threads of a core
  (bsc#1218180 ltc#204476).
- commit 4c4f84a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/kms/nv50-: create heads based on nvkm head mask (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b0cc0d9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp/nv50-: skip DCB_OUTPUT_TV (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d1169f5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: move outp init/fini paths to chipset code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4367ebb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: move outp/conn construction to chipset code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 83ca168
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: add dp mst id get/put methods (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c18b778
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: add dp sst config method (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2a16d31
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: move link training out of supervisor (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 72db5f0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: add dp train method (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 561c5bb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/kms/nv50-: fixup sink D3 before tearing down link (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 205538f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/kms/nv50-: flush mst disables together (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5546f2c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/kms/nv50-: split DP disable+enable into two modesets (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9b7d75c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: add dp rates method (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 47dc73c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: add dp aux xfer method (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 24565e5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: move dp aux pwr method to HAL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f9a8619
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: add hdmi audio hal function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 79b328a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: add output lvds config method (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b507113
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: add output backlight control methods (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8b23054
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: remove SOR routing updates from supervisor (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a7eb999
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: release outputs post-modeset (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ac5873e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: move hdmi disable out of release() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9783000
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: add output hdmi config method (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d4527a5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/kms/nv50-: move audio enable post-modeset (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2f4fb23
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/kms/nv50-: keep output state around until modeset (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5ee9ce2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/kms/nv50-: remove nv_encoder.audio.connector (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 042a52e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/kms/nv50-: pull some common init out of OR-specific code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f566a1b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: update SOR routing immediately on acquire() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1753a18
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: add acquire_sor/pior() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0c91fb2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: add acquire_dac() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 88b24fd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: shuffle to make upcoming diffs prettier (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 17153d7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/kms: Add INHERIT ioctl to nvkm/nvif for reading IOR state (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 22cf797
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: rename internal output acquire/release functions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 810a240
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: add output method to fetch edid (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c5a2126
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: add output detect method (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e5a7b52
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/disp: rearrange output methods (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6538ae2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/kms/nv50-: fix mst payload alloc fail crashing evo (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aea5b69
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/mmu/gp100-: always invalidate TLBs at CACHE_LEVEL_ALL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 89de0b6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/gr/gf100-: lose contents of global ctxbufs across suspend (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 53da021
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/imem: support allocations not preserved across suspend (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1b2d42e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/devinit/tu102-: remove attempt at loading PreOS (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fe23d30
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/dp_mst: Tune down error message during payload addition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 36bfd8b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/dp_mst: Sanitize error return during payload addition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 796f4f5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/dp_mst: Fix NULL dereference during payload addition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 21dc6be
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: dw-hdmi-cec: Add arbitration lost event (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 79d3a0d
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/pm: refactor deprecated strncpy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3003786
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/core: refactor deprecated strncpy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5a59e9b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/nouveau/nvif: refactor deprecated strncpy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 12dd886
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/komeda: add NV12 format to support writeback layer type (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit db1ea9c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ssd130x: Store the HW buffer in the driver-private CRTC state (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f52ebd0
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/debugfs: Fix drm_debugfs_remove_files() stub (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 40bfae7
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amd/display: Fix -Wuninitialized in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit acb52e6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ingenic: Call drm_atomic_helper_shutdown() at shutdown time (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 71881ca
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/imx/ipuv3: Call drm_atomic_helper_shutdown() at shutdown/unbind (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit de82057
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/atomic-helper: drm_atomic_helper_shutdown(NULL) should be a noop (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7cf2a59
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panel: otm8009a: Don't double check prepared/enabled (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4411d26
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panel: s6e63m0: Don't store+check prepared/enabled (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1bacc20
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panel: Don't store+check prepared/enabled for simple cases (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6ca5057
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/i915: Move the size computations to drm buddy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 23b01d5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/amdgpu: Move the size computations to drm buddy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c63a833
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/buddy: Improve contiguous memory allocation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit de505fd
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/core: Clean up include statements in fbmem.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a21b3c6
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/core: Remove empty internal helpers from fb_logo.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 96ad7c9
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/core: Move logo functions into separate source file (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2b3e5a9
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/core: Unexport logo helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 34b0a11
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/core: Fix style of code for boot-up logo (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 394dafd
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/mmp/mmpfb: Do not display boot-up logo (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 231bd54
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/au1200fb: Do not display boot-up logo (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 05e349f
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ssd130x: Use bool for ssd130x_deviceinfo flags (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1e9058a
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ssd130x: Print the PWM's label instead of its number (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c82cdc8
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/shmobile: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0cca49b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/msm: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 65b1972
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/ingenic: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cd9d1ba
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/imx/ipuv3: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f0c6538
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mst: Refactor the flow for payload allocation/removement (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 46352d3
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/mst: delete unnecessary case in drm_dp_add_payload_part2() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2feb266
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/tests: Zero initialize fourccs_out (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b08d6dd
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/debugfs: Add inline to drm_debugfs_dev_init() to suppres (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0d60056
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/doc/rfc: Mark GPU VA as complete. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7bfc180
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/doc/rfc: Mark DRM_VM_BIND as complete. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 22c99db
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/doc/rfc: Mark Dev_coredump as completed. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cae5703
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/doc/rfc: No STAGING out of drivers/staging. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 09111c5
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/connector: document DRM_MODE_COLORIMETRY_COUNT (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c44af89
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: Drop CONFIG_OF conditionals around of_node pointers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c99b400
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: Drop conditionals around of_node pointers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 73c183c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge/analogix/anx78xx: Drop ID table (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c37ef7e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm: bridge: it66121: Extend match support for OF tables (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 30b6a90
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/hyperv_fb: Use fb_ops helpers for deferred I/O (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9760f74
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev: Add Kconfig macro FB_IOMEM_HELPERS_DEFERRED (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 91d0bac
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/udlfb: Use fb_ops helpers for deferred I/O (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0414980
* Fri Feb 16 2024 nik.borisov@suse.com
- KVM: VMX: Move VERW closer to VMentry for MDS mitigation (git-fixes).
- KVM: VMX: Use BT+JNC, i.e. EFLAGS.CF to select VMRESUME vs. VMLAUNCH (git-fixes).
- x86/bugs: Use ALTERNATIVE() instead of mds_user_clear static key (git-fixes).
- x86/entry_32: Add VERW just before userspace transition (git-fixes).
- x86/entry_64: Add VERW just before userspace transition (git-fixes).
- x86/bugs: Add asm helpers for executing VERW (git-fixes).
- commit 6f2943c
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/smscufx: Use fb_ops helpers for deferred I/O (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 568be29
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/virtio: Remove unused function declarations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4b5f5e9
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/debugfs: rework drm_debugfs_create_files implementation v2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ed253c2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/debugfs: remove dev->debugfs_list and debugfs_mutex v2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e95b68c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/debugfs: rework debugfs directory creation v5 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ff9e4b2
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/debugfs: disallow debugfs access when device isn't registered (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3421b7e
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/debugfs: drop debugfs_init() for the render and accel node v2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4c558ae
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/tcx: Use initializer macro for struct fb_ops (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1f54b3a
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/p9100: Use initializer macro for struct fb_ops (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 32336da
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/leo: Use initializer macro for struct fb_ops (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d240d98
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/ffb: Use initializer macro for struct fb_ops (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 38cac7d
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/cg6: Use initializer macro for struct fb_ops (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a5637c0
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/cg3: Use initializer macro for struct fb_ops (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ab66585
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/cg14: Use initializer macro for struct fb_ops (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 637ff7c
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/bw2: Use initializer macro for struct fb_ops (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 53a0d2a
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/sbus: Add initializer macros and Kconfig tokens for SBUS (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a6caeae
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/sbus: Forward declare all necessary structures in header (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9d7d959
* Fri Feb 16 2024 pjakobsson@suse.de
- fbdev/sbus: Build sbuslib.o if CONFIG_FB_SBUS has been selected (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b272235
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/tests: Add KUnit tests for drm_fb_memcpy() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ebb55ff
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/tests: Add multi-plane support to conversion_buf_size() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 583bc27
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/tests: Add KUnit tests for drm_fb_build_fourcc_list() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e9848c6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/tests: Add KUnit tests for drm_fb_clip_offset() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d06bd5c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/tests: Add KUnit tests for drm_fb_swab() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4110338
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/tests: Test default pitch fallback (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5e082ee
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/repaper: fix -Wvoid-pointer-to-enum-cast warning (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit db0f015
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/gma500: Remove unused declarations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 60f1133
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/gma500: remove duplicate macro definitions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1ff752b
* Fri Feb 16 2024 pjakobsson@suse.de
- doc: uapi: Add document describing dma-buf semantics (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e29a8fa
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panfrost: Do not check for 0 return after calling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7acbe64
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panel: JDI LT070ME05000 drop broken link (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 80a825b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/panel: simple: Add support for Mitsubishi AA084XE01 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bd2a3eb
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: panel: Add a device link between drm device and panel (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fe26a6c
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/rockchip: vop: Use cleanup helper directly as destroy funcs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 532b508
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/bridge: lvds-codec: Implement atomic_get_input_bus_fmts for LVDS (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1f7bd0f
* Fri Feb 16 2024 pjakobsson@suse.de
- accel/ivpu: Document DRM_IVPU_PARAM_CAPABILITIES (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 98b854b
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/rockchip: dsi: Add rv1126 MIPI DSI support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0c403d6
* Fri Feb 16 2024 pjakobsson@suse.de
- drm/rockchip: vop: Add rv1126 vop_lite support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8a64dd7
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau/svm: Split assignment from if conditional (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f9739f0
* Fri Feb 16 2024 pjakobsson@suse.de
- nouveau/svm: Replace one-element array with flexible-array member in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7534231
* Fri Feb 16 2024 pjakobsson@suse.de
- PCI: Add pci_get_base_class() helper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 937f4d8
* Fri Feb 16 2024 pjakobsson@suse.de
- Delete
  patches.suse/drm-amdgpu-Restrict-extended-wait-to-PSP-v13.0.6.patch.
- commit 399db8f
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-Add-HPD-state-to-drm_connector_oob_hotplug_event.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 jsc#PED-6028).
- Refresh
  patches.suse/usb-typec-altmodes-displayport-Signal-hpd-when.patch.
- commit 43da14e
* Fri Feb 16 2024 denis.kirjanov@suse.com
- net: ethernet: mtk_wed: fix possible NULL pointer dereference
  in mtk_wed_wo_queue_tx_clean() (git-fixes).
- commit f6c1c6f
* Fri Feb 16 2024 denis.kirjanov@suse.com
- net: ks8851: Fix TX stall caused by TX buffer overrun
  (git-fixes).
- commit 309032b
* Fri Feb 16 2024 denis.kirjanov@suse.com
- net: mscc: ocelot: fix pMAC TX RMON stats for bucket 256-511
  and above (git-fixes).
- commit f51244f
* Fri Feb 16 2024 denis.kirjanov@suse.com
- net: mscc: ocelot: fix eMAC TX RMON stats for bucket 256-511
  and above (git-fixes).
- commit 0cdf0a3
* Fri Feb 16 2024 denis.kirjanov@suse.com
- net: atlantic: fix double free in ring reinit logic (git-fixes).
- commit 7354340
* Fri Feb 16 2024 denis.kirjanov@suse.com
- net: stmmac: Handle disabled MDIO busses from devicetree
  (git-fixes).
- commit be25be7
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/uapi-stddef.h-Fix-__DECLARE_FLEX_ARRAY-for-C.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d7f10c6
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Fix-sending-VSC-colorimetry-packets-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 24540f7
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-skip-gpu_info-fw-loading-on-navi12.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 479cb85
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-add-nv12-bounding-box.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 49bb5d0
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-pbn_div-need-be-updated-for-hotplug-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 456ae01
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-mgag200-Fix-gamma-lut-not-initialized-for-G200ER.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 427bc78
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-ps8640-Fix-size-mismatch-warning-w-len.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7c0f0f9
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-ti-sn65dsi86-Never-store-more-than-msg-si.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ac440b3
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-parade-ps8640-Never-store-more-than-msg-s.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 91d6caf
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-perf-Update-handling-of-MMIO-triggered-repo.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c834c8d
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-dp-Fix-passing-the-correct-DPCD_REV-for-drm.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 990e5fd
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-dmc-Don-t-enable-any-pipe-DMC-events.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 66c5cba
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-mtl-Fix-HDMI-DP-PLL-clock-selection.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c820254
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Reject-async-flips-with-bigjoiner.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0611076
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-hwmon-Fix-static-analysis-tool-reported-iss.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0b8d00b
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-re-create-idle-bo-s-PTE-during-VM-state-m.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e983540
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-get-dprefclk-ss-info-from-integratio.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cec05f9
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Add-case-for-dcn35-to-support-usb4-d.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 32a0766
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdkfd-svm-range-always-mapped-flag-not-working-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e24941c
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-edid-also-call-add-modes-in-EDID-connector-updat.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 186e99f
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-crtc-fix-uninitialized-variable-use.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f8d192f
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-crtc-Fix-uninit-value-bug-in-drm_mode_setcrtc.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c59e9f5
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-Fix-FD-ownership-check-in-drm_master_check_perm.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4796f01
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-fix-tear-down-order-in-amdgpu_vm_pt_free.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7fa63f7
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-sdma5.2-add-begin-end_use-ring-callbacks.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e2b4703
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Disable-PSR-SU-on-Parade-0803-TCON-a.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4cffb04
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Restore-guard-against-default-backli.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 28169ea
* Fri Feb 16 2024 pjakobsson@suse.de
- Delete
  patches.suse/drm-amd-display-fix-hw-rotated-modes-when-PSR-SU-is-.patch.
- commit c4c99e8
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-edp-don-t-write-to-DP_LINK_BW_SET-when-usin.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 40b399d
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Fix-ADL-tiled-plane-stride-when-the-POT-str.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7fafc1f
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Fix-intel_atomic_setup_scalers-plane_state-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cdddc75
* Fri Feb 16 2024 denis.kirjanov@suse.com
- dpaa2-switch: do not ask for MDB, VLAN and FDB replay
  (git-fixes).
- commit c6e8879
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Fix-remapped-stride-with-CCS-on-ADL.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c9decbb
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Use-internal-class-when-counting-engine-res.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 41f2ffd
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-selftests-Fix-engine-reset-count-storage-fo.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9125213
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-mediatek-Fix-access-violation-in-mtk_drm_crtc_dm.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 36e198c
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-mediatek-Add-spinlock-for-setting-vblank-event-i.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c19fb81
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-mediatek-fix-kernel-oops-if-no-crtc-is-found.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 34a58bd
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/misc-mei-client.c-fix-problem-of-return-EOVERFLOW-in.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 547c308
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/misc-mei-client.c-return-negative-error-code-in-mei_.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8a5444b
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-exynos-fix-a-wrong-error-checking.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fc33a7d
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-exynos-fix-a-potential-error-pointer-dereference.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bc64419
* Fri Feb 16 2024 denis.kirjanov@suse.com
- dpaa2-switch: fix size of the dma_unmap (git-fixes).
- commit 23ea26f
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Add-NULL-checks-for-function-pointers.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 5c7a1dc
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Increase-frame-warning-limit-with-KA.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 769dd46
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Add-monitor-patch-for-specific-eDP.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a46860b
* Fri Feb 16 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-disable-MCBP-by-default.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 118c1ba
* Fri Feb 16 2024 denis.kirjanov@suse.com
- stmmac: dwmac-loongson: drop useless check for compatible
  fallback (git-fixes).
- commit 02807a5
* Fri Feb 16 2024 denis.kirjanov@suse.com
- stmmac: dwmac-loongson: Make sure MDIO is initialized before
  use (git-fixes).
- commit c27d9ce
* Fri Feb 16 2024 denis.kirjanov@suse.com
- net: fec: correct queue selection (git-fixes).
- commit 7f02173
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-atomic-helpers-Invoke-end_fb_access-while-owning.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e81b6ed
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-tc358768-select-CONFIG_VIDEOMODE_HELPERS.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 85cce1f
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/nouveau-tu102-flush-all-pdbs-on-vmm-flush.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 02c760c
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-mst-Reject-modes-that-require-the-bigjoiner.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b70a9b0
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-mst-Fix-.mode_valid_ctx-return-values.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 130f8b8
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Skip-some-timing-checks-on-BXT-GLK-DSI-tran.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f53198f
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/Revert-drm-prime-Unexport-helpers-for-fd-handle-conv.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d0c962e
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Use-another-offset-for-GC-9.4.3-remap.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0f803c9
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdkfd-Free-gang_ctx_bo-and-wptr_bo-in-pqm_unini.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b11ffa5
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Update-EEPROM-I2C-address-for-smu-v13_0_0.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7e02e0c
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Fix-cat-debugfs-amdgpu_regs_didt-causes-k.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6dfc295
* Fri Feb 16 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Enable-PCIe-PME-from-D3.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 72123f1
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-pm-fix-a-memleak-in-aldebaran_tables_init.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e9b884c
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-update-dcn315-lpddr-pstate-latency.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f945f85
* Fri Feb 16 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-ABM-disablement.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cbc2d9e
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdkfd-Use-common-function-for-IP-version-check.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a2595ea
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-force-toggle-rate-wa-for-first-link-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 67e3ff8
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-correct-the-amdgpu-runtime-dereference-us.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7b01d65
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Update-min-Z8-residency-time-to-2100.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 71dc081
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Remove-min_dst_y_next_start-check-fo.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9ab4e92
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-fix-memory-overflow-in-the-IB-test.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1405f0b
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Simplify-brightness-initialization.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8057440
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Increase-num-voltage-states-to-40.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2c8f43a
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Use-DRAM-speed-from-validation-for-d.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 42b2114
* Fri Feb 16 2024 denis.kirjanov@suse.com
- qca_spi: Fix reset behavior (git-fixes).
- commit f971346
* Fri Feb 16 2024 pjakobsson@suse.de
- Delete
  patches.suse/drm-amd-display-Fix-MPCC-1DLUT-programming.patch.
- commit db96a92
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Force-order-between-a-read-and-write-to-t.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 6e559a6
* Fri Feb 16 2024 denis.kirjanov@suse.com
- qca_debug: Fix ethtool -G iface tx behavior (git-fixes).
- commit 87b783f
* Fri Feb 16 2024 denis.kirjanov@suse.com
- qca_debug: Prevent crash on TX ring changes (git-fixes).
- commit a319e0e
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Do-not-issue-gpu-reset-from-nbio-v7_9-bif.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 54ea2d2
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Include-udelay-when-waiting-for-INBO.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit de8ed45
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-panel-nt36523-fix-return-value-check-in-nt36523_.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e4c0453
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-panel-starry-2081101qfh032011-53g-Fine-tune-the-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8793198
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/nouveau-find-the-smallest-page-allocation-to-cover-a.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fe1b807
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/dma-buf-fix-check-in-dma_resv_add_fence.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 64455a1
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Call-intel_pre_plane_updates-also-for-pipes.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 815c966
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Also-check-for-VGA-converter-in-eDP-probe.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2afd15a
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-gsc-Mark-internal-GSC-engine-with-reserved-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 80ee04c
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-do-not-clean-GT-table-on-error-path.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8a36eea
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-panel-boe-tv101wum-nl6-Fine-tune-Himax83102-j02-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7fccfb5
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-ast-Disconnect-BMC-if-physical-connector-is-conn.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8ebca0e
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-rockchip-vop-Fix-color-for-RGB888-BGR888-format-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8f4c509
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-panel-simple-Fix-Innolux-G101ICE-L01-timings.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d33a365
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-panel-simple-Fix-Innolux-G101ICE-L01-bus-flags.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7545b8e
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-panel-auo-b101uan08.3-Fine-tune-the-panel-power-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2a2419b
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dpu-Add-missing-safe_lut_tbl-in-sc8280xp-cat.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3195ba7
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dsi-use-the-correct-VREG_CTRL_1-value-for-4n.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 64eb523
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Change-the-DMCUB-mailbox-memory-loca.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d76beb7
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Clear-dpcd_sink_ext_caps-if-not-set.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b65656f
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Enable-fast-plane-updates-on-DCN3.2-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f14bcc
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-fix-a-NULL-pointer-dereference-in-am.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 84d077d
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-correct-chunk_ptr-to-a-pointer-to-chunk.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a72a734
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Fix-DSC-not-Enabled-on-Direct-MST-Si.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c94ec1e
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-finalizing-mem_partitions-at-the-end-of-G.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 44feb8d
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Do-not-program-VF-copy-regs-in-mmhub-v1.8.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 45d0974
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Guard-against-invalid-RPTR-WPTR-bein.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 577949b
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/nouveau-use-an-rwlock-for-the-event-lock.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0d8694b
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/fbdev-fsl-diu-fb-mark-wr_reg_wa-static.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1d95496
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/fbdev-imsttfb-fix-a-resource-leak-in-probe.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9686763
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/fbdev-imsttfb-fix-double-free-in-probe.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b19bddf
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/fbdev-omapfb-Drop-unused-remove-function.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit caa420d
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-fix-error-handling-in-amdgpu_vm_init.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3fdda15
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Fix-possible-null-pointer-dereference.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6d99d27
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-fix-software-pci_unplug-on-some-chips.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c4fe712
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-lower-CS-errors-to-debug-severity.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 95f25f6
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-fix-error-handling-in-amdgpu_bo_list_get.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4aaaeb7
* Fri Feb 16 2024 pjakobsson@suse.de
- Update patches.suse/drm-qxl-prevent-memory-leak.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 14981e8
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-syncobj-fix-DRM_SYNCOBJ_WAIT_FLAGS_WAIT_AVAILABL.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 06fbf83
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-vc4-tests-Fix-UAF-in-the-mock-helpers.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5169a07
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-tc-Fix-Wformat-truncation-in-intel_tc_port_.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b51f04d
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Fix-potential-spectre-vulnerability.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6aa5688
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Bump-GLK-CDCLK-frequency-when-driving-multi.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7b5da6c
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/i915-perf-Fix-NULL-deref-bugs-with-drm_dbg-calls.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a387d6c
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-mtl-Support-HBR3-rate-with-C10-phy-and-eDP-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f9066b9
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Flush-WC-GGTT-only-on-required-platforms.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit c23be1d
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-mtl-avoid-stringop-overflow-warning.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dc1705c
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-fix-GRBM-read-timeout-when-do-mes_self_te.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8512f76
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Avoid-NULL-dereference-of-timing-gen.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dd4b83c
* Fri Feb 16 2024 pjakobsson@suse.de
- Delete
  patches.suse/drm-amdgpu-don-t-put-MQDs-in-VRAM-on-ARM-ARM64.patch.
- commit fd1474c
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-smu13-drop-compute-workload-workaround.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 93de5a5
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-add-a-retry-for-IP-discovery-init.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9019cd2
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-don-t-use-pci_is_thunderbolt_attached.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2d9993e
* Fri Feb 16 2024 pjakobsson@suse.de
- Delete
  patches.suse/drm-amdgpu-don-t-use-ATRM-for-external-devices.patch.
- commit ce743c7
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-gfx10-11-use-memcpy_to-fromio-for-MQDs.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 2fde690
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-pm-Fix-error-of-MACO-flag-setting-code.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 557a137
* Fri Feb 16 2024 pjakobsson@suse.de
- Update patches.suse/vga16fb-drop-powerpc-support.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3a76aec
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/backlight-pwm_bl-Disable-PWM-on-shutdown-suspend-and.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cdfd819
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/fbdev-stifb-Make-the-STI-next-font-pointer-a-32-bit-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3cbfa66
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Remove-unused-variables-from-amdgpu_show_.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2545167
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Remove-duplicate-fdinfo-fields.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 44acf7b
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-check-num-of-link-levels-when-update-pcie-pa.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d07263f
* Fri Feb 16 2024 pjakobsson@suse.de
- Delete
  patches.suse/drm-amd-display-fix-num_ways-overflow-error.patch.
- commit de1eb3a
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Reduce-default-backlight-min-from-5-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6d5d863
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-Disable-PP_PCIE_DPM_MASK-when-dynamic-speed-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit db305f9
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Fix-a-null-pointer-access-when-the-smc_rr.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9b83576
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Remove-power-sequencing-check.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c7e5a88
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdkfd-Fix-shift-out-of-bounds-issue.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 693006c
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-rockchip-vop2-remove-the-unsupported-format-of-c.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 91d5324
* Fri Feb 16 2024 pjakobsson@suse.de
- Update patches.suse/drm-vc4-fix-typo.patch (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 67fa922
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-rockchip-remove-unused-struct-in-vop2.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5336fb6
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-rockchip-Fix-type-promotion-bug-in-rockchip_gem_.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9208f94
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-lt9611uxc-fix-the-race-in-the-error-path.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 200d562
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-panel-st7703-Pick-different-reset-sequence.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4d178fe
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-pm-Handle-non-terminated-overdrive-commands.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b272e5e
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-update-retry-times-for-psp-BL-wait.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 52eb61e
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-pm-Fix-a-memory-leak-on-an-error-path.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 0723316
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/Revert-drm-amdgpu-Program-xcp_ctl-registers-as-neede.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 195bc9e
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-vmwgfx_surface.c-copy-user-array-safely.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a1d8c03
* Fri Feb 16 2024 pjakobsson@suse.de
- Update patches.suse/drm_lease.c-copy-user-array-safely.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0270579
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/string.h-add-array-wrappers-for-v-memdup_user.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6bf5e6b
* Fri Feb 16 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dsi-free-TX-buffer-in-unbind.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1a2a3c4
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dsi-use-msm_gem_kernel_put-to-free-TX-buffer.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8c6b427
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-a6xx-Fix-unknown-speedbin-case.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5b9df95
* Fri Feb 16 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-adreno-Fix-SM6375-GPU-ID.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9cb711b
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dp-skip-validity-check-for-DP-CTS-EDID-check.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1198d37
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-mediatek-mtk_dsi-Fix-NO_EOT_PACKET-settings-hand.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3667833
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-mediatek-Fix-iommu-fault-during-crtc-enabling.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 68fff1b
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-mediatek-Fix-iommu-fault-by-swapping-FBs-after-u.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0db16dc
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-mediatek-Fix-using-wrong-drm-private-data-to-bin.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d57eba6
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-mediatek-Add-crtc-path-enum-for-all_drm_priv-arr.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ec54728
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-mediatek-Add-mmsys_dev_num-to-mt8188-vdosys0-dri.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2aca049
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-mediatek-dp-fix-memory-leak-on-get_edid-callback-fcaf976.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 16ae864
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-mediatek-dp-fix-memory-leak-on-get_edid-callback.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f1fe274
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-mediatek-Fix-coverity-issue-with-unintentional-i.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d435b14
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-vkms-fix-a-possible-null-pointer-derefere.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 295e0da
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-radeon-fix-a-possible-null-pointer-dereference.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3feef84
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdkfd-get-doorbell-s-absolute-offset-based-on-t.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f0305a7
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Don-t-use-fsleep-for-PSR-exit-waits.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 177f05a
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Fix-potential-null-pointer-derefernce.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 158ef68
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-Fix-UBSAN-array-index-out-of-bounds-for-Pola.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ad981b8
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-Fix-UBSAN-array-index-out-of-bounds-for-SMU7.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aab9397
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-use-full-update-for-clip-size-increa.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1f2a41c
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-refactor-ILR-to-make-it-work.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cffe063
* Fri Feb 16 2024 pjakobsson@suse.de
- Refresh
  patches.suse/drm-amd-display-Fix-tiled-display-misalignment.patch.
- Delete
  patches.suse/drm-amd-display-enable-dsc_clk-even-if-dsc_pg-disabl.patch.
- commit c31149a
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Add-Null-check-for-DPP-resource.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 87fc4ac
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-Update-update_pcie_parameters-functions-to-u.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b18d6f5
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Bail-from-dm_check_crtc_cursor-if-no.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 58851f5
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/Revert-drm-amd-display-Enable-Replay-for-static-scre.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 065e3dc
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Refactor-dm_get_plane_scale-helper.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b5318a3
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-update-retry-times-for-psp-vmbx-wait.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 25b01ca
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdkfd-Fix-a-race-condition-of-vram-buffer-unref.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c34445a
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Check-all-enabled-planes-in-dm_check.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cb7fdfd
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Fix-null-pointer-dereference-in-erro.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c19d878
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdkfd-Handle-errors-from-svm-validate-and-map.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit adcbc9d
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-not-to-save-bo-in-the-case-of-RAS-err_eve.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a05e6a5
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdkfd-fix-some-race-conditions-in-vram-buffer-a.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d277307
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Increase-IH-soft-ring-size-for-GFX-v9.4.3.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 219b82e
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdkfd-Remove-svm-range-validated_once-flag.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a70f952
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-add-seamless-pipe-topology-transitio.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 417397b
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Don-t-lock-phantom-pipe-on-disabling.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0e29bd8
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Blank-phantom-OTG-before-enabling.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b726034
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Fix-refclk-reporting-for-SMU-v13.0.6.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5809c7d
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-remove-useless-check-in-should_enabl.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 38c6040
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdkfd-ratelimited-SQ-interrupt-messages.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c012e8c
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-radeon-Remove-the-references-of-radeon_gem_-prea.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b5d72d5
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-amdgpu-amdgpu_doorbell_mgr-Correct-misdocume.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 12c831c
* Fri Feb 16 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-possible-buffer-overflow.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9a894fa
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Refactor-edp-power-control.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6636a56
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Add-missing-GSCCS-documentation.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 17e2691
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Add-missing-CCS-documentation.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e0493ec
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/gpu-host1x-Correct-allocated-size-for-contexts.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6e3569c
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Introduce-crtc_state-enhanced_framing.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 938d12f
* Fri Feb 16 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Fix-FEC-state-dump.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c20799b
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-display-Eliminate-IS_METEORLAKE-checks.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 270ec96
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Eliminate-IS_MTL_DISPLAY_STEP.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b54e4e3
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-dg2-Drop-pre-production-display-workarounds.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 45e9762
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-dg2-Recognize-pre-production-hardware.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c425dd2
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-mtl-Update-workaround-14016712196.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bdb6d13
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Replace-several-IS_METEORLAKE-with-proper-I.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 52bfb9f
* Fri Feb 16 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-mtl-Eliminate-subplatforms.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 07b4217
* Fri Feb 16 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Eliminate-IS_MTL_MEDIA_STEP.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8cad653
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Eliminate-IS_MTL_GRAPHICS_STEP.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a196bc0
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-xelpg-Call-Xe_LPG-workaround-functions-base.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7df9edc
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-xelpmp-Don-t-assume-workarounds-extend-to-f.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1031056
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Consolidate-condition-for-Wa_22011802037.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bebf894
* Fri Feb 16 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dg2-Drop-Wa_16011777198.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 96d06cd
* Fri Feb 16 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Tidy-workaround-definitions.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4814549
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-dg2-Drop-pre-production-GT-workarounds.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 46aa492
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-panel-panel-tpo-tpg110-fix-a-possible-null-point.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 065fd43
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-panel-fix-a-possible-null-pointer-dereference.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 650fcea
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-rockchip-cdn-dp-Fix-some-error-handling-paths-in.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9173bb3
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-edid-Fixup-h-vsync_end-instead-of-h-vtotal.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0adb14f
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-Call-drm_atomic_helper_shutdown-at-shutdown-remo.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit acd9811
* Fri Feb 16 2024 pjakobsson@suse.de
- Update patches.suse/drm-Update-file-owner-during-use.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 24604a6
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-tc358768-Fix-tc358768_ns_to_cnt.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c34b5e7
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-tc358768-Clean-up-clock-period-code.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b65effd
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-tc358768-Rename-dsibclk-to-hsbyteclk.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7043033
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-tc358768-Use-dev-for-dbg-prints-not-priv-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a3f42b
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-tc358768-Print-logical-values-not-raw-reg.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 58d08e1
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-tc358768-Use-struct-videomode.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ca68a97
* Fri Feb 16 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-Fix-bit-updates.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 24b573e
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-tc358768-Fix-use-of-uninitialized-variabl.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6026cf0
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-it66121-get_edid-callback-must-not-return.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0505586
* Fri Feb 16 2024 pjakobsson@suse.de
- Update patches.suse/drm-ssd130x-Fix-screen-clearing.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 03015af
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-lt8912b-Add-missing-drm_bridge_attach-cal.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 53a6da3
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-lt8912b-Manually-disable-HPD-only-if-it-w.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 912267b
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-lt8912b-Fix-crash-on-bridge-detach.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 395d695
* Fri Feb 16 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-lt8912b-Fix-bridge_detach.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 20423b9
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-it66121-Fix-invalid-connector-dereference.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ec19151
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-komeda-drop-all-currently-held-locks-if-deadlock.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fe6d5da
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-gma500-Fix-call-trace-when-psb_gem_mm_init-fails.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b925226
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-Fix-kernel-doc-typo-in-desc-of-output_bus.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 963c938
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-rockchip-vop2-Add-missing-call-to-crtc-reset-hel.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f474f1e
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-rockchip-vop2-Don-t-crash-for-invalid-duplicate_.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0359791
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-rockchip-vop-Fix-call-to-crtc-reset-helper.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b338586
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-rockchip-vop-Fix-reset-of-state-in-duplicate-sta.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1cf8546
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-loongson-Fix-error-handling-in-lsdc_pixel_pll_se.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bebb0c5
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-samsung-dsim-Fix-waiting-for-empty-cmd-tr.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3db85de
* Fri Feb 16 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-for-GENERIC_PHY_MIPI_DPHY-also-select-GEN.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c593905
* Fri Feb 16 2024 svarbanov@suse.de
- memory: tegra: add MC client for Tegra234 GPU (bsc#1221330)
- commit f5d121c
* Fri Feb 16 2024 svarbanov@suse.de
- memory: tegra: Add clients used by DRM in Tegra234 (bsc#1221330).
- commit 67c31f5
* Thu Feb 15 2024 jwiesner@suse.de
- clocksource: Replace all non-returning strlcpy with strscpy
  (bsc#1219953).
- commit b844ff1
* Thu Feb 15 2024 jwiesner@suse.de
- x86/smpboot: Avoid pointless delay calibration if TSC is
  synchronized (bsc#1219953).
- commit 7dfe12b
* Thu Feb 15 2024 jwiesner@suse.de
- rcutorture: Add fqs_holdoff check before fqs_task is created
  (bsc#1219953).
- commit d6f81ac
* Thu Feb 15 2024 jwiesner@suse.de
- locktorture: Increase Hamming distance between call_rcu_chain
  and rcu_call_chains (bsc#1219953).
- commit 82380d1
* Thu Feb 15 2024 jwiesner@suse.de
- asm-generic: qspinlock: fix queued_spin_value_unlocked()
  implementation (bsc#1219953).
- commit a3ab6e9
* Thu Feb 15 2024 jwiesner@suse.de
- locktorture: Check the correct variable for allocation failure
  (bsc#1219953).
- commit 5884e2f
* Thu Feb 15 2024 jwiesner@suse.de
- rcutorture: Traverse possible cpu to set maxcpu in
  rcu_nocb_toggle() (bsc#1219953).
- commit ac1c709
* Thu Feb 15 2024 jwiesner@suse.de
- rcutorture: Replace schedule_timeout*() 1-jiffy waits with HZ/20
  (bsc#1219953).
- commit de5b047
* Thu Feb 15 2024 jwiesner@suse.de
- locktorture: Rename readers_bind/writers_bind to
  bind_readers/bind_writers (bsc#1219953).
- commit 1dc09ec
* Thu Feb 15 2024 jwiesner@suse.de
- doc: Catch-up update for locktorture module parameters
  (bsc#1219953).
- commit 19c054c
* Thu Feb 15 2024 jwiesner@suse.de
- locktorture: Add call_rcu_chains module parameter (bsc#1219953).
- commit 9348bbf
* Thu Feb 15 2024 jwiesner@suse.de
- locktorture: Add new module parameters to
  lock_torture_print_module_parms() (bsc#1219953).
- commit 59c9dd5
* Thu Feb 15 2024 jwiesner@suse.de
- torture: Print out torture module parameters (bsc#1219953).
- commit f0a2f52
* Thu Feb 15 2024 jwiesner@suse.de
- locktorture: Add acq_writer_lim to complain about long
  acquistion times (bsc#1219953).
- commit 495f129
* Thu Feb 15 2024 jwiesner@suse.de
- locktorture: Consolidate "if" statements in
  lock_torture_writer() (bsc#1219953).
- commit 19cd3cf
* Thu Feb 15 2024 jwiesner@suse.de
- locktorture: Alphabetize torture_param() entries (bsc#1219953).
- commit 4d45162
* Thu Feb 15 2024 jwiesner@suse.de
- locktorture: Add readers_bind and writers_bind module parameters
  (bsc#1219953).
- commit d4bab3f
* Thu Feb 15 2024 jwiesner@suse.de
- rcutorture: Fix stuttering races and other issues (bsc#1219953).
- commit 14a2209
* Thu Feb 15 2024 jwiesner@suse.de
- torture: Move rcutorture_sched_setaffinity() out of rcutorture
  (bsc#1219953).
- commit ec64c16
* Thu Feb 15 2024 jwiesner@suse.de
- torture: Make torture_hrtimeout_ns() take an hrtimer mode
  parameter (bsc#1219953).
- commit 7155d42
* Thu Feb 15 2024 jwiesner@suse.de
- torture: Share torture_random_state with torture_shuffle_tasks()
  (bsc#1219953).
- commit abf8744
* Thu Feb 15 2024 jwiesner@suse.de
- locking/lockdep: Fix string sizing bug that triggers a
  format-truncation compiler-warning (bsc#1219953).
- commit 23d08c5
* Thu Feb 15 2024 jwiesner@suse.de
- locking/debug: Fix debugfs API return value checks to use
  IS_ERR() (bsc#1219953).
- commit 048609a
* Thu Feb 15 2024 jwiesner@suse.de
- locking/ww_mutex/test: Make sure we bail out instead of livelock
  (bsc#1219953).
- commit 4038509
* Thu Feb 15 2024 jwiesner@suse.de
- locking/ww_mutex/test: Fix potential workqueue corruption
  (bsc#1219953).
- commit def0333
* Thu Feb 15 2024 jwiesner@suse.de
- locking/ww_mutex/test: Use prng instead of rng to avoid hangs
  at bootup (bsc#1219953).
- commit aacf9cc
* Thu Feb 15 2024 jwiesner@suse.de
- asm-generic: ticket-lock: Optimize arch_spin_value_unlocked()
  (bsc#1219953).
- commit b967504
* Thu Feb 15 2024 jwiesner@suse.de
- futex: Use a folio instead of a page (bsc#1219953).
- commit a11123c
* Thu Feb 15 2024 jwiesner@suse.de
- locking/seqlock: Do the lockdep annotation before locking in
  do_write_seqcount_begin_nested() (bsc#1219953).
- commit d372072
* Thu Feb 15 2024 jwiesner@suse.de
- rcutorture: Stop right-shifting torture_random() return values
  (bsc#1219953).
- commit a88dc75
* Thu Feb 15 2024 jwiesner@suse.de
- torture: Stop right-shifting torture_random() return values
  (bsc#1219953).
- commit 9c51efc
* Thu Feb 15 2024 jwiesner@suse.de
- torture: Move stutter_wait() timeouts to hrtimers (bsc#1219953).
- commit 8bcefe1
* Thu Feb 15 2024 jwiesner@suse.de
- torture: Move torture_shuffle() timeouts to hrtimers
  (bsc#1219953).
- commit 24edc78
* Thu Feb 15 2024 jwiesner@suse.de
- torture: Move torture_onoff() timeouts to hrtimers
  (bsc#1219953).
- commit c16d2c1
* Thu Feb 15 2024 jwiesner@suse.de
- torture: Make torture_hrtimeout_*() use TASK_IDLE (bsc#1219953).
- commit 15e523b
* Thu Feb 15 2024 jwiesner@suse.de
- torture: Add lock_torture writer_fifo module parameter
  (bsc#1219953).
- commit 86a51c8
* Thu Feb 15 2024 jwiesner@suse.de
- torture: Add a kthread-creation callback to
  _torture_create_kthread() (bsc#1219953).
- commit a568efe
* Thu Feb 15 2024 jwiesner@suse.de
- torture: Support randomized shuffling for proxy exec testing
  (bsc#1219953).
- commit dfb6658
* Thu Feb 15 2024 jwiesner@suse.de
- rcutorture: Dump grace-period state upon rtort_pipe_count
  incidents (bsc#1219953).
- commit 39c3645
* Thu Feb 15 2024 jwiesner@suse.de
- powerpc/kcsan: Properly instrument arch_spin_unlock()
  (bsc#1219953).
- commit 49ef44f
* Thu Feb 15 2024 jwiesner@suse.de
- locktorture: Add long_hold to adjust lock-hold delays
  (bsc#1219953).
- commit 21a09d3
* Thu Feb 15 2024 ggherdovich@suse.cz
- intel_idle: add Sierra Forest SoC support (jsc#PED-5816).
- commit d8dfa47
* Thu Feb 15 2024 ggherdovich@suse.cz
- intel_idle: add Grand Ridge SoC support (jsc#PED-5816).
- commit be47fec
* Thu Feb 15 2024 msuchanek@suse.de
- powerpc/pseries/papr-sysparm: use u8 arrays for payloads
  (jsc#PED-4486 git-fixes).
- commit 8b94284
* Thu Feb 15 2024 oneukum@suse.com
- PCI: Add PCIE_PME_TO_L2_TIMEOUT_US L2 ready timeout value
  (git-fixes).
- commit a77e06b
* Thu Feb 15 2024 oneukum@suse.com
- PCI: dwc: Drop host prefix from struct dw_pcie_host_ops members
  (git-fixes).
- commit 4a87954
* Thu Feb 15 2024 oneukum@suse.com
- PCI: dwc: endpoint: Introduce .pre_init() and .deinit()
  (git-fixes).
- commit 75c1ddc
* Thu Feb 15 2024 oneukum@suse.com
- PCI: dwc: Add host_post_init() callback (git-fixes).
- commit 5c6ab40
* Thu Feb 15 2024 oneukum@suse.com
- PCI: dwc: Implement generic suspend/resume functionality
  (git-fixes).
- commit 42b5947
* Thu Feb 15 2024 oneukum@suse.com
- dmaengine: dw-edma: Rename dw_edma_core_ops structure to
  dw_edma_plat_ops (git-fixes).
- commit a3742cf
* Thu Feb 15 2024 jlee@suse.com
- net/rds: Fix UBSAN: array-index-out-of-bounds in rds_cmsg_recv
  (bsc#1219127 CVE-2024-23849).
- commit 7f27245
* Wed Feb 14 2024 jgross@suse.com
- x86/coco: Define cc_vendor without CONFIG_ARCH_HAS_CC_PLATFORM
  (jsc#PED-7322).
- commit 98c6595
* Wed Feb 14 2024 jgross@suse.com
- x86/kvm: Fix SEV check in sev_map_percpu_data() (jsc#PED-7322).
- commit 082b8e1
* Wed Feb 14 2024 jgross@suse.com
- KVM: x86: Give a hint when Win2016 might fail to boot due to
  XSAVES erratum (jsc#PED-7322).
- commit d5577b6
* Wed Feb 14 2024 jgross@suse.com
- KVM: x86: Check irqchip mode before create PIT (jsc#PED-7322).
- commit d2cbe00
* Wed Feb 14 2024 jwiesner@suse.de
- Update config files (bsc#1205603 bsc#1212446 bsc#1219440).
  Change the CONFIG_LSM option to exclude all major LSMs apart from selinux.
  The default upstream value for CONFIG_LSM causes a performance regression
  if a user removes the security= parameter from the kernel command line.
  Removing the security= parameter results in the tomoyo LSM being enabled,
  which causes a regression in throughput in situations where small amounts
  of data are transferred between processes and many syscalls are made.
- commit b35e0be
* Wed Feb 14 2024 jwiesner@suse.de
- Update config files (bsc#1219440).
  Update the CONFIG_LSM option to include the BPF LSM in the default set of
  LSMs that get enabled when booting up. The new version of systemd in
  SLE15-SP6 requires the BPF LSM.
- commit bf6e39d
* Wed Feb 14 2024 jgross@suse.com
- KVM: introduce CONFIG_KVM_COMMON (jsc#PED-7322).
- Update config files.
- commit 60742fc
* Wed Feb 14 2024 dwagner@suse.de
- Update metadata: "scsi: lpfc: Use unsigned type for num_sge (bsc#1214746)."
  Move patch into sorted section.
- commit bf77043
* Wed Feb 14 2024 jgross@suse.com
- virt: sev-guest: Convert to platform remove callback returning
  void (jsc#PED-7322).
- commit 5752a5f
* Wed Feb 14 2024 jgross@suse.com
- KVM: remove CONFIG_HAVE_KVM_IRQFD (jsc#PED-7322).
- Update config files.
- commit 6e3621a
* Wed Feb 14 2024 oneukum@suse.com
- PCI: dwc: Fix a 64bit bug in dw_pcie_ep_raise_msix_irq()
  (git-fixes).
- commit 686e708
* Wed Feb 14 2024 oneukum@suse.com
- PCI: dwc: Use FIELD_GET/PREP() (git-fixes).
- commit 34f9411
* Wed Feb 14 2024 jgross@suse.com
- KVM: remove CONFIG_HAVE_KVM_EVENTFD (jsc#PED-7322).
- Update config files.
- commit 6361a8e
* Wed Feb 14 2024 oneukum@suse.com
- PCI/ASPM: Fix deadlock when enabling ASPM (git-fixes).
- commit aa4d6dc
* Wed Feb 14 2024 oneukum@suse.com
- PCI: qcom: Clean up ASPM comment (git-fixes).
- commit a57ad60
* Wed Feb 14 2024 oneukum@suse.com
- PCI: qcom: Fix potential deadlock when enabling ASPM
  (git-fixes).
- commit adc25b6
* Wed Feb 14 2024 oneukum@suse.com
- PCI: qcom: Enable ASPM for platforms supporting 1.9.0 ops
  (git-fixes).
- commit c63fc13
* Wed Feb 14 2024 oneukum@suse.com
- PCI: qcom: Use PCIE_SPEED2MBS_ENC() macro for encoding link
  speed (git-fixes).
- commit a80c081
* Wed Feb 14 2024 oneukum@suse.com
- PCI: qcom: Do not advertise hotplug capability for IP v2.1.0
  (git-fixes).
- commit 756f736
* Wed Feb 14 2024 oneukum@suse.com
- PCI: qcom: Do not advertise hotplug capability for IP v1.0.0
  (git-fixes).
- commit 00fef1b
* Wed Feb 14 2024 oneukum@suse.com
- PCI: qcom: Use post init sequence of IP v2.3.2 for v2.4.0
  (git-fixes).
- commit 2132a8c
* Wed Feb 14 2024 oneukum@suse.com
- PCI: qcom: Do not advertise hotplug capability for IP v2.3.2
  (git-fixes).
- commit 1e670bc
* Wed Feb 14 2024 oneukum@suse.com
- PCI: qcom: Do not advertise hotplug capability for IPs v2.3.3
  and v2.9.0 (git-fixes).
- commit 2b2b866
* Wed Feb 14 2024 oneukum@suse.com
- PCI: qcom: Do not advertise hotplug capability for IPs v2.7.0
  and v1.9.0 (git-fixes).
- commit c7b4716
* Wed Feb 14 2024 oneukum@suse.com
- x86/Kconfig: Transmeta Crusoe is CPU family 5, not 6
  (git-fixes).
- commit 5367630
* Wed Feb 14 2024 jgross@suse.com
- Update config files.
- commit 6ba26a3
* Wed Feb 14 2024 jgross@suse.com
- KVM x86/xen: add an override for PVCLOCK_TSC_STABLE_BIT
  (jsc#PED-7322).
- commit 737fb0e
* Wed Feb 14 2024 tbogendoerfer@suse.de
- octeontx2-af: Initialize maps (jsc#PED-6931).
- net: intel: fix old compiler regressions (jsc#PED-4874).
- octeontx2-pf: Fix a memleak otx2_sq_init (jsc#PED-6931).
- idpf: avoid compiler padding in virtchnl2_ptype struct
  (jsc#PED-6716).
- octeontx2-pf: Remove xdp queues on program detach
  (jsc#PED-6931).
- ixgbe: Fix an error handling path in
  ixgbe_read_iosf_sb_reg_x550() (jsc#PED-4872).
- e1000e: correct maximum frequency adjustment values
  (jsc#PED-4868).
- bnxt_en: Make PTP timestamp HWRM more silent (jsc#PED-5742).
- gve: Fix skb truesize underestimation (bsc#1214479).
- commit 610ddc5
* Wed Feb 14 2024 jgross@suse.com
- KVM: nSVM: Hide more stuff under CONFIG_KVM_HYPERV/CONFIG_HYPERV
  (jsc#PED-7322).
- commit c8c1c08
* Wed Feb 14 2024 msuchanek@suse.de
- kernel-binary: Move build script to the end
  All other spec templates have the build script at the end, only
  kernel-binary has it in the middle. Align with the other templates.
- commit 98cbdd0
* Wed Feb 14 2024 msuchanek@suse.de
- rpm templates: Aggregate subpackage descriptions
  While in some cases the package tags, description, scriptlets and
  filelist are located together in other cases they are all across the
  spec file. Aggregate the information related to a subpackage in one
  place.
- commit 8eeb08c
* Wed Feb 14 2024 msuchanek@suse.de
- rpm templates: sort rpm tags
  The rpm tags in kernel spec files are sorted at random.
  Make the order of rpm tags somewhat more consistent across rpm spec
  templates.
- commit 8875c35
* Wed Feb 14 2024 denis.kirjanov@suse.com
- team: Fix use-after-free when an option instance allocation
  fails (git-fixes).
- commit aa6501b
* Wed Feb 14 2024 jgross@suse.com
- KVM: nVMX: Hide more stuff under CONFIG_KVM_HYPERV (jsc#PED-7322).
- commit bc6ea0c
* Wed Feb 14 2024 denis.kirjanov@suse.com
- net: dsa: microchip: provide a list of valid protocols for
  xmit handler (git-fixes).
- commit 14ae17e
* Wed Feb 14 2024 denis.kirjanov@suse.com
- nfp: flower: fix for take a mutex lock in soft irq context
  and rcu lock (git-fixes).
- commit 8699210
* Wed Feb 14 2024 denis.kirjanov@suse.com
- net: hns: fix fake link up on xge port (git-fixes).
- commit 7b3f477
* Wed Feb 14 2024 denis.kirjanov@suse.com
- net: hns: fix wrong head when modify the tx feature when
  sending packets (git-fixes).
- commit 848eb56
* Wed Feb 14 2024 denis.kirjanov@suse.com
- net: atlantic: Fix NULL dereference of skb pointer in
  (git-fixes).
- commit bfa6175
* Wed Feb 14 2024 denis.kirjanov@suse.com
- net: stmmac: fix FPE events losing (git-fixes).
- commit 2382976
* Wed Feb 14 2024 oneukum@suse.com
- pm: Introduce DEFINE_NOIRQ_DEV_PM_OPS() helper (git-fixes).
- commit 3f9a915
* Wed Feb 14 2024 denis.kirjanov@suse.com
- net: ravb: Keep reverse order of operations in ravb_remove()
  (git-fixes).
- commit d60c1dc
* Wed Feb 14 2024 denis.kirjanov@suse.com
- net: ravb: Stop DMA in case of failures on ravb_open()
  (git-fixes).
- commit 536e15e
* Wed Feb 14 2024 oneukum@suse.com
- platform: mellanox: Cosmetic changes (git-fixes).
- commit 201fef6
* Wed Feb 14 2024 denis.kirjanov@suse.com
- net: ravb: Start TX queues after HW initialization succeeded
  (git-fixes).
- commit 67bd94d
* Wed Feb 14 2024 denis.kirjanov@suse.com
- net: ravb: Make write access to CXR35 first before accessing
  other EMAC registers (git-fixes).
- commit 2f42ed8
* Wed Feb 14 2024 denis.kirjanov@suse.com
- net: ravb: Use pm_runtime_resume_and_get() (git-fixes).
- commit f02fced
* Wed Feb 14 2024 denis.kirjanov@suse.com
- net: ravb: Check return value of reset_control_deassert()
  (git-fixes).
- commit 864deed
* Wed Feb 14 2024 denis.kirjanov@suse.com
- net: libwx: fix memory leak on msix entry (git-fixes).
- commit 159ffaa
* Wed Feb 14 2024 jgross@suse.com
- KVM: nVMX: Introduce accessor to get Hyper-V eVMCS pointer
  (jsc#PED-7322).
- commit 4c639bf
* Wed Feb 14 2024 jgross@suse.com
- KVM: nVMX: Introduce helpers to check if Hyper-V evmptr12 is
  valid/set (jsc#PED-7322).
- commit bc7347a
* Wed Feb 14 2024 jgross@suse.com
- KVM: x86: Make Hyper-V emulation optional (jsc#PED-7322).
- Update config files.
- commit 87507f6
* Wed Feb 14 2024 tiwai@suse.de
- Drop ASoC AMD ACP patch causing a regression (bsc#1219789)
- commit 1eacaea
* Wed Feb 14 2024 oneukum@suse.com
- platform/mellanox: mlxbf-bootctl: add NET dependency into
  Kconfig (git-fixes).
- commit c7f1631
* Wed Feb 14 2024 oneukum@suse.com
- platform/chrome: cros_ec_lpc: Remove EC panic shutdown timeout
  (git-fixes).
- commit d61129c
* Wed Feb 14 2024 jgross@suse.com
- KVM: nVMX: Move guest_cpuid_has_evmcs() to hyperv.h (jsc#PED-7322).
- commit 2cbad81
* Wed Feb 14 2024 jgross@suse.com
- KVM: nVMX: Split off helper for emulating VMCLEAR on Hyper-V
  eVMCS (jsc#PED-7322).
- commit 82136e4
* Wed Feb 14 2024 jgross@suse.com
- KVM: x86: Introduce helper to handle Hyper-V paravirt TLB
  flush requests (jsc#PED-7322).
- commit 92008f5
* Wed Feb 14 2024 jgross@suse.com
- KVM: VMX: Split off hyperv_evmcs.{ch} (jsc#PED-7322).
- commit 056eb46
* Wed Feb 14 2024 jgross@suse.com
- KVM: x86: Introduce helper to check if vector is set in Hyper-V
  SynIC (jsc#PED-7322).
- commit ee580aa
* Wed Feb 14 2024 jgross@suse.com
- KVM: x86: Introduce helper to check if auto-EOI is set in
  Hyper-V SynIC (jsc#PED-7322).
- commit 3628f1b
* Wed Feb 14 2024 jgross@suse.com
- KVM: VMX: Split off vmx_onhyperv.{ch} from hyperv.{ch}
  (jsc#PED-7322).
- commit a52f7d7
* Wed Feb 14 2024 jgross@suse.com
- KVM: x86: Move Hyper-V partition assist page out of Hyper-V
  emulation context (jsc#PED-7322).
- commit c274d49
* Wed Feb 14 2024 jgross@suse.com
- KVM: x86/xen: Remove unneeded xen context from kvm_arch when
  !CONFIG_KVM_XEN (jsc#PED-7322).
- commit 1a3426d
* Wed Feb 14 2024 jgross@suse.com
- KVM: x86/mmu: fix comment about mmu_unsync_pages_lock
  (jsc#PED-7322).
- commit 6927f64
* Wed Feb 14 2024 jgross@suse.com
- KVM: x86/mmu: always take tdp_mmu_pages_lock (jsc#PED-7322).
- commit 3c339d8
* Wed Feb 14 2024 jgross@suse.com
- KVM: x86/mmu: remove unnecessary "bool shared" argument from
  iterators (jsc#PED-7322).
- commit 26089fe
* Wed Feb 14 2024 jgross@suse.com
- KVM: x86/mmu: remove unnecessary "bool shared" argument from
  functions (jsc#PED-7322).
- commit 20e6465
* Wed Feb 14 2024 jgross@suse.com
- KVM: x86/mmu: Check for leaf SPTE when clearing dirty bit in
  the TDP MMU (jsc#PED-7322).
- commit 04b615d
* Wed Feb 14 2024 jgross@suse.com
- KVM: x86/mmu: Fix off-by-1 when splitting huge pages during
  CLEAR (jsc#PED-7322).
- commit ca542a6
* Wed Feb 14 2024 jgross@suse.com
- KVM: x86: Harden copying of userspace-array against overflow
  (jsc#PED-7322).
- commit 2624bb5
* Wed Feb 14 2024 jgross@suse.com
- KVM: x86/pmu: Track emulated counter events instead of previous
  counter (jsc#PED-7322).
- commit 50f3c68
* Wed Feb 14 2024 svarbanov@suse.de
- supported.conf: Add supported entry for stusb160x (bsc#1221330)
- commit d3bd091
* Wed Feb 14 2024 jgross@suse.com
- KVM: x86/pmu: Update sample period in pmc_write_counter()
  (jsc#PED-7322).
- commit b607273
* Wed Feb 14 2024 jgross@suse.com
- KVM: x86/pmu: Remove manual clearing of fields in kvm_pmu_init()
  (jsc#PED-7322).
- commit 5d80669
* Wed Feb 14 2024 jgross@suse.com
- KVM: x86/pmu: Stop calling kvm_pmu_reset() at RESET (it's
  redundant) (jsc#PED-7322).
- commit ba0d28d
* Tue Feb 13 2024 jgross@suse.com
- KVM: x86/pmu: Reset the PMU, i.e. stop counters, before
  refreshing (jsc#PED-7322).
- commit 3e9e29b
* Tue Feb 13 2024 jgross@suse.com
- KVM: x86/pmu: Move PMU reset logic to common x86 code
  (jsc#PED-7322).
- commit 4d829a7
* Tue Feb 13 2024 jgross@suse.com
- KVM: SVM,VMX: Use %%rip-relative addressing to access
  kvm_rebooting (jsc#PED-7322).
- commit 94d4ceb
* Tue Feb 13 2024 jgross@suse.com
- KVM: SVM: Don't intercept IRET when injecting NMI and vNMI is
  enabled (jsc#PED-7322).
- commit abf0f42
* Tue Feb 13 2024 jgross@suse.com
- KVM: SVM: Explicitly require FLUSHBYASID to enable SEV support
  (jsc#PED-7322).
- commit 51dc0ef
* Tue Feb 13 2024 jgross@suse.com
- KVM: nSVM: Advertise support for flush-by-ASID (jsc#PED-7322).
- commit d96ff28
* Tue Feb 13 2024 jgross@suse.com
- Revert "nSVM: Check for reserved encodings of TLB_CONTROL in
  nested VMCB" (jsc#PED-7322).
- commit 733d5b1
* Tue Feb 13 2024 jgross@suse.com
- KVM: x86: Don't unnecessarily force masterclock update on vCPU
  hotplug (jsc#PED-7322).
- commit e2477e4
* Tue Feb 13 2024 jgross@suse.com
- KVM: x86: Use a switch statement and macros in
  __feature_translate() (jsc#PED-7322).
- commit 26af95a
* Tue Feb 13 2024 jgross@suse.com
- KVM: x86: Advertise CPUID.(EAX=7,ECX=2):EDX[5:0] to userspace
  (jsc#PED-7322).
- commit 8de3668
* Tue Feb 13 2024 colyli@suse.de
- dm: limit the number of targets and parameter size area
  (bsc#1219827, bsc#1219146, CVE-2023-52429, CVE-2024-23851).
- commit 7512798
* Tue Feb 13 2024 jgross@suse.com
- KVM: x86: Turn off KVM_WERROR by default for all configs
  (jsc#PED-7322).
- commit 427cbaf
* Tue Feb 13 2024 jgross@suse.com
- KVM: x86/mmu: Declare flush_remote_tlbs{_range}() hooks iff
  HYPERV!=n (jsc#PED-7322).
- commit 47fe30a
* Tue Feb 13 2024 mkoutny@suse.com
- mm: memcontrol: don't throttle dying tasks on memory.high
  (bsc#1219889).
- kernel/fork: beware of __put_task_struct() calling context
  (bsc#1216761).
- commit e3538e2
* Tue Feb 13 2024 jgross@suse.com
- KVM: x86: Use KVM-governed feature framework to track "LAM
  enabled" (jsc#PED-7322).
- commit e0b7547
* Tue Feb 13 2024 svarbanov@suse.de
- docs/perf: Add ampere_cspmu to toctree to fix a build warning (jsc#PED-7859)
- commit 5a39b75
* Tue Feb 13 2024 jgross@suse.com
- KVM: x86: Advertise and enable LAM (user and supervisor)
  (jsc#PED-7322).
- commit be96f66
* Tue Feb 13 2024 jgross@suse.com
- KVM: x86: Virtualize LAM for user pointer (jsc#PED-7322).
- commit 51ea9b3
* Tue Feb 13 2024 jgross@suse.com
- KVM: x86: Virtualize LAM for supervisor pointer (jsc#PED-7322).
- commit 4719d36
* Tue Feb 13 2024 svarbanov@suse.de
- perf vendor events arm64 AmpereOneX: Add core PMU events and metrics (jsc#PED-7859)
- commit 8763e5d
* Tue Feb 13 2024 denis.kirjanov@suse.com
- netdevsim: Don't accept device bound programs (git-fixes).
- commit c28704b
* Tue Feb 13 2024 denis.kirjanov@suse.com
- ravb: Fix races between ravb_tx_timeout_work() and net related
  ops (git-fixes).
- commit ca1ed03
* Tue Feb 13 2024 denis.kirjanov@suse.com
- r8169: prevent potential deadlock in rtl8169_close (git-fixes).
- commit c6c74b1
* Tue Feb 13 2024 denis.kirjanov@suse.com
- r8169: fix deadlock on RTL8125 in jumbo mtu mode (git-fixes).
- commit 350e699
* Tue Feb 13 2024 denis.kirjanov@suse.com
- net: stmmac: xgmac: Disable FPE MMC interrupts (git-fixes).
- commit 4d4a44e
* Tue Feb 13 2024 denis.kirjanov@suse.com
- dpaa2-eth: recycle the RX buffer only after all processing done
  (git-fixes).
- commit 6f9cf91
* Tue Feb 13 2024 jgross@suse.com
- KVM: x86: Untag addresses for LAM emulation where applicable
  (jsc#PED-7322).
- commit 3aca57c
* Tue Feb 13 2024 denis.kirjanov@suse.com
- dpaa2-eth: increase the needed headroom to account for alignment
  (git-fixes).
- commit aeead7c
* Tue Feb 13 2024 denis.kirjanov@suse.com
- net: rswitch: Fix missing dev_kfree_skb_any() in error path
  (git-fixes).
- commit dfab415
* Tue Feb 13 2024 denis.kirjanov@suse.com
- net: rswitch: Fix return value in rswitch_start_xmit()
  (git-fixes).
- commit 3061c1f
* Tue Feb 13 2024 denis.kirjanov@suse.com
- net: rswitch: Fix type of ret in rswitch_start_xmit()
  (git-fixes).
- commit 3bd4f02
* Tue Feb 13 2024 denis.kirjanov@suse.com
- net: ipa: fix one GSI register field width (git-fixes).
- commit 57e43ae
* Tue Feb 13 2024 denis.kirjanov@suse.com
- net: axienet: Fix check for partial TX checksum (git-fixes).
- commit 765d022
* Tue Feb 13 2024 denis.kirjanov@suse.com
- amd-xgbe: propagate the correct speed and duplex status
  (git-fixes).
- commit ca7f648
* Tue Feb 13 2024 denis.kirjanov@suse.com
- amd-xgbe: handle the corner-case during tx completion
  (git-fixes).
- commit 05c99da
* Tue Feb 13 2024 denis.kirjanov@suse.com
- amd-xgbe: handle corner-case during sfp hotplug (git-fixes).
- commit 63bb25f
* Tue Feb 13 2024 denis.kirjanov@suse.com
- net: veth: fix ethtool stats reporting (git-fixes).
- commit 40065a7
* Tue Feb 13 2024 denis.kirjanov@suse.com
- wireguard: use DEV_STATS_INC() (git-fixes).
- commit c56067d
* Tue Feb 13 2024 denis.kirjanov@suse.com
- net: wangxun: fix kernel panic due to null pointer (git-fixes).
- commit cc57ffc
* Tue Feb 13 2024 jgross@suse.com
- KVM: x86: Introduce get_untagged_addr() in kvm_x86_ops and
  call it in emulator (jsc#PED-7322).
- Refresh
  patches.suse/KVM-SEV-Make-AVIC-backing-VMSA-and-VMCB-memory-allocation-SNP-sa.
- commit db34c34
* Tue Feb 13 2024 denis.kirjanov@suse.com
- stmmac: dwmac-loongson: Add architecture dependency (git-fixes).
- commit 746bbc5
* Tue Feb 13 2024 denis.kirjanov@suse.com
- macvlan: Don't propagate promisc change to lower dev in passthru
  (git-fixes).
- commit ad66810
* Tue Feb 13 2024 denis.kirjanov@suse.com
- pds_core: use correct index to mask irq (git-fixes).
- commit f2391e5
* Tue Feb 13 2024 denis.kirjanov@suse.com
- net: stmmac: avoid rx queue overrun (git-fixes).
- commit 3a28d91
* Tue Feb 13 2024 denis.kirjanov@suse.com
- net: stmmac: fix rx budget limit check (git-fixes).
- commit 739b241
* Tue Feb 13 2024 jgross@suse.com
- KVM: x86: Remove kvm_vcpu_is_illegal_gpa() (jsc#PED-7322).
- commit 214f40f
* Tue Feb 13 2024 jgross@suse.com
- KVM: x86: Add & use kvm_vcpu_is_legal_cr3() to check CR3's
  legality (jsc#PED-7322).
- commit 0ea18e6
* Tue Feb 13 2024 jgross@suse.com
- KVM: x86/mmu: Drop non-PA bits when getting GFN for guest's PGD
  (jsc#PED-7322).
- commit a7a4e2c
* Tue Feb 13 2024 jgross@suse.com
- KVM: x86: Add X86EMUL_F_INVLPG and pass it in em_invlpg()
  (jsc#PED-7322).
- commit 469975b
* Tue Feb 13 2024 jgross@suse.com
- KVM: x86: Add an emulation flag for implicit system access
  (jsc#PED-7322).
- commit d9485ea
* Tue Feb 13 2024 jgross@suse.com
- KVM: x86: Consolidate flags for __linearize() (jsc#PED-7322).
- commit bc10a7d
* Tue Feb 13 2024 tonyj@suse.de
- tools arch x86: Sync the msr-index.h copy with the
  kernel sources to pick IA32_MKTME_KEYID_PARTITIONING
  (perf-sync-headers).
- Delete
  patches.suse/sync-tools-arch-header-for-support-branch-counters-logging.patch.
- commit 4348ec9
* Tue Feb 13 2024 tonyj@suse.de
- tools headers x86 cpufeatures: Sync with the kernel sources
  to pick TDX, Zen, APIC MSR fence changes (perf-sync-headers).
- commit 13aa64d
* Tue Feb 13 2024 tonyj@suse.de
- perf evlist: Fix evlist__new_default() for > 1 core PMU
  (git-fixes).
- perf db-export: Fix missing reference count get in
  call_path_from_sample() (git-fixes).
- perf stat: Fix hard coded LL miss units (git-fixes).
- perf env: Avoid recursively taking env->bpf_progs.lock
  (git-fixes).
- perf vendor events: Remove UTF-8 characters from cmn.json
  (git-fixes).
- perf unwind-libunwind: Fix base address for .eh_frame
  (git-fixes).
- perf unwind-libdw: Handle JIT-generated DSOs properly
  (git-fixes).
- perf genelf: Set ELF program header addresses properly
  (git-fixes).
- perf hisi-ptt: Fix one memory leakage in
  hisi_ptt_process_auxtrace_event() (git-fixes).
- perf header: Fix one memory leakage in
  perf_event__fprintf_event_update() (git-fixes).
- perf stat: Fix help message for --metric-no-threshold option
  (git-fixes).
- perf stat: Exit perf stat if parse groups fails (git-fixes).
- perf mem: Fix error on hybrid related to availability of mem
  event in a PMU (git-fixes).
- perf vendor events powerpc: Update datasource event name to
  fix duplicate events (git-fixes).
- perf vendor events arm64 AmpereOne: Rename BPU_FLUSH_MEM_FAULT
  to GPC_FLUSH_MEM_FAULT (git-fixes).
- perf test record user-regs: Fix mask for vg register
  (git-fixes).
- perf docs: Fix man page formatting for 'perf lock' (git-fixes).
- perf test record+probe_libc_inet_pton: Fix call chain match
  on powerpc (bsc#1218986).
- perf tests: Skip pipe test if noploop symbol is missing
  (bsc#1219617).
- perf tests lib: Add perf_has_symbol.sh (bsc#1219617).
- perf header: Fix segfault on build_mem_topology() error path
  (git-fixes).
- perf test: Remove atomics from test_loop to avoid test failures
  (git-fixes).
- commit a32b1b0
* Mon Feb 12 2024 tiwai@suse.de
- Update config files: disable broken ATOMISP drivers (bsc#1210639)
  It's been broken over a year, better to disable it before hitting another victim
- commit a1a6906
* Mon Feb 12 2024 ohering@suse.de
- hv_netvsc: Register VF in netvsc_probe if NET_DEVICE_REGISTER
  missed (git-fixes).
- hv_netvsc: Fix race condition between netvsc_probe and
  netvsc_remove (git-fixes).
- scsi: storvsc: Fix ring buffer size calculation (git-fixes).
- hv_netvsc: Calculate correct ring size when PAGE_SIZE is not
  4 Kbytes (git-fixes).
- commit 721575c
* Mon Feb 12 2024 mfranc@suse.cz
- s390/scm: fix virtual vs physical address confusion (git-fixes
  bsc#1219816).
- commit d8288d6
* Mon Feb 12 2024 mfranc@suse.cz
- s390/boot: always align vmalloc area on segment boundary
  (git-fixes bsc#1219815).
- commit 08905ad
* Mon Feb 12 2024 mfranc@suse.cz
- s390/vfio-ap: fix sysfs status attribute for AP queue devices
  (git-fixes bsc#1219814).
- commit 2f4c817
* Mon Feb 12 2024 mfranc@suse.cz
- s390/ptrace: handle setting of fpc register correctly (git-fixes
  bsc#1219812).
- commit be5b93a
* Mon Feb 12 2024 mfranc@suse.cz
- s390/qeth: Fix potential loss of L3-IP@ in case of network
  issues (git-fixes bsc#1219811).
- commit 32d0fc0
* Mon Feb 12 2024 nik.borisov@suse.com
- Reference recently released CVE
- Update
  patches.suse/x86-coco-Disable-32-bit-emulation-by-default-on-TDX-.patch
  (jsc#PED-7322 CVE-2024-25744).
- Update
  patches.suse/x86-entry-convert-int-0x80-emulation-to-idtentry.patch
  (bsc#1217927 CVE-2024-25744).
- Update
  patches.suse/x86-entry-do-not-allow-external-0x80-interrupts.patch
  (bsc#1217927 CVE-2024-25744).
- Update
  patches.suse/x86-tdx-Allow-32-bit-emulation-by-default.patch
  (jsc#PED-7322 CVE-2024-25744).
- commit 06d4b38
* Mon Feb 12 2024 mfranc@suse.cz
- KVM: s390: vsie: fix race during shadow creation (git-fixes
  bsc#1219810).
- commit 8180746
* Mon Feb 12 2024 mfranc@suse.cz
- KVM: s390: fix setting of fpc register (git-fixes bsc#1219809).
- commit 478f49e
* Mon Feb 12 2024 mfranc@suse.cz
- KVM: s390: fix cc for successful PQAP (git-fixes bsc#1219808).
- commit 51e5204
* Mon Feb 12 2024 mfranc@suse.cz
- KVM: s390: add stat counter for shadow gmap events
  (jsc#PED-5439).
- commit 256c0f9
* Mon Feb 12 2024 mfranc@suse.cz
- KVM: s390: add tracepoint in gmap notifier (jsc#PED-5439).
- commit 06f0c94
* Mon Feb 12 2024 dwagner@suse.de
- nvme-host: fix the updating of the firmware version (git-fixes).
- commit 9bc381c
* Mon Feb 12 2024 nik.borisov@suse.com
- x86/MCE: Always save CS register on AMD Zen IF Poison errors (git-fixes).
- commit 63e2bb6
* Mon Feb 12 2024 nik.borisov@suse.com
- x86/entry/ia32: Ensure s32 is sign extended to s64 (git-fixes).
- commit d1f7bea
* Mon Feb 12 2024 nik.borisov@suse.com
- x86/srso: Move retbleed IBPB check into existing 'has_microcode' code  block (git-fixes).
- commit b594e28
* Mon Feb 12 2024 nik.borisov@suse.com
- x86/srso: Print mitigation for retbleed IBPB case (git-fixes).
- Refresh
  patches.suse/x86-srso-fix-vulnerability-reporting-for-missing-microcode.patch.
- commit 5b45539
* Mon Feb 12 2024 nik.borisov@suse.com
- x86/purgatory: Remove LTO flags (git-fixes).
- commit 215c902
* Mon Feb 12 2024 nik.borisov@suse.com
- x86/kvm: Do not try to disable kvmclock if it was not enabled (git-fixes).
- commit 0a9eee3
* Sat Feb 10 2024 lduncan@suse.com
- scsi: fnic: unlock on error path in fnic_queuecommand()
  (git-fixes).
- commit af1e53a
* Sat Feb 10 2024 denis.kirjanov@suse.com
- net: ethernet: cortina: Drop TSO support (git-fixes).
- commit 1041212
* Sat Feb 10 2024 iivanov@suse.de
- Update patches.suse/arm64-errata-Add-Cortex-A520-speculative-unprivilege.patch (git-fixes, bsc#1219443)
  Add reference to bsc#1219443.
- commit b300257
* Sat Feb 10 2024 iivanov@suse.de
- arm64: errata: Add Cortex-A510 speculative unprivileged load (bsc#1219443)
  Enable erratum workaround.
- commit b26ca40
* Sat Feb 10 2024 denis.kirjanov@suse.com
- r8169: fix network lost after resume on DASH systems
  (git-fixes).
- commit c170312
* Sat Feb 10 2024 denis.kirjanov@suse.com
- r8169: add handling DASH when DASH is disabled (git-fixes).
- commit 43f9a07
* Sat Feb 10 2024 denis.kirjanov@suse.com
- net: ethernet: cortina: Fix MTU max setting (git-fixes).
- commit cdfb94f
* Sat Feb 10 2024 denis.kirjanov@suse.com
- net: ethernet: cortina: Handle large frames (git-fixes).
- commit 76e929a
* Sat Feb 10 2024 denis.kirjanov@suse.com
- net: ethernet: cortina: Fix max RX frame define (git-fixes).
- commit 1807254
* Sat Feb 10 2024 denis.kirjanov@suse.com
- bonding: stop the device in bond_setup_by_slave() (git-fixes).
- commit 072954c
* Sat Feb 10 2024 denis.kirjanov@suse.com
- ppp: limit MRU to 64K (git-fixes).
- commit 80ad17a
* Sat Feb 10 2024 denis.kirjanov@suse.com
- net: mvneta: fix calls to page_pool_get_stats (git-fixes).
- commit 73be237
* Sat Feb 10 2024 denis.kirjanov@suse.com
- net: hns3: fix VF wrong speed and duplex issue (git-fixes).
- commit 01a4b9c
* Sat Feb 10 2024 tiwai@suse.de
- net: phy: realtek: add 5Gbps support to rtl822x_config_aneg()
  (bsc#1217417).
- net: phy: realtek: use generic MDIO constants (bsc#1217417).
- net: mdio: add 2.5g and 5g related PMA speed constants
  (bsc#1217417).
- commit 51b8f13
* Sat Feb 10 2024 tiwai@suse.de
- hwmon: (coretemp) Fix bogus core_id to attr name mapping
  (git-fixes).
- hwmon: (coretemp) Fix out-of-bounds memory access (git-fixes).
- hwmon: (aspeed-pwm-tacho) mutex for tach reading (git-fixes).
- mmc: sdhci-pci-o2micro: Fix a warm reboot issue that disk
  can't be detected by BIOS (git-fixes).
- drm/i915/gvt: Fix uninitialized variable in handle_mmio()
  (git-fixes).
- commit fb6968f
* Fri Feb  9 2024 lduncan@suse.com
- scsi: fnic: Increment driver version (jsc#PED-7888).
- scsi: fnic: Improve logs and add support for multiqueue (MQ)
  (jsc#PED-7888).
- scsi: fnic: Add support for multiqueue (MQ) in fnic driver
  (jsc#PED-7888).
- scsi: fnic: Add support for multiqueue (MQ) in fnic_main.c
  (jsc#PED-7888).
- scsi: fnic: Remove usage of host_lock (jsc#PED-7888).
- scsi: fnic: Define stats to track multiqueue (MQ) IOs
  (jsc#PED-7888).
- scsi: fnic: Modify ISRs to support multiqueue (MQ)
  (jsc#PED-7888).
- commit 4ae8e51
* Fri Feb  9 2024 lduncan@suse.com
- scsi: fnic: Refactor and redefine fnic.h for multiqueue
  (jsc#PED-7888).
- Refresh
  patches.suse/fnic-move-fnic_fnic_flush_tx-to-a-work-queue.patch.
- commit 5d5bc93
* Fri Feb  9 2024 lduncan@suse.com
- scsi: fnic: Get copy workqueue count and interrupt mode from
  config (jsc#PED-7888).
- scsi: fnic: Rename wq_copy to hw_copy_wq (jsc#PED-7888).
- scsi: fnic: Add and improve log messages (jsc#PED-7888).
- scsi: fnic: Add and use fnic number (jsc#PED-7888).
- scsi: fnic: Modify definitions to sync with VIC firmware
  (jsc#PED-7888).
- commit 4104ea5
* Fri Feb  9 2024 denis.kirjanov@suse.com
- net: hns3: fix VF reset fail issue (git-fixes).
- commit 357e0c0
* Fri Feb  9 2024 denis.kirjanov@suse.com
- net: hns3: fix variable may not initialized problem in
  hns3_init_mac_addr() (git-fixes).
- commit 761dece
* Fri Feb  9 2024 denis.kirjanov@suse.com
- net: hns3: fix out-of-bounds access may occur when coalesce
  info is read via debugfs (git-fixes).
- commit 9368f32
* Fri Feb  9 2024 denis.kirjanov@suse.com
- net: hns3: fix incorrect capability bit display for copper port
  (git-fixes).
- commit 7b8e42d
* Fri Feb  9 2024 denis.kirjanov@suse.com
- net: hns3: add barrier in vf mailbox reply process (git-fixes).
- commit deb564c
* Fri Feb  9 2024 denis.kirjanov@suse.com
- net: hns3: fix add VLAN fail issue (git-fixes).
- commit 6ae1571
* Fri Feb  9 2024 denis.kirjanov@suse.com
- ipvlan: add ipvlan_route_v6_outbound() helper (git-fixes).
- commit 5f2d3b6
* Fri Feb  9 2024 denis.kirjanov@suse.com
- net: enetc: shorten enetc_setup_xdp_prog() error message to
  fit NETLINK_MAX_FMTMSG_LEN (git-fixes).
- commit f882476
* Fri Feb  9 2024 denis.kirjanov@suse.com
- net: sfp: add quirk for FS's 2.5G copper SFP (git-fixes).
- commit eb7d824
* Fri Feb  9 2024 tiwai@suse.de
- driver core: Replace kstrdup() + strreplace() with
  kstrdup_and_replace() (jsc#PED-6054 bsc#1219692).
- lib/string_helpers: Add kstrdup_and_replace() helper
  (jsc#PED-6054 bsc#1219692).
- commit d4a62fc
* Fri Feb  9 2024 denis.kirjanov@suse.com
- net: ethernet: mtk_wed: fix EXT_INT_STATUS_RX_FBUF definitions
  for MT7986 SoC (git-fixes).
- commit be286c4
* Fri Feb  9 2024 denis.kirjanov@suse.com
- net: spider_net: Use size_add() in call to struct_size()
  (git-fixes).
- commit 722bf2b
* Fri Feb  9 2024 tiwai@suse.de
- lib/string_helpers: Change returned value of the strreplace()
  (bsc#1219692).
- jbd2: Avoid printing outside the boundary of the buffer
  (bsc#1219692).
- commit 8aa13d7
* Fri Feb  9 2024 denis.kirjanov@suse.com
- mlxsw: Use size_mul() in call to struct_size() (git-fixes).
- commit a527704
* Fri Feb  9 2024 denis.kirjanov@suse.com
- net: ethernet: adi: adin1110: Fix uninitialized variable
  (git-fixes).
- commit 4905ac5
* Fri Feb  9 2024 denis.kirjanov@suse.com
- net: mdio-mux: fix C45 access returning -EIO after API change
  (git-fixes).
- commit 8842ac4
* Fri Feb  9 2024 denis.kirjanov@suse.com
- net: dsa: bcm_sf2: Fix possible memory leak in
  bcm_sf2_mdio_register() (git-fixes).
- commit 8a76104
* Fri Feb  9 2024 denis.kirjanov@suse.com
- team: fix null-ptr-deref when team device type is changed
  (git-fixes).
- commit c07a0c7
* Fri Feb  9 2024 denis.kirjanov@suse.com
- net: fec: use netdev_err_once() instead of netdev_err()
  (git-fixes).
- commit 45e8d45
* Fri Feb  9 2024 tiwai@suse.de
- wifi: iwlwifi: exit eSR only after the FW does (git-fixes).
- wifi: mac80211: fix waiting for beacons logic (git-fixes).
- wifi: mac80211: fix RCU use in TDLS fast-xmit (git-fixes).
- wifi: cfg80211: fix wiphy delayed work queueing (git-fixes).
- wifi: iwlwifi: fix double-free bug (git-fixes).
- selftests: cmsg_ipv6: repeat the exact packet (git-fixes).
- selftests: net: let big_tcp test cope with slow env (git-fixes).
- atm: idt77252: fix a memleak in open_card_ubr0 (git-fixes).
- selftests: net: avoid just another constant wait (git-fixes).
- selftests: net: cut more slack for gro fwd tests (git-fixes).
- crypto: algif_hash - Remove bogus SGL free on zero-length
  error path (git-fixes).
- crypto: ccp - Fix null pointer dereference in
  __sev_platform_shutdown_locked (git-fixes).
- commit f9fa694
* Thu Feb  8 2024 msuchanek@suse.de
- kernel-binary: certs: Avoid trailing space
- commit bc7dc31
* Thu Feb  8 2024 tiwai@suse.de
- Drop the driver core change that caused memory corruption (bsc#1219692 bsc#1219732)
  patches.suse/driver-core-Replace-kstrdup-strreplace-with-kstrdup_.patch
  required the change of strreplace() API behavior as an implicit prerequiste
- commit 9bd691b
* Thu Feb  8 2024 mgorman@suse.de
- sched: fair: move unused stub functions to header (git fixes
  (sched)).
- sched/fair: Fix the decision for load balance (git fixes
  (sched)).
- sched/core: Fix RQCF_ACT_SKIP leak (git fixes (sched)).
- commit ec9d436
* Thu Feb  8 2024 vkarasulli@suse.de
- Update
  patches.suse/Bluetooth-Fix-atomicity-violation-in-min-max-_key_si.patch
  (git-fixes bsc#1219608 CVE-2024-24860).
- commit 060d07f
* Thu Feb  8 2024 vbabka@suse.cz
- Update
  patches.suse/mm-lock_vma_under_rcu-must-check-vma-anon_vma-.patch
  (bsc#1012628 per-VMA_lock_fix CVE-2024-1312 bsc#1219731).
- commit 91e52e6
* Thu Feb  8 2024 nik.borisov@suse.com
- Refresh patches.suse/RAS-AMD-ATL-Add-MI300-support.patch.
  Fix min() related warning.
- commit 7a6c291
* Wed Feb  7 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Fix-potential-fence-use-after-free-.patch
  (bsc#1219128 CVE-2023-51042 jsc#PED-3527 jsc#PED-5475
  jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- commit 72ce736
* Wed Feb  7 2024 svarbanov@suse.de
- iommu: Don't reserve 0-length IOVA region (git-fixes)
- commit d83c0fa
* Wed Feb  7 2024 jslaby@suse.cz
- rpm/kernel-binary.spec.in: install scripts/gdb when enabled in config
  (bsc#1219653)
  They are put into -devel subpackage. And a proper link to
  /usr/share/gdb/auto-load/ is created.
- commit 1dccf2a
* Wed Feb  7 2024 fweisbecker@suse.de
- fs/buffer.c: disable per-CPU buffer_head cache for isolated (bsc#1219631)
- commit 55bb990
* Wed Feb  7 2024 nik.borisov@suse.com
- EDAC/amd64: Add MI300 row retirement support (jsc#PED-7618).
- commit 36c2567
* Wed Feb  7 2024 nik.borisov@suse.com
- RAS/AMD/ATL: Add MI300 DRAM to normalized address translation support (jsc#PED-7618).
- commit 76938a8
* Wed Feb  7 2024 nik.borisov@suse.com
- RAS/AMD/ATL: Fix array overflow in get_logical_coh_st_fabric_id_mi300() (jsc#PED-7618).
- commit d6d16c5
* Wed Feb  7 2024 nik.borisov@suse.com
- RAS/AMD/ATL: Add MI300 support (jsc#PED-7618).
- commit c9f0c56
* Wed Feb  7 2024 nik.borisov@suse.com
- Documentation: RAS: Add index and address translation section (jsc#PED-7618).
- commit f894cc4
* Wed Feb  7 2024 nik.borisov@suse.com
- EDAC/amd64: Use new AMD Address Translation Library (jsc#PED-7618).
- commit 22937f8
* Wed Feb  7 2024 nik.borisov@suse.com
- RAS: Introduce AMD Address Translation Library (jsc#PED-7618).
- commit 2857e01
* Tue Feb  6 2024 denis.kirjanov@suse.com
- netfilter: nf_tables: check if catch-all set element is active
  in next generation (CVE-2024-1085 bsc#1219429).
- commit c4588a6
* Tue Feb  6 2024 vbabka@suse.cz
- mm/writeback: fix possible divide-by-zero in wb_dirty_limits(),
  again (git-fixes).
- commit 5ddccd0
* Tue Feb  6 2024 vbabka@suse.cz
- mm: migrate: fix getting incorrect page mapping during page
  migration (git-fixes).
- commit 54204d1
* Tue Feb  6 2024 vbabka@suse.cz
- mm: migrate: record the mlocked page status to remove
  unnecessary lru drain (git-fixes).
- commit 1782112
* Tue Feb  6 2024 vbabka@suse.cz
- mm/gup: fix follow_devmap_pd() on page==NULL handling
  (git-fixes).
- commit 3518c0e
* Tue Feb  6 2024 vbabka@suse.cz
- mm: page_alloc: unreserve highatomic page blocks before oom
  (git-fixes).
- commit 61457c0
* Tue Feb  6 2024 vbabka@suse.cz
- mm: page_alloc: enforce minimum zone size to do high atomic
  reserves (git-fixes).
- commit 4f2bf1e
* Tue Feb  6 2024 vbabka@suse.cz
- mm: page_alloc: correct high atomic reserve calculations
  (git-fixes).
- commit 5a4ddfb
* Tue Feb  6 2024 vbabka@suse.cz
- mm: fix unmap_mapping_range high bits shift bug (git-fixes).
- commit 7453200
* Tue Feb  6 2024 vbabka@suse.cz
- mm/shmem: fix race in shmem_undo_range w/THP (git-fixes).
- commit 6a39858
* Tue Feb  6 2024 vbabka@suse.cz
- mm: fix for negative counter: nr_file_hugepages (git-fixes).
- commit db03bb0
* Tue Feb  6 2024 vbabka@suse.cz
- mm: fix unaccount of memory on vma_link() failure (git-fixes).
- commit 8c916f3
* Tue Feb  6 2024 vbabka@suse.cz
- mm/mremap: fix unaccount of memory on vma_merge() failure
  (git-fixes).
- commit 1139c35
* Tue Feb  6 2024 vbabka@suse.cz
- mm: zswap: fix pool refcount bug around shrink_worker()
  (git-fixes).
- commit ae8fafe
* Tue Feb  6 2024 vbabka@suse.cz
- mm/migrate: fix do_pages_move for compat pointers (git-fixes).
- commit d66394c
* Tue Feb  6 2024 vbabka@suse.cz
- mm: mempolicy: keep VMA walk if both MPOL_MF_STRICT and
  MPOL_MF_MOVE are specified (git-fixes).
- commit d9dbc78
* Tue Feb  6 2024 vbabka@suse.cz
- slab: kmalloc_size_roundup() must not return 0 for non-zero size
  (git-fixes).
- commit 4566078
* Tue Feb  6 2024 vbabka@suse.cz
- mm/slab_common: fix slab_caches list corruption after
  kmem_cache_destroy() (git-fixes).
- commit 5566bfb
* Tue Feb  6 2024 denis.kirjanov@suse.com
- netfilter: nf_tables: reject QUEUE/DROP verdict parameters
  (CVE-2024-1086 bsc#1219434).
- commit 459b678
* Tue Feb  6 2024 jroedel@suse.de
- KVM: x86: Add support for "protected VMs" that can utilize
  private memory (jsc#PED-5122).
- Update config files.
- commit 646dbdf
* Tue Feb  6 2024 fweisbecker@suse.de
- tick/sched: Preserve number of idle sleeps across CPU hotplug (git-fixes)
- commit 60b5ecb
* Tue Feb  6 2024 jroedel@suse.de
- KVM: Convert KVM_ARCH_WANT_MMU_NOTIFIER to
  CONFIG_KVM_GENERIC_MMU_NOTIFIER (jsc#PED-5122).
- Update config files.
- commit dd9b571
* Tue Feb  6 2024 jroedel@suse.de
- KVM: x86: add missing "depends on KVM" (jsc#PED-5122).
- KVM: guest-memfd: fix unused-function warning (jsc#PED-5122).
- KVM: Allow arch code to track number of memslot address spaces
  per VM (jsc#PED-5122).
- KVM: Drop superfluous __KVM_VCPU_MULTIPLE_ADDRESS_SPACE macro
  (jsc#PED-5122).
- KVM: x86/mmu: Handle page fault for private memory
  (jsc#PED-5122).
- KVM: x86: Disallow hugepages when memory attributes are mixed
  (jsc#PED-5122).
- KVM: x86: "Reset" vcpu->run->exit_reason early in KVM_RUN
  (jsc#PED-5122).
- KVM: Add KVM_CREATE_GUEST_MEMFD ioctl() for guest-specific
  backing memory (jsc#PED-5122).
- fs: Rename anon_inode_getfile_secure() and
  anon_inode_getfd_secure() (jsc#PED-5122).
- mm: Add AS_UNMOVABLE to mark mapping as completely unmovable
  (jsc#PED-5122).
- KVM: Introduce per-page memory attributes (jsc#PED-5122).
- KVM: Drop .on_unlock() mmu_notifier hook (jsc#PED-5122).
- KVM: Add a dedicated mmu_notifier flag for reclaiming freed
  memory (jsc#PED-5122).
- KVM: Add KVM_EXIT_MEMORY_FAULT exit to report faults to
  userspace (jsc#PED-5122).
- KVM: Introduce KVM_SET_USER_MEMORY_REGION2 (jsc#PED-5122).
- KVM: PPC: Return '1' unconditionally for KVM_CAP_SYNC_MMU
  (jsc#PED-5122).
- KVM: PPC: Drop dead code related to KVM_ARCH_WANT_MMU_NOTIFIER
  (jsc#PED-5122).
- KVM: WARN if there are dangling MMU invalidations at VM
  destruction (jsc#PED-5122).
- KVM: Use gfn instead of hva for mmu_notifier_retry
  (jsc#PED-5122).
- KVM: Assert that mmu_invalidate_in_progress *never* goes
  negative (jsc#PED-5122).
- KVM: Tweak kvm_hva_range and hva_handler_t to allow reusing
  for gfn ranges (jsc#PED-5122).
- commit 5a43605
* Tue Feb  6 2024 svarbanov@suse.de
- perf: arm_cspmu: ampere_cspmu: Add support for Ampere SoC PMU (jsc#PED-7859)
- commit 1242994
* Tue Feb  6 2024 svarbanov@suse.de
- perf: arm_cspmu: Support implementation specific validation (jsc#PED-7859)
- commit 36b0b74
* Tue Feb  6 2024 svarbanov@suse.de
- perf: arm_cspmu: Support implementation specific filters (jsc#PED-7859)
- commit d78d04c
* Tue Feb  6 2024 svarbanov@suse.de
- perf: arm_cspmu: Split 64-bit write to 32-bit writes (jsc#PED-7859)
- commit ae4b62f
* Tue Feb  6 2024 svarbanov@suse.de
- perf: arm_cspmu: Separate Arm and vendor module (jsc#PED-7859)
- commit d997aaf
* Tue Feb  6 2024 jroedel@suse.de
- x86/CPU/AMD: Add X86_FEATURE_ZEN1 (jsc#PED-5122).
- commit 91f26ba
* Tue Feb  6 2024 ailiop@suse.com
- reiserfs: Avoid touching renamed directory if parent does not
  change (git-fixes).
- commit 1175a85
* Tue Feb  6 2024 ailiop@suse.com
- afs: fix the usage of read_seqbegin_or_lock() in
  afs_find_server*() (git-fixes).
- commit 81e58a2
* Tue Feb  6 2024 ailiop@suse.com
- afs: fix the usage of read_seqbegin_or_lock() in
  afs_lookup_volume_rcu() (git-fixes).
- commit 17037c1
* Tue Feb  6 2024 ailiop@suse.com
- jfs: fix array-index-out-of-bounds in diNewExt (git-fixes).
- commit 924a4d7
* Tue Feb  6 2024 ailiop@suse.com
- jfs: fix uaf in jfs_evict_inode (git-fixes).
- commit 4a45faa
* Tue Feb  6 2024 ailiop@suse.com
- jfs: fix array-index-out-of-bounds in dbAdjTree (git-fixes).
- commit 8299bf8
* Tue Feb  6 2024 ailiop@suse.com
- jfs: fix slab-out-of-bounds Read in dtSearch (git-fixes).
- commit 1662dc0
* Tue Feb  6 2024 ailiop@suse.com
- UBSAN: array-index-out-of-bounds in dtSplitRoot (git-fixes).
- commit 40de905
* Tue Feb  6 2024 ailiop@suse.com
- FS:JFS:UBSAN:array-index-out-of-bounds in dbAdjTree (git-fixes).
- commit cfc648a
* Tue Feb  6 2024 jroedel@suse.de
- x86/cpufeatures: Add SEV-SNP CPU feature (jsc#PED-5122).
- Refresh patches.suse/kabi-reserve-cpuid-leaves.patch.
- commit ecc8bfa
* Tue Feb  6 2024 jroedel@suse.de
- crypto: ccp: Add the SNP_SET_CONFIG command (jsc#PED-5122).
- crypto: ccp: Add the SNP_COMMIT command (jsc#PED-5122).
- crypto: ccp: Add the SNP_PLATFORM_STATUS command (jsc#PED-5122).
- x86/cpufeatures: Enable/unmask SEV-SNP CPU feature
  (jsc#PED-5122).
- KVM: SEV: Make AVIC backing, VMSA and VMCB memory allocation
  SNP safe (jsc#PED-5122).
- crypto: ccp: Add panic notifier for SEV/SNP firmware shutdown
  on kdump (jsc#PED-5122).
- iommu/amd: Clean up RMP entries for IOMMU pages during SNP
  shutdown (jsc#PED-5122).
- crypto: ccp: Handle legacy SEV commands when SNP is enabled
  (jsc#PED-5122).
- crypto: ccp: Handle non-volatile INIT_EX data when SNP is
  enabled (jsc#PED-5122).
- crypto: ccp: Handle the legacy TMR allocation when SNP is
  enabled (jsc#PED-5122).
- x86/sev: Introduce an SNP leaked pages list (jsc#PED-5122).
- crypto: ccp: Provide an API to issue SEV and SNP commands
  (jsc#PED-5122).
- crypto: ccp: Add support to initialize the AMD-SP for SEV-SNP
  (jsc#PED-5122).
- crypto: ccp: Define the SEV-SNP commands (jsc#PED-5122).
- x86/sev: Adjust the directmap to avoid inadvertent RMP faults
  (jsc#PED-5122).
- x86/sev: Add helper functions for RMPUPDATE and PSMASH
  instruction (jsc#PED-5122).
- x86/fault: Dump RMP table information when RMP page faults occur
  (jsc#PED-5122).
- x86/traps: Define RMP violation #PF error code (jsc#PED-5122).
- x86/fault: Add helper for dumping RMP entries (jsc#PED-5122).
- x86/sev: Add RMP entry lookup helpers (jsc#PED-5122).
- x86/mtrr: Don't print errors if MtrrFixDramModEn is set when
  SNP enabled (jsc#PED-5122).
- x86/sev: Add SEV-SNP host initialization support (jsc#PED-5122).
- iommu/amd: Don't rely on external callers to enable IOMMU SNP
  support (jsc#PED-5122).
- x86/speculation: Do not enable Automatic IBRS if SEV-SNP is
  enabled (jsc#PED-5122).
- x86/sme: Fix memory encryption setting if enabled by default
  and not overridden (jsc#PED-5122).
- x86/mm: Fix memory encryption features advertisement
  (jsc#PED-5122).
- x86/sev: Harden #VC instruction emulation somewhat
  (jsc#PED-5122).
- x86/CPU/AMD: Add X86_FEATURE_ZEN5 (jsc#PED-5122).
- x86/CPU/AMD: Drop now unused CPU erratum checking function
  (jsc#PED-5122).
- x86/CPU/AMD: Get rid of amd_erratum_1485 (jsc#PED-5122).
- x86/CPU/AMD: Get rid of amd_erratum_400 (jsc#PED-5122).
- x86/CPU/AMD: Get rid of amd_erratum_383 (jsc#PED-5122).
- x86/CPU/AMD: Get rid of amd_erratum_1054 (jsc#PED-5122).
- x86/CPU/AMD: Move the DIV0 bug detection to the Zen1 init
  function (jsc#PED-5122).
- x86/CPU/AMD: Move Zenbleed check to the Zen2 init function
  (jsc#PED-5122).
- x86/CPU/AMD: Rename init_amd_zn() to init_amd_zen_common()
  (jsc#PED-5122).
- x86/CPU/AMD: Call the spectral chicken in the Zen2 init function
  (jsc#PED-5122).
- x86/CPU/AMD: Move erratum 1076 fix into the Zen1 init function
  (jsc#PED-5122).
- x86/CPU/AMD: Move the Zen3 BTC_NO detection to the Zen3 init
  function (jsc#PED-5122).
- x86/CPU/AMD: Carve out the erratum 1386 fix (jsc#PED-5122).
- x86/CPU/AMD: Add ZenX generations flags (jsc#PED-5122).
- x86/cpu/intel_epb: Don't rely on link order (jsc#PED-5122).
- x86/barrier: Do not serialize MSR accesses on AMD
  (jsc#PED-5122).
- x86/cpu: Fix AMD erratum #1485 on Zen4-based CPUs
  (jsc#PED-5122).
- commit 708312f
* Tue Feb  6 2024 tiwai@suse.de
- usb: xhci-plat: fix usb disconnect issue after s4 (git-fixes).
- usb: hub: Add quirk to decrease IN-ep poll interval for
  Microchip USB491x hub (git-fixes).
- tty: allow TIOCSLCKTRMIOS with CAP_CHECKPOINT_RESTORE
  (git-fixes).
- spmi: mediatek: Fix UAF on device remove (git-fixes).
- spmi: mtk-pmif: Serialize PMIF status check and command
  submission (git-fixes).
- watchdog: it87_wdt: Keep WDTCTRL bit 3 unmodified for
  IT8784/IT8786 (git-fixes).
- wifi: cfg80211: fix RCU dereference in __cfg80211_bss_update
  (git-fixes).
- wifi: cfg80211: free beacon_ies when overridden from hidden BSS
  (git-fixes).
- wifi: rtl8xxxu: Add additional USB IDs for RTL8192EU devices
  (git-fixes).
- wifi: ath12k: fix and enable AP mode for WCN7850 (git-fixes).
- wifi: ath11k: fix race due to setting
  ATH11K_FLAG_EXT_IRQ_ENABLED too early (git-fixes).
- wifi: ath9k: Fix potential array-index-out-of-bounds read in
  ath9k_htc_txstatus() (git-fixes).
- wifi: wfx: fix possible NULL pointer dereference in
  wfx_set_mfp_ap() (git-fixes).
- wifi: mt76: mt7996: add PCI IDs for mt7992 (git-fixes).
- wifi: mt76: connac: fix EHT phy mode check (git-fixes).
- wifi: rt2x00: correct wrong BBP register in RxDCOC calibration
  (git-fixes).
- wifi: rt2x00: restart beacon queue when hardware reset
  (git-fixes).
- wifi: rtw89: fix timeout calculation in rtw89_roc_end()
  (git-fixes).
- thermal: core: Fix thermal zone suspend-resume synchronization
  (git-fixes).
- commit 556e60c
* Tue Feb  6 2024 tiwai@suse.de
- libsubcmd: Fix memory leak in uniq() (git-fixes).
- misc: lis3lv02d_i2c: Add missing setting of the reg_ctrl
  callback (git-fixes).
- PCI: switchtec: Fix stdev_release() crash after surprise hot
  remove (git-fixes).
- PCI: Fix 64GT/s effective data rate calculation (git-fixes).
- PCI: Only override AMD USB controller if required (git-fixes).
- PCI/AER: Decode Requester ID when no error info found
  (git-fixes).
- i3c: master: cdns: Update maximum prescaler value for i2c clock
  (git-fixes).
- mailbox: arm_mhuv2: Fix a bug for mhuv2_sender_interrupt
  (git-fixes).
- leds: trigger: panic: Don't register panic notifier if creating
  the trigger failed (git-fixes).
- mfd: ti_am335x_tscadc: Fix TI SoC dependencies (git-fixes).
- media: i2c: imx335: Fix hblank min/max values (git-fixes).
- media: ddbridge: fix an error code problem in ddb_probe
  (git-fixes).
- media: amphion: remove mutext lock in condition of wait_event
  (git-fixes).
- media: rkisp1: resizer: Stop manual allocation of
  v4l2_subdev_state (git-fixes).
- media: rkisp1: Fix IRQ disable race issue (git-fixes).
- media: rkisp1: Store IRQ lines (git-fixes).
- media: rkisp1: Fix IRQ handler return values (git-fixes).
- media: rkisp1: Drop IRQF_SHARED (git-fixes).
- media: uvcvideo: Fix power line control for SunplusIT camera
  (git-fixes).
- media: uvcvideo: Fix power line control for a Chicony camera
  (git-fixes).
- media: rockchip: rga: fix swizzling for RGB formats (git-fixes).
- media: stk1160: Fixed high volume of stk1160_dbg messages
  (git-fixes).
- soc: xilinx: fix unhandled SGI warning message (git-fixes).
- soc: xilinx: Fix for call trace due to the usage of
  smp_processor_id() (git-fixes).
- net: phy: at803x: fix passing the wrong reference for
  config_intr (git-fixes).
- PCI: Add no PM reset quirk for NVIDIA Spectrum devices
  (git-fixes).
- net: phy: micrel: fix ts_info value in case of no phc
  (git-fixes).
- pstore/ram: Fix crash when setting number of cpus to an odd
  number (git-fixes).
- PNP: ACPI: fix fortify warning (git-fixes).
- regulator: core: Only increment use_count when enable_count
  changes (git-fixes).
- commit 1095bc9
* Tue Feb  6 2024 tiwai@suse.de
- drm/amdgpu: Fix missing error code in 'gmc_v6/7/8/9_0_hw_init()'
  (git-fixes).
- drm/amdkfd: Fix 'node' NULL check in
  'svm_range_get_range_boundaries()' (git-fixes).
- drm/amdgpu: Release 'adev->pm.fw' before return in
  'amdgpu_device_need_post()' (git-fixes).
- drm/amdgpu: Fix with right return code '-EIO' in
  'amdgpu_gmc_vram_checking()' (git-fixes).
- drm/amd/powerplay: Fix kzalloc parameter 'ATOM_Tonga_PPM_Table'
  in 'get_platform_power_management_table()' (git-fixes).
- drm/amdgpu: fix avg vs input power reporting on smu7
  (git-fixes).
- drm/amdkfd: Fix lock dependency warning with srcu (git-fixes).
- drm/amdkfd: Fix lock dependency warning (git-fixes).
- i2c: rk3x: Adjust mask/value offset for i2c2 on rv1126
  (git-fixes).
- hwmon: (nct6775) Fix fan speed set failure in automatic mode
  (git-fixes).
- drm/amdgpu: apply the RV2 system aperture fix to RN/CZN as well
  (git-fixes).
- drm/amdkfd: Fix iterator used outside loop in
  'kfd_add_peer_prop()' (git-fixes).
- drm/amdgpu: Drop 'fence' check in 'to_amdgpu_amdkfd_fence()'
  (git-fixes).
- drm/amdgpu: Fix '*fw' from request_firmware() not released in
  'amdgpu_ucode_request()' (git-fixes).
- drm/amdgpu: Let KFD sync with VM fences (git-fixes).
- drm/amd/display: Fix minor issues in BW Allocation Phase2
  (git-fixes).
- drm/amdgpu: Fix ecc irq enable/disable unpaired (git-fixes).
- drm/amd/display: make flip_timestamp_in_us a 64-bit variable
  (git-fixes).
- drm: using mul_u32_u32() requires linux/math64.h (git-fixes).
- drm/msm/dpu: fix writeback programming for YUV cases
  (git-fixes).
- commit 9877917
* Tue Feb  6 2024 jroedel@suse.de
- powerpc: iommu: Bring back table group release_ownership()
  call (git-fixes).
- drm/tegra: Do not assume that a NULL domain means no DMA IOMMU
  (git-fixes).
- iommu: Allow ops->default_domain to work when !CONFIG_IOMMU_DMA
  (git-fixes).
- commit ba460b4
* Tue Feb  6 2024 tiwai@suse.de
- drm/msm/dpu: Ratelimit framedone timeout msgs (git-fixes).
- drm/msm/dpu: enable writeback on SM8450 (git-fixes).
- drm/msm/dpu: enable writeback on SM8350 (git-fixes).
- drm/msm/dp: Add DisplayPort controller for SM8650 (git-fixes).
- drm/msm/dsi: Enable runtime PM (git-fixes).
- drm/amdkfd: only flush mes process context if mes support is
  there (git-fixes).
- drm/amdgpu: fix ftrace event amdgpu_bo_move always move on
  same heap (git-fixes).
- drm/amdkfd: fix mes set shader debugger process management
  (git-fixes).
- drm/amd/display: For prefetch mode > 0, extend prefetch if
  possible (git-fixes).
- drm/amd/display: Fix MST PBN/X.Y value calculations (git-fixes).
- drm/exynos: Call drm_atomic_helper_shutdown() at shutdown/unbind
  time (git-fixes).
- drm/mipi-dsi: Fix detach call without attach (git-fixes).
- drm/framebuffer: Fix use of uninitialized variable (git-fixes).
- drm/drm_file: fix use of uninitialized variable (git-fixes).
- drm/bridge: anx7625: Fix Set HPD irq detect window to 2ms
  (git-fixes).
- drm/panel-edp: Add override_edid_mode quirk for generic edp
  (git-fixes).
- drm/amd/display: Fix tiled display misalignment (git-fixes).
- crypto: stm32/crc32 - fix parsing list of devices (git-fixes).
- Documentation/sphinx: fix Python string escapes (git-fixes).
- commit 63f49fd
* Tue Feb  6 2024 tiwai@suse.de
- 9p: Fix initialisation of netfs_inode for 9p (git-fixes).
- clk: imx: clk-imx8qxp: fix LVDS bypass, pixel and phy clocks
  (git-fixes).
- clk: mmp: pxa168: Fix memory leak in pxa168_clk_init()
  (git-fixes).
- clk: hi3620: Fix memory leak in hi3620_mmc_clk_init()
  (git-fixes).
- ASoC: amd: Add new dmi entries for acp5x platform (git-fixes).
- ASoC: doc: Fix undefined SND_SOC_DAPM_NOPM argument (git-fixes).
- ALSA: hda: intel-dspcfg: add filters for ARL-S and ARL
  (git-fixes).
- ALSA: hda: Refer to correct stream index at loops (git-fixes).
- accel/habanalabs: add support for Gaudi2C device (git-fixes).
- Bluetooth: L2CAP: Fix possible multiple reject send (git-fixes).
- Bluetooth: hci_sync: fix BR/EDR wakeup bug (git-fixes).
- Bluetooth: ISO: Avoid creating child socket if PA sync is
  terminating (git-fixes).
- Bluetooth: qca: Set both WIDEBAND_SPEECH and LE_STATES quirks
  for QCA2066 (git-fixes).
- crypto: octeontx2 - Fix cptvf driver cleanup (git-fixes).
- crypto: p10-aes-gcm - Avoid -Wstringop-overflow warnings
  (git-fixes).
- ACPI: NUMA: Fix the logic of getting the fake_pxm value
  (git-fixes).
- ACPI: extlog: fix NULL pointer dereference check (git-fixes).
- ACPI: APEI: set memory failure flags as MF_ACTION_REQUIRED on
  synchronous events (git-fixes).
- ACPI: video: Add quirk for the Colorful X15 AT 23 Laptop
  (git-fixes).
- commit 2d4658b
* Tue Feb  6 2024 jslaby@suse.cz
- rpm/mkspec: sort entries in _multibuild
  Otherwise it creates unnecessary diffs when tar-up-ing. It's of course
  due to readdir() using "random" order as served by the underlying
  filesystem.
  See for example:
  https://build.opensuse.org/request/show/1144457/changes
- commit d1155de
* Tue Feb  6 2024 vbabka@suse.cz
- maple_tree: do not preallocate nodes for slot stores
  (bsc#1219404).
- commit 2307e38
* Tue Feb  6 2024 vbabka@suse.cz
- mm: always lock new vma before inserting into vma tree
  (bsc#1219558).
- commit 4dd5f88
* Tue Feb  6 2024 vbabka@suse.cz
- mm: lock vma explicitly before doing vm_flags_reset and
  vm_flags_reset_once (bsc#1219558).
- commit 3ebd604
* Tue Feb  6 2024 vbabka@suse.cz
- mm: replace mmap with vma write lock assertions when operating
  on a vma (bsc#1219558).
- commit 50e3b4d
* Tue Feb  6 2024 vbabka@suse.cz
- mm: for !CONFIG_PER_VMA_LOCK equate write lock assertion for
  vma and mmap (bsc#1219558).
- commit b999b29
* Tue Feb  6 2024 vbabka@suse.cz
- mmap: fix vma_iterator in error path of vma_merge()
  (bsc#1219558).
- commit af3b8c0
* Mon Feb  5 2024 vbabka@suse.cz
- mm: fix vm_brk_flags() to not bail out while holding lock
  (bsc#1219558).
- commit 817bef2
* Mon Feb  5 2024 vbabka@suse.cz
- mm/mmap: change vma iteration order in do_vmi_align_munmap()
  (bsc#1219558).
- commit 8f876cd
* Mon Feb  5 2024 vbabka@suse.cz
- mm: set up vma iterator for vma_iter_prealloc() calls
  (bsc#1219558).
- commit 2d402b6
* Mon Feb  5 2024 vbabka@suse.cz
- mm: use vma_iter_clear_gfp() in nommu (bsc#1219558).
- commit 666385f
* Mon Feb  5 2024 vbabka@suse.cz
- mm: remove re-walk from mmap_region() (bsc#1219558).
- commit 85c7321
* Mon Feb  5 2024 vbabka@suse.cz
- mm: remove prev check from do_vmi_align_munmap() (bsc#1219558).
- commit d77a7e1
* Mon Feb  5 2024 vbabka@suse.cz
- mm: change do_vmi_align_munmap() tracking of VMAs to remove
  (bsc#1219558).
- commit 595be09
* Mon Feb  5 2024 vbabka@suse.cz
- mm/mmap: clean up validate_mm() calls (bsc#1219558).
- Refresh patches.suse/mm-re-introduce-vm_flags-to-do_mmap.patch.
- commit 5726712
* Mon Feb  5 2024 fweisbecker@suse.de
- tick-sched: Fix idle and iowait sleeptime accounting vs CPU (bsc#1219497)
- commit c0129ec
* Mon Feb  5 2024 vbabka@suse.cz
- mm/mmap: move vma operations to mm_struct out of the critical
  section of file mapping lock (bsc#1219558).
- commit 4a16ce1
* Mon Feb  5 2024 dwagner@suse.de
- nvme-rdma: Fix transfer length when write_generate/read_verify
  are 0 (git-fixes).
- nvme: trace: avoid memcpy overflow warning (git-fixes).
- nvmet: re-fix tracing strncpy() warning (git-fixes).
- nvme: fix max_discard_sectors calculation (git-fixes).
- nvmet-tcp: fix a missing endianess conversion in
  nvmet_tcp_try_peek_pdu (git-fixes).
- nvme-pci: fix sleeping function called from interrupt context
  (git-fixes).
- Revert "nvme-fc: fix race between error recovery and creating
  association" (git-fixes).
- nvme: blank out authentication fabrics options if not configured
  (git-fixes).
- nvme: catch errors from nvme_configure_metadata() (git-fixes).
- nvme-tcp: only evaluate 'tls' option if TLS is selected
  (git-fixes).
  Refresh:
  - patches.suse/nvme-tcp-fix-compile-time-checks-for-TLS-mode.patch
- nvme-auth: set explanation code for failure2 msgs (git-fixes).
- commit 542cb02
* Mon Feb  5 2024 dwagner@suse.de
- scsi: lpfc: Update lpfc version to 14.2.0.17 (bsc#1219582).
- scsi: lpfc: Move determination of vmid_flag after VMID
  reinitialization completes (bsc#1219582).
- scsi: lpfc: Reinitialize an NPIV's VMID data structures after
  FDISC (bsc#1219582).
- scsi: lpfc: Change VMID driver load time parameters to read only
  (bsc#1219582).
- commit a28d317
* Mon Feb  5 2024 lhenriques@suse.de
- ceph: select FS_ENCRYPTION_ALGS if FS_ENCRYPTION (bsc#1219567).
- ceph_wait_on_conflict_unlink(): grab reference before dropping
  - >d_lock (bsc#1219566).
- commit 9d8ca8e
* Mon Feb  5 2024 tiwai@suse.de
- maple_tree: add MAS_UNDERFLOW and MAS_OVERFLOW states
  (bsc#1219558).
- maple_tree: add mas_is_active() to detect in-tree walks
  (bsc#1219558).
- maple_tree: shrink struct maple_tree (bsc#1219558).
- maple_tree: clean up mas_wr_append() (bsc#1219558).
- maple_tree: reduce resets during store setup (bsc#1219558).
- maple_tree: refine mas_preallocate() node calculations
  (bsc#1219558).
- maple_tree: move mas_wr_end_piv() below mas_wr_extend_null()
  (bsc#1219558).
- maple_tree: adjust node allocation on mas_rebalance()
  (bsc#1219558).
- maple_tree: re-introduce entry to mas_preallocate() arguments
  (bsc#1219558).
- commit 911aa39
* Mon Feb  5 2024 tiwai@suse.de
- maple_tree: introduce __mas_set_range() (bsc#1219558).
- maple_tree: add benchmarking for mas_prev() (bsc#1219558).
- maple_tree: add benchmarking for mas_for_each (bsc#1219558).
- maple_tree: Be more strict about locking (bsc#1219558).
- mm/mmap: change detached vma locking scheme (bsc#1219558).
- maple_tree: relax lockdep checks for on-stack trees
  (bsc#1219558).
- maple_tree: mtree_insert: fix typo in kernel-doc description
  of GFP flags (bsc#1219558).
- maple_tree: mtree_insert*: fix typo in kernel-doc description
  (bsc#1219558).
- maple_tree: drop mas_first_entry() (bsc#1219558).
- maple_tree: replace mas_logical_pivot() with mas_safe_pivot()
  (bsc#1219558).
- commit a3884af
* Mon Feb  5 2024 tiwai@suse.de
- maple_tree: update mt_validate() (bsc#1219558).
- maple_tree: make mas_validate_limits() check root node and
  node limit (bsc#1219558).
- maple_tree: fix mas_validate_child_slot() to check last missed
  slot (bsc#1219558).
- maple_tree: make mas_validate_gaps() to check metadata
  (bsc#1219558).
- maple_tree: don't use MAPLE_ARANGE64_META_MAX to indicate no
  gap (bsc#1219558).
- maple_tree: add a fast path case in mas_wr_slot_store()
  (bsc#1219558).
- maple_tree: optimize mas_wr_append(), also improve duplicating
  VMAs (bsc#1219558).
- maple_tree: add test for mas_wr_modify() fast path
  (bsc#1219558).
- maple_tree: fix a few documentation issues (bsc#1219558).
- commit ed58165
* Mon Feb  5 2024 ailiop@suse.com
- afs: Hide silly-rename files from userspace (git-fixes).
- commit 7f411ab
* Mon Feb  5 2024 tiwai@suse.de
- ALSA: hda/realtek: Enable headset mic on Vaio VJFE-ADL
  (git-fixes).
- ASoC: amd: yc: Add DMI quirk for MSI Bravo 15 C7VF (git-fixes).
- ASoC: qcom: sc8280xp: limit speaker volumes (git-fixes).
- ALSA: hda/realtek: Apply headset jack quirk for non-bass alc287
  thinkpads (git-fixes).
- ALSA: hda/realtek: Enable Mute LED on HP Laptop 14-fq0xxx
  (git-fixes).
- ALSA: hda/realtek: Fix the external mic not being recognised
  for Acer Swift 1 SF114-32 (git-fixes).
- ALSA: usb-audio: Add delay quirk for MOTU M Series 2nd revision
  (git-fixes).
- ALSA: hda/realtek - Add speaker pin verbtable for Dell dual
  speaker platform (git-fixes).
- ALSA: usb-audio: Add a quirk for Yamaha YIT-W12TX transmitter
  (git-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP ZBook Power
  (git-fixes).
- commit 3a5699c
* Mon Feb  5 2024 tiwai@suse.de
- misc: fastrpc: Mark all sessions as invalid in cb_remove
  (git-fixes).
- serial: max310x: prevent infinite while() loop in port startup
  (git-fixes).
- serial: max310x: fail probe if clock crystal is unstable
  (git-fixes).
- serial: max310x: improve crystal stable clock detection
  (git-fixes).
- serial: max310x: set default value when reading clock ready bit
  (git-fixes).
- usb: typec: tcpm: fix the PD disabled case (git-fixes).
- usb: ucsi_acpi: Fix command completion handling (git-fixes).
- usb: ucsi: Add missing ppm_lock (git-fixes).
- usb: ulpi: Fix debugfs directory leak (git-fixes).
- Revert "usb: typec: tcpm: fix cc role at port reset"
  (git-fixes).
- USB: hub: check for alternate port before enabling
  A_ALT_HNP_SUPPORT (git-fixes).
- usb: chipidea: core: handle power lost in workqueue (git-fixes).
- usb: dwc3: gadget: Fix NULL pointer dereference in
  dwc3_gadget_suspend (git-fixes).
- usb: core: Prevent null pointer dereference in
  update_port_device_state (git-fixes).
- xhci: fix off by one check when adding a secondary interrupter
  (git-fixes).
- usb: host: xhci-plat: Add support for
  XHCI_SG_TRB_CACHE_SIZE_QUIRK (git-fixes).
- dmaengine: fix is_slave_direction() return false when
  DMA_DEV_TO_DEV (git-fixes).
- dmaengine: fsl-qdma: Fix a memory leak related to the queue
  command DMA (git-fixes).
- dmaengine: fsl-qdma: Fix a memory leak related to the status
  queue DMA (git-fixes).
- dmaengine: ti: k3-udma: Report short packet errors (git-fixes).
- dmaengine: fsl-dpaa2-qdma: Fix the size of dma pools
  (git-fixes).
- phy: ti: phy-omap-usb2: Fix NULL pointer dereference for SRP
  (git-fixes).
- phy: renesas: rcar-gen3-usb2: Fix returning wrong error code
  (git-fixes).
- commit a23ce22
* Sun Feb  4 2024 tiwai@suse.de
- ASoC: cs35l56: Firmware file must match the version of preloaded
  firmware (git-fixes).
- commit 726969d
* Sun Feb  4 2024 tiwai@suse.de
- ASoC: cs35l56: Wake transactions need to be issued twice
  (git-fixes).
- commit 92aa6aa
* Sun Feb  4 2024 tiwai@suse.de
- drm/amd/display: Add NULL check for kzalloc in
  'amdgpu_dm_atomic_commit_tail()' (git-fixes).
- drm/amd: Don't init MEC2 firmware when it fails to load
  (git-fixes).
- Input: atkbd - do not skip atkbd_deactivate() when skipping
  ATKBD_CMD_GETID (git-fixes).
- Input: atkbd - skip ATKBD_CMD_SETLEDS when skipping
  ATKBD_CMD_GETID (git-fixes).
- Input: bcm5974 - check endpoint type before starting traffic
  (git-fixes).
- ALSA: hda: cs35l56: Firmware file must match the version of
  preloaded firmware (git-fixes).
- ASoC: cs35l56: Allow more time for firmware to boot (git-fixes).
- ASoC: cs35l56: Load tunings for the correct speaker models
  (git-fixes).
- ASoC: cs35l56: Fix misuse of wm_adsp 'part' string for silicon
  revision (git-fixes).
- ASoC: cs35l56: Fix for initializing ASP1 mixer registers
  (git-fixes).
- ASoC: cs35l56: Remove unused hibernate wake constants
  (git-fixes).
- commit a79a167
* Sun Feb  4 2024 tiwai@suse.de
- ALSA: hda: cs35l56: Initialize all ASP1 registers (git-fixes).
- ASoC: cs35l56: Fix default SDW TX mixer registers (git-fixes).
- ASoC: cs35l56: Fix to ensure ASP1 registers match cache
  (git-fixes).
- ASoC: cs35l56: Remove buggy checks from
  cs35l56_is_fw_reload_needed() (git-fixes).
- ASoC: cs35l56: Don't add the same register patch multiple times
  (git-fixes).
- ASoC: cs35l56: cs35l56_component_remove() must clean up wm_adsp
  (git-fixes).
- ASoC: cs35l56: cs35l56_component_remove() must clear
  cs35l56->component (git-fixes).
- ASoC: wm_adsp: Fix firmware file search order (git-fixes).
- ASoC: sun4i-spdif: Fix requirements for H6 (git-fixes).
- ASoC: codecs: lpass-wsa-macro: fix compander volume hack
  (git-fixes).
- commit 210b81e
* Sun Feb  4 2024 tiwai@suse.de
- ALSA: hda: cs35l56: Fix filename string field layout
  (git-fixes).
- ALSA: hda: cs35l56: Fix order of searching for firmware files
  (git-fixes).
- ASoC: codecs: wsa883x: fix PA volume control (git-fixes).
- ASoC: codecs: wcd938x: handle deferred probe (git-fixes).
- ASoC: codecs: wcd938x: fix headphones volume controls
  (git-fixes).
- ALSA: usb-audio: Sort quirk table entries (git-fixes).
- ALSA: usb-audio: add quirk for RODE NT-USB+ (git-fixes).
- ALSA: usb-audio: fix typo (git-fixes).
- ALSA: hda/cs8409: Suppress vmaster control for Dolphin models
  (git-fixes).
- commit cbd1581
* Fri Feb  2 2024 pmladek@suse.com
- workqueue: Provide one lock class key per work_on_cpu() callsite
  (bsc#1219510).
- commit cc7032e
* Fri Feb  2 2024 pmladek@suse.com
- workqueue: Override implicit ordered attribute in
  workqueue_apply_unbound_cpumask() (bsc#1219509).
- commit 6b333df
* Fri Feb  2 2024 iivanov@suse.de
- perf/arm-cmn: Fix the unhandled overflow status of counter 4 to 7 (bsc#1219496)
- commit 2ad8787
* Fri Feb  2 2024 iivanov@suse.de
- Update patches.suse/sbsa_gwdt-Calculate-timeout-with-64-bit-math.patch (git-fixes, bsc#1219470)
  Add reference to bsc#1219470.
- commit f55db61
* Fri Feb  2 2024 iivanov@suse.de
- Update patches.suse/i2c-designware-Disable-TX_EMPTY-irq-while-waiting-fo.patch (git-fixes, bsc#1219473)
  Add reference to bsc#1219473.
- commit 4fc714a
* Fri Feb  2 2024 tiwai@suse.de
- net: phy: realtek: add support for RTL8126A-integrated 5Gbps
  PHY (bsc#1217417).
- r8169: add support for RTL8126A (bsc#1217417).
- commit cff22d0
* Fri Feb  2 2024 tiwai@suse.de
- r8169: fix rtl8125b PAUSE frames blasting when suspended
  (bsc#1217417).
- commit 1d2e69e
* Fri Feb  2 2024 tiwai@suse.de
- nfc: nci: free rx_data_reassembly skb on NCI device cleanup
  (git-fixes).
- HID: bpf: actually free hdev memory after attaching a HID-BPF
  program (git-fixes).
- HID: bpf: remove double fdget() (git-fixes).
- HID: i2c-hid-of: fix NULL-deref on failed power up (git-fixes).
- HID: hidraw: fix a problem of memory leak in hidraw_release()
  (git-fixes).
- firewire: core: correct documentation of fw_csr_string()
  kernel API (git-fixes).
- regulator: ti-abb: don't use
  devm_platform_ioremap_resource_byname for shared interrupt
  register (git-fixes).
- serial: sc16is7xx: improve do/while loop in sc16is7xx_irq()
  (git-fixes).
- serial: sc16is7xx: remove obsolete loop in sc16is7xx_port_irq()
  (git-fixes).
- serial: sc16is7xx: fix invalid sc16is7xx_lines bitfield in
  case of probe error (git-fixes).
- serial: sc16is7xx: fix unconditional activation of THRI
  interrupt (git-fixes).
- commit 5ceb45c
* Fri Feb  2 2024 jroedel@suse.de
- supported.conf: Add new VFIO modules
- commit 0e15e54
* Fri Feb  2 2024 jroedel@suse.de
- vfio/pds: Add missing PCI_IOV depends (jsc#PED-7779
  jsc#PED-7780).
- vfio/pds: Fix calculations in pds_vfio_dirty_sync (jsc#PED-7779
  jsc#PED-7780).
- Refresh patches.suse/vfio-Move-iova_bitmap-into-iommufd.
- commit d637959
* Fri Feb  2 2024 shung-hsi.yu@suse.com
- selftests/bpf: user_ringbuf.c define c_ringbuf_size
  (jsc#PED-6811).
- commit 777a0e5
* Thu Feb  1 2024 lduncan@suse.com
- Revert "scsi: fcoe: Fix potential deadlock on &fip->ctlr_lock"
  (bsc#1219141).
- fnic: move fnic_fnic_flush_tx() to a work queue (bsc#1219141).
- commit 43e1290
* Thu Feb  1 2024 jgross@suse.com
- xen-netback: don't produce zero-size SKB frags (CVE-2023-46838,
  XSA-448, bsc#1218836).
- commit b4061c7
* Thu Feb  1 2024 tiwai@suse.de
- vm: fix move_vma() memory accounting being off (bsc#1219404).
- commit 8061f6c
* Thu Feb  1 2024 oneukum@suse.com
- Refresh
  patches.suse/usb-typec-tcpm-Support-multiple-capabilities.patch.
  Fixes an error that I made backporting.
  It leads to an unused variable warning.
  Does not really hurt, but should not happen
- commit 2ce740a
* Thu Feb  1 2024 tiwai@suse.de
- mm: Update do_vmi_align_munmap() return semantics (bsc#1219404).
- Refresh patches.suse/mm-re-introduce-vm_flags-to-do_mmap.patch.
- commit 7580cf9
* Thu Feb  1 2024 tiwai@suse.de
- mm: don't do validate_mm() unnecessarily and without mmap
  locking (bsc#1219404).
- mm: validate the mm before dropping the mmap lock (bsc#1219404).
- mm: Always downgrade mmap_lock if requested (bsc#1219404).
- userfaultfd: fix regression in userfaultfd_unmap_prep()
  (bsc#1219404).
- mm/mmap: separate writenotify and dirty tracking logic
  (bsc#1219404).
- commit b6ee33d
* Thu Feb  1 2024 tiwai@suse.de
- maple_tree: add comments and some minor cleanups to
  mas_wr_append() (bsc#1219404).
- Refresh
  patches.suse/maple_tree-disable-mas_wr_append-when-other-re.patch.
- commit 8ab650e
* Thu Feb  1 2024 tiwai@suse.de
- maple_tree: relocate the declaration of mas_empty_area_rev()
  (bsc#1219404).
- maple_tree: simplify and clean up mas_wr_node_store()
  (bsc#1219404).
- maple_tree: rework mas_wr_slot_store() to be cleaner and more
  efficient (bsc#1219404).
- maple_tree: add mas_wr_new_end() to calculate new_end accurately
  (bsc#1219404).
- maple_tree: make the code symmetrical in mas_wr_extend_null()
  (bsc#1219404).
- maple_tree: simplify mas_is_span_wr() (bsc#1219404).
- maple_tree: drop mas_{rev_}alloc() and mas_fill_gap()
  (bsc#1219404).
- maple_tree: rework mtree_alloc_{range,rrange}() (bsc#1219404).
- commit d2740e9
* Thu Feb  1 2024 tiwai@suse.de
- maple_tree: update testing code for mas_{next,prev,walk}
  (bsc#1219404).
- Refresh
  patches.suse/maple_tree-fix-32-bit-mas_next-testing.patch.
- commit befb467
* Thu Feb  1 2024 tiwai@suse.de
- mm: avoid rewalk in mmap_region (bsc#1219404).
- mm: add vma_iter_{next,prev}_range() to vma iterator
  (bsc#1219404).
- maple_tree: clear up index and last setting in single entry tree
  (bsc#1219404).
- maple_tree: add mas_prev_range() and mas_find_range_rev
  interface (bsc#1219404).
- maple_tree: introduce mas_prev_slot() interface (bsc#1219404).
- maple_tree: relocate mas_rewalk() and mas_rewalk_if_dead()
  (bsc#1219404).
- maple_tree: add mas_next_range() and mas_find_range() interfaces
  (bsc#1219404).
- maple_tree: introduce mas_next_slot() interface (bsc#1219404).
- maple_tree: change RCU checks to WARN_ON() instead of BUG_ON()
  (bsc#1219404).
- commit ac1cd44
* Thu Feb  1 2024 tiwai@suse.de
- maple_tree: make test code work without debug enabled
  (bsc#1219404).
- Refresh
  patches.suse/maple_tree-add-GFP_KERNEL-to-allocations-in-mas_expe.patch.
- commit c5591fa
* Thu Feb  1 2024 tiwai@suse.de
- maple_tree: fix testing mas_empty_area() (bsc#1219404).
- maple_tree: revise limit checks in mas_empty_area{_rev}()
  (bsc#1219404).
- maple_tree: try harder to keep active node with mas_prev()
  (bsc#1219404).
- maple_tree: try harder to keep active node after mas_next()
  (bsc#1219404).
- mm/mmap: change do_vmi_align_munmap() for maple tree iterator
  changes (bsc#1219404).
- maple_tree: mas_start() reset depth on dead node (bsc#1219404).
- maple_tree: remove unnecessary check from mas_destroy()
  (bsc#1219404).
- mm: update vma_iter_store() to use MAS_WARN_ON() (bsc#1219404).
- mm: update validate_mm() to use vma iterator (bsc#1219404).
- commit b5f7997
* Thu Feb  1 2024 tiwai@suse.de
- maple_tree: return error on mte_pivots() out of range
  (bsc#1219404).
- maple_tree: use MAS_BUG_ON() prior to calling mas_meta_gap()
  (bsc#1219404).
- maple_tree: use MAS_WR_BUG_ON() in mas_store_prealloc()
  (bsc#1219404).
- maple_tree: use MAS_BUG_ON() in mas_set_height() (bsc#1219404).
- maple_tree: convert debug code to use MT_WARN_ON() and
  MAS_WARN_ON() (bsc#1219404).
- maple_tree: convert BUG_ON() to MT_BUG_ON() (bsc#1219404).
- maple_tree: clean up mas_dfs_postorder() (bsc#1219404).
- maple_tree: avoid unnecessary ascending (bsc#1219404).
- maple_tree: fix static analyser cppcheck issue (bsc#1219404).
- commit e7b5e3b
* Thu Feb  1 2024 spradhan@suse.de
- fanotify: allow "weak" fsid when watching a single filesystem (bsc#1218177).
- commit 1ae4770
* Thu Feb  1 2024 spradhan@suse.de
- fanotify: store fsid in mark instead of in connector (bsc#1218177).
- commit 6a1149a
* Thu Feb  1 2024 jroedel@suse.de
- s390/pci: Use dma-iommu layer (jsc#PED-7779 jsc#PED-7780).
- Update config files.
- commit 5632afd
* Thu Feb  1 2024 tiwai@suse.de
- maple_tree: replace data before marking dead in split and
  spanning store (bsc#1219404).
- maple_tree: change mas_adopt_children() parent usage
  (bsc#1219404).
- maple_tree: introduce mas_tree_parent() definition
  (bsc#1219404).
- maple_tree: introduce mas_put_in_tree() (bsc#1219404).
- maple_tree: reorder replacement of nodes to avoid live lock
  (bsc#1219404).
- maple_tree: add hex output to maple_arange64 dump (bsc#1219404).
- maple_tree: fix the arguments to __must_hold() (bsc#1219404).
- maple_tree: use MAS_BUG_ON() from mas_topiary_range()
  (bsc#1219404).
- maple_tree: use MAS_BUG_ON() when setting a leaf node as a
  parent (bsc#1219404).
- maple_tree: add debug BUG_ON and WARN_ON variants (bsc#1219404).
- maple_tree: add format option to mt_dump() (bsc#1219404).
- maple_tree: clean up mas_parent_enum() and rename to
  mas_parent_type() (bsc#1219404).
- commit eb22d39
* Thu Feb  1 2024 jroedel@suse.de
- vfio: Move iova_bitmap into iommufd (jsc#PED-7779 jsc#PED-7780).
- Update config files.
- commit 999dadf
* Thu Feb  1 2024 jroedel@suse.de
- iommufd: Do not UAF during iommufd_put_object() (jsc#PED-7779
  jsc#PED-7780).
- iommufd: Add iommufd_ctx to iommufd_put_object() (jsc#PED-7779
  jsc#PED-7780).
- iommufd/selftest: Fix _test_mock_dirty_bitmaps() (jsc#PED-7779
  jsc#PED-7780).
- vfio: Drop vfio_file_iommu_group() stub to fudge around a KVM
  wart (jsc#PED-7779 jsc#PED-7780).
- vfio/pds: Fix possible sleep while in atomic context
  (jsc#PED-7779 jsc#PED-7780).
- vfio/pds: Fix mutex lock->magic != lock warning (jsc#PED-7779
  jsc#PED-7780).
- iommu: Fix printk arg in of_iommu_get_resv_regions()
  (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Set variable intel_dirty_ops to static (jsc#PED-7779
  jsc#PED-7780).
- iommu/vt-d: Fix incorrect cache invalidation for mm notification
  (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Add MTL to quirk list to skip TE disabling
  (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Make context clearing consistent with context
  mapping (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Disable PCI ATS in legacy passthrough mode
  (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Omit devTLB invalidation requests when TES=0
  (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Support enforce_cache_coherency only for empty
  domains (jsc#PED-7779 jsc#PED-7780).
- iommu: Avoid more races around device probe (jsc#PED-7779
  jsc#PED-7780).
- MAINTAINERS: list all Qualcomm IOMMU drivers in the QUALCOMM
  IOMMU entry (jsc#PED-7779 jsc#PED-7780).
- iommu: Flow ERR_PTR out from __iommu_domain_alloc()
  (jsc#PED-7779 jsc#PED-7780).
- s390/pci: Fix reset of IOMMU software counters (jsc#PED-7779
  jsc#PED-7780).
- iommu/dma: Use a large flush queue and timeout for
  shadow_on_flush (jsc#PED-7779 jsc#PED-7780).
- iommu/dma: Allow a single FQ in addition to per-CPU FQs
  (jsc#PED-7779 jsc#PED-7780).
- iommu/s390: Disable deferred flush for ISM devices (jsc#PED-7779
  jsc#PED-7780).
- s390/pci: prepare is_passed_through() for dma-iommu
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Allow .iotlb_sync_map to fail and handle s390's -ENOMEM
  return (jsc#PED-7779 jsc#PED-7780).
- iommu/dart: Remove the force_bypass variable (jsc#PED-7779
  jsc#PED-7780).
- iommu/dart: Call apple_dart_finalize_domain() as part of
  alloc_paging() (jsc#PED-7779 jsc#PED-7780).
- iommu/dart: Convert to domain_alloc_paging() (jsc#PED-7779
  jsc#PED-7780).
- iommu/dart: Move the blocked domain support to a global static
  (jsc#PED-7779 jsc#PED-7780).
- iommu/dart: Use static global identity domains (jsc#PED-7779
  jsc#PED-7780).
- iommufd: Convert to alloc_domain_paging() (jsc#PED-7779
  jsc#PED-7780).
- iommu/vt-d: Use ops->blocked_domain (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Update the definition of the blocking domain
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Move IOMMU_DOMAIN_BLOCKED global statics to
  ops->blocked_domain (jsc#PED-7779 jsc#PED-7780).
- iommu: change iommu_map_sgtable to return signed values
  (jsc#PED-7779 jsc#PED-7780).
- powerpc/iommu: Do not do platform domain attach atctions after
  probe (jsc#PED-7779 jsc#PED-7780).
- iommu: Fix return code in iommu_group_alloc_default_domain()
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Do not use IOMMU_DOMAIN_DMA if CONFIG_IOMMU_DMA is not
  enabled (jsc#PED-7779 jsc#PED-7780).
- iommu: Remove duplicate include (jsc#PED-7779 jsc#PED-7780).
- iommu/iova: Manage the depot list size (jsc#PED-7779
  jsc#PED-7780).
- iommu/iova: Make the rcache depot scale better (jsc#PED-7779
  jsc#PED-7780).
- iommu: Improve map/unmap sanity checks (jsc#PED-7779
  jsc#PED-7780).
- iommu: Retire map/unmap ops (jsc#PED-7779 jsc#PED-7780).
- iommu/tegra-smmu: Update to {map,unmap}_pages (jsc#PED-7779
  jsc#PED-7780).
- iommu/sun50i: Update to {map,unmap}_pages (jsc#PED-7779
  jsc#PED-7780).
- iommu/rockchip: Update to {map,unmap}_pages (jsc#PED-7779
  jsc#PED-7780).
- iommu/omap: Update to {map,unmap}_pages (jsc#PED-7779
  jsc#PED-7780).
- iommu/exynos: Update to {map,unmap}_pages (jsc#PED-7779
  jsc#PED-7780).
- iommu/omap: Convert to generic_single_device_group()
  (jsc#PED-7779 jsc#PED-7780).
- iommu/ipmmu-vmsa: Convert to generic_single_device_group()
  (jsc#PED-7779 jsc#PED-7780).
- iommu/rockchip: Convert to generic_single_device_group()
  (jsc#PED-7779 jsc#PED-7780).
- iommu/sprd: Convert to generic_single_device_group()
  (jsc#PED-7779 jsc#PED-7780).
- iommu/sun50i: Convert to generic_single_device_group()
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Add generic_single_device_group() (jsc#PED-7779
  jsc#PED-7780).
- iommu: Remove useless group refcounting (jsc#PED-7779
  jsc#PED-7780).
- iommu: Convert remaining simple drivers to domain_alloc_paging()
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Convert simple drivers with DOMAIN_DMA to
  domain_alloc_paging() (jsc#PED-7779 jsc#PED-7780).
- iommu: Add ops->domain_alloc_paging() (jsc#PED-7779
  jsc#PED-7780).
- iommu: Add __iommu_group_domain_alloc() (jsc#PED-7779
  jsc#PED-7780).
- iommu: Require a default_domain for all iommu drivers
  (jsc#PED-7779 jsc#PED-7780).
- iommu/sun50i: Add an IOMMU_IDENTITIY_DOMAIN (jsc#PED-7779
  jsc#PED-7780).
- iommu/mtk_iommu: Add an IOMMU_IDENTITIY_DOMAIN (jsc#PED-7779
  jsc#PED-7780).
- iommu/ipmmu: Add an IOMMU_IDENTITIY_DOMAIN (jsc#PED-7779
  jsc#PED-7780).
- iommu/qcom_iommu: Add an IOMMU_IDENTITIY_DOMAIN (jsc#PED-7779
  jsc#PED-7780).
- iommu: Remove ops->set_platform_dma_ops() (jsc#PED-7779
  jsc#PED-7780).
- iommu/msm: Implement an IDENTITY domain (jsc#PED-7779
  jsc#PED-7780).
- iommu/omap: Implement an IDENTITY domain (jsc#PED-7779
  jsc#PED-7780).
- iommu/tegra-smmu: Support DMA domains in tegra (jsc#PED-7779
  jsc#PED-7780).
- iommu/tegra-smmu: Implement an IDENTITY domain (jsc#PED-7779
  jsc#PED-7780).
- iommu/exynos: Implement an IDENTITY domain (jsc#PED-7779
  jsc#PED-7780).
- iommu: Allow an IDENTITY domain as the default_domain in ARM32
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Reorganize iommu_get_default_domain_type() to respect
  def_domain_type() (jsc#PED-7779 jsc#PED-7780).
- iommu/mtk_iommu_v1: Implement an IDENTITY domain (jsc#PED-7779
  jsc#PED-7780).
- iommu/tegra-gart: Remove tegra-gart (jsc#PED-7779 jsc#PED-7780).
- iommu/fsl_pamu: Implement a PLATFORM domain (jsc#PED-7779
  jsc#PED-7780).
- iommu: Add IOMMU_DOMAIN_PLATFORM for S390 (jsc#PED-7779
  jsc#PED-7780).
- powerpc/iommu: Setup a default domain and remove
  set_platform_dma_ops (jsc#PED-7779 jsc#PED-7780).
- iommu: Add IOMMU_DOMAIN_PLATFORM (jsc#PED-7779 jsc#PED-7780).
- iommu: Add iommu_ops->identity_domain (jsc#PED-7779
  jsc#PED-7780).
- iommu/amd: Remove DMA_FQ type from domain allocation path
  (jsc#PED-7779 jsc#PED-7780).
- Revert "iommu: Fix false ownership failure on AMD systems with
  PASID activated" (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Remove unused EXPORT_SYMBOLS (jsc#PED-7779
  jsc#PED-7780).
- iommu/amd: Remove amd_iommu_device_info() (jsc#PED-7779
  jsc#PED-7780).
- iommu/amd: Remove PPR support (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Remove iommu_v2 module (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Initialize iommu_device->max_pasids (jsc#PED-7779
  jsc#PED-7780).
- iommu/amd: Enable device ATS/PASID/PRI capabilities
  independently (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Introduce iommu_dev_data.flags to track device
  capabilities (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Introduce iommu_dev_data.ppr (jsc#PED-7779
  jsc#PED-7780).
- iommu/amd: Rename ats related variables (jsc#PED-7779
  jsc#PED-7780).
- iommu/amd: Modify logic for checking GT and PPR features
  (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Consolidate feature detection and reporting logic
  (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Miscellaneous clean up when free domain (jsc#PED-7779
  jsc#PED-7780).
- iommu/amd: Do not set amd_iommu_pgtable in pass-through mode
  (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Introduce helper functions for managing GCR3 table
  (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Refactor protection domain allocation code
  (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Consolidate logic to allocate protection domain
  (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Consolidate timeout pre-define to amd_iommu_type.h
  (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Remove unused amd_io_pgtable.pt_root variable
  (jsc#PED-7779 jsc#PED-7780).
- Revert "iommu/vt-d: Remove unused function" (jsc#PED-7779
  jsc#PED-7780).
- iommu/vt-d: debugfs: Support dumping a specified page table
  (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: debugfs: Create/remove debugfs file per {device,
  pasid} (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: debugfs: Dump entry pointing to huge page
  (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Remove unused function (jsc#PED-7779 jsc#PED-7780).
- iommu/virtio: Add __counted_by for struct viommu_request and
  use struct_size() (jsc#PED-7779 jsc#PED-7780).
- dt-bindings: arm-smmu: Add SM7150 GPU SMMUv2 (jsc#PED-7779
  jsc#PED-7780).
- iommu/arm-smmu-v3-sva: Remove bond refcount (jsc#PED-7779
  jsc#PED-7780).
- iommu/arm-smmu-v3-sva: Remove unused iommu_sva handle
  (jsc#PED-7779 jsc#PED-7780).
- iommu/arm-smmu-v3: Rename cdcfg to cd_table (jsc#PED-7779
  jsc#PED-7780).
- iommu/arm-smmu-v3: Update comment about STE liveness
  (jsc#PED-7779 jsc#PED-7780).
- iommu/arm-smmu-v3: Cleanup arm_smmu_domain_finalise
  (jsc#PED-7779 jsc#PED-7780).
- iommu/arm-smmu-v3: Move CD table to arm_smmu_master
  (jsc#PED-7779 jsc#PED-7780).
- iommu/arm-smmu-v3: Refactor write_ctx_desc (jsc#PED-7779
  jsc#PED-7780).
- iommu/arm-smmu-v3: move stall_enabled to the cd table
  (jsc#PED-7779 jsc#PED-7780).
- iommu/arm-smmu-v3: Encapsulate ctx_desc_cfg init in
  alloc_cd_tables (jsc#PED-7779 jsc#PED-7780).
- iommu/arm-smmu-v3: Replace s1_cfg with cdtab_cfg (jsc#PED-7779
  jsc#PED-7780).
- iommu/arm-smmu-v3: Move ctx_desc out of s1_cfg (jsc#PED-7779
  jsc#PED-7780).
- iommu/arm-smmu-qcom: Add SM7150 SMMUv2 (jsc#PED-7779
  jsc#PED-7780).
- iommu/arm-smmu-qcom: Add SDM670 MDSS compatible (jsc#PED-7779
  jsc#PED-7780).
- iommu/tegra-smmu: Drop unnecessary error check for for
  debugfs_create_dir() (jsc#PED-7779 jsc#PED-7780).
- iommufd: Organize the mock domain alloc functions closer to
  Joerg's tree (jsc#PED-7779 jsc#PED-7780).
- iommufd/selftest: Fix page-size check in iommufd_test_dirty()
  (jsc#PED-7779 jsc#PED-7780).
- iommufd: Add iopt_area_alloc() (jsc#PED-7779 jsc#PED-7780).
- iommufd: Fix missing update of domains_itree after splitting
  iopt_area (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Disallow read-only mappings to nest parent domain
  (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Add nested domain allocation (jsc#PED-7779
  jsc#PED-7780).
- iommu/vt-d: Set the nested domain to a device (jsc#PED-7779
  jsc#PED-7780).
- iommu/vt-d: Make domain attach helpers to be extern
  (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Add helper to setup pasid nested translation
  (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Add helper for nested domain allocation
  (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Extend dmar_domain to support nested domain
  (jsc#PED-7779 jsc#PED-7780).
- iommufd: Add data structure for Intel VT-d stage-1 domain
  allocation (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Enhance capability check for nested parent domain
  allocation (jsc#PED-7779 jsc#PED-7780).
- iommufd/selftest: Add coverage for IOMMU_HWPT_ALLOC with nested
  HWPTs (jsc#PED-7779 jsc#PED-7780).
- iommufd/selftest: Add nested domain allocation for mock domain
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Add iommu_copy_struct_from_user helper (jsc#PED-7779
  jsc#PED-7780).
- iommufd: Add a nested HW pagetable object (jsc#PED-7779
  jsc#PED-7780).
- iommu: Pass in parent domain with user_data to domain_alloc_user
  op (jsc#PED-7779 jsc#PED-7780).
- iommufd: Share iommufd_hwpt_alloc with IOMMUFD_OBJ_HWPT_NESTED
  (jsc#PED-7779 jsc#PED-7780).
- iommufd: Derive iommufd_hwpt_paging from iommufd_hw_pagetable
  (jsc#PED-7779 jsc#PED-7780).
- iommufd/device: Wrap IOMMUFD_OBJ_HWPT_PAGING-only configurations
  (jsc#PED-7779 jsc#PED-7780).
- iommufd: Rename IOMMUFD_OBJ_HW_PAGETABLE to
  IOMMUFD_OBJ_HWPT_PAGING (jsc#PED-7779 jsc#PED-7780).
- iommu: Add IOMMU_DOMAIN_NESTED (jsc#PED-7779 jsc#PED-7780).
- iommufd: Only enforce cache coherency in
  iommufd_hw_pagetable_alloc (jsc#PED-7779 jsc#PED-7780).
- iommufd/selftest: Test IOMMU_HWPT_GET_DIRTY_BITMAP_NO_CLEAR flag
  (jsc#PED-7779 jsc#PED-7780).
- iommufd/selftest: Test out_capabilities in IOMMU_GET_HW_INFO
  (jsc#PED-7779 jsc#PED-7780).
- iommufd/selftest: Test IOMMU_HWPT_GET_DIRTY_BITMAP (jsc#PED-7779
  jsc#PED-7780).
- iommufd/selftest: Test IOMMU_HWPT_SET_DIRTY_TRACKING
  (jsc#PED-7779 jsc#PED-7780).
- iommufd/selftest: Test IOMMU_HWPT_ALLOC_DIRTY_TRACKING
  (jsc#PED-7779 jsc#PED-7780).
- iommufd/selftest: Expand mock_domain with dev_flags
  (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Access/Dirty bit support for SS domains
  (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Access/Dirty bit support in IOPTEs (jsc#PED-7779
  jsc#PED-7780).
- iommu/amd: Add domain_alloc_user based domain allocation
  (jsc#PED-7779 jsc#PED-7780).
- iommufd: Add a flag to skip clearing of IOPTE dirty
  (jsc#PED-7779 jsc#PED-7780).
- iommufd: Add capabilities to IOMMU_GET_HW_INFO (jsc#PED-7779
  jsc#PED-7780).
- iommufd: Add IOMMU_HWPT_GET_DIRTY_BITMAP (jsc#PED-7779
  jsc#PED-7780).
- iommufd: Add IOMMU_HWPT_SET_DIRTY_TRACKING (jsc#PED-7779
  jsc#PED-7780).
- iommufd: Add a flag to enforce dirty tracking on attach
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Add iommu_domain ops for dirty tracking (jsc#PED-7779
  jsc#PED-7780).
- iommufd/iova_bitmap: Move symbols to IOMMUFD namespace
  (jsc#PED-7779 jsc#PED-7780).
- vfio/iova_bitmap: Export more API symbols (jsc#PED-7779
  jsc#PED-7780).
- iommufd: Correct IOMMU_HWPT_ALLOC_NEST_PARENT description
  (jsc#PED-7779 jsc#PED-7780).
- iommufd/selftest: Rework TEST_LENGTH to test min_size explicitly
  (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Add domain_alloc_user op (jsc#PED-7779
  jsc#PED-7780).
- iommufd/selftest: Add domain_alloc_user() support in iommu mock
  (jsc#PED-7779 jsc#PED-7780).
- iommufd: Support allocating nested parent domain (jsc#PED-7779
  jsc#PED-7780).
- iommufd: Flow user flags for domain allocation to
  domain_alloc_user() (jsc#PED-7779 jsc#PED-7780).
- iommufd: Use the domain_alloc_user() op for domain allocation
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Add new iommu op to create domains owned by userspace
  (jsc#PED-7779 jsc#PED-7780).
- iommufd/selftest: Iterate idev_ids in mock_domain's alloc_hwpt
  test (jsc#PED-7779 jsc#PED-7780).
- iommufd: Fix spelling errors in comments (jsc#PED-7779
  jsc#PED-7780).
- vfio/mtty: Enable migration support (jsc#PED-7779 jsc#PED-7780).
- vfio/mtty: Overhaul mtty interrupt handling (jsc#PED-7779
  jsc#PED-7780).
- vfio: Fix smatch errors in vfio_combine_iova_ranges()
  (jsc#PED-7779 jsc#PED-7780).
- vfio/cdx: Add parentheses between bitwise AND expression and
  logical NOT (jsc#PED-7779 jsc#PED-7780).
- vfio/mlx5: Activate the chunk mode functionality (jsc#PED-7779
  jsc#PED-7780).
- vfio/mlx5: Add support for READING in chunk mode (jsc#PED-7779
  jsc#PED-7780).
- vfio/mlx5: Add support for SAVING in chunk mode (jsc#PED-7779
  jsc#PED-7780).
- vfio/mlx5: Pre-allocate chunks for the STOP_COPY phase
  (jsc#PED-7779 jsc#PED-7780).
- vfio/mlx5: Rename some stuff to match chunk mode (jsc#PED-7779
  jsc#PED-7780).
- vfio/mlx5: Enable querying state size which is > 4GB
  (jsc#PED-7779 jsc#PED-7780).
- vfio/mlx5: Refactor the SAVE callback to activate a work only
  upon an error (jsc#PED-7779 jsc#PED-7780).
- vfio/mlx5: Wake up the reader post of disabling the SAVING
  migration file (jsc#PED-7779 jsc#PED-7780).
- vfio: use __aligned_u64 in struct vfio_device_ioeventfd
  (jsc#PED-7779 jsc#PED-7780).
- vfio: use __aligned_u64 in struct vfio_device_gfx_plane_info
  (jsc#PED-7779 jsc#PED-7780).
- vfio: trivially use __aligned_u64 for ioctl structs
  (jsc#PED-7779 jsc#PED-7780).
- vfio-cdx: add bus mastering device feature support (jsc#PED-7779
  jsc#PED-7780).
- vfio: add bus master feature to device feature ioctl
  (jsc#PED-7779 jsc#PED-7780).
- cdx: add support for bus mastering (jsc#PED-7779 jsc#PED-7780).
- commit 5461635
* Thu Feb  1 2024 oneukum@suse.com
- PM: sleep: Fix possible deadlocks in core system-wide PM code
  (git-fixes).
- commit 186fd19
* Thu Feb  1 2024 oneukum@suse.com
- async: Introduce async_schedule_dev_nocall() (git-fixes).
- commit 3d2402e
* Thu Feb  1 2024 oneukum@suse.com
- async: Split async_schedule_node_domain() (git-fixes).
- commit 02d0aec
* Thu Feb  1 2024 jslaby@suse.cz
- vfio/pci: Clear VFIO_IRQ_INFO_NORESIZE for MSI-X (jsc#PED-7785).
- vfio/pci: Support dynamic MSI-X (jsc#PED-7785).
- vfio/pci: Probe and store ability to support dynamic MSI-X
  (jsc#PED-7785).
- vfio/pci: Use bitfield for struct vfio_pci_core_device flags
  (jsc#PED-7785).
- vfio/pci: Update stale comment (jsc#PED-7785).
- vfio/pci: Remove interrupt context counter (jsc#PED-7785).
- vfio/pci: Use xarray for interrupt context storage
  (jsc#PED-7785).
- vfio/pci: Move to single error path (jsc#PED-7785).
- vfio/pci: Prepare for dynamic interrupt context storage
  (jsc#PED-7785).
- vfio/pci: Remove negative check on unsigned vector
  (jsc#PED-7785).
- vfio/pci: Consolidate irq cleanup on MSI/MSI-X disable
  (jsc#PED-7785).
- commit bb72f32
* Thu Feb  1 2024 tiwai@suse.de
- serial: sc16is7xx: change EFR lock to operate on each channels
  (git-fixes).
- Refresh
  patches.suse/serial-sc16is7xx-convert-from-_raw_-to-_noinc_-regma.patch.
- commit b43ff48
* Thu Feb  1 2024 tiwai@suse.de
- serial: core: Simplify uart_get_rs485_mode() (git-fixes).
- Refresh
  patches.suse/serial-core-imx-do-not-set-RS485-enabled-if-it-is-no.patch.
- commit 52b3d86
* Thu Feb  1 2024 tiwai@suse.de
- selftests: bonding: do not test arp/ns target with mode
  balance-alb/tlb (git-fixes).
- selftests: netdevsim: fix the udp_tunnel_nic test (git-fixes).
- selftests: net: fix rps_default_mask with >32 CPUs (git-fixes).
- selftest: Don't reuse port for SO_INCOMING_CPU test (git-fixes).
- selftests: bonding: Increase timeout to 1200s (git-fixes).
- nouveau/vmm: don't set addr on the fail path to avoid warning
  (git-fixes).
- rtc: cmos: Use ACPI alarm for non-Intel x86 systems too
  (git-fixes).
- soundwire: fix initializing sysfs for same devices on different
  buses (git-fixes).
- soundwire: bus: introduce controller_id (git-fixes).
- serial: core: set missing supported flag for RX during TX GPIO
  (git-fixes).
- serial: sc16is7xx: convert from _raw_ to _noinc_ regmap
  functions for FIFO (git-fixes).
- serial: sc16is7xx: remove unused line structure member
  (git-fixes).
- serial: sc16is7xx: remove global regmap from struct
  sc16is7xx_port (git-fixes).
- serial: sc16is7xx: remove wasteful static buffer in
  sc16is7xx_regmap_name() (git-fixes).
- serial: sc16is7xx: improve regmap debugfs by using one regmap
  per port (git-fixes).
- iio: adc: ad7091r: Enable internal vref if external vref is
  not supplied (git-fixes).
- thermal: intel: hfi: Add syscore callbacks for system-wide PM
  (git-fixes).
- mmc: mmc_spi: remove custom DMA mapped buffers (git-fixes).
- mmc: core: Use mrq.sbc in close-ended ffu (git-fixes).
- scripts/get_abi: fix source path leak (git-fixes).
- thermal: intel: hfi: Disable an HFI instance when all its CPUs
  go offline (git-fixes).
- thermal: intel: hfi: Refactor enabling code into helper
  functions (git-fixes).
- serial: core: fix kernel-doc for uart_port_unlock_irqrestore()
  (git-fixes).
- serial: sc16is7xx: Use port lock wrappers (git-fixes).
- serial: core: Provide port lock wrappers (git-fixes).
- thermal: trip: Drop lockdep assertion from
  thermal_zone_trip_id() (git-fixes).
- thermal: core: Store trip pointer in struct thermal_instance
  (git-fixes).
- thermal: trip: Drop redundant trips check from
  for_each_thermal_trip() (git-fixes).
- commit 9cd2e11
* Thu Feb  1 2024 tiwai@suse.de
- drm/amdgpu/pm: Fix the power source flag error (git-fixes).
- drm/amd/display: Fix uninitialized variable usage in core_link_
  'read_dpcd() & write_dpcd()' functions (git-fixes).
- gpiolib: acpi: Ignore touchpad wakeup on GPD G1619-04
  (git-fixes).
- drm/amd/display: Align the returned error code with legacy DP
  (git-fixes).
- drm/amd/display: Port DENTIST hang and TDR fixes to OTG disable
  W/A (git-fixes).
- drm/amd/display: Fix late derefrence 'dsc' check in
  'link_set_dsc_pps_packet()' (git-fixes).
- drm/amd/display: Fix variable deferencing before NULL check
  in edp_setup_replay() (git-fixes).
- drm/amdgpu: correct the cu count for gfx v11 (git-fixes).
- iio: adc: ad7091r: Allow users to configure device events
  (git-fixes).
- iio: adc: ad7091r: Set alert bit in config register (git-fixes).
- drm: Don't unref the same fb many times by mistake due to
  deadlock handling (git-fixes).
- drm/panel-edp: drm/panel-edp: Fix AUO B116XTN02 name
  (git-fixes).
- drm/panel-edp: drm/panel-edp: Fix AUO B116XAK01 name and timing
  (git-fixes).
- drm/panel-edp: Add AUO B116XTN02, BOE NT116WHM-N21,836X2,
  NV116WHM-N49 V8.0 (git-fixes).
- docs: kernel_abi.py: fix command injection (git-fixes).
- crypto: api - Disallow identical driver names (git-fixes).
- commit 38dac4b
* Wed Jan 31 2024 msuchanek@suse.de
- kernel-source: Fix description typo
- commit 8abff35
* Wed Jan 31 2024 dwagner@suse.de
- nvmet-tcp: Fix the H2C expected PDU len calculation
  (bsc#1217987 bsc#1217988 bsc#1217989 CVE-2023-6535 CVE-2023-6536
  CVE-2023-6356).
- nvmet-tcp: remove boilerplate code (bsc#1217987 bsc#1217988
  bsc#1217989 CVE-2023-6535 CVE-2023-6536 CVE-2023-6356).
- nvmet-tcp: fix a crash in nvmet_req_complete() (bsc#1217987
  bsc#1217988 bsc#1217989 CVE-2023-6535 CVE-2023-6536
  CVE-2023-6356).
- nvmet-tcp: Fix a kernel panic when host sends an invalid H2C
  PDU length (bsc#1217987 bsc#1217988 bsc#1217989 CVE-2023-6535
  CVE-2023-6536 CVE-2023-6356).
- commit abe1056
* Wed Jan 31 2024 oneukum@suse.com
- usb: typec: tcpm: Fix sink caps op current check (git-fixes).
- commit 0565e82
* Wed Jan 31 2024 oneukum@suse.com
- usb: typec: tcpm: Support multiple capabilities (jsc#PED-6054).
- usb: hub: Replace hardcoded quirk value with BIT() macro
  (jsc#PED-6054).
- commit b09eb06
* Wed Jan 31 2024 oneukum@suse.com
- usb: typec: tcpm: skip checking port->send_discover in PD3.0
  (git-fixes).
- commit 7e54159
* Wed Jan 31 2024 tiwai@suse.de
- maple_tree: update mas_preallocate() testing (bsc#1219404).
- commit 49b074b
* Wed Jan 31 2024 denis.kirjanov@suse.com
- Update config files: disable qlcnic network driver (jsc#PED-6922)
- commit 4671a1d
* Wed Jan 31 2024 jroedel@suse.de
- vfio: Compile vfio_group infrastructure optionally (jsc#PED-7779
  jsc#PED-7780).
- Update config files.
- commit 31c540c
* Wed Jan 31 2024 jwiesner@suse.de
- clocksource: disable watchdog checks on TSC when TSC is watchdog
  (bsc#1215885).
- commit 277f89c
* Wed Jan 31 2024 denis.kirjanov@suse.com
- rswitch: Fix imbalance phy_power_off() calling (git-fixes).
- commit 537c1a6
* Wed Jan 31 2024 denis.kirjanov@suse.com
- rswitch: Fix renesas_eth_sw_remove() implementation (git-fixes).
- commit b476e28
* Wed Jan 31 2024 denis.kirjanov@suse.com
- nfp: flower: avoid rmmod nfp crash issues (git-fixes).
- commit 3a0449b
* Wed Jan 31 2024 denis.kirjanov@suse.com
- net: phy: mscc: macsec: reject PN update requests (git-fixes).
- commit ccf5c28
* Wed Jan 31 2024 denis.kirjanov@suse.com
- mlxsw: fix mlxsw_sp2_nve_vxlan_learning_set() return type
  (git-fixes).
- commit e16a1ab
* Wed Jan 31 2024 jroedel@suse.de
- iommu: Avoid unnecessary cache invalidations (jsc#PED-7779
  jsc#PED-7780).
- iommu/vt-d: Avoid memory allocation in iommu_suspend()
  (jsc#PED-7779 jsc#PED-7780).
- iommu/apple-dart: Handle DMA_FQ domains in attach_dev()
  (jsc#PED-7779 jsc#PED-7780).
- dt-bindings: arm-smmu: Fix SDM630 clocks description
  (jsc#PED-7779 jsc#PED-7780).
- iommu/arm-smmu-v3: Avoid constructing invalid range commands
  (jsc#PED-7779 jsc#PED-7780).
- iommu/mediatek: Fix share pgtable for iova over 4GB
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Explicitly include correct DT includes (jsc#PED-7779
  jsc#PED-7780).
- iommu: Optimise PCI SAC address trick (jsc#PED-7779
  jsc#PED-7780).
- iommu: Avoid locking/unlocking for iommu_probe_device()
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Split iommu_group_add_device() (jsc#PED-7779
  jsc#PED-7780).
- iommu: Always destroy the iommu_group during
  iommu_release_device() (jsc#PED-7779 jsc#PED-7780).
- iommu: Do not export iommu_device_link/unlink() (jsc#PED-7779
  jsc#PED-7780).
- iommu: Move the iommu driver sysfs setup into
  iommu_init/deinit_device() (jsc#PED-7779 jsc#PED-7780).
- iommu: Add iommu_init/deinit_device() paired functions
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Simplify the __iommu_group_remove_device() flow
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Inline iommu_group_get_for_dev() into
  __iommu_probe_device() (jsc#PED-7779 jsc#PED-7780).
- iommu: Use iommu_group_ref_get/put() for dev->iommu_group
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Have __iommu_probe_device() check for already probed
  devices (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Rearrange DTE bit definations (jsc#PED-7779
  jsc#PED-7780).
- iommu/amd: Remove unsued extern declaration
  amd_iommu_init_hardware() (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Enable PPR/GA interrupt after interrupt handler setup
  (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Consolidate PPR log enablement (jsc#PED-7779
  jsc#PED-7780).
- iommu/amd: Disable PPR log/interrupt in iommu_disable()
  (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Enable separate interrupt for PPR and GA log
  (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Refactor IOMMU interrupt handling logic for Event,
  PPR, and GA logs (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Handle PPR log overflow (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Generalize log overflow handling (jsc#PED-7779
  jsc#PED-7780).
- iommu/amd/iommu_v2: Clear pasid state in free path (jsc#PED-7779
  jsc#PED-7780).
- iommu/vt-d: Remove unused extern declaration
  dmar_parse_dev_scope() (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Fix to convert mm pfn to dma pfn (jsc#PED-7779
  jsc#PED-7780).
- iommu/vt-d: Remove rmrr check in domain attaching device path
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Prevent RESV_DIRECT devices from blocking domains
  (jsc#PED-7779 jsc#PED-7780).
- dmaengine/idxd: Re-enable kernel workqueue under DMA API
  (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Add set_dev_pasid callback for dma domain
  (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Prepare for set_dev_pasid callback (jsc#PED-7779
  jsc#PED-7780).
- iommu/vt-d: Make prq draining code generic (jsc#PED-7779
  jsc#PED-7780).
- iommu/vt-d: Remove pasid_mutex (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Add domain_flush_pasid_iotlb() (jsc#PED-7779
  jsc#PED-7780).
- iommu: Move global PASID allocation from SVA to core
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Generalize PASID 0 for normal DMA w/o PASID (jsc#PED-7779
  jsc#PED-7780).
- dt-bindings: arm-smmu: Fix MSM8998 clocks description
  (jsc#PED-7779 jsc#PED-7780).
- dt-bindings: iommu: qcom,iommu: Add QSMMUv2 and MSM8976
  compatibles (jsc#PED-7779 jsc#PED-7780).
- dt-bindings: iommu: qcom,iommu: Add qcom,ctx-asid property
  (jsc#PED-7779 jsc#PED-7780).
- iommu/arm-smmu-qcom: Add SM6375 SMMUv2 (jsc#PED-7779
  jsc#PED-7780).
- iommu/arm-smmu-qcom: Add SM6350 DPU compatible (jsc#PED-7779
  jsc#PED-7780).
- iommu/arm-smmu-qcom: Add SM6375 DPU compatible (jsc#PED-7779
  jsc#PED-7780).
- iommu/arm-smmu-qcom: Sort the compatible list alphabetically
  (jsc#PED-7779 jsc#PED-7780).
- iommu/qcom: Add support for QSMMUv2 and QSMMU-500 secured
  contexts (jsc#PED-7779 jsc#PED-7780).
- iommu/qcom: Index contexts by asid number to allow asid 0
  (jsc#PED-7779 jsc#PED-7780).
- iommu/qcom: Use the asid read from device-tree if specified
  (jsc#PED-7779 jsc#PED-7780).
- iommu/arm-smmu: Clean up resource handling during Qualcomm
  context probe (jsc#PED-7779 jsc#PED-7780).
- iommu/arm-smmu-v3: Change vmid alloc strategy from bitmap to
  ida (jsc#PED-7779 jsc#PED-7780).
- iommu: rockchip: Allocate tables from all available memory
  for IOMMU v2 (jsc#PED-7779 jsc#PED-7780).
- iommu/ipmmu-vmsa: Allow PCIe devices (jsc#PED-7779
  jsc#PED-7780).
- iommu/ipmmu-vmsa: Convert to read_poll_timeout_atomic()
  (jsc#PED-7779 jsc#PED-7780).
- MAINTAINERS: iommu/mediatek: Update the header file name
  (jsc#PED-7779 jsc#PED-7780).
- iommu/mediatek: mt8188: Add iova_region_larb_msk (jsc#PED-7779
  jsc#PED-7780).
- iommu/mediatek: Add MT8188 IOMMU Support (jsc#PED-7779
  jsc#PED-7780).
- iommu/mediatek: Add enable IOMMU SMC command for INFRA masters
  (jsc#PED-7779 jsc#PED-7780).
- iommu/mediatek: Adjust mtk_iommu_config flow (jsc#PED-7779
  jsc#PED-7780).
- dt-bindings: mediatek: mt8188: Add binding for MM & INFRA IOMMU
  (jsc#PED-7779 jsc#PED-7780).
- iommu/apple-dart: mark apple_dart_pm_ops static (jsc#PED-7779
  jsc#PED-7780).
- iommufd/selftest: Don't leak the platform device memory when
  unloading the module (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Implement hw_info for iommu capability query
  (jsc#PED-7779 jsc#PED-7780).
- iommufd/selftest: Add coverage for IOMMU_GET_HW_INFO ioctl
  (jsc#PED-7779 jsc#PED-7780).
- iommufd: Add IOMMU_GET_HW_INFO (jsc#PED-7779 jsc#PED-7780).
- iommu: Add new iommu op to get iommu hardware information
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Move dev_iommu_ops() to private header (jsc#PED-7779
  jsc#PED-7780).
- iommufd: Remove iommufd_ref_to_users() (jsc#PED-7779
  jsc#PED-7780).
- iommufd/selftest: Make the mock iommu driver into a real driver
  (jsc#PED-7779 jsc#PED-7780).
- vfio: Support IO page table replacement (jsc#PED-7779
  jsc#PED-7780).
- iommufd/selftest: Add IOMMU_TEST_OP_ACCESS_REPLACE_IOAS coverage
  (jsc#PED-7779 jsc#PED-7780).
- iommufd: Add iommufd_access_replace() API (jsc#PED-7779
  jsc#PED-7780).
- iommufd: Use iommufd_access_change_ioas in
  iommufd_access_destroy_object (jsc#PED-7779 jsc#PED-7780).
- iommufd: Add iommufd_access_change_ioas(_id) helpers
  (jsc#PED-7779 jsc#PED-7780).
- iommufd: Allow passing in iopt_access_list_id to
  iopt_remove_access() (jsc#PED-7779 jsc#PED-7780).
- vfio: Do not allow !ops->dma_unmap in vfio_pin/unpin_pages()
  (jsc#PED-7779 jsc#PED-7780).
- iommufd/selftest: Add a selftest for IOMMU_HWPT_ALLOC
  (jsc#PED-7779 jsc#PED-7780).
- iommufd/selftest: Return the real idev id from selftest
  mock_domain (jsc#PED-7779 jsc#PED-7780).
- iommufd: Add IOMMU_HWPT_ALLOC (jsc#PED-7779 jsc#PED-7780).
- iommufd/selftest: Test iommufd_device_replace() (jsc#PED-7779
  jsc#PED-7780).
- iommufd: Make destroy_rwsem use a lock class per object type
  (jsc#PED-7779 jsc#PED-7780).
- iommufd: Add iommufd_device_replace() (jsc#PED-7779
  jsc#PED-7780).
- iommu: Introduce a new iommu_group_replace_domain() API
  (jsc#PED-7779 jsc#PED-7780).
- iommufd: Reorganize iommufd_device_attach into
  iommufd_device_change_pt (jsc#PED-7779 jsc#PED-7780).
- iommufd: Fix locking around hwpt allocation (jsc#PED-7779
  jsc#PED-7780).
- iommufd: Allow a hwpt to be aborted after allocation
  (jsc#PED-7779 jsc#PED-7780).
- iommufd: Add enforced_cache_coherency to
  iommufd_hw_pagetable_alloc() (jsc#PED-7779 jsc#PED-7780).
- iommufd: Move putting a hwpt to a helper function (jsc#PED-7779
  jsc#PED-7780).
- iommufd: Make sw_msi_start a group global (jsc#PED-7779
  jsc#PED-7780).
- iommufd: Use the iommufd_group to avoid duplicate MSI setup
  (jsc#PED-7779 jsc#PED-7780).
- iommufd: Keep track of each device's reserved regions instead
  of groups (jsc#PED-7779 jsc#PED-7780).
- iommu: Export iommu_get_resv_regions() (jsc#PED-7779
  jsc#PED-7780).
- iommufd: Replace the hwpt->devices list with iommufd_group
  (jsc#PED-7779 jsc#PED-7780).
- iommufd: Add iommufd_group (jsc#PED-7779 jsc#PED-7780).
- iommufd: Move isolated msi enforcement to iommufd_device_bind()
  (jsc#PED-7779 jsc#PED-7780).
- vfio/pds: Send type for SUSPEND_STATUS command (jsc#PED-7779
  jsc#PED-7780).
- vfio/pds: fix return value in pds_vfio_get_lm_file()
  (jsc#PED-7779 jsc#PED-7780).
- pds_core: Fix function header descriptions (jsc#PED-7779
  jsc#PED-7780).
- vfio: align capability structures (jsc#PED-7779 jsc#PED-7780).
- vfio/type1: fix cap_migration information leak (jsc#PED-7779
  jsc#PED-7780).
- vfio/fsl-mc: Use module_fsl_mc_driver macro to simplify the code
  (jsc#PED-7779 jsc#PED-7780).
- vfio/cdx: Remove redundant initialization owner in
  vfio_cdx_driver (jsc#PED-7779 jsc#PED-7780).
- vfio/pds: Add Kconfig and documentation (jsc#PED-7779
  jsc#PED-7780).
- vfio/pds: Add support for firmware recovery (jsc#PED-7779
  jsc#PED-7780).
- vfio/pds: Add support for dirty page tracking (jsc#PED-7779
  jsc#PED-7780).
- vfio/pds: Add VFIO live migration support (jsc#PED-7779
  jsc#PED-7780).
- vfio/pds: register with the pds_core PF (jsc#PED-7779
  jsc#PED-7780).
- pds_core: Require callers of register/unregister to pass PF
  drvdata (jsc#PED-7779 jsc#PED-7780).
- vfio/pds: Initial support for pds VFIO driver (jsc#PED-7779
  jsc#PED-7780).
- vfio: Commonize combine_ranges for use in other VFIO drivers
  (jsc#PED-7779 jsc#PED-7780).
- kvm/vfio: avoid bouncing the mutex when adding and deleting
  groups (jsc#PED-7779 jsc#PED-7780).
- kvm/vfio: ensure kvg instance stays around in
  kvm_vfio_group_add() (jsc#PED-7779 jsc#PED-7780).
- docs: vfio: Add vfio device cdev description (jsc#PED-7779
  jsc#PED-7780).
- vfio: Move the IOMMU_CAP_CACHE_COHERENCY check in
  __vfio_register_dev() (jsc#PED-7779 jsc#PED-7780).
- vfio: Add VFIO_DEVICE_[AT|DE]TACH_IOMMUFD_PT (jsc#PED-7779
  jsc#PED-7780).
- vfio: Add VFIO_DEVICE_BIND_IOMMUFD (jsc#PED-7779 jsc#PED-7780).
- vfio: Avoid repeated user pointer cast in
  vfio_device_fops_unl_ioctl() (jsc#PED-7779 jsc#PED-7780).
- iommufd: Add iommufd_ctx_from_fd() (jsc#PED-7779 jsc#PED-7780).
- vfio: Test kvm pointer in _vfio_device_get_kvm_safe()
  (jsc#PED-7779 jsc#PED-7780).
- vfio: Add cdev for vfio_device (jsc#PED-7779 jsc#PED-7780).
- vfio: Move device_del() before waiting for the last vfio_device
  registration refcount (jsc#PED-7779 jsc#PED-7780).
- vfio: Move vfio_device_group_unregister() to be the first
  operation in unregister (jsc#PED-7779 jsc#PED-7780).
- vfio-iommufd: Add detach_ioas support for emulated VFIO devices
  (jsc#PED-7779 jsc#PED-7780).
- iommufd/device: Add iommufd_access_detach() API (jsc#PED-7779
  jsc#PED-7780).
- vfio-iommufd: Add detach_ioas support for physical VFIO devices
  (jsc#PED-7779 jsc#PED-7780).
- vfio: Record devid in vfio_device_file (jsc#PED-7779
  jsc#PED-7780).
- vfio-iommufd: Split bind/attach into two steps (jsc#PED-7779
  jsc#PED-7780).
- vfio-iommufd: Move noiommu compat validation out of
  vfio_iommufd_bind() (jsc#PED-7779 jsc#PED-7780).
- vfio: Make vfio_df_open() single open for device cdev path
  (jsc#PED-7779 jsc#PED-7780).
- vfio: Add cdev_device_open_cnt to vfio_group (jsc#PED-7779
  jsc#PED-7780).
- vfio: Block device access via device fd until device is opened
  (jsc#PED-7779 jsc#PED-7780).
- vfio: Pass struct vfio_device_file * to vfio_device_open/close()
  (jsc#PED-7779 jsc#PED-7780).
- kvm/vfio: Accept vfio device file from userspace (jsc#PED-7779
  jsc#PED-7780).
- kvm/vfio: Prepare for accepting vfio device fd (jsc#PED-7779
  jsc#PED-7780).
- vfio: Accept vfio device file in the KVM facing kAPI
  (jsc#PED-7779 jsc#PED-7780).
- vfio: Refine vfio file kAPIs for KVM (jsc#PED-7779
  jsc#PED-7780).
- vfio: Allocate per device file structure (jsc#PED-7779
  jsc#PED-7780).
- vfio/pci: Allow passing zero-length fd array in
  VFIO_DEVICE_PCI_HOT_RESET (jsc#PED-7779 jsc#PED-7780).
- vfio/pci: Copy hot-reset device info to userspace in the
  devices loop (jsc#PED-7779 jsc#PED-7780).
- vfio/pci: Extend VFIO_DEVICE_GET_PCI_HOT_RESET_INFO for vfio
  device cdev (jsc#PED-7779 jsc#PED-7780).
- vfio: Add helper to search vfio_device in a dev_set
  (jsc#PED-7779 jsc#PED-7780).
- vfio: Mark cdev usage in vfio_device (jsc#PED-7779
  jsc#PED-7780).
- iommufd: Add helper to retrieve iommufd_ctx and devid
  (jsc#PED-7779 jsc#PED-7780).
- iommufd: Add iommufd_ctx_has_group() (jsc#PED-7779
  jsc#PED-7780).
- iommufd: Reserve all negative IDs in the iommufd xarray
  (jsc#PED-7779 jsc#PED-7780).
- vfio/pci: Move the existing hot reset logic to be a helper
  (jsc#PED-7779 jsc#PED-7780).
- vfio/pci: Update comment around group_fd get in
  vfio_pci_ioctl_pci_hot_reset() (jsc#PED-7779 jsc#PED-7780).
- commit 5a8a192
* Wed Jan 31 2024 nik.borisov@suse.com
- x86/tsc: Extend watchdog check exemption to 4-Sockets platform (jsc#PED-7786).
- commit 8c26887
* Wed Jan 31 2024 denis.kirjanov@suse.com
- qlcnic: replace deprecated strncpy with strscpy (jsc#PED-6886).
- commit 2cd64fa
* Wed Jan 31 2024 oneukum@suse.com
- drivers: base: Free devm resources when unregistering a device
  (jsc#PED-6054)
- Refresh
  patches.suse/kernfs-fix-missing-kernfs_iattr_rwsem-locking.patch.
- commit 1ff927f
* Wed Jan 31 2024 oneukum@suse.com
- lib/string_helpers: Add kstrdup_and_replace() helper
  (jsc#PED-6054).
- commit 425f257
* Wed Jan 31 2024 jroedel@suse.de
- vfio/cdx: add support for CDX bus (jsc#PED-7779 jsc#PED-7780).
- Update config files.
- commit 1dda3a4
* Wed Jan 31 2024 jroedel@suse.de
- vfio/platform: Cleanup Kconfig (jsc#PED-7779 jsc#PED-7780).
- Update config files.
- commit 20a24ad
* Wed Jan 31 2024 jroedel@suse.de
- vfio/fsl: Create Kconfig sub-menu (jsc#PED-7779 jsc#PED-7780).
- vfio/pci: Cleanup Kconfig (jsc#PED-7779 jsc#PED-7780).
- vfio/pci-core: Add capability for AtomicOp completer support
  (jsc#PED-7779 jsc#PED-7780).
- vfio/pci: Also demote hiding standard cap messages (jsc#PED-7779
  jsc#PED-7780).
- vfio/pci: Clear VFIO_IRQ_INFO_NORESIZE for MSI-X (jsc#PED-7779
  jsc#PED-7780).
- vfio/pci: Support dynamic MSI-X (jsc#PED-7779 jsc#PED-7780).
- vfio/pci: Probe and store ability to support dynamic MSI-X
  (jsc#PED-7779 jsc#PED-7780).
- vfio/pci: Use bitfield for struct vfio_pci_core_device flags
  (jsc#PED-7779 jsc#PED-7780).
- vfio/pci: Update stale comment (jsc#PED-7779 jsc#PED-7780).
- vfio/pci: Remove interrupt context counter (jsc#PED-7779
  jsc#PED-7780).
- vfio/pci: Use xarray for interrupt context storage (jsc#PED-7779
  jsc#PED-7780).
- vfio/pci: Move to single error path (jsc#PED-7779 jsc#PED-7780).
- vfio/pci: Prepare for dynamic interrupt context storage
  (jsc#PED-7779 jsc#PED-7780).
- vfio/pci: Remove negative check on unsigned vector (jsc#PED-7779
  jsc#PED-7780).
- vfio/pci: Consolidate irq cleanup on MSI/MSI-X disable
  (jsc#PED-7779 jsc#PED-7780).
- vfio/pci: demote hiding ecap messages to debug level
  (jsc#PED-7779 jsc#PED-7780).
- commit 35c9b4b
* Wed Jan 31 2024 jroedel@suse.de
- iommu: Fix crash during syfs iommu_groups/N/type (jsc#PED-7779
  jsc#PED-7780).
- commit ccef64e
* Wed Jan 31 2024 oneukum@suse.com
- device property: Clarify usage scope of some struct
  fwnode_handle members (jsc#PED-6054).
- commit a9856b6
* Wed Jan 31 2024 jroedel@suse.de
- iommu/amd: Remove extern from function prototypes (jsc#PED-7779
  jsc#PED-7780).
- iommu/amd: Use BIT/BIT_ULL macro to define bit fields
  (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Fix DTE_IRQ_PHYS_ADDR_MASK macro (jsc#PED-7779
  jsc#PED-7780).
- iommu/amd: Fix compile error for unused function (jsc#PED-7779
  jsc#PED-7780).
- iommu/amd: Improving Interrupt Remapping Table Invalidation
  (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Do not Invalidate IRT when IRTE caching is disabled
  (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Remove the unused struct amd_ir_data.ref
  (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Switch amd_iommu_update_ga() to use modify_irte_ga()
  (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Update copyright notice (jsc#PED-7779 jsc#PED-7780).
- iommu/amd: Use page mode macros in fetch_pte() (jsc#PED-7779
  jsc#PED-7780).
- iommu: Tidy the control flow in iommu_group_store_type()
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Remove __iommu_group_for_each_dev() (jsc#PED-7779
  jsc#PED-7780).
- iommu: Allow IOMMU_RESV_DIRECT to work on ARM (jsc#PED-7779
  jsc#PED-7780).
- iommu: Consolidate the default_domain setup to one function
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Revise iommu_group_alloc_default_domain() (jsc#PED-7779
  jsc#PED-7780).
- iommu: Consolidate the code to calculate the target default
  domain type (jsc#PED-7779 jsc#PED-7780).
- iommu: Remove the assignment of group->domain during default
  domain alloc (jsc#PED-7779 jsc#PED-7780).
- iommu: Do iommu_group_create_direct_mappings() before attach
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Fix iommu_probe_device() to attach the right domain
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Replace iommu_group_do_dma_first_attach with
  __iommu_device_set_domain (jsc#PED-7779 jsc#PED-7780).
- iommu: Remove iommu_group_do_dma_first_attach() from
  iommu_group_add_device() (jsc#PED-7779 jsc#PED-7780).
- iommu: Replace __iommu_group_dma_first_attach() with set_domain
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Use __iommu_group_set_domain() in
  iommu_change_dev_def_domain() (jsc#PED-7779 jsc#PED-7780).
- iommu: Use __iommu_group_set_domain() for __iommu_attach_group()
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Make __iommu_group_set_domain() handle error unwind
  (jsc#PED-7779 jsc#PED-7780).
- iommu: Add for_each_group_device() (jsc#PED-7779 jsc#PED-7780).
- iommu: Replace iommu_group_device_count() with
  list_count_nodes() (jsc#PED-7779 jsc#PED-7780).
- iommu: Suppress empty whitespaces in prints (jsc#PED-7779
  jsc#PED-7780).
- iommu: Use flush queue capability (jsc#PED-7779 jsc#PED-7780).
- iommu: Add a capability for flush queue support (jsc#PED-7779
  jsc#PED-7780).
- iommu/iova: Optimize iova_magazine_alloc() (jsc#PED-7779
  jsc#PED-7780).
- iommu/vt-d: Remove commented-out code (jsc#PED-7779
  jsc#PED-7780).
- iommu/vt-d: Remove two WARN_ON in domain_context_mapping_one()
  (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Handle the failure case of dmar_reenable_qi()
  (jsc#PED-7779 jsc#PED-7780).
- iommu/vt-d: Remove unnecessary (void*) conversions (jsc#PED-7779
  jsc#PED-7780).
- iommu/fsl: Use driver_managed_dma to allow VFIO to work
  (jsc#PED-7779 jsc#PED-7780).
- iommu/fsl: Move ENODEV to fsl_pamu_probe_device() (jsc#PED-7779
  jsc#PED-7780).
- iommu/fsl: Always allocate a group for non-pci devices
  (jsc#PED-7779 jsc#PED-7780).
- dt-bindings: arm-smmu: Add SDX75 SMMU compatible (jsc#PED-7779
  jsc#PED-7780).
- dt-bindings: arm-smmu: Add SM6375 GPU SMMU (jsc#PED-7779
  jsc#PED-7780).
- dt-bindings: iommu: arm,smmu: enable clocks for sa8775p Adreno
  SMMU (jsc#PED-7779 jsc#PED-7780).
- iommu/arm-smmu-v3: Set TTL invalidation hint better
  (jsc#PED-7779 jsc#PED-7780).
- commit 9bad5bb
* Wed Jan 31 2024 oneukum@suse.com
- driver core: make device_is_dependent() static (jsc#PED-6054).
- commit d020041
* Wed Jan 31 2024 oneukum@suse.com
- driver core: Replace kstrdup() + strreplace() with
  kstrdup_and_replace() (jsc#PED-6054).
- commit 3214968
* Wed Jan 31 2024 oneukum@suse.com
- usb: typec: tcpm: Refactor the PPS APDO selection
  (jsc#PED-6054).
- commit ec52f17
* Wed Jan 31 2024 oneukum@suse.com
- usb: typec: tcpm: add get max power support (jsc#PED-6054).
- usb: typec: tcpm: fix cc role at port reset (git-fixes).
- commit 0ea7d31
* Wed Jan 31 2024 oneukum@suse.com
- usb: typec: change altmode SVID to u16 entry (jsc#PED-6054).
- commit 37d29a2
* Wed Jan 31 2024 oneukum@suse.com
- usb: typec: tcpm: add tcpm_port_error_recovery symbol
  (jsc#PED-6054).
- commit a85d742
* Wed Jan 31 2024 oneukum@suse.com
- usb: typec: intel_pmc_mux: enable sysfs usb role access
  (jsc#PED-6054).
- commit 8dfd45f
* Wed Jan 31 2024 oneukum@suse.com
- usb: typec: tcpm: reset counter when enter into unattached
  state after try role (git-fixes).
- commit e166f48
* Wed Jan 31 2024 oneukum@suse.com
- usb: typec: tcpm: not sink vbus if operational current is 0mA
  (git-fixes).
- commit ca613ac
* Wed Jan 31 2024 nik.borisov@suse.com
- cpu/hotplug: Increase the number of dynamic states (jsc#PED-7789).
- commit c2f3ebe
* Wed Jan 31 2024 oneukum@suse.com
- thunderbolt: Keep link as asymmetric if preferred by hardware
  (jsc#PED-6054).
- commit 49c8848
* Wed Jan 31 2024 oneukum@suse.com
- thunderbolt: Disable PCIe extended encapsulation upon teardown
  properly (jsc#PED-6054).
- commit 46ca554
* Wed Jan 31 2024 oneukum@suse.com
- thunderbolt: Make PCIe tunnel setup and teardown follow CM guide
  (jsc#PED-6054).
- commit 8e6fc8d
* Tue Jan 30 2024 oneukum@suse.com
- thunderbolt: Improve logging when DisplayPort resource is
  added due to hotplug (jsc#PED-6054).
- commit d195201
* Tue Jan 30 2024 petr.pavlu@suse.com
- tracing: Add kabi placeholders (git-fixes).
- commit fe66dad
* Tue Jan 30 2024 osalvador@suse.de
- kernel/crash_core.c: make __crash_hotplug_lock static
  (git-fixes).
- commit b795e50
* Tue Jan 30 2024 tiwai@suse.de
- Update config files: disable CONFIG_USELIB (bsc#1219222)
  It's only for the old libc5. Let's reduce the possible attack surfaces.
- commit a92262c
* Tue Jan 30 2024 osalvador@suse.de
- kexec: drop dependency on ARCH_SUPPORTS_KEXEC from CRASH_DUMP
  (git-fixes).
- commit 2b8e009
* Tue Jan 30 2024 oneukum@suse.com
- thunderbolt: Use tb_dp_read_cap() to read DP_COMMON_CAP as well
  (jsc#PED-6054).
- commit 817c431
* Tue Jan 30 2024 oneukum@suse.com
- thunderbolt: Disable CL states only when actually needed
  (jsc#PED-6054).
- commit 12f7c4b
* Tue Jan 30 2024 oneukum@suse.com
- thunderbolt: Transition link to asymmetric only when both
  sides support it (jsc#PED-6054).
- commit c0db739
* Tue Jan 30 2024 oneukum@suse.com
- thunderbolt: Log XDomain link speed and width (jsc#PED-6054).
- thunderbolt: Move width_name() helper to tb.h (jsc#PED-6054).
- commit 3864ca8
* Tue Jan 30 2024 tiwai@suse.de
- wifi: brcmfmac: Fix use-after-free bug in brcmf_cfg80211_detach
  (CVE-2023-47233 bsc#1216702).
- commit 358e411
* Tue Jan 30 2024 oneukum@suse.com
- thunderbolt: Handle lane bonding of Gen 4 XDomain links properly
  (jsc#PED-6054).
- commit 903c24d
* Tue Jan 30 2024 oneukum@suse.com
- thunderbolt: Unwind TMU configuration if
  tb_switch_set_tmu_mode_params() fails (jsc#PED-6054).
- commit beff1a5
* Tue Jan 30 2024 denis.kirjanov@suse.com
- net: dsa: qca8k: fix potential MDIO bus conflict when accessing
  internal PHYs via management frames (git-fixes).
- commit 652abc9
* Tue Jan 30 2024 oneukum@suse.com
- thunderbolt: Remove duplicated re-assignment of pointer 'out'
  (jsc#PED-6054).
- commit 051cc47
* Tue Jan 30 2024 denis.kirjanov@suse.com
- net: dsa: qca8k: fix regmap bulk read/write methods on big
  endian systems (git-fixes).
- commit 72d26f3
* Tue Jan 30 2024 denis.kirjanov@suse.com
- net: ethernet: mediatek: disable irq before schedule napi
  (git-fixes).
- commit be9ea94
* Tue Jan 30 2024 denis.kirjanov@suse.com
- net: stmmac: dwmac-stm32: fix resume on STM32 MCU (git-fixes).
- commit 70db3b0
* Tue Jan 30 2024 denis.kirjanov@suse.com
- net: ethernet: ti: am65-cpsw: Fix error code in
  am65_cpsw_nuss_init_tx_chns() (git-fixes).
- commit 654c23c
* Tue Jan 30 2024 denis.kirjanov@suse.com
- rswitch: Fix PHY station management clock setting (git-fixes).
- commit b773ebb
* Tue Jan 30 2024 denis.kirjanov@suse.com
- sky2: Make sure there is at least one frag_addr available
  (git-fixes).
- commit 77a9b4b
* Tue Jan 30 2024 denis.kirjanov@suse.com
- net: dsa: mv88e6xxx: Avoid EEPROM timeout when EEPROM is absent
  (git-fixes).
- commit 9713936
* Tue Jan 30 2024 denis.kirjanov@suse.com
- drivers/net: process the result of hdlc_open() and add call
  of hdlc_close() in uhdlc_close() (git-fixes).
- commit 09258c6
* Tue Jan 30 2024 denis.kirjanov@suse.com
- net: hinic: Fix warning-hinic_set_vlan_fliter() warn: variable
  dereferenced before check 'hwdev' (git-fixes).
- commit 6fc3024
* Tue Jan 30 2024 tbogendoerfer@suse.de
- net/mlx5e: fix a potential double-free in fs_any_create_groups
  (jsc#PED-3311).
- net/mlx5e: fix a double-free in arfs_create_groups
  (jsc#PED-3311).
- net/mlx5e: Ignore IPsec replay window values on sender side
  (jsc#PED-3311).
- net/mlx5e: Allow software parsing when IPsec crypto is enabled
  (jsc#PED-3311).
- net/mlx5: Use mlx5 device constant for selecting CQ period
  mode for ASO (jsc#PED-3311).
- net/mlx5: DR, Can't go to uplink vport on RX rule
  (jsc#PED-3311).
- net/mlx5: DR, Use the right GVMI number for drop action
  (jsc#PED-3311).
- net/mlx5: Bridge, fix multicast packets sent to uplink
  (jsc#PED-3311).
- net/mlx5: Fix a WARN upon a callback command failure
  (jsc#PED-3311).
- net/mlx5e: Fix peer flow lists handling (jsc#PED-3311).
- net/mlx5e: Fix inconsistent hairpin RQT sizes (jsc#PED-3311).
- net/mlx5e: Fix operation precedence bug in port timestamping
  napi_poll context (jsc#PED-3311).
- net/mlx5: Fix query of sd_group field (jsc#PED-3311).
- net/mlx5e: Use the correct lag ports number when creating TISes
  (jsc#PED-3311).
- i40e: update xdp_rxq_info::frag_size for ZC enabled Rx queue
  (jsc#PED-4874).
- i40e: set xdp_rxq_info::frag_size (jsc#PED-4874).
- ice: update xdp_rxq_info::frag_size for ZC enabled Rx queue
  (jsc#PED-4876).
- intel: xsk: initialize skb_frag_t::bv_offset in ZC drivers
  (jsc#PED-4874).
- ice: remove redundant xdp_rxq_info registration (jsc#PED-4876).
- i40e: handle multi-buffer packets that are shrunk by xdp prog
  (jsc#PED-4874).
- ice: work on pre-XDP prog frag count (jsc#PED-4876).
- xsk: make xsk_buff_pool responsible for clearing xdp_buff::flags
  (jsc#PED-4874).
- net: fill in MODULE_DESCRIPTION()s for rvu_mbox (jsc#PED-6931).
- dpll: fix register pin with unregistered parent pin
  (jsc#PED-6079).
- dpll: fix userspace availability of pins (jsc#PED-6079).
- dpll: fix pin dump crash for rebound module (jsc#PED-6079).
- dpll: fix broken error path in
  dpll_pin_alloc(..) (jsc#PED-6079).
- idpf: distinguish vports by the dev_port attribute
  (jsc#PED-6716).
- bnxt_en: Fix possible crash after creating sw mqprio TCs
  (jsc#PED-7574).
- bnxt_en: Prevent kernel warning when running offline self test
  (jsc#PED-7574).
- bnxt_en: Fix RSS table entries calculation for P5_PLUS chips
  (jsc#PED-7574).
- bnxt_en: Fix memory leak in bnxt_hwrm_get_rings()
  (jsc#PED-7574).
- bnxt_en: Wait for FLR to complete during probe (jsc#PED-7574).
- RDMA/efa: Add EFA query MR support (jsc#PED-6864).
- RDMA/erdma: Add hardware statistics support (jsc#PED-6864).
- RDMA/erdma: Introduce dma pool for hardware responses of CMDQ
  requests (jsc#PED-6864).
- IB/iser: iscsi_iser.h: fix kernel-doc warning and spellos
  (jsc#PED-6864).
- IB/ipoib: Fix mcast list locking (jsc#PED-6864).
- RDMA/hns: Add a max length of gid table (jsc#PED-6864).
- RDMA/hns: Response dmac to userspace (jsc#PED-6864).
- RDMA/hns: Rename the interrupts (jsc#PED-6864).
- RDMA/siw: Call orq_get_current if possible (jsc#PED-6864).
- RDMA/siw: Set qp_state in siw_query_qp (jsc#PED-6864).
- RDMA/siw: Reduce memory usage of struct siw_rx_stream
  (jsc#PED-6864).
- RDMA/siw: Move tx_cpu ahead (jsc#PED-6864).
- RDMA/IPoIB: Add tx timeout work to recover queue stop situation
  (jsc#PED-6864).
- RDMA/IPoIB: Fix error code return in ipoib_mcast_join
  (jsc#PED-6864).
- RDMA/rtrs: Use %%pe to print errors (jsc#PED-6864).
- RDMA/rtrs-clt: Use %%pe to print errors (jsc#PED-6864).
- RDMA/rtrs-clt: Add warning logs for RDMA events (jsc#PED-6864).
- RDMA/hns: Support SW stats with debugfs (jsc#PED-6864).
- RDMA/hns: Add debugfs to hns RoCE (jsc#PED-6864).
- RDMA/siw: Update comments for siw_qp_sq_process (jsc#PED-6864).
- RDMA/siw: Introduce siw_destroy_cep_sock (jsc#PED-6864).
- RDMA/siw: Only check attrs->cap.max_send_wr in siw_create_qp
  (jsc#PED-6864).
- RDMA/siw: Fix typo (jsc#PED-6864).
- RDMA/siw: Remove siw_sk_save_upcalls (jsc#PED-6864).
- RDMA/siw: Cleanup siw_accept (jsc#PED-6864).
- RDMA/siw: Introduce siw_free_cm_id (jsc#PED-6864).
- RDMA/siw: Introduce siw_cep_set_free_and_put (jsc#PED-6864).
- RDMA/siw: Add one parameter to siw_destroy_cpulist
  (jsc#PED-6864).
- RDMA/siw: Introduce SIW_STAG_MAX_INDEX (jsc#PED-6864).
- RDMA/siw: Factor out siw_rx_data helper (jsc#PED-6864).
- RDMA/siw: No need to check term_info.valid before call
  siw_send_terminate (jsc#PED-6864).
- RDMA/siw: Remove rcu from siw_qp (jsc#PED-6864).
- RDMA/siw: Remove goto lable in siw_mmap (jsc#PED-6864).
- RDMA/siw: Use iov.iov_len in kernel_sendmsg (jsc#PED-6864).
- RDMA/siw: Introduce siw_update_skb_rcvd (jsc#PED-6864).
- RDMA/siw: Introduce siw_get_page (jsc#PED-6864).
- RDMA/irdma: Use crypto_shash_digest() in
  irdma_ieq_check_mpacrc() (jsc#PED-4862).
- RDMA/siw: Use crypto_shash_digest() in siw_qp_prepare_tx()
  (jsc#PED-6864).
- RDMA/hfi1: Copy userspace arrays safely (jsc#PED-6864).
- RDMA/siw: Use ib_umem_get() to pin user pages (jsc#PED-6864).
- vsock/virtio: use skb_frag_*() helpers (jsc#PED-5505).
- virtio/vsock: send credit update during setting SO_RCVLOWAT
  (jsc#PED-5505).
- virtio/vsock: fix logic which reduces credit update messages
  (jsc#PED-5505).
- gve: Remove dependency on 4k page size (bsc#1214479).
- gve: Add page size register to the register_page_list command
  (bsc#1214479).
- gve: Remove obsolete checks that rely on page size
  (bsc#1214479).
- gve: Deprecate adminq_pfn for pci revision 0x1 (bsc#1214479).
- gve: Perform adminq allocations through a dma_pool
  (bsc#1214479).
- gve: add gve_features_check() (bsc#1214479).
- PCI: Add Alibaba Vendor ID to linux/pci_ids.h (jsc#PED-6864).
- vsock/virtio: fix "comparison of distinct pointer types lacks
  a cast" warning (jsc#PED-5505).
- net: fill in MODULE_DESCRIPTION()s for SOCK_DIAG modules
  (jsc#PED-5505).
- virtio/vsock: Fix uninit-value in virtio_transport_recv_pkt()
  (jsc#PED-5505).
- RDMA: Annotate struct rdma_hw_stats with __counted_by
  (jsc#PED-6864).
- vsock: enable setting SO_ZEROCOPY (jsc#PED-5505).
- vsock/loopback: support MSG_ZEROCOPY for transport
  (jsc#PED-5505).
- vsock/virtio: support MSG_ZEROCOPY for transport (jsc#PED-5505).
- vhost/vsock: support MSG_ZEROCOPY for transport (jsc#PED-5505).
- vsock: enable SOCK_SUPPORT_ZC bit (jsc#PED-5505).
- vsock: check for MSG_ZEROCOPY support on send (jsc#PED-5505).
- vsock: read from socket's error queue (jsc#PED-5505).
- vsock: set EPOLLERR on non-empty error queue (jsc#PED-5505).
- vsock/virtio: MSG_ZEROCOPY flag support (jsc#PED-5505).
- vsock/virtio: non-linear skb handling for tap (jsc#PED-5505).
- vsock/virtio: support to send non-linear skb (jsc#PED-5505).
- vsock/virtio/vhost: read data from non-linear skb
  (jsc#PED-5505).
- vsock: send SIGPIPE on write to shutdowned socket
  (jsc#PED-5505).
- vsock: Remove unused function declarations (jsc#PED-5505).
- virtio/vsock: support MSG_PEEK for SOCK_SEQPACKET
  (jsc#PED-5505).
- virtio/vsock: rework MSG_PEEK for SOCK_STREAM (jsc#PED-5505).
- commit 0dfd8ae
* Tue Jan 30 2024 iivanov@suse.de
- arm64: entry: fix ARM64_WORKAROUND_SPECULATIVE_UNPRIV_LOAD (git-fixes)
- commit a6327d2
* Tue Jan 30 2024 iivanov@suse.de
- arm64: entry: Simplify tramp_alias macro and tramp_exit routine (git-fixes)
- commit 33427e9
* Tue Jan 30 2024 petr.pavlu@suse.com
- tracing/trigger: Fix to return error if failed to alloc snapshot
  (git-fixes).
- commit 5235870
* Tue Jan 30 2024 petr.pavlu@suse.com
- tracing: Ensure visibility when inserting an element into
  tracing_map (git-fixes).
- commit 8d0199c
* Tue Jan 30 2024 petr.pavlu@suse.com
- bpf: Limit the number of kprobes when attaching program to
  multiple kprobes (git-fixes).
- commit 405ad58
* Tue Jan 30 2024 petr.pavlu@suse.com
- ring-buffer: Do not record in NMI if the arch does not support
  cmpxchg in NMI (git-fixes).
- commit 5299cd1
* Tue Jan 30 2024 petr.pavlu@suse.com
- tracing: Fix uaf issue when open the hist or hist_debug file
  (git-fixes).
- commit 74ab383
* Tue Jan 30 2024 iivanov@suse.de
- arm64: entry: Preserve/restore X29 even for compat tasks (git-fixes)
- commit c87e6ab
* Tue Jan 30 2024 petr.pavlu@suse.com
- tracing: Add size check when printing trace_marker output
  (git-fixes).
- commit b4fc359
* Tue Jan 30 2024 petr.pavlu@suse.com
- tracing: Have large events show up as '' instead of nothing
  (git-fixes).
- commit 89b3b19
* Tue Jan 30 2024 petr.pavlu@suse.com
- tracing: relax trace_event_eval_update() execution with
  cond_resched() (git-fixes).
- commit 598ec62
* Tue Jan 30 2024 petr.pavlu@suse.com
- ring-buffer: Do not attempt to read past "commit" (git-fixes).
- commit 32b2fd5
* Tue Jan 30 2024 petr.pavlu@suse.com
- ring-buffer: Avoid softlockup in ring_buffer_resize()
  (git-fixes).
- commit 522e4dc
* Tue Jan 30 2024 iivanov@suse.de
- arm64: Rename ARM64_WORKAROUND_2966298 (git-fixes)
  Refresh cpu_hwcaps reservation and enable WORKAROUND_SPECULATIVE_UNPRIV_LOAD.
  ".. The workaround isn't necessary if page table isolation (KPTI) is
  enabled, but for simplicity it will be. Page table isolation should
  normally be disabled for Cortex-A520 as it supports the CSV3 feature
  and the E0PD feature (used when KASLR is enabled).  ..."
- commit 3a5b06f
* Tue Jan 30 2024 oneukum@suse.com
- Update config files.
  A mainframe does physically not have an HSI interface.
  Inadvertedly enabled during an update. Redisable.
- commit d4a175d
* Tue Jan 30 2024 jslaby@suse.cz
- rpm/constraints.in: set jobs for riscv to 8
  The same workers are used for x86 and riscv and the riscv builds take
  ages. So align the riscv jobs count to x86.
- commit b2c82b9
* Tue Jan 30 2024 oneukum@suse.com
- Update config files.
  CAIF makes no sense on a mainframe.
  It was inadvertedly switched on during an update.
  Redisable.
- commit 29744a1
* Tue Jan 30 2024 oneukum@suse.com
- Update config files.
  PHONET got switched on during an update
  Connecting a mainframe to old Nokia cell phones
  just makes no sense. This is bloat.
- commit c0b2948
* Tue Jan 30 2024 mkoutny@suse.com
- cgroup_freezer: cgroup_freezing: Check if not frozen
  (bsc#1219338).
- commit 6549fad
* Tue Jan 30 2024 iivanov@suse.de
- Update patches.suse/arm64-sdei-abort-running-SDEI-handlers-during-crash.patch (git-fixes, bsc#1219254)
  Add reference to bsc#1219254.
- commit 6a70510
* Tue Jan 30 2024 iivanov@suse.de
- perf: arm_cspmu: Reject events meant for other PMUs (bsc#1219247)
- commit faa4288
* Tue Jan 30 2024 iivanov@suse.de
- Update patches.suse/arm64-arm-arm_pmuv3-perf-Don-t-truncate-64-bit-regis.patch (git-fixes, bsc#1219246)
  Add reference to bsc#1219246
- commit 9f6d94a
* Tue Jan 30 2024 aabdallah@suse.de
- platform/x86: ISST: Reduce noise for missing numa information
  in logs (bsc#1219285).
- commit 070f01e
* Tue Jan 30 2024 tiwai@suse.de
- Update config files: enable CONFIG_IMA_DISABLE_HTABLE consistently (bsc#1218400)
- commit a05b251
* Tue Jan 30 2024 tiwai@suse.de
- Update config files: align CONFIG_PSTORE_* setup with SLE15-SP6 (bsc#1219328)
  Those have been disabled unintentionally.  Let's reenable them.
- commit 57589c1
* Tue Jan 30 2024 tiwai@suse.de
- supported.conf: Mark lz4* related modules as supported (bsc#1217030)
  Those are used by zram and other modules.
- commit 7165080
* Mon Jan 29 2024 tiwai@suse.de
- selftests: mm: hugepage-vmemmap fails on 64K page size systems
  (bsc#1219286).
- commit f1ce7e1
* Mon Jan 29 2024 oneukum@suse.com
- Update config files.
  Remove USB4 on s390, where it makes no sense
  Switching on by accident while bumping the kernel version
- commit 40d0815
* Mon Jan 29 2024 denis.kirjanov@suse.com
- r8169: respect userspace disabling IFF_MULTICAST (git-fixes).
- commit 29e98eb
* Mon Jan 29 2024 denis.kirjanov@suse.com
- net: phylink: initialize carrier state at creation (git-fixes).
- commit 4a57df5
* Mon Jan 29 2024 denis.kirjanov@suse.com
- net: stmmac: xgmac: Enable support for multiple Flexible PPS
  outputs (git-fixes).
- commit 7a5f412
* Mon Jan 29 2024 denis.kirjanov@suse.com
- ipvlan: properly track tx_errors (git-fixes).
- commit 9072c00
* Mon Jan 29 2024 denis.kirjanov@suse.com
- tsnep: Fix tsnep_request_irq() format-overflow warning
  (git-fixes).
- commit 7127754
* Mon Jan 29 2024 denis.kirjanov@suse.com
- net: renesas: rswitch: Add spin lock protection for irq {un}mask
  (git-fixes).
- commit 57d1654
* Mon Jan 29 2024 denis.kirjanov@suse.com
- net: renesas: rswitch: Add runtime speed change support
  (git-fixes).
- commit b524173
* Mon Jan 29 2024 denis.kirjanov@suse.com
- net: phy: Provide Module 4 KSZ9477 errata (DS80000754C)
  (git-fixes).
- commit 4eb114e
* Mon Jan 29 2024 denis.kirjanov@suse.com
- net: phy: micrel: Move KSZ9477 errata fixes to PHY driver
  (git-fixes).
- commit 3919cda
* Mon Jan 29 2024 denis.kirjanov@suse.com
- net: phy: Fix deadlocking in phy_error() invocation (git-fixes).
- commit f16a410
* Mon Jan 29 2024 denis.kirjanov@suse.com
- net: phy: avoid kernel warning dump when stopping an errored
  PHY (git-fixes).
- commit deb85a0
* Mon Jan 29 2024 oneukum@suse.com
- r8152: add vendor/device ID pair for ASUS USB-C2500 (git-fixes).
- commit 0834d50
* Mon Jan 29 2024 mgorman@suse.de
- Refresh and enable
  patches.suse/sched-fair-Increase-wakeup_gran-if-current-task-has-not-executed-the-minimum-granularity.patch.
- commit d4cda80
* Mon Jan 29 2024 tiwai@suse.de
- =?UTF-8?q?cxl/region=EF=BC=9AFix=20overflow=20issue=20in?=
  =?UTF-8?q?=20alloc=5Fhpa()?= (git-fixes).
- genirq: Initialize resend_node hlist for all interrupt
  descriptors (git-fixes).
- clocksource: Skip watchdog check for large watchdog intervals
  (git-fixes).
- commit 79eca77
* Sun Jan 28 2024 tiwai@suse.de
- Add alt-commit to platform x86 p2sb patch (git-fixes)
- commit f23ac66
* Sun Jan 28 2024 tiwai@suse.de
- platform/x86/intel/ifs: Call release_firmware() when handling
  errors (git-fixes).
- platform/x86: intel-uncore-freq: Fix types in sysfs callbacks
  (git-fixes).
- drm/i915/psr: Only allow PSR in LPSP mode on HSW non-ULT
  (git-fixes).
- commit c877cc1
* Sat Jan 27 2024 tiwai@suse.de
- drm/bridge: parade-ps8640: Make sure we drop the AUX mutex in
  the error case (git-fixes).
- commit 8520b33
* Sat Jan 27 2024 tiwai@suse.de
- cpufreq/amd-pstate: Fix setting scaling max/min freq values
  (git-fixes).
- drm: bridge: samsung-dsim: Don't use FORCE_STOP_STATE
  (git-fixes).
- Revert "drivers/firmware: Move sysfb_init() from device_initcall
  to subsys_initcall_sync" (git-fixes).
- drm/bridge: anx7625: Ensure bridge is suspended in disable()
  (git-fixes).
- drm/bridge: parade-ps8640: Ensure bridge is suspended in
  .post_disable() (git-fixes).
- drm/bridge: sii902x: Fix audio codec unregistration (git-fixes).
- drm/bridge: sii902x: Fix probing race issue (git-fixes).
- drm/panel: samsung-s6d7aa0: drop DRM_BUS_FLAG_DE_HIGH for
  lsl080al02 (git-fixes).
- drm: panel-simple: add missing bus flags for Tianma
  tm070jvhg[30/33] (git-fixes).
- drm/bridge: parade-ps8640: Wait for HPD when doing an AUX
  transfer (git-fixes).
- drm/exynos: gsc: minor fix for loop iteration in
  gsc_runtime_resume (git-fixes).
- drm/exynos: fix accidental on-stack copy of exynos_drm_plane
  (git-fixes).
- dt-bindings: display: samsung,exynos-mixer: Fix 'regs' typo
  (git-fixes).
- Revert "drm/i915/dsi: Do display on sequence later on icl+"
  (git-fixes).
- firmware: arm_scmi: Use xa_insert() when saving raw queues
  (git-fixes).
- firmware: arm_scmi: Check mailbox/SMT channel for consistency
  (git-fixes).
- spi: fix finalize message on error return (git-fixes).
- spi: spi-cadence: Reverse the order of interleaved write and
  read operations (git-fixes).
- spi: bcm-qspi: fix SFDP BFPT read by usig mspi read (git-fixes).
- spi: intel-pci: Remove Meteor Lake-S SoC PCI ID from the list
  (git-fixes).
- gpio: eic-sprd: Clear interrupt after set the interrupt type
  (git-fixes).
- net: phy: micrel: populate .soft_reset for KSZ9131 (git-fixes).
- commit 04f99fe
* Fri Jan 26 2024 denis.kirjanov@suse.com
- net: sched: sch_qfq: Use non-work-conserving warning handler
  (CVE-2023-4921 bsc#1215275).
- commit 24b313c
* Fri Jan 26 2024 msuchanek@suse.de
- mkspec: Use variant in constraints template
  Constraints are not applied consistently with kernel package variants.
  Add variant to the constraints template as appropriate, and expand it
  in mkspec.
- commit cc68ab9
* Fri Jan 26 2024 pjakobsson@suse.de
- Update
  patches.suse/drm-atomic-Fix-potential-use-after-free-in-nonb.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 bsc#1219120
  CVE-2023-51043).
- commit 9891763
* Fri Jan 26 2024 tiwai@suse.de
- fjes: fix memleaks in fjes_hw_setup (git-fixes).
- wifi: iwlwifi: fix a memory corruption (git-fixes).
- wifi: mac80211: fix potential sta-link leak (git-fixes).
- clocksource/drivers/timer-ti-dm: Fix make W=n kerneldoc warnings
  (git-fixes).
- serial: 8250_exar: Set missing rs485_supported flag (git-fixes).
- bus: mhi: ep: Use slab allocator where applicable (git-fixes).
- pwm: stm32: Fix enable count for clk in .probe() (git-fixes).
- pwm: stm32: Use hweight32 in stm32_pwm_detect_channels
  (git-fixes).
- clk: renesas: rzg2l: Check reset monitor registers (git-fixes).
- clk: renesas: rzg2l-cpg: Reuse code in rzg2l_cpg_reset()
  (git-fixes).
- drm/tidss: Fix dss reset (git-fixes).
- drm/tidss: Check for K2G in in dispc_softreset() (git-fixes).
- drm/tidss: Return error value from from softreset (git-fixes).
- drm/tidss: Move reset to the end of dispc_init() (git-fixes).
- wifi: mwifiex: fix uninitialized firmware_stat (git-fixes).
- wifi: mwifiex: add extra delay for firmware ready (git-fixes).
- cpufreq: scmi: process the result of
  devm_of_clk_add_hw_provider() (git-fixes).
- cpuidle: haltpoll: Do not enable interrupts when entering idle
  (git-fixes).
- gpio: sysfs: drop the mention of gpiochip_find() from sysfs code
  (git-fixes).
- gpiolib: provide gpio_device_find() (git-fixes).
- gpiolib: make gpio_device_get() and gpio_device_put() public
  (git-fixes).
- commit 3a58ed2
* Fri Jan 26 2024 dwagner@suse.de
- scsi: lpfc: Limit IRQ vectors to online cpus if kdump kernel
  (bsc#1218180).
- commit 955ec78
* Fri Jan 26 2024 jslaby@suse.cz
- rpm/constraints.in: add static multibuild packages
  Commit 841012b049a5 (rpm/mkspec: use kernel-source: prefix for
  constraints on multibuild) added "kernel-source:" prefix to the
  dynamically generated kernels. But there are also static ones like
  kernel-docs. Those fail to build as the constraints are still not
  applied.
  So add the prefix also to the static ones.
  Note kernel-docs-rt is given kernel-source-rt prefix. I am not sure it
  will ever be multibuilt...
- commit c2e0681
* Thu Jan 25 2024 tbogendoerfer@suse.de
- xsk: make struct xsk_cb_desc available outside
  CONFIG_XDP_SOCKETS (jsc#PED-4876).
- commit ca48ebb
* Thu Jan 25 2024 lhenriques@suse.de
- ext4: fix warning in ext4_dio_write_end_io() (bsc#1219163).
- ext4: properly sync file size update after O_SYNC direct IO
  (bsc#1219163).
- ext4: fix BUG in ext4_mb_new_inode_pa() due to overflow
  (bsc#1219165).
- ext4: add two helper functions extent_logical_end() and
  pa_logical_end() (bsc#1219165).
- commit 16340ba
* Thu Jan 25 2024 tiwai@suse.de
- Update config files: disable CONFIG_ICE and CONFIG_IGC on s390x (bsc#1219190)
  Those have been enabled rather superfluously.
  Aligning with SLE15-SP6 config now.
- commit 25d1f2a
* Thu Jan 25 2024 tbogendoerfer@suse.de
- eth: dpaa: add missing net/xdp.h include (jsc#PED-4876).
- commit fab3862
* Thu Jan 25 2024 denis.kirjanov@suse.com
- net: hns3: add 5ms delay before clear firmware reset irq source
  (git-fixes).
- commit 249431c
* Thu Jan 25 2024 denis.kirjanov@suse.com
- net: hns3: fix fail to delete tc flower rules during reset issue
  (git-fixes).
- commit c1d1e1b
* Thu Jan 25 2024 denis.kirjanov@suse.com
- net: hns3: only enable unicast promisc when mac table full
  (git-fixes).
- commit 2b96a6c
* Thu Jan 25 2024 denis.kirjanov@suse.com
- net: hns3: fix GRE checksum offload issue (git-fixes).
- commit cbe1774
* Thu Jan 25 2024 denis.kirjanov@suse.com
- net: hns3: add cmdq check for vf periodic service task
  (git-fixes).
- commit a9c5505
* Thu Jan 25 2024 denis.kirjanov@suse.com
- tsnep: Fix NAPI polling with budget 0 (git-fixes).
- commit ddad93c
* Thu Jan 25 2024 denis.kirjanov@suse.com
- tsnep: Fix ethtool channels (git-fixes).
- commit 41a218b
* Thu Jan 25 2024 denis.kirjanov@suse.com
- tsnep: Fix NAPI scheduling (git-fixes).
- commit bd62c71
* Thu Jan 25 2024 denis.kirjanov@suse.com
- net: thunderbolt: Fix TCPv6 GSO checksum calculation
  (git-fixes).
- commit 043a669
* Thu Jan 25 2024 denis.kirjanov@suse.com
- net: microchip: sparx5: Fix possible memory leaks in
  vcap_api_kunit (git-fixes).
- commit e2834b7
* Thu Jan 25 2024 denis.kirjanov@suse.com
- net: microchip: sparx5: Fix possible memory leaks in
  test_vcap_xn_rule_creator() (git-fixes).
- commit 3330249
* Thu Jan 25 2024 denis.kirjanov@suse.com
- net: microchip: sparx5: Fix possible memory leak in
  vcap_api_encode_rule_test() (git-fixes).
- commit ebce63e
* Thu Jan 25 2024 denis.kirjanov@suse.com
- net: microchip: sparx5: Fix memory leak for
  vcap_api_rule_add_actionvalue_test() (git-fixes).
- commit 340155d
* Thu Jan 25 2024 denis.kirjanov@suse.com
- net: microchip: sparx5: Fix memory leak for
  vcap_api_rule_add_keyvalue_test() (git-fixes).
- commit 991c250
* Thu Jan 25 2024 hare@suse.de
- Delete
  patches.suse/nvme-auth-retry-command-if-DNR-bit-is-not-set.patch.
- commit 623e3d2
* Thu Jan 25 2024 tbogendoerfer@suse.de
- ice: read internal temperature sensor (jsc#PED-4876).
- Update config files.
- commit 680fce4
* Thu Jan 25 2024 tbogendoerfer@suse.de
- net: invert the netdevice.h vs xdp.h dependency (jsc#PED-4876).
- Refresh
  patches.suse/netdev-expose-DPLL-pin-handle-for-netdevice.patch.
- commit 6b2e009
* Thu Jan 25 2024 tbogendoerfer@suse.de
- i40e: Include types.h to some headers (jsc#PED-4874).
- octeontx2-af: CN10KB: Fix FIFO length calculation for RPM2
  (jsc#PED-6931).
- vdpa/mlx5: Add mkey leak detection (jsc#PED-3311).
- vdpa/mlx5: Introduce reference counting to mrs (jsc#PED-3311).
- vdpa/mlx5: Use vq suspend/resume during .set_map (jsc#PED-3311).
- vdpa/mlx5: Mark vq state for modification in hw vq
  (jsc#PED-3311).
- vdpa/mlx5: Mark vq addrs for modification in hw vq
  (jsc#PED-3311).
- vdpa/mlx5: Introduce per vq and device resume (jsc#PED-3311).
- vdpa/mlx5: Allow modifying multiple vq fields in one modify
  command (jsc#PED-3311).
- vdpa/mlx5: Expose resumable vq capability (jsc#PED-3311).
- RDMA/mlx5: Expose register c0 for RDMA device (jsc#PED-3311).
- net/mlx5: E-Switch, expose eswitch manager vport (jsc#PED-3311).
- net/mlx5: Manage ICM type of SW encap (jsc#PED-3311).
- RDMA/mlx5: Support handling of SW encap ICM area (jsc#PED-3311).
- net/mlx5: Introduce indirect-sw-encap ICM properties
  (jsc#PED-3311).
- mlxbf_gige: Enable the GigE port in mlxbf_gige_open
  (jsc#PED-6866).
- mlxbf_gige: Fix intermittent no ip issue (jsc#PED-6866).
- Revert "mlx5 updates 2023-12-20" (jsc#PED-3311).
- net: ethtool: reject unsupported RSS input xfrm values
  (jsc#PED-4876).
- net/mlx5: DPLL, Implement fractional frequency offset get pin op
  (jsc#PED-3311).
- net/mlx5: DPLL, Use struct to get values from
  mlx5_dpll_synce_status_get() (jsc#PED-3311).
- dpll: expose fractional frequency offset value to user
  (jsc#PED-6079).
- ice: Fix some null pointer dereference issues in ice_ptp.c
  (jsc#PED-4876).
- ice: ice_base.c: Add const modifier to params and vars
  (jsc#PED-4876).
- ice: remove rx_len_errors statistic (jsc#PED-4876).
- ice: replace ice_vf_recreate_vsi() with ice_vf_reconfig_vsi()
  (jsc#PED-4876).
- ice: Add support for packet mirroring using hardware in
  switchdev mode (jsc#PED-4876).
- ice: Enable SW interrupt from FW for LL TS (jsc#PED-4876).
- ice: Schedule service task in IRQ top half (jsc#PED-4876).
- i40e: Avoid unnecessary use of comma operator (jsc#PED-4874).
- i40e: Fix VF disable behavior to block all traffic
  (jsc#PED-4874).
- ixgbe: Refactor returning internal error codes (jsc#PED-4872).
- ixgbe: Refactor overtemp event handling (jsc#PED-4872).
- ixgbe: report link state for VF devices (jsc#PED-4872).
- octeontx2-af: Fix max NPC MCAM entry check while validating
  ref_entry (jsc#PED-6931).
- net: ethtool: Fix symmetric-xor RSS RX flow hash check
  (jsc#PED-4876).
- net: ethtool: add a NO_CHANGE uAPI for new RXFH's input_xfrm
  (jsc#PED-4876).
- net: ethtool: copy input_xfrm to user-space in ethtool_get_rxfh
  (jsc#PED-4876).
- net/mlx5: Implement management PF Ethernet profile
  (jsc#PED-3311).
- net/mlx5: Enable SD feature (jsc#PED-3311).
- net/mlx5e: Block TLS device offload on combined SD netdev
  (jsc#PED-3311).
- net/mlx5e: Support per-mdev queue counter (jsc#PED-3311).
- net/mlx5e: Support cross-vhca RSS (jsc#PED-3311).
- net/mlx5e: Let channels be SD-aware (jsc#PED-3311).
- net/mlx5e: Create EN core HW resources for all secondary devices
  (jsc#PED-3311).
- net/mlx5e: Create single netdev per SD group (jsc#PED-3311).
- net/mlx5: SD, Add informative prints in kernel log
  (jsc#PED-3311).
- net/mlx5: SD, Implement steering for primary and secondaries
  (jsc#PED-3311).
- net/mlx5: SD, Implement devcom communication and primary
  election (jsc#PED-3311).
- net/mlx5: SD, Implement basic query and instantiation
  (jsc#PED-3311).
- net/mlx5: SD, Introduce SD lib (jsc#PED-3311).
- net/mlx5: Fix query of sd_group field (jsc#PED-3311).
- net/mlx5e: Use the correct lag ports number when creating TISes
  (jsc#PED-3311).
- octeontx2-af: Fix a double free issue (jsc#PED-6931).
- idpf: refactor some missing field get/prep conversions
  (jsc#PED-6716).
- ice: cleanup inconsistent code (jsc#PED-4876).
- ice: field get conversion (jsc#PED-4876).
- iavf: field get conversion (jsc#PED-4937).
- i40e: field get conversion (jsc#PED-4874).
- igc: field get conversion (jsc#PED-4860).
- intel: legacy: field get conversion (jsc#PED-4866).
- igc: field prep conversion (jsc#PED-4860).
- ice: fix pre-shifted bit usage (jsc#PED-4876).
- ice: field prep conversion (jsc#PED-4876).
- iavf: field prep conversion (jsc#PED-4937).
- i40e: field prep conversion (jsc#PED-4874).
- intel: legacy: field prep conversion (jsc#PED-4866).
- intel: add bit macro includes where needed (jsc#PED-4866).
- e1000e: make lost bits explicit (jsc#PED-4868).
- octeontx2-af: insert space after include (jsc#PED-6931).
- octeon_ep: support firmware notifications for VFs
  (jsc#PED-6954).
- octeon_ep: control net framework to support VF offloads
  (jsc#PED-6954).
- octeon_ep: PF-VF mailbox version support (jsc#PED-6954).
- octeon_ep: add PF-VF mailbox communication (jsc#PED-6954).
- net, xdp: Correct grammar (jsc#PED-4876).
- mlx5: implement VLAN tag XDP hint (jsc#PED-3311).
- ice: use VLAN proto from ring packet context in skb path
  (jsc#PED-4876).
- ice: Implement VLAN tag hint (jsc#PED-4876).
- xdp: Add VLAN tag hint (jsc#PED-4876).
- ice: Support XDP hints in AF_XDP ZC mode (jsc#PED-4876).
- xsk: add functions to fill control buffer (jsc#PED-4876).
- ice: Support RX hash XDP hint (jsc#PED-4876).
- ice: Support HW timestamp hint (jsc#PED-4876).
- ice: Introduce ice_xdp_buff (jsc#PED-4876).
- ice: Make ptype internal to descriptor info processing
  (jsc#PED-4876).
- ice: make RX HW timestamp reading code more reusable
  (jsc#PED-4876).
- ice: make RX hash reading code more reusable (jsc#PED-4876).
- net, xdp: Allow metadata > 32 (jsc#PED-4876).
- octeontx2-af: Add new devlink param to configure maximum usable
  NIX block LFs (jsc#PED-6931).
- ice: add ability to read and configure FW log data
  (jsc#PED-4876).
- ice: enable FW logging (jsc#PED-4876).
- ice: configure FW logging (jsc#PED-4876).
- ice: remove FW logging code (jsc#PED-4876).
- octeontx2-af: Fix multicast/mirror group lock/unlock issue
  (jsc#PED-6931).
- net/mlx5: DR, Use swap() instead of open coding it
  (jsc#PED-3311).
- net/mlx5: devcom, Add component size getter (jsc#PED-3311).
- net/mlx5e: Decouple CQ from priv (jsc#PED-3311).
- net/mlx5e: Add wrapping for auxiliary_driver ops and remove
  unused args (jsc#PED-3311).
- net/mlx5e: Statify function mlx5e_monitor_counter_arm
  (jsc#PED-3311).
- net/mlx5: Move TISes from priv to mdev HW resources
  (jsc#PED-3311).
- net/mlx5e: Remove TLS-specific logic in generic create TIS API
  (jsc#PED-3311).
- net/mlx5: fs, Command to control TX flow table root
  (jsc#PED-3311).
- net/mlx5: fs, Command to control L2TABLE entry silent mode
  (jsc#PED-3311).
- net/mlx5: Expose Management PCIe Index Register (MPIR)
  (jsc#PED-3311).
- net/mlx5: Add mlx5_ifc bits used for supporting single netdev
  Socket-Direct (jsc#PED-3311).
- i40e: remove fake support of rx-frames-irq (jsc#PED-4874).
- e1000e: Use pcie_capability_read_word() for reading LNKSTA
  (jsc#PED-4868).
- e1000e: Use PCI_EXP_LNKSTA_NLW & FIELD_GET() instead of custom
  defines/code (jsc#PED-4868).
- igb: Use FIELD_GET() to extract Link Width (jsc#PED-4866).
- iavf: enable symmetric-xor RSS for Toeplitz hash function
  (jsc#PED-4876).
- ice: enable symmetric-xor RSS for Toeplitz hash function
  (jsc#PED-4876).
- ice: refactor the FD and RSS flow ID generation (jsc#PED-4876).
- ice: refactor RSS configuration (jsc#PED-4876).
- ice: fix ICE_AQ_VSI_Q_OPT_RSS_* register values (jsc#PED-4876).
- net: ethtool: add support for symmetric-xor RSS hash
  (jsc#PED-4876).
- net: ethtool: get rid of get/set_rxfh_context functions
  (jsc#PED-4876).
- dpll: allocate pin ids in cycle (jsc#PED-6079).
- idpf: add get/set for Ethtool's header split ringparam
  (jsc#PED-6716).
- ethtool: add SET for TCP_DATA_SPLIT ringparam (jsc#PED-6716).
- ionic: fill out pci error handlers (jsc#PED-6953).
- ionic: lif debugfs refresh on reset (jsc#PED-6953).
- ionic: use timer_shutdown_sync (jsc#PED-6953).
- ionic: no fw read when PCI reset failed (jsc#PED-6953).
- ionic: prevent pci disable of already disabled device
  (jsc#PED-6953).
- ionic: bypass firmware cmds when stuck in reset (jsc#PED-6953).
- ionic: keep filters across FLR (jsc#PED-6953).
- ionic: pass opcode to devcmd_wait (jsc#PED-6953).
- dpll: remove leftover mode_supported() op and use mode_get()
  instead (jsc#PED-6079).
- net: Convert some ethtool_sprintf() to ethtool_puts()
  (jsc#PED-4876).
- ethtool: Implement ethtool_puts() (jsc#PED-4876).
- octeontx2-af: cn10k: Increase outstanding LMTST transactions
  (jsc#PED-6931).
- ionic: Re-arrange ionic_intr_info struct for cache perf
  (jsc#PED-6953).
- ionic: Make the check for Tx HW timestamping more obvious
  (jsc#PED-6953).
- ionic: Don't check null when calling vfree() (jsc#PED-6953).
- ionic: set ionic ptr before setting up ethtool ops
  (jsc#PED-6953).
- ionic: Use cached VF attributes (jsc#PED-6953).
- octeon_ep: control net API framework to support offloads
  (jsc#PED-6954).
- sfc-siena: Implement ndo_hwtstamp_(get|set) (jsc#PED-6894).
- sfc: Implement ndo_hwtstamp_(get|set) (jsc#PED-6894).
- ice: Rename E822 to E82X (jsc#PED-4876).
- ice: periodically kick Tx timestamp interrupt (jsc#PED-4876).
- ice: Re-enable timestamping correctly after reset
  (jsc#PED-4876).
- ice: Improve logs for max ntuple errors (jsc#PED-4876).
- ice: add CGU info to devlink info callback (jsc#PED-4876).
- octeontx2-pf: TC flower offload support for mirror
  (jsc#PED-6931).
- octeontx2-af: Add new mbox to support multicast/mirror offload
  (jsc#PED-6931).
- octeontx2-af: debugfs: update CQ context fields (jsc#PED-6931).
- octeon_ep: set backpressure watermark for RX queues
  (jsc#PED-6954).
- octeon_ep: Fix error code in probe() (jsc#PED-6954).
- octeon_ep: support OCTEON CN98 devices (jsc#PED-6954).
- octeon_ep: implement device unload control net API
  (jsc#PED-6954).
- net/mlx5e: Implement AF_XDP TX timestamp and checksum offload
  (jsc#PED-3311).
- iavf: use iavf_schedule_aq_request() helper (jsc#PED-4937).
- iavf: Remove queue tracking fields from iavf_adminq_ring
  (jsc#PED-4937).
- i40e: Remove queue tracking fields from i40e_adminq_ring
  (jsc#PED-4874).
- i40e: Remove AQ register definitions for VF types
  (jsc#PED-4874).
- i40e: Delete unused and useless i40e_pf fields (jsc#PED-4874).
- ice: fix error code in ice_eswitch_attach() (jsc#PED-4876).
- octeon_ep: get max rx packet length from firmware
  (jsc#PED-6954).
- octeon_ep: Solve style issues in control net files
  (jsc#PED-6954).
- octeontx2-pf: TC flower offload support for ICMP type and code
  (jsc#PED-6931).
- octeon_ep: support Octeon CN10K devices (jsc#PED-6954).
- ice: reserve number of CP queues (jsc#PED-4876).
- ice: adjust switchdev rebuild path (jsc#PED-4876).
- ice: add VF representors one by one (jsc#PED-4876).
- ice: realloc VSI stats arrays (jsc#PED-4876).
- ice: set Tx topology every time new repr is added
  (jsc#PED-4876).
- ice: allow changing SWITCHDEV_CTRL VSI queues (jsc#PED-4876).
- ice: return pointer to representor (jsc#PED-4876).
- ice: make representor code generic (jsc#PED-4876).
- ice: remove VF pointer reference in eswitch code (jsc#PED-4876).
- ice: track port representors in xarray (jsc#PED-4876).
- ice: use repr instead of vf->repr (jsc#PED-4876).
- ice: track q_id in representor (jsc#PED-4876).
- ice: remove unused control VSI parameter (jsc#PED-4876).
- ice: remove redundant max_vsi_num variable (jsc#PED-4876).
- ice: rename switchdev to eswitch (jsc#PED-4876).
- igc: Add support for PTP .getcyclesx64() (jsc#PED-4860).
- igc: Simplify setting flags in the TX data descriptor
  (jsc#PED-4860).
- net/mlx5e: Remove early assignment to netdev->features
  (jsc#PED-3311).
- net/mlx5e: Add local loopback counter to vport rep stats
  (jsc#PED-3311).
- net/mlx5: Query maximum frequency adjustment of the PTP hardware
  clock (jsc#PED-3311).
- net/mlx5: Convert scaled ppm values outside the s32 range for
  PHC frequency adjustments (jsc#PED-3311).
- net/mlx5: Initialize clock->ptp_info inside
  mlx5_init_timer_clock (jsc#PED-3311).
- net/mlx5: Refactor real time clock operation checks for PHC
  (jsc#PED-3311).
- net/mlx5e: Access array with enum values instead of magic
  numbers (jsc#PED-3311).
- net/mlx5: simplify mlx5_set_driver_version string assignments
  (jsc#PED-3311).
- net/mlx5: Annotate struct mlx5_flow_handle with __counted_by
  (jsc#PED-3311).
- net/mlx5: Annotate struct mlx5_fc_bulk with __counted_by
  (jsc#PED-3311).
- net/mlx5e: Some cleanup in mlx5e_tc_stats_matchall()
  (jsc#PED-3311).
- net/mlx5: Allow sync reset flow when BF MGT interface device
  is present (jsc#PED-3311).
- net/mlx5: print change on SW reset semaphore returns busy
  (jsc#PED-3311).
- octeon_ep: remove atomic variable usage in Tx data path
  (jsc#PED-6954).
- octeon_ep: implement xmit_more in transmit (jsc#PED-6954).
- octeon_ep: remove dma sync in trasmit path (jsc#PED-6954).
- octeon_ep: add padding for small packets (jsc#PED-6954).
- i40e: Delete unused i40e_mac_info fields (jsc#PED-4874).
- i40e: Move inline helpers to i40e_prototype.h (jsc#PED-4874).
- i40e: Remove VF MAC types (jsc#PED-4874).
- i40e: Use helpers to check running FW and AQ API versions
  (jsc#PED-4874).
- i40e: Add other helpers to check version of running firmware
  and AQ API (jsc#PED-4874).
- i40e: Move i40e_is_aq_api_ver_ge helper (jsc#PED-4874).
- i40e: Initialize hardware capabilities at single place
  (jsc#PED-4874).
- i40e: Consolidate hardware capabilities (jsc#PED-4874).
- i40e: Use DECLARE_BITMAP for flags field in i40e_hw
  (jsc#PED-4874).
- i40e: Use DECLARE_BITMAP for flags and hw_features fields in
  i40e_pf (jsc#PED-4874).
- i40e: Remove _t suffix from enum type names (jsc#PED-4874).
- i40e: Remove unused flags (jsc#PED-4874).
- i40e: Change user notification of non-SFP module in
  i40e_get_module_info() (jsc#PED-4874).
- i40e: add an error code check in i40e_vsi_setup (jsc#PED-4874).
- i40e: increase max descriptors for XL710 (jsc#PED-4874).
- net: ethtool: Unify ETHTOOL_{G,S}RXFH rxnfc copy (jsc#PED-4876).
- ethtool: ioctl: account for sopass diff in set_wol
  (jsc#PED-4876).
- ethtool: ioctl: improve error checking for set_wol
  (jsc#PED-4876).
- commit b118f81
* Thu Jan 25 2024 msuchanek@suse.de
- Revert "Limit kernel-source build to architectures for which the kernel binary"
  This reverts commit 08a9e44c00758b5f3f3b641830ab6affff041132.
  The fix for bsc#1108281 directly causes bsc#1218768, revert.
- commit 2943b8a
* Thu Jan 25 2024 msuchanek@suse.de
- mkspec: Include constraints for both multibuild and plain package always
  There is no need to check for multibuild flag, the constraints can be
  always generated for both cases.
- commit 308ea09
* Thu Jan 25 2024 jslaby@suse.cz
- rpm/mkspec: use kernel-source: prefix for constraints on multibuild
  Otherwise the constraints are not applied with multibuild enabled.
- commit 841012b
* Thu Jan 25 2024 hare@suse.de
- Delete
  patches.suse/nvme-auth-align-to-pre-upstream-FFDHE-implementation.patch.
- commit ea56939
* Thu Jan 25 2024 tiwai@suse.de
- exec: Fix error handling in begin_new_exec() (git-fixes).
- commit baf76e9
* Wed Jan 24 2024 iivanov@suse.de
- arm64: dts: freescale: imx8-ss-lsio: Fix #pwm-cells (git-fixes)
- commit bb9ccad
* Wed Jan 24 2024 iivanov@suse.de
- arm64: dts: rockchip: Fix led pinctrl of lubancat 1 (git-fixes)
- commit ed2b8f0
* Wed Jan 24 2024 iivanov@suse.de
- arm64: dts: rockchip: Fix rk3588 USB power-domain clocks (git-fixes)
- commit a68e5ac
* Wed Jan 24 2024 iivanov@suse.de
- arm64: dts: rockchip: configure eth pad driver strength for orangepi (git-fixes)
- commit 417f128
* Wed Jan 24 2024 iivanov@suse.de
- arm64: dts: sprd: fix the cpu node for UMS512 (git-fixes)
- commit d752ae0
* Wed Jan 24 2024 iivanov@suse.de
- arm64: dts: armada-3720-turris-mox: set irq type for RTC (git-fixes)
- commit 3b64296
* Wed Jan 24 2024 iivanov@suse.de
- arm64: dts: imx8mm: Reduce GPU to nominal speed (git-fixes)
- commit 7de6fae
* Wed Jan 24 2024 iivanov@suse.de
- arm64: dts: hisilicon: hikey970-pmic: fix regulator cells properties (git-fixes)
- commit 3671940
* Wed Jan 24 2024 iivanov@suse.de
- arm64: dts: rockchip: Fix eMMC Data Strobe PD on rk3588 (git-fixes)
- commit 32940df
* Wed Jan 24 2024 iivanov@suse.de
- arm64: dts: rockchip: Fix PCI node addresses on rk3399-gru (git-fixes)
- commit 53695e4
* Wed Jan 24 2024 iivanov@suse.de
- arm64: dts: rockchip: fix rk356x pcie msg interrupt name (git-fixes)
- commit f23d8af
* Wed Jan 24 2024 iivanov@suse.de
- arm64: dts: rockchip: Expand reg size of vdec node for RK3399 (git-fixes)
- commit 4ce9ac8
* Wed Jan 24 2024 iivanov@suse.de
- arm64: dts: rockchip: Expand reg size of vdec node for RK3328 (git-fixes)
- commit 3a84208
* Wed Jan 24 2024 iivanov@suse.de
- arm64: dts: imx8-apalis: set wifi regulator to always-on (git-fixes)
- commit 48b000f
* Wed Jan 24 2024 iivanov@suse.de
- arm64: dts: imx93: correct mediamix power (git-fixes)
- commit dff5f85
* Wed Jan 24 2024 iivanov@suse.de
- arm64: dts: imx8mp: imx8mq: Add parkmode-disable-ss-quirk on DWC3 (git-fixes)
- commit 4ad1e7f
* Wed Jan 24 2024 iivanov@suse.de
- arm64: add dependency between vmlinuz.efi and Image (git-fixes)
- commit d79de8f
* Wed Jan 24 2024 iivanov@suse.de
- arm64: dts: ls208xa: use a pseudo-bus to constrain usb dma size (git-fixes)
- commit 7a3fb4e
* Wed Jan 24 2024 iivanov@suse.de
- arm64: dts: imx8-ss-lsio: Add PWM interrupts (git-fixes)
- commit 776de9a
* Wed Jan 24 2024 jslaby@suse.cz
- rpm/kernel-source.rpmlintrc: add action-ebpf
  Upstream commit a79d8ba734bd (selftests: tc-testing: remove buildebpf
  plugin) added this precompiled binary blob. Adapt rpmlintrc for
  kernel-source.
- commit b5ccb33
* Wed Jan 24 2024 iivanov@suse.de
- arm64: add HWCAP for FEAT_HBC (hinted conditional branches) (git-fixes)
  Refresh
  patches.suse/arm64-cpufeature-Fix-CLRBHB-and-BC-detection.patch.
- commit 71c2551
* Wed Jan 24 2024 jslaby@suse.cz
- Update
  patches.suse/genirq-Encapsulate-sparse-bitmap-handling.patch
  (bsc#1216838 jsc#PED-7520).
- Update
  patches.suse/genirq-Use-a-maple-tree-for-interrupt-descriptor-management.patch
  (bsc#1216838 jsc#PED-7520).
- Update
  patches.suse/genirq-Use-hlist-for-managing-resend-handlers.patch
  (bsc#1216838 jsc#PED-7520).
  Add JIRA reference.
- commit 93058c5
* Tue Jan 23 2024 jack@suse.cz
- blk-wbt: Fix detection of dirty-throttled tasks (bsc#1218272).
- commit 497a3db
* Tue Jan 23 2024 tiwai@suse.de
- rpm/kernel-source.changes.old: update and correct the truncated references
- commit 8e09770
* Tue Jan 23 2024 tiwai@suse.de
- scripts/tar-up.sh: don't add spurious entry from kernel-sources.changes.old
  The previous change added the manual entry from kernel-sources.change.old
  to old_changelog.txt unnecessarily.  Let's fix it.
- commit fb033e8
* Tue Jan 23 2024 tbogendoerfer@suse.de
- bnxt_en: Add completion ring pointer in TX and RX ring
  structures (jsc#PED-7574).
- commit 0ea0ed9
* Tue Jan 23 2024 tbogendoerfer@suse.de
- bnxt_en: Restructure cp_ring_arr in struct bnxt_cp_ring_info
  (jsc#PED-7574).
- commit 3718949
* Tue Jan 23 2024 tbogendoerfer@suse.de
- bnxt_en: Add completion ring pointer in TX and RX ring
  structures (jsc#PED-7574).
- commit 25104e1
* Tue Jan 23 2024 tbogendoerfer@suse.de
- bnxt_en: Put the TX producer information in the TX BD opaque
  field (jsc#PED-7574).
- commit 2c6ccef
* Tue Jan 23 2024 denis.kirjanov@suse.com
- net: renesas: rswitch: Fix unmasking irq condition (git-fixes).
- commit 2f5e1f7
* Tue Jan 23 2024 denis.kirjanov@suse.com
- veth: Update XDP feature set when bringing up device
  (git-fixes).
- commit fbdb33d
* Tue Jan 23 2024 denis.kirjanov@suse.com
- net: macb: fix sleep inside spinlock (git-fixes).
- commit 356d69f
* Tue Jan 23 2024 denis.kirjanov@suse.com
- net: dsa: sja1105: block FDB accesses that are concurrent with
  a switch reset (git-fixes).
- commit 07b2fec
* Tue Jan 23 2024 tbogendoerfer@suse.de
- Delete
  patches.suse/infiniband-Remove-the-now-superfluous-sentinel-eleme.patch.
  Patch uses not present changes in sysctl, so drop it.
- commit d544c7c
* Tue Jan 23 2024 denis.kirjanov@suse.com
- net: dsa: sja1105: serialize sja1105_port_mcast_flood() with
  other FDB accesses (git-fixes).
- commit aab1ac7
* Tue Jan 23 2024 denis.kirjanov@suse.com
- net: hns3: remove GSO partial feature bit (git-fixes).
- commit 55bf00a
* Tue Jan 23 2024 denis.kirjanov@suse.com
- net: dsa: sja1105: fix multicast forwarding working only for
  last added mdb entry (git-fixes).
- commit 53a6499
* Tue Jan 23 2024 denis.kirjanov@suse.com
- net: hns3: fix the port information display when sfp is absent
  (git-fixes).
- commit c6ec734
* Tue Jan 23 2024 denis.kirjanov@suse.com
- net: dsa: sja1105: propagate exact error code from
  sja1105_dynamic_config_poll_valid() (git-fixes).
- commit c09eaad
* Tue Jan 23 2024 denis.kirjanov@suse.com
- net: hns3: fix invalid mutex between tc qdisc and dcb ets
  command issue (git-fixes).
- commit 45bfc6e
* Tue Jan 23 2024 denis.kirjanov@suse.com
- net: dsa: sja1105: hide all multicast addresses from "bridge
  fdb show" (git-fixes).
- commit 3565617
* Tue Jan 23 2024 denis.kirjanov@suse.com
- net: hns3: fix debugfs concurrency issue between kfree buffer
  and read (git-fixes).
- commit 46a2318
* Tue Jan 23 2024 denis.kirjanov@suse.com
- net:ethernet:adi:adin1110: Fix forwarding offload (git-fixes).
- commit ba0f408
* Tue Jan 23 2024 denis.kirjanov@suse.com
- net: hns3: fix byte order conversion issue in
  hclge_dbg_fd_tcam_read() (git-fixes).
- commit df3933b
* Tue Jan 23 2024 denis.kirjanov@suse.com
- net: ethernet: mtk_eth_soc: fix possible NULL pointer
  dereference in mtk_hwlro_get_fdir_all() (git-fixes).
- commit 256db71
* Tue Jan 23 2024 denis.kirjanov@suse.com
- net: hns3: fix tx timeout issue (git-fixes).
- commit cb13d0b
* Tue Jan 23 2024 denis.kirjanov@suse.com
- net: ethernet: mvpp2_main: fix possible OOB write in
  mvpp2_ethtool_get_rxnfc() (git-fixes).
- commit 0b2ebf3
* Tue Jan 23 2024 denis.kirjanov@suse.com
- net: stmmac: fix handling of zero coalescing tx-usecs
  (git-fixes).
- commit dc13842
* Tue Jan 23 2024 denis.kirjanov@suse.com
- net: microchip: vcap api: Fix possible memory leak for
  vcap_dup_rule() (git-fixes).
- commit d26d0cc
* Tue Jan 23 2024 denis.kirjanov@suse.com
- net: enetc: distinguish error from valid pointers in
  enetc_fixup_clear_rss_rfs() (git-fixes).
- commit 86014cf
* Tue Jan 23 2024 jslaby@suse.cz
- rpm/kernel-docs.spec.in: fix build with 6.8
  Since upstream commit f061c9f7d058 (Documentation: Document each netlink
  family), the build needs python yaml.
- commit 6a7ece3
* Mon Jan 22 2024 denis.kirjanov@suse.com
- net: dsa: sja1105: complete tc-cbs offload support on SJA1110
  (git-fixes).
- commit 63f659d
* Mon Jan 22 2024 denis.kirjanov@suse.com
- net: dsa: sja1105: fix -ENOSPC when replacing the same tc-cbs
  too many times (git-fixes).
- commit ad24f2b
* Mon Jan 22 2024 denis.kirjanov@suse.com
- net: dsa: sja1105: fix bandwidth discrepancy between tc-cbs
  software and offload (git-fixes).
- commit 0f502ee
* Mon Jan 22 2024 denis.kirjanov@suse.com
- veth: Fixing transmit return status for dropped packets
  (git-fixes).
- commit bd05611
* Mon Jan 22 2024 denis.kirjanov@suse.com
- pds_core: pass opcode to devcmd_wait (git-fixes).
- commit fa54ffe
* Mon Jan 22 2024 denis.kirjanov@suse.com
- pds_core: check for work queue before use (git-fixes).
- commit 9dfa465
* Mon Jan 22 2024 denis.kirjanov@suse.com
- pds_core: no reset command for VF (git-fixes).
- commit 9f656c7
* Mon Jan 22 2024 denis.kirjanov@suse.com
- pds_core: no health reporter in VF (git-fixes).
- commit bb060b3
* Mon Jan 22 2024 denis.kirjanov@suse.com
- mlxsw: core_hwmon: Adjust module label names based on MTCAP
  sensor counter (git-fixes).
- commit d88bc5a
* Mon Jan 22 2024 tbogendoerfer@suse.de
- net-device: move xdp_prog to net_device_read_rx (jsc#PED-7574).
- net-device: move gso_partial_features to net_device_read_tx
  (jsc#PED-7574).
- bpf: Use nla_ok() instead of checking nla_len directly
  (jsc#PED-7574).
- net: sysfs: fix locking in carrier read (jsc#PED-7574).
- Documentations: fix net_cachelines documentation build warning
  (jsc#PED-7574).
- Documentations: Analyze heavily used Networking related structs
  (jsc#PED-7574).
- tools: ynl: make sure we use local headers for page-pool
  (jsc#PED-7574).
- tools: ynl: fix build of the page-pool sample (jsc#PED-7574).
- ipv6: also use netdev_hold() in ip6_route_check_nh()
  (jsc#PED-7574).
- commit f0c6261
* Mon Jan 22 2024 tbogendoerfer@suse.de
- RDMA/bnxt_re: Fix error code in bnxt_re_create_cq()
  (jsc#PED-7574).
- RDMA/bnxt_re: Fix the sparse warnings (jsc#PED-7574).
- RDMA/bnxt_re: Fix the offset for GenP7 adapters for user
  applications (jsc#PED-7574).
- RDMA/bnxt_re: Share a page to expose per CQ info with userspace
  (jsc#PED-7574).
- RDMA/bnxt_re: Add UAPI to share a page with user space
  (jsc#PED-7574).
- RDMA/bnxt_re: Adds MSN table capability for Gen P7 adapters
  (jsc#PED-7574).
- RDMA/bnxt_re: Doorbell changes (jsc#PED-7574).
- RDMA/bnxt_re: Get the toggle bits from CQ completions
  (jsc#PED-7574).
- RDMA/bnxt_re: Update the HW interface definitions
  (jsc#PED-7574).
- RDMA/bnxt_re: Update the BAR offsets (jsc#PED-7574).
- RDMA/bnxt_re: Support new 5760X P7 devices (jsc#PED-7574).
- RDMA/bnxt_re: Remove roundup_pow_of_two depth for all hardware
  queue resources (jsc#PED-7574).
- RDMA/bnxt_re: Refactor the queue index update (jsc#PED-7574).
- bnxt_en: Fix RCU locking for ntuple filters in
  bnxt_rx_flow_steer() (jsc#PED-7574).
- bnxt_en: Fix RCU locking for ntuple filters in
  bnxt_srxclsrldel() (jsc#PED-7574).
- bnxt_en: Remove unneeded variable in
  bnxt_hwrm_clear_vnic_filter() (jsc#PED-7574).
- bnxt_en: Fix compile error without CONFIG_RFS_ACCEL
  (jsc#PED-7574).
- bnxt_en: Add support for ntuple filter deletion by ethtool
  (jsc#PED-7574).
- bnxt_en: Add support for ntuple filters added from ethtool
  (jsc#PED-7574).
- bnxt_en: Add ntuple matching flags to the bnxt_ntuple_filter
  structure (jsc#PED-7574).
- bnxt_en: Refactor ntuple filter removal logic in
  bnxt_cfg_ntp_filters() (jsc#PED-7574).
- bnxt_en: Refactor the hash table logic for ntuple filters
  (jsc#PED-7574).
- bnxt_en: Refactor filter insertion logic in bnxt_rx_flow_steer()
  (jsc#PED-7574).
- bnxt_en: Add new BNXT_FLTR_INSERTED flag to bnxt_filter_base
  struct (jsc#PED-7574).
- bnxt_en: Add bnxt_lookup_ntp_filter_from_idx() function
  (jsc#PED-7574).
- bnxt_en: Add function to calculate Toeplitz hash (jsc#PED-7574).
- bnxt_en: Refactor L2 filter alloc/free firmware commands
  (jsc#PED-7574).
- bnxt_en: Re-structure the bnxt_ntuple_filter structure
  (jsc#PED-7574).
- bnxt_en: Add bnxt_l2_filter hash table (jsc#PED-7574).
- bnxt_en: Refactor bnxt_ntuple_filter structure (jsc#PED-7574).
- net: Add MDB bulk deletion device operation (jsc#PED-7574).
- genetlink: introduce helpers to do filtered multicast
  (jsc#PED-7574).
- netlink: introduce typedef for filter function (jsc#PED-7574).
- xsk: Add missing SPDX to AF_XDP TX metadata documentation
  (jsc#PED-7574).
- page_pool: halve BIAS_MAX for multiple user references of a
  fragment (jsc#PED-7574).
- net: ethtool: pass a pointer to parameters to get/set_rxfh
  ethtool ops (jsc#PED-7574).
- net: page_pool: factor out releasing DMA from releasing the page
  (jsc#PED-7574).
- page_pool: transition to reference count management after page
  draining (jsc#PED-7574).
- bnxt_en: Make PTP TX timestamp HWRM query silent (jsc#PED-7574).
- bnxt_en: Skip nic close/open when configuring tstamp filters
  (jsc#PED-7574).
- bnxt_en: Add support for UDP GSO on 5760X chips (jsc#PED-7574).
- bnxt_en: add rx_filter_miss extended stats (jsc#PED-7574).
- bnxt_en: Configure UDP tunnel TPA (jsc#PED-7574).
- bnxt_en: Add support for VXLAN GPE (jsc#PED-7574).
- bnxt_en: Use proper TUNNEL_DST_PORT_ALLOC* commands
  (jsc#PED-7574).
- bnxt_en: Allocate extra QP backing store memory when RoCE FW
  reports it (jsc#PED-7574).
- bnxt_en: Support TX coalesced completion on 5760X chips
  (jsc#PED-7574).
- bnxt_en: Prevent TX timeout with a very small TX ring
  (jsc#PED-7574).
- bnxt_en: Fix TX ring indexing logic (jsc#PED-7574).
- bnxt_en: Fix AGG ring check logic in bnxt_check_rings()
  (jsc#PED-7574).
- bnxt_en: Fix trimming of P5 RX and TX rings (jsc#PED-7574).
- netlink: Return unsigned value for nla_len() (jsc#PED-7574).
- net: core: synchronize link-watch when carrier is queried
  (jsc#PED-7574).
- net-device: reorganize net_device fast path variables
  (jsc#PED-7574).
- eth: bnxt: link NAPI instances to queues and IRQs
  (jsc#PED-7574).
- netdev-genl: Add PID for the NAPI thread (jsc#PED-7574).
- netdev-genl: spec: Add PID in netdev netlink YAML spec
  (jsc#PED-7574).
- net: Add NAPI IRQ support (jsc#PED-7574).
- netdev-genl: spec: Add irq in netdev netlink YAML spec
  (jsc#PED-7574).
- netdev-genl: Add netlink framework functions for napi
  (jsc#PED-7574).
- netdev-genl: spec: Extend netdev netlink spec in YAML for NAPI
  (jsc#PED-7574).
- netdev-genl: Add netlink framework functions for queue
  (jsc#PED-7574).
- ice: Add support in the driver for associating queue with napi
  (jsc#PED-7574).
- net: Add queue and napi association (jsc#PED-7574).
- netdev-genl: spec: Extend netdev netlink spec in YAML for queue
  (jsc#PED-7574).
- bnxt_en: Add 5760X (P7) PCI IDs (jsc#PED-7574).
- bnxt_en: Report the new ethtool link modes in the new firmware
  interface (jsc#PED-7574).
- bnxt_en: Support force speed using the new HWRM fields
  (jsc#PED-7574).
- bnxt_en: Support new firmware link parameters (jsc#PED-7574).
- bnxt_en: Refactor ethtool speeds logic (jsc#PED-7574).
- bnxt_en: Add support for new RX and TPA_START completion types
  for P7 (jsc#PED-7574).
- bnxt_en: Refactor and refine bnxt_tpa_start() and bnxt_tpa_end()
  (jsc#PED-7574).
- bnxt_en: Refactor RX VLAN acceleration logic (jsc#PED-7574).
- bnxt_en: Add new P7 hardware interface definitions
  (jsc#PED-7574).
- bnxt_en: Refactor RSS capability fields (jsc#PED-7574).
- bnxt_en: Implement the new toggle bit doorbell mechanism on
  P7 chips (jsc#PED-7574).
- bnxt_en: Consolidate DB offset calculation (jsc#PED-7574).
- bnxt_en: Define basic P7 macros (jsc#PED-7574).
- bnxt_en: Update firmware interface to 1.10.3.15 (jsc#PED-7574).
- bnxt_en: Fix backing store V2 logic (jsc#PED-7574).
- cache: enforce cache groups (jsc#PED-7574).
- xsk: Add option to calculate TX checksum in SW (jsc#PED-7574).
- xsk: Validate xsk_tx_metadata flags (jsc#PED-7574).
- xsk: Document tx_metadata_len layout (jsc#PED-7574).
- xsk: Add TX timestamp and TX checksum offload support
  (jsc#PED-7574).
- xsk: Support tx_metadata_len (jsc#PED-7574).
- net: page_pool: fix general protection fault in page_pool_unlist
  (jsc#PED-7574).
- tools: ynl: add sample for getting page-pool information
  (jsc#PED-7574).
- net: page_pool: mute the periodic warning for visible page pools
  (jsc#PED-7574).
- net: page_pool: expose page pool stats via netlink
  (jsc#PED-7574).
- net: page_pool: report when page pool was destroyed
  (jsc#PED-7574).
- net: page_pool: report amount of memory held by page pools
  (jsc#PED-7574).
- net: page_pool: add netlink notifications for state changes
  (jsc#PED-7574).
- net: page_pool: implement GET in the netlink API (jsc#PED-7574).
- net: page_pool: add nlspec for basic access to page pools
  (jsc#PED-7574).
- eth: link netdev to page_pools in drivers (jsc#PED-7574).
- net: page_pool: stash the NAPI ID for easier access
  (jsc#PED-7574).
- net: page_pool: record pools per netdev (jsc#PED-7574).
- net: page_pool: id the page pools (jsc#PED-7574).
- net: page_pool: factor out uninit (jsc#PED-7574).
- bnxt_en: Rename some macros for the P5 chips (jsc#PED-7574).
- bnxt_en: Modify the NAPI logic for the new P7 chips
  (jsc#PED-7574).
- bnxt_en: Modify RX ring indexing logic (jsc#PED-7574).
- bnxt_en: Modify TX ring indexing logic (jsc#PED-7574).
- bnxt_en: Add db_ring_mask and related macro to bnxt_db_info
  struct (jsc#PED-7574).
- bnxt_en: Add support for HWRM_FUNC_BACKING_STORE_CFG_V2 firmware
  calls (jsc#PED-7574).
- bnxt_en: Add support for new backing store query firmware API
  (jsc#PED-7574).
- bnxt_en: Add bnxt_setup_ctxm_pg_tbls() helper function
  (jsc#PED-7574).
- bnxt_en: Use the pg_info field in bnxt_ctx_mem_type struct
  (jsc#PED-7574).
- bnxt_en: Add page info to struct bnxt_ctx_mem_type
  (jsc#PED-7574).
- bnxt_en: Restructure context memory data structures
  (jsc#PED-7574).
- bnxt_en: Free bp->ctx inside bnxt_free_ctx_mem() (jsc#PED-7574).
- bnxt_en: The caller of bnxt_alloc_ctx_mem() should always free
  bp->ctx (jsc#PED-7574).
- net: page_pool: avoid touching slow on the fastpath
  (jsc#PED-7574).
- net: page_pool: split the page_pool_params into fast and slow
  (jsc#PED-7574).
- rtnetlink: introduce nlmsg_new_large and use it in rtnl_getlink
  (jsc#PED-7574).
- bnxt_en: Optimize xmit_more TX path (jsc#PED-7574).
- bnxt_en: Use existing MSIX vectors for all mqprio TX rings
  (jsc#PED-7574).
- bnxt_en: Add macros related to TC and TX rings (jsc#PED-7574).
- bnxt_en: Add helper to get the number of CP rings required
  for TX rings (jsc#PED-7574).
- bnxt_en: Support up to 8 TX rings per MSIX (jsc#PED-7574).
- bnxt_en: Refactor bnxt_hwrm_set_coal() (jsc#PED-7574).
- bnxt_en: New encoding for the TX opaque field (jsc#PED-7574).
- bnxt_en: Refactor bnxt_tx_int() (jsc#PED-7574).
- bnxt_en: Remove BNXT_RX_HDL and BNXT_TX_HDL (jsc#PED-7574).
- connector: Fix proc_event_num_listeners count not cleared
  (jsc#PED-7574).
- net: tls, update curr on splice as well (bsc#1218941
  CVE-2024-0646).
- xsk: Skip polling event check for unbound socket (jsc#PED-7574).
- net: Move {l,t,d}stats allocation to core and convert veth &
  vrf (jsc#PED-7574).
- net, vrf: Move dstats structure to core (jsc#PED-7574).
- net: Add MDB get device operation (jsc#PED-7574).
- xsk: Avoid starving the xsk further down the list
  (jsc#PED-7574).
- net, bpf: Add a warning if NAPI cb missed xdp_do_flush()
  (jsc#PED-7574).
- netlink: add variable-length / auto integers (jsc#PED-7574).
- net: introduce napi_is_scheduled helper (jsc#PED-7574).
- net/core: Introduce netdev_core_stats_inc() (jsc#PED-7574).
- ynl: netdev: drop unnecessary enum-as-flags (jsc#PED-7574).
- net: implement lockless SO_PRIORITY (jsc#PED-7574).
- bpf: expose information about supported xdp metadata kfunc
  (jsc#PED-7574).
- bpf: make it easier to add new metadata kfunc (jsc#PED-7574).
- xsk: add multi-buffer support for sockets sharing umem
  (jsc#PED-7574).
- Fix NULL pointer dereference in cn_filter() (jsc#PED-7574).
- netdev-genl: use struct genl_info for reply construction
  (jsc#PED-7574).
- net: add hwtstamping helpers for stackable net devices
  (jsc#PED-7574).
- net: add NDOs for configuring hardware timestamping
  (jsc#PED-7574).
- net: convert some netlink netdev iterators to depend on the
  xarray (jsc#PED-7574).
- ynl: expose xdp-zc-max-segs (jsc#PED-7574).
- netlink: allow be16 and be32 types in all uint policy checks
  (jsc#PED-7574).
- net: Remove unused declaration dev_restart() (jsc#PED-7574).
- connector/cn_proc: Allow non-root users access (jsc#PED-7574).
- connector/cn_proc: Performance improvements (jsc#PED-7574).
- connector/cn_proc: Add filtering to fix some bugs
  (jsc#PED-7574).
- netlink: Add new netlink_release function (jsc#PED-7574).
- netlink: Reverse the patch which removed filtering
  (jsc#PED-7574).
- selftests/xsk: add basic multi-buffer test (jsc#PED-7574).
- selftests/xsk: transmit and receive multi-buffer packets
  (jsc#PED-7574).
- xsk: support ZC Tx multi-buffer in batch API (jsc#PED-7574).
- xsk: discard zero length descriptors in Tx path (jsc#PED-7574).
- net: create device lookup API with reference tracking
  (jsc#PED-7574).
- commit e8d3010
* Mon Jan 22 2024 oneukum@suse.com
- r8152: Choose our USB config with choose_configuration()
  rather than probe() (git-fixes).
- commit 1e8cc32
* Mon Jan 22 2024 denis.kirjanov@suse.com
- mlxsw: i2c: Limit single transaction buffer size (git-fixes).
- commit 8e2d36d
* Mon Jan 22 2024 oneukum@suse.com
- usb: core: Fix crash w/ usb_choose_configuration() if no driver
  (git-fixes).
- commit 3b35679
* Mon Jan 22 2024 denis.kirjanov@suse.com
- mlxsw: i2c: Fix chunk size setting in output mailbox buffer
  (git-fixes).
- commit 05f3c6b
* Mon Jan 22 2024 denis.kirjanov@suse.com
- net: handle ARPHRD_PPP in dev_is_mac_header_xmit() (git-fixes).
- commit 06f5d73
* Mon Jan 22 2024 denis.kirjanov@suse.com
- net: lan966x: Fix return value check for vcap_get_rule()
  (git-fixes).
- commit 03b99a2
* Mon Jan 22 2024 oneukum@suse.com
- usb: core: Allow subclassed USB drivers to override
  usb_choose_configuration() (git-fixes).
- commit 44b3c00
* Mon Jan 22 2024 denis.kirjanov@suse.com
- net: hns3: fix wrong rpu tln reg issue (git-fixes).
- commit a1137c7
* Mon Jan 22 2024 denis.kirjanov@suse.com
- net: hns3: Support tlv in regs data for HNS3 PF driver
  (git-fixes).
- commit 6734c8c
* Mon Jan 22 2024 denis.kirjanov@suse.com
- net: hns3: move dump regs function to a separate file
  (git-fixes).
- commit 4080e37
* Mon Jan 22 2024 denis.kirjanov@suse.com
- net: ethernet: adi: adin1110: use eth_broadcast_addr() to
  assign broadcast address (git-fixes).
- commit c53d87f
* Mon Jan 22 2024 oneukum@suse.com
- usb: core: Don't force USB generic_subclass drivers to define
  probe() (git-fixes).
- commit 7e41fc6
* Mon Jan 22 2024 denis.kirjanov@suse.com
- net: altera: tse: remove mac_an_restart() function (git-fixes).
- commit 666a388
* Mon Jan 22 2024 tiwai@suse.de
- net: usb: ax88179_178a: avoid two consecutive device resets
  (bsc#1218948).
- commit 8517946
* Mon Jan 22 2024 ohering@suse.de
- RDMA/mana_ib: Add CQ interrupt support for RAW QP (git-fixes).
- RDMA/mana_ib: query device capabilities (git-fixes).
- RDMA/mana_ib: register RDMA device with GDMA (git-fixes).
- hv_netvsc: remove duplicated including of slab.h (git-fixes).
- net: mana: add msix index sharing between EQs (git-fixes).
- net: mana: Fix spelling mistake "enforecement" -> "enforcement"
  (git-fixes).
- net :mana :Add remaining GDMA stats for MANA to ethtool
  (git-fixes).
- net: mana: select PAGE_POOL (git-fixes).
- hv_netvsc: rndis_filter needs to select NLS (git-fixes).
- commit a651fcd
* Mon Jan 22 2024 tiwai@suse.de
- Move upstreamed patches into sorted section
- commit 412a82b
* Mon Jan 22 2024 jslaby@suse.cz
- misc: hpilo: make ilo_class a static const structure
  (jsc#PED-7689).
- commit 48ef5cd
* Mon Jan 22 2024 neilb@suse.de
- nfsd: fix RELEASE_LOCKOWNER (bsc#1218968).
- commit 2ac4814
* Sun Jan 21 2024 ailiop@suse.com
- xfs: allow read IO and FICLONE to run concurrently
  (bsc#1218934).
- commit b6b4c4a
* Sun Jan 21 2024 tiwai@suse.de
- Input: atkbd - use ab83 as id when skipping the getid command
  (git-fixes).
- commit 09aa4d9
* Sun Jan 21 2024 tiwai@suse.de
- Add alt-commit to an ASoC fix
- commit ac54a21
* Sun Jan 21 2024 tiwai@suse.de
- parport: parport_serial: Add Brainboxes device IDs and geometry
  (git-fixes).
- parport: parport_serial: Add Brainboxes BAR details (git-fixes).
- scripts/decode_stacktrace.sh: optionally use LLVM utilities
  (git-fixes).
- nfc: Do not send datagram if socket state isn't LLCP_BOUND
  (git-fixes).
- Input: xpad - add Razer Wolverine V2 support (git-fixes).
- Input: i8042 - add nomux quirk for Acer P459-G2-M (git-fixes).
- Input: atkbd - skip ATKBD_CMD_GETID in translated mode
  (git-fixes).
- Input: psmouse - enable Synaptics InterTouch for ThinkPad L14 G1
  (git-fixes).
- kselftest: alsa: fixed a print formatting warning (git-fixes).
- i2c: rk3x: fix potential spinlock recursion on poll (git-fixes).
- pinctrl: cy8c95x0: Fix get_pincfg (git-fixes).
- pinctrl: cy8c95x0: Fix regression (git-fixes).
- pinctrl: cy8c95x0: Fix typo (git-fixes).
- pinctrl: amd: Mask non-wake source pins with interrupt enabled
  at suspend (git-fixes).
- wifi: iwlwifi: pcie: avoid a NULL pointer dereference
  (git-fixes).
- reset: hisilicon: hi6220: fix Wvoid-pointer-to-enum-cast warning
  (git-fixes).
- platform/x86/amd/pmc: Disable keyboard wakeup on AMD Framework
  13 (git-fixes).
- platform/x86/amd/pmc: Move keyboard wakeup disablement detection
  to pmc-quirks (git-fixes).
- platform/x86/amd/pmc: Only run IRQ1 firmware version check on
  Cezanne (git-fixes).
- platform/x86/amd/pmc: Move platform defines to header
  (git-fixes).
- platform/x86: thinkpad_acpi: fix for incorrect fan reporting
  on some ThinkPad systems (git-fixes).
- soundwire: intel_ace2x: fix AC timing setting for ACE2.x
  (git-fixes).
- platform/x86: intel-vbtn: Fix missing tablet-mode-switch events
  (git-fixes).
- hwtracing: hisi_ptt: Don't try to attach a task (git-fixes).
- hwtracing: hisi_ptt: Handle the interrupt in hardirq context
  (git-fixes).
- hwmon: (corsair-psu) Fix probe when built-in (git-fixes).
- nouveau/tu102: flush all pdbs on vmm flush (git-fixes).
- kunit: Reset suite counter right before running tests
  (git-fixes).
- kunit: Warn if tests are slow (git-fixes).
- wifi: mac80211: handle 320 MHz in
  ieee80211_ht_cap_ie_to_sta_ht_cap (git-fixes).
- wifi: avoid offset calculation on NULL pointer (git-fixes).
- wifi: cfg80211: lock wiphy mutex for rfkill poll (git-fixes).
- pinctrl: lochnagar: Don't build on MIPS (git-fixes).
- pinctrl: s32cc: Avoid possible string truncation (git-fixes).
- pinctrl: amd: Use pm_pr_dbg to show debugging messages
  (git-fixes).
- commit ab000cc
* Sun Jan 21 2024 tiwai@suse.de
- dmaengine: idxd: Move dma_free_coherent() out of spinlocked
  context (git-fixes).
- dmaengine: fix NULL pointer in channel unregistration function
  (git-fixes).
- driver core: Add a guard() definition for the device_lock()
  (git-fixes).
- drm/amd/display: get dprefclk ss info from integration info
  table (git-fixes).
- drm/amd/display: Add case for dcn35 to support usb4 dmub hpd
  event (git-fixes).
- drm/amdkfd: svm range always mapped flag not working on APU
  (git-fixes).
- HID: nintendo: Prevent divide-by-zero on code (git-fixes).
- HID: nintendo: fix initializer element is not constant error
  (git-fixes).
- drm/crtc: fix uninitialized variable use (git-fixes).
- drm/crtc: Fix uninit-value bug in drm_mode_setcrtc (git-fixes).
- drm/exynos: fix a wrong error checking (git-fixes).
- drm/exynos: fix a potential error pointer dereference
  (git-fixes).
- drm/amdgpu: Add NULL checks for function pointers (git-fixes).
- drm/amd/display: Add monitor patch for specific eDP (git-fixes).
- drm/amdgpu: Use another offset for GC 9.4.3 remap (git-fixes).
- drm/amdkfd: Free gang_ctx_bo and wptr_bo in pqm_uninit
  (git-fixes).
- drm/amdgpu: Fix cat debugfs amdgpu_regs_didt causes kernel
  null pointer (git-fixes).
- drm/amd/display: update dcn315 lpddr pstate latency (git-fixes).
- drm/amdkfd: Use common function for IP version check
  (git-fixes).
- drm/amdgpu: Do not issue gpu reset from nbio v7_9 bif interrupt
  (git-fixes).
- commit f779c78
* Sun Jan 21 2024 colyli@suse.de
- virtio_pmem: support feature SHMEM_REGION (jsc#PED-5853).
- nvdimm/namespace: fix kernel-doc for function params
  (jsc#PED-5853).
- nvdimm/dimm_devs: fix kernel-doc for function params
  (jsc#PED-5853).
- nvdimm/btt: fix btt_blk_cleanup() kernel-doc (jsc#PED-5853).
- nvdimm-btt: simplify code with the scope based resource
  management (jsc#PED-5853).
- nvdimm: Remove usage of the deprecated ida_simple_xx() API
  (jsc#PED-5853).
- nvdimm/btt: replace deprecated strncpy with strscpy
  (jsc#PED-5853).
- dax/kmem: allow kmem to add memory with memmap_on_memory
  (jsc#PED-5853).
- libnvdimm: remove kernel-doc warnings: (jsc#PED-5853).
- libnvdimm: Annotate struct nd_region with __counted_by
  (jsc#PED-5853).
- nd_btt: Make BTT lanes preemptible (jsc#PED-5853).
- libnvdimm/of_pmem: Use devm_kstrdup instead of kstrdup and
  check its return value (jsc#PED-5853).
- dax: refactor deprecated strncpy (jsc#PED-5853).
- nvdimm: Fix dereference after free in register_nvdimm_pmu()
  (jsc#PED-5853).
- nvdimm: Fix memleak of pmu attr_groups in
  unregister_nvdimm_pmu() (jsc#PED-5853).
- nvdimm/pfn_dev: Avoid unnecessary endian conversion
  (jsc#PED-5853).
- nvdimm/pfn_dev: Prevent the creation of zero-sized namespaces
  (jsc#PED-5853).
- nvdimm: Explicitly include correct DT includes (jsc#PED-5853).
- nvdimm: Use kstrtobool() instead of strtobool() (jsc#PED-5853).
- mm/hugepage pud: allow arch-specific helper function to check
  huge page pud support (jsc#PED-5853).
- dax: enable dax fault handler to report VM_FAULT_HWPOISON
  (jsc#PED-5853).
- dax: Cleanup extra dax_region references (jsc#PED-5853).
- dax: Use device_unregister() in unregister_dax_mapping()
  (jsc#PED-5853).
- nvdimm: make security_show static (jsc#PED-5853).
- nvdimm: make nd_class variable static (jsc#PED-5853).
- libnvdimm: mark 'security_show' static again (jsc#PED-5853).
- dax: fix missing-prototype warnings (jsc#PED-5853).
- commit b5a37cd
* Sun Jan 21 2024 tiwai@suse.de
- bus: moxtet: Add spi device table (git-fixes).
- bus: moxtet: Mark the irq as shared (git-fixes).
- ACPI: resource: Add another DMI match for the TongFang GMxXGxx
  (git-fixes).
- ARM: sun9i: smp: fix return code check of
  of_property_match_string (git-fixes).
- ASoC: SOF: Intel: hda-codec: Delay the codec device registration
  (git-fixes).
- ASoC: Intel: bytcr_rt5640: Add new swapped-speakers quirk
  (git-fixes).
- ASoC: Intel: bytcr_rt5640: Add quirk for the Medion Lifetab
  S10346 (git-fixes).
- ASoC: cs35l45: Prevents spinning during runtime suspend
  (git-fixes).
- ASoC: cs35l45: Prevent IRQ handling when suspending/resuming
  (git-fixes).
- ASoC: cs35l45: Use modern pm_ops (git-fixes).
- clk: rockchip: rk3128: Fix HCLK_OTG gate register (git-fixes).
- clk: rockchip: rk3568: Add PLL rate for 292.5MHz (git-fixes).
- ASoC: da7219: Support low DC impedance headset (git-fixes).
- ASoC: SOF: ipc4-topology: Correct data structures for the GAIN
  module (git-fixes).
- ASoC: SOF: ipc4-topology: Correct data structures for the SRC
  module (git-fixes).
- ASoC: hdac_hda: Conditionally register dais for HDMI and Analog
  (git-fixes).
- ASoC: SOF: sof-audio: Modify logic for enabling/disabling
  topology cores (git-fixes).
- ASoC: SOF: ipc4-topology: Add core_mask in struct
  snd_sof_pipeline (git-fixes).
- ASoC: Intel: skl_hda_dsp_generic: Drop HDMI routes when HDMI
  is not available (git-fixes).
- ASoC: fsl_xcvr: refine the requested phy clock frequency
  (git-fixes).
- ASoC: rt5650: add mutex to avoid the jack detection failure
  (git-fixes).
- ASoC: fsl_xcvr: Enable 2 * TX bit clock for spdif only case
  (git-fixes).
- ASoC: cs43130: Fix incorrect frame delay configuration
  (git-fixes).
- ASoC: cs43130: Fix the position of const qualifier (git-fixes).
- ASoC: Intel: Skylake: mem leak in skl register function
  (git-fixes).
- ASoC: SOF: topology: Fix mem leak in sof_dai_load() (git-fixes).
- ASoC: nau8822: Fix incorrect type in assignment and cast to
  restricted __be16 (git-fixes).
- ASoC: Intel: Skylake: Fix mem leak in few functions (git-fixes).
- ASoC: wm8974: Correct boost mixer inputs (git-fixes).
- commit 8e23814
* Sat Jan 20 2024 tiwai@suse.de
- watchdog/hpwdt: Remove unused variable (jsc#PED-7477).
- watchdog/hpwdt: Remove redundant test (jsc#PED-7477).
- commit 1d0b9e9
* Sat Jan 20 2024 tiwai@suse.de
- Update patch reference for hpwdt patch (jsc#PED-7477)
- commit 6b37003
* Sat Jan 20 2024 tiwai@suse.de
- ALSA: hda/realtek: Enable headset mic on Lenovo M70 Gen5
  (git-fixes).
- ALSA: hda/realtek: Enable mute/micmute LEDs and limit mic
  boost on HP ZBook (git-fixes).
- ALSA: hda/relatek: Enable Mute LED on HP Laptop 15s-fq2xxx
  (git-fixes).
- commit 9f81551
* Sat Jan 20 2024 tiwai@suse.de
- libapi: Add missing linux/types.h header to get the __u64 type
  on io.h (git-fixes).
- arm64/sme: Always exit sme_alloc() early with existing storage
  (git-fixes).
- arm64/fpsimd: Remove spurious check for SVE support (git-fixes).
- arm64/ptrace: Don't flush ZA/ZT storage when writing ZA via
  ptrace (git-fixes).
- arm64: scs: Work around full LTO issue with dynamic SCS
  (git-fixes).
- ASoC: SOF: ipc4-loader: remove the CPC check warnings
  (git-fixes).
- ASoC: SOF: ipc4-pcm: remove log message for LLP (git-fixes).
- ASoC: mediatek: sof-common: Add NULL check for normal_link
  string (git-fixes).
- ALSA: oxygen: Fix right channel of capture volume mixer
  (git-fixes).
- drm/amdgpu: revert "Adjust removal control flow for smu v13_0_2"
  (git-fixes).
- drm/amdgpu: Fix the null pointer when load rlc firmware
  (git-fixes).
- drm/amdgpu: fall back to INPUT power for AVG power via INFO
  IOCTL (git-fixes).
- drm/amdkfd: fixes for HMM mem allocation (git-fixes).
- Revert "drm/amd/display: fix bandwidth validation failure on
  DCN 2.1" (git-fixes).
- power: supply: cw2015: correct time_to_empty units in sysfs
  (git-fixes).
- power: supply: bq256xx: fix some problem in bq256xx_hw_init
  (git-fixes).
- apparmor: avoid crash when parsed profile name is empty
  (git-fixes).
- apparmor: fix possible memory leak in unpack_trans_table
  (git-fixes).
- serial: sc16is7xx: set safe default SPI clock frequency
  (git-fixes).
- serial: sc16is7xx: add check for unsupported SPI modes during
  probe (git-fixes).
- commit ec5fb8d
* Fri Jan 19 2024 tonyj@suse.de
- perf/x86/intel/uncore: Factor out topology_gidnid_map()
  (bsc#1218958).
- perf/x86/intel/uncore: Fix NULL pointer dereference issue in
  upi_fill_topology() (bsc#1218958).
- commit 3c9d9ce
* Fri Jan 19 2024 tiwai@suse.de
- selftests: mlxsw: qos_pfc: Adjust the test to support 8 lanes
  (git-fixes).
- selftests: mlxsw: qos_pfc: Remove wrong description (git-fixes).
- selftests: bonding: Add more missing config options (git-fixes).
- selftests: netdevsim: add a config file (git-fixes).
- usb: mon: Fix atomicity violation in mon_bin_vma_fault
  (git-fixes).
- usb: typec: class: fix typec_altmode_put_partner to put plugs
  (git-fixes).
- usb: xhci-mtk: fix a short packet issue of gen1 isoc-in transfer
  (git-fixes).
- usb: dwc3: gadget: Queue PM runtime idle on disconnect event
  (git-fixes).
- usb: phy: mxs: remove CONFIG_USB_OTG condition for
  mxs_phy_is_otg_host() (git-fixes).
- usb: chipidea: wait controller resume finished for wakeup irq
  (git-fixes).
- usb: cdns3: Fix uvc fail when DMA cross 4k boundery since sg
  enabled (git-fixes).
- usb: cdns3: fix iso transfer error when mult is not zero
  (git-fixes).
- usb: cdns3: fix uvc failure work since sg support enabled
  (git-fixes).
- usb: dwc: ep0: Update request status in dwc3_ep0_stall_restart
  (git-fixes).
- usb: dwc3: gadget: Handle EP0 request dequeuing properly
  (git-fixes).
- Revert "usb: dwc3: don't reset device side if dwc3 was
  configured as host-only" (git-fixes).
- Revert "usb: dwc3: Soft reset phy on probe for host"
  (git-fixes).
- Revert "usb: typec: class: fix typec_altmode_put_partner to
  put plugs" (git-fixes).
- usb: gadget: webcam: Make g_webcam loadable again (git-fixes).
- serial: omap: do not override settings for RS485 support
  (git-fixes).
- serial: core, imx: do not set RS485 enabled if it is not
  supported (git-fixes).
- serial: core: make sure RS485 cannot be enabled when it is
  not supported (git-fixes).
- serial: core: fix sanitizing check for RTS settings (git-fixes).
- serial: 8250_bcm2835aux: Restore clock error handling
  (git-fixes).
- serial: imx: Ensure that imx_uart_rs485_config() is called
  with enabled clock (git-fixes).
- serial: apbuart: fix console prompt on qemu (git-fixes).
- serial: imx: Correct clock error message in function probe()
  (git-fixes).
- serial: imx: fix tx statemachine deadlock (git-fixes).
- serial: sccnxp: Improve error message if regulator_disable()
  fails (git-fixes).
- serial: 8250: omap: Don't skip resource freeing if
  pm_runtime_resume_and_get() failed (git-fixes).
- software node: Let args be NULL in
  software_node_get_reference_args (git-fixes).
- commit 1dd97ae
* Fri Jan 19 2024 tiwai@suse.de
- modpost: move __attribute__((format(printf, 2, 3))) to modpost.h
  (git-fixes).
- kbuild: buildtar: Remove unused $dirs (git-fixes).
- kdb: Fix a potential buffer overflow in kdb_local() (git-fixes).
- selftests: bonding: add missing build configs (git-fixes).
- selftests: netdevsim: sprinkle more udevadm settle (git-fixes).
- selftests: bonding: Change script interpreter (git-fixes).
- i2c: s3c24xx: fix transferring more than one message in polling
  mode (git-fixes).
- i2c: s3c24xx: fix read transfers in polling mode (git-fixes).
- rtc: Extend timeout for waiting for UIP to clear to 1s
  (git-fixes).
- rtc: Add support for configuring the UIP timeout for RTC reads
  (git-fixes).
- rtc: Adjust failure return code for cmos_set_alarm()
  (git-fixes).
- rtc: mc146818-lib: Adjust failure return code for
  mc146818_get_time() (git-fixes).
- gpio: EN7523: fix kernel-doc warnings (git-fixes).
- pwm: jz4740: Don't use dev_err_probe() in .request()
  (git-fixes).
- pwm: Fix out-of-bounds access in of_pwm_single_xlate()
  (git-fixes).
- backlight: hx8357: Convert to agnostic GPIO API (git-fixes).
- dma-debug: fix kernel-doc warnings (git-fixes).
- cxl/port: Fix decoder initialization when nr_targets >
  interleave_ways (git-fixes).
- cxl/region: fix x9 interleave typo (git-fixes).
- selftests/sgx: Skip non X86_64 platform (git-fixes).
- selftests/sgx: Include memory clobber for inline asm in test
  enclave (git-fixes).
- selftests/sgx: Fix uninitialized pointer dereferences in
  encl_get_entry (git-fixes).
- selftests/sgx: Fix uninitialized pointer dereference in error
  path (git-fixes).
- class: fix use-after-free in class_register() (git-fixes).
- acpi: property: Let args be NULL in
  __acpi_node_get_property_reference (git-fixes).
- base/node.c: initialize the accessor list before registering
  (git-fixes).
- commit 7b0bf11
* Fri Jan 19 2024 mfranc@suse.cz
- s390/vfio-ap: do not reset queue removed from host config
  (git-fixes bsc#1218996).
- commit bc352ee
* Fri Jan 19 2024 mfranc@suse.cz
- s390/vfio-ap: reset queues associated with adapter for queue
  unbound from driver (bsc#1218993 git-fixes).
- commit 5646a17
* Fri Jan 19 2024 mfranc@suse.cz
- s390/vfio-ap: realize the VFIO_DEVICE_SET_IRQS ioctl
  (bsc#1218992 git-fixes).
- commit 772cff8
* Fri Jan 19 2024 mfranc@suse.cz
- s390/vfio-ap: realize the VFIO_DEVICE_GET_IRQ_INFO ioctl
  (bsc#1218992 git-fixes).
- commit 7a3f44a
* Fri Jan 19 2024 mfranc@suse.cz
- s390/vfio-ap: reset queues filtered from the guest's AP config
  (git-fixes bsc#1218992).
- commit 79ec7d5
* Fri Jan 19 2024 mfranc@suse.cz
- s390/vfio-ap: let on_scan_complete() callback filter matrix
  and update guest's APCB (git-fixes bsc#1218991).
- commit 692b477
* Fri Jan 19 2024 mfranc@suse.cz
- s390/vfio-ap: loop over the shadow APCB when filtering guest's
  AP configuration (git-fixes bsc#1218989).
- commit 8ddc8b3
* Fri Jan 19 2024 mfranc@suse.cz
- s390/vfio-ap: always filter entire AP matrix (git-fixes
  bsc#1218988).
- commit 8a86865
* Fri Jan 19 2024 mfranc@suse.cz
- s390/pci: fix max size calculation in zpci_memcpy_toio()
  (git-fixes bsc#1218987).
- commit d38497a
* Thu Jan 18 2024 shung-hsi.yu@suse.com
- bpf: Use c->unit_size to select target cache during free
  (jsc#PED-6811).
- bpf: Limit the number of uprobes when attaching program to
  multiple uprobes (jsc#PED-6811).
- bpf: Add KF_RCU flag to bpf_refcount_acquire_impl
  (jsc#PED-6811).
- bpf: Add missing BPF_LINK_TYPE invocations (jsc#PED-6811).
- netfilter: bpf: fix bad registration on nf_defrag
  (jsc#PED-6811).
- bpf: Fix a verifier bug due to incorrect branch offset
  comparison with cpu=v4 (jsc#PED-6811).
- bpf: Add missed allocation hint for bpf_mem_cache_alloc_flags()
  (jsc#PED-6811).
- selftests/bpf: trace_helpers.c: Optimize kallsyms cache
  (jsc#PED-6811).
- net: Fix skb consume leak in sch_handle_egress (jsc#PED-6811).
- net: Fix slab-out-of-bounds in inet_steal_sock (jsc#PED-6811).
- net: remove duplicate INDIRECT_CALLABLE_DECLARE of udp_ehashfn
  (jsc#PED-6811).
- tcx: Fix splat during dev unregister (jsc#PED-6811).
- tcx: Fix splat in ingress_destroy upon tcx_entry_free
  (jsc#PED-6811).
- commit 5be5d11
* Thu Jan 18 2024 mfranc@suse.cz
- KVM: s390: vsie: Fix STFLE interpretive execution identification
  (git-fixes bsc#1218960).
- commit ad0fc48
* Thu Jan 18 2024 shung-hsi.yu@suse.com
- powerpc/bpf: use bpf_jit_binary_pack_[alloc|finalize|free]
  (jsc#PED-5083).
- powerpc/bpf: rename powerpc64_jit_data to powerpc_jit_data
  (jsc#PED-5083).
- powerpc/bpf: implement bpf_arch_text_invalidate for
  bpf_prog_pack (jsc#PED-5083).
- powerpc/bpf: implement bpf_arch_text_copy (jsc#PED-5083).
- powerpc/code-patching: introduce patch_instructions()
  (jsc#PED-5083).
- commit ed7c82d
* Thu Jan 18 2024 ailiop@suse.com
- ubifs: ubifs_symlink: Fix memleak of inode->i_link in error path
  (git-fixes).
- commit b2151e4
* Thu Jan 18 2024 ailiop@suse.com
- ubifs: Check @c->dirty_[n|p]n_cnt and @c->nroot state under
  @c->lp_mutex (git-fixes).
- commit 837ee41
* Thu Jan 18 2024 ailiop@suse.com
- exfat: support handle zero-size directory (git-fixes).
- commit 4e50352
* Thu Jan 18 2024 shung-hsi.yu@suse.com
- bpf: Add fd-based tcx multi-prog infra with link support (jsc#PED-6811).
- Update config files, add CONFIG_XGRESS=y
- commit 2251cdf
* Thu Jan 18 2024 denis.kirjanov@suse.com
- ibmveth: Remove condition to recompute TCP header checksum
  (jsc#PED-5067).
- commit 59a623a
* Thu Jan 18 2024 denis.kirjanov@suse.com
- tipc: fix a potential deadlock on &tx->lock (bsc#1218916
  CVE-2024-0641).
- commit eaf2892
* Thu Jan 18 2024 denis.kirjanov@suse.com
- Update metadata
- commit bd3aa7e
* Thu Jan 18 2024 tiwai@suse.de
- config: Use upstream default CONFIG_HZ (jsc#PED-7600)
  Follow SLE15-SP6 for the CONFIG_HZ value changes; except for x86_64
  all archs are with the upstream default values.
- commit fc0f1af
* Thu Jan 18 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add testcase for async callback return value
  failure (jsc#PED-6811).
- bpf: Fix verifier log for async callback return values
  (jsc#PED-6811).
- xdp: Fix zero-size allocation warning in xskq_create()
  (jsc#PED-6811).
- riscv, bpf: Track both a0 (RISC-V ABI) and a5 (BPF) return
  values (jsc#PED-6811).
- riscv, bpf: Sign-extend return values (jsc#PED-6811).
- selftests/bpf: Make seen_tc* variable tests more robust
  (jsc#PED-6811).
- selftests/bpf: Test query on empty mprog and pass revision
  into attach (jsc#PED-6811).
- selftests/bpf: Adapt assert_mprog_count to always expect 0 count
  (jsc#PED-6811).
- selftests/bpf: Test bpf_mprog query API via libbpf and raw
  syscall (jsc#PED-6811).
- bpf: Refuse unused attributes in bpf_prog_{attach,detach}
  (jsc#PED-6811).
- bpf: Handle bpf_mprog_query with NULL entry (jsc#PED-6811).
- bpf: Fix BPF_PROG_QUERY last field check (jsc#PED-6811).
- bpf: Use kmalloc_size_roundup() to adjust size_index
  (jsc#PED-6811).
- selftest/bpf: Add various selftests for program limits
  (jsc#PED-6811).
- bpf, mprog: Fix maximum program check on mprog attachment
  (jsc#PED-6811).
- bpf, sockmap: Reject sk_msg egress redirects to non-TCP sockets
  (jsc#PED-6811).
- bpf, sockmap: Add tests for MSG_F_PEEK (jsc#PED-6811).
- bpf, sockmap: Do not inc copied_seq when PEEK flag set
  (jsc#PED-6811).
- bpf: tcp_read_skb needs to pop skb regardless of seq
  (jsc#PED-6811).
- bpf: unconditionally reset backtrack_state masks on global
  func exit (jsc#PED-6811).
- bpf: Fix tr dereferencing (jsc#PED-6811).
- selftests/bpf: Check bpf_cubic_acked() is called via struct_ops
  (jsc#PED-6811).
- bpf: Fix BTF_ID symbol generation collision in tools/
  (jsc#PED-6811).
- bpf: Fix BTF_ID symbol generation collision (jsc#PED-6811).
- bpf: Fix uprobe_multi get_pid_task error path (jsc#PED-6811).
- bpf: Skip unit_size checking for global per-cpu allocator
  (jsc#PED-6811).
- netfilter, bpf: Adjust timeouts of non-confirmed CTs in
  bpf_ct_insert_entry() (jsc#PED-6811).
- selftests/bpf: Fix kprobe_multi_test/attach_override test
  (jsc#PED-6811).
- bpf, cgroup: fix multiple kernel-doc warnings (jsc#PED-6811).
- selftests/bpf: fix unpriv_disabled check in test_verifier
  (jsc#PED-6811).
- bpf: Fix a erroneous check after snprintf() (jsc#PED-6811).
- selftests/bpf: ensure all CI arches set
  CONFIG_BPF_KPROBE_OVERRIDE=y (jsc#PED-6811).
- selftests/bpf: Offloaded prog after non-offloaded should not
  cause BUG (jsc#PED-6811).
- bpf: Avoid dummy bpf_offload_netdev in __bpf_prog_dev_bound_init
  (jsc#PED-6811).
- bpf: Avoid deadlock when using queue and stack maps from NMI
  (jsc#PED-6811).
- selftests/bpf: Update bpf_clone_redirect expected return code
  (jsc#PED-6811).
- bpf: Clarify error expectations from bpf_clone_redirect
  (jsc#PED-6811).
- selftests/bpf: Test all valid alloc sizes for bpf mem allocator
  (jsc#PED-6811).
- bpf: Ensure unit_size is matched with slab cache object size
  (jsc#PED-6811).
- bpf: Don't prefill for unused bpf_mem_cache (jsc#PED-6811).
- bpf: Adjust size_index according to the value of
  KMALLOC_MIN_SIZE (jsc#PED-6811).
- selftests/bpf: Add kprobe_multi override test (jsc#PED-6811).
- bpf, riscv: use prog pack allocator in the BPF JIT
  (jsc#PED-6811).
- riscv: implement a memset like function for text (jsc#PED-6811).
- riscv: extend patch_text_nosync() for multiple pages
  (jsc#PED-6811).
- bpf: make bpf_prog_pack allocator portable (jsc#PED-6811).
- selftests/bpf: Check bpf_sk_storage has uncharged sk_omem_alloc
  (jsc#PED-6811).
- bpf: bpf_sk_storage: Fix the missing uncharge in sk_omem_alloc
  (jsc#PED-6811).
- bpf: bpf_sk_storage: Fix invalid wait context lockdep report
  (jsc#PED-6811).
- bpf: Assign bpf_tramp_run_ctx::saved_run_ctx before recursion
  check (jsc#PED-6811).
- bpf: Invoke __bpf_prog_exit_sleepable_recur() on recursion in
  kern_sys_bpf() (jsc#PED-6811).
- bpf, sockmap: Fix skb refcnt race after locking changes
  (jsc#PED-6811).
- docs/bpf: Fix "file doesn't exist" warnings in
  {llvm_reloc,btf}.rst (jsc#PED-6811).
- selftests/bpf: Include build flavors for install target
  (jsc#PED-6811).
- bpf: Annotate bpf_long_memcpy with data_race (jsc#PED-6811).
- selftests/bpf: Fix d_path test (jsc#PED-6811).
- bpf, docs: Fix invalid escape sequence warnings in bpf_doc.py
  (jsc#PED-6811).
- bpf, docs: s/eBPF/BPF in standards documents (jsc#PED-6811).
- bpf, docs: Add abi.rst document to standardization subdirectory
  (jsc#PED-6811).
- bpf, docs: Move linux-notes.rst to root bpf docs tree
  (jsc#PED-6811).
- bpf, sockmap: Fix preempt_rt splat when using raw_spin_lock_t
  (jsc#PED-6811).
- docs/bpf: Add description for CO-RE relocations (jsc#PED-6811).
- bpf, docs: Correct source of offset for program-local call
  (jsc#PED-6811).
- bpftool: Fix build warnings with -Wtype-limits (jsc#PED-6811).
- bpf: Prevent inlining of bpf_fentry_test7() (jsc#PED-6811).
- commit 65b8e7a
* Thu Jan 18 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add tests for rbtree API interaction in sleepable
  progs (jsc#PED-6811).
- bpf: Allow bpf_spin_{lock,unlock} in sleepable progs
  (jsc#PED-6811).
- bpf: Consider non-owning refs to refcounted nodes RCU protected
  (jsc#PED-6811).
- bpf: Reenable bpf_refcount_acquire (jsc#PED-6811).
- bpf: Use bpf_mem_free_rcu when bpf_obj_dropping refcounted nodes
  (jsc#PED-6811).
- bpf: Consider non-owning refs trusted (jsc#PED-6811).
- selftests/bpf: Enable cpu v4 tests for RV64 (jsc#PED-6811).
- riscv, bpf: Support unconditional bswap insn (jsc#PED-6811).
- riscv, bpf: Support signed div/mod insns (jsc#PED-6811).
- riscv, bpf: Support 32-bit offset jmp insn (jsc#PED-6811).
- riscv, bpf: Support sign-extension mov insns (jsc#PED-6811).
- riscv, bpf: Support sign-extension load insns (jsc#PED-6811).
- riscv, bpf: Fix missing exception handling and redundant zext
  for LDX_B/H/W (jsc#PED-6811).
- samples/bpf: Add note to README about the XDP utilities moved
  to xdp-tools (jsc#PED-6811).
- samples/bpf: Cleanup .gitignore (jsc#PED-6811).
- samples/bpf: Remove the xdp_sample_pkts utility (jsc#PED-6811).
- samples/bpf: Remove the xdp1 and xdp2 utilities (jsc#PED-6811).
- samples/bpf: Remove the xdp_rxq_info utility (jsc#PED-6811).
- samples/bpf: Remove the xdp_redirect* utilities (jsc#PED-6811).
- samples/bpf: Remove the xdp_monitor utility (jsc#PED-6811).
- selftests/bpf: Add a local kptr test with no special fields
  (jsc#PED-6811).
- bpf: Remove a WARN_ON_ONCE warning related to local kptr
  (jsc#PED-6811).
- libbpf: fix signedness determination in CO-RE relo handling
  logic (jsc#PED-6811).
- selftests/bpf: add uprobe_multi test binary to .gitignore
  (jsc#PED-6811).
- libbpf: Add bpf_object__unpin() (jsc#PED-6811).
- selftests/bpf: Add selftest for allow_ptr_leaks (jsc#PED-6811).
- bpf: Fix issue in verifying allow_ptr_leaks (jsc#PED-6811).
- libbpf: Free btf_vmlinux when closing bpf_object (jsc#PED-6811).
- selftests/bpf: Add test for bpf_obj_drop with bad reg->off
  (jsc#PED-6811).
- bpf: Fix check_func_arg_reg_off bug for graph root/node
  (jsc#PED-6811).
- selftests/bpf: Add a failure test for bpf_kptr_xchg() with
  local kptr (jsc#PED-6811).
- bpf: Fix a bpf_kptr_xchg() issue with local kptr (jsc#PED-6811).
- selftests/bpf: Add extra link to uprobe_multi tests
  (jsc#PED-6811).
- selftests/bpf: Add uprobe_multi pid filter tests (jsc#PED-6811).
- selftests/bpf: Add uprobe_multi cookie test (jsc#PED-6811).
- selftests/bpf: Add uprobe_multi usdt bench test (jsc#PED-6811).
- selftests/bpf: Add uprobe_multi usdt test code (jsc#PED-6811).
- selftests/bpf: Add uprobe_multi bench test (jsc#PED-6811).
- selftests/bpf: Add uprobe_multi test program (jsc#PED-6811).
- selftests/bpf: Add uprobe_multi link test (jsc#PED-6811).
- selftests/bpf: Add uprobe_multi api test (jsc#PED-6811).
- selftests/bpf: Add uprobe_multi skel test (jsc#PED-6811).
- selftests/bpf: Move get_time_ns to testing_helpers.h
  (jsc#PED-6811).
- libbpf: Add uprobe multi link support to
  bpf_program__attach_usdt (jsc#PED-6811).
- libbpf: Add uprobe multi link detection (jsc#PED-6811).
- libbpf: Add support for uprobe.multi[.s] program sections
  (jsc#PED-6811).
- libbpf: Add bpf_program__attach_uprobe_multi function
  (jsc#PED-6811).
- libbpf: Add bpf_link_create support for multi uprobes
  (jsc#PED-6811).
- libbpf: Add elf_resolve_pattern_offsets function (jsc#PED-6811).
- libbpf: Add elf_resolve_syms_offsets function (jsc#PED-6811).
- libbpf: Add elf symbol iterator (jsc#PED-6811).
- libbpf: Add elf_open/elf_close functions (jsc#PED-6811).
- libbpf: Move elf_find_func_offset* functions to elf object
  (jsc#PED-6811).
- libbpf: Add uprobe_multi attach type and link names
  (jsc#PED-6811).
- bpf: Add bpf_get_func_ip helper support for uprobe link
  (jsc#PED-6811).
- bpf: Add pid filter support for uprobe_multi link
  (jsc#PED-6811).
- bpf: Add cookies support for uprobe_multi link (jsc#PED-6811).
- bpf: Add multi uprobe link (jsc#PED-6811).
- bpf: Add attach_type checks under
  bpf_prog_attach_check_attach_type (jsc#PED-6811).
- bpf: Switch BPF_F_KPROBE_MULTI_RETURN macro to enum
  (jsc#PED-6811).
- samples/bpf: simplify spintest with kprobe.multi (jsc#PED-6811).
- samples/bpf: refactor syscall tracing programs using
  BPF_KSYSCALL macro (jsc#PED-6811).
- samples/bpf: fix broken map lookup probe (jsc#PED-6811).
- samples/bpf: fix bio latency check with tracepoint
  (jsc#PED-6811).
- samples/bpf: make tracing programs to be more CO-RE centric
  (jsc#PED-6811).
- samples/bpf: fix symbol mismatch by compiler optimization
  (jsc#PED-6811).
- samples/bpf: unify bpf program suffix to .bpf with tracing
  programs (jsc#PED-6811).
- samples/bpf: convert to vmlinux.h with tracing programs
  (jsc#PED-6811).
- samples/bpf: fix warning with ignored-attributes (jsc#PED-6811).
- bpf, cpumask: Clean up bpf_cpu_map_entry directly in
  cpu_map_free (jsc#PED-6811).
- bpf, cpumap: Use queue_rcu_work() to remove unnecessary
  rcu_barrier() (jsc#PED-6811).
- selftests/bpf: Fix a selftest compilation error (jsc#PED-6811).
- selftests/bpf: Add CO-RE relocs kfunc flavors tests
  (jsc#PED-6811).
- libbpf: Support triple-underscore flavors for kfunc relocation
  (jsc#PED-6811).
- bpf/tests: Enhance output on error and fix typos (jsc#PED-6811).
- selftests/bpf: Add lwt_xmit tests for BPF_REROUTE
  (jsc#PED-6811).
- selftests/bpf: Add lwt_xmit tests for BPF_REDIRECT
  (jsc#PED-6811).
- lwt: Check LWTUNNEL_XMIT_CONTINUE strictly (jsc#PED-6811).
- lwt: Fix return values of BPF xmit ops (jsc#PED-6811).
- selftests/bpf: Enable cpu v4 tests for arm64 (jsc#PED-6811).
- bpf, arm64: Support signed div/mod instructions (jsc#PED-6811).
- bpf, arm64: Support 32-bit offset jmp instruction
  (jsc#PED-6811).
- bpf, arm64: Support unconditional bswap (jsc#PED-6811).
- bpf, arm64: Support sign-extension mov instructions
  (jsc#PED-6811).
- bpf, arm64: Support sign-extension load instructions
  (jsc#PED-6811).
- arm64: insn: Add encoders for LDRSB/LDRSH/LDRSW (jsc#PED-6811).
- selftests/bpf: Add mptcpify test (jsc#PED-6811).
- selftests/bpf: Fix error checks of mptcp open_and_load
  (jsc#PED-6811).
- selftests/bpf: Add two mptcp netns helpers (jsc#PED-6811).
- bpf: Add update_socket_protocol hook (jsc#PED-6811).
- bpftool: Implement link show support for xdp (jsc#PED-6811).
- bpftool: Implement link show support for tcx (jsc#PED-6811).
- selftests/bpf: Add selftest for fill_link_info (jsc#PED-6811).
- bpf: Fix uninitialized symbol in bpf_perf_link_fill_kprobe()
  (jsc#PED-6811).
- bpf: Document struct bpf_struct_ops fields (jsc#PED-6811).
- bpf: Support default .validate() and .update() behavior for
  struct_ops links (jsc#PED-6811).
- selftests/bpf: Add various more tcx test cases (jsc#PED-6811).
- bpftool: fix perf help message (jsc#PED-6811).
- bpf: Remove unused declaration bpf_link_new_file()
  (jsc#PED-6811).
- bpf: btf: Remove two unused function declarations
  (jsc#PED-6811).
- bpf: lru: Remove unused declaration bpf_lru_promote()
  (jsc#PED-6811).
- selftests/bpf: relax expected log messages to allow emitting
  BPF_ST (jsc#PED-6811).
- selftests/bpf: remove duplicated functions (jsc#PED-6811).
- selftests/bpf: fix the incorrect verification of port numbers
  (jsc#PED-6811).
- commit 3e6c5b4
* Thu Jan 18 2024 tiwai@suse.de
- uio: Fix use-after-free in uio_open (git-fixes).
- scripts/tags.sh: Update comment (addition of gtags) (git-fixes).
- iio: adc: ad7091r: Pass iio_dev to event handler (git-fixes).
- iio: adc: ad9467: fix scale setting (git-fixes).
- iio: adc: ad9467: add mutex to struct ad9467_state (git-fixes).
- iio: adc: ad9467: don't ignore error codes (git-fixes).
- iio: adc: ad9467: fix reset gpio handling (git-fixes).
- bus: mhi: host: Drop chan lock before queuing buffers
  (git-fixes).
- bus: mhi: host: Add spinlock to protect WP access when queueing
  TREs (git-fixes).
- bus: mhi: host: Add alignment check for event ring read pointer
  (git-fixes).
- bus: mhi: ep: Do not allocate event ring element on stack
  (git-fixes).
- PCI: mediatek-gen3: Fix translation window size calculation
  (git-fixes).
- PCI: mediatek: Clear interrupt status before dispatching handler
  (git-fixes).
- PCI: keystone: Fix race condition when initializing PHYs
  (git-fixes).
- PCI: dwc: endpoint: Fix dw_pcie_ep_raise_msix_irq() alignment
  support (git-fixes).
- PCI: Add ACS quirk for more Zhaoxin Root Ports (git-fixes).
- PCI: Avoid potential out-of-bounds read in
  pci_dev_for_each_resource() (git-fixes).
- PCI/P2PDMA: Remove reference to pci_p2pdma_map_sg() (git-fixes).
- pinctrl: intel: Revert "Unexport intel_pinctrl_probe()"
  (git-fixes).
- leds: ledtrig-tty: Free allocated ttyname buffer on deactivate
  (git-fixes).
- leds: aw2013: Select missing dependency REGMAP_I2C (git-fixes).
- mfd: intel-lpss: Fix the fractional clock divider flags
  (git-fixes).
- mfd: syscon: Fix null pointer dereference in
  of_syscon_register() (git-fixes).
- mfd: intel-lpss: Revert "Add missing check for
  platform_get_resource" (git-fixes).
- hwspinlock: qcom: Remove IPQ6018 SOC specific compatible
  (git-fixes).
- ARM: 9330/1: davinci: also select PINCTRL (git-fixes).
- commit e00102e
* Thu Jan 18 2024 tiwai@suse.de
- rpm/kernel-source.changes.old: update to mention the old entries in kernel-docs
- commit 6b4d1f8
* Thu Jan 18 2024 shung-hsi.yu@suse.com
- bpf, docs: Fix small typo and define semantics of sign extension
  (jsc#PED-6811).
- selftests/bpf: Add bpf_get_func_ip test for uprobe inside
  function (jsc#PED-6811).
- selftests/bpf: Add bpf_get_func_ip tests for uprobe on function
  entry (jsc#PED-6811).
- bpf: Add support for bpf_get_func_ip helper for uprobe program
  (jsc#PED-6811).
- selftests/bpf: Add a movsx selftest for sign-extension of R10
  (jsc#PED-6811).
- bpf: Fix an incorrect verification success with movsx insn
  (jsc#PED-6811).
- bpf, docs: Formalize type notation and function semantics in
  ISA standard (jsc#PED-6811).
- bpf: change bpf_alu_sign_string and bpf_movsx_string to static
  (jsc#PED-6811).
- libbpf: Use local includes inside the library (jsc#PED-6811).
- bpf: fix bpf_dynptr_slice() to stop return an ERR_PTR
  (jsc#PED-6811).
- bpf: fix inconsistent return types of bpf_xdp_copy_buf()
  (jsc#PED-6811).
- selftests/bpf: Add test for detachment on empty mprog entry
  (jsc#PED-6811).
- bpf: Fix mprog detachment for empty mprog entry (jsc#PED-6811).
- bpf: bpf_struct_ops: Remove unnecessary initial values of
  variables (jsc#PED-6811).
- selftests/bpf: Add testcase for xdp attaching failure tracepoint
  (jsc#PED-6811).
- bpf, xdp: Add tracepoint to xdp attaching failure
  (jsc#PED-6811).
- bpf: fix bpf_probe_read_kernel prototype mismatch
  (jsc#PED-6811).
- riscv, bpf: Adapt bpf trampoline to optimized riscv ftrace
  framework (jsc#PED-6811).
- libbpf: fix typos in Makefile (jsc#PED-6811).
- tracing: bpf: use struct trace_entry in struct syscall_tp_t
  (jsc#PED-6811).
- bpf, devmap: Remove unused dtab field from bpf_dtab_netdev
  (jsc#PED-6811).
- bpf, cpumap: Remove unused cmap field from bpf_cpu_map_entry
  (jsc#PED-6811).
- netfilter: bpf: Only define get_proto_defrag_hook() if necessary
  (jsc#PED-6811).
- bpf: Fix an array-index-out-of-bounds issue in disasm.c
  (jsc#PED-6811).
- docs/bpf: Fix malformed documentation (jsc#PED-6811).
- bpf: selftests: Add defrag selftests (jsc#PED-6811).
- bpf: selftests: Support custom type and proto for client sockets
  (jsc#PED-6811).
- bpf: selftests: Support not connecting client socket
  (jsc#PED-6811).
- netfilter: bpf: Support BPF_F_NETFILTER_IP_DEFRAG in netfilter
  link (jsc#PED-6811).
- netfilter: defrag: Add glue hooks for enabling/disabling defrag
  (jsc#PED-6811).
- docs/bpf: Improve documentation for cpu=v4 instructions
  (jsc#PED-6811).
- bpf: Non-atomically allocate freelist during prefill
  (jsc#PED-6811).
- selftests/bpf: Enable test test_progs-cpuv4 for gcc build kernel
  (jsc#PED-6811).
- bpf: Fix compilation warning with -Wparentheses (jsc#PED-6811).
- docs/bpf: Add documentation for new instructions (jsc#PED-6811).
- selftests/bpf: Test ldsx with more complex cases (jsc#PED-6811).
- selftests/bpf: Add unit tests for new gotol insn (jsc#PED-6811).
- selftests/bpf: Add unit tests for new sdiv/smod insns
  (jsc#PED-6811).
- selftests/bpf: Add unit tests for new bswap insns
  (jsc#PED-6811).
- selftests/bpf: Add unit tests for new sign-extension mov insns
  (jsc#PED-6811).
- selftests/bpf: Add unit tests for new sign-extension load insns
  (jsc#PED-6811).
- selftests/bpf: Add a cpuv4 test runner for cpu=v4 testing
  (jsc#PED-6811).
- selftests/bpf: Fix a test_verifier failure (jsc#PED-6811).
- bpf: Add kernel/bpftool asm support for new instructions
  (jsc#PED-6811).
- bpf: Support new 32bit offset jmp instruction (jsc#PED-6811).
- bpf: Fix jit blinding with new sdiv/smov insns (jsc#PED-6811).
- bpf: Support new signed div/mod instructions (jsc#PED-6811).
- bpf: Support new unconditional bswap instruction (jsc#PED-6811).
- bpf: Handle sign-extenstin ctx member accesses (jsc#PED-6811).
- bpf: Support new sign-extension mov insns (jsc#PED-6811).
- bpf: Support new sign-extension load insns (jsc#PED-6811).
- bpf, docs: fix BPF_NEG entry in instruction-set.rst
  (jsc#PED-6811).
- bpf: work around -Wuninitialized warning (jsc#PED-6811).
- selftests/bpf: Test that SO_REUSEPORT can be used with sk_assign
  helper (jsc#PED-6811).
- bpf, net: Support SO_REUSEPORT sockets with bpf_sk_assign
  (jsc#PED-6811).
- net: remove duplicate sk_lookup helpers (jsc#PED-6811).
- net: document inet_lookup_reuseport sk_state requirements
  (jsc#PED-6811).
- net: remove duplicate reuseport_lookup functions (jsc#PED-6811).
- net: export inet_lookup_reuseport and inet6_lookup_reuseport
  (jsc#PED-6811).
- bpf: reject unhashed sockets in bpf_sk_assign (jsc#PED-6811).
- udp: re-score reuseport groups when connected sockets are
  present (jsc#PED-6811).
- udp: Remove unused function declaration udp_bpf_get_proto()
  (jsc#PED-6811).
- bpf, net: Introduce skb_pointer_if_linear() (jsc#PED-6811).
- bpf: sync tools/ uapi header with (jsc#PED-6811).
- selftests/bpf: Add mprog API tests for BPF tcx links
  (jsc#PED-6811).
- selftests/bpf: Add mprog API tests for BPF tcx opts
  (jsc#PED-6811).
- bpftool: Extend net dump with tcx progs (jsc#PED-6811).
- libbpf: Add helper macro to clear opts structs (jsc#PED-6811).
- libbpf: Add link-based API for tcx (jsc#PED-6811).
- libbpf: Add opts-based attach/detach/query API for tcx
  (jsc#PED-6811).
- bpf: Add generic attach/detach/query API for multi-progs
  (jsc#PED-6811).
- bpf, x86: initialize the variable "first_off" in save_args()
  (jsc#PED-6811).
- bpf: allow any program to use the bpf_map_sum_elem_count kfunc
  (jsc#PED-6811).
- bpf: make an argument const in the bpf_map_sum_elem_count kfunc
  (jsc#PED-6811).
- bpf: consider CONST_PTR_TO_MAP as trusted pointer to struct
  bpf_map (jsc#PED-6811).
- bpf: consider types listed in reg2btf_ids as trusted
  (jsc#PED-6811).
- bpf: Drop useless btf_vmlinux in bpf_tcp_ca (jsc#PED-6811).
- samples/bpf: README: Update build dependencies required
  (jsc#PED-6811).
- selftests/bpf: Disable newly-added 'owner' field test until
  refcount re-enabled (jsc#PED-6811).
- selftests/bpf: Add rbtree test exercising race which 'owner'
  field prevents (jsc#PED-6811).
- bpf: Add 'owner' field to bpf_{list,rb}_node (jsc#PED-6811).
- bpf: Introduce internal definitions for UAPI-opaque
  bpf_{rb,list}_node (jsc#PED-6811).
- selftests/bpf: Add selftest for PTR_UNTRUSTED (jsc#PED-6811).
- bpf: Fix an error in verifying a field in a union
  (jsc#PED-6811).
- selftests/bpf: Add selftests for nested_trust (jsc#PED-6811).
- bpf: Fix an error around PTR_UNTRUSTED (jsc#PED-6811).
- selftests/bpf: add testcase for TRACING with 6+ arguments
  (jsc#PED-6811).
- bpf, x86: allow function arguments up to 12 for TRACING
  (jsc#PED-6811).
- bpf, x86: save/restore regs with BPF_DW size (jsc#PED-6811).
- bpftool: Use "fallthrough;" keyword instead of comments
  (jsc#PED-6811).
- bpf: Add object leak check (jsc#PED-6811).
- bpf: Convert bpf_cpumask to bpf_mem_cache_free_rcu
  (jsc#PED-6811).
- bpf: Introduce bpf_mem_free_rcu() similar to kfree_rcu()
  (jsc#PED-6811).
- selftests/bpf: Improve test coverage of bpf_mem_alloc
  (jsc#PED-6811).
- rcu: Export rcu_request_urgent_qs_task() (jsc#PED-6811).
- bpf: Allow reuse from waiting_for_gp_ttrace list (jsc#PED-6811).
- bpf: Add a hint to allocated objects (jsc#PED-6811).
- bpf: Change bpf_mem_cache draining process (jsc#PED-6811).
- bpf: Further refactor alloc_bulk() (jsc#PED-6811).
- bpf: Factor out inc/dec of active flag into helpers
  (jsc#PED-6811).
- bpf: Refactor alloc_bulk() (jsc#PED-6811).
- bpf: Let free_all() return the number of freed elements
  (jsc#PED-6811).
- bpf: Simplify code of destroy_mem_alloc() with kmemdup()
  (jsc#PED-6811).
- bpf: Rename few bpf_mem_alloc fields (jsc#PED-6811).
- selftests/bpf: extend existing map resize tests for per-cpu
  use case (jsc#PED-6811).
- bpf: teach verifier actual bounds of bpf_get_smp_processor_id()
  result (jsc#PED-6811).
- bpftool: Show perf link info (jsc#PED-6811).
- bpftool: Add perf event names (jsc#PED-6811).
- bpf: Support ->fill_link_info for perf_event (jsc#PED-6811).
- bpf: Add a common helper bpf_copy_to_user() (jsc#PED-6811).
- bpf: Expose symbol's respective address (jsc#PED-6811).
- bpf: Protect probed address based on kptr_restrict setting
  (jsc#PED-6811).
- bpftool: Show kprobe_multi link info (jsc#PED-6811).
- bpftool: Dump the kernel symbol's module name (jsc#PED-6811).
- bpf: Support ->fill_link_info for kprobe_multi (jsc#PED-6811).
- samples/bpf: syscall_tp: Aarch64 no open syscall (jsc#PED-6811).
- libbpf: Remove HASHMAP_INIT static initialization helper
  (jsc#PED-6811).
- libbpf: Fix realloc API handling in zero-sized edge cases
  (jsc#PED-6811).
- bpf,docs: Create new standardization subdirectory
  (jsc#PED-6811).
- bpftool: Use a local bpf_perf_event_value to fix accessing
  its fields (jsc#PED-6811).
- bpftool: Use a local copy of BPF_LINK_TYPE_PERF_EVENT in
  pid_iter.bpf.c (jsc#PED-6811).
- bpftool: Define a local bpf_perf_link to fix accessing its
  fields (jsc#PED-6811).
- bpftool: use a local copy of perf_event to fix accessing ::
  Bpf_cookie (jsc#PED-6811).
- libbpf: only reset sec_def handler when necessary
  (jsc#PED-6811).
- selftests/bpf: Correct two typos (jsc#PED-6811).
- libbpf: Use available_filter_functions_addrs with multi-kprobes
  (jsc#PED-6811).
- libbpf: Cross-join available_filter_functions and kallsyms
  for multi-kprobes (jsc#PED-6811).
- selftests/bpf: Bump and validate MAX_SYMS (jsc#PED-6811).
- selftests/bpf: test map percpu stats (jsc#PED-6811).
- bpf: make preloaded map iterators to display map elements count
  (jsc#PED-6811).
- bpf: populate the per-cpu insertions/deletions counters for
  hashmaps (jsc#PED-6811).
- bpf: add a new kfunc to return current bpf_map elements count
  (jsc#PED-6811).
- bpf: add percpu stats for bpf_map elements insertions/deletions
  (jsc#PED-6811).
- Refresh patches.suse/kABI-padding-for-bpf.patch
- selftests/bpf: Add benchmark for bpf memory allocator
  (jsc#PED-6811).
- selftests/bpf: Honor $(O) when figuring out paths
  (jsc#PED-6811).
- selftests/bpf: Add F_NEEDS_EFFICIENT_UNALIGNED_ACCESS to some
  tests (jsc#PED-6811).
- bpf: Remove unnecessary ring buffer size check (jsc#PED-6811).
- selftests/bpf: Add bpf_program__attach_netfilter helper test
  (jsc#PED-6811).
- libbpf: Add netfilter link attach helper (jsc#PED-6811).
- libbpf: Skip modules BTF loading when CAP_SYS_ADMIN is missing
  (jsc#PED-6811).
- selftests/bpf: Verify that the cgroup_skb filters receive
  expected packets (jsc#PED-6811).
- bpf, net: Check skb ownership against full socket
  (jsc#PED-6811).
- selftests/bpf: Add test to exercise typedef walking
  (jsc#PED-6811).
- bpf: Resolve modifiers when walking structs (jsc#PED-6811).
- bpf, docs: Fix definition of BPF_NEG operation (jsc#PED-6811).
- bpf: Replace deprecated -target with --target= for Clang
  (jsc#PED-6811).
- lib/test_bpf: Call page_address() on page acquired with
  GFP_KERNEL flag (jsc#PED-6811).
- hw_breakpoint: fix single-stepping when using
  bpf_overflow_handler (jsc#PED-6811).
- bpf: convert to ctime accessor functions (jsc#PED-6811).
- commit 886f447
* Wed Jan 17 2024 tonyj@suse.de
- perf/x86/intel/cstate: Add Sierra Forest support (bsc#1218855).
- x86/smp: Export symbol cpu_clustergroup_mask() (bsc#1218855).
- perf/x86/intel/cstate: Cleanup duplicate attr_groups
  (bsc#1218855).
- powerpc/hv-gpci: Add return value check in
  affinity_domain_via_partition_show function (bsc#1218893).
- commit 7a674ac
* Wed Jan 17 2024 ematsumiya@suse.de
- smb: client: fix OOB in receive_encrypted_standard()
  (bsc#1218832 CVE-2024-0565).
- commit 01f51de
* Wed Jan 17 2024 lduncan@suse.com
- scsi: libsas: Simplify sas_queue_reset() and remove unused code
  (bsc#1216435).
- commit 2ed80e9
* Wed Jan 17 2024 ykaukab@suse.de
- config: s390x: Use upstream default CONFIG_HZ in zfcpdump
  References: jsc#PED-7600
  Update CONFIG_HZ in s390 zfcpdump config to match upstream zfcpdump_defconfig
- commit 2429ee3
* Wed Jan 17 2024 ailiop@suse.com
- xfs: fix reloading entire unlinked bucket lists (bsc#1218829).
- commit 657b3be
* Wed Jan 17 2024 ailiop@suse.com
- dlm: fix format seq ops type 4 (git-fixes).
- commit 63ceeef
* Wed Jan 17 2024 ailiop@suse.com
- fs: dlm: Fix the size of a buffer in dlm_create_debug_file()
  (git-fixes).
- commit 0ca2a21
* Wed Jan 17 2024 ailiop@suse.com
- gfs2: Silence "suspicious RCU usage in gfs2_permission" warning
  (git-fixes).
- commit b0d3c38
* Wed Jan 17 2024 hare@suse.de
- io_uring: use kiocb_{start,end}_write() helpers (bsc#1216436).
- commit 6a1a1c1
* Wed Jan 17 2024 hare@suse.de
- blk-wbt: remove the separate write cache tracking (bsc#1216436).
- block: reject invalid operation in submit_bio_noacct
  (bsc#1216436).
- block: renumber QUEUE_FLAG_HW_WC (bsc#1216436).
- block/null_blk: Fix double blk_mq_start_request() warning
  (bsc#1216436).
- io_uring/rw: disable IOCB_DIO_CALLER_COMP (bsc#1216436).
- commit b90cfd8
* Wed Jan 17 2024 hare@suse.de
- cachefiles: use kiocb_{start,end}_write() helpers (bsc#1216436).
- ovl: use kiocb_{start,end}_write() helpers (bsc#1216436).
- aio: use kiocb_{start,end}_write() helpers (bsc#1216436).
- commit 8f90684
* Wed Jan 17 2024 hare@suse.de
- fs: create kiocb_{start,end}_write() helpers (bsc#1216436).
- fs: add kerneldoc to file_{start,end}_write() helpers
  (bsc#1216436).
- commit 7d3b5d1
* Wed Jan 17 2024 nmorey@suse.com
- IB/iser: Prevent invalidating wrong MR (git-fixes)
- commit 434f8f8
* Wed Jan 17 2024 nmorey@suse.com
- RDMA/hns: Fix memory leak in free_mr_init() (git-fixes)
- commit 20aa9db
* Wed Jan 17 2024 nmorey@suse.com
- RDMA/hns: Remove unnecessary checks for NULL in mtr_alloc_bufs() (git-fixes)
- commit ec404c2
* Wed Jan 17 2024 nmorey@suse.com
- RDMA/hns: Fix inappropriate err code for unsupported operations (git-fixes)
- commit d195558
* Wed Jan 17 2024 nmorey@suse.com
- RDMA/usnic: Silence uninitialized symbol smatch warnings (git-fixes)
- commit 238dd09
* Wed Jan 17 2024 hare@suse.de
- direct_write_fallback(): on error revert the ->ki_pos update
  (bsc#1216436).
- iomap: handle error conditions more gracefully in iomap_to_bh
  (bsc#1216436).
- commit 4b812b9
* Wed Jan 17 2024 hare@suse.de
- buffer: convert block_truncate_page() to use a folio
  (bsc#1216436).
- buffer: use a folio in __find_get_block_slow() (bsc#1216436).
- buffer: convert link_dev_buffers to take a folio (bsc#1216436).
- buffer: convert init_page_buffers() to folio_init_buffers()
  (bsc#1216436).
- buffer: convert grow_dev_page() to use a folio (bsc#1216436).
- buffer: convert page_zero_new_buffers() to
  folio_zero_new_buffers() (bsc#1216436).
- buffer: convert __block_commit_write() to take a folio
  (bsc#1216436).
- buffer: convert block_page_mkwrite() to use a folio
  (bsc#1216436).
- buffer: make block_write_full_page() handle large folios
  (bsc#1216436).
- gfs2: support ludicrously large folios in
  gfs2_trans_add_databufs() (bsc#1216436).
- buffer: convert __block_write_full_page() to
  __block_write_full_folio() (bsc#1216436).
- gfs2: convert gfs2_write_jdata_page() to
  gfs2_write_jdate_folio() (bsc#1216436).
- gfs2: pass a folio to __gfs2_jdata_write_folio() (bsc#1216436).
- gfs2: use a folio inside gfs2_jdata_writepage() (bsc#1216436).
- commit 203df10
* Wed Jan 17 2024 hare@suse.de
- driver core: return an error when dev_set_name() hasn't happened
  (bsc#1216436).
- commit e74385c
* Wed Jan 17 2024 hare@suse.de
- iomap: micro optimize the ki_pos assignment in
  iomap_file_buffered_write (bsc#1216436).
- iomap: fix a regression for partial write errors (bsc#1216436).
- commit 5452bfb
* Wed Jan 17 2024 vkarasulli@suse.de
- ida: Fix crash in ida_free when the bitmap is empty (bsc#1218804
  CVE-2023-6915).
- commit 8fc965e
* Wed Jan 17 2024 lduncan@suse.com
- scsi: libsas: Delete sas_ssp_task.retry_count (bsc#1216435).
- Refresh
  patches.suse/scsi-libsas-Delete-sas_ssp_task.enable_first_burst.patch.
- Refresh
  patches.suse/scsi-libsas-Delete-sas_ssp_task.task_prio.patch.
- commit e634ae4
* Wed Jan 17 2024 lduncan@suse.com
- scsi: libsas: Remove unused declarations (bsc#1216435).
- Refresh patches.suse/scsi-libsas-Delete-enum-sas_class.patch.
- commit eb80cd9
* Tue Jan 16 2024 lduncan@suse.com
- scsi: hisi_sas: Fix warning detected by sparse (bsc#1216435).
- scsi: hisi_sas: Delete unused lock in
  hisi_sas_port_notify_formed() (bsc#1216435).
- scsi: hisi_sas: Block requests before a debugfs snapshot
  (bsc#1216435).
- scsi: hisi_sas: Convert to platform remove callback returning
  void (bsc#1216435).
- scsi: hisi_sas: Change DMA setup lock timeout to 2.5s
  (bsc#1216435).
- scsi: hisi_sas: Configure initial value of some registers
  according to HBA model (bsc#1216435).
- scsi: libsas: factor out sas_check_fanout_expander_topo()
  (bsc#1216435).
- scsi: libsas: Remove an empty branch in
  sas_check_parent_topology() (bsc#1216435).
- scsi: libsas: Simplify sas_check_eeds() (bsc#1216435).
- commit 0820552
* Tue Jan 16 2024 mkoutny@suse.com
- blk-cgroup: fix rcu lockdep warning in blkg_lookup()
  (bsc#1218870).
- blk-cgroup: avoid to warn !rcu_read_lock_held() in blkg_lookup()
  (bsc#1218870).
- commit dff344a
* Tue Jan 16 2024 mkoutny@suse.com
- mm: memcg: normalize the value passed into memcg_rstat_updated()
  (bsc#1218869).
- commit e19dd2b
* Tue Jan 16 2024 mkoutny@suse.com
- sched: psi: fix unprivileged polling against cgroups
  (bsc#1212887).
- commit 924611d
* Tue Jan 16 2024 vkarasulli@suse.de
- Update references to patch
  patches.suse/accel-habanalabs-fix-information-leak-in-sec_attest_.patch
  (git-fixes bsc#1217930 CVE-2023-50431).
- commit 866277b
* Tue Jan 16 2024 mkoutny@suse.com
- mm: kmem: drop __GFP_NOFAIL when allocating objcg vectors
  (bsc#1218515).
- commit 8d4a19d
* Tue Jan 16 2024 ykaukab@suse.de
- config: Use upstream default CONFIG_HZ
  References: jsc#PED-7600
  Update CONFIG_HZ for arm and arm64 to match upstream default values.
  All architectures now use upstream default CONFIG_HZ value except
  x86_64. The value for x86_64 is not changed as it was considered to be
  an unnecessary risk without any clear gains.
- commit fef3240
* Tue Jan 16 2024 tiwai@suse.de
- wifi: rtlwifi: rtl8723{be,ae}: using calculate_bit_shift()
  (git-fixes).
- commit 0009fb7
* Tue Jan 16 2024 tiwai@suse.de
- wifi: rtlwifi: rtl8723_common: using calculate_bit_shift()
  (git-fixes).
- wifi: rtlwifi: rtl8192se: using calculate_bit_shift()
  (git-fixes).
- wifi: rtlwifi: rtl8192ee: using calculate_bit_shift()
  (git-fixes).
- wifi: rtlwifi: rtl8192de: using calculate_bit_shift()
  (git-fixes).
- wifi: rtlwifi: rtl8192ce: using calculate_bit_shift()
  (git-fixes).
- wifi: rtlwifi: rtl8192cu: using calculate_bit_shift()
  (git-fixes).
- wifi: rtlwifi: rtl8192c: using calculate_bit_shift()
  (git-fixes).
- wifi: rtlwifi: rtl8188ee: phy: using calculate_bit_shift()
  (git-fixes).
- wifi: rtlwifi: add calculate_bit_shift() (git-fixes).
- asm-generic: Fix 32 bit __generic_cmpxchg_local (git-fixes).
- asix: Add check for usbnet_get_endpoints (git-fixes).
- efi/x86: Fix the missing KASLR_FLAG bit in
  boot_params->hdr.loadflags (git-fixes).
- ethernet: atheros: fix a memleak in atl1e_setup_ring_resources
  (git-fixes).
- atm: Fix Use-After-Free in do_vcc_ioctl (git-fixes).
- atm: solos-pci: Fix potential deadlock on &tx_queue_lock
  (git-fixes).
- atm: solos-pci: Fix potential deadlock on &cli_queue_lock
  (git-fixes).
- lib/generic-radix-tree.c: Don't overflow in peek() (git-fixes).
- commit 99556cb
* Tue Jan 16 2024 ailiop@suse.com
- xfs: make inode unlinked bucket recovery work with quotacheck
  (bsc#1218829).
- commit 2168985
* Tue Jan 16 2024 ailiop@suse.com
- xfs: reload entire unlinked bucket lists (bsc#1218829).
- commit 4e6da6a
* Tue Jan 16 2024 ailiop@suse.com
- xfs: use i_prev_unlinked to distinguish inodes that are not
  on the unlinked list (bsc#1218829).
- commit 0c425d8
* Tue Jan 16 2024 ailiop@suse.com
- xfs: load uncached unlinked inodes into memory on demand
  (bsc#1218829).
- commit d642831
* Tue Jan 16 2024 ailiop@suse.com
- xfs: fix internal error from AGFL exhaustion (bsc#1218830).
- commit f1dd667
* Tue Jan 16 2024 ailiop@suse.com
- gfs2: don't withdraw if init_threads() got interrupted
  (git-fixes).
- commit 87324d2
* Tue Jan 16 2024 ailiop@suse.com
- gfs2: fix an oops in gfs2_permission (git-fixes).
- commit a65b3db
* Tue Jan 16 2024 ailiop@suse.com
- gfs2: ignore negated quota changes (git-fixes).
- commit 32058b1
* Tue Jan 16 2024 ailiop@suse.com
- gfs2: fix glock shrinker ref issues (git-fixes).
- commit 43753f2
* Tue Jan 16 2024 ailiop@suse.com
- jfs: fix array-index-out-of-bounds in diAlloc (git-fixes).
- commit 8bb1897
* Tue Jan 16 2024 ailiop@suse.com
- jfs: fix array-index-out-of-bounds in dbFindLeaf (git-fixes).
- commit 0452792
* Tue Jan 16 2024 ailiop@suse.com
- fs/jfs: Add validity check for db_maxag and db_agpref
  (git-fixes).
- commit e9fcd3d
* Tue Jan 16 2024 ailiop@suse.com
- fs/jfs: Add check for negative db_l2nbperpage (git-fixes).
- commit 46b8104
* Tue Jan 16 2024 ailiop@suse.com
- jfs: fix invalid free of JFS_IP(ipimap)->i_imap in diUnmount
  (git-fixes).
- commit e1dca98
* Tue Jan 16 2024 ailiop@suse.com
- fs/jfs: prevent double-free in dbUnmount() after failed
  jfs_remount() (git-fixes).
- commit 7bc674c
* Tue Jan 16 2024 ailiop@suse.com
- fs: dlm: Simplify buffer size computation in
  dlm_create_debug_file() (git-fixes).
- commit 893cdc2
* Tue Jan 16 2024 ailiop@suse.com
- fs: dlm: debugfs for queued callbacks (git-fixes).
- commit 1daca84
* Tue Jan 16 2024 hare@suse.de
- Update config files.
- commit 3f040eb
* Tue Jan 16 2024 hare@suse.de
- partitions/ibm: Introduce defines for magic string length values
  (bsc#1216436).
- partitions/ibm: Replace strncpy() and improve readability
  (bsc#1216436).
- partitions/ibm: Remove unnecessary memset (bsc#1216436).
- block/null_blk: add queue_rqs() support (bsc#1216436).
- blk-mq: update driver tags request table when start request
  (bsc#1216436).
- blk-mq: support batched queue_rqs() on shared tags queue
  (bsc#1216436).
- blk-mq: remove RQF_MQ_INFLIGHT (bsc#1216436).
- blk-mq: account active requests when get driver tag
  (bsc#1216436).
- blk-throttle: check for overflow in calculate_bytes_allowed
  (bsc#1216436).
- block: Fix regression in sed-opal for a saved key (bsc#1216436).
- block: Don't invalidate pagecache for invalid falloc modes
  (bsc#1216436).
- block: correct stale comment in rq_qos_wait (bsc#1216436).
- ovl: disable IOCB_DIO_CALLER_COMP (bsc#1216436).
- blk-mq: fix tags UAF when shrinking q->nr_hw_queues
  (bsc#1216436).
- block: fix pin count management when merging same-page segments
  (bsc#1216436).
- block: don't add or resize partition on the disk with
  GENHD_FL_NO_PART (bsc#1216436).
- block: remove the call to file_remove_privs in blkdev_write_iter
  (bsc#1216436).
- blk-throttle: consider 'carryover_ios/bytes' in
  throtl_trim_slice() (bsc#1216436).
- blk-throttle: use calculate_io/bytes_allowed() for
  throtl_trim_slice() (bsc#1216436).
- blk-throttle: fix wrong comparation while 'carryover_ios/bytes'
  is negative (bsc#1216436).
- blk-throttle: print signed value 'carryover_bytes/ios' for user
  (bsc#1216436).
- driver core: Call in reversed order in
  device_platform_notify_remove() (bsc#1216436).
- driver core: Return proper error code when dev_set_name()
  fails (bsc#1216436).
- block: use strscpy() to instead of strncpy() (bsc#1216436).
- blk-mq: prealloc tags when increase tagset nr_hw_queues
  (bsc#1216436).
- blk-mq: delete redundant tagset map update when fallback
  (bsc#1216436).
- blk-mq: fix tags leak when shrink nr_hw_queues (bsc#1216436).
- block: Bring back zero_fill_bio_iter (bsc#1216436).
- block: Allow bio_iov_iter_get_pages() with bio->bi_bdev unset
  (bsc#1216436).
- block: Add some exports for bcachefs (bsc#1216436).
- commit 4e8aeac
* Tue Jan 16 2024 hare@suse.de
- scsi: core: Support setting BLK_MQ_F_BLOCKING (bsc#1216436).
- Delete
  patches.suse/drivers-base-implement-dev_enable_async_probe.patch.
- Delete
  patches.suse/scsi-add-disable_async_probing-module-argument.patch.
- commit c65ed74
* Tue Jan 16 2024 hare@suse.de
- scsi: core: Rework scsi_host_block() (bsc#1216436).
- commit dc547b7
* Tue Jan 16 2024 hare@suse.de
- block: fix bad lockdep annotation in blk-iolatency
  (bsc#1216436).
- swim3: mark swim3_init() static (bsc#1216436).
- block: remove init_mutex and open-code blk_iolatency_try_init
  (bsc#1216436).
- bio-integrity: create multi-page bvecs in
  bio_integrity_add_page() (bsc#1216436).
- bio-integrity: cleanup adding integrity pages to bip's bvec
  (bsc#1216436).
- bio-integrity: update the payload size in
  bio_integrity_add_page() (bsc#1216436).
- block: make bvec_try_merge_hw_page() non-static (bsc#1216436).
- iocost_monitor: improve it by adding iocg wait_ms (bsc#1216436).
- iocost_monitor: print vrate inuse along with base_vrate
  (bsc#1216436).
- iocost_monitor: fix kernel queue kobj changes (bsc#1216436).
- fs/Kconfig: Fix compile error for romfs (bsc#1216436).
- fs: add CONFIG_BUFFER_HEAD (bsc#1216436).
- ext2: Move direct-io to use iomap (bsc#1216436).
- ext4: Use generic_buffers_fsync_noflush() implementation
  (bsc#1216436).
- fs/buffer.c: Add generic_buffers_fsync*() implementation
  (bsc#1216436).
- commit 0ae71f3
* Tue Jan 16 2024 hare@suse.de
- block: use iomap for writes to block devices (bsc#1216436).
- block: stop setting ->direct_IO (bsc#1216436).
- commit ac1d801
* Tue Jan 16 2024 hare@suse.de
- block: open code __generic_file_write_iter for blkdev writes
  (bsc#1216436).
- fs: rename and move block_page_mkwrite_return (bsc#1216436).
- fs: remove emergency_thaw_bdev (bsc#1216436).
- commit 3d051af
* Tue Jan 16 2024 hare@suse.de
- iomap: support IOCB_DIO_CALLER_COMP (bsc#1216436).
- io_uring/rw: add write support for IOCB_DIO_CALLER_COMP
  (bsc#1216436).
- fs: add IOCB flags related to passing back dio completions
  (bsc#1216436).
- iomap: add IOMAP_DIO_INLINE_COMP (bsc#1216436).
- iomap: only set iocb->private for polled bio (bsc#1216436).
- iomap: treat a write through cache the same as FUA
  (bsc#1216436).
- commit c35c5e8
* Tue Jan 16 2024 hare@suse.de
- fuse: use direct_write_fallback (bsc#1216436).
- fuse: drop redundant arguments to fuse_perform_write
  (bsc#1216436).
- fuse: update ki_pos in fuse_perform_write (bsc#1216436).
- fs: factor out a direct_write_fallback helper (bsc#1216436).
- iomap: use kiocb_write_and_wait and kiocb_invalidate_pages
  (bsc#1216436).
- iomap: update ki_pos in iomap_file_buffered_write (bsc#1216436).
- filemap: add a kiocb_invalidate_post_direct_write helper
  (bsc#1216436).
- filemap: add a kiocb_invalidate_pages helper (bsc#1216436).
- filemap: add a kiocb_write_and_wait helper (bsc#1216436).
- filemap: update ki_pos in generic_perform_write (bsc#1216436).
- iomap: update ki_pos a little later in iomap_dio_complete
  (bsc#1216436).
- backing_dev: remove current->backing_dev_info (bsc#1216436).
- commit e9c583e
* Tue Jan 16 2024 hare@suse.de
- iomap: use an unsigned type for IOMAP_DIO_* defines
  (bsc#1216436).
- iomap: cleanup up iomap_dio_bio_end_io() (bsc#1216436).
- commit f5b487e
* Tue Jan 16 2024 hare@suse.de
- blk-iocost: fix queue stats accounting (bsc#1216436).
- block: don't make REQ_POLLED imply REQ_NOWAIT (bsc#1216436).
- block: get rid of unused plug->nowait flag (bsc#1216436).
- commit 8bbf8a3
* Tue Jan 16 2024 hare@suse.de
- block: cleanup bio_integrity_prep (bsc#1216436).
- block: Improve performance for BLK_MQ_F_BLOCKING drivers
  (bsc#1216436).
- scsi: Remove a blk_mq_run_hw_queues() call (bsc#1216436).
- scsi: core: Only kick the requeue list if necessary
  (bsc#1216436).
- commit ac14f2c
* Tue Jan 16 2024 hare@suse.de
- scsi: Inline scsi_kick_queue() (bsc#1216436).
- commit b8b609b
* Tue Jan 16 2024 hare@suse.de
- block: don't pass a bio to bio_try_merge_hw_seg (bsc#1216436).
- block: move the bi_size update out of __bio_try_merge_page
  (bsc#1216436).
- block: downgrade a bio_full call in bio_add_page (bsc#1216436).
- block: move the bi_size overflow check in (bsc#1216436).
- block: move the bi_vcnt check out of __bio_try_merge_page
  (bsc#1216436).
- block: move the BIO_CLONED checks out of __bio_try_merge_page
  (bsc#1216436).
- block: use SECTOR_SHIFT bio_add_hw_page (bsc#1216436).
- block: tidy up the bio full checks in bio_add_hw_page
  (bsc#1216436).
- block: refactor to use helper (bsc#1216436).
- blk-flush: reuse rq queuelist in flush state machine
  (bsc#1216436).
- blk-flush: count inflight flush_data requests (bsc#1216436).
- blk-mq: use percpu csd to remote complete instead of per-rq csd
  (bsc#1216436).
- block: don't allow enabling a cache on devices that don't
  support it (bsc#1216436).
- block: cleanup queue_wc_store (bsc#1216436).
- commit 6ac1e2a
* Tue Jan 16 2024 hare@suse.de
- blk-iocost: skip empty flush bio in iocost (bsc#1216436).
- blk-mq: delete dead struct blk_mq_hw_ctx->queued field
  (bsc#1216436).
- commit 4b9b327
* Tue Jan 16 2024 hare@suse.de
- blk-mq: fix start_time_ns and alloc_time_ns for pre-allocated rq
  (bsc#1216436).
- block: remove dead struc request->completion_data field
  (bsc#1216436).
- commit 3fc36a5
* Tue Jan 16 2024 hare@suse.de
- nvme: improved uring polling (bsc#1216436).
- Refresh
  patches.suse/io_uring-retain-top-8bits-of-uring_cmd-flags-for-ker.patch.
- Refresh
  patches.suse/nvme-core-don-t-hold-rcu-read-lock-in-nvme_ns_chr_ur.patch.
- commit 46103bf
* Tue Jan 16 2024 hare@suse.de
- block: add request polling helper (bsc#1216436).
- commit 21a3178
* Tue Jan 16 2024 hare@suse.de
- blk-sysfs: add a new attr_group for blk_mq (bsc#1218785).
- blk-iocost: move wbt_enable/disable_default() out of spinlock
  (bsc#1218785).
- blk-wbt: cleanup rwb_enabled() and wbt_disabled() (bsc#1218785).
- blk-wbt: remove dead code to handle wbt enable/disable with
  io inflight (bsc#1218785).
- blk-wbt: don't create wbt sysfs entry if CONFIG_BLK_WBT is
  disabled (bsc#1218785).
- commit 0b53563
* Tue Jan 16 2024 hare@suse.de
- bsg: make bsg_class a static const structure (bsc#1218785).
- Refresh patches.suse/scsi-bsg-Increase-number-of-devices.patch.
- commit 26819b8
* Tue Jan 16 2024 hare@suse.de
- block: add capacity validation in bdev_add_partition()
  (bsc#1218785).
- block: fine-granular CAP_SYS_ADMIN for Persistent Reservation
  (bsc#1218785).
- block: disallow Persistent Reservation on partitions
  (bsc#1218785).
- block: document the holder argument to blkdev_get_by_path
  (bsc#1218785).
- commit b5047c7
* Tue Jan 16 2024 krisman@suse.de
- x86: bring back rep movsq for user access on CPUs without ERMS
  (bsc#1217756).
- commit 0e4b75f
* Mon Jan 15 2024 hare@suse.de
- swim: fix a missing FMODE_ -> BLK_OPEN_ conversion in floppy_open
  (bsc#1218785).
- blk-mq: check on cpu id when there is only one ctx mapping
  (bsc#1218785).
- commit 34e3536
* Mon Jan 15 2024 tonyj@suse.de
- tools: Disable __packed attribute compiler warning due
  to -Werror=attributes (perf-v6.7 git-fixes (jsc#PED-6012
  jsc#PED-6121)).
- tools build: Fix llvm feature detection, still used by bpftool
  (perf-v6.7 git-fixes (jsc#PED-6012 jsc#PED-6121)).
- perf/benchmark: fix seccomp_unotify benchmark for 32-bit
  (perf-v6.7 git-fixes (jsc#PED-6012 jsc#PED-6121)).
- commit 46e701f
* Mon Jan 15 2024 nik.borisov@suse.com
- x86/amd_nb: Add AMD Family MI300 PCI IDs (jsc#PED-7622).
- Refresh
  patches.suse/PCI-Prevent-xHCI-driver-from-claiming-AMD-VanGogh-US.patch.
- commit eb725e3
* Mon Jan 15 2024 nik.borisov@suse.com
- x86/MCE/AMD: Add new MA_LLC, USR_DP, and USR_CP bank types (jsc#PED-7622).
- commit 7d080dd
* Mon Jan 15 2024 nik.borisov@suse.com
- x86/mce/amd, EDAC/mce_amd: Move long names to decoder module (jsc#PED-7622).
- Refresh
  patches.suse/EDAC-mce_amd-Remove-SMCA-Extended-Error-code-descriptions.patch.
- commit e24f23e
* Mon Jan 15 2024 nik.borisov@suse.com
- EDAC/mce_amd: Remove SMCA Extended Error code descriptions (jsc#PED-7622).
- commit 26b9953
* Mon Jan 15 2024 nik.borisov@suse.com
- EDAC/mc: Add support for HBM3 memory type (jsc#PED-7622).
- commit 87fa543
* Mon Jan 15 2024 nik.borisov@suse.com
- Documentation: Begin a RAS section (jsc#PED-7622).
- commit c5a4e59
* Mon Jan 15 2024 nik.borisov@suse.com
- EDAC/amd64: Add support for family 0x19, models 0x90-9f devices (jsc#PED-7622).
- commit ce743a1
* Mon Jan 15 2024 nik.borisov@suse.com
- x86/mce: Cleanup mce_usable_address() (jsc#PED-7623).
- commit 19a7df2
* Mon Jan 15 2024 nik.borisov@suse.com
- x86/mce: Define amd_mce_usable_address() (jsc#PED-7623).
- commit 4f93668
* Mon Jan 15 2024 nik.borisov@suse.com
- x86/MCE/AMD: Split amd_mce_is_memory_error() (jsc#PED-7623).
- commit d0a7ad4
* Mon Jan 15 2024 nik.borisov@suse.com
- x86: sta2x11: include header for sta2x11_get_instance() prototype (git-fixes).
- commit 1ee8ffe
* Mon Jan 15 2024 nik.borisov@suse.com
- x86/nmi: Fix out-of-order NMI nesting checks & false positive warning (git-fixes).
- commit a789183
* Mon Jan 15 2024 nik.borisov@suse.com
- x86/mce/inject: Clear test status value (git-fixes).
- commit 8b89223
* Mon Jan 15 2024 nik.borisov@suse.com
- x86/lib: Fix overflow when counting digits (git-fixes).
- commit 620dff6
* Mon Jan 15 2024 nik.borisov@suse.com
- x86/kprobes: fix incorrect return address calculation in kprobe_emulate_call_indirect (git-fixes).
- commit 8be12d2
* Mon Jan 15 2024 nik.borisov@suse.com
- x86/cpu/hygon: Fix the CPU topology evaluation for real (git-fixes).
- commit 8f83bcd
* Mon Jan 15 2024 nik.borisov@suse.com
- x86/boot: Fix incorrect startup_gdt_descr.size (git-fixes).
- commit c875e2d
* Mon Jan 15 2024 nik.borisov@suse.com
- x86/amd_nb: Use Family 19h Models 60h-7Fh Function 4 IDs (git-fixes).
- commit e3deaea
* Mon Jan 15 2024 nik.borisov@suse.com
- x86/alternatives: Sync core before enabling interrupts (git-fixes).
- commit 44dde1b
* Mon Jan 15 2024 nik.borisov@suse.com
- x86: Fix CPUIDLE_FLAG_IRQ_ENABLE leaking timer reprogram (git-fixes).
- commit 81b2e99
* Mon Jan 15 2024 iivanov@suse.de
- coresight: etm4x: Ensure valid drvdata and clock before clk_put() (bsc#1218779)
- commit 220f26f
* Mon Jan 15 2024 hare@suse.de
- fs: remove the now unused FMODE_* flags (bsc#1218785).
- block: store the holder in file->private_data (bsc#1218785).
- commit be82207
* Mon Jan 15 2024 hare@suse.de
- block: always use I_BDEV on file->f_mapping->host to find the
  bdev (bsc#1218785).
- commit ae98ee3
* Mon Jan 15 2024 hare@suse.de
- block: replace fmode_t with a block-specific type for block
  open flags (bsc#1218785).
- Refresh patches.suse/bcache-Fix-bcache-device-claiming.patch.
- Refresh
  patches.suse/drdb-Convert-to-use-bdev_open_by_path.patch.
- Refresh
  patches.suse/md-fix-warning-for-holder-mismatch-from-export_rdev.patch.
- Refresh
  patches.suse/nbd-factor-out-a-helper-to-get-nbd_config-without-holding-config_lock.patch.
- Refresh
  patches.suse/nbd-fold-nbd-config-initialization-into-nbd_alloc_config.patch.
- commit 29ae81a
* Mon Jan 15 2024 hare@suse.de
- mtd: block2mtd: don't call early_lookup_bdev after the system
  (bsc#1218785).
- commit 42c612f
* Mon Jan 15 2024 hare@suse.de
- mtd: block2mtd: factor the early block device open logic into
  (bsc#1218785).
- Refresh
  patches.suse/block-use-the-holder-as-indication-for-exclusive-opens.patch.
- commit dd8efb4
* Mon Jan 15 2024 iivanov@suse.de
- coresight: etm4x: Add ACPI support in platform driver (bsc#1218779)
- commit c34f1a7
* Mon Jan 15 2024 iivanov@suse.de
- coresight: platform: acpi: Ignore the absence of graph (bsc#1218779)
- commit 89c1dad
* Mon Jan 15 2024 iivanov@suse.de
- coresight: etm4x: Change etm4_platform_driver driver for MMIO devices (bsc#1218779)
- commit 961790d
* Mon Jan 15 2024 mfranc@suse.cz
- s390/dasd: fix double module refcount decrement (bsc#1141539).
- commit f61a5ce
* Mon Jan 15 2024 iivanov@suse.de
- coresight: etm4x: Drop pid argument from etm4_probe() (bsc#1218779)
- commit c7f3146
* Mon Jan 15 2024 iivanov@suse.de
- coresight: etm4x: Drop iomem 'base' argument from etm4_probe() (bsc#1218779)
- commit f4cee1c
* Mon Jan 15 2024 iivanov@suse.de
- coresight: etm4x: Allocate and device assign 'struct etmv4_drvdata' (bsc#1218779)
- commit 793dfc1
* Mon Jan 15 2024 hare@suse.de
- block: remove unused fmode_t arguments from ioctl handlers
  (bsc#1218785).
- commit 99715e2
* Mon Jan 15 2024 hare@suse.de
- ubd: remove commented out code in ubd_open (bsc#1218785).
- mtd: block: use a simple bool to track open for write
  (bsc#1218785).
- commit 0f563df
* Mon Jan 15 2024 hare@suse.de
- nvme: replace the fmode_t argument to the nvme ioctl handlers
  with a simple bool (bsc#1218785).
- Refresh
  patches.suse/nvme-ioctl-move-capable-admin-check-to-the-end.patch.
- commit 20cc5be
* Mon Jan 15 2024 hare@suse.de
- scsi: replace the fmode_t argument to ->sg_io_fn with a simple
  bool (bsc#1218785).
- scsi: replace the fmode_t argument to scsi_ioctl with a simple
  bool (bsc#1218785).
- scsi: replace the fmode_t argument to scsi_cmd_allowed with
  a simple bool (bsc#1218785).
- fs: remove sb->s_mode (bsc#1218785).
- block: add a sb_open_mode helper (bsc#1218785).
- commit b3b96ce
* Mon Jan 15 2024 hare@suse.de
- btrfs: don't pass a holder for non-exclusive blkdev_get_by_path
  (bsc#1218785).
- commit da2722b
* Mon Jan 15 2024 hare@suse.de
- bcache: don't pass a stack address to blkdev_get_by_path
  (bsc#1218785).
- Refresh patches.suse/bcache-Fix-bcache-device-claiming.patch.
- Refresh
  patches.suse/block-use-the-holder-as-indication-for-exclusive-opens.patch.
- commit 348ae97
* Mon Jan 15 2024 tonyj@suse.de
- sync tools/arch header for Support branch counters logging
  (jsc#PED-6012 jsc#PED-6121).
- perf test: Basic branch counter support (jsc#PED-6012
  jsc#PED-6121).
- perf tools: Add branch counter knob (jsc#PED-6012 jsc#PED-6121).
- perf header: Support num and width of branch counters
  (jsc#PED-6012 jsc#PED-6121).
- tools headers UAPI: Sync include/uapi/linux/perf_event.h header
  with the kernel (jsc#PED-6012 jsc#PED-6121).
- perf/x86/intel: Support branch counters logging (jsc#PED-6012
  jsc#PED-6121).
- perf/x86/intel: Reorganize attrs and is_visible (jsc#PED-6012
  jsc#PED-6121).
- perf: Add branch_sample_call_stack (jsc#PED-6012 jsc#PED-6121).
- perf/x86: Add PERF_X86_EVENT_NEEDS_BRANCH_STACK flag
  (jsc#PED-6012 jsc#PED-6121).
- perf: Add branch stack counters (jsc#PED-6012 jsc#PED-6121).
- perf list: Fix JSON segfault by setting the used
  skip_duplicate_pmus callback (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf vendor events arm64: AmpereOne: Add missing
  DefaultMetricgroupName fields (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf metrics: Avoid segv if default metricgroup isn't set
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- tools perf: Add arm64 sysreg files to MANIFEST (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- tools headers: Update tools's copy of s390/asm headers
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- tools headers: Update tools's copy of arm64/asm headers
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- commit d14bff1
* Mon Jan 15 2024 hare@suse.de
- block: rename blkdev_close to blkdev_release (bsc#1218785).
- commit 92c813f
* Mon Jan 15 2024 tonyj@suse.de
- tools headers: Update tools's copy of x86/asm headers (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- Refresh patches.suse/kabi-reserve-cpuid-leaves.patch.
- commit cceb480
* Mon Jan 15 2024 hare@suse.de
- cdrom: remove the unused cdrom_close_write release code
  (bsc#1218785).
- cdrom: remove the unused mode argument to cdrom_ioctl
  (bsc#1218785).
- Refresh
  patches.suse/cdrom-remove-the-unused-mode-argument-to-cdrom_release.patch.
- Refresh
  patches.suse/cdrom-track-if-a-cdrom_device_info-was-opened-for-data.patch.
- commit f4a27e4
* Mon Jan 15 2024 hare@suse.de
- block: also call ->open for incremental partition opens
  (bsc#1218785).
- Refresh
  patches.suse/block-remove-the-unused-mode-argument-to-release.patch.
- Refresh patches.suse/cdrom-gdrom-Fix-build-error.patch.
- commit 00ba146
* Mon Jan 15 2024 pjakobsson@suse.de
- Refresh
  patches.suse/drm-amd-display-Fix-sending-VSC-colorimetry-packets-.patch
  (git-fixes)
  Alt-commit
- commit de32d60
* Mon Jan 15 2024 nik.borisov@suse.com
- Refresh patches.suse/x86-virt-tdx-Disable-TDX-host-support-when-kexec-is-enable.patch.
  Move the kexec check right after TDX has been initialized as otherwise
  KEXEC is permanently broken.
- commit 76414b1
* Mon Jan 15 2024 pjakobsson@suse.de
- Refresh
  patches.suse/drm-amdgpu-re-create-idle-bo-s-PTE-during-VM-state-m.patch
  (git-fixes)
  Alt-commit
- commit 77ade9c
* Mon Jan 15 2024 pjakobsson@suse.de
- Refresh
  patches.suse/drm-amd-display-Restore-guard-against-default-backli.patch
  (git-fixes)
  Alt-commit
- commit 6354727
* Mon Jan 15 2024 pjakobsson@suse.de
- Refresh
  patches.suse/drm-amd-display-fix-hw-rotated-modes-when-PSR-SU-is-.patch
  (git-fixes)
  Alt-commit
- commit 1767b1e
* Mon Jan 15 2024 pjakobsson@suse.de
- Refresh
  patches.suse/drm-amdgpu-Restrict-extended-wait-to-PSP-v13.0.6.patch
  (git-fixes)
  Alt-commit
- commit d7149a5
* Mon Jan 15 2024 tonyj@suse.de
- tools headers UAPI: Update tools's copy of vhost.h header
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf lock contention: Fix a build error on 32-bit (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf kwork: Fix a build error on 32-bit (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf vendor events intel: Update tsx_cycles_per_elision metrics
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update bonnell version number to v5
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update westmereex events to v4
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update meteorlake events to v1.06
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update knightslanding events to v16
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Add typo fix for ivybridge FP
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update a spelling in haswell/haswellx
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update emeraldrapids to v1.01
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update alderlake/alderlake events
  to v1.23 (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf build: Disable BPF skeletons if clang version is < 12.0.1
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf callchain: Fix spelling mistake "statisitcs" ->
  "statistics" (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf report: Fix spelling mistake "heirachy" -> "hierarchy"
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf python: Fix binding linkage due to rename and move
  of evsel__increase_rlimit() (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf tests: test_arm_coresight: Simplify source iteration
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Add tigerlake two metrics (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Add broadwellde two metrics (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Fix broadwellde
  tma_info_system_dram_bw_use metric (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf mem_info: Add and use map_symbol__exit and
  addr_map_symbol__exit (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf callchain: Minor layout changes to callchain_list
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf callchain: Make brtype_stat in callchain_list optional
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf callchain: Make display use of branch_type_stat const
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf offcpu: Add missed btf_free (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf threads: Remove unused dead thread list (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf hist: Add missing puts to hist__account_cycles (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- libperf rc_check: Add RC_CHK_EQUAL (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- libperf rc_check: Make implicit enabling work for GCC (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf machine: Avoid out of bounds LBR memory read (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf rwsem: Add debug mode that uses a mutex (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf build: Address stray '\' before # that is warned about
  since grep 3.8 (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf report: Fix hierarchy mode on pipe input (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf lock contention: Use per-cpu array map for spinlocks
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf lock contention: Check race in tstamp elem creation
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf lock contention: Clear lock addr after use (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf evsel: Rename evsel__increase_rlimit to
  rlimit__increase_nofile (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf bench sched pipe: Add -G/--cgroups option (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test: Skip CoreSight tests if cs_etm// event is not
  available (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf data: Increase RLIMIT_NOFILE limit when open too many
  files in perf_data__create_dir() (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf trace: Use the right bpf_probe_read(_str) variant for
  reading user data (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tools: Do not ignore the default vmlinux.h (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf: script: fix missing ',' for fields option (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf tests: Fix shellcheck warning in stat_all_metricgroups
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests: Fix shellcheck warning in record_sideband.sh
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests: Ignore shellcheck warning in lock_contention
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- tools/perf/arch/powerpc: Fix the CPU ID const char* value by
  adding 0x prefix (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf cs-etm: Respect timestamp option (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf cs-etm: Validate timestamp tracing in per-thread mode
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Lazily compute default config (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf pmu-events: Remember the perf_events_map for a PMU
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Const-ify perf_pmu__config_terms (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Const-ify file APIs (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf arm-spe: Move PMU initialization from default config code
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf intel-pt: Move PMU initialization from default config code
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Rename perf_pmu__get_default_config to
  perf_pmu__arch_init (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf intel-pt: Prefer get_unaligned_le64 to memcpy_le64
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf intel-pt: Use get_unaligned_le16() etc (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf intel-pt: Use existing definitions of le16_to_cpu() etc
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf intel-pt: Simplify intel_pt_get_vmcs() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf tools: Add get_unaligned_leNN() (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf cs-etm: Fix incorrect or missing decoder for raw trace
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf bpf_counter: Fix a few memory leaks (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf header: Fix various error path memory leaks (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf trace-event-info: Avoid passing NULL value to closedir
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Fix unlikely memory leak when cloning terms
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf lock: Fix a memory leak on an error path (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf svghelper: Avoid memory leak (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf hists browser: Avoid potential NULL dereference (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf hists browser: Reorder variables to reduce padding
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf dlfilter: Be defensive against potential NULL dereference
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf mem-events: Avoid uninitialized read (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf jitdump: Avoid memory leak (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf env: Remove unnecessary NULL tests (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf buildid-cache: Fix use of uninitialized value (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf bench uprobe: Fix potential use of memory after free
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Fix for term values that are raw events
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf build: Add missing comment about NO_LIBTRACEEVENT=1
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf symbols: Add 'intel_idle_ibrs' to the list of idle symbols
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Avoid erange from hex numbers (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- tools/perf: Update call stack check in builtin-lock.c (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- tools/perf/tests: Fix object code reading to skip address
  that falls out of text section (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- tools/perf: Add "is_kmod" to struct dso to check if it is
  kernel module (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- tools/perf: Add text_end to "struct dso" to save .text section
  size (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test: Avoid system wide when not privileged (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf hisi-ptt: Fix memory leak in lseek failure handling
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf intel-pt: Fix async branch flags (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf pmus: Make PMU alias name loading lazy (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test: Fix parse-events tests to skip parametrized events
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events: Add JSON metrics for Arm CMN (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf jevents: Add support for Arm CMN PMU aliasing (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test: Add pmu-event test for "Compat" and new event_field
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test: Make matching_pmu effective (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf jevents: Support EventidCode and NodeType (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf metric: "Compat" supports regular expression matching
  identifiers (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: "Compat" supports regular expression matching
  identifiers (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf record: Fix BTF type checks in the off-cpu profiling
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf bench messaging: Kill child processes when exit abnormally
  in process mode (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf bench messaging: Store chlid process pid when creating
  worker for process mode (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf bench messaging: Factor out create_worker() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf bench messaging: Fix coding style issues for
  sched-messaging (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- tests/shell: Fix shellcheck warnings for SC2153 in multiple
  scripts (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- tests/shell: Fix shellcheck issues in
  tests/shell/stat+shadow_stat.sh tetscase (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- tests/shell: Fix shellcheck SC1090 to handle the location of
  sourced files (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf kwork: Fix spelling mistake "Captuer" -> "Capture"
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf evlist: Avoid frequency mode for the dummy event (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendors events: Remove repeated word in comments (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events arm64: Fix for AmpereOne metrics (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test lock_contention.sh: Skip test if not enough CPUs
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test stat+shadow_stat.sh: Add threshold for rounding errors
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf jevents: fix no member named 'entries' issue (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Fix tracepoint name memory leak (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test: Detect off-cpu support from build options (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test: Ensure EXTRA_TESTS is covered in build test
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test: Update build test for changed BPF skeleton defaults
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf build: Default BUILD_BPF_SKEL, warn/disable for missing
  deps (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf version: Add status of bpf skeletons (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf kwork top: Simplify bool conversion (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test: Fix test-record-dummy-C0 failure for supported
  PERF_FORMAT_LOST feature kernel (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf kwork: Fix spelling mistake "COMMMAND" -> "COMMAND"
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf annotate: Add more x86 mov instruction cases (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Remove unused function (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf pmus: Simplify perf_pmus__find_core_pmu() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Move pmu__find_core_pmu() to pmus.c (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf symbol: Avoid an undefined behavior warning (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf bpf-filter: Add YYDEBUG (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf pmu: Add YYDEBUG (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf expr: Make YYDEBUG dependent on doing a debug build
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Make YYDEBUG dependent on doing a debug build
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Remove unused header files (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf tools: Add includes for detected configs in Makefile.perf
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test: Update cs_etm testcase for Arm ETE (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events arm64: Add V1 metrics using Arm telemetry
  repo (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events arm64: Update V1 events using Arm telemetry
  repo (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test: Add a test for strcmp_cpuid_str() expression
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf util: Add a function for replacing characters in a string
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf jevents: Remove unused keyword (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf test: Check result of has_event(cycles) test (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf list pfm: Retry supported test with exclude_kernel
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf list: Avoid a hardcoded cpu PMU name (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test shell lock_contention: Add cgroup aggregation and
  filter tests (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf lock contention: Add -G/--cgroup-filter option (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf lock contention: Add --lock-cgroup option (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf lock contention: Prepare to handle cgroups (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf tools: Add read_all_cgroups() and __cgroup_find()
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf kwork top: Add BPF-based statistics on softirq event
  support (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf kwork top: Add BPF-based statistics on hardirq event
  support (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf kwork top: Implements BPF-based cpu usage statistics
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf kwork top: Add -C/--cpu -i/--input -n/--name -s/--sort
  - -time options (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf kwork top: Add statistics on softirq event support
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf kwork top: Add statistics on hardirq event support
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf evsel: Add evsel__intval_common() helper (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf kwork top: Introduce new top utility (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf kwork: Add `root` parameter to work_sort() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf kwork: Add sched record support (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf kwork: Set default events list if not specified in
  setup_event_list() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf kwork: Overwrite original atom in the list when a new
  atom is pushed (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf kwork: Add `kwork` and `src_type` to work_init() for
  'struct kwork_class' (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf kwork: Set ordered_events to true in 'struct perf_tool'
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf kwork: Add the supported subcommands to the document
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf kwork: Fix incorrect and missing free atom in
  work_push_atom() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test: Add perf_event_attr test for record dummy event
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test: Add test case for record sideband events (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf record: Track sideband events for all CPUs when tracing
  selected CPUs (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf record: Move setting tracking events before
  record__init_thread_masks() (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf evlist: Add evlist__findnew_tracking_event() helper
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf evlist: Add perf_evlist__go_system_wide() helper (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Fix spelling mistakes (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Add emeraldrapids, update
  sapphirerapids to v1.16 (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Add lunarlake v1.0 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Introduce 'struct parse_events_terms'
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Copy fewer term lists (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Avoid enum casts (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf parse-events: Tidy up str parameter (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Remove unnecessary __maybe_unused (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf shell completion: Support completion of
  metrics/metricgroups (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf completion: Support completion of libpfm4 events (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf shell completion: Restrict completion of events to events
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf stat: Fix aggr mode initialization (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf vendor events power10: Add extra data-source events
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf machine: Use true and false for bool variable (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf dlfilter: Add a test for object_code() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf dlfilter: Fix use of addr_location__exit() in
  dlfilter__object_code() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Fix perf stat output with correct scale and unit
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf jevent: fix core dump on software events on s390 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Ensure all alias variables are initialized (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf jevents metric: Fix type of strcmp_cpuid_str (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf trace: Avoid compile error wrt redefining bool (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf bpf-prologue: Remove unused file (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- tools headers UAPI: Update tools's copy of drm.h headers
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- tools arch x86: Sync the msr-index.h copy with the kernel
  sources (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf bench sched-seccomp-notify: Use the tools copy of seccomp.h
  UAPI (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- tools headers UAPI: Copy seccomp.h to be able to build 'perf
  bench' in older systems (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- tools headers UAPI: Sync files changed by new fchmodat2 and
  map_shadow_stack syscalls with the kernel sources (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Fix driver config term (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Fixes relating to no_value terms (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Fix propagation of term's no_value when
  cloning (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Name the two term enums (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf list: Don't print Unit for "default_core" (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Fix modifier in
  tma_info_system_mem_parallel_reads for skylake (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf dlfilter: Avoid leak in v0 API test use of
  resolve_address() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf metric: Add #num_cpus_online literal (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Remove str from perf_pmu_alias (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Make common term list to strbuf helper
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Minor help message improvements (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Avoid uninitialized use of alias->str (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf jevents: Use "default_core" for events with no Unit
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test stat_bpf_counters_cgrp: Enhance perf stat cgroup
  BPF counter test (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test shell stat_bpf_counters: Fix test on Intel (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test shell record_bpf_filter: Skip 6.2 kernel (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- libperf: Get rid of attr.id field (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf tools: Convert to perf_record_header_attr_id() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- libperf: Add perf_record_header_attr_id() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf tools: Handle old data in PERF_RECORD_ATTR (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmus: Skip duplicate PMUs and don't print list suffix by
  default (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmus: Sort pmus by name then suffix (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf beauty mmap_flags: Use "test -f" instead of "" (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf beauty mmap_flags: Fix script for archs that use the
  generic mman.h (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tools: Allow to use cpuinfo on LoongArch (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf lock contention: Fix typo in max-stack option description
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tui slang: Tidy casts (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf build-id: Simplify build_id_cache__cachedir() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Make id const and add missing free (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Make term's config const (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Remove logic for PMU name being NULL (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf header: Fix missing PMU caps (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf jevents: Don't append Unit to desc (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf scripts python gecko: Launch the profiler UI on the default
  browser with the appropriate URL (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf scripts python: Add support for input args in gecko script
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf jevents: Sort strings in the big C string to reduce faults
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Lazily load sysfs aliases (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf pmu: Be lazy about loading event info files from sysfs
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Scan type early to fail an invalid PMU quickly
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Lazily add JSON events (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf pmu: Cache JSON events table (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf pmu: Merge JSON events with sysfs at load time (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Prefer passing pmu to aliases list (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Parse sysfs events directly from a file (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmu-events: Add pmu_events_table__find_event() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmu-events: Reduce processed events by passing PMU
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf s390 s390_cpumcfdg_dump: Don't scan all PMUs (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Improve error message for double setting
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf jevents: Group events by PMU (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf pmu-events: Add extra underscore to function names
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Abstract alias/event struct (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf pmu: Make the loading of formats lazy (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf build: Allow customization of clang options for BPF target
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Pass PMU rather than aliases and format (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Avoid passing format list to perf_pmu__format_bits()
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Avoid passing format list to perf_pmu__format_type
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Avoid passing format list to perf_pmu__config_terms()
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Reduce scope of perf_pmu_error() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Move perf_pmu__set_format to pmu.y (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Avoid a path name copy (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf script ibs: Remove unused include (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf bench breakpoint: Skip run if no breakpoints available
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf lzma: Convert some pr_err() to pr_debug() as callers
  already use pr_debug() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf stat-display: Check if snprintf()'s fmt argument is NULL
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf bpf augmented_raw_syscalls: Add an assert to make sure
  sizeof(augmented_arg->value) is a power of two (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf bpf augmented_raw_syscalls: Add an assert to make sure
  sizeof(saddr) is a power of two (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf vendor events arm64: AmpereOne: Remove unsupported events
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events arm64: Add AmpereOne metrics (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events arm64: AmpereOne: Mark affected STALL_*
  events impacted by errata (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf vendor events arm64: Remove L1D_CACHE_LMISS from AmpereOne
  list (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf jevents: Raise exception for no definition of a arch std
  event (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf trace: Use heuristic when deciding if a syscall tracepoint
  "const char *" field is really a string (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf trace: Use the augmented_raw_syscall BPF skel only for
  tracing syscalls (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf lock: Don't pass an ERR_PTR() directly to
  perf_session__delete() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf top: Don't pass an ERR_PTR() directly to
  perf_session__delete() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events arm64: Update N2 and V2 metrics and
  events using Arm telemetry repo (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf vendor events arm64: Update stall_slot workaround for N2
  r0p3 (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf jevents: Add a new expression builtin strcmp_cpuid_str()
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test: Add a test for the new Arm CPU ID comparison behavior
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf arm64: Allow version comparisons of CPU IDs (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf bpf_skel augmented_raw_syscalls: Cap the socklen parameter
  using &= sizeof(saddr) (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- libperf: Implement riscv mmap support (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf parse-regs: Move out arch specific header from
  util/perf_regs.h (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-regs: Remove PERF_REGS_{MAX|MASK} from common code
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-regs: Remove unused macros PERF_REG_{IP|SP}
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf unwind: Use perf_arch_reg_{ip|sp}() to substitute macros
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-regs: Introduce functions perf_arch_reg_{ip|sp}()
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-regs: Refactor arch register parsing functions
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf docs: Fix format of unordered lists (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events arm64: Update scale units and descriptions of
  common topdown metrics (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf cs-etm: Don't duplicate FIELD_GET() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf dlfilter: Add al_cleanup() (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf dlfilter: Initialize addr_location before passing
  it to thread__find_symbol_fb() (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf dlfilter: Add a test for resolve_address() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf scripts python: Update audit-libs package name for python3
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf scripts python: Support syscall name parsing on arm64
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf evsel: Remove duplicate check for `field` in
  evsel__intval() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test: Add perf record sample filtering test (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf bpf-filter: Fix sample flag check with || (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf trace: Tidy comments related to BPF + syscall augmentation
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf bpf examples: With no BPF events remove examples (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf trace: Migrate BPF augmentation to use a skeleton
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Remove BPF event support (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf bpf: Remove support for embedding clang for compiling
  BPF events (-e foo.c) (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests trace+probe_vfs_getname.sh: Accept quotes surrounding
  the filename (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test trace+probe_vfs_getname.sh: Remove stray \ before /
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf script python: Add stub for PMU symbol to the python
  binding (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf symbols: Fix DSO kernel load and symbol process to
  correctly map DSO to its long_name, type and adjust_symbols
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf build: Remove -Wno-unused-but-set-variable from the
  flex flags when building with clang < 13.0.0 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf script: Print "cgroup" field on the same line as "comm"
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf probe: Make synthesize_perf_probe_point() private to
  probe-event.c (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf probe: Free string returned by
  synthesize_perf_probe_point() on failure in
  synthesize_perf_probe_command() (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf probe: Free string returned by
  synthesize_perf_probe_point() on failure to add a probe
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf hists browser: Fix the number of entries for 'e' key
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf hists browser: Fix hierarchy mode header (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf annotate bpf: Don't enclose non-debug code with an assert()
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf build: Support llvm and clang support compiled in
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf script python: Cope with declarations after statements
  found in Python.h (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf python: Cope with declarations after statements found in
  Python.h (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update Icelake+ metric constraints
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update sapphirerapids to 1.15
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update meteorlake to 1.04 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events x86: Avoid sorting uops_retired.slots
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf probe: Show correct error message about @symbol usage
  for uprobe (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test bpf: Address error about non-null argument for
  epoll_pwait 2nd arg (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests stat+std_output: Fix shellcheck warnings about word
  splitting/quoting and local variables (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf tests stat+std_output: Fix shellcheck warnings about word
  splitting/quoting (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests lib stat_output: Fix shellcheck warning about
  missing shebang (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests coresight thread_loop_check_tid_2: Fix shellcheck
  warnings about word splitting/quoting (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf tests record+zstd_comp_decomp: Fix the shellcheck
  warnings about word splitting/quoting (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf arch x86: Address shellcheck warnings about unused
  variables in syscalltbl.sh (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf trace x86_arch_prctl: Address shellcheck warnings about
  local variables (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests lib waiting: Fix the shellcheck warnings about
  missing shebang (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests lib probe_vfs_getname: Fix shellcheck warnings
  about missing shebang/local variables (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf tests unroll_loop_thread_10: Fix shellcheck warnings about
  word splitting/quoting (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests thread_loop_check_tid_10: Fix shellcheck warnings
  bout word splitting/quoting (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf build: Fix shellcheck issue about quotes for
  check-headers.sh (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf beauty arch_errno_names: Fix shellcheck issue about local
  variables (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests lib probe: Fix shellcheck warning about about
  missing shebang (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests memcpy_thread_16k_10: Fix shellcheck warning about
  word splitting/quote (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests asm_pure_loop: Fix shellcheck warning about word
  splitting/quote (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests stat+shadow_stat: Fix shellcheck warning about
  unused variable (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests stat_bpf_counters: Fix usage of '==' to address
  shellcheck warning (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests perf_dat _converter_json: Use quoting to avoid word
  splitting (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests stat+csv_summary: Fix unused variable references
  detected via shellcheck (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests: Address signal case issues detected via shellcheck
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test stat_bpf_counters_cgrp: Fix shellcheck issue about
  logical operators (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests lock_contention: Fix shellcheck issue about quoting
  to avoid word splitting (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests record_offcpu: Fix shellcheck warnings about
  word splitting/quoting and signal names case (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf tests probe_vfs_getname: Fix shellcheck warnings about
  word splitting/quoting (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests trace+probe_vfs_getname: Fix shellcheck warnings
  about word splitting/quoting (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf tests task_analyzer: Check perf build options for
  libtraceevent support (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Remove array remnants (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf tools: Revert enable indices setting syntax for BPF map
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-event: Avoid BPF test SEGV (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf build: Include generated header files properly (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf build: Update build rule for generated files (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf build: Remove -Wno-redundant-decls in 2 cases (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf build: Disable fewer bison warnings (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf build: Disable fewer flex warnings (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf build: Add Wextra for C++ compilation (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf build: Don't always set -funwind-tables and -ggdb3
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf bpf-loader: Remove unneeded diagnostic pragma (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events arm64: Add JSON metrics for Yitian 710 DDR
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf jevents: Add support for Yitian 710 DDR PMU (arm64)
  aliasing (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tools: Add a place to put kernel config fragments for
  test runs (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf scripts python: Add command execution for gecko script
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf scripts python: Implement add sample function and thread
  processing (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf scripts python: Add trace end processing and PRODUCT and
  CATEGORIES information (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf scripts python: Add classes and conversion functions
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf scripts python: Extact necessary information from process
  event (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf scripts python: Add initial script file with usage
  information (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf doc: Fix typo in perf.data-file-format.txt (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf machine: Include data symbols in the kernel map (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf symbols: Add kallsyms__get_symbol_start() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Remove ABORT_ON (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf parse-events: Improve location for add pmu (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Populate error column for BPF/tracepoint
  events (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Additional error reporting (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Separate ENOMEM memory handling (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Move instances of YYABORT to YYNOMEM
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Separate YYABORT and YYNOMEM cases (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-event: Add memory allocation test for name terms
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf build: Define YYNOMEM as YYNOABORT for bison < 3.81
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Avoid regrouped warning for wild card events
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Add more comments to 'struct
  parse_events_state' (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Remove two unused tokens (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Remove unused PE_KERNEL_PMU_EVENT token
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Remove unused PE_PMU_EVENT_FAKE token
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf build: Add LTO build option (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf test: Avoid weak symbol for arch_tests (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Avoid use uninitialized warning (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf stat: Avoid uninitialized use of perf_stat_config
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf diff: Replaces some ',' as separator with the more usual
  ';' (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf bench uprobe trace_printk: Add entry attaching an BPF
  program that does a trace_printk (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf bench uprobe empty: Add entry attaching an empty BPF
  program (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf bench uprobe: Show diff to previous (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf bench uprobe: Print diff to baseline (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf bench uprobe: Add benchmark to test uprobe overhead
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf trace: Free thread_trace->files table (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf trace: Really free the evsel->priv area (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf trace: Register a thread priv destructor (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf thread: Allow tools to register a thread->priv destructor
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf evsel: Free evsel->filter on the destructor (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf: tests: Adapt mmap-basic.c for riscv (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf/mem: Introduce PERF_MEM_LVLNUM_UNC (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf/benchmark: add a new benchmark for seccom_unotify
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf stat: Don't display zero tool counts (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- tools arch x86: Sync the msr-index.h copy with the kernel
  sources (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test parse-events: Test complex name has required event
  format (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmus: Create placholder regardless of scanning core_only
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Only move force grouped evsels when sorting
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: When fixing group leaders always set the
  leader (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Extra care around force grouped events
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf callchain powerpc: Fix addr location init during
  arch_skip_callchain_idx function (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf test task_exit: No need for a cycles event to check if we
  get an PERF_RECORD_EXIT (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- tools headers arm64: Sync arm64's cputype.h with the kernel
  sources (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- tools include UAPI: Sync the sound/asound.h copy with the
  kernel sources (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- tools include UAPI: Sync linux/vhost.h with the kernel sources
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Avoid SEGV if PMU lookup fails for legacy
  cache terms (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events amd: Fix large metrics (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- tools headers UAPI: Sync drm/i915_drm.h with the kernel sources
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test: Fix event parsing test when
  PERF_PMU_CAP_EXTENDED_HW_TYPE isn't supported (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test: Fix event parsing test on Arm (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf evsel amd: Fix IBS error message (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf: unwind: Fix symfs with libdw (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf symbol: Fix uninitialized return value in
  symbols__find_by_name() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test: Test perf lock contention CSV output (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf lock contention: Add --output option (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf lock contention: Add -x option for CSV style output
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf lock: Remove stale comments (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf vendor events intel: Update tigerlake to 1.13 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update skylakex to 1.31 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update skylake to 57 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update sapphirerapids to 1.14
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update icelakex to 1.21 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update icelake to 1.19 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update cascadelakex to 1.19 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update meteorlake to 1.03 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Add rocketlake events/metrics
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor metrics intel: Make transaction metrics conditional
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf jevents: Support for has_event function (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf expr: Add has_event function (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf tools: Do not remove addr_location.thread in
  thread__find_map() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmus: Add placeholder core PMU (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf test: Fix a compile error on pe-file-parsing.c (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf: Replace deprecated -target with --target= for Clang
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Correct auto_merge_stats test (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf tools: Add missing else to cmd_daemon subcommand condition
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tools: Add printing perf_event_attr config symbol
  in perf_event_attr__fprintf() (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf tools: Add printing perf_event_attr type symbol
  in perf_event_attr__fprintf() (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf tools: Extend PRINT_ATTRf to support printing of members
  with a value of 0 (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf trace-event-info: Add tracepoint_id_to_name() helper
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf symbol: Remove now unused symbol_conf.sort_by_name
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf symbol: Remove symbol_name_rb_node (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf dso: Sort symbols under lock (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf build: Filter out BTF sources without a .BTF section
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test: Add build tests for BUILD_BPF_SKEL (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- commit c505690
* Mon Jan 15 2024 pjakobsson@suse.de
- Refresh
  patches.suse/drm-amd-display-Increase-frame-warning-limit-with-KA.patch
  (git-fixes)
  Alt-commit
- commit 6af175c
* Mon Jan 15 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amdgpu-disable-MCBP-by-default.patch
  (git-fixes)
  Alt-commit
- commit 7c5a9d4
* Mon Jan 15 2024 pjakobsson@suse.de
- Refresh
  patches.suse/1372-drm-i915-pmu-Check-if-pmu-is-closed-before-stopping-.patch
  (git-fixes)
  Alt-commit
- commit 5a0ab05
* Mon Jan 15 2024 pjakobsson@suse.de
- Refresh
  patches.suse/1371-drm-i915-mcr-Hold-GT-forcewake-during-steering-opera.patch
  (git-fixes)
  Alt-commit
- commit c7edfb4
* Mon Jan 15 2024 pjakobsson@suse.de
- Refresh
  patches.suse/drm-amd-pm-fix-a-memleak-in-aldebaran_tables_init.patch
  (git-fixes)
  Alt-commit
- commit 4325f96
* Mon Jan 15 2024 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-Also-check-for-VGA-converter-in-eDP-probe.patch
  (git-fixes)
  Alt-commit
- commit 9ed137b
* Mon Jan 15 2024 pjakobsson@suse.de
- drm/dp_mst: Fix fractional DSC bpp handling (git-fixes).
- commit c36b908
* Mon Jan 15 2024 tonyj@suse.de
- perf build: Add ability to build with a generated vmlinux.h
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- Refresh
  patches.suse/perf-bpf-Move-the-declaration-of-struct-rq.patch.
- commit 8909076
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Skip metrics w/o event name in stat STD output linter
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test: Reorder event name checks in stat STD output linter
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Remove a hard coded cpu PMU assumption (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmus: Add notion of default PMU for JSON events (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf unwind: Fix map reference counts (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf script: Initialize buffer for regs_map() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf tests: Fix test_arm_callgraph_fp variable expansion
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf symbol: Add LoongArch case in get_plt_sizes() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test: Rerun failed metrics with longer workload (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test: Add skip list for metrics known would fail (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test: Add metric value validation test (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf jit: Fix incorrect file name in DWARF line table (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf annotate: Fix instruction association and parsing for
  LoongArch (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf annotation: Switch lock from a mutex to a sharded_mutex
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf sharded_mutex: Introduce sharded_mutex (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- tools: Fix incorrect calculation of object size by sizeof
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Remove unneeded semicolon (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse: Add missing newline to pr_debug message in
  evsel__compute_group_pmu_name() (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf stat: Add missing newline in pr_err messages (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmus: Check if we can encode the PMU number in
  perf_event_attr.type (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf print-events: Export is_event_supported() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test record+probe_libc_inet_pton.sh: Use "grep -F" instead
  of obsolescent "fgrep" (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf mem: Scan all PMUs instead of just core ones (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf mem amd: Fix perf_pmus__num_mem_pmus() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmus: Describe semantics of 'core_pmus' and 'other_pmus'
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf stat: Show average value on multiple runs (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test: fix failing test cases on linux-next for s390
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf annotate: Work with vmlinux outside symfs (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events arm64: Add default tags for Hisi hip08 L1
  metrics (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test: Add test case for the standard 'perf stat' output
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test: Move all the check functions of stat CSV output to
  lib (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf stat: New metricgroup output for the default mode
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf metrics: Sort the Default metricgroup (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- pert tests: Update metric-value for perf stat JSON output
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf stat,jevents: Introduce Default tags for the default mode
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf metric: JSON flag to default metric group (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf evsel: Fix the annotation for hardware events on hybrid
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf srcline: Fix handling of inline functions (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf srcline: Add a timeout to reading from addr2line (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- tools api: Add simple timeout to io read (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events arm64: Add default tags into topdown L1
  metrics (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- pert tests: Support metricgroup perf stat JSON output (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf tests task_analyzer: Print command that failed instead
  of just "perf" (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests stat+shadow_stat.sh: Fix all POSIX sh warnings
  found using shellcheck (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests test_brstack.sh: Fix all POSIX sh warnings (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf tests shell: Fixed shellcheck warnings (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf tests lock_contention: Fix shellscript errors (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf tests test_arm_spe: Address shellcheck warnings about
  signal name case (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- commit cb6b373
* Mon Jan 15 2024 tonyj@suse.de
- perf tests test_task_analyzer: Fix shellcheck issues (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- Refresh
  patches.suse/perf-tests-task_analyzer-Skip-tests-if-no-libtr.patch.
- commit 9011213
* Mon Jan 15 2024 tonyj@suse.de
- perf tests stat_all_metrics: Fix shellcheck warning SC2076
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests test_arm_coresight: Shellcheck fixes (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf tests stat+csv_output: Fix shellcheck warnings (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf tests daemon: Address shellcheck warnings (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf tests arm_callgraph_fp: Address shellcheck warnings about
  signal names and adding double quotes for expression (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf tests stat+json_output: Address shellcheck warnings
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf python scripting: Get rid of unused import in
  arm-cs-trace-disasm (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Avoid string for PE_BP_COLON, PE_BP_SLASH
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf srcline: Make sentinel reading for binutils addr2line
  more robust (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf srcline: Make addr2line configuration failure more verbose
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tests: Make x86 new instructions test optional at build
  time (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf dwarf-aux: Allow unnamed struct/union/enum (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pfm: Remove duplicate util/cpumap.h include (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf annotate: Allow whitespace between insn operands (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf inject: Lazily allocate guest_event event_buf (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf inject: Lazily allocate event_copy (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf script: Remove some large stack allocations (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf sched: Avoid large stack allocations (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf bench sched messaging: Free contexts on exit (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf bench futex: Avoid memory leaks from pthread_attr
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf bench epoll: Fix missing frees/puts on the exit path
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf help: Ensure clean_cmds is called on all paths (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf cs-etm: Add exception level consistency check (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf cs-etm: Track exception level (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf cs-etm: Make PID format accessible from struct
  cs_etm_auxtrace (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf cs-etm: Use previous thread for branch sample source IP
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf cs-etm: Only track threads instead of PID and TIDs
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf map: Fix double 'struct map' reference free found with
  - DREFCNT_CHECKING=1 (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf srcline: Optimize comparision against SRCLINE_UNKNOWN
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf hist: Fix srcline memory leak (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf srcline: Change free_srcline to zfree_srcline (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf callchain: Use pthread keys for tls callchain_cursor
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf header: Avoid out-of-bounds read (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf top: Add exit routine for main thread (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf annotate: Fix parse_objdump_line memory leak (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf map/maps/thread: Changes to reference counting (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf machine: Don't leak module maps (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf machine: Fix leak of kernel dso (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf maps: Fix overlapping memory leak (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf symbol-elf: Correct holding a reference (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf jit: Fix two thread leaks (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf python: Avoid 2 leak sanitizer issues (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf evlist: Free stats in all evlist destruction (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf intel-pt: Fix missed put and leak (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf stat: Avoid evlist leak (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf header: Ensure bitmaps are freed (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf report: Avoid 'parent_thread' thread leak on '--tasks'
  processing (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf machine: Make delete_threads part of machine__exit
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf thread: Add reference count checking (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- commit 608c758
* Mon Jan 15 2024 tonyj@suse.de
- perf addr_location: Add init/exit/copy functions (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- Refresh
  patches.suse/Revert-perf-report-Append-inlines-to-non-DWARF.patch.
- commit 325f16f
* Mon Jan 15 2024 tonyj@suse.de
- perf addr_location: Move to its own header (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf maps: Make delete static, always use put (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf thread: Add accessor functions for thread (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- commit 5dca2fc
* Mon Jan 15 2024 tonyj@suse.de
- perf thread: Make threads rbtree non-invasive (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- Refresh
  patches.suse/Revert-perf-report-Append-inlines-to-non-DWARF.patch.
- commit 94d9b89
* Mon Jan 15 2024 tonyj@suse.de
- perf thread: Remove notion of dead threads (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test: Add test of libpfm4 events (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf list: Check arguments to show libpfm4 events (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf list: Check if libpfm4 event is supported (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse: Allow config terms with breakpoints (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- tools headers: Make the difference output easier to read
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf annotate: Remove x86 instructions with suffix (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf annotate: Handle x86 instruction suffix generally
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf stat: Document --metric-no-threshold and threshold colors
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf expr: Make the evaluation of & and | logical and lazy
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf LoongArch: Simplify mksyscalltbl (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf arm64: Use max_nr to define SYSCALLTBL_ARM64_MAX_ID
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf arm64: Handle __NR3264_ prefixed syscall number (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf arm64: Rename create_table_from_c() to create_sc_table()
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf tools: Declare syscalltbl_* as const for all archs
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf script: Increase PID/TID width for output (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Warn about invalid config for all PMUs and configs
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Only warn about unsupported formats once (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test: Update parse-events expectations to test for multiple
  events (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Wildcard most "numeric" events (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf evsel: Add verbose 3 print of evsel name when opening
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Correct perf_pmu__auto_merge_stats() affecting hybrid
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf kvm powerpc: Add missing rename opf pmu_have_event() to
  perf_pmus__have_event() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test pmu: Avoid 2 static path arrays (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf scripting-engines: Move static to local variable, remove
  16384 from .bss (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf path: Make mkpath thread safe, remove 16384 bytes from .bss
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf probe: Dynamically allocate params memory (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf timechart: Make large arrays dynamic (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf lock: Dynamically allocate lockhash_table (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf daemon: Dynamically allocate path to perf (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf trace beauty: Make MSR arrays const to move it to
  .data.rel.ro (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf trace: Make some large static arrays const to move it to
  .data.rel.ro (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test x86: intel-pt-test data is immutable so mark it const
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test x86: insn-x86 test data is immutable so mark it const
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf header: Make nodes dynamic in write_mem_topology()
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf evsel: Don't let evsel__group_pmu_name() traverse unsorted
  group (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Remove is_pmu_hybrid (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf pmus: Remove perf_pmus__has_hybrid (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf pmus: Add function to return count of core PMUs (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmus: Ensure all PMUs are read for find_by_type (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmus: Avoid repeated sysfs scanning (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmus: Allow just core PMU scanning (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf pmus: Split pmus list into core and other (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Separate pmu and pmus (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf x86 mem: minor refactor to is_mem_loads_aux_event
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmus: Prefer perf_pmu__scan over perf_pmus__for_each_pmu
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Remove perf_pmu__hybrid_pmus list (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf mem: Avoid hybrid PMU list (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf stat: Avoid hybrid PMU list (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf metrics: Remove perf_pmu__is_hybrid use (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf header: Avoid hybrid PMU list in write_pmu_caps (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf evsel: Compute is_hybrid from PMU being core (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf topology: Avoid hybrid list for hybrid topology (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf x86: Iterate hybrid PMUs as core PMUs (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Rewrite perf_pmu__has_hybrid to avoid list (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Remove perf_pmu__hybrid_mounted (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf evlist: Reduce scope of evlist__has_hybrid (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf evlist: Remove __evlist__add_default (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf evlist: Remove evlist__warn_hybrid_group (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf tools: Warn if no user requested CPUs match PMU's CPUs
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf target: Remove unused hybrid value (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf evlist: Allow has_user_cpus to be set on hybrid (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf evlist: Propagate user CPU maps intersecting core PMU maps
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Add CPU map for "cpu" PMUs (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf evsel: Add is_pmu_core inorder to interpret own_cpus
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf pmu: Add is_core to pmu (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf pmu: Detect ARM and hybrid PMUs with sysfs (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- libperf cpumap: Add "any CPU"/dummy test function (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf cpumap: Add equal function (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf cpumap: Add internal nr and cpu accessors (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test python: Put perf python at start of sys.path
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test: Fix perf stat JSON output test (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf tests: Organize cpu_map tests into a single suite
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf cpumap: Add intersect function (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf vendor events intel: Add metricgroup descriptions for
  all models (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf jevents: Add support for metricgroup descriptions
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- pert tests: Add tests for new "perf stat --per-cache"
  aggregation option (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf stat: Add "--per-cache" aggregation option and document it
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf stat record: Save cache level information (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf stat: Setup the foundation to allow aggregation based on
  cache topology (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf: Extract building cache level for a CPU into separate
  function (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update tigerlake events/metrics
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update snowridgex events (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update skylake/skylakex events/metrics
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update sapphirerapids events/metrics
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update sandybridge metrics (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update jaketown metrics (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update ivybridge/ivytown metrics
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update icelake/icelakex events/metrics
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update haswell(x) metrics (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update elkhartlake events (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update cascadelakex events/metrics
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update broadwell variant
  events/metrics (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Update alderlake events/metrics
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test: Add test validating JSON generated by 'perf data
  convert --to-json' (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events arm64: Add AmpereOne core PMU events
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf ftrace: Flush output after each writing (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf annotate browser: Add '<' and '>' keys for navigation
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf annotate: Parse x86 SIB addressing properly (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf annotate: Handle "decq", "incq", "testq", "tzcnt"
  instructions on x86 (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf doc: Add support for KBUILD_BUILD_TIMESTAMP (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf doc: Define man page date when using asciidoctor (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test: Add cputype testing to perf stat (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf build: Don't use -ftree-loop-distribute-patterns and
  - gno-variable-location-views in the python feature test when
  building with clang-13 (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Reduce scope of is_event_supported (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf stat: Don't disable TopdownL1 metric on hybrid (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf metrics: Be PMU specific in event match (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf jevents: Don't rewrite metrics across PMUs (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Correct alderlake metrics (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf stat: Command line PMU metric filtering (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- commit 462a115
* Mon Jan 15 2024 tonyj@suse.de
- perf metrics: Be PMU specific for referenced metrics (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- Refresh patches.suse/perf-metric-Fix-no-group-check.patch.
- commit 95a6d4b
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Don't reorder atom cpu events (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Don't auto merge hybrid wildcard events
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Avoid error when assigning a legacy cache
  term (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Avoid error when assigning a term (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Support hardware events as terms (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test: Fix parse-events tests for >1 core PMU (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf stat: Make cputype filter generic (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf parse-events: Add pmu filter (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf parse-events: Minor type safety cleanup (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Remove now unused hybrid logic (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Support wildcards on raw events (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf print-events: Print legacy cache events for each PMU
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Wildcard legacy cache events (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Support PMUs for legacy cache events
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test x86 hybrid: Add hybrid extended type checks (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test x86 hybrid: Update test expectations (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test: Move x86 hybrid tests to arch/x86 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Avoid scanning PMUs before parsing (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf print-events: Avoid unnecessary strlist (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Set pmu_name whenever a pmu is given
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf parse-events: Set attr.type to PMU type early (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test: Roundtrip name, don't assume 1 event per name
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf test: Test more with config_cache (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf test: Mask configs with extended types then test (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf test: Use valid for PMU tests (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf test: Test more sysfs events (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf vendor events intel: Add tigerlake metric constraints
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Add sapphirerapids metric constraints
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Add icelakex metric constraints
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Add icelake metric constraints
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf vendor events intel: Add alderlake metric constraints
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf script: Refine printing of dso offset (dsoff) (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf dso: Declare dso const as needed (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
- perf script: Add new output field 'dsoff' to print dso offset
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf map: Add helper map__fprintf_dsoname_dsoff (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- perf tools riscv: Add support for riscv lookup_binutils_path
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf arm-spe: Fix a dangling Documentation/arm64 reference
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- perf/x86/intel: Define bit macros for FixCntrCtl MSR
  (jsc#PED-6012 jsc#PED-6121).
- perf test: Add selftest to test IBS invocation via core pmu
  events (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- commit 9b6e46d
* Sat Jan 13 2024 ailiop@suse.com
- xfs: short circuit xfs_growfs_data_private() if delta is zero
  (git-fixes).
- commit 9cb834b
* Sat Jan 13 2024 ailiop@suse.com
- xfs: update dir3 leaf block metadata after swap (git-fixes).
- commit caef603
* Sat Jan 13 2024 ailiop@suse.com
- xfs: remove unused fields from struct xbtree_ifakeroot
  (git-fixes).
- commit bc03199
* Sat Jan 13 2024 ailiop@suse.com
- xfs: add missing nrext64 inode flag check to scrub (git-fixes).
- commit 57da6fe
* Sat Jan 13 2024 ailiop@suse.com
- xfs: initialise di_crc in xfs_log_dinode (git-fixes).
- commit 5f2ca54
* Sat Jan 13 2024 ailiop@suse.com
- afs: Fix use-after-free due to get/remove race in volume tree
  (git-fixes).
- commit 38f8a72
* Sat Jan 13 2024 ailiop@suse.com
- afs: Fix overwriting of result of DNS query (git-fixes).
- commit 76d3367
* Sat Jan 13 2024 ailiop@suse.com
- afs: Fix dynamic root lookup DNS check (git-fixes).
- commit 5665414
* Sat Jan 13 2024 ailiop@suse.com
- afs: Fix the dynamic root's d_delete to always delete unused
  dentries (git-fixes).
- commit 5416d8e
* Sat Jan 13 2024 ailiop@suse.com
- afs: Fix refcount underflow from error handling race
  (git-fixes).
- commit d515023
* Sat Jan 13 2024 ailiop@suse.com
- gfs2: low-memory forced flush fixes (git-fixes).
- commit 8adbd88
* Sat Jan 13 2024 ailiop@suse.com
- gfs2: Switch to wait_event in gfs2_logd (git-fixes).
- commit 9362810
* Sat Jan 13 2024 ailiop@suse.com
- gfs2: Fix kernel NULL pointer dereference in gfs2_rgrp_dump
  (git-fixes).
- commit 994e6ea
* Sat Jan 13 2024 ailiop@suse.com
- dlm: use kernel_connect() and kernel_bind() (git-fixes).
- commit 50016bf
* Sat Jan 13 2024 tiwai@suse.de
- supported.conf: add missing snd-hda-cirrus-scodec
- commit 3feaf53
* Sat Jan 13 2024 tiwai@suse.de
- Update config files: add missing CONFIG_SND_HDA_CIRRUS_SCODEC=m
- commit f33bdd1
* Sat Jan 13 2024 tiwai@suse.de
- ALSA: hda/tas2781: annotate calibration data endianness
  (git-fixes).
- ALSA: hda/tas2781: add TAS2563 support for 14ARB7 (git-fixes).
- ALSA: hda/tas2781: add configurable global i2c address
  (git-fixes).
- ALSA: hda/tas2781: add ptrs to calibration functions
  (git-fixes).
- ALSA: hda/tas2781: configure the amp after firmware load
  (git-fixes).
- ALSA: hda: cs35l56: Enable low-power hibernation mode on SPI
  (git-fixes).
- ALSA: hda: cs35l56: Enable low-power hibernation mode on i2c
  (git-fixes).
- ALSA: hda: Intel: Fix error handling in azx_probe() (git-fixes).
- ALSA: hda: cs35l56: Add support for speaker id (git-fixes).
- commit bd898ac
* Sat Jan 13 2024 tiwai@suse.de
- ALSA: hda/conexant: Fix headset auto detect fail in cx8070
  and SN6140 (git-fixes).
- ALSA: hda: Intel: add HDA_ARL PCI ID support (git-fixes).
- PCI: add INTEL_HDA_ARL to pci_ids.h (git-fixes).
- commit 52049a6
* Sat Jan 13 2024 tiwai@suse.de
- ALSA: hda: cs35l41: Support more HP models without _DSD
  (git-fixes).
- ALSA: hda/tas2781: add fixup for Lenovo 14ARB7 (git-fixes).
- ALSA: hda: Add driver properties for cs35l41 for Lenovo Legion
  Slim 7 Gen 8 serie (git-fixes).
- ALSA: hda: cs35l41: Prevent firmware load if SPI speed too low
  (git-fixes).
- ALSA: hda: cs35l41: Support additional Dell models without _DSD
  (git-fixes).
- ALSA: hda/cs35l56: Use set/get APIs to access spi->chip_select
  (git-fixes).
- ALSA: hda: cs35l41: fix building without CONFIG_SPI (git-fixes).
- ALSA: hda: cs35l41: Only add SPI CS GPIO if SPI is enabled in
  kernel (git-fixes).
- ALSA: hda: cs35l41: Do not allow uninitialised variables to
  be freed (git-fixes).
- ALSA: hda/realtek: Add quirks for ASUS Zenbook 2023 Models
  (git-fixes).
- ALSA: hda: cs35l41: Support additional ASUS Zenbook 2023 Models
  (git-fixes).
- ALSA: hda/realtek: Add quirks for ASUS Zenbook 2022 Models
  (git-fixes).
- ALSA: hda: cs35l41: Support additional ASUS Zenbook 2022 Models
  (git-fixes).
- ALSA: hda/realtek: Add quirks for ASUS ROG 2023 models
  (git-fixes).
- ALSA: hda: cs35l41: Support additional ASUS ROG 2023 models
  (git-fixes).
- ALSA: hda: cs35l41: Add config table to support many laptops
  without _DSD (git-fixes).
- commit a239730
* Sat Jan 13 2024 tiwai@suse.de
- ALSA: hda/realtek: Fix mute and mic-mute LEDs for HP Envy X360
  13-ay0xxx (git-fixes).
- ALSA: hda/realtek: enable SND_PCI_QUIRK for Lenovo Legion Slim
  7 Gen 8 (2023) serie (git-fixes).
- ALSA: hda/realtek: Add quirks for Dell models (git-fixes).
- commit 30d4186
* Sat Jan 13 2024 tiwai@suse.de
- of: unittest: Fix of_count_phandle_with_args() expected value
  message (git-fixes).
- drm/rockchip: vop2: Avoid use regmap_reinit_cache at runtime
  (git-fixes).
- drm/bridge: nxp-ptn3460: simplify some error checking
  (git-fixes).
- drm/panfrost: Ignore core_mask for poweroff and disable PWRTRANS
  irq (git-fixes).
- commit 443d37c
* Sat Jan 13 2024 tiwai@suse.de
- of: Fix double free in of_parse_phandle_with_args_map
  (git-fixes).
- HID: wacom: Correct behavior when processing some confidence ==
  false touches (git-fixes).
- fbdev: flush deferred IO before closing (git-fixes).
- fbdev: flush deferred work in fb_deferred_io_fsync()
  (git-fixes).
- fbdev: mmp: Fix typo and wording in code comment (git-fixes).
- fbdev: imxfb: fix left margin setting (git-fixes).
- media: docs: uAPI: Fix documentation of 'which' field for
  routing ioctls (git-fixes).
- media: dt-bindings: ov8856: decouple lanes and link frequency
  from driver (git-fixes).
- media: dvb-frontends: m88ds3103: Fix a memory leak in an error
  handling path of m88ds3103_probe() (git-fixes).
- media: dvbdev: drop refcount on error path in dvb_device_open()
  (git-fixes).
- media: rkisp1: Fix media device memory leak (git-fixes).
- media: dt-bindings: media: rkisp1: Fix the port description
  for the parallel interface (git-fixes).
- media: imx-mipi-csis: Fix clock handling in remove()
  (git-fixes).
- media: cx231xx: fix a memleak in cx231xx_init_isoc (git-fixes).
- media: videobuf2-dma-sg: fix vmap callback (git-fixes).
- media: v4l2-subdev: Fix indentation in v4l2-subdev.h
  (git-fixes).
- media: ov9734: Enable runtime PM before registering async
  sub-device (git-fixes).
- media: ov13b10: Enable runtime PM before registering async
  sub-device (git-fixes).
- media: imx355: Enable runtime PM before registering async
  sub-device (git-fixes).
- media: rkvdec: Hook the (TRY_)DECODER_CMD stateless ioctls
  (git-fixes).
- media: verisilicon: Hook the (TRY_)DECODER_CMD stateless ioctls
  (git-fixes).
- media: visl: Hook the (TRY_)DECODER_CMD stateless ioctls
  (git-fixes).
- media: mtk-jpeg: Fix timeout schedule error in
  mtk_jpegdec_worker (git-fixes).
- media: mtk-jpeg: Fix use after free bug due to error path
  handling in mtk_jpeg_dec_device_run (git-fixes).
- media: mtk-jpeg: Remove cancel worker in mtk_jpeg_remove to
  avoid the crash of multi-core JPEG devices (git-fixes).
- media: pvrusb2: fix use after free on context disconnection
  (git-fixes).
- mmc: sdhci_omap: Fix TI SoC dependencies (git-fixes).
- mmc: sdhci_am654: Fix TI SoC dependencies (git-fixes).
- gpio: xilinx: remove excess kernel doc (git-fixes).
- gpio: sysfs: fix forward declaration of struct gpio_device
  (git-fixes).
- watchdog: rti_wdt: Drop runtime pm reference count when watchdog
  is unused (git-fixes).
- watchdog: bcm2835_wdt: Fix WDIOC_SETTIMEOUT handling
  (git-fixes).
- watchdog/hpwdt: Only claim UNKNOWN NMI if from iLO (git-fixes).
- watchdog: set cdev owner before adding (git-fixes).
- kselftest/alsa - conf: Stringify the printed errno in
  sysfs_get() (git-fixes).
- kselftest/alsa - mixer-test: Fix the print format specifier
  warning (git-fixes).
- kselftest/alsa - mixer-test: fix the number of parameters to
  ksft_exit_fail_msg() (git-fixes).
- gpu/drm/radeon: fix two memleaks in radeon_vm_init (git-fixes).
- commit c646735
* Sat Jan 13 2024 tiwai@suse.de
- drivers: clk: zynqmp: update divider round rate logic
  (git-fixes).
- drivers: clk: zynqmp: calculate closest mux rate (git-fixes).
- clk: qcom: gcc-sm8550: Mark RCGs shared where applicable
  (git-fixes).
- clk: qcom: gcc-sm8550: use collapse-voting for PCIe GDSCs
  (git-fixes).
- clk: qcom: gcc-sm8550: Mark the PCIe GDSCs votable (git-fixes).
- clk: qcom: gcc-sm8550: Add the missing RETAIN_FF_ENABLE GDSC
  flag (git-fixes).
- clk: qcom: videocc-sm8150: Add missing PLL config property
  (git-fixes).
- clk: qcom: gpucc-sm8150: Update the gpu_cc_pll1 config
  (git-fixes).
- clk: samsung: Fix kernel-doc comments (git-fixes).
- clk: fixed-rate: fix
  clk_hw_register_fixed_rate_with_accuracy_parent_hw (git-fixes).
- clk: si5341: fix an error code problem in
  si5341_output_clk_set_rate (git-fixes).
- clk: rs9: Fix DIF OEn bit placement on 9FGV0241 (git-fixes).
- clk: sp7021: fix return value check in sp7021_clk_probe()
  (git-fixes).
- ABI: sysfs-class-hwmon: fix tempY_crit_alarm access rights
  (git-fixes).
- ASoC: rt5645: Drop double EF20 entry from dmi_platform_data[]
  (git-fixes).
- ASoC: amd: acp: Add missing MODULE_DESCRIPTION in mach-common
  (git-fixes).
- ASoC: amd: acp-config: Add missing MODULE_DESCRIPTION
  (git-fixes).
- ASoC: amd: vangogh: Drop conflicting ACPI-based probing
  (git-fixes).
- ASoC: tas2781: add support for FW version 0x0503 (git-fixes).
- ASoC: SOF: topology: Use partial match for disconnecting DAI
  link and DAI widget (git-fixes).
- ASoC: Intel: sof_sdw_rt_sdca_jack_common: ctx->headset_codec_dev
  = NULL (git-fixes).
- ASoC: Intel: glk_rt5682_max98357a: fix board id mismatch
  (git-fixes).
- ASoC: cs35l33: Fix GPIO name and drop legacy include
  (git-fixes).
- drm/amd/display: fix bandwidth validation failure on DCN 2.1
  (git-fixes).
- Revert "drm/amdkfd: Relocate TBA/TMA to opposite side of VM
  hole" (git-fixes).
- drm/amd/display: avoid stringop-overflow warnings for
  dp_decide_lane_settings() (git-fixes).
- drm/amd/pm/smu7: fix a memleak in smu7_hwmgr_backend_init
  (git-fixes).
- drm/amdkfd: Confirm list is non-empty before utilizing
  list_first_entry in kfd_topology.c (git-fixes).
- drm/amdkfd: Fix type of 'dbg_flags' in 'struct kfd_process'
  (git-fixes).
- accel/habanalabs: fix information leak in sec_attest_info()
  (git-fixes).
- drm/mediatek: dp: Add phy_mtk_dp module as pre-dependency
  (git-fixes).
- drm/mediatek: Fix underrun in VDO1 when switches off the layer
  (git-fixes).
- drm/mediatek: Remove the redundant driver data for DPI
  (git-fixes).
- drm/mediatek: Return error if MDP RDMA failed to enable the
  clock (git-fixes).
- drm/msm/dpu: Drop enable and frame_count parameters from
  dpu_hw_setup_misr() (git-fixes).
- drm/msm/dpu: Set input_sel bit for INTF (git-fixes).
- drm/msm/dpu: rename dpu_encoder_phys_wb_setup_cdp to match
  its functionality (git-fixes).
- drm/msm/adreno: Fix A680 chip id (git-fixes).
- drm/msm/dpu: correct clk bit for WB2 block (git-fixes).
- drm/msm/dsi: Use pm_runtime_resume_and_get to prevent refcnt
  leaks (git-fixes).
- drm/msm/dpu: Add missing safe_lut_tbl in sc8180x catalog
  (git-fixes).
- drm/msm/mdp4: flush vblank event on disable (git-fixes).
- drm/amd/pm: fix a double-free in
  amdgpu_parse_extended_power_table (git-fixes).
- drivers/amd/pm: fix a use-after-free in kv_parse_power_table
  (git-fixes).
- drm/amd/pm: fix a double-free in si_dpm_init (git-fixes).
- drm/amdgpu/debugfs: fix error code when smc register accessors
  are NULL (git-fixes).
- Revert "drm/rockchip: vop2: Use regcache_sync() to fix
  suspend/resume" (git-fixes).
- drm/panel: st7701: Fix AVCL calculation (git-fixes).
- drm/radeon/trinity_dpm: fix a memleak in
  trinity_parse_power_table (git-fixes).
- drm/radeon/dpm: fix a memleak in sumo_parse_power_table
  (git-fixes).
- drm/radeon: check the alloc_workqueue return value in
  radeon_crtc_init() (git-fixes).
- drm/bridge: tc358767: Fix return value on error case
  (git-fixes).
- drm/bridge: cdns-mhdp8546: Fix use of uninitialized variable
  (git-fixes).
- drm: Fix TODO list mentioning non-KMS drivers (git-fixes).
- drm/bridge: nxp-ptn3460: fix i2c_master_send() error checking
  (git-fixes).
- drm/drv: propagate errors from drm_modeset_register_all()
  (git-fixes).
- drm/imx/lcdc: Fix double-free of driver data (git-fixes).
- drm/tidss: Fix atomic_flush check (git-fixes).
- fbdev/acornfb: Fix name of fb_ops initializer macro (git-fixes).
- drm/bridge: Fix typo in post_disable() description (git-fixes).
- drm/virtio: Disable damage clipping if FB changed since last
  page-flip (git-fixes).
- drm: Allow drivers to indicate the damage helpers to ignore
  damage clips (git-fixes).
- drm: Disable the cursor plane on atomic contexts with
  virtualized drivers (git-fixes).
- drm/radeon: check return value of radeon_ring_lock()
  (git-fixes).
- drm/radeon/r100: Fix integer overflow issues in
  r100_cs_track_check() (git-fixes).
- drm/radeon/r600_cs: Fix possible int overflows in
  r600_cs_check_reg() (git-fixes).
- drm/tilcdc: Fix irq free on unload (git-fixes).
- drm/bridge: tpd12s015: Drop buggy __exit annotation for remove
  function (git-fixes).
- drm/nouveau/fence:: fix warning directly dereferencing a rcu
  pointer (git-fixes).
- drm/panel-elida-kd35t133: hold panel in reset for unprepare
  (git-fixes).
- drm/panel: nv3051d: Hold panel in reset for unprepare
  (git-fixes).
- drm/panfrost: Really power off GPU cores in
  panfrost_gpu_power_off() (git-fixes).
- drm/panel: nt35510: fix typo (git-fixes).
- Revert "drm/omapdrm: Annotate dma-fence critical section in
  commit path" (git-fixes).
- Revert "drm/tidss: Annotate dma-fence critical section in
  commit path" (git-fixes).
- commit 3228adc
* Fri Jan 12 2024 msuchanek@suse.de
- powerpc/smp: Dynamically build Powerpc topology (jsc#PED-7581).
- powerpc/smp: Avoid asym packing within thread_group of a core
  (jsc#PED-7581).
- powerpc/smp: Add __ro_after_init attribute (jsc#PED-7581).
- powerpc/smp: Disable MC domain for shared processor
  (jsc#PED-7581).
- powerpc/smp: Enable Asym packing for cores on shared processor
  (jsc#PED-7581).
- powerpc/paravirt: Improve vcpu_is_preempted (jsc#PED-7581).
- sched/topology: Rename 'DIE' domain to 'PKG' (jsc#PED-7581).
- commit efa591d
* Fri Jan 12 2024 tbogendoerfer@suse.de
- Update config files.
- supported.conf: marked chelsio driver before T4 unsupported
  Disabled Chelsio drivers before T4 (jsc#PED-964 jsc#SLE-4137)
- commit 5bf6fea
* Fri Jan 12 2024 tbogendoerfer@suse.de
- Update config files.
- supported.conf: marked bna unsupported
  Disabled BNA ethernet driver (jsc#PED-964)
- commit 7865de2
* Fri Jan 12 2024 tbogendoerfer@suse.de
- Update config files.
- supported.conf: marked qlge unspported
  Disable QLGE ethernet driver (jsc#PED-964)
- commit 98af955
* Fri Jan 12 2024 ailiop@suse.com
- xfs: remove CPU hotplug infrastructure (bsc#1218753).
- commit a033740
* Fri Jan 12 2024 ailiop@suse.com
- xfs: remove the all-mounts list (bsc#1218753).
- commit 0a0f7e2
* Fri Jan 12 2024 tiwai@suse.de
- Drop kasan fix that broke the build on ALP-current branch
- commit 57aea3a
* Fri Jan 12 2024 tiwai@suse.de
- Update patch reference for rose fix (CVE-2023-51782 bsc#1218757)
- commit bf72188
* Fri Jan 12 2024 tiwai@suse.de
- ring-buffer/Documentation: Add documentation on buffer_percent
  file (git-fixes).
- kernel-doc: handle a void function without producing a warning
  (git-fixes).
- scripts/kernel-doc: restore warning for Excess struct/union
  (git-fixes).
- dma-mapping: clear dev->dma_mem to NULL after freeing it
  (git-fixes).
- ARM: davinci: always select CONFIG_CPU_ARM926T (git-fixes).
- soc: qcom: llcc: Fix LLCC_TRP_ATTR2_CFGn offset (git-fixes).
- soc: qcom: llcc: Fix dis_cap_alloc and retain_on_pc
  configuration (git-fixes).
- soc: qcom: pmic_glink_altmode: fix port sanity check
  (git-fixes).
- firmware: ti_sci: Fix an off-by-one in ti_sci_debugfs_create()
  (git-fixes).
- soc: fsl: cpm1: qmc: Remove inline function specifiers
  (git-fixes).
- soc: fsl: cpm1: qmc: Fix rx channel reset (git-fixes).
- soc: fsl: cpm1: qmc: Fix __iomem addresses declaration
  (git-fixes).
- soc: fsl: cpm1: tsa: Fix __iomem addresses declaration
  (git-fixes).
- wifi: cfg80211: parse all ML elements in an ML probe response
  (git-fixes).
- wifi: cfg80211: correct comment about MLD ID (git-fixes).
- Bluetooth: Fix atomicity violation in {min,max}_key_size_set
  (git-fixes).
- Bluetooth: btmtkuart: fix recv_buf() return value (git-fixes).
- Bluetooth: btnxpuart: fix recv_buf() return value (git-fixes).
- Bluetooth: Fix bogus check for re-auth no supported with non-ssp
  (git-fixes).
- wifi: iwlwifi: assign phy_ctxt before eSR activation
  (git-fixes).
- wifi: iwlwifi: fix out of bound copy_from_user (git-fixes).
- wifi: iwlwifi: mvm: send TX path flush in rfkill (git-fixes).
- wifi: iwlwifi: mvm: set siso/mimo chains to 1 in FW SMPS request
  (git-fixes).
- wifi: ath11k: Defer on rproc_get failure (git-fixes).
- wifi: mwifiex: configure BSSID consistently when starting AP
  (git-fixes).
- wifi: mt76: mt7921: fix country count limitation for CLC
  (git-fixes).
- wifi: mt76: mt7921s: fix workqueue problem causes STA
  association fail (git-fixes).
- wifi: mt76: mt7996: fix rate usage of inband discovery frames
  (git-fixes).
- wifi: mt76: mt7996: fix the size of struct bss_rate_tlv
  (git-fixes).
- wifi: mt76: mt7915: fallback to non-wed mode if
  platform_get_resource fails in mt7915_mmio_wed_init()
  (git-fixes).
- wifi: mt76: fix broken precal loading from MTD for mt7915
  (git-fixes).
- wifi: iwlwifi: don't support triggered EHT CQI feedback
  (git-fixes).
- wifi: rtlwifi: Convert LNKCTL change to PCIe cap RMW accessors
  (git-fixes).
- wifi: rtlwifi: Remove bogus and dangerous ASPM disable/enable
  code (git-fixes).
- wifi: rtw88: sdio: Honor the host max_req_size in the RX path
  (git-fixes).
- wifi: rtlwifi: rtl8821ae: phy: fix an undefined bitwise shift
  behavior (git-fixes).
- selftests/net: fix grep checking for fib_nexthop_multiprefix
  (git-fixes).
- selftests/net: specify the interface when do arping (git-fixes).
- wifi: libertas: stop selecting wext (git-fixes).
- wifi: rtw88: fix RX filter in FIF_ALLMULTI flag (git-fixes).
- wifi: plfxlc: check for allocation failure in
  plfxlc_usb_wreq_async() (git-fixes).
- commit 2c42655
* Thu Jan 11 2024 tiwai@suse.de
- arm64: errata: Add Cortex-A520 speculative unprivileged load
  workaround (git-fixes).
- Update config files.
- commit 73e6623
* Thu Jan 11 2024 tiwai@suse.de
- Refresh patches.suse/media-mediatek-vcodec-remove-the-dependency-of-vcode.patch
  Fix compile warning due to trailing spaces
- commit 3d15652
* Thu Jan 11 2024 tiwai@suse.de
- wifi: mac80211: do not pass AP_VLAN vif pointer to drivers
  during flush (git-fixes).
- commit 27184e7
* Thu Jan 11 2024 tiwai@suse.de
- wifi: cfg80211: fix cqm_config access race (git-fixes).
- commit 006357c
* Thu Jan 11 2024 tiwai@suse.de
- wifi: ath11k: fix boot failure with one MSI vector (git-fixes).
- commit affc905
* Thu Jan 11 2024 tiwai@suse.de
- serial: 8250_omap: Add earlycon support for the AM654 UART
  controller (git-fixes).
- powercap: DTPM: Fix missing cpufreq_cpu_put() calls (git-fixes).
- powercap: DTPM: Fix unneeded conversions to micro-Watts
  (git-fixes).
- commit 9e04295
* Thu Jan 11 2024 tiwai@suse.de
- kasan: use unchecked __memset internally (git-fixes).
- kasan: print the original fault addr when access invalid shadow
  (git-fixes).
- commit 4dd0ace
* Thu Jan 11 2024 tiwai@suse.de
- crypto: sahara - handle zero-length aes requests (git-fixes).
- commit 830e401
* Thu Jan 11 2024 tiwai@suse.de
- net: 9p: avoid freeing uninit memory in p9pdu_vreadf
  (git-fixes).
- arm64: Add Cortex-A520 CPU part definition (git-fixes).
- commit d8e3e86
* Thu Jan 11 2024 tiwai@suse.de
- crypto: virtio - Wait for tasklet to complete on device remove
  (git-fixes).
- commit 3bcb20e
* Thu Jan 11 2024 tiwai@suse.de
- crypto: scomp - fix req->dst buffer overflow (git-fixes).
- crypto: sahara - do not resize req->src when doing hash
  operations (git-fixes).
- crypto: sahara - fix processing hash requests with req->nbytes <
  sg->length (git-fixes).
- crypto: sahara - improve error handling in sahara_sha_process()
  (git-fixes).
- crypto: sahara - fix wait_for_completion_timeout() error
  handling (git-fixes).
- crypto: sahara - fix ahash reqsize (git-fixes).
- crypto: shash - remove excess kerneldoc members (git-fixes).
- crypto: s390/aes - Fix buffer overread in CTR mode (git-fixes).
- crypto: hisilicon/qm - save capability registers in qm init
  process (git-fixes).
- crypto: sahara - fix error handling in
  sahara_hw_descriptor_create() (git-fixes).
- crypto: sahara - fix processing requests with cryptlen <
  sg->length (git-fixes).
- crypto: sahara - fix ahash selftest failure (git-fixes).
- crypto: sahara - fix cbc selftest failure (git-fixes).
- crypto: sahara - remove FLAGS_NEW_KEY logic (git-fixes).
- crypto: safexcel - Add error handling for dma_map_sg() calls
  (git-fixes).
- crypto: ccp - fix memleak in ccp_init_dm_workarea (git-fixes).
- crypto: sa2ul - Return crypto_aead_setkey to transfer the error
  (git-fixes).
- crypto: virtio - Handle dataq logic with tasklet (git-fixes).
- commit 7a91e6a
* Thu Jan 11 2024 msuchanek@suse.de
- powerpc/ftrace: Fix stack teardown in ftrace_no_trace
  (bsc#1215199).
- KVM: PPC: Book3S HV: Fix KVM_RUN clobbering FP/VEC user
  registers (bsc#1215199).
- powerpc: Hide empty pt_regs at base of the stack (bsc#1215199).
- commit 7a81658
* Thu Jan 11 2024 msuchanek@suse.de
- kexec: fix KEXEC_FILE dependencies (jsc#PED-5077 git-fixes).
- Update config files.
- commit 4b1ebff
* Thu Jan 11 2024 msuchanek@suse.de
- powerpc/powernv: Add a null pointer check to
  scom_debug_init_one() (bsc#1194869).
- powerpc/pseries: fix potential memory leak in
  init_cpu_associativity() (bsc#1194869).
- powerpc/xive: Fix endian conversion size (bsc#1194869).
- powerpc/fadump: reset dump area size if fadump memory reserve
  fails (bsc#1194869).
- powerpc/pseries: fix possible memory leak in ibmebus_bus_init()
  (bsc#1194869).
- commit fcc1a42
* Thu Jan 11 2024 msuchanek@suse.de
- powerpc/pseries/iommu: enable_ddw incorrectly returns direct
  mapping for SR-IOV device (bsc#1212091 ltc#199106 git-fixes).
- commit 9b92407
* Thu Jan 11 2024 msuchanek@suse.de
- powerpc/powernv: Add a null pointer check in
  opal_powercap_init() (bsc#1181674 ltc#189159 git-fixes).
- powerpc/powernv: Add a null pointer check in opal_event_init()
  (bsc#1065729).
- powerpc/pseries/memhp: Fix access beyond end of drmem array
  (bsc#1065729).
- commit 9639ea1
* Thu Jan 11 2024 lhenriques@suse.de
- fuse: dax: set fc->dax to NULL in fuse_dax_conn_free()
  (bsc#1218727).
- fuse: share lookup state between submount and its parent
  (bsc#1218726).
- commit 9d825b4
* Thu Jan 11 2024 duwe@suse.de
- crypto: qat - add NULL pointer check (git-fixes).
- crypto: qat - fix mutex ordering in adf_rl (git-fixes).
- crypto: qat - fix error path in add_update_sla() (git-fixes).
- crypto: qat - add sysfs_added flag for rate limiting
  (git-fixes).
- crypto: qat - add sysfs_added flag for ras (git-fixes).
- crypto: qat - prevent underflow in rp2srv_store() (git-fixes).
- commit 5134eb8
* Thu Jan 11 2024 iivanov@suse.de
- ACPI: arm64: export acpi_arch_thermal_cpufreq_pctg() (bsc#1214377)
- commit c6bcd6a
* Thu Jan 11 2024 iivanov@suse.de
- ACPI: processor: reduce CPUFREQ thermal reduction pctg for Tegra241 (bsc#1214377)
- commit e222f81
* Thu Jan 11 2024 iivanov@suse.de
- ACPI: thermal: Add Thermal fast Sampling Period (_TFP) support (bsc#1214377)
- commit 2b1eb2d
* Thu Jan 11 2024 mfranc@suse.cz
- s390/kasan: avoid short by one page shadow memory (git-fixes
  bsc#1218721).
- commit b716fcb
* Thu Jan 11 2024 mfranc@suse.cz
- s390/kasan: handle DCSS mapping in memory holes (git-fixes
  bsc#1218721).
- commit fbbd3ff
* Thu Jan 11 2024 mfranc@suse.cz
- s390/vfio-ap: unpin pages on gisc registration failure
  (git-fixes bsc#1218720).
- commit d53827d
* Thu Jan 11 2024 tiwai@suse.de
- Delete rpm/old_changelog.txt: irrelevant fo ALP-current branch
- commit 8fb755d
* Thu Jan 11 2024 tiwai@suse.de
- hwrng: core - Fix page fault dead lock on mmap-ed hwrng
  (git-fixes).
- pstore: ram_core: fix possible overflow in
  persistent_ram_init_ecc() (git-fixes).
- firewire: ohci: suppress unexpected system reboot in AMD Ryzen
  machines and ASM108x/VT630x PCIe cards (git-fixes).
- mmc: core: Cancel delayed work before releasing host
  (git-fixes).
- drm/amdgpu: skip gpu_info fw loading on navi12 (git-fixes).
- drm/amd/display: add nv12 bounding box (git-fixes).
- drm/amd/display: pbn_div need be updated for hotplug event
  (git-fixes).
- drm/amd/display: Increase frame warning limit with KASAN or
  KCSAN in dml (git-fixes).
- drm/amd/display: Increase num voltage states to 40 (git-fixes).
- media: qcom: camss: Comment CSID dt_id field (git-fixes).
- commit 322c8e9
* Thu Jan 11 2024 tiwai@suse.de
- rpm/old_changelog.txt: create the truncated changelog entries (bsc#1218713)
- commit 332be9f
* Thu Jan 11 2024 tiwai@suse.de
- Store the old kernel changelog entries in kernel-docs package (bsc#1218713)
  The old entries are found in kernel-docs/old_changelog.txt in docdir.
  rpm/old_changelog.txt can be an optional file that stores the similar
  info like rpm/kernel-sources.changes.old.  It can specify the commit
  range that have been truncated.  scripts/tar-up.sh expands from the
  git log accordingly.
- commit c9a2566
* Wed Jan 10 2024 msuchanek@suse.de
- powerpc: qspinlock: Enforce qnode writes prior to publishing
  to queue (bsc#1218636 ltc#204570).
- commit bfa52fa
* Wed Jan 10 2024 msuchanek@suse.de
- powerpc/qspinlock: Rename yield_propagate_owner tunable
  (bsc#1218636 ltc#204570).
- powerpc/qspinlock: Propagate sleepy if previous waiter is
  preempted (bsc#1218636 ltc#204570).
- powerpc/qspinlock: don't propagate the not-sleepy state
  (bsc#1218636 ltc#204570).
- powerpc/qspinlock: propagate owner preemptedness rather than
  CPU number (bsc#1218636 ltc#204570).
- powerpc/qspinlock: stop queued waiters trying to set lock sleepy
  (bsc#1218636 ltc#204570).
- powerpc: qspinlock: Mark accesses to qnode lock checks
  (bsc#1218636 ltc#204570).
- commit 3465c10
* Wed Jan 10 2024 pmladek@kunlun.suse.cz
- Refresh patches.suse/vsprintf-kallsyms-Prevent-invalid-data-when-printing.patch. Fix build warning by moving static_assert().
- commit 4960f65
* Wed Jan 10 2024 oneukum@suse.com
- media: mediatek: vcodec: remove the dependency of vcodec debug
  log (git-fixes).
- commit 209f340
* Wed Jan 10 2024 oneukum@suse.com
- media: mediatek: vcodec: Removing struct 'mtk_vcodec_ctx/dev'
  for shared interface (git-fixes).
- Refresh
  patches.suse/media-mediatek-vcodec-Removing-useless-debug-log.patch.
- commit 595721b
* Wed Jan 10 2024 lhruska@suse.cz
- livepatch: Add sample livepatch module (bsc#1218644).
- commit 87a7c27
* Wed Jan 10 2024 lhruska@suse.cz
- kbuild/modpost: integrate klp-convert (bsc#1218644).
- commit 1f6875e
* Wed Jan 10 2024 lhruska@suse.cz
- livepatch: Add klp-convert tool (bsc#1218644).
- commit dd2884f
* Wed Jan 10 2024 lhruska@suse.cz
- livepatch: Create and include UAPI headers (bsc#1218644).
- commit d3771a8
* Wed Jan 10 2024 nik.borisov@suse.com
- platform/x86/intel/ifs: ARRAY BIST for Sierra Forest (jsc#PED-6127).
- commit 9c38930
* Wed Jan 10 2024 nik.borisov@suse.com
- platform/x86/intel/ifs: Add new error code (jsc#PED-6127).
- commit af0a052
* Wed Jan 10 2024 nik.borisov@suse.com
- platform/x86/intel/ifs: Add new CPU support (jsc#PED-6127).
- commit 0e0dc7c
* Wed Jan 10 2024 nik.borisov@suse.com
- platform/x86/intel/ifs: Metadata validation for start_chunk (jsc#PED-6127).
- commit 2652260
* Wed Jan 10 2024 nik.borisov@suse.com
- platform/x86/intel/ifs: Validate image size (jsc#PED-6127).
- commit 35af862
* Wed Jan 10 2024 nik.borisov@suse.com
- platform/x86/intel/ifs: Gen2 Scan test support (jsc#PED-6127).
- commit e25bc6a
* Wed Jan 10 2024 nik.borisov@suse.com
- platform/x86/intel/ifs: Gen2 scan image loading (jsc#PED-6127).
- commit f76f8b9
* Wed Jan 10 2024 nik.borisov@suse.com
- platform/x86/intel/ifs: Refactor image loading code (jsc#PED-6127).
- commit 3f1b68f
* Wed Jan 10 2024 nik.borisov@suse.com
- platform/x86/intel/ifs: Store IFS generation number (jsc#PED-6127).
- commit 3429838
* Wed Jan 10 2024 tiwai@suse.de
- Move upstreamed perf and powerpc patches into sorted section
- commit ab87600
* Wed Jan 10 2024 tiwai@suse.de
- kunit: debugfs: Fix unchecked dereference in
  debugfs_print_results() (git-fixes).
- ipmi: Use regspacings passed as a module parameter (git-fixes).
- platform/x86/intel/vsec: Fix xa_alloc memory leak (git-fixes).
- PM: hibernate: Enforce ordering during image
  compression/decompression (git-fixes).
- PM / devfreq: Fix buffer overflow in trans_stat_show
  (git-fixes).
- dt-bindings: thermal: qcom-spmi-adc-tm5/hc: Fix example node
  names (git-fixes).
- thermal: core: Fix NULL pointer dereference in zone registration
  error path (git-fixes).
- ACPI: LPSS: Fix the fractional clock divider flags (git-fixes).
- ACPI: extlog: Clear Extended Error Log status when RAS_CEC
  handled the error (git-fixes).
- ACPI: video: check for error while searching for backlight
  device parent (git-fixes).
- ACPI: LPIT: Avoid u32 multiplication overflow (git-fixes).
- mtd: rawnand: rockchip: Add missing title to a kernel doc
  comment (git-fixes).
- mtd: rawnand: rockchip: Rename a structure (git-fixes).
- mtd: rawnand: pl353: Fix kernel doc (git-fixes).
- mtd: rawnand: Increment IFC_TIMEOUT_MSECS for nand controller
  response (git-fixes).
- mtd: rawnand: Clarify conditions to enable continuous reads
  (git-fixes).
- mtd: rawnand: Prevent sequential reads with on-die ECC engines
  (git-fixes).
- mtd: rawnand: Fix core interference with sequential reads
  (git-fixes).
- mtd: rawnand: Prevent crossing LUN boundaries during sequential
  reads (git-fixes).
- mtd: Fix gluebi NULL pointer dereference caused by ftl notifier
  (git-fixes).
- spi: spi-zynqmp-gqspi: fix driver kconfig dependencies
  (git-fixes).
- KEYS: encrypted: Add check for strsep (git-fixes).
- selinux: Fix error priority for bind with AF_UNSPEC on PF_INET6
  socket (git-fixes).
- selinux: remove the wrong comment about multithreaded process
  handling (git-fixes).
- usr/Kconfig: fix typos of "its" (git-fixes).
- usb: fsl-mph-dr-of: mark fsl_usb2_mpc5121_init() static
  (git-fixes).
- selftests/mm: dont run ksm_functional_tests twice (git-fixes).
- commit 753d79e
* Tue Jan  9 2024 krisman@suse.de
- io_uring/poll: don't enable lazy wake for POLLEXCLUSIVE
  (bsc#1218447).
- commit 6e78ef6
* Tue Jan  9 2024 lduncan@suse.com
- scsi: mpi3mr: Update driver version to 8.5.1.0.0 (bsc#1218003).
- scsi: mpi3mr: Support for preallocation of SGL BSG data buffers
  part-3 (bsc#1218003).
- scsi: mpi3mr: Support for preallocation of SGL BSG data buffers
  part-2 (bsc#1218003).
- scsi: mpi3mr: Support for preallocation of SGL BSG data buffers
  part-1 (bsc#1218003).
- scsi: mpi3mr: Fetch correct device dev handle for status reply
  descriptor (bsc#1218003).
- scsi: mpi3mr: Block PEL Enable Command on Controller Reset
  and Unrecoverable State (bsc#1218003).
- scsi: mpi3mr: Clean up block devices post controller reset
  (bsc#1218003).
- scsi: mpi3mr: Refresh sdev queue depth after controller reset
  (bsc#1218003).
- scsi: mpi3mr: driver version upgrade to 8.5.0.0.50
  (bsc#1218003).
- scsi: mpi3mr: Add support for status reply descriptor
  (bsc#1218003).
- scsi: mpi3mr: Increase maximum number of PHYs to 64 from 32
  (bsc#1218003).
- scsi: mpi3mr: Add PCI checks where SAS5116 diverges from SAS4116
  (bsc#1218003).
- scsi: mpi3mr: Add support for SAS5116 PCI IDs (bsc#1218003).
- scsi: mpi3mr: Split off bus_reset function from host_reset
  (bsc#1218003).
- commit 0caa83b
* Tue Jan  9 2024 krisman@suse.de
- io_uring/af_unix: disable sending io_uring over sockets
  (bsc#1218447 CVE-2023-6531).
- io_uring/kbuf: check for buffer list readiness after NULL check
  (bsc#1215211).
- io_uring/kbuf: Fix an NULL vs IS_ERR() bug in
  io_alloc_pbuf_ring() (bsc#1215211).
- io_uring: fix mutex_unlock with unreferenced ctx (bsc#1215211).
- io_uring: use fget/fput consistently (bsc#1215211).
- io_uring: free io_buffer_list entries via RCU (bsc#1215211).
- io_uring/kbuf: prune deferred locked cache when tearing down
  (bsc#1215211).
- io_uring/kbuf: recycle freed mapped buffer ring entries
  (bsc#1215211).
- io_uring/kbuf: defer release of mapped buffer rings
  (bsc#1215211).
- io_uring: enable io_mem_alloc/free to be used in other parts
  (bsc#1215211).
- io_uring: don't guard IORING_OFF_PBUF_RING with SETUP_NO_MMAP
  (bsc#1215211).
- io_uring: don't allow discontig pages for IORING_SETUP_NO_MMAP
  (bsc#1215211).
- io_uring/fs: consider link->flags when getting path for LINKAT
  (bsc#1215211).
- io_uring/fdinfo: remove need for sqpoll lock for thread/pid
  retrieval (bsc#1215211).
- io_uring: do not clamp read length for multishot read
  (bsc#1215211).
- io_uring: do not allow multishot read to set addr or len
  (bsc#1215211).
- io_uring: indicate if io_kbuf_recycle did recycle anything
  (bsc#1215211).
- io_uring/rw: add separate prep handler for fixed read/write
  (bsc#1215211).
- io_uring/rw: add separate prep handler for readv/writev
  (bsc#1215211).
- io_uring/net: ensure socket is marked connected on connect retry
  (bsc#1215211).
- io_uring/rw: don't attempt to allocate async data if opcode
  doesn't need it (bsc#1215211).
- io_uring/cmd: Pass compat mode in issue_flags (bsc#1215211).
- io_uring/poll: use IOU_F_TWQ_LAZY_WAKE for wakeups
  (bsc#1215211).
- commit e405062
* Tue Jan  9 2024 krisman@suse.de
- io_uring: cancelable uring_cmd (bsc#1215211).
- io_uring: retain top 8bits of uring_cmd flags for kernel
  internal use (bsc#1215211).
- io_uring/rw: add support for IORING_OP_READ_MULTISHOT
  (bsc#1215211).
- io_uring/rw: mark readv/writev as vectored in the opcode
  definition (bsc#1215211).
- io_uring/rw: split io_read() into a helper (bsc#1215211).
- commit ccfbdcd
* Tue Jan  9 2024 oneukum@suse.com
- media: v4l2-ctrls: Add user control base for Nuvoton NPCM
  controls (git-fixes).
- commit 0968627
* Tue Jan  9 2024 oneukum@suse.com
- media: mediatek: vcodec: Fix potential crash in
  mtk_vcodec_dbgfs_remove() (git-fixes).
- media: platform: mdp3: mark OF related data as maybe unused
  (git-fixes).
- commit 400939c
* Tue Jan  9 2024 oneukum@suse.com
- media: platform: mdp3: drop of_match_ptr for ID table
  (git-fixes).
- commit fc34f11
* Tue Jan  9 2024 oneukum@suse.com
- media: mediatek: vcodec: Consider vdecsys presence in reg
  range check (git-fixes).
- commit fa96941
* Tue Jan  9 2024 oneukum@suse.com
- media: mediatek: vcodec: fix cancel_work_sync fail with fluster
  test (git-fixes).
- Refresh
  patches.suse/media-mediatek-vcodec-fix-potential-double-free.patch.
- commit 260b764
* Tue Jan  9 2024 oneukum@suse.com
- media: mediatek: vpu: add missing clk_unprepare (git-fixes).
- commit 3048ea2
* Tue Jan  9 2024 oneukum@suse.com
- media: mediatek: vcodec: using empty lat buffer as the last one
  (git-fixes).
- commit 09568ec
* Tue Jan  9 2024 oneukum@suse.com
- media: mediatek: vcodec: Avoid unneeded error logging
  (git-fixes).
- commit 4f48ca0
* Tue Jan  9 2024 nik.borisov@suse.com
- x86/virt/tdx: Make TDX host depend on X86_MCE (jsc#PED-5824).
- commit 9ee9d54
* Tue Jan  9 2024 tiwai@suse.de
- arm64: properly install vmlinuz.efi (git-fixes).
- EDAC/thunderx: Fix possible out-of-bounds string access
  (git-fixes).
- userns: eliminate many kernel-doc warnings (git-fixes).
- commit 78c52da
* Tue Jan  9 2024 oneukum@suse.com
- media: Add common header file with JPEG marker definitions
  (git-fixes).
- commit 6090b39
* Tue Jan  9 2024 oneukum@suse.com
- media: mediatek: vcodec: mtk_vcodec_dec_hw: Use
  devm_pm_runtime_enable() (git-fixes).
- commit 64717c3
* Tue Jan  9 2024 tbogendoerfer@suse.de
- igc: Fix hicredit calculation (jsc#PED-4860).
- ice: fix Get link status data length (jsc#PED-4876).
- i40e: Restore VF MSI-X state during PCI reset (jsc#PED-4874).
- i40e: fix use-after-free in i40e_aqc_add_filters()
  (jsc#PED-4874).
- bnxt_en: Remove mis-applied code from bnxt_cfg_ntp_filters()
  (jsc#PED-5742).
- octeontx2-af: Re-enable MAC TX in otx2_stop processing
  (jsc#PED-6931).
- octeontx2-af: Always configure NIX TX link credits based on
  max frame size (jsc#PED-6931).
- igc: Check VLAN EtherType mask (jsc#PED-4860).
- igc: Check VLAN TCI mask (jsc#PED-4860).
- igc: Report VLAN EtherType matching back to user (jsc#PED-4860).
- i40e: Fix filter input checks to prevent config with invalid
  values (jsc#PED-4874).
- ice: dpll: fix phase offset value (jsc#PED-4876).
- ice: Shut down VSI with "link-down-on-close" enabled
  (jsc#PED-4876).
- ice: Fix link_down_on_close message (jsc#PED-4876).
- idpf: avoid compiler introduced padding in virtchnl2_rss_key
  struct (jsc#PED-6716).
- idpf: fix corrupted frames and skb leaks in singleq mode
  (jsc#PED-6716).
- sfc: fix a double-free bug in efx_probe_filters (jsc#PED-6894).
- mlxbf_gige: fix receive packet race condition (jsc#PED-6866).
- octeontx2-af: Fix marking couple of structure as __packed
  (jsc#PED-6931).
- net: ethernet: mellanox: Convert to platform remove callback
  returning void (jsc#PED-6866).
- mlxbf_gige: Remove two unused function declarations
  (jsc#PED-6866).
- commit 635e530
* Tue Jan  9 2024 oneukum@suse.com
- media: uapi: HEVC: Add num_delta_pocs_of_ref_rps_idx field
  (git-fixes).
- commit 1bae51c
* Tue Jan  9 2024 msuchanek@suse.de
- Add missing package description to align with other branches
- commit a39325c
* Tue Jan  9 2024 nik.borisov@suse.com
- x86/virt/tdx: Disable TDX host support when kexec is enabled (jsc#PED-5824).
- commit 4a81389
* Tue Jan  9 2024 nik.borisov@suse.com
- Documentation/x86: Add documentation for TDX host support (jsc#PED-5824).
- commit f287a95
* Tue Jan  9 2024 nik.borisov@suse.com
- x86/mce: Differentiate real hardware #MCs from TDX erratum ones (jsc#PED-5824).
- commit 782309c
* Tue Jan  9 2024 nik.borisov@suse.com
- x86/cpu: Detect TDX partial write machine check erratum (jsc#PED-5824).
- commit 4131296
* Tue Jan  9 2024 nik.borisov@suse.com
- x86/virt/tdx: Handle TDX interaction with sleep and hibernation (jsc#PED-5824).
- commit c58086d
* Tue Jan  9 2024 nik.borisov@suse.com
- x86/virt/tdx: Initialize all TDMRs (jsc#PED-5824).
- commit 7075173
* Tue Jan  9 2024 nik.borisov@suse.com
- x86/virt/tdx: Configure global KeyID on all packages (jsc#PED-5824).
- commit 769e6e6
* Tue Jan  9 2024 nik.borisov@suse.com
- x86/virt/tdx: Configure TDX module with the TDMRs and global KeyID (jsc#PED-5824).
- commit e2262c3
* Tue Jan  9 2024 nik.borisov@suse.com
- x86/virt/tdx: Designate reserved areas for all TDMRs (jsc#PED-5824).
- commit 50d43e1
* Tue Jan  9 2024 nik.borisov@suse.com
- x86/virt/tdx: Allocate and set up PAMTs for TDMRs (jsc#PED-5824).
- commit 5d2d43b
* Tue Jan  9 2024 nik.borisov@suse.com
- x86/virt/tdx: Fill out TDMRs to cover all TDX memory regions (jsc#PED-5824).
- commit 1315701
* Tue Jan  9 2024 nik.borisov@suse.com
- x86/virt/tdx: Add placeholder to construct TDMRs to cover all TDX  memory regions (jsc#PED-5824).
- commit 73694c5
* Tue Jan  9 2024 nik.borisov@suse.com
- x86/virt/tdx: Get module global metadata for module initialization (jsc#PED-5824).
- commit 43cc2ba
* Tue Jan  9 2024 nik.borisov@suse.com
- x86/virt/tdx: Use all system memory when initializing TDX module as  TDX memory (jsc#PED-5824).
- commit a8d608a
* Tue Jan  9 2024 nik.borisov@suse.com
- x86/virt/tdx: Add skeleton to enable TDX on demand (jsc#PED-5824).
- commit 04046a4
* Tue Jan  9 2024 nik.borisov@suse.com
- x86/virt/tdx: Add SEAMCALL error printing for module initialization (jsc#PED-5824).
- commit ddfd550
* Tue Jan  9 2024 nik.borisov@suse.com
- x86/virt/tdx: Handle SEAMCALL no entropy error in common code (jsc#PED-5824).
- commit ea37d02
* Tue Jan  9 2024 nik.borisov@suse.com
- x86/virt/tdx: Make INTEL_TDX_HOST depend on X86_X2APIC (jsc#PED-5824).
- commit 461aa50
* Tue Jan  9 2024 nik.borisov@suse.com
- x86/virt/tdx: Define TDX supported page sizes as macros (jsc#PED-5824).
- commit 4fad607
* Tue Jan  9 2024 nik.borisov@suse.com
- x86/virt/tdx: Detect TDX during kernel boot (jsc#PED-5824).
- commit 48e2855
* Tue Jan  9 2024 nik.borisov@suse.com
- x86/mm: Remove "INVPCID single" feature tracking (jsc#PED-5824).
- commit 4340565
* Tue Jan  9 2024 tiwai@suse.de
- tools/power turbostat: version 2023.11.07 (bsc#1218556).
- tools/power/turbostat: bugfix "--show IPC" (bsc#1218556).
- tools/power/turbostat: Add initial support for LunarLake
  (bsc#1218556).
- tools/power/turbostat: Add initial support for ArrowLake
  (bsc#1218556).
- tools/power/turbostat: Add initial support for GrandRidge
  (bsc#1218556).
- tools/power/turbostat: Add initial support for SierraForest
  (bsc#1218556).
- tools/power/turbostat: Add initial support for GraniteRapids
  (bsc#1218556).
- tools/power/turbostat: Add MSR_CORE_C1_RES support for
  spr_features (bsc#1218556).
- tools/power/turbostat: Move process to root cgroup
  (bsc#1218556).
- tools/power/turbostat: Handle cgroup v2 cpu limitation
  (bsc#1218556).
- tools/power/turbostat: Abstrct function for parsing cpu string
  (bsc#1218556).
- tools/power/turbostat: Handle offlined CPUs in cpu_subset
  (bsc#1218556).
- tools/power/turbostat: Obey allowed CPUs for system summary
  (bsc#1218556).
- tools/power/turbostat: Obey allowed CPUs for primary thread/core
  detection (bsc#1218556).
- tools/power/turbostat: Abstract several functions (bsc#1218556).
- tools/power/turbostat: Obey allowed CPUs during startup
  (bsc#1218556).
- tools/power/turbostat: Obey allowed CPUs when accessing CPU
  counters (bsc#1218556).
- tools/power/turbostat: Introduce cpu_allowed_set (bsc#1218556).
- tools/power/turbostat: Remove PC7/PC9 support on ADL/RPL
  (bsc#1218556).
- tools/power/turbostat: Enable MSR_CORE_C1_RES on recent Intel
  client platforms (bsc#1218556).
- tools/power/turbostat: Introduce probe_pm_features()
  (bsc#1218556).
- tools/power/turbostat: Relocate more probing related code
  (bsc#1218556).
- tools/power/turbostat: Reorder some functions (bsc#1218556).
- tools/power/turbostat: Relocate thermal probing code
  (bsc#1218556).
- tools/power/turbostat: Relocate lpi probing code (bsc#1218556).
- tools/power/turbostat: Relocate graphics probing code
  (bsc#1218556).
- tools/power/turbostat: Rename rapl probing function
  (bsc#1218556).
- tools/power/turbostat: Rename uncore probing function
  (bsc#1218556).
- tools/power/turbostat: Relocate pstate probing code
  (bsc#1218556).
- tools/power/turbostat: Relocate cstate probing code
  (bsc#1218556).
- tools/power/turbostat: Improve probe_platform_features() logic
  (bsc#1218556).
- tools/power/turbostat: Delete intel_model_duplicates()
  (bsc#1218556).
- tools/power/turbostat: Abstract cstate prewake bit support
  (bsc#1218556).
- tools/power/turbostat: Abstract aperf/mperf multiplier support
  (bsc#1218556).
- tools/power/turbostat: Abstract extended cstate MSRs support
  (bsc#1218556).
- tools/power/turbostat: Abstract MSR_KNL_CORE_C6_RESIDENCY
  support (bsc#1218556).
- tools/power/turbostat: Abstract MSR_ATOM_PKG_C6_RESIDENCY
  support (bsc#1218556).
- tools/power/turbostat: Abstract
  MSR_CC6/MC6_DEMOTION_POLICY_CONFIG support (bsc#1218556).
- tools/power/turbostat: Abstract MSR_MODULE_C6_RES_MS support
  (bsc#1218556).
- tools/power/turbostat: Abstract MSR_CORE_C1_RES support
  (bsc#1218556).
- tools/power/turbostat: Abstract IRTL support (bsc#1218556).
- tools/power/turbostat: Use fine grained IRTL output
  (bsc#1218556).
- tools/power/turbostat: Adjust cstate for
  is_slm()/is_knl()/is_cnl()/is_ehl() models (bsc#1218556).
- tools/power/turbostat: Adjust cstate for has_c8910_msrs()
  models (bsc#1218556).
- tools/power/turbostat: Adjust cstate for is_bdx() models
  (bsc#1218556).
- tools/power/turbostat: Adjust cstate for
  is_skx()/is_icx()/is_spr() models (bsc#1218556).
- tools/power/turbostat: Adjust cstate for is_dnv() models
  (bsc#1218556).
- tools/power/turbostat: Adjust cstate for is_jvl() models
  (bsc#1218556).
- tools/power/turbostat: Adjust cstate for has_slv_msrs() models
  (bsc#1218556).
- tools/power/turbostat: Adjust cstate for has_snb_msrs() models
  (bsc#1218556).
- tools/power/turbostat: Adjust cstate for models with .cst_limit
  set (bsc#1218556).
- tools/power/turbostat: Adjust cstate for has_snb_msrs() models
  (bsc#1218556).
- tools/power/turbostat: Adjust cstate for models with
  .has_nhm_msrs set (bsc#1218556).
- tools/power/turbostat: Add skeleton support for cstate
  enumeration (bsc#1218556).
- tools/power/turbostat: Abstract TSC tweak support (bsc#1218556).
- tools/power/turbostat: Remove unused family/model parameters
  for RAPL functions (bsc#1218556).
- tools/power/turbostat: Abstract hardcoded TDP value
  (bsc#1218556).
- tools/power/turbostat: Abstract fixed DRAM Energy unit support
  (bsc#1218556).
- tools/power/turbostat: Abstract RAPL divisor support
  (bsc#1218556).
- tools/power/turbostat: Abstract Per Core RAPL support
  (bsc#1218556).
- tools/power/turbostat: Abstract RAPL MSRs support (bsc#1218556).
- tools/power/turbostat: Simplify the logic for RAPL enumeration
  (bsc#1218556).
- tools/power/turbostat: Redefine RAPL macros (bsc#1218556).
- tools/power/turbostat: Abstract hardcoded Crystal Clock
  frequency (bsc#1218556).
- tools/power/turbostat: Abstract Automatic Cstate Conversion
  support (bsc#1218556).
- tools/power/turbostat: Abstract Perf Limit Reasons MSRs support
  (bsc#1218556).
- tools/power/turbostat: Abstract TCC Offset bits support
  (bsc#1218556).
- tools/power/turbostat: Abstract Config TDP MSRs support
  (bsc#1218556).
- tools/power/turbostat: Rename some TRL functions (bsc#1218556).
- tools/power/turbostat: Abstract Turbo Ratio Limit MSRs support
  (bsc#1218556).
- tools/power/turbostat: Rename some functions (bsc#1218556).
- tools/power/turbostat: Remove a redundant check (bsc#1218556).
- tools/power/turbostat: Abstract Nehalem MSRs support
  (bsc#1218556).
- tools/power/turbostat: Abstract Package cstate limit decoding
  support (bsc#1218556).
- tools/power/turbostat: Abstract BCLK frequency support
  (bsc#1218556).
- tools/power/turbostat: Abstract MSR_MISC_PWR_MGMT support
  (bsc#1218556).
- tools/power/turbostat: Abstract MSR_MISC_FEATURE_CONTROL support
  (bsc#1218556).
- tools/power/turbostat: Add skeleton support for table driven
  feature enumeration (bsc#1218556).
- tools/power/turbostat: Remove pseudo check for two models
  (bsc#1218556).
- tools/power/turbostat: Remove redundant duplicates
  (bsc#1218556).
- tools/power/turbostat: Replace raw value cpu model with Macro
  (bsc#1218556).
- tools/power/turbostat: Support alternative graphics sysfs knobs
  (bsc#1218556).
- tools/power/turbostat: Enable TCC Offset on more models
  (bsc#1218556).
- tools/power/turbostat: Enable the C-state Pre-wake printing
  (bsc#1218556).
- tools/power/turbostat: Fix a knl bug (bsc#1218556).
- tools/power/turbostat: Fix failure with new uncore sysfs
  (bsc#1218556).
- cpupower: fix reference to nonexistent document (jsc#PED-5873).
- tools/power/x86/intel-speed-select: v1.18 release (jsc#PED-4647
  bsc#1218554).
- tools/power/x86/intel-speed-select: Use cgroup isolate for CPU 0
  (jsc#PED-4647 bsc#1218554).
- tools/power/x86/intel-speed-select: Increase max CPUs in one
  request (jsc#PED-4647 bsc#1218554).
- tools/power/x86/intel-speed-select: Display error for core-power
  support (jsc#PED-4647 bsc#1218554).
- tools/power/x86/intel-speed-select: No TRL for non compute
  domains (jsc#PED-4647 bsc#1218554).
- tools/power/x86/intel-speed-select: turbo-mode enable disable
  swapped (jsc#PED-4647 bsc#1218554).
- tools/power/x86/intel-speed-select: Update help for TRL
  (jsc#PED-4647 bsc#1218554).
- tools/power/x86/intel-speed-select: Sanitize integer arguments
  (jsc#PED-4647 bsc#1218554).
- cpupower: Add Georgian translation to Makefile LANGUAGES
  (jsc#PED-5873).
- tools/power/x86/intel-speed-select: v1.17 release (jsc#PED-4647
  bsc#1218554).
- tools/power/x86/intel-speed-select: Change mem-frequency
  display name (jsc#PED-4647 bsc#1218554).
- tools/power/x86/intel-speed-select: Prevent CPU 0 offline
  (jsc#PED-4647 bsc#1218554).
- tools/power/x86/intel-speed-select: Error on CPU count exceed
  in request (jsc#PED-4647 bsc#1218554).
- tools/power/x86/intel-speed-select: Support more than 8 sockets
  (jsc#PED-4647 bsc#1218554).
- tools/power/x86/intel-speed-select: Fix CPU count display
  (jsc#PED-4647 bsc#1218554).
- cpupower: Fix cpuidle_set to accept only numeric values for
  idle-set operation (jsc#PED-5873).
- cpupower: Add turbo-boost support in cpupower (jsc#PED-5873).
- cpupower: Add support for amd_pstate mode change (jsc#PED-5873).
- cpupower: Add EPP value change support (jsc#PED-5873).
- cpupower: Add is_valid_path API (jsc#PED-5873).
- cpupower: Recognise amd-pstate active mode driver
  (jsc#PED-5873).
- tools/power/x86/intel-speed-select: v1.16 release (jsc#PED-4647
  bsc#1218554).
- tools/power/x86/intel-speed-select: Fix json formatting issue
  (jsc#PED-4647 bsc#1218554).
- tools/power/x86/intel-speed-select: Adjust scope of core-power
  config (jsc#PED-4647 bsc#1218554).
- commit 926ea11
* Tue Jan  9 2024 jgross@suse.com
- xen/events: fix delayed eoi list handling (git-fixes).
- commit e085feb
* Tue Jan  9 2024 ddiss@suse.de
- Update config files to remove CONFIG_TCM_RBD=m (bsc#1218634)
- commit 1dcd1b3
* Tue Jan  9 2024 ddiss@suse.de
- target: revert LIO target_core_rbd patches (bsc#1218634)
- Delete
  patches.suse/libceph-add-support-for-CMPEXT-compare-extent-reques.patch.
- Delete patches.suse/rbd-add-img_request-done-callback.patch.
- Delete patches.suse/rbd-add-lio-specific-data-area.patch.
- Delete
  patches.suse/rbd-add-rbd_img_fill_cmp_and_write_from_bvecs.patch.
- Delete
  patches.suse/rbd-add-support-for-COMPARE_AND_WRITE-CMPEXT.patch.
- Delete
  patches.suse/rbd-export-some-functions-used-by-lio-rbd-backend.patch.
- Delete
  patches.suse/rbd-move-structs-used-by-lio-rbd-to-new-header.patch.
- Delete
  patches.suse/target-add-lio-rbd-to-makefile-Kconfig.patch.
- Delete patches.suse/target-add-rbd-backend.patch.
- Delete
  patches.suse/target-compare-and-write-backend-driver-sense-handli.patch.
- Delete
  patches.suse/target-disallow-emulate_legacy_capacity-with-RBD-obj.patch.
- Delete patches.suse/target-rbd-add-WRITE-SAME-support.patch.
- Delete
  patches.suse/target-rbd-add-emulate_legacy_capacity-dev-attribute.patch.
- Delete
  patches.suse/target-rbd-conditionally-fix-off-by-one-bug-in-get_b.patch.
- Delete
  patches.suse/target-rbd-detect-stripe_unit-SCSI-block-size-misali.patch.
- Delete
  patches.suse/target-rbd-fix-unmap-discard-block-size-conversion.patch.
- Delete
  patches.suse/target-rbd-fix-unmap-handling-with-unmap_zeroes_data.patch.
- Delete patches.suse/target-rbd-support-COMPARE_AND_WRITE.patch.
- Delete
  patches.suse/target_core_rbd-fix-leak-and-reduce-kmalloc-calls.patch.
- Delete
  patches.suse/target_core_rbd-fix-rbd_img_request.snap_id-assignme.patch.
- Delete
  patches.suse/target_core_rbd-remove-snapshot-existence-validation.patch.
- commit 391445c
* Tue Jan  9 2024 ohering@suse.de
- io_uring/af_unix: disable sending io_uring over sockets
  (bsc#1218447, CVE-2023-6531).
- commit 7d4ebd3
* Tue Jan  9 2024 jgross@suse.com
- xen/events: avoid using info_for_irq() in xen_send_IPI_one()
  (git-fixes).
- commit aa0ccc0
* Tue Jan  9 2024 jgross@suse.com
- xen-pciback: Consider INTx disabled when MSI/MSI-X is enabled
  (git-fixes).
- commit 74e0704
* Tue Jan  9 2024 jgross@suse.com
- xenbus: fix error exit in xenbus_init() (git-fixes).
- commit a5387b3
* Mon Jan  8 2024 palcantara@suse.de
- smb: client: fix potential OOB in smb2_dump_detail()
  (bsc#1217946 CVE-2023-6610).
- commit 88dbafd
* Mon Jan  8 2024 krisman@suse.de
- io_uring: fix off-by one bvec index (bsc#1218624).
- io_uring/kbuf: Use slab for struct io_buffer objects
  (git-fixes).
- io_uring/kbuf: Allow the full buffer id space for provided
  buffers (git-fixes).
- io_uring/kbuf: Fix check of BID wrapping in provided buffers
  (git-fixes).
- io_uring: use files_lookup_fd_locked() (git-fixes).
- commit db1b5e4
* Mon Jan  8 2024 jgross@suse.com
- vsock/virtio: Fix unsigned integer wrap around in
  virtio_transport_has_space() (git-fixes).
- commit 87e311c
* Mon Jan  8 2024 jgross@suse.com
- vsock/virtio: remove socket from connected/bound list on
  shutdown (git-fixes).
- commit d833002
* Mon Jan  8 2024 jgross@suse.com
- vsock/virtio: initialize the_virtio_vsock before using VQs
  (git-fixes).
- commit 11e10ec
* Mon Jan  8 2024 jgross@suse.com
- virtio_pci: fix the common cfg map size (git-fixes).
- commit 368664b
* Mon Jan  8 2024 jgross@suse.com
- virtio-mmio: fix memory leak of vm_dev (git-fixes).
- commit 6dc7491
* Mon Jan  8 2024 pmladek@suse.com
- vsprintf/kallsyms: Prevent invalid data when printing symbol
  (bsc#1217602).
- commit b959f1c
* Mon Jan  8 2024 oneukum@suse.com
- Revert "media: mediatek: vcodec: Fix bitstream crop information
  error" (git-fixes).
- commit e79cc48
* Mon Jan  8 2024 oneukum@suse.com
- media: platform: mtk-mdp3: release node reference before
  returning (git-fixes).
- commit ca2e5ae
* Mon Jan  8 2024 jgross@suse.com
- net: more strict VIRTIO_NET_HDR_GSO_UDP_L4 validation
  (git-fixes).
- commit 623ab0a
* Mon Jan  8 2024 jgross@suse.com
- KVM: SEV: Do not intercept accesses to MSR_IA32_XSS for SEV-ES
  guests (git-fixes).
- commit 23fdc35
* Mon Jan  8 2024 oneukum@suse.com
- media: mediatek: vcodec: Read HW active status from syscon
  (git-fixes).
- commit e1d2d26
* Mon Jan  8 2024 oneukum@suse.com
- media: Add AV1 uAPI (git-fixes).
- commit 4741e9b
* Mon Jan  8 2024 jgross@suse.com
- x86/boot: Move x86_cache_alignment initialization to correct
  spot (bsc#1216015).
- commit 5dc3dc0
* Mon Jan  8 2024 oneukum@suse.com
- media: mediatek: vcodec: Define address for VDEC_HW_ACTIVE
  (git-fixes).
- commit 5f137d4
* Mon Jan  8 2024 oneukum@suse.com
- media: Explicitly include correct DT includes (git-fixes).
- commit 2db0dfc
* Mon Jan  8 2024 oneukum@suse.com
- media: mediatek: vcodec: Change dbgfs interface to support
  encode (git-fixes).
- commit bd5f191
* Mon Jan  8 2024 oneukum@suse.com
- media: mediatek: vcodec: Add a debugfs file to get different
  useful information (git-fixes).
- commit bdc1207
* Mon Jan  8 2024 msuchanek@suse.de
- Limit kernel-source build to architectures for which the kernel binary
  is built (bsc#1108281).
- commit 08a9e44
* Mon Jan  8 2024 oneukum@suse.com
- media: mediatek: vcodec: fix resource leaks in
  vdec_msg_queue_init() (git-fixes).
- commit c0e90df
* Mon Jan  8 2024 duwe@suse.de
- units: add missing header (git-fixes).
- crypto: qat - move adf_cfg_services (jsc#PED-5174 jsc#PED-5861).
- crypto: qat - add num_rps sysfs attribute (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - add rp2svc sysfs attribute (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - add rate limiting sysfs interface (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - add rate limiting feature to qat_4xxx
  (jsc#PED-5174 jsc#PED-5861).
- crypto: qat - add retrieval of fw capabilities (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - add bits.h to icp_qat_hw.h (jsc#PED-5174
  jsc#PED-5861).
- units: Add BYTES_PER_*BIT (jsc#PED-5174 jsc#PED-5861).
- crypto: qat - move admin api (jsc#PED-5174 jsc#PED-5861).
- crypto: qat - fix ring to service map for QAT GEN4 (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - use masks for AE groups (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - refactor fw config related functions (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - count QAT GEN4 errors (jsc#PED-5174 jsc#PED-5861).
- crypto: qat - add error counters (jsc#PED-5174 jsc#PED-5861).
- crypto: qat - add handling of errors from ERRSOU3 for QAT GEN4
  (jsc#PED-5174 jsc#PED-5861).
- crypto: qat - add adf_get_aram_base() helper function
  (jsc#PED-5174 jsc#PED-5861).
- crypto: qat - add handling of compression related errors for
  QAT GEN4 (jsc#PED-5174 jsc#PED-5861).
- crypto: qat - add handling of errors from ERRSOU2 for QAT GEN4
  (jsc#PED-5174 jsc#PED-5861).
- crypto: qat - add reporting of errors from ERRSOU1 for QAT GEN4
  (jsc#PED-5174 jsc#PED-5861).
- crypto: qat - add reporting of correctable errors for QAT GEN4
  (jsc#PED-5174 jsc#PED-5861).
- crypto: qat - add infrastructure for error reporting
  (jsc#PED-5174 jsc#PED-5861).
- crypto: qat - add cnv_errors debugfs file (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - add pm_status debugfs file (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - refactor included headers (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - add namespace to driver (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - Remove zlib-deflate (jsc#PED-5174 jsc#PED-5861).
- crypto: qat - Annotate struct adf_fw_counters with __counted_by
  (jsc#PED-5174 jsc#PED-5861).
- crypto: qat - enable dc chaining service (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - consolidate services structure (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - fix unregistration of compression algorithms
  (jsc#PED-5174 jsc#PED-5861).
- crypto: qat - do not shadow error code (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - refactor deprecated strncpy (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - Use list_for_each_entry() helper (jsc#PED-5174
  jsc#PED-5861).
- Documentation: ABI: debugfs-driver-qat: fix fw_counters path
  (git-fixes).
- crypto: qat - fix crypto capability detection for 4xxx
  (jsc#PED-5174 jsc#PED-5861).
- crypto: qat - Remove unused function declarations (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - use kfree_sensitive instead of memset/kfree()
  (jsc#PED-5174 jsc#PED-5861).
- crypto: qat - replace the if statement with min() (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - add heartbeat counters check (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - add heartbeat feature (jsc#PED-5174 jsc#PED-5861).
- crypto: qat - add measure clock frequency (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - drop obsolete heartbeat interface (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - add internal timer for qat 4xxx (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - add fw_counters debugfs file (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - change value of default idle filter (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - do not export adf_init_admin_pm() (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - expose pm_idle_enabled through sysfs (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - extend configuration for 4xxx (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - refactor fw config logic for 4xxx (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - make fw images name constant (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - move returns to default case (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - update slice mask for 4xxx devices (jsc#PED-5174
  jsc#PED-5861).
- crypto: qat - set deprecated capabilities as reserved
  (jsc#PED-5174 jsc#PED-5861).
- crypto: qat - add missing function declaration in adf_dbgfs.h
  (jsc#PED-5174 jsc#PED-5861).
- crypto: qat - move dbgfs init to separate file (jsc#PED-5174
  jsc#PED-5861).
- commit a45a239
* Mon Jan  8 2024 duwe@suse.de
- Delete
  patches.suse/crypto-qat-change-value-of-default-idle-filter.patch.
  (will be re-added as part of the QAT series)
- commit c06831d
* Mon Jan  8 2024 oneukum@suse.com
- media: mc: Make media_get_pad_index() use pad type flag
  (git-fixes).
- commit 5b7fb34
* Mon Jan  8 2024 jack@suse.cz
- readahead: Avoid multiple marked readahead pages (bsc#1217818).
- commit a26eeaa
* Mon Jan  8 2024 jgross@suse.com
- x86/sev-es: Set x86_virt_bits to the correct value straight
  away, instead of a two-phase approach (bsc#1216015).
- commit 9f9f39c
* Mon Jan  8 2024 nik.borisov@suse.com
- x86/resctrl: Fix kernel-doc warnings (git-fixes).
- commit 4ce9baf
* Mon Jan  8 2024 nik.borisov@suse.com
- x86/lib/msr: Clean up kernel-doc notation (git-fixes).
- commit 0fd47d0
* Mon Jan  8 2024 nik.borisov@suse.com
- x86/ibt: Avoid duplicate ENDBR in __put_user_nocheck*() (git-fixes).
- commit c99440e
* Mon Jan  8 2024 nik.borisov@suse.com
- x86/fineibt: Poison ENDBR at +0 (git-fixes).
- commit 0340aa5
* Mon Jan  8 2024 nik.borisov@suse.com
- x86/boot/compressed: Reserve more memory for page tables (git-fixes).
- commit 1b49bd4
* Mon Jan  8 2024 nik.borisov@suse.com
- x86/alternatives: Disable KASAN in apply_alternatives()   (git-fixes).
- commit 0de097e
* Mon Jan  8 2024 nik.borisov@suse.com
- x86/ibt: Suppress spurious ENDBR (git-fixes).
- commit 127632c
* Mon Jan  8 2024 nik.borisov@suse.com
- x86/CPU/AMD: Check vendor in the AMD microcode callback (git-fixes).
- commit ec38da9
* Mon Jan  8 2024 jgross@suse.com
- x86/sev-es: Allow copy_from_kernel_nofault() in earlier boot
  (bsc#1216015).
- commit 2c6b247
* Mon Jan  8 2024 nik.borisov@suse.com
- x86/alternatives: Disable interrupts and sync when optimizing NOPs in  place (git-fixes).
- commit 3ed13fa
* Mon Jan  8 2024 nik.borisov@suse.com
- x86/srso: Fix SBPB enablement for (possible) future fixed HW  (git-fixes).
- Refresh
  patches.suse/x86-srso-fix-vulnerability-reporting-for-missing-microcode.patch.
- commit b0edd5b
* Mon Jan  8 2024 nik.borisov@suse.com
- x86/srso: Fix vulnerability reporting for missing microcode (git-fixes).
- commit e2cfc2e
* Mon Jan  8 2024 jlee@suse.com
- EDAC: Explicitly include correct DT includes (jsc#PED-6747).
- commit f6ef38c
* Sun Jan  7 2024 tiwai@suse.de
- i2c: core: Fix atomic xfer check for non-preempt config
  (git-fixes).
- commit e75469f
* Sat Jan  6 2024 lduncan@suse.com
- ublk: zoned: support REQ_OP_ZONE_RESET_ALL (bsc#1216436).
- ublk: Switch to memdup_user_nul() helper (bsc#1216436).
- ublk: fix 'warn: variable dereferenced before check 'req''
  from Smatch (bsc#1216436).
- ublk: Fix signedness bug returning warning (bsc#1216436).
- ublk: enable zoned storage support (bsc#1216436).
- ublk: move check for empty address field on command submission
  (bsc#1216436).
- ublk: add helper to check if device supports user copy
  (bsc#1216436).
- ublk: make ublk_chr_class a static const structure
  (bsc#1216436).
- ublk: add control command of UBLK_U_CMD_GET_FEATURES
  (bsc#1216436).
- ublk: fix build warning on iov_iter_get_pages2 (bsc#1216436).
- ublk: support user copy (bsc#1216436).
- ublk: add read()/write() support for ublk char device
  (bsc#1216436).
- ublk: support to copy any part of request pages (bsc#1216436).
- ublk: grab request reference when the request is handled by
  userspace (bsc#1216436).
- ublk: cleanup ublk_copy_user_pages (bsc#1216436).
- ublk: cleanup io cmd code path by adding ublk_fill_io_cmd()
  (bsc#1216436).
- ublk: kill queuing request by task_work_add (bsc#1216436).
- commit 9fb699d
* Sat Jan  6 2024 tiwai@suse.de
- mmc: sdhci-sprd: Fix eMMC init failure after hw reset
  (git-fixes).
- mmc: rpmb: fixes pause retune on all RPMB partitions
  (git-fixes).
- mmc: meson-mx-sdhc: Fix initialization frozen issue (git-fixes).
- drm/amd/display: Fix sending VSC (+ colorimetry) packets for
  DP/eDP displays without PSR (git-fixes).
- ARM: sun9i: smp: Fix array-index-out-of-bounds read in
  sunxi_mc_smp_init (git-fixes).
- commit 6d8c3af
* Fri Jan  5 2024 tiwai@suse.de
- Update patch reference for BT fix (CVE-2023-51779 bsc#1218559)
- commit 5031658
* Fri Jan  5 2024 tiwai@suse.de
- platform/x86/intel/tpmi: Add debugfs support for read/write
  blocked (bsc#1218555).
- platform/x86/intel/tpmi: Add debugfs interface (bsc#1218555).
- platform/x86/intel/tpmi: Read feature control status
  (bsc#1218555).
- commit 504e179
* Fri Jan  5 2024 tiwai@suse.de
- selftests: bonding: do not set port down when adding to bond
  (git-fixes).
- r8169: Fix PCI error on system resume (git-fixes).
- wifi: iwlwifi: pcie: don't synchronize IRQs from IRQ
  (git-fixes).
- nfc: llcp_core: Hold a ref to llcp_local->dev when holding a
  ref to llcp_local (git-fixes).
- Revert "platform/x86: p2sb: Allow p2sb_bar() calls during PCI
  device probe" (git-fixes).
- drm/mgag200: Fix gamma lut not initialized for G200ER, G200EV,
  G200SE (git-fixes).
- drm/bridge: ps8640: Fix size mismatch warning w/ len
  (git-fixes).
- drm/bridge: ti-sn65dsi86: Never store more than msg->size
  bytes in AUX xfer (git-fixes).
- drm/bridge: parade-ps8640: Never store more than msg->size
  bytes in AUX xfer (git-fixes).
- accel/qaic: Implement quirk for SOC_HW_VERSION (git-fixes).
- accel/qaic: Fix GEM import path code (git-fixes).
- drm/i915/perf: Update handling of MMIO triggered reports
  (git-fixes).
- drm/i915/dp: Fix passing the correct DPCD_REV for
  drm_dp_set_phy_test_pattern (git-fixes).
- selftests: secretmem: floor the memory size to the multiple
  of page_size (git-fixes).
- PM: hibernate: Fix the exclusive get block device in test_resume
  mode (git-fixes).
- commit 0536703
* Fri Jan  5 2024 tiwai@suse.de
- ALSA: hda/tas2781: remove sound controls in unbind (git-fixes).
- commit f8516b2
* Fri Jan  5 2024 tiwai@suse.de
- ALSA: hda/realtek: Fix mute and mic-mute LEDs for HP ProBook
  440 G6 (git-fixes).
- ASoC: meson: g12a-tohdmitx: Fix event generation for S/PDIF mux
  (git-fixes).
- ASoC: meson: g12a-toacodec: Fix event generation (git-fixes).
- ASoC: meson: g12a-tohdmitx: Validate written enum values
  (git-fixes).
- ASoC: meson: g12a-toacodec: Validate written enum values
  (git-fixes).
- ASoC: mediatek: mt8186: fix AUD_PAD_TOP register and offset
  (git-fixes).
- ASoC: fsl_rpmsg: Fix error handler with pm_runtime_enable
  (git-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs for a HP ZBook
  (git-fixes).
- ALSA: hda/realtek: enable SND_PCI_QUIRK for hp pavilion
  14-ec1xxx series (git-fixes).
- ALSA: hda/tas2781: move set_drv_data outside tasdevice_init
  (git-fixes).
- ALSA: hda/tas2781: fix typos in comment (git-fixes).
- ALSA: hda/tas2781: do not use regcache (git-fixes).
- commit 38d6c8e
* Fri Jan  5 2024 pjakobsson@suse.de
- drm/i915/mtl: Update workaround 14016712196 (git-fixes).
- commit eff3878
* Fri Jan  5 2024 colyli@suse.de
- badblocks: avoid checking invalid range in badblocks_check()
  (jsc#PED-7513).
- dm-raid: delay flushing event_work() after reconfig_mutex is
  released (jsc#PED-7514).
- md: split MD_RECOVERY_NEEDED out of mddev_resume (jsc#PED-7542).
- md: fix stopping sync thread (jsc#PED-7542).
- md: don't leave 'MD_RECOVERY_FROZEN' in error path of
  md_set_readonly() (jsc#PED-7542).
- md: fix missing flush of sync_work (jsc#PED-7542).
- md/raid6: use valid sector values to determine if an I/O should
  wait on the reshape (jsc#PED-7542).
- bcache: revert replacing IS_ERR_OR_NULL with IS_ERR
  (jsc#PED-7513).
- dm-flakey: start allocating with MAX_ORDER (jsc#PED-7514).
- dm-verity: align struct dm_verity_fec_io properly
  (jsc#PED-7514).
- dm verity: don't perform FEC for failed readahead IO
  (jsc#PED-7514).
- dm verity: initialize fec io before freeing it (jsc#PED-7514).
- closures: CLOSURE_CALLBACK() to fix type punning (jsc#PED-7513).
- md: fix bi_status reporting in md_end_clone_io (jsc#PED-7542).
- bcache: avoid NULL checking to c->root in run_cache_set()
  (jsc#PED-7513).
- bcache: add code comments for bch_btree_node_get() and
  __bch_btree_node_alloc() (jsc#PED-7513).
- bcache: replace a mistaken IS_ERR() by IS_ERR_OR_NULL() in
  btree_gc_coalesce() (jsc#PED-7513).
- bcache: fixup multi-threaded bch_sectors_dirty_init() wake-up
  race (jsc#PED-7513).
- bcache: fixup lock c->root error (jsc#PED-7513).
- bcache: fixup init dirty data errors (jsc#PED-7513).
- bcache: prevent potential division by zero error (jsc#PED-7513).
- bcache: remove redundant assignment to variable cur_idx
  (jsc#PED-7513).
- bcache: check return value from btree_node_alloc_replacement()
  (jsc#PED-7513).
- bcache: avoid oversize memory allocation by small stripe_size
  (jsc#PED-7513).
- dm-crypt: start allocating with MAX_ORDER (jsc#PED-7514).
- dm-verity: don't use blocking calls from tasklets
  (jsc#PED-7514).
- dm-bufio: fix no-sleep mode (jsc#PED-7514).
- dm-delay: avoid duplicate logic (jsc#PED-7514).
- dm-delay: fix bugs introduced by kthread mode (jsc#PED-7514).
- dm-delay: fix a race between delay_presuspend and delay_bio
  (jsc#PED-7514).
- closures: Fix race in closure_sync() (jsc#PED-7513).
- closures: Better memory barriers (jsc#PED-7513).
- dm crypt: account large pages in cc->n_allocated_pages
  (jsc#PED-7514).
- dm integrity: use crypto_shash_digest() in sb_mac()
  (jsc#PED-7514).
- dm crypt: use crypto_shash_digest() in crypt_iv_tcw_whitening()
  (jsc#PED-7514).
- dm error: Add support for zoned block devices (jsc#PED-7514).
- dm delay: for short delays, use kthread instead of timers and wq
  (jsc#PED-7514).
- dm: respect REQ_NOWAIT flag in normal bios issued to DM
  (jsc#PED-7514).
- dm: enhance alloc_multiple_bios() to be more versatile
  (jsc#PED-7514).
- dm: make __send_duplicate_bios return unsigned int
  (jsc#PED-7514).
- dm log userspace: replace deprecated strncpy with strscpy
  (jsc#PED-7514).
- dm ioctl: replace deprecated strncpy with strscpy_pad
  (jsc#PED-7514).
- dm crypt: replace open-coded kmemdup_nul (jsc#PED-7514).
- dm cache metadata: replace deprecated strncpy with strscpy
  (jsc#PED-7514).
- dm: shortcut the calls to linear_map and stripe_map
  (jsc#PED-7514).
- md: cleanup pers->prepare_suspend() (jsc#PED-7542).
- md-cluster: check for timeout while a new disk adding
  (jsc#PED-7542).
- md: rename __mddev_suspend/resume() back to
  mddev_suspend/resume() (jsc#PED-7542).
- md: remove old apis to suspend the array (jsc#PED-7542).
- md: suspend array in md_start_sync() if array need
  reconfiguration (jsc#PED-7542).
- md/raid5: replace suspend with quiesce() callback
  (jsc#PED-7542).
- md/md-linear: cleanup linear_add() (jsc#PED-7542).
- md: cleanup mddev_create/destroy_serial_pool() (jsc#PED-7542).
- md: use new apis to suspend array before
  mddev_create/destroy_serial_pool (jsc#PED-7542).
- md: use new apis to suspend array for ioctls involed array
  reconfiguration (jsc#PED-7542).
- md: use new apis to suspend array for adding/removing rdev
  from state_store() (jsc#PED-7542).
- md: use new apis to suspend array for sysfs apis (jsc#PED-7542).
- md/raid5: use new apis to suspend array (jsc#PED-7542).
- md/raid5-cache: use new apis to suspend array (jsc#PED-7542).
- md/md-bitmap: use new apis to suspend array for location_store()
  (jsc#PED-7542).
- md/dm-raid: use new apis to suspend array (jsc#PED-7514).
- md: add new helpers to suspend/resume and lock/unlock array
  (jsc#PED-7542).
- md: add new helpers to suspend/resume array (jsc#PED-7542).
- md: replace is_md_suspended() with 'mddev->suspended' in
  md_check_recovery() (jsc#PED-7542).
- md/raid5-cache: use READ_ONCE/WRITE_ONCE for 'conf->log'
  (jsc#PED-7542).
- md: use READ_ONCE/WRITE_ONCE for 'suspend_lo' and 'suspend_hi'
  (jsc#PED-7542).
- md/raid1: don't split discard io for write behind
  (jsc#PED-7542).
- md: do not require mddev_lock() for all options in
  array_state_store() (jsc#PED-7542).
- md: simplify md_seq_ops (jsc#PED-7542).
- md: factor out a helper from mddev_put() (jsc#PED-7542).
- md: replace deprecated strncpy with memcpy (jsc#PED-7542).
- md/md-linear: Annotate struct linear_conf with __counted_by
  (jsc#PED-7542).
- md: don't check 'mddev->pers' and 'pers->quiesce' from
  suspend_lo_store() (jsc#PED-7542).
- md: don't check 'mddev->pers' from suspend_hi_store()
  (jsc#PED-7542).
- md-bitmap: suspend array earlier in location_store()
  (jsc#PED-7542).
- md-bitmap: remove the checking of 'pers->quiesce' from
  location_store() (jsc#PED-7542).
- md: don't rely on 'mddev->pers' to be set in mddev_suspend()
  (jsc#PED-7542).
- md: initialize 'writes_pending' while allocating mddev
  (jsc#PED-7542).
- md: initialize 'active_io' while allocating mddev
  (jsc#PED-7542).
- md: delay remove_and_add_spares() for read only array to
  md_start_sync() (jsc#PED-7542).
- md: factor out a helper rdev_addable() from
  remove_and_add_spares() (jsc#PED-7542).
- md: factor out a helper rdev_is_spare() from
  remove_and_add_spares() (jsc#PED-7542).
- md: factor out a helper rdev_removeable() from
  remove_and_add_spares() (jsc#PED-7542).
- md: delay choosing sync action to md_start_sync()
  (jsc#PED-7542).
- md: factor out a helper to choose sync action from
  md_check_recovery() (jsc#PED-7542).
- md: use separate work_struct for md_start_sync() (jsc#PED-7542).
- badblocks: switch to the improved badblock handling code
  (jsc#PED-7542).
- badblocks: improve badblocks_check() for multiple ranges
  handling (jsc#PED-7542).
- badblocks: improve badblocks_clear() for multiple ranges
  handling (jsc#PED-7542).
- badblocks: improve badblocks_set() for multiple ranges handling
  (jsc#PED-7542).
- badblocks: add helper routines for badblock ranges handling
  (jsc#PED-7542).
- badblocks: add more helper structure and routines in badblocks.h
  (jsc#PED-7542).
- dm: Annotate struct dm_bio_prison with __counted_by
  (jsc#PED-7514).
- dm: Annotate struct dm_stat with __counted_by (jsc#PED-7514).
- dm: Annotate struct stripe_c with __counted_by (jsc#PED-7514).
- dm crypt: Annotate struct crypt_config with __counted_by
  (jsc#PED-7514).
- dm raid: Annotate struct raid_set with __counted_by
  (jsc#PED-7514).
- closures: Add a missing include (jsc#PED-7542).
- closures: closure_nr_remaining() (jsc#PED-7542).
- closures: closure_wait_event() (jsc#PED-7542).
- commit 99c2319
* Fri Jan  5 2024 colyli@suse.de
- bcache: move closures to lib/ (jsc#PED-7513).
  - Update config files for the above change, add CONFIG_CLOSURES,
  - config/arm64/default
  - config/armv7hl/default
  - config/ppc64le/default
  - config/s390x/default
  - config/x86_64/default
- commit 74c7cf7
* Fri Jan  5 2024 colyli@suse.de
- dm crypt: Fix reqsize in crypt_iv_eboiv_gen (jsc#PED-7514).
- MAINTAINERS: update the dm-devel mailing list (jsc#PED-7514).
- dm zoned: free dmz->ddev array in dmz_put_zoned_devices
  (jsc#PED-7514).
- md/raid5: release batch_last before waiting for another
  stripe_head (jsc#PED-7542).
- dm: don't attempt to queue IO under RCU protection
  (jsc#PED-7514).
- dm: fix a race condition in retrieve_deps (jsc#PED-7514).
- md: Put the right device in md_seq_next (jsc#PED-7542).
- md/raid1: fix error: ISO C90 forbids mixed declarations
  (jsc#PED-7542).
- md: don't dereference mddev after export_rdev() (jsc#PED-7542).
- md: raid0: account for split bio in iostat accounting
  (jsc#PED-7542).
- md raid1: allow writebehind to work on any leg device set
  WriteMostly (jsc#PED-7542).
- md/raid1: hold the barrier until handle_read_error() finishes
  (jsc#PED-7542).
- md/raid1: free the r1bio before waiting for blocked rdev
  (jsc#PED-7542).
- md/raid1: call free_r1bio() before allow_barrier() in
  raid_end_bio_io() (jsc#PED-7542).
- md/raid5-cache: fix null-ptr-deref for
  r5l_flush_stripe_to_raid() (jsc#PED-7542).
- raid6: test: only check for Altivec if building on powerpc hosts
  (jsc#PED-7542).
- raid6: test: make sure all intermediate and artifact files
  are .gitignored (jsc#PED-7542).
- raid6: test: cosmetic cleanups for the test Makefile
  (jsc#PED-7542).
- raid6: guard the tables.c include of <linux/export.h> with
  __KERNEL__ (jsc#PED-7542).
- raid6: remove the <linux/export.h> include from recov.c
  (jsc#PED-7542).
- md: Hold mddev->reconfig_mutex when trying to get
  mddev->sync_thread (jsc#PED-7542).
- md/raid10: fix a 'conf->barrier' leakage in raid10_takeover()
  (jsc#PED-7542).
- md: raid1: fix potential OOB in raid1_remove_disk()
  (jsc#PED-7542).
- md/raid5-cache: fix a deadlock in r5l_exit_log() (jsc#PED-7542).
- md/md-bitmap: hold 'reconfig_mutex' in backlog_store()
  (jsc#PED-7542).
- md/md-bitmap: remove unnecessary local variable in
  backlog_store() (jsc#PED-7542).
- md/raid10: use dereference_rdev_and_rrdev() to get devices
  (jsc#PED-7542).
- md/raid10: factor out dereference_rdev_and_rrdev()
  (jsc#PED-7542).
- md/raid10: check replacement and rdev to prevent submit the
  same io twice (jsc#PED-7542).
- md/raid1: Avoid lock contention from wake_up() (jsc#PED-7542).
- md: restore 'noio_flag' for the last mddev_resume()
  (jsc#PED-7542).
- md: don't quiesce in mddev_suspend() (jsc#PED-7542).
- md: remove redundant check in fix_read_error() (jsc#PED-7542).
- commit 81527d2
* Fri Jan  5 2024 colyli@suse.de
- md/raid10: optimize fix_read_error (jsc#PED-7542).
- Update patches.suse/md-display-timeout-error.patch for the above change.
- commit 7006b22
* Fri Jan  5 2024 colyli@suse.de
- md/raid1: prioritize adding disk to 'removed' mirror
  (jsc#PED-7542).
- md/md-faulty: enable io accounting (jsc#PED-7542).
- md/md-linear: enable io accounting (jsc#PED-7542).
- md/md-multipath: enable io accounting (jsc#PED-7542).
- commit 48f2a41
* Fri Jan  5 2024 colyli@suse.de
- md/raid10: switch to use md_account_bio() for io accounting
  (jsc#PED-7542).
- Refresh patches.suse/md-display-timeout-error.patch for the above change.
- commit f7260ba
* Fri Jan  5 2024 colyli@suse.de
- md/raid1: switch to use md_account_bio() for io accounting
  (jsc#PED-7542).
- raid5: fix missing io accounting in raid5_align_endio()
  (jsc#PED-7542).
- md: also clone new io if io accounting is disabled
  (jsc#PED-7542).
- md: move initialization and destruction of 'io_acct_set'
  to md.c (jsc#PED-7542).
- md: deprecate bitmap file support (jsc#PED-7542).
- commit 6586ee2
* Fri Jan  5 2024 colyli@suse.de
- md: make bitmap file support optional (jsc#PED-7542).
- Update config files for the above change, add option
  CONFIG_MD_BITMAP_FILE set by y (the default behavior
  as old kernel versions do),
  - config/arm64/default
  - config/armv7hl/default
  - config/ppc64le/default
  - config/s390x/default
  - config/s390x/zfcpdump
  - config/x86_64/default
- commit 20d8462
* Fri Jan  5 2024 colyli@suse.de
- md-bitmap: don't use ->index for pages backing the bitmap file
  (jsc#PED-7542).
- md-bitmap: account for mddev->bitmap_info.offset in read_sb_page
  (jsc#PED-7542).
- md-bitmap: cleanup read_sb_page (jsc#PED-7542).
- md-bitmap: refactor md_bitmap_init_from_disk (jsc#PED-7542).
- md-bitmap: rename read_page to read_file_page (jsc#PED-7542).
- md-bitmap: split file writes into a separate helper
  (jsc#PED-7542).
- md-bitmap: use %%pD to print the file name in md_bitmap_file_kick
  (jsc#PED-7542).
- md-bitmap: initialize variables at declaration time in
  md_bitmap_file_unmap (jsc#PED-7542).
- md-bitmap: set BITMAP_WRITE_ERROR in write_sb_page
  (jsc#PED-7542).
- md: enhance checking in md_check_recovery() (jsc#PED-7542).
- md: wake up 'resync_wait' at last in md_reap_sync_thread()
  (jsc#PED-7542).
- md: refactor idle/frozen_sync_thread() to fix deadlock
  (jsc#PED-7542).
- md: add a mutex to synchronize idle and frozen in action_store()
  (jsc#PED-7542).
- md: refactor action_store() for 'idle' and 'frozen'
  (jsc#PED-7542).
- Revert "md: unlock mddev before reap sync_thread in
  action_store" (jsc#PED-7542).
- dm integrity: fix double free on memory allocation failure
  (jsc#PED-7514).
- raid10: avoid spin_lock from fastpath from raid10_unplug()
  (jsc#PED-7542).
- md: fix 'delete_mutex' deadlock (jsc#PED-7542).
- dm crypt: Avoid using MAX_CIPHER_BLOCKSIZE (jsc#PED-7514).
- dm: get rid of GFP_NOIO workarounds for __vmalloc and kvmalloc
  (jsc#PED-7514).
- dm integrity: scale down the recalculate buffer if memory
  allocation fails (jsc#PED-7514).
- dm integrity: only allocate recalculate buffer when needed
  (jsc#PED-7514).
- dm ioctl: Refuse to create device named "." or
  ".." (jsc#PED-7514).
- dm ioctl: Refuse to create device named "control"
  (jsc#PED-7514).
- dm ioctl: structs and parameter strings must not overlap
  (jsc#PED-7514).
- dm ioctl: Avoid pointer arithmetic overflow (jsc#PED-7514).
- dm ioctl: Check dm_target_spec is sufficiently aligned
  (jsc#PED-7514).
- dm integrity: Use %%*ph for printing hexdump of a small buffer
  (jsc#PED-7514).
- dm thin: disable discards for thin-pool if no_discard_passdown
  (jsc#PED-7514).
- dm: remove stale/redundant dm_internal_{suspend,resume}
  prototypes in dm.h (jsc#PED-7514).
- dm: skip dm-stats work in alloc_io() unless needed
  (jsc#PED-7514).
- dm: avoid needless dm_io access if all IO accounting is disabled
  (jsc#PED-7514).
- dm: support turning off block-core's io stats accounting
  (jsc#PED-7514).
- dm zone: Use the bitmap API to allocate bitmaps (jsc#PED-7514).
- dm thin metadata: Fix ABBA deadlock by resetting dm_bufio_client
  (jsc#PED-7514).
- dm crypt: fix crypt_ctr_cipher_new return value on invalid
  AEAD cipher (jsc#PED-7514).
- dm thin: update .io_hints methods to not require handling
  discards last (jsc#PED-7514).
- dm thin: remove return code variable in pool_map (jsc#PED-7514).
- dm flakey: introduce random_read_corrupt and
  random_write_corrupt options (jsc#PED-7514).
- dm flakey: clone pages on write bio before corrupting them
  (jsc#PED-7514).
- dm crypt: allocate compound pages if possible (jsc#PED-7514).
- md/raid5: Convert stripe_head's "dev" to flexible array member
  (jsc#PED-7542).
- dm integrity: Use alloc_ordered_workqueue() to create ordered
  workqueues (jsc#PED-7514).
- bcache: Remove dead references to cache_readaheads
  (jsc#PED-7513).
- bcache: make kobj_type structures constant (jsc#PED-7513).
- md/raid1-10: limit the number of plugged bio (jsc#PED-7542).
- md/raid1-10: don't handle pluged bio by daemon thread
  (jsc#PED-7542).
- md/md-bitmap: add a new helper to unplug bitmap asynchrously
  (jsc#PED-7542).
- md/raid10: Do not add spare disk when recovery fails
  (jsc#PED-7542).
- md/raid10: clean up md_add_new_disk() (jsc#PED-7542).
- md/raid10: prioritize adding disk to 'removed' mirror
  (jsc#PED-7542).
- md/raid10: improve code of mrdev in raid10_sync_request
  (jsc#PED-7542).
- md/raid5: don't start reshape when recovery or replace is in
  progress (jsc#PED-7542).
- md: protect md_thread with rcu (jsc#PED-7542).
- md/bitmap: factor out a helper to set timeout (jsc#PED-7542).
- md/bitmap: always wake up md_thread in timeout_store
  (jsc#PED-7542).
- dm-raid: remove useless checking in raid_message()
  (jsc#PED-7514).
- md: factor out a helper to wake up md_thread directly
  (jsc#PED-7542).
- md: fix duplicate filename for rdev (jsc#PED-7542).
- commit bda8d48
* Fri Jan  5 2024 colyli@suse.de
- md/raid5: fix a deadlock in the case that reshape is interrupted
  (jsc#PED-7542).
- md: add a new api prepare_suspend() in md_personality
  (jsc#PED-7542).
- md: export md_is_rdwr() and is_md_suspended() (jsc#PED-7542).
- md/raid5: don't allow replacement while reshape is in progress
  (jsc#PED-7542).
- raid6: neon: add missing prototypes (jsc#PED-7542).
- commit 3705efe
* Thu Jan  4 2024 tonyj@suse.de
- perf/core: Fix cpuctx refcounting (git-fixes).
- powerpc/perf: Fix disabling BHRB and instruction sampling
  (git-fixes).
- powerpc/imc-pmu: Use the correct spinlock initializer
  (git-fixes).
- perf: Optimize perf_cgroup_switch() (git-fixes).
- perf/x86/amd: Do not WARN() on every IRQ (git-fixes).
- perf/x86/amd/core: Fix overflow reset on hotplug (git-fixes).
- perf/x86/uncore: Correct the number of CHAs on EMR (git-fixes).
- powerpc/perf: Convert fsl_emb notifier to state machine
  callbacks (git-fixes).
- commit 15e4363
* Thu Jan  4 2024 lduncan@suse.com
- scsi: core: Always send batch on reset or error handling command
  (git-fixes).
- scsi: bnx2fc: Fix skb double free in bnx2fc_rcv() (git-fixes).
- Revert "scsi: aacraid: Reply queue mapping to CPUs based on
  IRQ affinity" (git-fixes).
- scsi: be2iscsi: Fix a memleak in beiscsi_init_wrb_handle()
  (git-fixes).
- scsi: sd: Fix system start for ATA devices (git-fixes).
- scsi: qla2xxx: Fix system crash due to bad pointer access
  (git-fixes).
- scsi: megaraid: Fix up debug message in
  megaraid_abort_and_reset() (git-fixes).
- scsi: mpt3sas: Fix loop logic (git-fixes).
- scsi: ibmvfc: Fix erroneous use of rtas_busy_delay with hcall
  return code (git-fixes).
- commit 1ec1291
* Thu Jan  4 2024 msuchanek@suse.de
- powerpc/rtas: Warn if per-function lock isn't held (jsc#PED-4486).
- Refresh patches.suse/powerpc-pseries-Add-papr-vpd-character-driver-for-VP.patch.
- Refresh patches.suse/powerpc-pseries-papr-sysparm-Expose-character-device.patch.
- Refresh patches.suse/powerpc-pseries-papr-sysparm-Validate-buffer-object-.patch.
- Refresh patches.suse/powerpc-rtas-Facilitate-high-level-call-sequences.patch.
- Refresh patches.suse/powerpc-rtas-Serialize-firmware-activation-sequences.patch.
- Refresh patches.suse/powerpc-selftests-Add-test-for-papr-sysparm.patch.
- Refresh patches.suse/powerpc-selftests-Add-test-for-papr-vpd.patch.
- Delete patches.suse/powerpc-rtas-Factor-out-function-descriptor-lookup.patch.
- Delete patches.suse/powerpc-uapi-Export-papr-miscdev.h-header.patch.
- commit 5cce45a
* Thu Jan  4 2024 msuchanek@suse.de
- powerpc/rtas: Move token validation from block_rtas_call()
  to sys_rtas() (jsc#PED-4486).
- powerpc/rtas: Add function return status constants
  (jsc#PED-4486).
- powerpc/rtas: Fall back to linear search on failed
  token->function lookup (jsc#PED-4486).
- Refresh patches.suse/powerpc-rtas-Facilitate-high-level-call-sequences.patch.
- powerpc/rtas: Add for_each_rtas_function() iterator
  (jsc#PED-4486).
- powerpc/rtas: Avoid warning on invalid token argument to
  sys_rtas() (jsc#PED-4486).
- Refresh patches.suse/powerpc-rtas-Facilitate-high-level-call-sequences.patch.
- powerpc/rtas: export rtas_error_rc() for reuse (jsc#PED-4486).
- commit b1914f5
* Thu Jan  4 2024 msuchanek@suse.de
- powerpc/pseries/vas: Migration suspend waits for no in-progress
  open windows (bsc#1218397 ltc#204523).
- commit d755665
* Thu Jan  4 2024 msuchanek@suse.de
- config: ppc64le: CONFIG_MEM_SOFT_DIRTY=y (bsc#1218286 ltc#204519).
- commit 20c1c94
* Thu Jan  4 2024 tiwai@suse.de
- rpm/kernel-source.changes.old: Add references of the truncated entries
- commit 09d65ce
* Thu Jan  4 2024 oneukum@suse.com
- media: mediatek: vcodec: Add debug params to control different
  log level (git-fixes).
- commit c0c8ce6
* Thu Jan  4 2024 oneukum@suse.com
- media: mediatek: vcodec: Add debugfs interface to get debug
  information (git-fixes).
- commit 26e0de4
* Thu Jan  4 2024 oneukum@suse.com
- media: mediatek: vcodec: fix AV1 decode fail for 36bit iova
  (git-fixes).
- commit 0051dd0
* Thu Jan  4 2024 oneukum@suse.com
- media: mediatek: vcodec: support stateless AV1 decoder
  (git-fixes).
- commit b7dcb87
* Thu Jan  4 2024 oneukum@suse.com
- media: mediatek: vcodec: Removing useless debug log (git-fixes).
- commit 0d64628
* Thu Jan  4 2024 oneukum@suse.com
- media: mediatek: vcodec: move core context from device to each
  instance (git-fixes).
- Refresh
  patches.suse/media-mediatek-vcodec-fix-potential-double-free.patch.
- commit 8d9cbbe
* Thu Jan  4 2024 oneukum@suse.com
- media: mediatek: vcodec: support stateless hevc decoder
  (git-fixes).
- commit 942b219
* Thu Jan  4 2024 pjakobsson@suse.de
- drm/i915/display: Eliminate IS_METEORLAKE checks (git-fixes).
- commit 7ad18c2
* Thu Jan  4 2024 pjakobsson@suse.de
- drm/i915: Eliminate IS_MTL_DISPLAY_STEP (git-fixes).
- commit 7ca4a24
* Thu Jan  4 2024 pjakobsson@suse.de
- drm/i915: Replace several IS_METEORLAKE with proper IP version
  checks (git-fixes).
- commit 58c8fe6
* Thu Jan  4 2024 pjakobsson@suse.de
- drm/i915/mtl: Eliminate subplatforms (git-fixes).
- commit cd2a9ea
* Thu Jan  4 2024 pjakobsson@suse.de
- drm/i915: Eliminate IS_MTL_MEDIA_STEP (git-fixes).
- Refresh
  patches.suse/drm-i915-dg2-Drop-pre-production-display-workarounds.patch.
- commit 3916da5
* Thu Jan  4 2024 pjakobsson@suse.de
- drm/i915: Eliminate IS_MTL_GRAPHICS_STEP (git-fixes).
- commit 1469af7
* Thu Jan  4 2024 pjakobsson@suse.de
- drm/i915/xelpg: Call Xe_LPG workaround functions based on IP
  version (git-fixes).
- commit 616fa82
* Thu Jan  4 2024 pjakobsson@suse.de
- drm/i915/xelpmp: Don't assume workarounds extend to future
  platforms (git-fixes).
- commit ad141ce
* Thu Jan  4 2024 pjakobsson@suse.de
- drm/i915: Consolidate condition for Wa_22011802037 (git-fixes).
- commit cbed939
* Thu Jan  4 2024 pjakobsson@suse.de
- drm/i915/dg2: Drop Wa_16011777198 (git-fixes).
- Refresh
  patches.suse/drm-i915-dg2-Drop-pre-production-display-workarounds.patch.
- commit 11a74f7
* Thu Jan  4 2024 pjakobsson@suse.de
- drm/i915: Tidy workaround definitions (git-fixes).
- commit 616b60d
* Thu Jan  4 2024 pjakobsson@suse.de
- drm/i915/dg2: Drop pre-production GT workarounds (git-fixes).
- commit 49a0f7a
* Thu Jan  4 2024 pjakobsson@suse.de
- drm/i915/dg2: Drop pre-production display workarounds
  (git-fixes).
- commit 4d0a03c
* Thu Jan  4 2024 pjakobsson@suse.de
- drm/i915/dg2: Recognize pre-production hardware (git-fixes).
- commit 126b5be
* Thu Jan  4 2024 pjakobsson@suse.de
- Refresh
  patches.suse/1315-i915-guc-Get-runtime-pm-in-busyness-worker-only-if-a.patch
  (git-fixes)
  Alt-commit
- commit f3e49a6
* Thu Jan  4 2024 tiwai@suse.de
- Revert "PCI/ASPM: Remove pcie_aspm_pm_state_change()"
  (git-fixes).
- commit 1dc63c5
* Thu Jan  4 2024 lduncan@suse.com
- md: fix warning for holder mismatch from export_rdev()
  (git-fixes).
- Refresh patches.suse/md-display-timeout-error.patch.
- commit 152b053
* Wed Jan  3 2024 msuchanek@suse.de
- mkspec: Add multibuild support (JSC-SLE#5501, boo#1211226, bsc#1218184)
  When MULTIBUILD option in config.sh is enabled generate a _multibuild
  file listing all spec files.
- commit f734347
* Wed Jan  3 2024 lduncan@suse.com
- block: fix the exclusive open mask in disk_scan_partitions
  (git-fixes).
- commit 48da2dc
* Wed Jan  3 2024 msuchanek@suse.de
- Build in the correct KOTD repository with multibuild
  (JSC-SLE#5501, boo#1211226, bsc#1218184)
  With multibuild setting repository flags is no longer supported for
  individual spec files - see
  https://github.com/openSUSE/open-build-service/issues/3574
  Add ExclusiveArch conditional that depends on a macro set up by
  bs-upload-kernel instead. With that each package should build only in
  one repository - either standard or QA.
  Note: bs-upload-kernel does not interpret rpm conditionals, and only
  uses the first ExclusiveArch line to determine the architectures to
  enable.
- commit aa5424d
* Wed Jan  3 2024 tbogendoerfer@suse.de
- Update
  patches.suse/dpll-sanitize-possible-null-pointer-dereference-in-d.patch
  (jsc#PED-6079 bsc#1217944 CVE-2023-6679).
  Added CVE reference.
- commit a38c222
* Wed Jan  3 2024 tbogendoerfer@suse.de
- ice: Fix PF with enabled XDP going no-carrier after reset
  (jsc#PED-4876).
- ice: alter feature support check for SRIOV and LAG
  (jsc#PED-4876).
- ice: stop trashing VF VSI aggregator node ID information
  (jsc#PED-4876).
- bnxt_en: do not map packet buffers twice (jsc#PED-5742).
- octeontx2-pf: Fix graceful exit during PFC configuration failure
  (jsc#PED-6931).
- net/mlx5e: Correct snprintf truncation handling for fw_version
  buffer used by representors (jsc#PED-3311).
- net/mlx5e: Correct snprintf truncation handling for fw_version
  buffer (jsc#PED-3311).
- net/mlx5e: Fix error codes in alloc_branch_attr()
  (jsc#PED-3311).
- net/mlx5e: Fix error code in mlx5e_tc_action_miss_mapping_get()
  (jsc#PED-3311).
- net/mlx5: Refactor mlx5_flow_destination->rep pointer to vport
  num (jsc#PED-3311).
- net/mlx5: Fix fw tracer first block check (jsc#PED-3311).
- net/mlx5e: XDP, Drop fragmented packets larger than MTU size
  (jsc#PED-3311).
- net/mlx5e: Decrease num_block_tc when unblock tc offload
  (jsc#PED-3311).
- net/mlx5e: Fix overrun reported by coverity (jsc#PED-3311).
- net/mlx5e: fix a potential double-free in fs_udp_create_groups
  (jsc#PED-3311).
- net/mlx5e: Fix a race in command alloc flow (jsc#PED-3311).
- net/mlx5e: Fix slab-out-of-bounds in
  mlx5_query_nic_vport_mac_list() (jsc#PED-3311).
- net/mlx5e: fix double free of encap_header (jsc#PED-3311).
- Revert "net/mlx5e: fix double free of encap_header"
  (jsc#PED-3311).
- Revert "net/mlx5e: fix double free of encap_header in update
  funcs" (jsc#PED-3311).
- i40e: Fix ST code value for Clause 45 (jsc#PED-4874).
- ice: fix theoretical out-of-bounds access in ethtool link modes
  (jsc#PED-4876).
- commit ca3b156
* Wed Jan  3 2024 msuchanek@suse.de
- rpm/config.sh: Enable multibuild.
- commit 8362cb4
* Wed Jan  3 2024 tonyj@suse.de
- perf vendor events: Update PMC used in PM_RUN_INST_CMPL event
  for power10 platform (jsc#PED-3594, jsc#PED-5091).
- commit 12710f5
* Wed Jan  3 2024 lduncan@suse.com
- block: fix kernel-doc for disk_force_media_change() (git-fixes).
- cdrom/gdrom: Fix build error (git-fixes).
- bcache: Fix bcache device claiming (git-fixes).
- bcache: Alloc holder object before async registration
  (git-fixes).
- md: use mddev->external to select holder in export_rdev()
  (git-fixes).
- commit 38dc146
* Wed Jan  3 2024 tonyj@suse.de
- perf vendor events power10: Update JSON/events (jsc#PED-3594,
  jsc#PED-5091).
- perf vendor events: Update metric events for power10 platform
  (jsc#PED-3594, jsc#PED-5091).
- perf vendor events: Update metric event names for power10
  platform (jsc#PED-3594, jsc#PED-5091).
- perf vendor events: Update JSON/events for power10 platform
  (jsc#PED-3594, jsc#PED-5091).
- perf vendor events: Move JSON/events to appropriate files for
  power10 platform (jsc#PED-3594, jsc#PED-5091).
- perf vendor events: Drop STORES_PER_INST metric event for
  power10 platform (jsc#PED-3594, jsc#PED-5091).
- perf vendor events: Drop some of the JSON/events for power10
  platform (jsc#PED-3594, jsc#PED-5091).
- perf vendor events: Update the JSON/events descriptions for
  power10 platform (jsc#PED-3594, jsc#PED-5091).
- commit 8280d00
* Tue Jan  2 2024 tonyj@suse.de
- perf/x86/intel/uncore: Support Sierra Forest and Grand Ridge
  (jsc#PED-6055, jsc#PED-6010).
- perf/x86/intel/uncore: Support IIO free-running counters on GNR
  (jsc#PED-6055, jsc#PED-6010).
- perf/x86/intel/uncore: Support Granite Rapids (jsc#PED-6055,
  jsc#PED-6010).
- perf/x86/uncore: Use u64 to replace unsigned for the uncore
  offsets array (jsc#PED-6055, jsc#PED-6010).
- perf/x86/intel/uncore: Generic uncore_get_uncores and MMIO
  format of SPR (jsc#PED-6055, jsc#PED-6010).
- commit 5bc21af
* Tue Jan  2 2024 tonyj@suse.de
- x86/cpu: Fix Gracemont uarch (jsc#PED-6055, jsc#PED-6010).
- Refresh patches.suse/x86-cpu-Fix-Crestmont-uarch.patch.
- commit a634889
* Tue Jan  2 2024 lduncan@suse.com
- ext4: Fix warning in blkdev_put() (git-fixes).
- Refresh
  patches.suse/ext4-Fix-reusing-stale-buffer-heads-from-last-f.patch.
- commit fab1a49
* Tue Jan  2 2024 lduncan@suse.com
- reiserfs: fix blkdev_put() warning from release_journal_dev()
  (git-fixes).
- block: fix wrong mode for blkdev_get_by_dev() from
  disk_scan_partitions() (git-fixes).
- commit 8b9d231
* Tue Jan  2 2024 petr.pavlu@suse.com
- ftrace: Fix modification of direct_function hash while in use
  (git-fixes).
- commit b1c0500
* Tue Jan  2 2024 petr.pavlu@suse.com
- tracing: Fix blocked reader of snapshot buffer (git-fixes).
- commit 68d2572
* Tue Jan  2 2024 petr.pavlu@suse.com
- ring-buffer: Fix wake ups when buffer_percent is set to 100
  (git-fixes).
- commit 29d7ef2
* Tue Jan  2 2024 petr.pavlu@suse.com
- 9p: prevent read overrun in protocol dump tracepoint
  (git-fixes).
- commit 9a3061e
* Tue Jan  2 2024 petr.pavlu@suse.com
- tracing / synthetic: Disable events after testing in
  synth_event_gen_test_init() (git-fixes).
- commit 926c2ff
* Tue Jan  2 2024 petr.pavlu@suse.com
- tracing/synthetic: fix kernel-doc warnings (git-fixes).
- commit 53dc6a5
* Tue Jan  2 2024 petr.pavlu@suse.com
- ring-buffer: Fix slowpath of interrupted event (git-fixes).
- commit ba64bb4
* Tue Jan  2 2024 petr.pavlu@suse.com
- ring_buffer: Use try_cmpxchg instead of cmpxchg (git-fixes).
- Refresh
  patches.suse/ring-buffer-Remove-useless-update-to-write_stamp-in-rb_try_to_discard.patch.
- commit b61b3c7
* Tue Jan  2 2024 tiwai@suse.de
- supported.conf: mark pci-pf-stub as supported (bsc#1218245)
- commit f94262a
* Tue Jan  2 2024 tiwai@suse.de
- USB: serial: option: add Quectel EG912Y module support
  (git-fixes).
- USB: serial: ftdi_sio: update Actisense PIDs constant names
  (git-fixes).
- USB: serial: option: add Quectel RM500Q R13 firmware support
  (git-fixes).
- USB: serial: option: add Foxconn T99W265 with new baseline
  (git-fixes).
- iio: tmag5273: fix temperature offset (git-fixes).
- Input: soc_button_array - add mapping for airplane mode button
  (git-fixes).
- ALSA: usb-audio: Increase delay in MOTU M quirk (git-fixes).
- ALSA: hda/realtek: Add quirk for ASUS ROG GV302XA (git-fixes).
- drm/i915/dmc: Don't enable any pipe DMC events (git-fixes).
- drm/i915: Reject async flips with bigjoiner (git-fixes).
- Bluetooth: Add more enc key size check (git-fixes).
- Bluetooth: MGMT/SMP: Fix address type when using SMP over
  BREDR/LE (git-fixes).
- Bluetooth: L2CAP: Send reject on command corrupted request
  (git-fixes).
- Bluetooth: hci_event: Fix not checking if HCI_OP_INQUIRY has
  been sent (git-fixes).
- selftests: mptcp: join: fix subflow_send_ack lookup (git-fixes).
- wifi: cfg80211: fix certs build to not depend on file order
  (git-fixes).
- wifi: cfg80211: Add my certificate (git-fixes).
- spi: cadence: revert "Add SPI transfer delays" (git-fixes).
- drm/i915/edp: don't write to DP_LINK_BW_SET when using rate
  select (git-fixes).
- drm/i915: Introduce crtc_state->enhanced_framing (git-fixes).
- drm/i915: Fix FEC state dump (git-fixes).
- commit a8f651a
* Tue Jan  2 2024 jlee@suse.com
- Update References
  patches.suse/Bluetooth-Reject-connection-with-the-device-which-ha.patch
  (git-fixes bsc#1215237 CVE-2020-26555).
- commit 8449459
* Tue Jan  2 2024 jlee@suse.com
- Update References
  patches.suse/Bluetooth-hci_event-Ignore-NULL-link-key.patch
  (git-fixes bsc#1215237 CVE-2020-26555).
- commit 6302d04
* Sun Dec 31 2023 lduncan@suse.com
- drdb: Convert to use bdev_open_by_path() (bsc#1216436).
- null_blk: fix poll request timeout handling (bsc#1216436).
- floppy: call disk_force_media_change when changing the format
  (bsc#1216436).
- loop: do not enforce max_loop hard limit by (new) default
  (bsc#1216436).
- loop: deprecate autoloading callback loop_probe() (bsc#1216436).
- zram: further limit recompression threshold (bsc#1216436).
- aoe: make aoe_class a static const structure (bsc#1216436).
- brd: use cond_resched instead of cond_resched_rcu (bsc#1216436).
- pktcdvd: Sort headers (bsc#1216436).
- pktcdvd: Get rid of redundant 'else' (bsc#1216436).
- pktcdvd: Use put_unaligned_be16() and get_unaligned_be16()
  (bsc#1216436).
- pktcdvd: Use DEFINE_SHOW_ATTRIBUTE() to simplify code
  (bsc#1216436).
- pktcdvd: Drop redundant castings for sector_t (bsc#1216436).
- pktcdvd: Get rid of pkt_seq_show() forward declaration
  (bsc#1216436).
- pktcdvd: use sysfs_emit() to instead of scnprintf()
  (bsc#1216436).
- pktcdvd: replace sscanf() by kstrtoul() (bsc#1216436).
- commit 46dad64
* Sun Dec 31 2023 lduncan@suse.com
- pktcdvd: Get rid of custom printing macros (bsc#1216436).
- Refresh
  patches.suse/block-use-the-holder-as-indication-for-exclusive-opens.patch.
- commit 740ebd1
* Sun Dec 31 2023 lduncan@suse.com
- brd: use XArray instead of radix-tree to index backing pages
  (bsc#1216436).
- commit c5b0ad5
* Sat Dec 30 2023 lduncan@suse.com
- drbd: Annotate struct fifo_buffer with __counted_by
  (bsc#1216436).
- rbd: take header_rwsem in rbd_dev_refresh() only when updating
  (bsc#1216436).
- rbd: decouple parent info read-in from updating rbd_dev
  (bsc#1216436).
- rbd: decouple header read-in from updating rbd_dev->header
  (bsc#1216436).
- rbd: move rbd_dev_refresh() definition (bsc#1216436).
- drbd: stop defining __KERNEL_SYSCALLS__ (bsc#1216436).
- drbd: use __bio_add_page to add page to bio (bsc#1216436).
- commit f0dd2a2
* Sat Dec 30 2023 tiwai@suse.de
- platform/x86/intel/pmc: Move GBE LTR ignore to suspend callback
  (git-fixes).
- platform/x86/intel/pmc: Allow reenabling LTRs (git-fixes).
- platform/x86/intel/pmc: Add suspend callback (git-fixes).
- platform/x86: p2sb: Allow p2sb_bar() calls during PCI device
  probe (git-fixes).
- linux/export: Ensure natural alignment of kcrctab array
  (git-fixes).
- usb: fotg210-hcd: delete an incorrect bounds test (git-fixes).
- usb-storage: Add quirk for incorrect WP on Kingston DT Ultimate
  3.0 G3 (git-fixes).
- usb: typec: ucsi: fix gpio-based orientation detection
  (git-fixes).
- net: usb: ax88179_178a: avoid failed operations when device
  is disconnected (git-fixes).
- thunderbolt: Fix minimum allocated USB 3.x and PCIe bandwidth
  (git-fixes).
- thunderbolt: Fix memory leak in margining_port_remove()
  (git-fixes).
- iio: adc: imx93: add four channels for imx93 adc (git-fixes).
- interconnect: qcom: sm8250: Enable sync_state (git-fixes).
- interconnect: Treat xlate() returning NULL node as an error
  (git-fixes).
- Input: ipaq-micro-keys - add error handling for devm_kmemdup
  (git-fixes).
- lib/vsprintf: Fix %%pfwf when current node refcount == 0
  (git-fixes).
- pinctrl: at91-pio4: use dedicated lock class for IRQ
  (git-fixes).
- net: phy: skip LED triggers on PHYs on SFP modules (git-fixes).
- net/rose: fix races in rose_kill_by_device() (git-fixes).
- wifi: mt76: fix crash with WED rx support enabled (git-fixes).
- wifi: mac80211: mesh_plink: fix matches_local logic (git-fixes).
- wifi: mac80211: mesh: check element parsing succeeded
  (git-fixes).
- wifi: mac80211: check defragmentation succeeded (git-fixes).
- wifi: mac80211: don't re-add debugfs during reconfig
  (git-fixes).
- net: rfkill: gpio: set GPIO direction (git-fixes).
- wifi: mac80211: check if the existing link config remains
  unchanged (git-fixes).
- wifi: iwlwifi: pcie: add another missing bh-disable for
  rxq->lock (git-fixes).
- wifi: ieee80211: don't require protected vendor action frames
  (git-fixes).
- reset: Fix crash when freeing non-existent optional resets
  (git-fixes).
- platform/x86/intel/pmc: Fix hang in pmc_core_send_ltr_ignore()
  (git-fixes).
- spi: atmel: Fix clock issue when using devices with different
  polarities (git-fixes).
- net/rose: Fix Use-After-Free in rose_ioctl (git-fixes).
- scripts/checkstack.pl: match all stack sizes for s390
  (git-fixes).
- net: usb: qmi_wwan: claim interface 4 for ZTE MF290 (git-fixes).
- nfc: virtual_ncidev: Add variable to check if ndev is running
  (git-fixes).
- usb: aqc111: check packet for fixup for true limit (git-fixes).
- platform/x86: intel_telemetry: Fix kernel doc descriptions
  (git-fixes).
- Input: xpad - add HyperX Clutch Gladiate Support (git-fixes).
- commit 5ce31fd
* Sat Dec 30 2023 tiwai@suse.de
- iio: adc: ti_am335x_adc: Fix return value check of
  tiadc_request_dma() (git-fixes).
- iio: triggered-buffer: prevent possible freeing of wrong buffer
  (git-fixes).
- iio: imu: inv_mpu6050: fix an error code problem in
  inv_mpu6050_read_raw (git-fixes).
- iio: imu: adis16475: add spi_device_id table (git-fixes).
- iio: common: ms_sensors: ms_sensors_i2c: fix humidity conversion
  time table (git-fixes).
- iio: kx022a: Fix acceleration value scaling (git-fixes).
- ASoC: fsl_sai: Fix channel swap issue on i.MX8MP (git-fixes).
- ASoC: hdmi-codec: fix missing report for jack initial status
  (git-fixes).
- ASoC: tas2781: check the validity of prm_no/cfg_no (git-fixes).
- ALSA: hda/tas2781: select program 0, conf 0 by default
  (git-fixes).
- i2c: aspeed: Handle the coalesced stop conditions with the
  start conditions (git-fixes).
- i2c: qcom-geni: fix missing clk_disable_unprepare() and
  geni_se_resources_off() (git-fixes).
- gpio: dwapb: mask/unmask IRQ when disable/enale it (git-fixes).
- gpiolib: cdev: add gpio_device locking wrapper around
  gpio_ioctl() (git-fixes).
- drm/i915/mtl: Fix HDMI/DP PLL clock selection (git-fixes).
- drm/i915/hwmon: Fix static analysis tool reported issues
  (git-fixes).
- drm/amdgpu: re-create idle bo's PTE during VM state machine
  reset (git-fixes).
- Bluetooth: af_bluetooth: Fix Use-After-Free in bt_sock_recvmsg
  (git-fixes).
- Bluetooth: hci_core: Fix hci_conn_hash_lookup_cis (git-fixes).
- Bluetooth: hci_event: shut up a false-positive warning
  (git-fixes).
- Bluetooth: Fix deadlock in vhci_send_frame (git-fixes).
- Bluetooth: Fix not notifying when connection encryption changes
  (git-fixes).
- ARM: OMAP2+: Fix null pointer dereference and memory leak in
  omap_soc_device_init (git-fixes).
- bus: ti-sysc: Flush posted write only after srst_udelay
  (git-fixes).
- drm/amdgpu: fix tear down order in amdgpu_vm_pt_free
  (git-fixes).
- drm/amdgpu/sdma5.2: add begin/end_use ring callbacks
  (git-fixes).
- drm/amd/display: Disable PSR-SU on Parade 0803 TCON again
  (git-fixes).
- drm/i915: Fix ADL+ tiled plane stride when the POT stride is
  smaller than the original (git-fixes).
- drm/i915: Fix intel_atomic_setup_scalers() plane_state handling
  (git-fixes).
- drm/i915: Fix remapped stride with CCS on ADL+ (git-fixes).
- HID: Add quirk for Labtec/ODDOR/aikeec handbrake (git-fixes).
- HID: i2c-hid: Add IDEA5002 to i2c_hid_acpi_blacklist[]
  (git-fixes).
- HID: multitouch: Add quirk for HONOR GLO-GXXX touchpad
  (git-fixes).
- HID: hid-asus: reset the backlight brightness level on resume
  (git-fixes).
- HID: hid-asus: add const to read-only outgoing usb buffer
  (git-fixes).
- HID: add ALWAYS_POLL quirk for Apple kb (git-fixes).
- HID: glorious: fix Glorious Model I HID report (git-fixes).
- HID: mcp2221: Allow IO to start during probe (git-fixes).
- HID: mcp2221: Set driver data before I2C adapter add
  (git-fixes).
- commit 1dc9b8c
* Sat Dec 30 2023 lduncan@suse.com
- nbd: pass nbd_sock to nbd_read_reply() instead of index
  (bsc#1216436).
- nbd: fix null-ptr-dereference while accessing 'nbd->config'
  (bsc#1216436).
- nbd: factor out a helper to get nbd_config without holding
  'config_lock' (bsc#1216436).
- nbd: fold nbd config initialization into nbd_alloc_config()
  (bsc#1216436).
- nbd: fix uaf in nbd_open (bsc#1216436).
- nbd: don't call blk_mark_disk_dead nbd_clear_sock_ioctl
  (bsc#1216436).
- nbd: automatically load module on genl access (bsc#1216436).
- block: simplify the disk_force_media_change interface
  (bsc#1216436).
- nbd: call blk_mark_disk_dead in nbd_clear_sock_ioctl
  (bsc#1216436).
- drivers/rnbd: restore sysfs interface to rnbd-client
  (bsc#1216436).
- scsi: block: virtio_blk: Set zone limits before revalidating
  zones (bsc#1216436).
- scsi: block: nullblk: Set zone limits before revalidating zones
  (bsc#1216436).
- block/rnbd: make all 'class' structures const (bsc#1216436).
- block: move a few internal definitions out of blkdev.h
  (bsc#1216436).
- rnbd-srv: replace sess->open_flags with a "bool readonly"
  (bsc#1216436).
- commit 12893ed
* Fri Dec 29 2023 lduncan@suse.com
- block: use the holder as indication for exclusive opens
  (bsc#1216436).
- Refresh
  patches.suse/ext4-Fix-reusing-stale-buffer-heads-from-last-f.patch.
- Refresh patches.suse/target-add-rbd-backend.patch.
- commit c8ca904
* Fri Dec 29 2023 shung-hsi.yu@suse.com
- selftests/bpf: lsm_cgroup define sockaddr_ll (jsc#PED-6811).
- commit 89c43a8
* Fri Dec 29 2023 jlee@suse.com
- KEYS: use kfree_sensitive with key (jsc#PED-5460).
- KEYS: fix kernel-doc warnings in verify_pefile (jsc#PED-5460).
- KEYS: Replace all non-returning strlcpy with strscpy
  (jsc#PED-5460).
- commit 49cc465
* Thu Dec 28 2023 lduncan@suse.com
- rnbd-srv: don't pass a holder for non-exclusive
  blkdev_get_by_path (bsc#1216436).
- commit 87004c4
* Thu Dec 28 2023 lduncan@suse.com
- swsusp: don't pass a stack address to blkdev_get_by_path
  (bsc#1216436).
- block: remove the unused mode argument to ->release
  (bsc#1216436).
- block: pass a gendisk to ->open (bsc#1216436).
- block: pass a gendisk on bdev_check_media_change (bsc#1216436).
- cdrom: remove the unused mode argument to cdrom_release
  (bsc#1216436).
- cdrom: track if a cdrom_device_info was opened for data
  (bsc#1216436).
- cdrom: remove the unused bdev argument to cdrom_open
  (bsc#1216436).
- block/rnbd-srv: make process_msg_sess_info returns void
  (bsc#1216436).
- block/rnbd-srv: init err earlier in rnbd_srv_init_module
  (bsc#1216436).
- block/rnbd-srv: init ret with 0 instead of -EPERM (bsc#1216436).
- block/rnbd-srv: rename one member in rnbd_srv_dev (bsc#1216436).
- block/rnbd-srv: no need to check sess_dev (bsc#1216436).
- block/rnbd: introduce rnbd_access_modes (bsc#1216436).
- block/rnbd-srv: remove unused header (bsc#1216436).
- block/rnbd: kill rnbd_flags_supported (bsc#1216436).
- nbd: Add the maximum limit of allocated index in nbd_dev_add
  (bsc#1216436).
- commit dfaefc2
* Thu Dec 28 2023 shung-hsi.yu@suse.com
- bpf: Fix missed rcu read lock in bpf_task_under_cgroup()
  (jsc#PED-6811).
- selftests/bpf: Fix a CI failure caused by vsock write
  (jsc#PED-6811).
- selftests/bpf: Fix flaky cgroup_iter_sleepable subtest
  (jsc#PED-6811).
- bpf: Ensure kptr_struct_meta is non-NULL for collection insert
  and refcount_acquire (jsc#PED-6811).
- libbpf: Set close-on-exec flag on gzopen (jsc#PED-6811).
- selftests/bpf: Add sockmap test for redirecting partial skb data
  (jsc#PED-6811).
- selftests/bpf: Add more tests for check_max_stack_depth bug
  (jsc#PED-6811).
- selftests/bpf: Add selftest for check_stack_max_depth bug
  (jsc#PED-6811).
- commit 00d8cd6
* Thu Dec 28 2023 jlee@suse.com
- Update
  patches.suse/tty-n_gsm-fix-the-UAF-caused-by-race-condition.patch
  (bsc#1012628 bsc#1218335 CVE-2023-6546).
- commit 6ab066d
* Thu Dec 28 2023 shung-hsi.yu@suse.com
- bpf, docs: Document existing macros instead of deprecated
  (jsc#PED-6811).
- bpf, docs: BPF Iterator Document (jsc#PED-6811).
- selftests/bpf: Fix compilation failure for prog
  vrf_socket_lookup (jsc#PED-6811).
- selftests/bpf: Add vrf_socket_lookup tests (jsc#PED-6811).
- selftests/bpf: Set the default value of consumer_cnt as 0
  (jsc#PED-6811).
- selftests/bpf: Ensure that next_cpu() returns a valid CPU number
  (jsc#PED-6811).
- selftests/bpf: Output the correct error code for pthread APIs
  (jsc#PED-6811).
- selftests/bpf: Use producer_cnt to allocate local counter array
  (jsc#PED-6811).
- bpf: Keep BPF_PROG_LOAD permission checks clear of validations
  (jsc#PED-6811).
- selftests/bpf: Verify that check_ids() is used for scalars in
  regsafe() (jsc#PED-6811).
- selftests/bpf: Check if mark_chain_precision() follows scalar
  ids (jsc#PED-6811).
- bpf/docs: Update documentation for new cpumask kfuncs
  (jsc#PED-6811).
- selftests/bpf: Update bpf_cpumask_any* tests to use
  bpf_cpumask_any_distribute* (jsc#PED-6811).
- bpf: Replace bpf_cpumask_any* with bpf_cpumask_any_distribute*
  (jsc#PED-6811).
- selftests/bpf: Add test for new bpf_cpumask_first_and() kfunc
  (jsc#PED-6811).
- bpf: Add bpf_cpumask_first_and() kfunc (jsc#PED-6811).
- bpf: Hide unused bpf_patch_call_args (jsc#PED-6811).
- selftests/bpf: Add missing prototypes for several test kfuncs
  (jsc#PED-6811).
- bpf: Factor out a common helper free_all() (jsc#PED-6811).
- bpf: Cleanup unused function declaration (jsc#PED-6811).
- selftests/bpf: Add missing selftests kconfig options
  (jsc#PED-6811).
- selftests/bpf: Add test for non-NULLable PTR_TO_BTF_IDs
  (jsc#PED-6811).
- bpf: Teach verifier that trusted PTR_TO_BTF_ID pointers are
  non-NULL (jsc#PED-6811).
- bpf: Replace open code with for allocated object check
  (jsc#PED-6811).
- bpf/xdp: optimize bpf_xdp_pointer to avoid reading sinfo
  (jsc#PED-6811).
- selftests/bpf: Test table ID fib lookup BPF helper
  (jsc#PED-6811).
- bpf: Add table ID to bpf_fib_lookup BPF helper (jsc#PED-6811).
- net: Use umd_cleanup_helper() (jsc#PED-6811).
- bpf: Replace all non-returning strlcpy with strscpy
  (jsc#PED-6811).
- bpf/tests: Use struct_size() (jsc#PED-6811).
- selftests/bpf: Add a test where map key_type_id with decl_tag
  type (jsc#PED-6811).
- bpf: Fix bad unlock balance on freeze_mutex (jsc#PED-6811).
- libbpf: Ensure FD >= 3 during bpf_map__reuse_fd()
  (jsc#PED-6811).
- libbpf: Ensure libbpf always opens files with O_CLOEXEC
  (jsc#PED-6811).
- selftests/bpf: Check whether to run selftest (jsc#PED-6811).
- libbpf: Change var type in datasec resize func (jsc#PED-6811).
- bpf: drop unnecessary bpf_capable() check in BPF_MAP_FREEZE
  command (jsc#PED-6811).
- libbpf: Selftests for resizing datasec maps (jsc#PED-6811).
- libbpf: Add capability for resizing datasec maps (jsc#PED-6811).
- selftests/bpf: Add path_fd-based BPF_OBJ_PIN and BPF_OBJ_GET
  tests (jsc#PED-6811).
- libbpf: Add opts-based bpf_obj_pin() API and add support for
  path_fd (jsc#PED-6811).
- bpf: Support O_PATH FDs in BPF_OBJ_PIN and BPF_OBJ_GET commands
  (jsc#PED-6811).
- libbpf: Start v1.3 development cycle (jsc#PED-6811).
- bpf: Validate BPF object in BPF_OBJ_PIN before calling LSM
  (jsc#PED-6811).
- bpftool: Specify XDP Hints ifname when loading program
  (jsc#PED-6811).
- selftests/bpf: Add xdp_feature selftest for bond device
  (jsc#PED-6811).
- selftests/bpf: Test bpf_sock_destroy (jsc#PED-6811).
- selftests/bpf: Add helper to get port using getsockname
  (jsc#PED-6811).
- bpf: Add bpf_sock_destroy kfunc (jsc#PED-6811).
- bpf: Add kfunc filter function to 'struct btf_kfunc_id_set'
  (jsc#PED-6811).
- bpf: udp: Implement batching for sockets iterator
  (jsc#PED-6811).
- udp: seq_file: Remove bpf_seq_afinfo from udp_iter_state
  (jsc#PED-6811).
- bpf: udp: Encapsulate logic to get udp table (jsc#PED-6811).
- udp: seq_file: Helper function to match socket attributes
  (jsc#PED-6811).
- bpftool: Show target_{obj,btf}_id in tracing link info
  (jsc#PED-6811).
- bpf: Show target_{obj,btf}_id in tracing link fdinfo
  (jsc#PED-6811).
- selftests/bpf: Make bpf_dynptr_is_rdonly() prototyype consistent
  with kernel (jsc#PED-6811).
- selftests/bpf: Fix dynptr/test_dynptr_is_null (jsc#PED-6811).
- bpf, docs: Shift operations are defined to use a mask
  (jsc#PED-6811).
- bpftool: Support bpffs mountpoint as pin path for prog loadall
  (jsc#PED-6811).
- selftests/xsk: adjust packet pacing for multi-buffer support
  (jsc#PED-6811).
- selftests/xsk: generate data for multi-buffer packets
  (jsc#PED-6811).
- selftests/xsk: populate fill ring based on frags needed
  (jsc#PED-6811).
- selftests/xsx: test for huge pages only once (jsc#PED-6811).
- selftests/xsk: store offset in pkt instead of addr
  (jsc#PED-6811).
- selftests/xsk: add packet iterator for tx to packet stream
  (jsc#PED-6811).
- selftests/xsk: dump packet at error (jsc#PED-6811).
- selftests/xsk: add varying payload pattern within packet
  (jsc#PED-6811).
- selftests/xsk: generate simpler packets with variable length
  (jsc#PED-6811).
- selftests/xsk: do not change XDP program when not necessary
  (jsc#PED-6811).
- bpf: Move kernel test kfuncs to bpf_testmod (jsc#PED-6811).
- selftests/bpf: Remove extern from kfuncs declarations
  (jsc#PED-6811).
- selftests/bpf: Allow to use kfunc from testmod.ko in
  test_verifier (jsc#PED-6811).
- selftests/bpf: Load bpf_testmod for verifier test
  (jsc#PED-6811).
- selftests/bpf: Use un/load_bpf_testmod functions in tests
  (jsc#PED-6811).
- selftests/bpf: Do not unload bpf_testmod in load_bpf_testmod
  (jsc#PED-6811).
- selftests/bpf: Use only stdout in un/load_bpf_testmod functions
  (jsc#PED-6811).
- selftests/bpf: Move test_progs helpers to testing_helpers object
  (jsc#PED-6811).
- selftests/bpf: Move kfunc exports to
  bpf_testmod/bpf_testmod_kfunc.h (jsc#PED-6811).
- libbpf: Store zero fd to fd_array for loader kfunc relocation
  (jsc#PED-6811).
- selftests/bpf: Fix s390 sock_field test failure (jsc#PED-6811).
- selftests/bpf: improve netcnt test robustness (jsc#PED-6811).
- bpf, arm64: Support struct arguments in the BPF trampoline
  (jsc#PED-6811).
- bpf: fix calculation of subseq_idx during precision backtracking
  (jsc#PED-6811).
- refresh context of
  patches.suse/bpf-Use-scalar-ids-in-mark_chain_precision.patch
- bpf: Document EFAULT changes for sockopt (jsc#PED-6811).
- selftests/bpf: Correctly handle optlen > 4096 (jsc#PED-6811).
- selftests/bpf: Update EFAULT {g,s}etsockopt selftests
  (jsc#PED-6811).
- bpf: Add --skip_encoding_btf_inconsistent_proto,
  - -btf_gen_optimized to pahole flags for v1.25 (jsc#PED-6811).
- selftests/bpf: Accept mem from dynptr in helper funcs
  (jsc#PED-6811).
- bpf: verifier: Accept dynptr mem as mem in helpers
  (jsc#PED-6811).
- selftests/bpf: Check overflow in optional buffer (jsc#PED-6811).
- selftests/bpf: Test allowing NULL buffer in dynptr slice
  (jsc#PED-6811).
- bpf: Allow NULL buffers in bpf_dynptr_slice(_rw) (jsc#PED-6811).
- selftests/bpf: Add testcase for bpf_task_under_cgroup
  (jsc#PED-6811).
- bpf: Add bpf_task_under_cgroup() kfunc (jsc#PED-6811).
- bpf, docs: Update llvm_relocs.rst with typo fixes
  (jsc#PED-6811).
- selftests/bpf: revert iter test subprog precision workaround
  (jsc#PED-6811).
- selftests/bpf: add precision propagation tests in the presence
  of subprogs (jsc#PED-6811).
- bpf: support precision propagation in the presence of subprogs
  (jsc#PED-6811).
- bpf: fix mark_all_scalars_precise use in mark_chain_precision
  (jsc#PED-6811).
- bpf: mark relevant stack slots scratched for register read
  instructions (jsc#PED-6811).
- veristat: add -t flag for adding BPF_F_TEST_STATE_FREQ program
  flag (jsc#PED-6811).
- libbpf: Fix comment about arc and riscv arch in bpf_tracing.h
  (jsc#PED-6811).
- bpf: Emit struct bpf_tcp_sock type in vmlinux BTF
  (jsc#PED-6811).
- selftests/bpf: Test_progs can read test lists from file
  (jsc#PED-6811).
- selftests/bpf: Extract insert_test from parse_test_list
  (jsc#PED-6811).
- selftests/bpf: Add fexit_sleep to DENYLIST.aarch64
  (jsc#PED-6811).
- selftests/bpf: Fix selftest test_global_funcs/global_func1
  failure with latest clang (jsc#PED-6811).
- bpftool: Dump map id instead of value for map_of_maps types
  (jsc#PED-6811).
- selftests/bpf: Update the aarch64 tests deny list
  (jsc#PED-6811).
- bpftool: Show map IDs along with struct_ops links
  (jsc#PED-6811).
- docs/bpf: Add LRU internals description and graph
  (jsc#PED-6811).
- docs/bpf: Add table to describe LRU properties (jsc#PED-6811).
- selftests/bpf: Add test case to assert precise scalar path
  pruning (jsc#PED-6811).
- selftests/bpf: Add tests for dynptr convenience helpers
  (jsc#PED-6811).
- bpf: Add bpf_dynptr_clone (jsc#PED-6811).
- refresh context in
  patches.suse/bpf-Make-bpf_refcount_acquire-fallible-for-non-.patch
- bpf: Add bpf_dynptr_size (jsc#PED-6811).
- bpf: Add bpf_dynptr_is_null and bpf_dynptr_is_rdonly
  (jsc#PED-6811).
- bpf: Add bpf_dynptr_adjust (jsc#PED-6811).
- kallsyms: remove unused arch_get_kallsym() helper
  (jsc#PED-6811).
- commit a4a043b
* Wed Dec 27 2023 palcantara@suse.de
- smb: client: fix OOB in smbCalcSize() (bsc#1217947
  CVE-2023-6606).
- commit b60bc77
* Fri Dec 22 2023 mfranc@suse.cz
- s390/vx: fix save/restore of fpu kernel context (git-fixes
  bsc#1218359).
- commit 3ba3bc2
* Fri Dec 22 2023 dwagner@suse.de
- nvme: fix deadlock between reset and scan (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: prevent potential spectre v1 gadget (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: improve NVME_HOST_AUTH and NVME_TARGET_AUTH config
  descriptions (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062
  jsc#PED-3535).
- nvme-ioctl: move capable() admin check to the end (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: ensure reset state check ordering (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
  Refresh:
  - patches.suse/nvme-tcp-do-not-terminate-commands-when-in-resetting.patch
  - patches.suse/nvme-tcp-make-err_work-a-delayed-work.patch
- nvme: introduce helper function to get ctrl state (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-core: check for too small lba shift (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: check for valid nvme_identify_ns() before using it
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-core: fix a memory leak in nvme_ns_info_from_identify()
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: fine-tune sending of first keep-alive (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: tcp: fix compile-time checks for TLS mode (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: target: fix Kconfig select statements (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: target: fix nvme_keyring_id() references (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: move nvme_stop_keep_alive() back to original position
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvmet-tcp: always initialize tls_handshake_tmo_work
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- commit b03ed0f
* Fri Dec 22 2023 denis.kirjanov@suse.com
- net/smc: Fix pos miscalculation in statistics (bsc#1218139).
- commit 7941d68
* Fri Dec 22 2023 denis.kirjanov@suse.com
- ipv4: igmp: fix refcnt uaf issue when receiving igmp query
  packet (bsc#1218253 CVE-2023-6932).
- commit af60a2b
* Fri Dec 22 2023 tonyj@suse.de
- perf: Fix perf_event_validate_size() lockdep splat
  (CVE-2023-6931 bsc#1218258).
- perf: Fix perf_event_validate_size() (CVE-2023-6931
  bsc#1218258).
- commit 0110162
* Thu Dec 21 2023 oneukum@suse.com
- thunderbolt: Only add device router DP IN to the head of the
  DP resource list (jsc#PED-6054).
- commit 73bf26d
* Thu Dec 21 2023 oneukum@suse.com
- thunderbolt: Add DP IN added last in the head of the list of
  DP resources (jsc#PED-6054).
- commit b502fd4
* Wed Dec 20 2023 dwagner@suse.de
- scsi: lpfc: use unsigned type for num_sge (bsc#1214747).
- commit 50bbe87
* Wed Dec 20 2023 oneukum@suse.com
- r8152: Add RTL8152_INACCESSIBLE checks to more loops
  (git-fixes).
- commit e6c2185
* Wed Dec 20 2023 oneukum@suse.com
- r8152: Rename RTL8152_UNPLUG to RTL8152_INACCESSIBLE
  (git-fixes).
- commit 6479271
* Wed Dec 20 2023 oneukum@suse.com
- r8152: Add RTL8152_INACCESSIBLE to r8153_aldps_en() (git-fixes).
- commit e5544fb
* Wed Dec 20 2023 oneukum@suse.com
- r8152: Add RTL8152_INACCESSIBLE to r8153_pre_firmware_1()
  (git-fixes).
- commit a3f8de5
* Wed Dec 20 2023 oneukum@suse.com
- r8152: Add RTL8152_INACCESSIBLE to r8156b_wait_loading_flash()
  (git-fixes).
- commit c0fbad7
* Wed Dec 20 2023 tbogendoerfer@suse.de
- iavf: Fix iavf_shutdown to call iavf_remove instead iavf_close
  (jsc#PED-4937).
- iavf: Handle ntuple on/off based on new state machines for
  flow director (jsc#PED-4937).
- iavf: Introduce new state machines for flow director
  (jsc#PED-4937).
- dpll: sanitize possible null pointer dereference in
  dpll_pin_parent_pin_set() (jsc#PED-6079).
- net: ena: Fix XDP redirection error (git-fixes).
- net: ena: Fix DMA syncing in XDP path when SWIOTLB is on
  (git-fixes).
- net: ena: Fix xdp drops handling due to multibuf packets
  (git-fixes).
- net: ena: Destroy correct number of xdp queues upon failure
  (git-fixes).
- qed: Fix a potential use-after-free in qed_cxt_tables_alloc
  (jsc#PED-5734).
- octeontx2-af: Fix pause frame configuration (jsc#PED-6931).
- octeontx2-af: Update RSS algorithm index (jsc#PED-6931).
- octeontx2-pf: Fix promisc mcam entry action (jsc#PED-6931).
- octeon_ep: explicitly test for firmware ready value
  (jsc#PED-6954).
- octeontx2-af: fix a use-after-free in rvu_nix_register_reporters
  (jsc#PED-6931).
- bnxt_en: Fix HWTSTAMP_FILTER_ALL packet timestamp logic
  (jsc#PED-5742).
- bnxt_en: Fix wrong return value check in bnxt_close_nic()
  (jsc#PED-5742).
- bnxt_en: Fix skb recycling logic in bnxt_deliver_skb()
  (jsc#PED-5742).
- bnxt_en: Clear resource reservation during resume
  (jsc#PED-5742).
- octeon_ep: initialise control mbox tasks before using APIs
  (jsc#PED-6954).
- net/mlx5: Fix a NULL vs IS_ERR() check (jsc#PED-3311).
- net/mlx5e: Check netdev pointer before checking its net ns
  (jsc#PED-3311).
- net/mlx5: Nack sync reset request when HotPlug is enabled
  (jsc#PED-3311).
- net/mlx5e: TC, Don't offload post action rule if not supported
  (jsc#PED-3311).
- net/mlx5e: Fix possible deadlock on mlx5e_tx_timeout_work
  (jsc#PED-3311).
- net/mlx5e: Disable IPsec offload support if not FW steering
  (jsc#PED-3311).
- net/mlx5e: Check the number of elements before walk TC
  rhashtable (jsc#PED-3311).
- net/mlx5e: Reduce eswitch mode_lock protection context
  (jsc#PED-3311).
- net/mlx5e: Tidy up IPsec NAT-T SA discovery (jsc#PED-3311).
- net/mlx5e: Add IPsec and ASO syndromes check in HW
  (jsc#PED-3311).
- net/mlx5e: Remove exposure of IPsec RX flow steering struct
  (jsc#PED-3311).
- net/mlx5e: Unify esw and normal IPsec status table
  creation/destruction (jsc#PED-3311).
- net/mlx5e: Ensure that IPsec sequence packet number starts
  from 1 (jsc#PED-3311).
- net/mlx5e: Honor user choice of IPsec replay window size
  (jsc#PED-3311).
- iavf: validate tx_coalesce_usecs even if rx_coalesce_usecs is
  zero (jsc#PED-4937).
- i40e: Fix unexpected MFS warning message (jsc#PED-4874).
- ice: Restore fix disabling RX VLAN filtering (jsc#PED-4876).
- ice: change vfs.num_msix_per to vf->num_msix (jsc#PED-4876).
- octeontx2-af: Update Tx link register range (jsc#PED-6931).
- octeontx2-af: Add missing mcs flr handler call (jsc#PED-6931).
- octeontx2-af: Fix mcs stats register address (jsc#PED-6931).
- octeontx2-af: Fix mcs sa cam entries size (jsc#PED-6931).
- octeontx2-af: Adjust Tx credits when MCS external bypass is
  disabled (jsc#PED-6931).
- ionic: Fix dim work handling in split interrupt mode
  (jsc#PED-6953).
- ionic: fix snprintf format length warning (jsc#PED-6953).
- net: bnxt: fix a potential use-after-free in bnxt_init_tc
  (jsc#PED-5742).
- octeontx2-af: fix a use-after-free in rvu_npa_register_reporters
  (jsc#PED-6931).
- octeontx2-pf: consider both Rx and Tx packet stats for adaptive
  interrupt coalescing (jsc#PED-6931).
- octeontx2-af: Check return value of nix_get_nixlf before using
  nixlf (jsc#PED-6931).
- octeontx2-pf: Add missing mutex lock in otx2_get_pauseparam
  (jsc#PED-6931).
- vdpa/mlx5: preserve CVQ vringh index (jsc#PED-3311).
- ice: Fix VF Reset paths when interface in a failed over
  aggregate (jsc#PED-4876).
- tools: ynl-gen: always construct struct ynl_req_state
  (git-fixes).
- octeontx2-pf: Restore TC ingress police rules when interface
  is up (jsc#PED-6931).
- octeontx2-pf: Fix adding mbox work queue entry when num_vfs >
  64 (jsc#PED-6931).
- octeontx2-af: Fix possible buffer overflow (jsc#PED-6931).
- tg3: Increment tx_dropped in tg3_tso_bug() (jsc#PED-5736).
- tg3: Move thex_dropped counters to tg3_napi (jsc#PED-5736).
- tg3: Fix the TX ring stall (jsc#PED-5736).
- tg3: power down device only on SYSTEM_POWER_OFF (jsc#PED-5736).
- tg3: Improve PTP TX timestamping logic (jsc#PED-5736).
- tun: prevent negative ifindex (git-fixes).
- net: ena: Flush XDP packets on error (git-fixes).
- net: ena: Use pci_dev_id() to simplify the code (git-fixes).
- tg3: Use pci_dev_id() to simplify the code (jsc#PED-5736).
- net: ena: Add dynamic recycling mechanism for rx buffers
  (git-fixes).
- commit 43e6daa
* Wed Dec 20 2023 oneukum@suse.com
- mm: make PR_MDWE_REFUSE_EXEC_GAIN an unsigned long (git-fixes).
- commit fc58eb5
* Wed Dec 20 2023 oneukum@suse.com
- jbd2: remove unused t_handle_lock (git-fixes).
- commit e50bd21
* Wed Dec 20 2023 oneukum@suse.com
- smackfs: Prevent underflow in smk_set_cipso() (git-fixes).
- commit 19ba679
* Wed Dec 20 2023 oneukum@suse.com
- swiotlb: move slot allocation explanation comment where it
  belongs (git-fixes).
- commit cdccf55
* Wed Dec 20 2023 oneukum@suse.com
- cpupower: Bump soname version (git-fixes).
- commit a912f28
* Wed Dec 20 2023 oneukum@suse.com
- refscale: Fix uninitalized use of wait_queue_head_t (git-fixes).
- commit 06a01d7
* Wed Dec 20 2023 oneukum@suse.com
- cpumask: eliminate kernel-doc warnings (git-fixes).
- commit 94d578f
* Wed Dec 20 2023 oneukum@suse.com
- cpumask: fix function description kernel-doc notation
  (git-fixes).
- commit 8b6305c
* Wed Dec 20 2023 oneukum@suse.com
- Revert ".gitignore: ignore *.cover and *.mbx" (git-fixes).
- commit ac2dce9
* Tue Dec 19 2023 krisman@suse.de
- tcp: Fix listen() warning with v4-mapped-v6 address (git-fixes).
- tcp: Fix bind() regression for v4-mapped-v6 non-wildcard address
  (git-fixes).
- tcp: Fix bind() regression for v4-mapped-v6 wildcard address
  (git-fixes).
- tcp: Factorise sk_family-independent comparison in
  inet_bind2_bucket_match(_addr_any) (git-fixes).
- commit 41534fb
* Tue Dec 19 2023 jack@suse.cz
- Disable CONFIG_DEBUG_CREDENTIALS again because the feature has been
  removed from upstream in the mean time (jsc#PED-6721)"
- commit 3c8d7db
* Tue Dec 19 2023 petr.pavlu@suse.com
- ring-buffer: Have rb_time_cmpxchg() set the msb counter too
  (git-fixes).
- commit 29f5745
* Tue Dec 19 2023 petr.pavlu@suse.com
- ring-buffer: Fix 32-bit rb_time_read() race with
  rb_time_cmpxchg() (git-fixes).
- commit 2dbbea6
* Tue Dec 19 2023 petr.pavlu@suse.com
- ring-buffer: Fix a race in rb_time_cmpxchg() for 32 bit archs
  (git-fixes).
- commit 89b9305
* Tue Dec 19 2023 petr.pavlu@suse.com
- ring-buffer: Remove useless update to write_stamp in
  rb_try_to_discard() (git-fixes).
- commit c9b15cc
* Tue Dec 19 2023 petr.pavlu@suse.com
- ring-buffer: Do not try to put back write_stamp (git-fixes).
- commit c35af22
* Tue Dec 19 2023 petr.pavlu@suse.com
- ring-buffer: Have saved event hold the entire event (git-fixes).
- commit fada082
* Tue Dec 19 2023 petr.pavlu@suse.com
- ring-buffer: Do not update before stamp when switching
  sub-buffers (git-fixes).
- commit 9bf543e
* Tue Dec 19 2023 petr.pavlu@suse.com
- tracing: Update snapshot buffer on resize if it is allocated
  (git-fixes).
- commit caf0573
* Tue Dec 19 2023 petr.pavlu@suse.com
- ring-buffer: Fix memory leak of free page (git-fixes).
- commit a733f18
* Tue Dec 19 2023 petr.pavlu@suse.com
- ring-buffer: Fix writing to the buffer with max_data_size
  (git-fixes).
- commit 91450fc
* Mon Dec 18 2023 tiwai@suse.de
- soundwire: stream: fix NULL pointer dereference for multi_link
  (git-fixes).
- phy: sunplus: return negative error code in sp_usb_phy_probe
  (git-fixes).
- phy: mediatek: mipi: mt8183: fix minimal supported frequency
  (git-fixes).
- dmaengine: idxd: Protect int_handle field in hw descriptor
  (git-fixes).
- dmaengine: stm32-dma: avoid bitfield overflow assertion
  (git-fixes).
- dmaengine: ti: k3-psil-am62a: Fix SPI PDMA data (git-fixes).
- dmaengine: ti: k3-psil-am62: Fix SPI PDMA data (git-fixes).
- kernel/resource: Increment by align value in
  get_free_mem_region() (git-fixes).
- clk: rockchip: rk3128: Fix SCLK_SDMMC's clock name (git-fixes).
- clk: rockchip: rk3128: Fix aclk_peri_src's parent (git-fixes).
- commit b545118
* Sun Dec 17 2023 tiwai@suse.de
- drm: Fix FD ownership check in drm_master_check_perm()
  (git-fixes).
- drm/amd/display: fix hw rotated modes when PSR-SU is enabled
  (git-fixes).
- drm: Update file owner during use (git-fixes).
- commit c714f47
* Sat Dec 16 2023 tiwai@suse.de
- ALSA: hda/realtek: Apply mute LED quirk for HP15-db (git-fixes).
- ALSA: hda/hdmi: add force-connect quirks for ASUSTeK Z170
  variants (git-fixes).
- ALSA: hda/hdmi: add force-connect quirk for NUC5CPYB
  (git-fixes).
- commit e03385f
* Sat Dec 16 2023 tiwai@suse.de
- arm64: mm: Always make sw-dirty PTEs hw-dirty in pte_modify
  (git-fixes).
- Revert "PCI: acpiphp: Reassign resources on bridge if necessary"
  (git-fixes).
- PCI: vmd: Fix potential deadlock when enabling ASPM (git-fixes).
- PCI/ASPM: Add pci_enable_link_state_locked() (git-fixes).
- PCI: loongson: Limit MRRS to 256 (git-fixes).
- ALSA: hda/tas2781: reset the amp before component_add
  (git-fixes).
- ALSA: hda/tas2781: call cleanup functions only once (git-fixes).
- ALSA: hda/tas2781: handle missing EFI calibration data
  (git-fixes).
- ALSA: hda/tas2781: leave hda_component in usable state
  (git-fixes).
- dt-bindings: panel-simple-dsi: move LG 5" HD TFT LCD panel
  into DSI yaml (git-fixes).
- drm/edid: also call add modes in EDID connector update fallback
  (git-fixes).
- drm/amd/display: Restore guard against default backlight value <
  1 nit (git-fixes).
- drm/i915: Use internal class when counting engine resets
  (git-fixes).
- drm/i915/selftests: Fix engine reset count storage for
  multi-tile (git-fixes).
- drm/mediatek: Fix access violation in mtk_drm_crtc_dma_dev_get
  (git-fixes).
- drm/mediatek: Add spinlock for setting vblank event in
  atomic_begin (git-fixes).
- drm/mediatek: fix kernel oops if no crtc is found (git-fixes).
- commit 5207326
* Fri Dec 15 2023 petr.pavlu@suse.com
- tracing/kprobes: Fix symbol counting logic by looking at
  modules as well (git-fixes).
- commit 67de3c0
* Fri Dec 15 2023 petr.pavlu@suse.com
- Documentation: probes: Add a new ret_ip callback parameter
  (git-fixes).
- commit e84c194
* Fri Dec 15 2023 jbohac@suse.cz
- supported.conf: mark ptp_ocp as supported
  Requested in jsc#PED-7238
- commit e0c28d2
* Fri Dec 15 2023 tiwai@suse.de
- Delete doc/config-options.changes (jsc#PED-5021)
- commit 34b84f2
* Fri Dec 15 2023 jbohac@suse.cz
- ptp: Fix type of mode parameter in ptp_ocp_dpll_mode_get()
  (jsc#PED-7238).
- ptp: ocp: fix error code in probe() (jsc#PED-7238).
- ptp_ocp: implement DPLL ops (jsc#PED-7238).
- ptp: ocp: Fix error handling in ptp_ocp_device_init
  (jsc#PED-7238).
- ptp: ocp: Add .getmaxphase ptp_clock_info callback
  (jsc#PED-7238).
- commit aef9dcd
* Fri Dec 15 2023 petr.pavlu@suse.com
- ring-buffer: Test last update in 32bit version of
  __rb_time_read() (git-fixes).
- commit ddca15e
* Fri Dec 15 2023 petr.pavlu@suse.com
- ring-buffer: Force absolute timestamp on discard of event
  (git-fixes).
- commit 0078764
* Fri Dec 15 2023 petr.pavlu@suse.com
- tracing: Disable snapshot buffer when stopping instance tracers
  (git-fixes).
- commit 2ad5c37
* Fri Dec 15 2023 petr.pavlu@suse.com
- tracing: Stop current tracer when resizing buffer (git-fixes).
- commit 85717e3
* Fri Dec 15 2023 petr.pavlu@suse.com
- tracing: Always update snapshot buffer size (git-fixes).
- commit 55e4ec8
* Fri Dec 15 2023 petr.pavlu@suse.com
- rethook: Use __rcu pointer for rethook::handler (git-fixes).
- commit b909a07
* Fri Dec 15 2023 petr.pavlu@suse.com
- fprobe: Pass return address to the handlers (git-fixes).
- commit f25e9ba
* Fri Dec 15 2023 petr.pavlu@suse.com
- kprobes: consistent rcu api usage for kretprobe holder
  (git-fixes).
- commit 84b3761
* Fri Dec 15 2023 petr.pavlu@suse.com
- tracing/kprobes: Fix the order of argument descriptions
  (git-fixes).
- commit 7eb21fc
* Fri Dec 15 2023 petr.pavlu@suse.com
- tracing: Have the user copy of synthetic event address use
  correct context (git-fixes).
- commit 4b8ad11
* Fri Dec 15 2023 petr.pavlu@suse.com
- tracing: Have trace_event_file have ref counters (git-fixes).
- commit 61d272b
* Fri Dec 15 2023 petr.pavlu@suse.com
- tracing: Expand all ring buffers individually (git-fixes).
- commit 1970232
* Fri Dec 15 2023 petr.pavlu@suse.com
- tracing/kprobes: Fix the description of variable length
  arguments (git-fixes).
- commit df99ba1
* Fri Dec 15 2023 petr.pavlu@suse.com
- tracing/kprobes: Return EADDRNOTAVAIL when func matches several
  symbols (git-fixes).
- commit f57bfdc
* Fri Dec 15 2023 petr.pavlu@suse.com
- neighbor: tracing: Move pin6 inside CONFIG_IPV6=y section
  (git-fixes).
- commit 4700835
* Fri Dec 15 2023 petr.pavlu@suse.com
- fprobe: Fix to ensure the number of active retprobes is not zero
  (git-fixes).
- commit da5f400
* Fri Dec 15 2023 ailiop@suse.com
- iomap: don't skip reading in !uptodate folios when unsharing
  a range (bsc#1218085).
- commit d11e144
* Fri Dec 15 2023 tiwai@suse.de
- sign-file: Fix incorrect return values check (git-fixes).
- commit 3b0f62f
* Thu Dec 14 2023 mfranc@suse.cz
- KVM: s390/mm: Properly reset no-dat (git-fixes bsc#1218054).
- commit be0cefa
* Thu Dec 14 2023 oneukum@suse.com
- thunderbolt: Introduce tb_for_each_upstream_port_on_path()
  (jsc#PED-6054).
- commit c195a89
* Thu Dec 14 2023 tiwai@suse.de
- efi/x86: Avoid physical KASLR on older Dell systems
  (bsc#1217344).
- serial: 8250_dw: Add ACPI ID for Granite Rapids-D UART
  (git-fixes).
- serial: sc16is7xx: address RX timeout interrupt errata
  (git-fixes).
- parport: Add support for Brainboxes IX/UC/PX parallel cards
  (git-fixes).
- nvme-pci: Add sleep quirk for Kingston drives (git-fixes).
- ASoC: qcom: sc8280xp: Limit speaker digital volumes (git-fixes).
- ASoC: ops: add correct range check for limiting volume
  (git-fixes).
- nilfs2: prevent WARNING in nilfs_sufile_set_segment_usage()
  (git-fixes).
- nilfs2: fix missing error check for sb_set_blocksize call
  (git-fixes).
- kconfig: fix memory leak from range properties (git-fixes).
- i2c: designware: Fix corrupted memory seen in the ISR
  (git-fixes).
- drm/amdgpu: correct chunk_ptr to a pointer to chunk (git-fixes).
- drm/amdgpu: finalizing mem_partitions at the end of GMC v9
  sw_fini (git-fixes).
- drm/amdgpu: Do not program VF copy regs in mmhub v1.8 under
  SRIOV (v2) (git-fixes).
- nouveau: use an rwlock for the event lock (git-fixes).
- zstd: Fix array-index-out-of-bounds UBSAN warning (git-fixes).
- drm/amdkfd: get doorbell's absolute offset based on the db_size
  (git-fixes).
- drm/amdgpu: Fix refclk reporting for SMU v13.0.6 (git-fixes).
- drm/amd/amdgpu/amdgpu_doorbell_mgr: Correct misdocumented param
  'doorbell_index' (git-fixes).
- commit 45ae2f4
* Thu Dec 14 2023 oneukum@suse.com
- thunderbolt: Send uevent after asymmetric/symmetric switch
  (jsc#PED-6054).
- commit ad1d6a8
* Thu Dec 14 2023 oneukum@suse.com
- thunderbolt: Fix one kernel-doc comment (jsc#PED-6054).
- commit 0dccd58
* Thu Dec 14 2023 oneukum@suse.com
- thunderbolt: Configure asymmetric link if needed and bandwidth
  allows (jsc#PED-6054).
- commit c7bb9b9
* Thu Dec 14 2023 oneukum@suse.com
- thunderbolt: Add support for asymmetric link (jsc#PED-6054).
- commit 1bf4da2
* Wed Dec 13 2023 oneukum@suse.com
- xhci: Clean up ERST_PTR_MASK inversion (jsc#PED-6054).
- commit 2207ebc
* Wed Dec 13 2023 oneukum@suse.com
- xhci: Set DESI bits in ERDP register correctly (jsc#PED-6054).
- Refresh
  patches.suse/xhci-Adjust-segment-numbers-after-ring-expansion.patch.
- Refresh
  patches.suse/xhci-Use-more-than-one-Event-Ring-segment.patch
- commit 22f918b
* Wed Dec 13 2023 nmorey@suse.com
- RDMA/irdma: Avoid free the non-cqp_request scratch (git-fixes)
- commit cd12372
* Wed Dec 13 2023 nmorey@suse.com
- RDMA/irdma: Fix support for 64k pages (git-fixes)
- commit 261e7e0
* Wed Dec 13 2023 nmorey@suse.com
- RDMA/irdma: Ensure iWarp QP queue memory is OS paged aligned (git-fixes)
- commit b19475f
* Wed Dec 13 2023 nmorey@suse.com
- RDMA/core: Fix umem iterator when PAGE_SIZE is greater then HCA pgsz (git-fixes)
- commit def5131
* Wed Dec 13 2023 nmorey@suse.com
- RDMA/irdma: Fix UAF in irdma_sc_ccq_get_cqe_info() (git-fixes)
- commit 09164cb
* Wed Dec 13 2023 nmorey@suse.com
- RDMA/bnxt_re: Correct module description string (git-fixes)
- commit 4ba52aa
* Wed Dec 13 2023 nmorey@suse.com
- RDMA/rtrs-clt: Remove the warnings for req in_use check (git-fixes)
- commit 4e78606
* Wed Dec 13 2023 nmorey@suse.com
- RDMA/rtrs-clt: Fix the max_send_wr setting (git-fixes)
- commit bb8ff91
* Wed Dec 13 2023 nmorey@suse.com
- RDMA/rtrs-srv: Destroy path files after making sure no IOs in-flight (git-fixes)
- commit 1d28d3d
* Wed Dec 13 2023 nmorey@suse.com
- RDMA/rtrs-srv: Free srv_mr iu only when always_invalidate is true (git-fixes)
- commit 4d9e342
* Wed Dec 13 2023 nmorey@suse.com
- RDMA/rtrs-srv: Check return values while processing info request (git-fixes)
- commit ab870d1
* Wed Dec 13 2023 nmorey@suse.com
- RDMA/rtrs-clt: Start hb after path_up (git-fixes)
- commit 03ea4b1
* Wed Dec 13 2023 nmorey@suse.com
- RDMA/rtrs-srv: Do not unconditionally enable irq (git-fixes)
- commit 35830e7
* Wed Dec 13 2023 nmorey@suse.com
- RDMA/irdma: Add wait for suspend on SQD (git-fixes)
- commit be78063
* Wed Dec 13 2023 nmorey@suse.com
- RDMA/irdma: Do not modify to SQD on error (git-fixes)
- commit 9415f0b
* Wed Dec 13 2023 nmorey@suse.com
- RDMA/hns: Fix unnecessary err return when using invalid congest control algorithm (git-fixes)
- commit 716447b
* Wed Dec 13 2023 nmorey@suse.com
- RDMA/core: Fix uninit-value access in ib_get_eth_speed() (git-fixes)
- commit 5a19ead
* Wed Dec 13 2023 oneukum@suse.com
- xhci: pass port structure to tracing instead of port number
  (jsc#PED-6054).
- commit 109343d
* Wed Dec 13 2023 oneukum@suse.com
- xhci: Expose segment numbers in debugfs (jsc#PED-6054).
- commit c529649
* Wed Dec 13 2023 oneukum@suse.com
- xhci: Update last segment pointer after Event Ring expansion
  (jsc#PED-6054).
- commit 4166daa
* Wed Dec 13 2023 oneukum@suse.com
- xhci: Use more than one Event Ring segment (jsc#PED-6054).
- commit 0938c06
* Wed Dec 13 2023 oneukum@suse.com
- xhci: Adjust segment numbers after ring expansion
  (jsc#PED-6054).
- commit c795cfc
* Wed Dec 13 2023 oneukum@suse.com
- xhci: expand next_trb() helper to support more ring types
  (jsc#PED-6054).
- commit f43e1c2
* Wed Dec 13 2023 oneukum@suse.com
- usb: Inform the USB Type-C class about enumerated devices
  (jsc#6054).
- commit c408f51
* Wed Dec 13 2023 svarbanov@suse.de
- i2c: tegra: Fix failure during probe deferral cleanup (jsc#PED-7377)
- commit e1a3e42
* Wed Dec 13 2023 svarbanov@suse.de
- i2c: tegra: Share same DMA channel for RX and TX (jsc#PED-7377)
- commit 60c8e2f
* Wed Dec 13 2023 oneukum@suse.com
- Update
  patches.suse/usb-typec-intel_pmc_mux-Configure-Displayport-Altern.patch
  (jsc#PED-6028 jsc#PED-6054).
  Added reference
- commit 7144def
* Wed Dec 13 2023 oneukum@suse.com
- Update
  patches.suse/usb-typec-Add-Displayport-Alternate-Mode-2.1-Support.patch
  (jsc#PED-6028 jsc#PED-6054).
  Added reference
- commit f2ceb0d
* Wed Dec 13 2023 oneukum@suse.com
- thunderbolt: Introduce tb_switch_depth() (jsc#PED-6028).
- commit 5fe288f
* Wed Dec 13 2023 svarbanov@suse.de
- cpufreq: tegra194: remove redundant AND with cpu_online_mask (jsc#PED-7377)
- commit 2b048f4
* Wed Dec 13 2023 svarbanov@suse.de
- cpufreq: tegra194: use refclk delta based loop instead of udelay (jsc#PED-7377)
- commit b4d7280
* Wed Dec 13 2023 svarbanov@suse.de
- cpufreq: tegra194: save CPU data to avoid repeated SMP calls (jsc#PED-7377)
- commit 0414ad1
* Wed Dec 13 2023 svarbanov@suse.de
- hwmon: (ina3221) Add support for channel summation disable (jsc#PED-7377)
- commit ea00bac
* Wed Dec 13 2023 svarbanov@suse.de
- memory: tegra: Set BPMP msg flags to reset IPC channels (jsc#PED-7377)
- commit e67ef95
* Wed Dec 13 2023 svarbanov@suse.de
- memory: tegra: Add Tegra234 clients for RCE and VI (jsc#PED-7377)
- commit faa58f6
* Wed Dec 13 2023 oneukum@suse.com
- thunderbolt: Set path power management packet support bit for
  USB4 v2 routers (jsc#PED-6028).
- commit 257221c
* Wed Dec 13 2023 oneukum@suse.com
- thunderbolt: Introduce tb_port_path_direction_downstream()
  (jsc#PED-6028).
- commit 1d8db59
* Wed Dec 13 2023 svarbanov@suse.de
- pinctrl: tegra: Consistently refer to SoC data (jsc#PED-7377)
- commit a8faf7c
* Wed Dec 13 2023 svarbanov@suse.de
- firmware: tegra: bpmp: Add support for DRAM MRQ GSCs (jsc#PED-7377)
- commit 408475f
* Wed Dec 13 2023 svarbanov@suse.de
- gpio: tegra186: Check PMC driver status before any request (jsc#PED-7377)
- commit 3b10a2a
* Wed Dec 13 2023 svarbanov@suse.de
- gpio: tegra186: Check GPIO pin permission before access. (jsc#PED-7377)
- commit 0ce1a89
* Wed Dec 13 2023 svarbanov@suse.de
- PCI: tegra194: Add interconnect support in Tegra234 (jsc#PED-7377)
- commit d74fa9b
* Wed Dec 13 2023 svarbanov@suse.de
- memory: tegra: make icc_set_bw return zero if BWMGR not supported (jsc#PED-7377)
- commit 734a54f
* Wed Dec 13 2023 oneukum@suse.com
- thunderbolt: Use tb_tunnel_dbg() where possible to make logging
  more consistent (jsc#PED-6028).
- commit 7ebfd05
* Wed Dec 13 2023 svarbanov@suse.de
- memory: tegra: Add dummy implementation on Tegra194 (jsc#PED-7377)
- commit d4119f8
* Wed Dec 13 2023 svarbanov@suse.de
- memory: tegra: Make CPU cluster BW request a multiple of MC channels (jsc#PED-7377)
- commit 312222e
* Wed Dec 13 2023 svarbanov@suse.de
- dt-bindings: tegra: Add ICC IDs for dummy memory clients (jsc#PED-7377)
- commit c75c8a3
* Wed Dec 13 2023 svarbanov@suse.de
- memory: tegra: Add software memory clients in Tegra234 (jsc#PED-7377)
- commit 1ccc65b
* Wed Dec 13 2023 svarbanov@suse.de
- memory: tegra: Add memory clients for Tegra234 (jsc#PED-7377)
- commit f35b21d
* Wed Dec 13 2023 svarbanov@suse.de
- memory: tegra: Add interconnect support for DRAM scaling in Tegra234 (jsc#PED-7377)
- commit ccec3a6
* Wed Dec 13 2023 svarbanov@suse.de
- soc/tegra: fuse: Fix Tegra234 fuse size (jsc#PED-7377)
- commit 7495f5c
* Wed Dec 13 2023 svarbanov@suse.de
- soc/tegra: pmc: Add AON SW Wake support for Tegra234 (jsc#PED-7377)
- commit 156c05b
* Wed Dec 13 2023 oneukum@suse.com
- thunderbolt: Change bandwidth reservations to comply USB4 v2
  (jsc#PED-6028).
- commit 306e786
* Wed Dec 13 2023 oneukum@suse.com
- thunderbolt: Make is_gen4_link() available to the rest of the
  driver (jsc#PED-6028).
- commit c1a0a56
* Wed Dec 13 2023 oneukum@suse.com
- thunderbolt: Create multiple DisplayPort tunnels if there are
  more DP IN/OUT pairs (jsc#PED-6028).
- commit 06ff552
* Wed Dec 13 2023 mgorman@suse.de
- x86/sched/itmt: Give all SMT siblings of a core the same
  priority (jsc#PED-6056).
- x86/sched: Remove SD_ASYM_PACKING from the SMT domain flags
  (jsc#PED-6056).
- sched/topology: Remove SHARED_CHILD from ASYM_PACKING
  (jsc#PED-6056).
- commit d22c830
* Wed Dec 13 2023 svarbanov@suse.de
- soc/tegra: fuse: Add support for Tegra264 (jsc#PED-7377)
- commit 920ec24
* Wed Dec 13 2023 oneukum@suse.com
- thunderbolt: Log NVM version of routers and retimers
  (jsc#PED-6028).
- commit 0c50e04
* Wed Dec 13 2023 oneukum@suse.com
- thunderbolt: Use tb_tunnel_xxx() log macros in tb.c
  (jsc#PED-6028).
- commit 605a60c
* Wed Dec 13 2023 oneukum@suse.com
- thunderbolt: Expose tb_tunnel_xxx() log macros to the rest of
  the driver.
- commit 00adf19
* Wed Dec 13 2023 oneukum@suse.com
- thunderbolt: Get rid of usb4_usb3_port_actual_link_rate()
  (jsc#PED-6028).
- commit 76fe0b7
* Wed Dec 13 2023 oneukum@suse.com
- usb: typec: altmodes/displayport: fixup drm internal api change
  vs new user (jsc#PED-6028).
- commit ba2512f
* Wed Dec 13 2023 oneukum@suse.com
- usb: typec: Link enumerated USB devices with Type-C partner
  (jsc#PED-6028).
- Refresh patches.suse/paddings-add-for-type-C-new-in-SP5.patch.
- Refresh patches.suse/typeC-Add-kABI-placeholders.patch.
- commit 4e3b5e7
* Wed Dec 13 2023 oneukum@suse.com
- drm: Add HPD state to drm_connector_oob_hotplug_event()
  (jsc#PED-6028).
- commit ce9139c
* Wed Dec 13 2023 tiwai@suse.de
- HID: lenovo: Restrict detection of patched firmware only to
  USB cptkbd (git-fixes).
- commit 4763471
* Tue Dec 12 2023 oneukum@suse.com
- usb: typec: mux: fix static inline syntax error (jsc#PED-6028).
- commit b8ea6e4
* Tue Dec 12 2023 oneukum@suse.com
- usb: typec: intel_pmc_mux: Configure Displayport Alternate
  mode 2.1 (jsc#PED-6028).
- commit 23d8b36
* Tue Dec 12 2023 oneukum@suse.com
- usb: typec: Add Displayport Alternate Mode 2.1 Support
  (jsc#PED-6028).
- commit 4c18d99
* Tue Dec 12 2023 oneukum@suse.com
- usb: typec: ucsi: Fix NULL pointer dereference (jsc#PED-6028).
- commit caa0786
* Tue Dec 12 2023 oneukum@suse.com
- usb: typec: altmodes/displayport: add support for embedded DP
  cases (jsc#PED-6028).
- commit 98d133c
* Tue Dec 12 2023 oneukum@suse.com
- usb: typec: ucsi: Add debugfs for ucsi commands (jsc#PED-6028).
- commit 98309e5
* Tue Dec 12 2023 oneukum@suse.com
- usb: typec: mux: intel: Add dependency on USB_COMMON
  (jsc#PED-6028).
- commit d0dd47c
* Tue Dec 12 2023 oneukum@suse.com
- Update
  patches.suse/usb-typec-ucsi-Mark-dGPUs-as-DEVICE-scope.patch
  (bsc#1012628 jsc#PED-6028).
  Updated reference
- commit f657452
* Tue Dec 12 2023 oneukum@suse.com
- usb: typec: intel_pmc_mux: Expose IOM port status to debugfs
  (jsc#PED-6028).
- Refresh
  patches.suse/usb-typec-intel_pmc_mux-Add-new-ACPI-ID-for-Lunar-La.patch.
- commit aadc1e8
* Tue Dec 12 2023 oneukum@suse.com
- usb: typec: intel_pmc_mux: Convert to platform remove callback
  returning void (jsc#PED-6028).
- commit 9949917
* Tue Dec 12 2023 oneukum@suse.com
- usb: typec: mux: Remove alt mode parameters from the API
  (jsc#PED-6028).
- commit 40910ac
* Tue Dec 12 2023 oneukum@suse.com
- usb: typec: mux: Clean up mux_fwnode_match() (jsc#PED-6028).
- commit bebd2fd
* Tue Dec 12 2023 oneukum@suse.com
- usb: typec: ucsi: correctly access opcode (git-fixes).
- commit 995d766
* Tue Dec 12 2023 oneukum@suse.com
- usb: typec: mux: gpio-sbu: Convert to platform remove callback
  returning void (jsc#PED-6028).
- commit 6ee1ca6
* Tue Dec 12 2023 oneukum@suse.com
- usb: typec: mux: Remove some unneeded includes (jsc#PED-6028).
- commit 2ab9be1
* Tue Dec 12 2023 oneukum@suse.com
- usb: typec: intel_pmc_mux: Configure Active and Retimer Cable
  type (jsc#PED-6028).
- commit f657439
* Tue Dec 12 2023 tiwai@suse.de
- Update config files: just refreshes
- commit 6e3665c
* Tue Dec 12 2023 tiwai@suse.de
- watchdog: advantech_ec_wdt: fix Kconfig dependencies
  (git-fixes).
- commit 8542b63
* Tue Dec 12 2023 tiwai@suse.de
- tools: iio: iio_generic_buffer ensure alignment (git-fixes).
- tools: iio: iio_generic_buffer: Fix some integer type and
  calculation (git-fixes).
- commit 663b22c
* Tue Dec 12 2023 tiwai@suse.de
- serial: 8250_omap: Fix errors with no_console_suspend
  (git-fixes).
- commit 21b4b9a
* Tue Dec 12 2023 tiwai@suse.de
- pwr-mlxbf: extend Kconfig to include gpio-mlxbf3 dependency
  (git-fixes).
- pwm: atmel-tcb: Fix resource freeing in error path and remove
  (git-fixes).
- pwm: atmel-tcb: Harmonize resource allocation order (git-fixes).
- commit d8a86b1
* Tue Dec 12 2023 tiwai@suse.de
- hwmon: (nct6775) Change labels for nct6799 (git-fixes).
- hwmon: (nct6775) Fix register for nct6799 (git-fixes).
- commit 7fac16b
* Tue Dec 12 2023 tiwai@suse.de
- hwmon: (nct6775) Fix IN scaling factors for 6798/6799
  (git-fixes).
- hwmon: (nct6755) Add support for NCT6799D (git-fixes).
- commit 939e9e6
* Tue Dec 12 2023 tiwai@suse.de
- can: sun4i_can: Only show Kconfig if ARCH_SUNXI is set
  (git-fixes).
- can: sun4i_can: Add support for the Allwinner D1 (git-fixes).
- can: sun4i_can: Add acceptance register quirk (git-fixes).
- commit afb2eb9
* Tue Dec 12 2023 tiwai@suse.de
- vga16fb: drop powerpc support (git-fixes).
- commit 308b143
* Tue Dec 12 2023 tiwai@suse.de
- drm/mediatek: Fix using wrong drm private data to bind
  mediatek-drm (git-fixes).
- drm/mediatek: Add crtc path enum for all_drm_priv array
  (git-fixes).
- commit f3ff4cb
* Tue Dec 12 2023 tiwai@suse.de
- Move a few upstreamed patches into sorted section
- commit 5e418e2
* Tue Dec 12 2023 denis.kirjanov@suse.com
- netfilter: nf_tables: bail out on mismatching dynset and set
  expressions (bsc#1217938 CVE-2023-6622).
- commit 524bf5f
* Tue Dec 12 2023 tbogendoerfer@suse.de
- net/tg3: fix race condition in tg3_reset_task() (bsc#1217801).
- commit 227cad2
* Mon Dec 11 2023 tiwai@suse.de
- selftests: netfilter: Run nft_audit.sh in its own netns
  (git-fixes).
- commit 9660e2e
* Mon Dec 11 2023 tiwai@suse.de
- apparmor: Fix kernel-doc warnings in apparmor/resource.c
  (git-fixes).
- apparmor: Fix kernel-doc warnings in apparmor/lib.c (git-fixes).
- apparmor: Fix kernel-doc warnings in apparmor/audit.c
  (git-fixes).
- buildid: reduce header file dependencies for module (git-fixes).
- clk: Sanitize possible_parent_show to Handle Return Value of
  of_clk_get_parent_name (git-fixes).
- clk: qcom: gcc-qdu1000: Register gcc_gpll1_out_even clock
  (git-fixes).
- crypto: lrw,xts - Replace strlcpy with strscpy (git-fixes).
- commit 448c480
* Mon Dec 11 2023 tiwai@suse.de
- drm/amdgpu: Restrict extended wait to PSP v13.0.6 (git-fixes).
- drm/amdgpu: disable MCBP by default (git-fixes).
- drm/amdgpu: update retry times for psp BL wait (git-fixes).
- HSI: fix ssi_waketest() declaration (git-fixes).
- commit 0e906dc
* Mon Dec 11 2023 tiwai@suse.de
- i2c: designware: fix __i2c_dw_disable() in case master is
  holding SCL low (git-fixes).
- misc: open-dice: make OPEN_DICE depend on HAS_IOMEM (git-fixes).
- kobject: Add sanity check for kset->kobj.ktype in
  kset_register() (git-fixes).
- i2c: imx-lpi2c: return -EINVAL when i2c peripheral clk doesn't
  work (git-fixes).
- commit 8a847b4
* Mon Dec 11 2023 tiwai@suse.de
- of: dynamic: Fix of_reconfig_get_state_change() return value
  documentation (git-fixes).
- of: address: Fix address translation when address-size is
  greater than 2 (git-fixes).
- of: overlay: Reorder struct fragment fields kerneldoc
  (git-fixes).
- of: property: fw_devlink: Add a devlink for panel followers
  (git-fixes).
- commit ff21d44
* Mon Dec 11 2023 tiwai@suse.de
- PCI: vmd: Disable bridge window for domain reset (git-fixes).
- PCI: fu740: Set the number of MSI vectors (git-fixes).
- PCI: dwc: Provide deinit callback for i.MX (git-fixes).
- commit 80cc726
* Mon Dec 11 2023 tiwai@suse.de
- PM: tools: Fix sleepgraph syntax error (git-fixes).
- radix tree test suite: fix allocation calculation in
  kmem_cache_alloc_bulk() (git-fixes).
- randstruct: Fix gcc-plugin performance mode to stay in group
  (git-fixes).
- commit c8cb0af
* Mon Dec 11 2023 tiwai@suse.de
- uapi: propagate __struct_group() attributes to the container
  union (git-fixes).
- commit d8d07c0
* Mon Dec 11 2023 tiwai@suse.de
- uapi: stddef.h: Fix __DECLARE_FLEX_ARRAY for C++ (git-fixes).
- commit 4169c49
* Mon Dec 11 2023 tiwai@suse.de
- soc: qcom: llcc: Refactor llcc driver to support multiple
  configuration (git-fixes).
- selftests: netfilter: Extend nft_audit.sh (git-fixes).
- selftests: netfilter: test for sctp collision processing in
  nf_conntrack (git-fixes).
- selftests: netfilter: Test nf_tables audit logging (git-fixes).
- selftests: fix dependency checker script (git-fixes).
- selftests/ftrace: Correctly enable event in instance-event.tc
  (git-fixes).
- serial: cpm_uart: Avoid suspicious locking (git-fixes).
- samples/hw_breakpoint: mark sample_hbp as static (git-fixes).
- samples/hw_breakpoint: fix building without module unloading
  (git-fixes).
- samples/hw_breakpoint: Fix kernel BUG 'invalid opcode: 0000'
  (git-fixes).
- selftests/nolibc: fix up kernel parameters support (git-fixes).
- kselftest/arm64: fix a memleak in zt_regs_run() (git-fixes).
- commit afe41bf
* Mon Dec 11 2023 tiwai@suse.de
- USB: xhci-plat: fix legacy PHY double init (git-fixes).
- usb: typec: intel_pmc_mux: Add new ACPI ID for Lunar Lake IOM
  device (git-fixes).
- commit 4a2ce58
* Mon Dec 11 2023 oneukum@suse.com
- usb-storage,uas: make internal quirks flags 64bit (git-fixes).
- commit d51505a
* Mon Dec 11 2023 petr.pavlu@suse.com
- tracing: Fix a possible race when disabling buffered events
  (bsc#1217036).
- commit 6000069
* Mon Dec 11 2023 oneukum@suse.com
- USB: typec: tps6598x: Refactor tps6598x port registration
  (git-fixes).
- commit 48961db
* Mon Dec 11 2023 oneukum@suse.com
- USB: typec: tps6598x: Add patch mode to tps6598x (git-fixes).
- commit fd3d950
* Mon Dec 11 2023 oneukum@suse.com
- USB: typec: tsp6598x: Add cmd timeout and response delay
  (git-fixes).
- commit 424ab23
* Mon Dec 11 2023 petr.pavlu@suse.com
- tracing: Fix a warning when allocating buffered events fails
  (bsc#1217036).
- commit eb5f373
* Mon Dec 11 2023 petr.pavlu@suse.com
- tracing: Fix incomplete locking when disabling buffered events
  (bsc#1217036).
- commit dab1aa2
* Mon Dec 11 2023 oneukum@suse.com
- usb: usbtest: fix a type promotion bug (git-fixes).
- commit bfce8cb
* Mon Dec 11 2023 oneukum@suse.com
- usb:typec:tcpm:support double Rp to Vbus cable as sink
  (git-fixes).
- commit 29c0fb8
* Mon Dec 11 2023 oneukum@suse.com
- usbmon: Use list_for_each_entry() helper (git-fixes).
- commit 6a78e9c
* Mon Dec 11 2023 oneukum@suse.com
- usb: chipidea: tegra: Consistently use dev_err_probe()
  (git-fixes).
- commit b0f110b
* Mon Dec 11 2023 tiwai@suse.de
- config.conf: Drop vanilla and syzkaller flavors
  kernel-vanilla was rather useless in the case of current builds, as
  we're based on 6.4.0, and it'll never change.
  Also, syzkaller config is still present even though it's disabled
  in config.conf.
  Let's drop both flavors now.  This aligns with SLE15-SP6, too.
- commit bf54f25
* Mon Dec 11 2023 jlee@suse.com
- ACPI: video: Use acpi_device_fix_up_power_children()
  (jsc#PED-6747).
- ACPI: PM: Add acpi_device_fix_up_power_children() function
  (jsc#PED-6747).
- ACPI: thermal: Fix acpi_thermal_unregister_thermal_zone()
  cleanup (jsc#PED-6747).
- x86/i8259: Skip probing when ACPI/MADT advertises PCAT
  compatibility (jsc#PED-6747).
- ACPI: NFIT: Install Notify() handler before getting NFIT table
  (jsc#PED-6747).
- cpu-hotplug: Provide prototypes for arch CPU registration
  (jsc#PED-6747).
- cpuidle, ACPI: Evaluate LPI arch_flags for broadcast timer
  (jsc#PED-6747).
- ACPI: video: Fix NULL pointer dereference in
  acpi_video_bus_add() (jsc#PED-6747).
- ACPI: processor: Fix uninitialized access of buf in
  acpi_set_pdc_bits() (jsc#PED-6747).
- acpi: Provide ia64 dummy implementation of
  acpi_proc_quirk_mwait_check() (jsc#PED-6747).
- thermal: Constify the trip argument of the .get_trend() zone
  callback (jsc#PED-6747).
- thermal: core: Rework .get_trend() thermal zone callback
  (jsc#PED-6747).
- ACPI: x86: s2idle: Add a function to get LPS0 constraint for
  a device (jsc#PED-6747).
- ACPI: x86: s2idle: Add for_each_lpi_constraint() helper
  (jsc#PED-6747).
- ACPI: x86: s2idle: Add more debugging for AMD constraints
  parsing (jsc#PED-6747).
- commit 06de448
* Mon Dec 11 2023 jlee@suse.com
- ACPI: x86: s2idle: Post-increment variables when getting
  constraints (jsc#PED-6747).
  Refresh
  patches.suse/ACPI-x86-s2idle-Fix-a-logic-error-parsing-AMD-constr.patch.
- ACPI: Adjust #ifdef for *_lps0_dev use (jsc#PED-6747).
- ACPI: Remove assorted unused declarations of functions
  (jsc#PED-6747).
- ACPI: extlog: Fix finding the generic error data for v3
  structure (jsc#PED-6747).
- ACPI: TAD: Install SystemCMOS address space handler for ACPI000E
  (jsc#PED-6747).
- ACPI: scan: Defer enumeration of devices with a _DEP pointing
  to IVSC device (jsc#PED-6747).
- ACPI: thermal: Eliminate code duplication from
  acpi_thermal_notify() (jsc#PED-6747).
- ACPI: thermal: Drop unnecessary thermal zone callbacks
  (jsc#PED-6747).
- ACPI: thermal: Rework thermal_get_trend() (jsc#PED-6747).
- ACPI: thermal: Use trip point table to register thermal zones
  (jsc#PED-6747).
- thermal: core: Rework and rename __for_each_thermal_trip()
  (jsc#PED-6747).
- thermal: core: Add priv pointer to struct thermal_trip
  (jsc#PED-6747).
- commit 18c6b75
* Mon Dec 11 2023 jgross@suse.com
- KVM: SVM: Update EFER software model on CR0 trap for SEV-ES
  (jsc#PED-7322).
- commit 4f7b650
* Mon Dec 11 2023 dwagner@suse.de
- nvmet: nul-terminate the NQNs passed in the connect command
  (bsc#1217250 CVE-2023-6121).
- commit 36f653d
* Mon Dec 11 2023 jgross@suse.com
- x86/tdx: Allow 32-bit emulation by default (jsc#PED-7322).
- commit 9d07a99
* Mon Dec 11 2023 mfranc@suse.cz
- KVM: s390: vsie: fix wrong VIR 37 when MSO is used (git-fixes
  bsc#1217931).
- commit 4e22764
* Mon Dec 11 2023 jgross@suse.com
- x86/coco: Disable 32-bit emulation by default on TDX and SEV
  (jsc#PED-7322).
- commit d47b180
* Mon Dec 11 2023 tiwai@suse.de
- freezer,sched: Do not restore saved_state of a thawed task
  (git-fixes).
- commit 8e98629
* Mon Dec 11 2023 jgross@suse.com
- KVM: x86: Remove 'return void' expression for 'void function'
  (jsc#PED-7322).
- commit 2d6a1b5
* Mon Dec 11 2023 nik.borisov@suse.com
- x86/entry: Do not allow external 0x80 interrupts (bsc#1217927)
- commit 7be8772
* Mon Dec 11 2023 nik.borisov@suse.com
- x86/entry: Convert INT 0x80 emulation to IDTENTRY (bsc#1217927)
- commit 028778b
* Mon Dec 11 2023 jgross@suse.com
- KVM: Set file_operations.owner appropriately for all such
  structures (jsc#PED-7322).
- commit 73a9ca1
* Mon Dec 11 2023 jgross@suse.com
- x86/sev: Fix kernel crash due to late update to read-only
  ghcb_version (jsc#PED-7322).
- commit c23f492
* Mon Dec 11 2023 jgross@suse.com
- KVM: x86: Get CPL directly when checking if loaded vCPU is in
  kernel mode (jsc#PED-7322).
- commit d36b994
* Mon Dec 11 2023 jlee@suse.com
- ACPI: thermal: Introduce struct acpi_thermal_trip
  (jsc#PED-6747).
- ACPI: thermal: Carry out trip point updates under zone lock
  (jsc#PED-6747).
- ACPI: thermal: Clean up acpi_thermal_register_thermal_zone()
  (jsc#PED-6747).
- thermal: core: Introduce thermal_zone_device_exec()
  (jsc#PED-6747).
- ACPI: thermal: Drop redundant local variable from
  acpi_thermal_resume() (jsc#PED-6747).
- ACPI: thermal: Do not attach private data to ACPI handles
  (jsc#PED-6747).
- ACPI: thermal: Drop enabled flag from struct acpi_thermal_active
  (jsc#PED-6747).
- ACPI: processor: LoongArch: Get physical ID from MADT
  (jsc#PED-6747).
- ACPI: processor: Refine messages in
  acpi_early_processor_control_setup() (jsc#PED-6747).
- ACPI: processor: Remove acpi_hwp_native_thermal_lvt_osc()
  (jsc#PED-6747).
- ACPI: processor: Use _OSC to convey OSPM processor support
  information (jsc#PED-6747).
- ACPI: processor: Introduce acpi_processor_osc() (jsc#PED-6747).
- ACPI: processor: Set CAP_SMP_T_SWCOORD in
  arch_acpi_set_proc_cap_bits() (jsc#PED-6747).
- ACPI: processor: Clear C_C2C3_FFH and C_C1_FFH in
  arch_acpi_set_proc_cap_bits() (jsc#PED-6747).
- ACPI: processor: Rename ACPI_PDC symbols (jsc#PED-6747).
- ACPI: processor: Refactor arch_acpi_set_pdc_bits()
  (jsc#PED-6747).
- ACPI: processor: Move processor_physically_present() to
  acpi_processor.c (jsc#PED-6747).
- ACPI: processor: Move MWAIT quirk out of acpi_processor.c
  (jsc#PED-6747).
- ACPI: video: Put ACPI video and its child devices into D0 on
  boot (jsc#PED-6747).
- ACPI: thermal: Install Notify() handler directly (jsc#PED-6747).
- ACPI: NFIT: Remove unnecessary .remove callback (jsc#PED-6747).
- ACPI: NFIT: Install Notify() handler directly (jsc#PED-6747).
- ACPI: HED: Install Notify() handler directly (jsc#PED-6747).
- ACPI: battery: Install Notify() handler directly (jsc#PED-6747).
- ACPI: video: Install Notify() handler directly (jsc#PED-6747).
- ACPI: AC: Install Notify() handler directly (jsc#PED-6747).
- ACPI: bus: Set driver_data to NULL every time .add() fails
  (jsc#PED-6747).
- ACPI: bus: Introduce wrappers for ACPICA notify handler
  install/remove (jsc#PED-6747).
- ACPICA: Update version to 20230628 (jsc#PED-6747).
- ACPICA: RHCT: Add flags, CMO and MMU nodes (jsc#PED-6747).
- ACPICA: MADT: Add RISC-V external interrupt controllers
  (jsc#PED-6747).
- ACPICA: Add a define for size of struct
  acpi_srat_generic_affinity device_handle (jsc#PED-6747).
- ACPICA: Slightly simplify an error message in
  acpi_ds_result_push() (jsc#PED-6747).
- ACPICA: Fix misspelled CDAT DSMAS define (jsc#PED-6747).
- ACPICA: Add interrupt command to acpiexec (jsc#PED-6747).
- ACPICA: Detect GED device and keep track of _EVT (jsc#PED-6747).
- ACPICA: fix for conflict macro definition on zephyr interface
  (jsc#PED-6747).
- ACPICA: Add support for _DSC as per ACPI 6.5 (jsc#PED-6747).
- ACPICA: exserial.c: replace ternary operator with ACPI_MIN()
  (jsc#PED-6747).
- ACPICA: Modify ACPI_STATE_COMMON (jsc#PED-6747).
- ACPICA: Fix GCC 12 dangling-pointer warning (jsc#PED-6747).
- commit 6bf05aa
* Sun Dec 10 2023 jgross@suse.com
- KVM: x86: Service NMI requests after PMI requests in VM-Enter
  path (jsc#PED-7322).
- commit 84ab0a7
* Sun Dec 10 2023 jgross@suse.com
- KVM: x86: Ignore MSR_AMD64_TW_CFG access (jsc#PED-7322).
- commit 6eb91ae
* Sun Dec 10 2023 jgross@suse.com
- KVM: x86: remove the unused assigned_dev_head from kvm_arch
  (jsc#PED-7322).
- commit eebb75b
* Sun Dec 10 2023 jgross@suse.com
- KVM: x86/mmu: Remove unnecessary 'NULL' values from sptep (jsc#PED-7322).
- commit fad8a6d
* Sun Dec 10 2023 jgross@suse.com
- x86: KVM: Add feature flag for CPUID.80000021H:EAX[bit 1]
  (jsc#PED-7322).
- commit b101f52
* Sun Dec 10 2023 jgross@suse.com
- KVM: x86: remove always-false condition in kvmclock_sync_fn
  (jsc#PED-7322).
- commit e81fec9
* Sun Dec 10 2023 jgross@suse.com
- KVM: x86: hyper-v: Don't auto-enable stimer on write from
  user-space (jsc#PED-7322).
- commit 157e0df
* Sun Dec 10 2023 jgross@suse.com
- KVM: x86: Update the variable naming in kvm_x86_ops.sched_in()
  (jsc#PED-7322).
- commit 695cd14
* Sun Dec 10 2023 jgross@suse.com
- KVM: x86/mmu: Stop kicking vCPUs to sync the dirty log when
  PML is disabled (jsc#PED-7322).
- commit f84fc4e
* Sun Dec 10 2023 jgross@suse.com
- KVM: x86: Use octal for file permission (jsc#PED-7322).
- commit 3c39fe8
* Sun Dec 10 2023 jgross@suse.com
- KVM: VMX: drop IPAT in memtype when CD=1 for
  KVM_X86_QUIRK_CD_NW_CLEARED (jsc#PED-7322).
- commit 921babe
* Sun Dec 10 2023 jgross@suse.com
- KVM: x86/mmu: Zap KVM TDP when noncoherent DMA assignment
  starts/stops (jsc#PED-7322).
- commit 9ab4a14
* Sun Dec 10 2023 jgross@suse.com
- KVM: x86: Don't sync user-written TSC against startup values
  (jsc#PED-7322).
- commit a4d4bc6
* Sun Dec 10 2023 jgross@suse.com
- KVM: x86/mmu: Zap SPTEs on MTRR update iff guest MTRRs are
  honored (jsc#PED-7322).
- commit caec33b
* Sun Dec 10 2023 jgross@suse.com
- KVM: x86/mmu: Zap SPTEs when CR0.CD is toggled iff guest MTRRs
  are honored (jsc#PED-7322).
- commit f32496f
* Sun Dec 10 2023 jgross@suse.com
- KVM: x86/mmu: Add helpers to return if KVM honors guest MTRRs
  (jsc#PED-7322).
- commit 4e2c1c1
* Sun Dec 10 2023 jgross@suse.com
- KVM: x86: Virtualize HWCR.TscFreqSel[bit 24] (jsc#PED-7322).
- commit d06002b
* Sun Dec 10 2023 tiwai@suse.de
- gpiolib: sysfs: Fix error handling on failed export (git-fixes).
- usb: gadget: f_hid: fix report descriptor allocation
  (git-fixes).
- Revert "xhci: Loosen RPM as default policy to cover for AMD
  xHC 1.1" (git-fixes).
- usb: typec: class: fix typec_altmode_put_partner to put plugs
  (git-fixes).
- USB: gadget: core: adjust uevent timing on gadget unbind
  (git-fixes).
- ARM: PL011: Fix DMA support (git-fixes).
- serial: 8250: 8250_omap: Clear UART_HAS_RHR_IT_DIS bit
  (git-fixes).
- serial: 8250: 8250_omap: Do not start RX DMA on THRI interrupt
  (git-fixes).
- hwtracing: hisi_ptt: Add dummy callback pmu::read() (git-fixes).
- devcoredump: Send uevent once devcd is ready (git-fixes).
- misc: mei: client.c: fix problem of return '-EOVERFLOW' in
  mei_cl_write (git-fixes).
- misc: mei: client.c: return negative error code in mei_cl_write
  (git-fixes).
- commit ef19e2e
* Sun Dec 10 2023 jgross@suse.com
- KVM: x86: Allow HWCR.McStatusWrEn to be cleared once set
  (jsc#PED-7322).
- commit 37e6049
* Sun Dec 10 2023 jgross@suse.com
- KVM: x86: Refine calculation of guest wall clock to use a
  single TSC read (jsc#PED-7322).
- commit 5da4c9a
* Sun Dec 10 2023 jgross@suse.com
- KVM: x86/xen: ignore the VCPU_SSHOTTMR_future flag
  (jsc#PED-7322).
- commit 2253071
* Sun Dec 10 2023 jgross@suse.com
- KVM: x86: Add SBPB support (jsc#PED-7322).
- commit 7aa606a
* Sun Dec 10 2023 jgross@suse.com
- KVM: x86: Add IBPB_BRTYPE support (jsc#PED-7322).
- commit 3d54281
* Sat Dec  9 2023 tiwai@suse.de
- ASoC: amd: yc: Add DMI entry to support System76 Pangolin 13
  (git-fixes).
- ASoC: amd: yc: Add HP 255 G10 into quirk table (git-fixes).
- commit 31f74df
* Sat Dec  9 2023 tiwai@suse.de
- ALSA: hda/realtek: Add quirk for Lenovo Yoga Pro 7 (git-fixes).
- ALSA: hda/realtek: Add Framework laptop 16 to quirks
  (git-fixes).
- ALSA: hda/realtek: add new Framework laptop to quirks
  (git-fixes).
- ASoC: amd: yc: Fix non-functional mic on ASUS E1504FA
  (git-fixes).
- ALSA: pcm: fix out-of-bounds in snd_pcm_state_names (git-fixes).
- ALSA: hda/realtek: Enable headset on Lenovo M90 Gen5
  (git-fixes).
- ALSA: hda/realtek: fix speakers on XPS 9530 (2023) (git-fixes).
- ALSA: usb-audio: Add Pioneer DJM-450 mixer controls (git-fixes).
- ALSA: hda/realtek: Apply quirk for ASUS UM3504DA (git-fixes).
- commit 72e3db8
* Sat Dec  9 2023 tiwai@suse.de
- hwmon: (nzxt-kraken2) Fix error handling path in kraken2_probe()
  (git-fixes).
- hwmon: (acpi_power_meter) Fix 4.29 MW bug (git-fixes).
- ASoC: wm_adsp: fix memleak in wm_adsp_buffer_populate
  (git-fixes).
- ASoC: codecs: lpass-tx-macro: set active_decimator correct
  default value (git-fixes).
- ASoC: fsl_sai: Fix no frame sync clock issue on i.MX8MP
  (git-fixes).
- drm/atomic-helpers: Invoke end_fb_access while owning plane
  state (git-fixes).
- drm/bridge: tc358768: select CONFIG_VIDEOMODE_HELPERS
  (git-fixes).
- drm/i915/mst: Reject modes that require the bigjoiner
  (git-fixes).
- drm/i915/mst: Fix .mode_valid_ctx() return values (git-fixes).
- drm/i915: Skip some timing checks on BXT/GLK DSI transcoders
  (git-fixes).
- scripts/gdb: fix lx-device-list-bus and lx-device-list-class
  (git-fixes).
- drivers/base/cpu: crash data showing should depends on
  KEXEC_CORE (git-fixes).
- checkstack: fix printed address (git-fixes).
- ACPI: video: Use acpi_video_device for cooling-dev driver data
  (git-fixes).
- drm/amdgpu: Update EEPROM I2C address for smu v13_0_0
  (git-fixes).
- drm/amd: Enable PCIe PME from D3 (git-fixes).
- drm/amd/display: fix ABM disablement (git-fixes).
- drm/amd/display: force toggle rate wa for first link training
  for a retimer (git-fixes).
- drm/amdgpu: correct the amdgpu runtime dereference usage count
  (git-fixes).
- drm/amd/display: Update min Z8 residency time to 2100 for DCN314
  (git-fixes).
- drm/amd/display: Remove min_dst_y_next_start check for Z8
  (git-fixes).
- drm/amdgpu: fix memory overflow in the IB test (git-fixes).
- drm/amd/display: Simplify brightness initialization (git-fixes).
- drm/amd/display: Use DRAM speed from validation for dummy
  p-state (git-fixes).
- drm/amd/display: Fix MPCC 1DLUT programming (git-fixes).
- drm/amdgpu: Force order between a read and write to the same
  address (git-fixes).
- drm/amd/display: Include udelay when waiting for INBOX0 ACK
  (git-fixes).
- nouveau: find the smallest page allocation to cover a buffer
  alloc (git-fixes).
- selftests/net: mptcp: fix uninitialized variable warnings
  (git-fixes).
- selftests/net: unix: fix unused variable compiler warning
  (git-fixes).
- selftests/net: fix a char signedness issue (git-fixes).
- selftests/net: ipsec: fix constant out of range (git-fixes).
- drm/amd/display: Reduce default backlight min from 5 nits to
  1 nits (git-fixes).
- drm/amd/display: Remove power sequencing check (git-fixes).
- drm/amd/display: refactor ILR to make it work (git-fixes).
- drm/amd/display: Refactor edp power control (git-fixes).
- commit eb38444
* Fri Dec  8 2023 jgross@suse.com
- KVM: SVM: Treat all "skip" emulation for SEV guests as outright
  failures (jsc#PED-7322).
- commit 7d41b6c
* Fri Dec  8 2023 jgross@suse.com
- KVM: x86: Refactor can_emulate_instruction() return to be more
  expressive (jsc#PED-7322).
- commit 3e2b139
* Fri Dec  8 2023 jgross@suse.com
- KVM: x86/xen: Use fast path for Xen timer delivery
  (jsc#PED-7322).
- commit c7b4170
* Fri Dec  8 2023 jgross@suse.com
- KVM: X86: Reduce size of kvm_vcpu_arch structure when
  CONFIG_KVM_XEN=n (jsc#PED-7322).
- commit 1d2e755
* Fri Dec  8 2023 jgross@suse.com
- x86/tdx: Replace deprecated strncpy() with strtomem_pad()
  (jsc#PED-7322).
- commit 8f088ed
* Fri Dec  8 2023 jgross@suse.com
- KVM: x86: Clear bit12 of ICR after APIC-write VM-exit
  (jsc#PED-7322).
- commit ac8ba0c
* Fri Dec  8 2023 jgross@suse.com
- KVM: x86: Fix lapic timer interrupt lost after loading a
  snapshot (jsc#PED-7322).
- commit 6265217
* Fri Dec  8 2023 jgross@suse.com
- KVM: SVM: Update SEV-ES shutdown intercepts with more metadata
  (jsc#PED-7322).
- commit 3d2bced
* Fri Dec  8 2023 jgross@suse.com
- KVM: x86: Add CONFIG_KVM_MAX_NR_VCPUS to allow up to 4096 vCPUs
  (jsc#PED-7322).
- Update config files.
- commit 2be3fda
* Fri Dec  8 2023 petr.pavlu@suse.com
- kernel-source: Remove config-options.changes (jsc#PED-5021)
  The file doc/config-options.changes was used in the past to document
  kernel config changes. It was introduced in 2010 but haven't received
  any updates on any branch since 2015. The file is renamed by tar-up.sh
  to config-options.changes.txt and shipped in the kernel-source RPM
  package under /usr/share/doc. As its content now only contains outdated
  information, retaining it can lead to confusion for users encountering
  this file.
  Config changes are nowadays described in associated Git commit messages,
  which get automatically collected and are incorporated into changelogs
  of kernel RPM packages.
  Drop then this obsolete file, starting with its packaging logic.
  For branch maintainers: Upon merging this commit on your branch, please
  correspondingly delete the file doc/config-options.changes.
- commit adedbd2
* Fri Dec  8 2023 jgross@suse.com
- KVM: x86: Force TLB flush on userspace changes to special
  registers (jsc#PED-7322).
- commit c7de714
* Fri Dec  8 2023 jgross@suse.com
- KVM: x86: Remove redundant vcpu->arch.cr0 assignments
  (jsc#PED-7322).
- commit d8de618
* Fri Dec  8 2023 petr.pavlu@suse.com
- doc/README.SUSE: Simplify the list of references (jsc#PED-5021)
  Reduce indentation in the list of references, make the style consistent
  with README.md.
- commit 70e3c33
* Fri Dec  8 2023 tiwai@suse.de
- regmap: fix bogus error on regcache_sync success (git-fixes).
- platform/x86: wmi: Skip blocks with zero instances (git-fixes).
- platform/surface: aggregator: fix recv_buf() return value
  (git-fixes).
- platform/x86: asus-wmi: Move i8042 filter install to shared
  asus-wmi code (git-fixes).
- commit 4a6226a
* Fri Dec  8 2023 jgross@suse.com
- x86/sev/docs: Update document URL in amd-memory-encryption.rst
  (jsc#PED-7322).
- commit 62a88ab
* Thu Dec  7 2023 lduncan@suse.com
- scsi: fnic: Fix sg_reset success path (jsc#PED-6316).
- scsi: fnic: Replace sgreset tag with max_tag_id (jsc#PED-6316).
- commit aad5e69
* Thu Dec  7 2023 tiwai@suse.de
- drm/amdgpu: Remove unused variables from amdgpu_show_fdinfo
  (git-fixes).
- commit 558199a
* Thu Dec  7 2023 tiwai@suse.de
- wifi: mt76: mt7921: fix the wrong rate selected in fw for the
  chanctx driver (git-fixes).
- wifi: mt76: mt7921: fix the wrong rate pickup for the chanctx
  driver (git-fixes).
- wifi: mt76: move struct ieee80211_chanctx_conf up to struct
  mt76_vif (git-fixes).
- wifi: mt76: fix potential memory leak of beacon commands
  (git-fixes).
- wifi: mt76: update beacon size limitation (git-fixes).
- wifi: mt76: fix clang-specific fortify warnings (git-fixes).
- commit eb4e161
* Thu Dec  7 2023 tiwai@suse.de
- Bluetooth: btusb: Add RTW8852BE device 13d3:3570 to device
  tables (git-fixes).
- Refresh
  patches.suse/Bluetooth-btusb-Add-0bda-b85b-for-Fn-Link-RTL8852BE.patch.
- commit 665b80a
* Thu Dec  7 2023 tiwai@suse.de
- USB: serial: option: add Luat Air72*U series products
  (git-fixes).
- USB: serial: option: add Fibocom L7xx modules (git-fixes).
- USB: serial: option: don't claim interface 4 for ZTE MF290
  (git-fixes).
- usb: misc: onboard-hub: add support for Microchip USB5744
  (git-fixes).
- USB: dwc2: write HCINT with INTMASK applied (git-fixes).
- ACPI: resource: Skip IRQ override on ASUS ExpertBook B1402CVA
  (git-fixes).
- ASoC: codecs: wsa883x: make use of new mute_unmute_on_trigger
  flag (git-fixes).
- ASoC: cs35l56: Use PCI SSID as the firmware UID (git-fixes).
- ASoC: Intel: sof_sdw: Copy PCI SSID to struct snd_soc_card
  (git-fixes).
- ASoC: fsl-asoc-card: use integer type for fll_id and pll_id
  (git-fixes).
- commit 8016cc8
* Thu Dec  7 2023 tiwai@suse.de
- ASoC: soc-dai: add flag to mute and unmute stream during trigger
  (git-fixes).
- commit f25c117
* Thu Dec  7 2023 tiwai@suse.de
- Revert "drm/prime: Unexport helpers for fd/handle conversion"
  (git-fixes).
- drm/amd/pm: fix a memleak in aldebaran_tables_init (git-fixes).
- drm/panel: nt36523: fix return value check in nt36523_probe()
  (git-fixes).
- drm/panel: starry-2081101qfh032011-53g: Fine tune the panel
  power sequence (git-fixes).
- drm/i915: Call intel_pre_plane_updates() also for pipes getting
  enabled (git-fixes).
- drm/i915/gsc: Mark internal GSC engine with reserved uabi class
  (git-fixes).
- fbdev: omapfb: Drop unused remove function (git-fixes).
- fbdev: stifb: Make the STI next font pointer a 32-bit signed
  offset (git-fixes).
- drm/amdgpu: Remove duplicate fdinfo fields (git-fixes).
- drm/rockchip: vop2: remove the unsupported format of cluster
  window (git-fixes).
- drm/vc4: fix typo (git-fixes).
- drm/rockchip: remove unused struct in vop2 (git-fixes).
- drm/amd/display: remove useless check in should_enable_fbc()
  (git-fixes).
- gpu: host1x: Correct allocated size for contexts (git-fixes).
- commit abf7bd4
* Thu Dec  7 2023 petr.pavlu@suse.com
- doc/README.SUSE: Add how to update the config for module signing
  (jsc#PED-5021)
  Configuration files for SUSE kernels include settings to integrate with
  signing support provided by the Open Build Service. This creates
  problems if someone tries to use such a configuration file to build
  a "standalone" kernel as described in doc/README.SUSE:
  * Default configuration files available in the kernel-source repository
  unset CONFIG_MODULE_SIG_ALL to leave module signing to
  pesign-obs-integration. In case of a "standalone" build, this
  integration is not available and the modules don't get signed.
  * The kernel spec file overrides CONFIG_MODULE_SIG_KEY to
  ".kernel_signing_key.pem" which is a file populated by certificates
  provided by OBS but otherwise not available. The value ends up in
  /boot/config-$VERSION-$RELEASE-$FLAVOR and /proc/config.gz. If someone
  decides to use one of these files as their base configuration then the
  build fails with an error because the specified module signing key is
  missing.
  Add information on how to enable module signing and where to find the
  relevant upstream documentation.
- commit a699dc3
* Thu Dec  7 2023 tiwai@suse.de
- Add alt-commit tags to DRM patches
- commit 1efaafd
* Thu Dec  7 2023 tiwai@suse.de
- drm/i915: Add missing GSCCS documentation (git-fixes).
- drm/i915: Add missing CCS documentation (git-fixes).
- drm/bridge: Fix kernel-doc typo in desc of output_bus_cfg in
  drm_bridge_state (git-fixes).
- drm/gud: Use size_add() in call to struct_size() (git-fixes).
- commit 60feada
* Thu Dec  7 2023 tiwai@suse.de
- Add cherry-pick IDs of DRM patches to blacklist and alt-commit tags
- commit 444311c
* Thu Dec  7 2023 tiwai@suse.de
- drm/i915: Also check for VGA converter in eDP probe
  (bsc#1217282).
- commit 327467b
* Thu Dec  7 2023 tiwai@suse.de
- Partially revert "drm/amd/display: Fix possible underflow for
  displays with large vblank" (git-fixes).
- Refresh
  patches.suse/0398-drm-amd-display-Correct-unit-conversion-for-vstartup.patch.
- Refresh
  patches.suse/1231-drm-amd-display-Roll-back-unit-correction.patch.
- Refresh
  patches.suse/1232-drm-amd-display-Correct-unit-conversion-for-vstartup.patch.
- commit 0d5ceec
* Thu Dec  7 2023 tiwai@suse.de
- drm/i915: do not clean GT table on error path (git-fixes).
- drm/panel: boe-tv101wum-nl6: Fine tune Himax83102-j02 panel
  HFP and HBP (git-fixes).
- drm/ast: Disconnect BMC if physical connector is connected
  (git-fixes).
- drm/rockchip: vop: Fix color for RGB888/BGR888 format on VOP
  full (git-fixes).
- drm/panel: simple: Fix Innolux G101ICE-L01 timings (git-fixes).
- drm/panel: simple: Fix Innolux G101ICE-L01 bus flags
  (git-fixes).
- drm/panel: auo,b101uan08.3: Fine tune the panel power sequence
  (git-fixes).
- drm/msm/dpu: Add missing safe_lut_tbl in sc8280xp catalog
  (git-fixes).
- drm/msm/dsi: use the correct VREG_CTRL_1 value for 4nm cphy
  (git-fixes).
- drm/amd/display: Change the DMCUB mailbox memory location from
  FB to inbox (git-fixes).
- drm/amd/display: Clear dpcd_sink_ext_caps if not set
  (git-fixes).
- drm/amd/display: Enable fast plane updates on DCN3.2 and above
  (git-fixes).
- drm/amd/display: fix a NULL pointer dereference in
  amdgpu_dm_i2c_xfer() (git-fixes).
- drm/amd/display: Fix DSC not Enabled on Direct MST Sink
  (git-fixes).
- drm/amd/display: Guard against invalid RPTR/WPTR being set
  (git-fixes).
- drm/amdgpu: fix error handling in amdgpu_vm_init (git-fixes).
- drm/amdgpu: Fix possible null pointer dereference (git-fixes).
- drm/amdgpu: lower CS errors to debug severity (git-fixes).
- drm/amdgpu: fix error handling in amdgpu_bo_list_get()
  (git-fixes).
- drm/i915/tc: Fix -Wformat-truncation in intel_tc_port_init
  (git-fixes).
- drm/i915: Fix potential spectre vulnerability (git-fixes).
- drm/i915: Bump GLK CDCLK frequency when driving multiple pipes
  (git-fixes).
- i915/perf: Fix NULL deref bugs with drm_dbg() calls (git-fixes).
- drm/i915/mtl: Support HBR3 rate with C10 phy and eDP in MTL
  (git-fixes).
- drm/i915: Flush WC GGTT only on required platforms (git-fixes).
- drm/amdgpu: fix GRBM read timeout when do mes_self_test
  (git-fixes).
- drm/amdgpu/smu13: drop compute workload workaround (git-fixes).
- drm/amdgpu: add a retry for IP discovery init (git-fixes).
- drm/amdgpu: don't use pci_is_thunderbolt_attached() (git-fixes).
- drm/amdgpu: don't use ATRM for external devices (git-fixes).
- drm/amd/pm: Fix error of MACO flag setting code (git-fixes).
- drm/amd/pm: Handle non-terminated overdrive commands
  (git-fixes).
- drm/mediatek/dp: fix memory leak on ->get_edid callback error
  path (git-fixes).
- drm/mediatek/dp: fix memory leak on ->get_edid callback audio
  detection (git-fixes).
- drm/amd/display: enable dsc_clk even if dsc_pg disabled
  (git-fixes).
- drm/amd/display: Add Null check for DPP resource (git-fixes).
- drm: bridge: it66121: ->get_edid callback must not return err
  pointers (git-fixes).
- commit 0cb9f4d
* Thu Dec  7 2023 tiwai@suse.de
- drm/amdgpu: fix software pci_unplug on some chips (git-fixes).
- drm/qxl: prevent memory leak (git-fixes).
- drm/i915/mtl: avoid stringop-overflow warning (git-fixes).
- drm/amd/display: Avoid NULL dereference of timing generator
  (git-fixes).
- drm/amd: check num of link levels when update pcie param
  (git-fixes).
- drm/amd/display: fix num_ways overflow error (git-fixes).
- drm/amd: Disable PP_PCIE_DPM_MASK when dynamic speed switching
  not supported (git-fixes).
- drm/amdgpu: Fix a null pointer access when the smc_rreg pointer
  is NULL (git-fixes).
- drm/amdkfd: Fix shift out-of-bounds issue (git-fixes).
- drm/panel: st7703: Pick different reset sequence (git-fixes).
- commit a67416d
* Thu Dec  7 2023 tiwai@suse.de
- drm: vmwgfx_surface.c: copy user-array safely (git-fixes).
- drm_lease.c: copy user-array safely (git-fixes).
- drm/msm/dp: skip validity check for DP CTS EDID checksum
  (git-fixes).
- drm/amdgpu/vkms: fix a possible null pointer dereference
  (git-fixes).
- drm/radeon: fix a possible null pointer dereference (git-fixes).
- drm/amdgpu: Fix potential null pointer derefernce (git-fixes).
- drm/amd: Fix UBSAN array-index-out-of-bounds for Polaris and
  Tonga (git-fixes).
- drm/amd: Fix UBSAN array-index-out-of-bounds for SMU7
  (git-fixes).
- drm/amd/display: use full update for clip size increase of
  large plane source (git-fixes).
- drm/amd: Update `update_pcie_parameters` functions to use
  uint8_t arguments (git-fixes).
- drm/amdgpu: update retry times for psp vmbx wait (git-fixes).
- drm/amdkfd: Fix a race condition of vram buffer unref in svm
  code (git-fixes).
- drm/amdgpu: not to save bo in the case of RAS err_event_athub
  (git-fixes).
- drm/amd/display: add seamless pipe topology transition check
  (git-fixes).
- drm/amd/display: Don't lock phantom pipe on disabling
  (git-fixes).
- drm/amd/display: Blank phantom OTG before enabling (git-fixes).
- drm/panel/panel-tpo-tpg110: fix a possible null pointer
  dereference (git-fixes).
- drm/panel: fix a possible null pointer dereference (git-fixes).
- drm/edid: Fixup h/vsync_end instead of h/vtotal (git-fixes).
- drm/komeda: drop all currently held locks if deadlock happens
  (git-fixes).
- commit 0591cfb
* Thu Dec  7 2023 tiwai@suse.de
- fbdev: fsl-diu-fb: mark wr_reg_wa() static (git-fixes).
- fbdev: imsttfb: fix a resource leak in probe (git-fixes).
- fbdev: imsttfb: fix double free in probe() (git-fixes).
- drm/syncobj: fix DRM_SYNCOBJ_WAIT_FLAGS_WAIT_AVAILABLE
  (git-fixes).
- drm/vc4: tests: Fix UAF in the mock helpers (git-fixes).
- drm/amdgpu: don't put MQDs in VRAM on ARM | ARM64 (git-fixes).
- drm/amdgpu/gfx10,11: use memcpy_to/fromio for MQDs (git-fixes).
- drm/rockchip: Fix type promotion bug in rockchip_gem_iommu_map()
  (git-fixes).
- drm/bridge: lt9611uxc: fix the race in the error path
  (git-fixes).
- drm/amd/pm: Fix a memory leak on an error path (git-fixes).
- drm/msm/dsi: free TX buffer in unbind (git-fixes).
- drm/msm/dsi: use msm_gem_kernel_put to free TX buffer
  (git-fixes).
- drm: mediatek: mtk_dsi: Fix NO_EOT_PACKET settings/handling
  (git-fixes).
- drm/mediatek: Fix iommu fault during crtc enabling (git-fixes).
- drm/mediatek: Fix iommu fault by swapping FBs after updating
  plane state (git-fixes).
- drm/mediatek: Add mmsys_dev_num to mt8188 vdosys0 driver data
  (git-fixes).
- drm/mediatek: Fix coverity issue with unintentional integer
  overflow (git-fixes).
- drm/amd/display: Don't use fsleep for PSR exit waits
  (git-fixes).
- drm/amd/display: Bail from dm_check_crtc_cursor if no relevant
  change (git-fixes).
- drm/amd/display: Refactor dm_get_plane_scale helper (git-fixes).
- drm/amd/display: Check all enabled planes in
  dm_check_crtc_cursor (git-fixes).
- drm/amd/display: Fix null pointer dereference in error message
  (git-fixes).
- drm/amdkfd: Handle errors from svm validate and map (git-fixes).
- drm/amdkfd: fix some race conditions in vram buffer alloc/free
  of svm code (git-fixes).
- drm/amdkfd: Remove svm range validated_once flag (git-fixes).
- drm/amdkfd: ratelimited SQ interrupt messages (git-fixes).
- drm/radeon: possible buffer overflow (git-fixes).
- drm/rockchip: cdn-dp: Fix some error handling paths in
  cdn_dp_probe() (git-fixes).
- drm: Call drm_atomic_helper_shutdown() at shutdown/remove time
  for misc drivers (git-fixes).
- drm/bridge: tc358768: Fix tc358768_ns_to_cnt() (git-fixes).
- drm/bridge: tc358768: Clean up clock period code (git-fixes).
- drm/bridge: tc358768: Rename dsibclk to hsbyteclk (git-fixes).
- drm/bridge: tc358768: Use dev for dbg prints, not priv->dev
  (git-fixes).
- drm/bridge: tc358768: Print logical values, not raw register
  values (git-fixes).
- drm/bridge: tc358768: Use struct videomode (git-fixes).
- drm/bridge: tc358768: Fix bit updates (git-fixes).
- drm/bridge: tc358768: Fix use of uninitialized variable
  (git-fixes).
- drm/bridge: lt8912b: Add missing drm_bridge_attach call
  (git-fixes).
- drm/bridge: lt8912b: Manually disable HPD only if it was enabled
  (git-fixes).
- drm/bridge: lt8912b: Fix crash on bridge detach (git-fixes).
- drm/bridge: lt8912b: Fix bridge_detach (git-fixes).
- drm: bridge: it66121: Fix invalid connector dereference
  (git-fixes).
- drm/gma500: Fix call trace when psb_gem_mm_init() fails
  (git-fixes).
- drm/rockchip: vop2: Add missing call to crtc reset helper
  (git-fixes).
- drm/rockchip: vop2: Don't crash for invalid duplicate_state
  (git-fixes).
- drm/rockchip: vop: Fix call to crtc reset helper (git-fixes).
- drm/rockchip: vop: Fix reset of state in duplicate state crtc
  funcs (git-fixes).
- drm: bridge: for GENERIC_PHY_MIPI_DPHY also select GENERIC_PHY
  (git-fixes).
- drm: bridge: samsung-dsim: Initialize ULPS EXIT for i.MX8M DSIM
  (git-fixes).
- commit 4e43af6
* Thu Dec  7 2023 mgorman@suse.de
- Update and enable
  patches.suse/sched-Temporarily-restore-deprecated-scheduler-sysctls-with-a-warning.patch
  (bsc#1192327, bsc#1191396, bsc#1216929).
  The deprecation warning was due to expire in SP6. However, due to
  upstream replacing CFS with EEVDF and bsc#1216929, extent the
  deprecation period until CFS is replaced.
- commit 76dbd30
* Thu Dec  7 2023 jlee@suse.com
- riscv: libstub: Implement KASLR by using generic functions
  (jsc#PED-5458).
  Refresh
  patches.suse/riscv-libstub-Implement-KASLR-by-using-generic-funct.patch.
- libstub: Fix compilation warning for rv32 (jsc#PED-5458).
- arm64: libstub: Move KASLR handling functions to kaslr.c
  (jsc#PED-5458).
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch.
- efi: Do not include <linux/screen_info.h> from EFI header
  (jsc#PED-5458).
- efi/arm64: Move EFI runtime call setup/teardown helpers out
  of line (jsc#PED-5458).
- commit 08bc679
* Thu Dec  7 2023 jlee@suse.com
- x86/boot: efistub: Assign global boot_params variable
  (jsc#PED-5458).
- x86/efistub: Don't try to print after ExitBootService()
  (jsc#PED-5458).
- efi/x86: Move EFI runtime call setup/teardown helpers out of
  line (jsc#PED-5458).
- x86/efistub: Fix PCI ROM preservation in mixed mode
  (jsc#PED-5458).
- efi/runtime-wrappers: Clean up white space and add __init
  annotation (jsc#PED-5458).
- acpi/prmt: Use EFI runtime sandbox to invoke PRM handlers
  (jsc#PED-5458).
- efi/runtime-wrappers: Don't duplicate setup/teardown code
  (jsc#PED-5458).
  Refresh
  patches.suse/0002-efi-Add-an-EFI_SECURE_BOOT-flag-to-indicate-secure-boot-mode.patch.
- efi/runtime-wrappers: Remove duplicated macro for service
  returning void (jsc#PED-5458).
- efi/runtime-wrapper: Move workqueue manipulation out of line
  (jsc#PED-5458).
- efi/runtime-wrappers: Use type safe encapsulation of call
  arguments (jsc#PED-5458).
- efi/riscv: Move EFI runtime call setup/teardown helpers out
  of line (jsc#PED-5458).
- efi/riscv: libstub: Fix comment about absolute relocation
  (jsc#PED-5458).
- efi: memmap: Remove kernel-doc warnings (jsc#PED-5458).
- efi: Remove unused extern declaration efi_lookup_mapped_addr()
  (jsc#PED-5458).
- efivarfs: convert to ctime accessor functions (jsc#PED-5458).
- efivarfs: update ctime when mtime changes on a write
  (jsc#PED-5458).
- commit 3d4c9a7
* Thu Dec  7 2023 jlee@suse.com
- EDAC/npcm: Add NPCM memory controller driver (jsc#PED-6747).
  Update config files. Add CONFIG_EDAC_NPCM is not set
  config/arm64/default
  config/armv7hl/default
- EDAC/thunderx: Check debugfs file creation retval properly
  (jsc#PED-6747).
- EDAC/amd64: Add support for ECC on family 19h model 60h-7Fh
  (jsc#PED-6747).
- EDAC/amd64: Remove module version string (jsc#PED-6747).
- commit b9ca23a
* Wed Dec  6 2023 tzimmermann@suse.com
- config: Disable fbdev user-space interfaces (jsc#PED-7409)
  Unset CONFIG_FB_DEVICE to disable /dev/fb* and other fbdev user-space
  interfaces. Implicitly disables a few obsolete fbdev drivers we still
  had on arm64.
- commit 5e51761
* Wed Dec  6 2023 petr.pavlu@suse.com
- doc/README.SUSE: Remove how to build modules using kernel-source
  (jsc#PED-5021)
  Remove the first method how to build kernel modules from the readme. It
  describes a process consisting of the kernel-source installation,
  configuring this kernel and then performing an ad-hoc module build.
  This method is not ideal as no modversion data is involved in the
  process. It results in a module with no symbol CRCs which can be wrongly
  loaded on an incompatible kernel.
  Removing the method also simplifies the readme because only two main
  methods how to build the modules are then described, either doing an
  ad-hoc build using kernel-devel, or creating a proper Kernel Module
  Package.
- commit 9285bb8
* Tue Dec  5 2023 tonyj@suse.de
- Delete patches.suse/perf_timechart_fix_zero_timestamps.patch
  Unclear why it was originally added, no BZ reference/etc. No response to 2017
  request for update. No timely response to 2023 request. Deleting.
- commit 8c9e160
* Tue Dec  5 2023 ailiop@suse.com
- dlm: fix plock lookup when using multiple lockspaces
  (git-fixes).
- commit 0c958d7
* Tue Dec  5 2023 ailiop@suse.com
- ubifs: ubifs_link: Fix wrong name len calculating when UBIFS
  is encrypted (git-fixes).
- commit 1f8caf2
* Tue Dec  5 2023 ailiop@suse.com
- ubifs: fix possible dereference after free (git-fixes).
- commit fa55cd2
* Tue Dec  5 2023 ailiop@suse.com
- ubifs: Fix memory leak of bud->log_hash (git-fixes).
- commit 211277a
* Tue Dec  5 2023 ailiop@suse.com
- afs: Fix file locking on R/O volumes to operate in local mode
  (git-fixes).
- commit 67ccd69
* Tue Dec  5 2023 ailiop@suse.com
- afs: Return ENOENT if no cell DNS record can be found
  (git-fixes).
- commit a820b19
* Tue Dec  5 2023 ailiop@suse.com
- afs: Make error on cell lookup failure consistent with OpenAFS
  (git-fixes).
- commit 08310f9
* Tue Dec  5 2023 ailiop@suse.com
- afs: Fix afs_server_list to be cleaned up with RCU (git-fixes).
- commit 9949efc
* Tue Dec  5 2023 ailiop@suse.com
- jfs: validate max amount of blocks before allocation
  (git-fixes).
- commit ec51391
* Tue Dec  5 2023 ailiop@suse.com
- reiserfs: Replace 1-element array with C99 style flex-array
  (git-fixes).
- commit a58aee5
* Tue Dec  5 2023 ailiop@suse.com
- reiserfs: Check the return value from __getblk() (git-fixes).
- commit 393a14b
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1316-drm-i915-Don-t-set-PIPE_CONTROL_FLUSH_L3-for-aux-inv.patch
  (git-fixes)
  Alt-commit
- commit 2087259
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1825-drm-i915-Fix-HPD-polling-reenabling-the-output-poll-.patch
  (git-fixes)
  Alt-commit
- commit b3e83d1
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-msm-dpu-drop-enum-dpu_core_perf_data_bus_id.patch
  (git-fixes)
  Alt-commit
- commit d9a3a4c
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-msm-mdss-correct-UBWC-programming-for-SM855.patch
  (git-fixes)
  Alt-commit
- commit c2018e6
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-msm-dsi-Drop-unused-regulators-from-QCM2290.patch
  (git-fixes)
  Alt-commit
- commit ec015d6
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/Revert-Revert-drm-amdgpu-display-change-pipe-p.patch
  (git-fixes)
  Alt-commit
- commit d29c603
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-amd-display-Fix-a-regression-on-Polaris-ca.patch
  (git-fixes)
  Alt-commit
- commit 0c4bc0e
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-amd-display-check-attr-flag-before-set-cur.patch
  (git-fixes)
  Alt-commit
- commit 6f25591
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-amd-display-Don-t-show-stack-trace-for-mis.patch
  (git-fixes)
  Alt-commit
- commit 3934302
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1795-drm-i915-fix-display-probe-for-IVB-Q-and-IVB-D-GT2-s.patch
  (git-fixes)
  Alt-commit
- commit 0f8e49f
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-sdvo-fix-panel_type-initialization.patch
  (git-fixes)
  Alt-commit
- commit 81db4b6
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-guc-slpc-Restore-efficient-freq-earli.patch
  (git-fixes)
  Alt-commit
- commit 20c7a06
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-Fix-premature-release-of-request-s-re.patch
  (git-fixes)
  Alt-commit
- commit baf4e7d
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-gt-Support-aux-invalidation-on-all-en.patch
  (git-fixes)
  Alt-commit
- commit 914eee8
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-gt-Poll-aux-invalidation-register-bit.patch
  (git-fixes)
  Alt-commit
- commit 067d27d
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-gt-Enable-the-CCS_FLUSH-bit-in-the-pi.patch
  (git-fixes)
  Alt-commit
- commit fd562e5
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-gt-Ensure-memory-quiesced-before-inva.patch
  (git-fixes)
  Alt-commit
- commit a1e8124
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-Fix-an-error-handling-path-in-igt_writ.patch
  (git-fixes)
  Alt-commit
- commit a05014c
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-perf-add-sentinel-to-xehp_oa_b_counter.patch
  (git-fixes)
  Alt-commit
- commit e9cc9e4
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-Fix-one-wrong-caching-mode-enum-usage.patch
  (git-fixes)
  Alt-commit
- commit fde4211
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-guc-slpc-Apply-min-softlimit-correctly.patch
  (git-fixes)
  Alt-commit
- commit cd6eb29
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-dpt-Use-shmem-for-dpt-objects.patch
  (git-fixes)
  Alt-commit
- commit 4657d31
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-Don-t-preserve-dpll_hw_state-for-slave.patch
  (git-fixes)
  Alt-commit
- commit e2e0b42
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-psr-Use-hw.adjusted-mode-when-calculat.patch
  (git-fixes)
  Alt-commit
- commit 8cd0e38
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-psr-Fix-BDW-PSR-AUX-CH-data-register-o.patch
  (git-fixes)
  Alt-commit
- commit 8abcc74
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-amd-Fix-an-error-handling-mistake-in-psp_sw.patch
  (git-fixes)
  Alt-commit
- commit 3baedc1
* Tue Dec  5 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-amdgpu-vkms-relax-timer-deactivation-by-hrt.patch
  (git-fixes)
  Alt-commit
- commit e7a79b2
* Mon Dec  4 2023 msuchanek@suse.de
- powerpc: Don't clobber f0/vs0 during fp|altivec register save
  (bsc#1217780).
- commit 61607ae
* Mon Dec  4 2023 msuchanek@suse.de
- Refresh sorted patches.
- commit 8461cc6
* Mon Dec  4 2023 svarbanov@suse.de
- supported.conf: Add UCSI CCG module in base image (jsc#PED-7377)
  This module is needed for Nvidia Orin platforms.
- commit 5f1a01b
* Mon Dec  4 2023 denis.kirjanov@suse.com
- igmp: limit igmpv3_newpack() packet size to IP_MAX_MTU
  (bsc#1215146 CVE-2023-42752).
- commit 9e90fb6
* Mon Dec  4 2023 denis.kirjanov@suse.com
- net: deal with integer overflows in kmalloc_reserve()
  (bsc#1215146 CVE-2023-42752).
- commit a668f40
* Mon Dec  4 2023 nstange@suse.de
- Refresh + reenable patches.suse/crypto-seqiv-flag-instantiations-as-fips-compliant.patch.
  Refresh + reenable the downstream
  patches.suse/crypto-seqiv-flag-instantiations-as-fips-compliant.patch
  carried over from 15-SP4 for FIPS compliance.
- commit ff6af6b
* Mon Dec  4 2023 nstange@suse.de
- Refresh + reenable patches.suse/crypto-dh-implement-FIPS-PCT.patch.
  Refresh + reenable the downstream
  patches.suse/crypto-dh-implement-FIPS-PCT.patch
  carried over from 15-SP4 for FIPS compliance.
- commit fde7d90
* Mon Dec  4 2023 nstange@suse.de
- Refresh + reenable patches.suse/crypto-ecdh-implement-FIPS-PCT.patch.
  Refresh + reenable the downstream
  patches.suse/crypto-ecdh-implement-FIPS-PCT.patch
  carried over from 15-SP4 for FIPS compliance.
- commit 413dd6f
* Mon Dec  4 2023 nstange@suse.de
- Reenable downstream crypto driver rejection facility for FIPS mode
  Future FIPS certifications will need a means to prevent unapproved
  crypto drivers from being used.
  Reenable
  patches.suse/0001-crypto-implement-downstream-solution-for-disabling-d.patch
  Mark the patch populating the actual reject list,
  patches.suse/0002-crypto-populate-downstream-list-of-drivers-unapprove.patch
  as carried over from 15-SP4, as needing further review (which can be
  conducted only once the complete set of all enabled crypto drivers has
  stabilized).
- commit e6a9ec2
* Mon Dec  4 2023 ykaukab@suse.de
- series.conf: remove pending soc-fsl patch
  Patch is already included in v6.4 kernel.
- commit f60468b
* Mon Dec  4 2023 nstange@suse.de
- Delete patches.suse/0002-crypto-HMAC---disallow-keys-112-bits-in-FIPS-mode.patch.
  Became obsolete with upstream commit
  37f36e571786 ("crypto: hmac - disallow keys < 112 bits in FIPS mode").
- commit 5200362
* Mon Dec  4 2023 nstange@suse.de
- Delete patches.suse/crypto-testmgr-enable-ecdsa-in-FIPS-mode.patch.
  Upstreamed as
  c27b2d2012e1 ("crypto: testmgr - allow ecdsa-nist-p256 and -p384 in FIPS
  mode").
- commit c3e3384
* Mon Dec  4 2023 nstange@suse.de
- Delete patches.suse/crypto-testmgr-disable-plain-ghash-in-FIPS-mode.patch.
  Upstreamed as
  2912eb9b17ac ("crypto: testmgr - disallow plain ghash in FIPS mode").
- commit 9e31869
* Mon Dec  4 2023 nstange@suse.de
- Delete patches.suse/crypto-testmgr-disable-plain-cbcmac-aes-in-FIPS-mode.patch.
  Upstreamed as
  1ce94a8c2c37 ("crypto: testmgr - disallow plain cbcmac(aes) in FIPS
  mode").
- commit 2e60932
* Mon Dec  4 2023 nstange@suse.de
- Delete patches.suse/crypto-xts-restrict-key-lengths-to-approved-values-i.patch.
  The patch got usptreamed in the meanwhile as
  1c4428b29588 ("crypto: xts - restrict key lengths to approved values in
  FIPS mode").
- commit cdfd7ec
* Mon Dec  4 2023 nstange@suse.de
- Delete patches.suse/crypto-dh-call-dh_init-after-drbg_init-and-jent_mod_.patch.
  With upstream commit adad556efcdd ("crypto: api - Fix built-in testing
  dependency failures"), the downstream quirk for getting the
  boot-time initialization ordering between jent, drbg and dh right
  should not be needed anymore. Drop it.
- commit 0d9fac4
* Mon Dec  4 2023 nstange@suse.de
- Delete crypto/dh safe-prime group patches
  With upstream commits
  1038fd78a1b8 ("crypto: kpp - provide support for KPP template instances")
  to
  35d2bf20683f ("crypto: dh - calculate Q from P for the full public key verification"),
  the safe-prime group DH patches are not needed anymore. Drop them.
- Delete
  patches.suse/0003-crypto-dh-optimize-domain-parameter-serialization-fo.patch.
- Delete
  patches.suse/0004-crypto-dh-introduce-RFC-7919-safe-prime-groups.patch.
- Delete
  patches.suse/0005-crypto-testmgr-add-DH-RFC-7919-ffdhe3072-test-vector.patch.
- Delete
  patches.suse/0006-crypto-dh-introduce-RFC-3526-safe-prime-groups.patch.
- Delete
  patches.suse/0007-crypto-testmgr-add-DH-RFC-3526-modp2048-test-vector.patch.
- Delete
  patches.suse/0008-crypto-testmgr-run-only-subset-of-DH-vectors-based-o.patch.
- Delete
  patches.suse/0009-crypto-dh-implement-private-key-generation-primitive.patch.
- Delete
  patches.suse/0010-crypto-dh-introduce-support-for-ephemeral-key-genera.patch.
- Delete
  patches.suse/0011-crypto-dh-introduce-support-for-ephemeral-key-genera.patch.
- Delete
  patches.suse/0012-crypto-dh-introduce-support-for-ephemeral-key-genera.patch.
- Delete
  patches.suse/0013-crypto-testmgr-add-DH-test-vectors-for-key-generatio.patch.
- Delete patches.suse/0014-lib-mpi-export-mpi_rshift.patch.
- Delete
  patches.suse/0015-crypto-dh-store-group-id-in-dh-generic-s-dh_ctx.patch.
- Delete
  patches.suse/0016-crypto-dh-calculate-Q-from-P-for-the-full-public-key.patch.
- Delete
  patches.suse/0017-crypto-dh-try-to-match-domain-parameters-to-a-known-.patch.
- Delete
  patches.suse/0018-crypto-dh-accept-only-approved-safe-prime-groups-in-.patch.
- commit b5eb0fe
* Sun Dec  3 2023 tiwai@suse.de
- firewire: core: fix possible memory leak in create_units()
  (git-fixes).
- commit 00295fc
* Sat Dec  2 2023 tiwai@suse.de
- ALSA: usb-audio: Don't try to submit URBs after disconnection
  (git-fixes).
- commit edc2762
* Sat Dec  2 2023 tiwai@suse.de
- ALSA: hda/realtek: Add supported ALC257 for ChromeOS
  (git-fixes).
- ALSA: hda/realtek: Headset Mic VREF to 100%% (git-fixes).
- ALSA: hda: intel-nhlt: Ignore vbps when looking for DMIC 32
  bps format (git-fixes).
- ALSA: hda - Fix speaker and headset mic pin config for CHUWI
  CoreBook XPro (git-fixes).
- commit e1dffb2
* Sat Dec  2 2023 tiwai@suse.de
- cpufreq/amd-pstate: Only print supported EPP values for
  performance governor (git-fixes).
- cpufreq/amd-pstate: Fix scaling_min_freq and scaling_max_freq
  update (git-fixes).
- cpufreq/amd-pstate: Fix the return value of
  amd_pstate_fast_switch() (git-fixes).
- ALSA: cs35l41: Fix for old systems which do not support command
  (git-fixes).
- ALSA: hda: cs35l41: Remove unnecessary boolean state variable
  firmware_running (git-fixes).
- dma-buf: fix check in dma_resv_add_fence (git-fixes).
- commit 68877b0
* Fri Dec  1 2023 msuchanek@suse.de
- kernel-binary: suse-module-tools is also required when installed
  Requires(pre) adds dependency for the specific sciptlet.
  However, suse-module-tools also ships modprobe.d files which may be
  needed at posttrans time or any time the kernel is on the system for
  generating ramdisk. Add plain Requires as well.
- commit 8c12816
* Fri Dec  1 2023 msuchanek@suse.de
- rpm: Use run_if_exists for all external scriptlets
  With that the scriptlets do not need to be installed for build.
- commit 25edd65
* Fri Dec  1 2023 nik.borisov@suse.com
- EDAC/amd64: Cache and use GPU node map (jsc#PED-7382).
- commit 662d7ea
* Fri Dec  1 2023 nik.borisov@suse.com
- EDAC/amd64: Add support for AMD heterogeneous Family 19h Model 30h-3Fh (jsc#PED-7382).
- commit 1df4bed
* Fri Dec  1 2023 nik.borisov@suse.com
- EDAC/amd64: Document heterogeneous system enumeration (jsc#PED-7382).
- commit a8ae10f
* Fri Dec  1 2023 nik.borisov@suse.com
- x86/MCE/AMD, EDAC/mce_amd: Decode UMC_V2 ECC errors (jsc#PED-7382).
- commit fd08174
* Fri Dec  1 2023 nik.borisov@suse.com
- x86/amd_nb: Re-sort and re-indent PCI defines (jsc#PED-7382).
- Refresh
  patches.suse/x86-amd_nb-add-pci-ids-for-amd-family-1ah-based-models.patch.
- commit 7dce06c
* Fri Dec  1 2023 nik.borisov@suse.com
- x86/amd_nb: Add MI200 PCI IDs (jsc#PED-7382).
- Refresh
  patches.suse/PCI-Prevent-xHCI-driver-from-claiming-AMD-VanGogh-US.patch.
- Refresh
  patches.suse/x86-amd_nb-add-pci-ids-for-amd-family-1ah-based-models.patch.
- commit 7c67cb5
* Fri Dec  1 2023 dwagner@suse.de
- scsi: lpfc: Copyright updates for 14.2.0.16 patches
  (bsc#1217731).
- scsi: lpfc: Update lpfc version to 14.2.0.16 (bsc#1217731).
- scsi: lpfc: Enhance driver logging for selected discovery events
  (bsc#1217731).
- scsi: lpfc: Refactor and clean up mailbox command memory free
  (bsc#1217731).
- scsi: lpfc: Return early in lpfc_poll_eratt() when the driver
  is unloading (bsc#1217731).
- scsi: lpfc: Eliminate unnecessary relocking in
  lpfc_check_nlp_post_devloss() (bsc#1217731).
- scsi: lpfc: Fix list_entry null check warning in
  lpfc_cmpl_els_plogi() (bsc#1217731).
- scsi: lpfc: Fix possible file string name overflow when updating
  firmware (bsc#1217731).
- scsi: lpfc: Correct maximum PCI function value for RAS fw
  logging (bsc#1217731).
- commit 010cf45
* Fri Dec  1 2023 rgoldwyn@suse.com
- Refresh patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit 3f78d5b
* Fri Dec  1 2023 nik.borisov@suse.com
- Delete patches.suse/x86-apic-force-bigsmp-apic-on-IBM-EXA3-4.patch.
  This patch pertains to 32bit architectures which are no longer supported
  and it also dates back to 2008 so highly unlikely it's relevant
  nowadays. Simply drop it.
- commit bcc8a7f
* Fri Dec  1 2023 mfranc@suse.cz
- Delete
  patches.suse/s390-sles15sp2-kdump-fix-out-of-memory-with-PCI.patch.
  The issue has been fixed in 73045a08cf55.  This was a partial backport
  to older trees.
- commit 6951e1d
* Fri Dec  1 2023 mfranc@suse.cz
- Delete
  patches.suse/s390-qeth-remove-OSN-deprecation-notice.patch.
  OSN support has been already dropped in a8c7629c622b.
- commit 239efff
* Fri Dec  1 2023 nik.borisov@suse.com
- Delete patches.suse/x86-retbleed-add-_x86_return_thunk-alignment-checks.patch.
  Changes of this patch are part of the SRSO series.
- commit b864e53
* Fri Dec  1 2023 msuchanek@suse.de
- Delete cdrom autoclose patches.
- Delete patches.suse/bdev-add-open_finish.patch.
- Delete patches.suse/cdrom-add-poll_event_interruptible.patch.
- Delete patches.suse/cdrom-export-autoclose-logic-as-a-separate-function.patch.
- Delete patches.suse/cdrom-factor-out-common-open_for_-code.patch.
- Delete patches.suse/cdrom-wait-for-the-tray-to-close.patch.
- Delete patches.suse/scsi-sr-wait-for-the-medium-to-become-ready.patch.
  Optical media are considered legacy, use on new product releases is not
  expected.
- commit 5960718
* Fri Dec  1 2023 tiwai@suse.de
- wifi: iwlwifi: mvm: fix an error code in iwl_mvm_mld_add_sta()
  (git-fixes).
- mmc: sdhci-sprd: Fix vqmmc not shutting down after the card
  was pulled (git-fixes).
- mmc: sdhci-pci-gli: Disable LPM during initialization
  (git-fixes).
- mmc: cqhci: Fix task clearing in CQE error recovery (git-fixes).
- mmc: cqhci: Warn of halt or task clear failure (git-fixes).
- mmc: block: Retry commands in CQE error recovery (git-fixes).
- mmc: block: Be sure to wait while busy in CQE error recovery
  (git-fixes).
- mmc: cqhci: Increase recovery halt timeout (git-fixes).
- mmc: block: Do not lose cache flush during CQE error recovery
  (git-fixes).
- efi/unaccepted: Fix off-by-one when checking for overlapping
  ranges (git-fixes).
- commit 6d97442
* Fri Dec  1 2023 ggherdovich@suse.cz
- Re-enable fixup to the acpi_pad driver
- commit 884cf0a
* Fri Dec  1 2023 ggherdovich@suse.cz
- Re-enable prerequisite patch to set CONFIG_CPU_FREQ_DEFAULT_GOV_ONDEMAND=y
- commit 66ad499
* Fri Dec  1 2023 ggherdovich@suse.cz
- Re-enable defaulting to intel_pstate/powersave on non-HWP machines
- commit ba4df31
* Fri Dec  1 2023 ggherdovich@suse.cz
- Re-enable idle-boost optimization for intel_pstate on non-HWP machines
- commit 9d4c643
* Fri Dec  1 2023 ggherdovich@suse.cz
- Re-enable intel_pstate optimization for low-utilization workloads on non-HWP machines
- commit a2c92be
* Fri Dec  1 2023 ggherdovich@suse.cz
- Re-enable aggressive iowait boost for intel_pstate for non-HWP machines
- commit ec7d3fd
* Thu Nov 30 2023 tiwai@suse.de
- Move upstreamed btusb patch into sorted section
- commit 6282635
* Thu Nov 30 2023 tiwai@suse.de
- ALSA: hda: Disable power-save on KONTRON SinglePC (bsc#1217140).
- commit 0ea5b2d
* Thu Nov 30 2023 pjakobsson@suse.de
- Revert "drm/amdgpu: Program xcp_ctl registers as needed"
  (git-fixes).
- commit aefbf56
* Thu Nov 30 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1344-drm-amdgpu-fix-SI-failure-due-to-doorbells-allocatio.patch
  (git-fixes)
  Alt-commit
- commit 36abf6d
* Thu Nov 30 2023 pjakobsson@suse.de
- drm/msm/a6xx: Fix unknown speedbin case (git-fixes).
- commit cb67e41
* Thu Nov 30 2023 pjakobsson@suse.de
- drm/msm/adreno: Fix SM6375 GPU ID (git-fixes).
- commit 2146082
* Thu Nov 30 2023 pjakobsson@suse.de
- Revert "drm/amd/display: Enable Replay for static screen use
  cases" (git-fixes).
- commit e83833a
* Thu Nov 30 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1318-drm-i915-Invalidate-the-TLBs-on-each-GT.patch
  (git-fixes)
  Alt-commit
- commit 030baea
* Thu Nov 30 2023 pjakobsson@suse.de
- drm/amdgpu: Increase IH soft ring size for GFX v9.4.3 dGPU
  (git-fixes).
- commit a3d0f57
* Thu Nov 30 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1311-drm-amdgpu-fix-a-memory-leak-in-amdgpu_ras_feature_e.patch
  (git-fixes)
  Alt-commit
- commit 3c3ade5
* Thu Nov 30 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1310-Revert-drm-amdgpu-Report-vbios-version-instead-of-PN.patch
  (git-fixes)
  Alt-commit
- commit 06528de
* Thu Nov 30 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1307-drm-i915-gt-Prevent-error-pointer-dereference.patch
  (git-fixes)
  Alt-commit
- commit 80dbf24
* Thu Nov 30 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1290-drm-amd-display-fix-replay_mode-kernel-doc-warning.patch
  (git-fixes)
  Alt-commit
- commit 5981676
* Thu Nov 30 2023 pjakobsson@suse.de
- Refresh patches.suse/1282-drm-amdgpu-fix-retry-loop-test.patch
  (git-fixes)
  Alt-commit
- commit 56c8ca9
* Thu Nov 30 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1275-drm-amdkfd-Fix-unaligned-64-bit-doorbell-warning.patch
  (git-fixes)
  Alt-commit
- commit f2b0169
* Thu Nov 30 2023 pjakobsson@suse.de
- drm/ssd130x: Fix screen clearing (git-fixes).
- commit a40227f
* Thu Nov 30 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1199-fbdev-g364fb-fix-build-failure-with-mips.patch
  (git-fixes)
  Alt-commit
- commit ee9589c
* Thu Nov 30 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1261-Revert-Revert-drm-amd-display-Implement-zpos-propert.patch
  (git-fixes)
  Alt-commit
- commit 5226b6f
* Thu Nov 30 2023 pjakobsson@suse.de
- drm/radeon: Remove the references of radeon_gem_ pread &
  pwrite ioctls (git-fixes).
- commit 595958a
* Thu Nov 30 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1247-Partially-revert-drm-amd-display-update-add-plane-to.patch
  (git-fixes)
  Alt-commit
- commit 0845e8e
* Thu Nov 30 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1242-drm-amd-pm-fix-debugfs-pm_info-output.patch
  (git-fixes)
  Alt-commit
- commit 5a6ff22
* Thu Nov 30 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1231-drm-amd-display-Roll-back-unit-correction.patch
  (git-fixes)
  Alt-commit
- commit 06e2420
* Thu Nov 30 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1178-drm-i915-Fix-TLB-Invalidation-seqno-store.patch
  (git-fixes)
  Alt-commit
- commit 40d0fa9
* Thu Nov 30 2023 pjakobsson@suse.de
- drm/loongson: Fix error handling in lsdc_pixel_pll_setup()
  (git-fixes).
- commit 223bebb
* Thu Nov 30 2023 pjakobsson@suse.de
- drm: bridge: samsung-dsim: Fix waiting for empty cmd transfer
  FIFO on older Exynos (git-fixes).
- commit 8f258a1
* Thu Nov 30 2023 pjakobsson@suse.de
- kunit: Fix obsolete name in documentation headers (func->action)
  (git-fixes).
- commit 8c0a6d2
* Thu Nov 30 2023 jdelvare@suse.de
- Disable Loongson drivers
  Loongson is a mips architecture, it doesn't make sense to build
  Loongson drivers on other architectures.
- commit ae18007
* Thu Nov 30 2023 pjakobsson@suse.de
- arch/arm: Implement <asm/fb.h> with generic helpers
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit e8d9e1a
* Thu Nov 30 2023 pjakobsson@suse.de
- drm/amdkfd: switch over to using drm_exec v3 (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Update config files.
- supported.conf: Add drm_exec as supported
- commit c240ef4
* Thu Nov 30 2023 tbogendoerfer@suse.de
- Refresh
  patches.suse/RDMA-Remove-unnecessary-ternary-operators.patch.
  Re-added missing hunk.
- commit c1fe660
* Thu Nov 30 2023 tbogendoerfer@suse.de
- tcp_bpf: properly release resources on error paths
  (jsc#PED-6831).
- commit 594eeec
* Thu Nov 30 2023 tbogendoerfer@suse.de
- tls: fix NULL deref on tls_sw_splice_eof() with empty record
  (jsc#PED-6831).
- crypto: chelsio - stop using crypto_ahash::init (jsc#PED-6831).
- IB/mlx5: Fix init stage error handling to avoid double free
  of same QP and UAF (jsc#PED-6864).
- RDMA/mlx5: Fix mkey cache WQ flush (jsc#PED-6864).
- RDMA/hfi1: Workaround truncation compilation error
  (jsc#PED-6864).
- IB/hfi1: Fix potential deadlock on &irq_src_lock and
  &dd->uctxt_lock (jsc#PED-6864).
- RDMA/core: Remove NULL check before dev_{put, hold}
  (jsc#PED-6864).
- RDMA/hfi1: Remove redundant assignment to pointer ppd
  (jsc#PED-6864).
- RDMA/bnxt_re: Fix clang -Wimplicit-fallthrough in
  bnxt_re_handle_cq_async_error() (jsc#PED-6864).
- RDMA/hns: Fix init failure of RoCE VF and HIP08 (jsc#PED-6864).
- RDMA/hns: Fix unnecessary port_num transition in HW stats
  allocation (jsc#PED-6864).
- RDMA/hns: The UD mode can only be configured with DCQCN
  (jsc#PED-6864).
- RDMA/hns: Add check for SL (jsc#PED-6864).
- RDMA/hns: Fix signed-unsigned mixed comparisons (jsc#PED-6864).
- RDMA/hns: Fix uninitialized ucmd in hns_roce_create_qp_common()
  (jsc#PED-6864).
- RDMA/hns: Fix printing level of asynchronous events
  (jsc#PED-6864).
- RDMA/core: Add support to set privileged QKEY parameter
  (jsc#PED-6864).
- RDMA/bnxt_re: Do not report SRQ error in srq notification
  (jsc#PED-6864).
- RDMA/bnxt_re: Report async events and errors (jsc#PED-6864).
- RDMA/bnxt_re: Update HW interface headers (jsc#PED-6864).
- IB/mlx5: Fix rdma counter binding for RAW QP (jsc#PED-6864).
- RDMA/irdma: Add support to re-register a memory region
  (jsc#PED-6864).
- RDMA/core: Fix a couple of obvious typos in comments
  (jsc#PED-6864).
- IB/hfi1: Annotate struct tid_rb_node with __counted_by
  (jsc#PED-6864).
- IB/mthca: Annotate struct mthca_icm_table with __counted_by
  (jsc#PED-6864).
- IB/srp: Annotate struct srp_fr_pool with __counted_by
  (jsc#PED-6864).
- RDMA/siw: Annotate struct siw_pbl with __counted_by
  (jsc#PED-6864).
- RDMA/usnic: Annotate struct usnic_uiom_chunk with __counted_by
  (jsc#PED-6864).
- RDMA/core: Annotate struct ib_pkey_cache with __counted_by
  (jsc#PED-6864).
- RDMA/hns: Support SRQ record doorbell (jsc#PED-6864).
- RDMA/ipoib: Add support for XDR speed in ethtool (jsc#PED-6864).
- IB/mlx5: Adjust mlx5 rate mapping to support 800Gb
  (jsc#PED-6864).
- IB/mlx5: Expose XDR speed through MAD (jsc#PED-6864).
- IB/core: Add support for XDR link speed (jsc#PED-6864).
- RDMA/mlx5: Implement mkeys management via LIFO queue
  (jsc#PED-6864).
- IB/qib: Replace deprecated strncpy (jsc#PED-6864).
- IB/hfi1: Replace deprecated strncpy (jsc#PED-6864).
- RDMA/irdma: Replace deprecated strncpy (jsc#PED-6864).
- RDMA/hns: Support SRQ restrack ops for hns driver
  (jsc#PED-6864).
- RDMA/core: Add support to dump SRQ resource in RAW format
  (jsc#PED-6864).
- RDMA/core: Add dedicated SRQ resource tracker function
  (jsc#PED-6864).
- RDMA/hfi1: Use FIELD_GET() to extract Link Width (jsc#PED-6864).
- RDMA/rtrs: Fix the problem of variable not initialized fully
  (jsc#PED-6864).
- RDMA/rtrs: Require holding rcu_read_lock explicitly
  (jsc#PED-6864).
- RDMA/core: Use size_{add,sub,mul}() in calls to struct_size()
  (jsc#PED-6864).
- IB/hfi1: Remove open coded reference to skb frag offset
  (jsc#PED-6864).
- RDMA/core: Fix repeated words in comments (jsc#PED-6864).
- IB: Use capital "OR" for multiple licenses in SPDX
  (jsc#PED-6864).
- infiniband: Remove the now superfluous sentinel element from
  ctl_table array (jsc#PED-6864).
- tls: don't reset prot->aad_size and prot->tail_size for TLS_HW
  (jsc#PED-6831).
- chtls: fix tp->rcv_tstamp initialization (jsc#PED-6831).
- tls: use fixed size for tls_offload_context_{tx,rx}.driver_state
  (jsc#PED-6831).
- chcr_ktls: use tls_offload_context_tx and driver_state like
  other drivers (jsc#PED-6831).
- tls: validate crypto_info in a separate helper (jsc#PED-6831).
- tls: remove tls_context argument from tls_set_device_offload
  (jsc#PED-6831).
- tls: remove tls_context argument from tls_set_sw_offload
  (jsc#PED-6831).
- tls: add a helper to allocate/initialize offload_ctx_tx
  (jsc#PED-6831).
- tls: also use init_prot_info in tls_set_device_offload
  (jsc#PED-6831).
- tls: move tls_prot_info initialization out of tls_set_sw_offload
  (jsc#PED-6831).
- tls: extract context alloc/initialization out of
  tls_set_sw_offload (jsc#PED-6831).
- tls: store iv directly within cipher_context (jsc#PED-6831).
- tls: rename MAX_IV_SIZE to TLS_MAX_IV_SIZE (jsc#PED-6831).
- tls: store rec_seq directly within cipher_context
  (jsc#PED-6831).
- tls: drop unnecessary cipher_type checks in tls offload
  (jsc#PED-6831).
- tls: get salt using crypto_info_salt in tls_enc_skb
  (jsc#PED-6831).
- tls: Use size_add() in call to struct_size() (jsc#PED-6831).
- infiniband: Use user_backed_iter() to see if iterator is
  UBUF/IOVEC (jsc#PED-6864).
- tcp: allow again tcp_disconnect() when threads are waiting
  (jsc#PED-6831).
- net/tls: do not free tls_rec on async operation in
  bpf_exec_tx_verdict() (jsc#PED-6831).
- tls: get cipher_name from cipher_desc in tls_set_sw_offload
  (jsc#PED-6831).
- tls: use tls_cipher_desc to access per-cipher crypto_info in
  tls_set_sw_offload (jsc#PED-6831).
- tls: use tls_cipher_desc to get per-cipher sizes in
  tls_set_sw_offload (jsc#PED-6831).
- tls: use tls_cipher_desc to simplify do_tls_getsockopt_conf
  (jsc#PED-6831).
- tls: get crypto_info size from tls_cipher_desc in
  do_tls_setsockopt_conf (jsc#PED-6831).
- tls: expand use of tls_cipher_desc in tls_sw_fallback_init
  (jsc#PED-6831).
- tls: allocate the fallback aead after checking that the cipher
  is valid (jsc#PED-6831).
- tls: expand use of tls_cipher_desc in tls_set_device_offload
  (jsc#PED-6831).
- tls: validate cipher descriptions at compile time
  (jsc#PED-6831).
- tls: extend tls_cipher_desc to fully describe the ciphers
  (jsc#PED-6831).
- tls: rename tls_cipher_size_desc to tls_cipher_desc
  (jsc#PED-6831).
- tls: reduce size of tls_cipher_size_desc (jsc#PED-6831).
- tls: add TLS_CIPHER_ARIA_GCM_* to tls_cipher_size_desc
  (jsc#PED-6831).
- tls: move tls_cipher_size_desc to net/tls/tls.h (jsc#PED-6831).
- net/tls: avoid TCP window full during ->read_sock()
  (jsc#PED-6831).
- net/tls: Remove unused function declarations (jsc#PED-6831).
- net/tls: implement ->read_sock() (jsc#PED-6831).
- net/tls: split tls_rx_reader_lock (jsc#PED-6831).
- net/tls: Use tcp_read_sock() instead of ops->read_sock()
  (jsc#PED-6831).
- net/tls: handle MSG_EOR for tls_device TX flow (jsc#PED-6831).
- net/tls: handle MSG_EOR for tls_sw TX flow (jsc#PED-6831).
- crypto: chelsio - Remove unused declarations (jsc#PED-6831).
- crypto: drivers - avoid memcpy size warning (jsc#PED-6831).
- net/tls: fix comment typo (jsc#PED-6831).
- tls: suppress wakeups unless we have a full record
  (jsc#PED-6831).
- commit 458f647
* Thu Nov 30 2023 mfranc@suse.cz
- s390/ap: fix AP bus crash on early config change callback
  invocation (git-fixes bsc#1217686).
- commit d914b2f
* Thu Nov 30 2023 tiwai@suse.de
- pinctrl: avoid reload of p state in list iteration (git-fixes).
- commit 1ab6bdb
* Thu Nov 30 2023 jslaby@suse.cz
- README.SUSE: fix patches.addon use
  It's series, not series.conf in there.
  And make it more precise on when the patches are applied.
- commit cb8969c
* Wed Nov 29 2023 tbogendoerfer@suse.de
- RDMA/mlx5: Change the key being sent for MPV device affiliation
  (jsc#PED-3311).
- netdevsim: Block until all devices are released (jsc#PED-3311).
- net: make sure we never create ifindex = 0 (jsc#PED-3311).
- commit 3490f32
* Wed Nov 29 2023 tbogendoerfer@suse.de
- staging/qlge: devlink use retained error fmsg API
  (jsc#PED-3311).
- tools: ynl: fix duplicate op name in devlink (jsc#PED-3311).
- net/mlx5e: Check return value of snprintf writing to fw_version
  buffer for representors (jsc#PED-3311).
- net/mlx5e: Check return value of snprintf writing to fw_version
  buffer (jsc#PED-3311).
- net/mlx5e: Reduce the size of icosq_str (jsc#PED-3311).
- net/mlx5: Increase size of irq name buffer (jsc#PED-3311).
- net/mlx5e: Update doorbell for port timestamping CQ before
  the software counter (jsc#PED-3311).
- net/mlx5e: Track xmit submission to PTP WQ after populating
  metadata map (jsc#PED-3311).
- net/mlx5e: Avoid referencing skb after free-ing in drop path
  of mlx5e_sq_xmit_wqe (jsc#PED-3311).
- net/mlx5e: Don't modify the peer sent-to-vport rules for IPSec
  offload (jsc#PED-3311).
- net/mlx5e: Fix pedit endianness (jsc#PED-3311).
- net/mlx5e: fix double free of encap_header in update funcs
  (jsc#PED-3311).
- net/mlx5e: fix double free of encap_header (jsc#PED-3311).
- net/mlx5: Decouple PHC .adjtime and .adjphase implementations
  (jsc#PED-3311).
- net/mlx5: DR, Allow old devices to use multi destination FTE
  (jsc#PED-3311).
- net/mlx5: Free used cpus mask when an IRQ is released
  (jsc#PED-3311).
- Revert "net/mlx5: DR, Supporting inline WQE when possible"
  (jsc#PED-3311).
- pds_core: fix up some format-truncation complaints
  (jsc#PED-3311).
- vhost-vdpa: fix use after free in vhost_vdpa_probe()
  (jsc#PED-3311).
- tools: ynl-gen: don't touch the output file if content is the
  same (jsc#PED-3311).
- netlink: specs: devlink: add forgotten port function caps enum
  values (jsc#PED-3311).
- vdpa/mlx5: implement .reset_map driver op (jsc#PED-3311).
- vhost-vdpa: clean iotlb map during reset for older userspace
  (jsc#PED-3311).
- vdpa: introduce .compat_reset operation callback (jsc#PED-3311).
- vhost-vdpa: introduce IOTLB_PERSIST backend feature bit
  (jsc#PED-3311).
- vhost-vdpa: reset vendor specific mapping to initial state in
  .release (jsc#PED-3311).
- vdpa: introduce .reset_map operation callback (jsc#PED-3311).
- mlx5_vdpa: offer VHOST_BACKEND_F_ENABLE_AFTER_DRIVER_OK
  (jsc#PED-3311).
- vdpa/mlx5: Update cvq iotlb mapping on ASID change
  (jsc#PED-3311).
- vdpa/mlx5: Make iotlb helper functions more generic
  (jsc#PED-3311).
- vdpa/mlx5: Enable hw support for vq descriptor mapping
  (jsc#PED-3311).
- vdpa/mlx5: Introduce mr for vq descriptor (jsc#PED-3311).
- vdpa/mlx5: Improve mr update flow (jsc#PED-3311).
- vdpa/mlx5: Move mr mutex out of mr struct (jsc#PED-3311).
- vdpa/mlx5: Allow creation/deletion of any given mr struct
  (jsc#PED-3311).
- vdpa/mlx5: Rename mr destroy functions (jsc#PED-3311).
- vdpa/mlx5: Collapse "dvq" mr add/delete functions
  (jsc#PED-3311).
- vdpa/mlx5: Take cvq iotlb lock during refresh (jsc#PED-3311).
- vdpa/mlx5: Decouple cvq iotlb handling from hw mapping code
  (jsc#PED-3311).
- vdpa/mlx5: Create helper function for dma mappings
  (jsc#PED-3311).
- vhost-vdpa: uAPI to get dedicated descriptor group id
  (jsc#PED-3311).
- vhost-vdpa: introduce descriptor group backend feature
  (jsc#PED-3311).
- vdpa: introduce dedicated descriptor group for virtqueue
  (jsc#PED-3311).
- vdpa/mlx5: Expose descriptor group mkey hw capability
  (jsc#PED-3311).
- IB/mlx5: Rename 400G_8X speed to comply to naming convention
  (jsc#PED-3311).
- IB/mlx5: Add support for 800G_8X lane speed (jsc#PED-3311).
- tools: ynl: introduce option to process unknown attributes or
  types (jsc#PED-3311).
- tools: ynl-gen: respect attr-cnt-name at the attr set level
  (jsc#PED-3311).
- netlink: specs: support conditional operations (jsc#PED-3311).
- netlink: make range pointers in policies const (jsc#PED-3311).
- net/mlx5: fix uninit value use (jsc#PED-3311).
- tools: ynl-gen: add support for exact-len validation
  (jsc#PED-3311).
- devlink: remove netlink small_ops (jsc#PED-3311).
- devlink: remove duplicated netlink callback prototypes
  (jsc#PED-3311).
- netlink: specs: devlink: add the remaining command to generate
  complete split_ops (jsc#PED-3311).
- devlink: rename netlink callback to be aligned with the
  generated ones (jsc#PED-3311).
- netlink: specs: devlink: make dont-validate single line
  (jsc#PED-3311).
- netlink: specs: devlink: remove reload-action from devlink-get
  cmd reply (jsc#PED-3311).
- tools: ynl-gen: render rsp_parse() helpers if cmd has only
  dump op (jsc#PED-3311).
- tools: ynl-gen: introduce support for bitfield32 attribute type
  (jsc#PED-3311).
- genetlink: don't merge dumpit split op for different cmds into
  single iter (jsc#PED-3311).
- tools: ynl-gen: change spacing around __attribute__
  (jsc#PED-3311).
- pds_core: add an error code check in pdsc_dl_info_get
  (jsc#PED-3311).
- netlink: specs: add support for auto-sized scalars
  (jsc#PED-3311).
- tools: ynl-gen: make the mnl_type() method public
  (jsc#PED-3311).
- devlink: convert most of devlink_fmsg_*() to return void
  (jsc#PED-3311).
- net/mlx5: devlink health: use retained error fmsg API
  (jsc#PED-3311).
- mlxsw: core: devlink health: use retained error fmsg API
  (jsc#PED-3311).
- hinic: devlink health: use retained error fmsg API
  (jsc#PED-3311).
- pds_core: devlink health: use retained error fmsg API
  (jsc#PED-3311).
- netdevsim: devlink health: use retained error fmsg API
  (jsc#PED-3311).
- devlink: retain error in struct devlink_fmsg (jsc#PED-3311).
- tools: ynl-gen: support limit names (jsc#PED-3311).
- tools: ynl-gen: support full range of min/max checks for
  integer values (jsc#PED-3311).
- tools: ynl-gen: track attribute use (jsc#PED-3311).
- devlink: document devlink_rel_nested_in_notify() function
  (jsc#PED-3311).
- devlink: don't take instance lock for nested handle put
  (jsc#PED-3311).
- devlink: take device reference for devlink object
  (jsc#PED-3311).
- devlink: call peernet2id_alloc() with net pointer under RCU
  read lock (jsc#PED-3311).
- net: treat possible_net_t net pointer as an RCU one and add
  read_pnet_rcu() (jsc#PED-3311).
- net/mlx5e: Allow IPsec soft/hard limits in bytes (jsc#PED-3311).
- net/mlx5e: Increase max supported channels number to 256
  (jsc#PED-3311).
- net/mlx5e: Preparations for supporting larger number of channels
  (jsc#PED-3311).
- net/mlx5e: Refactor mlx5e_rss_init() and mlx5e_rss_free()
  API's (jsc#PED-3311).
- net/mlx5e: Refactor mlx5e_rss_set_rxfh() and
  mlx5e_rss_get_rxfh() (jsc#PED-3311).
- net/mlx5e: Refactor rx_res_init() and rx_res_free() APIs
  (jsc#PED-3311).
- net/mlx5e: Use PTR_ERR_OR_ZERO() to simplify code
  (jsc#PED-3311).
- net/mlx5: Use PTR_ERR_OR_ZERO() to simplify code (jsc#PED-3311).
- net/mlx5: Remove unused declaration (jsc#PED-3311).
- net/mlx5: Replace global mlx5_intf_lock with HCA devcom
  component lock (jsc#PED-3311).
- net/mlx5: Refactor LAG peer device lookout bus logic to mlx5
  devcom (jsc#PED-3311).
- net/mlx5: Avoid false positive lockdep warning by adding
  lock_class_key (jsc#PED-3311).
- net/mlx5: Redesign SF active work to remove table_lock
  (jsc#PED-3311).
- net/mlx5: Parallelize vhca event handling (jsc#PED-3311).
- docs: netlink: clean up after deprecating version
  (jsc#PED-3311).
- tools: ynl: fix converting flags to names after recent cleanup
  (jsc#PED-3311).
- net/mlx5: Handle IPsec steering upon master unbind/bind
  (jsc#PED-3311).
- net/mlx5: Configure IPsec steering for ingress RoCEv2 MPV
  traffic (jsc#PED-3311).
- net/mlx5: Configure IPsec steering for egress RoCEv2 MPV traffic
  (jsc#PED-3311).
- net/mlx5: Add create alias flow table function to ipsec roce
  (jsc#PED-3311).
- net/mlx5: Implement alias object allow and create functions
  (jsc#PED-3311).
- net/mlx5: Add alias flow table bits (jsc#PED-3311).
- net/mlx5: Store devcom pointer inside IPsec RoCE (jsc#PED-3311).
- net/mlx5: Register mlx5e priv to devcom in MPV mode
  (jsc#PED-3311).
- RDMA/mlx5: Send events from IB driver about device affiliation
  state (jsc#PED-3311).
- net/mlx5: Introduce ifc bits for migration in a chunk mode
  (jsc#PED-3311).
- tools: ynl: use ynl-gen -o instead of stdout in Makefile
  (jsc#PED-3311).
- netlink: specs: don't allow version to be specified for
  genetlink (jsc#PED-3311).
- tools: ynl-gen: handle do ops with no input attrs
  (jsc#PED-3311).
- tools: ynl-gen: lift type requirement for attribute subsets
  (jsc#PED-3311).
- tools: ynl-gen: use uapi header name for the header guard
  (jsc#PED-3311).
- tools: ynl: use uAPI include magic for samples (jsc#PED-3311).
- tools: ynl: don't regen on every make (jsc#PED-3311).
- handshake: Fix sign of key_serial_t fields (jsc#PED-3311).
- handshake: Fix sign of socket file descriptor fields
  (jsc#PED-3311).
- net/mlx5: Enable 4 ports multiport E-switch (jsc#PED-3311).
- net/mlx5: Add a health error syndrome for pci data poisoned
  (jsc#PED-3311).
- net/mlx5: DR, Handle multi destination action in the right order
  (jsc#PED-3311).
- net/mlx5: DR, Add check for multi destination FTE
  (jsc#PED-3311).
- net/mlx5: Bridge, Enable mcast in smfs steering mode
  (jsc#PED-3311).
- net/mlx5e: Check police action rate for matchall filter
  (jsc#PED-3311).
- net/mlx5e: Consider aggregated port speed during rate
  configuration (jsc#PED-3311).
- net/mlx5: Remove redundant max_sfs check and field from struct
  mlx5_sf_dev_table (jsc#PED-3311).
- net/mlx5: Remove SF table reference counting (jsc#PED-3311).
- net/mlx5: Push common deletion code into mlx5_sf_del()
  (jsc#PED-3311).
- net/mlx5: Rename mlx5_sf_deactivate_all() to mlx5_sf_del_all()
  (jsc#PED-3311).
- net/mlx5: Move state lock taking into mlx5_sf_dealloc()
  (jsc#PED-3311).
- net/mlx5: Convert SF port_indices xarray to function_ids xarray
  (jsc#PED-3311).
- net/mlx5: Use devlink port pointer to get the pointer of
  container SF struct (jsc#PED-3311).
- net/mlx5: Call mlx5_sf_id_erase() once in mlx5_sf_dealloc()
  (jsc#PED-3311).
- tools: ynl: extend netdev sample to dump
  xdp-rx-metadata-features (jsc#PED-3311).
- net/mlx5e: Set en auxiliary devlink instance as nested
  (jsc#PED-3311).
- devlink: introduce possibility to expose info about nested
  devlinks (jsc#PED-3311).
- devlink: convert linecard nested devlink to new rel
  infrastructure (jsc#PED-3311).
- net/mlx5: SF, Implement peer devlink set for SF representor
  devlink port (jsc#PED-3311).
- devlink: expose peer SF devlink instance (jsc#PED-3311).
- devlink: introduce object and nested devlink relationship infra
  (jsc#PED-3311).
- devlink: extend devlink_nl_put_nested_handle() with attrtype
  arg (jsc#PED-3311).
- devlink: move devlink_nl_put_nested_handle() into netlink.c
  (jsc#PED-3311).
- devlink: put netnsid to nested handle (jsc#PED-3311).
- devlink: move linecard struct into linecard.c (jsc#PED-3311).
- vhost: Allow null msg.size on VHOST_IOTLB_INVALIDATE
  (jsc#PED-3311).
- netlink: specs: devlink: fix reply command values
  (jsc#PED-3311).
- devlink: Hold devlink lock on health reporter dump get
  (jsc#PED-3311).
- vdpa: add get_backend_features vdpa operation (jsc#PED-3311).
- vdpa: accept VHOST_BACKEND_F_ENABLE_AFTER_DRIVER_OK backend
  feature (jsc#PED-3311).
- vdpa: add VHOST_BACKEND_F_ENABLE_AFTER_DRIVER_OK flag
  (jsc#PED-3311).
- pds_core: protect devlink callbacks from fw_down state
  (jsc#PED-3311).
- devlink: move devlink_notify_register/unregister() to dev.c
  (jsc#PED-3311).
- devlink: move small_ops definition into netlink.c
  (jsc#PED-3311).
- devlink: move tracepoint definitions into core.c (jsc#PED-3311).
- devlink: push linecard related code into separate file
  (jsc#PED-3311).
- devlink: push rate related code into separate file
  (jsc#PED-3311).
- devlink: push trap related code into separate file
  (jsc#PED-3311).
- devlink: use tracepoint_enabled() helper (jsc#PED-3311).
- devlink: push region related code into separate file
  (jsc#PED-3311).
- devlink: push param related code into separate file
  (jsc#PED-3311).
- devlink: push resource related code into separate file
  (jsc#PED-3311).
- devlink: push dpipe related code into separate file
  (jsc#PED-3311).
- devlink: move and rename devlink_dpipe_send_and_alloc_skb()
  helper (jsc#PED-3311).
- devlink: push shared buffer related code into separate file
  (jsc#PED-3311).
- devlink: push port related code into separate file
  (jsc#PED-3311).
- devlink: push object register/unregister notifications into
  separate helpers (jsc#PED-3311).
- tools/net/ynl: Add support for create flags (jsc#PED-3311).
- tools/net/ynl: Implement nlattr array-nest decoding in ynl
  (jsc#PED-3311).
- tools/net/ynl: Add support for netlink-raw families
  (jsc#PED-3311).
- tools/net/ynl: Fix extack parsing with fixed header genlmsg
  (jsc#PED-3311).
- tools/ynl: Add mcast-group schema parsing to ynl (jsc#PED-3311).
- doc/netlink: Update genetlink-legacy documentation
  (jsc#PED-3311).
- doc/netlink: Add a schema for netlink-raw families
  (jsc#PED-3311).
- doc/netlink: Fix typo in genetlink-* schemas (jsc#PED-3311).
- tools: ynl-gen: fix uAPI generation after tempfile changes
  (jsc#PED-3311).
- tools: ynl-gen: support empty attribute lists (jsc#PED-3311).
- tools: ynl-gen: fix collecting global policy attrs
  (jsc#PED-3311).
- tools: ynl-gen: set length of binary fields (jsc#PED-3311).
- tools: ynl: allow passing binary data (jsc#PED-3311).
- tools: ynl-gen: use temporary file for rendering (jsc#PED-3311).
- tools: ynl: add more info to KeyErrors on missing attrs
  (jsc#PED-3311).
- genetlink: add genlmsg_iput() API (jsc#PED-3311).
- genetlink: add a family pointer to struct genl_info
  (jsc#PED-3311).
- genetlink: use attrs from struct genl_info (jsc#PED-3311).
- genetlink: add struct genl_info to struct genl_dumpit_info
  (jsc#PED-3311).
- genetlink: remove userhdr from struct genl_info (jsc#PED-3311).
- genetlink: make genl_info->nlhdr const (jsc#PED-3311).
- genetlink: push conditional locking into dumpit/done
  (jsc#PED-3311).
- netlink: specs: devlink: extend health reporter dump attributes
  by port index (jsc#PED-3311).
- devlink: extend health reporter dump selector by port index
  (jsc#PED-3311).
- netlink: specs: devlink: extend per-instance dump commands to
  accept instance attributes (jsc#PED-3311).
- devlink: allow user to narrow per-instance dumps by passing
  handle attrs (jsc#PED-3311).
- netlink: specs: devlink: add commands that do per-instance dump
  (jsc#PED-3311).
- tools: ynl-gen: add missing empty line between policies
  (jsc#PED-3311).
- tools: ynl-gen: avoid rendering empty validate field
  (jsc#PED-3311).
- devlink: Remove unused devlink_dpipe_table_resource_set()
  declaration (jsc#PED-3311).
- netlink: specs: devlink: add info-get dump op (jsc#PED-3311).
- ynl-gen-c.py: render netlink policies static for split ops
  (jsc#PED-3311).
- ynl-gen-c.py: allow directional model for kernel mode
  (jsc#PED-3311).
- ynl-gen-c.py: filter rendering of validate field values for
  split ops (jsc#PED-3311).
- netlink: specs: add dump-strict flag for dont-validate property
  (jsc#PED-3311).
- devlink: Remove unused extern declaration
  devlink_port_region_destroy() (jsc#PED-3311).
- net: store netdevs in an xarray (jsc#PED-3311).
- ynl: print xdp-zc-max-segs in the sample (jsc#PED-3311).
- ynl: regenerate all headers (jsc#PED-3311).
- ynl: mark max/mask as private for kdoc (jsc#PED-3311).
- genetlink: add explicit ordering break check for split ops
  (jsc#PED-3311).
- vhost-scsi: Rename vhost_scsi_iov_to_sgl (jsc#PED-3311).
- vhost-scsi: Fix alignment handling with windows (jsc#PED-3311).
- tools: ynl-gen: fix parse multi-attr enum attribute
  (jsc#PED-3311).
- vhost: Make parameter name match of vhost_get_vq_desc()
  (jsc#PED-3311).
- vhost: Allow worker switching while work is queueing
  (jsc#PED-3311).
- vhost_scsi: add support for worker ioctls (jsc#PED-3311).
- vhost: allow userspace to create workers (jsc#PED-3311).
- vhost: replace single worker pointer with xarray (jsc#PED-3311).
- vhost: add helper to parse userspace vring state/file
  (jsc#PED-3311).
- vhost: remove vhost_work_queue (jsc#PED-3311).
- vhost_scsi: flush IO vqs then send TMF rsp (jsc#PED-3311).
- vhost_scsi: convert to vhost_vq_work_queue (jsc#PED-3311).
- vhost_scsi: make SCSI cmd completion per vq (jsc#PED-3311).
- vhost_sock: convert to vhost_vq_work_queue (jsc#PED-3311).
- vhost: convert poll work to be vq based (jsc#PED-3311).
- vhost: take worker or vq for flushing (jsc#PED-3311).
- vhost: take worker or vq instead of dev for queueing
  (jsc#PED-3311).
- vhost, vhost_net: add helper to check if vq has work
  (jsc#PED-3311).
- vhost: add vhost_worker pointer to vhost_virtqueue
  (jsc#PED-3311).
- vhost: dynamically allocate vhost_worker (jsc#PED-3311).
- vhost: create worker at end of vhost_dev_set_owner
  (jsc#PED-3311).
- tools: ynl: add display-hint support to ynl (jsc#PED-3311).
- netlink: specs: add display-hint to schema definitions
  (jsc#PED-3311).
- tools: ynl: improve the direct-include header guard logic
  (jsc#PED-3311).
- tools: ynl: work around stale system headers (jsc#PED-3311).
- tools: ynl-gen: inherit policy in multi-attr (jsc#PED-3311).
- tools: ynl-gen: correct enum policies (jsc#PED-3311).
- netlink: support extack in dump ->start() (jsc#PED-3311).
- tools: ynl: add sample for ethtool (jsc#PED-3311).
- tools: ynl: generate code for the ethtool family (jsc#PED-3311).
- tools: ynl-gen: resolve enum vs struct name conflicts
  (jsc#PED-3311).
- tools: ynl-gen: don't generate enum types if unnamed
  (jsc#PED-3311).
- netlink: specs: support setting prefix-name per attribute
  (jsc#PED-3311).
- tools: ynl-gen: record extra args for regen (jsc#PED-3311).
- tools: ynl-gen: support excluding tricky ops (jsc#PED-3311).
- tools: ynl-gen: support / skip pads on the way to kernel
  (jsc#PED-3311).
- tools: ynl-gen: don't pass op_name to RenderInfo (jsc#PED-3311).
- tools: ynl-gen: support code gen for events (jsc#PED-3311).
- tools: ynl-gen: sanitize notification tracking (jsc#PED-3311).
- tools: ynl: regen: stop generating common notification handlers
  (jsc#PED-3311).
- tools: ynl-gen: stop generating common notification handlers
  (jsc#PED-3311).
- tools: ynl: regen: regenerate the if ladders (jsc#PED-3311).
- tools: ynl-gen: get attr type outside of if() (jsc#PED-3311).
- tools: ynl-gen: combine else with closing bracket
  (jsc#PED-3311).
- tools: ynl-gen: complete the C keyword list (jsc#PED-3311).
- tools: ynl: regen: cleanup user space header includes
  (jsc#PED-3311).
- tools: ynl-gen: cleanup user space header includes
  (jsc#PED-3311).
- Revert "tools: ynl: Remove duplicated include in
  handshake-user.c" (jsc#PED-3311).
- tools: ynl: Remove duplicated include in handshake-user.c
  (jsc#PED-3311).
- tools: ynl: add sample for devlink (jsc#PED-3311).
- tools: ynl-gen: don't generate forward declarations for policies
- regen (jsc#PED-3311).
- tools: ynl-gen: don't generate forward declarations for policies
  (jsc#PED-3311).
- tools: ynl-gen: walk nested types in depth (jsc#PED-3311).
- tools: ynl-gen: inherit struct use info (jsc#PED-3311).
- tools: ynl-gen: try to sort the types more intelligently
  (jsc#PED-3311).
- tools: ynl-gen: enable code gen for directional specs
  (jsc#PED-3311).
- tools: ynl-gen: refactor strmap helper generation
  (jsc#PED-3311).
- tools: ynl-gen: use enum names in op strmap more carefully
  (jsc#PED-3311).
- netlink: specs: devlink: fill in some details important for C
  (jsc#PED-3311).
- tools: ynl-gen: improve unwind on parsing errors (jsc#PED-3311).
- tools: ynl-gen: fill in support for MultiAttr scalars
  (jsc#PED-3311).
- tools: ynl: add sample for netdev (jsc#PED-3311).
- tools: ynl-gen: clean up stray new lines at the end of
  reply-less requests (jsc#PED-3311).
- tools: ynl-gen: generate static descriptions of notifications
  (jsc#PED-3311).
- tools: ynl-gen: switch to family struct (jsc#PED-3311).
- tools: ynl-gen: generate alloc and free helpers for req
  (jsc#PED-3311).
- tools: ynl-gen: move the response reading logic into YNL
  (jsc#PED-3311).
- tools: ynl-gen: generate enum-to-string helpers (jsc#PED-3311).
- tools: ynl-gen: add error checking for nested structs
  (jsc#PED-3311).
- tools: ynl-gen: loosen type consistency check for events
  (jsc#PED-3311).
- tools: ynl-gen: don't override pure nested struct
  (jsc#PED-3311).
- tools: ynl-gen: fix unused / pad attribute handling
  (jsc#PED-3311).
- tools: ynl-gen: add extra headers for user space (jsc#PED-3311).
- tools: ynl: Support enums in struct members in genetlink-legacy
  (jsc#PED-3311).
- tools: ynl: Initialise fixed headers to 0 in genetlink-legacy
  (jsc#PED-3311).
- doc: ynl: Add doc attr to struct members in genetlink-legacy
  spec (jsc#PED-3311).
- net: ynl: prefix uAPI header include with uapi/ (jsc#PED-3311).
- tools: ynl: Handle byte-order in struct members (jsc#PED-3311).
- tools: ynl: Use dict of predefined Structs to decode scalar
  types (jsc#PED-3311).
- commit 28f034d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Disable ASPM for VI w/ all Intel systems (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c59a93b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/pmu: Check if pmu is closed before stopping event (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f05d5c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/mcr: Hold GT forcewake during steering operations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c8c81e8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/perf: Determine context valid in OA reports (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d95b342
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/logicvc: Kconfig: select REGMAP and REGMAP_MMIO (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 42eb0f9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: reserve a fence slot while locking the BO (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1a8d66c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Remove redundant call to priority_is_valid() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d87d1ce
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/dp_mst: Fix NULL deref in get_mst_branch_device_by_guid_helper() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7783812
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: ignore duplicate BOs again (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c284b6a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mediatek: Correctly free sg_table in gem prime vmap (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 181dcf1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Retry gtt fault when out of fence registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 609ba44
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/cx0: Only clear/set the Pipe Reset bit of the PHY Lanes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 32ebc18
* Wed Nov 29 2023 pjakobsson@suse.de
- gpu/drm: Eliminate DRM_SCHED_PRIORITY_UNSET (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9a23859
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Unset context priority is now invalid (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dba17d0
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/edid: add 8 bpc quirk to the BenQ GW2765 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4494062
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ttm: Reorder sys manager cleanup step (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c730064
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau/disp: fix DP capable DSM connectors (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 948759b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: exec: fix ioctl kernel-doc warning (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8beefef
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: Move AUX B116XW03 out of panel-edp back to panel-simple (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c79026f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: ti-sn65dsi86: Associate DSI device lifetime with (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 281debb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Reserve fences for VM update (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f7974a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix possible null pointer dereference (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dd1c5e0
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: core: syscopyarea: fix sloppy typing (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0b1f5b7
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: core: cfbcopyarea: fix sloppy typing (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6b6c8a4
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: uvesafb: Call cn_del_callback() at the end of uvesafb_exit() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ac29aae
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: uvesafb: Remove uvesafb_exec() prototype from (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eb63967
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: sa1100fb: mark sa1100fb_init() static (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8bc8206
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: omapfb: fix some error codes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 546ab49
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: atyfb: only use ioremap_uc() on i386 and ia64 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f1e69e2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: fix SI failure due to doorbells allocation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d9ba14a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: add missing NULL check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 79f653c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Don't set dpms_off for seamless boot (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1c50480
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: fail dpu_plane_atomic_check() based on mdp clk limits (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0f9d053
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dp: Add newlines to debug printks (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7182856
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: change _dpu_plane_calc_bw() to use u64 to avoid overflow (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6ebf8ae
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dsi: fix irq_of_parse_and_map() error checking (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5672f8d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dsi: skip the wait for video mode done if not applicable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2aad66a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/mdss: fix highest-bank-bit for msm8998 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a2e812c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dp: do not reinitialize phy unless retry during link training (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 381896d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tiny: correctly print `struct resource *` on error (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e91fe15
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/atomic-helper: relax unregistered connector check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d0c6a0d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: boe-tv101wum-nl6: Completely pull GPW to VGL before TP (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7c55462
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/vmwgfx: fix typo of sizeof argument (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fe2b01a
* Wed Nov 29 2023 pjakobsson@suse.de
- dma-buf: add dma_fence_timestamp helper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2b40c37
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: exec: report max pushs through getparam (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d62a7fa
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: chan: use channel class definitions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e33824b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: chan: use struct nvif_mclass (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ca57f46
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: panel-orientation-quirks: Add quirk for One Mix 2S (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 731adeb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tests: Fix kunit_release_action ctx argument (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5bc11b8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: apply edge-case DISPCLK WDIVIDER changes to master (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fb172c1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Fix detection of _PR3 on the PCIe root port (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f9b3bd2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Fix logic error in sienna_cichlid_update_pcie_parameters() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9f79dc4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix a memory leak (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 150411c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: add unique_id for gc 11.0.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e378c9a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Invalidate the TLBs on each GT (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ef2a30e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Register engines early to avoid type confusion (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4d4649a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Don't set PIPE_CONTROL_FLUSH_L3 for aux inval (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 072034c
* Wed Nov 29 2023 pjakobsson@suse.de
- i915/guc: Get runtime pm in busyness worker only if already active (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a522fe7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/gt: Fix reservation address in ggtt_reserve_guc_top (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b08c2b7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: Use gpu_offset for user queue's wptr (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3953fbf
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: fix a memory leak in amdgpu_ras_feature_enable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 517ea49
* Wed Nov 29 2023 pjakobsson@suse.de
- Revert "drm/amdgpu: Report vbios version instead of PN" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ff0b6a0
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Fix MST recognizes connected displays as one (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ceb2606
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/gt: Prevent error pointer dereference (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d2d3297
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/sh7760fb: Depend on FB=y (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 032242e
* Wed Nov 29 2023 pjakobsson@suse.de
- nouveau/u_memcpya: fix NULL vs error pointer bug (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eb36ffc
* Wed Nov 29 2023 pjakobsson@suse.de
- nouveau/u_memcpya: use vmemdup_user (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7101c9d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: sched: fix leaking memory of timedout job (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 767e495
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: fence: fix type cast warning in nouveau_fence_emit() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a393281
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: fix up fbdev Kconfig defaults (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 802eaca
* Wed Nov 29 2023 pjakobsson@suse.de
- Revert "drm/vkms: Fix race-condition between the hrtimer and the (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7c6f9cc
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: Insert missing TLB flush on GFX10 and later (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fa0a165
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Fix 2nd DPIA encoder Assignment (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 211fd2f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Add DPIA Link Encoder Assignment Fix (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cac572f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: fix replay_mode kernel-doc warning (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0afda55
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Handle null atom context in VBIOS info ioctl (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 49af03d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: Checkpoint and restore queues on GFX11 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e22977d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Adjust the MST resume flow (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3cf5c40
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: fallback to old RAS error message for aqua_vanjaram (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 61f9054
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/nbio4.3: set proper rmmio_remap.reg_offset for SR-IOV (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7a70527
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/soc21: don't remap HDP registers for SR-IOV (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 03e9b5e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Don't check registers, if using AUX BL control (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 85c8025
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: fix retry loop test (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7bf7556
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Add dirty rect support for Replay (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3b1fe06
* Wed Nov 29 2023 pjakobsson@suse.de
- Revert "drm/amd: Disable S/G for APUs when 64GB or more host memory" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 88dba3a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: Update CU masking for GFX 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b386c0a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: Update cache info reporting for GFX v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 35f6384
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Store CU info from all XCCs for GFX v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fe25f99
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: Fix unaligned 64-bit doorbell warning (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e646c45
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: Fix reg offset for setting CWSR grace period (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 970ea3d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/drm_connector: Provide short description of param (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5ad0f1f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/drm_exec: Work around a WW mutex lockdep oddity (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9f9a786
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: ci: docs: fix build warning - add missing escape (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 51886fc
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: Add initial ci/ subdirectory (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0e3bcd8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Restrict bootloader wait to SMUv13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b00a240
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: limit the v_startup workaround to ASICs older than (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7d9df69
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: fix amdgpu_cs_p1_user_fence (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 704a521
* Wed Nov 29 2023 pjakobsson@suse.de
- Revert "Revert "drm/amd/display: Implement zpos property"" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5c04c08
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: Add missing gfx11 MQD manager callbacks (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c060dd3
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Free ras cmd input buffer properly (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d59f18f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Hide xcp partition sysfs under SRIOV (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bbd65f7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: use read-modify-write mode for gfx v9_4_3 SQ setting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a82f602
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: use mask to get v9 interrupt sq data bits correctly (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d28ba63
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Allocate coredump memory in a nonblocking way (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e75743d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Support query ecc cap for aqua_vanjaram (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9df9935
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Add umc_info v4_0 structure (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 62ac569
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: update blank state on ODM changes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f350385
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Add SMU v13.0.6 default reset methods (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 01ff41b
* Wed Nov 29 2023 pjakobsson@suse.de
- Partially revert "drm/amd/display: update add plane to context logic (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ed62806
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Add bootloader wait for PSP v13 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fa83197
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: register a dirty framebuffer callback for fbcon (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f2a7f80
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Updated TCP/UTCL1 programming (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5c9a562
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: fix debugfs pm_info output (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 87e283e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix the return for gpu mode1_reset (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eee062d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: fix static screen detection setting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9c6b0b4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Fix critical temp unit of SMU v13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b824103
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Remove SRAM clock gater override by driver (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 954f40d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Add bootloader status check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e8237a2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: use correct method to get clock under SRIOV (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 91d227e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Unset baco dummy mode on nbio v7.9 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 14a385d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: set minimum of VBlank_nom (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 112fbfa
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Correct unit conversion for vstartup
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit be5efc2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Roll back unit correction (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- commit 0b1f260
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Enable ras for mp0 v13_0_6 sriov (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 853f802
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: retry after EBUSY is returned from hmm_ranges_get_pages (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8d79ccb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/jpeg - skip change of power-gating state for sriov (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1bca7ed
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Add critical temp for GC v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c3012dd
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Update SMUv13.0.6 PMFW headers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d762fd6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: update gc_info v2_1 from discovery (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8568ba1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: update mall info v2 from discovery (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1706b34
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Only support RAS EEPROM on dGPU platform (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3acc630
* Wed Nov 29 2023 pjakobsson@suse.de
- Documentation/gpu: Update amdgpu documentation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6f0ca80
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/pm: Add notification for no DC support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a280c1c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Enable Replay for static screen use cases (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c9f5036
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: fence: fix undefined fence state after emit (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a50bf35
* Wed Nov 29 2023 pjakobsson@suse.de
- backlight: led_bl: Remove redundant of_match_ptr() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3cb5e04
* Wed Nov 29 2023 pjakobsson@suse.de
- backlight: lp855x: Drop ret variable in brightness change function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ce4f083
* Wed Nov 29 2023 pjakobsson@suse.de
- backlight: lp855x: Catch errors when changing brightness (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d051ae3
* Wed Nov 29 2023 pjakobsson@suse.de
- backlight: qcom-wled: Explicitly include correct DT includes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a45b995
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/g364fb: fix build failure with mips (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e6197c4
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: ssd1307fb: Use bool for ssd1307fb_deviceinfo flags (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6249e39
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: neofb: Shorten Neomagic product name in info struct (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bd2740c
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: mx3fb: Remove the driver (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d345b0f
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/core: Use list_for_each_entry() helper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ffcf976
* Wed Nov 29 2023 pjakobsson@suse.de
- mei: make mei_class a static const structure (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6c4d43c
* Wed Nov 29 2023 pjakobsson@suse.de
- mei: gsc: add module description (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c9be1cc
* Wed Nov 29 2023 pjakobsson@suse.de
- mei: pxp: Keep a const qualifier when calling mei_cldev_send() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2abde13
* Wed Nov 29 2023 pjakobsson@suse.de
- mei: obtain firmware version only on gsc. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b3c05a8
* Wed Nov 29 2023 pjakobsson@suse.de
- mei: bus: enable asynchronous suspend. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 870a347
* Wed Nov 29 2023 pjakobsson@suse.de
- mei: log firmware status on hw_start failure. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aff7b98
* Wed Nov 29 2023 pjakobsson@suse.de
- tty: sysrq: switch sysrq handlers from int to u8 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b19c8f9
* Wed Nov 29 2023 pjakobsson@suse.de
- PCI/VGA: Fix typos (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7d4ef02
* Wed Nov 29 2023 pjakobsson@suse.de
- PCI/VGA: Simplify vga_client_register() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4665017
* Wed Nov 29 2023 pjakobsson@suse.de
- PCI/VGA: Simplify vga_arbiter_notify_clients() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5c6b030
* Wed Nov 29 2023 pjakobsson@suse.de
- PCI/VGA: Correct vga_update_device_decodes() parameter type (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6965607
* Wed Nov 29 2023 pjakobsson@suse.de
- PCI/VGA: Correct vga_str_to_iostate() io_state parameter type (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eb88c53
* Wed Nov 29 2023 pjakobsson@suse.de
- PCI/VGA: Replace full MIT license text with SPDX identifier (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 47fd697
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Fix TLB-Invalidation seqno store (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e0b54a3
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/gpuva_mgr: remove unused prev pointer in __drm_gpuva_sm_map() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8ec603e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tests/drm_kunit_helpers: Place correct function name in the (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 143dd6b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: uapi: don't pass NO_PREFETCH flag implicitly (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit db24d10
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: uvmm: fix unset region pointer on remap (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e2bc18c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: sched: avoid job races between entities (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f7630bb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ttm/tests: Fix type conversion in ttm_pool_test (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1587360
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/a6xx: Bail out early if setting GPU OOB fails (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bdbcdd9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/a6xx: Move LLC accessors to the common header (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0fa653a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/a6xx: Introduce a6xx_llc_read (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3627a72
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/adreno: Add missing MODULE_FIRMWARE macros (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fefbd16
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/gpu: Push gpu lock down past runpm (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bb74beb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm: Remove vma use tracking (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ba79855
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm: Take lru lock once per submit_pin_objects() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5015011
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm: Use drm_gem_object in submit bos table (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a62c46
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm: Take lru lock once per job_run (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b4c8902
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/adreno: adreno_gpu: Switch to memdup_user_nul() helper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5576c9c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm: Disallow relocs on a6xx+ (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 17fd04b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/a6xx: Fix up GMU region reservations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 95d7c48
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/a6xx: Improve GMU force shutdown sequence (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 290dd51
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/a6xx: Ensure clean GMU state in a6xx_gmu_fw_start (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7719f70
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/a6xx: Skip empty protection ranges entries (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1009fcf
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/a6xx: Use descriptive bitfield names for CP_PROTECT_CNTL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 26dd175
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/a6xx: Add some missing header definitions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 12d0189
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/a6xx: Fix misleading comment (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e81c887
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/adreno: Switch to chip-id for identifying GPU (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 67fcfaa
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/adreno: Move adreno info to config (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ce7da59
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/adreno: Add helper for formating chip-id (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 68db992
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/adreno: Add adreno family (jsc#PED-3527 jsc#PED-5475
  jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh patches.suse/drm-msm-a690-Switch-to-a660_gmu.bin.patch.
- commit 65ac2d6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/adreno: Bring the a630 family together (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7a40ea1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/adreno: Move speedbin mapping to device table (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8d08940
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/adreno: Allow SoC specific gpu device table entries (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2a57b1c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/adreno: Use quirk to identify cached-coherent support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 02e183e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/adreno: Use quirk identify hw_apriv (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 527750f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/adreno: Remove redundant revn param (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4929d04
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/adreno: Remove redundant gmem size param (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ab2dbc7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/adreno: Remove GPU name (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ed69482
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: initialise clk_rate to 0 in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ac95b42
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: clean up some inconsistent indenting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 12a0237
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: Drop encoder vsync_event (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cc23a4d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: fix DSC 1.2 enc subblock length (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 067458b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: fix DSC 1.2 block lengths (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9a17712
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: drop dpu_core_perf_destroy() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b74d06c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: move max clock decision to dpu_kms. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 51815c2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: remove extra clk_round_rate() call (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b8fafa2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: remove unused fields from struct dpu_core_perf (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ba092f4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: use dpu_perf_cfg in DPU core_perf code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5ff1d0b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: drop the dpu_core_perf_crtc_update()'s stop_req param (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9c571c8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: rework indentation in dpu_core_perf (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 76a43fb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: drop separate dpu_core_perf_tune overrides (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6b3bcfa
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: bail from _dpu_core_perf_crtc_update_bus if there are no (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6ed7505
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: drop BWC features from DPU_MDP_foo namespace (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 850a1ba
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: drop UBWC configuration (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 43ac5c5
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: use MDSS data for programming SSPP (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 191242a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/mdss: populate missing data (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e4561e7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/mdss: export UBWC data (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 145d1ed
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/mdss: rename ubwc_version to ubwc_enc_version (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e6dcc4a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: drop compatibility INTR defines (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0c1bea9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: drop now-unused mdss_irqs field from hw
  catalog (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/drm-msm-dpu-increase-memtype-count-to-16-for-sm8550.patch.
- commit 01388bb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: autodetect supported interrupts (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 940ac24
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: split interrupt address arrays (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9ab9578
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: inline __intr_offset (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d51db9c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm: Remove redundant DRM_DEV_ERROR() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6afda46
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dsi: Reuse QCM2290 14nm DSI PHY configuration for SM6125 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0c6e922
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/mdss: Add SM6125 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 01a2177
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: Add SM6125 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b473f30
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: drop DPU_INTF_DATA_COMPRESS from dpu catalog (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ac0720d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: rename enable_compression() to program_intf_cmd_cfg() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 55586b1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: rename all hw_intf structs to have dpu_hw prefix (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a460f4a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: use dpu core's major version to enable data compress (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6574b8b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: re-introduce dpu core revision to the catalog (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e349e4a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dsi: Enable BURST_MODE for command mode for DSI 6G v1.3+ (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8214b84
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: Update dev core dump to dump registers of sub-blocks (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 729bc25
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: Refactor printing of main blocks in device core dump (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 26d3958
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: Remove redundant prefix/suffix in name of sub-blocks (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b91a1e6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: Define names for unnamed sblks (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6d2c5b0
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: Drop unused num argument from relevant macros (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e67332a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: drop empty features mask INTF_SDM845_MASK (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 544e06b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: drop empty features mask MERGE_3D_SM8150_MASK (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2b6196d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: inline INTF_BLK and INTF_BLK_DSI_TE macros (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c2ac749
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: inline WB_BLK macros (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 790e33e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: inline various PP_BLK_* macros (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7afd077
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: inline MERGE_3D_BLK macros (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2023ad0
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: inline DSC_BLK and DSC_BLK_1_2 macros (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6c81597
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: inline LM_BLK macros (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b84d7a6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: inline DSPP_BLK macros (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2f07fcd
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: inline SSPP_BLK macros (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a677538
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: correct indentation for CTL definitions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 69ecf04
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: drop zero features from dpu_ctl_cfg data (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f5b898
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: drop zero features from dpu_mdp_cfg data (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 521faa8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: expand .clk_ctrls definitions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8b20388
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: drop enum dpu_mdp and MDP_TOP value (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 291bad8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: drop dpu_mdss_cfg::mdp_count field (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b1ebb23
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: simplify peer LM handling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 15670d2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: always use MSM_DP/DSI_CONTROLLER_n (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 441f4c3
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm: enumerate DSI interfaces (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0fb2908
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dsi: Hook up refgen regulator (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4ae0d69
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: remove struct drm_dsc_config from struct (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 96bc85e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu: retrieve DSI DSC struct through priv->dsi[0] (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cf8e010
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm: stop storing the array of CRTCs in struct msm_drm_private (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 84452da
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm/dpu1: Rename sm8150_dspp_blk to sdm845_dspp_blk (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8b26912
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Add memory vendor information (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eb0e9dd
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Remove gfxoff check in GFX v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7cce2de
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Update pci link speed for smu v13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bbe978e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: allow the user to force BACO on smu v13.0.0/7 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a8c1159
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: Skip vcn power-gating change for sriov (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b62ecd9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Handle Replay related hpd irq (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eac1da6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/jpeg: sriov support for jpeg_v4_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 061c164
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Update adaptive sync infopackets for replay (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7673184
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Promote DAL to 3.2.247 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9c1c65d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.179.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e3e49d7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Replace ternary operator with min() in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 537ad3d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Replace ternary operator with min() in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f77174f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Hide unsupported power attributes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b7e6f8f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Rename AMDGPU_PP_SENSOR_GPU_POWER (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 896e298
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Show both power attributes for vega20 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d747cfb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Fix the return for average power on aldebaran (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7b0eb7c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Drop unnecessary helper for aldebaran (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bc6f954
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Fix SMU 13.0.4/13.0.11 GPU metrics average power (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 112db07
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon: Use pci_dev_id() to simplify the code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 18339da
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Remove duplicated includes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 659cd36
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in amdgpu_smu.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b011a5a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: enable low power mode for VGA memory (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 25eba37
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in smu_v11_0_pptable.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a9223f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: expand runpm parameter (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aa9317b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Introduce `AMDGPU_PP_SENSOR_GPU_INPUT_POWER` (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d5159f3
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Remove freesync video mode amdgpu parameter (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 526d733
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Add a new hwmon attribute for instantaneous power (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b813fea
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: sriov support for vcn_v4_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4f9f13c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Replace ternary operator with min() in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4d23b17
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Add some missing register definitions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0bb2457
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: avoid crash and add z8_marks related in dml (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 09ce132
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: implement pipe type definition and adding accessors (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 56f41c4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Enable 8k60hz mode on single display (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c4b38e1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: fix incorrect stream_res allocation for older ASIC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d2de1b5
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Gamut remap only changes missed (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bd95399
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: PMFW to wait for DMCUB ack for FPO cases (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8438398
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Enable subvp high refresh up to 175hz (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 84dc716
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: change end doorbell index for vcn_v4_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 800aded
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: workaround address watch clearing bug for gfx v9.4.2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eb80485
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: disable clock gating logic reversed bug fix (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4f0a17a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Support Compliance Test Pattern Generation with DP2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b0728f4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/jpeg: mmsch_v4_0_3 requires doorbell on 32 byte boundary (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 269d15e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon: Remove unnecessary NULL values (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit de9e98f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Remove unnecessary NULL values (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5851f44
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: mmsch_v4_0_3 requires doorbell on 32 byte boundary (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit be8a027
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: Remove unnecessary NULL values (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 41b0fc2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: dmub_replay: don't use kernel-doc markers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9ecbf5c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Add amdgpu_hwmon_get_sensor_generic() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0b5c030
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: Add MMSCH v4_0_3 support for sriov (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 646685f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Add I2C EEPROM support on smu v13_0_6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1af7daa
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: bump SMU v13.0.5 driver_if header version (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6749640
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: correct the logics for retreiving SMU13 OD setting limits (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3118a3a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: correct the way for checking custom OD settings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2bdc56f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Use pci_dev_id() to simplify the code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2128d7a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: fix double assign skip process context clear (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9fc64d1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Update replay for clk_mgr optimizations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9dde09c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix identifier names to function definition arguments in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 829655f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: mode1 reset needs to recover mp1 for mp0 v13_0_10 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b484e1f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: avoid driver getting empty metrics table for the first (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e38bde1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: Use memdup_user() rather than duplicating its (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2fd2e0c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Remove unnecessary ras cap check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 56dd3b9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: fix build failure without CONFIG_DYNAMIC_DEBUG (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e0d7884
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon: Fix multiple line dereference in 'atom_iio_execute' (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b1547ca
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Add vclk and dclk sysnode for GC 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3b0948b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: Add missing tba_hi programming on aldebaran (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 351c603
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix missing comment for mb() in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8a21e52
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Add Replay supported/enabled checks (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9d1db90
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ttm/tests: Require MMU when testing (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 080a90b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: simple: Fix Innolux G156HCE-L01 LVDS clock (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 80d5800
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/etnaviv: fix error code in event_alloc() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 82ac860
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/etnaviv: expedited MMU fault handling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9c3226d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/etnaviv: drop GPU initialized property (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 81b5bb0
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/etnaviv: better track GPU state (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7399b38
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/etnaviv: avoid runtime PM usage in etnaviv_gpu_bind (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8d9aed2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/etnaviv: make clock handling symetric between runtime resume and (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 06b6cb5
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/etnaviv: move runtime PM handling to events (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d86ecfc
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/etnaviv: free events the usual way in recover worker (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d871a53
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/etnaviv: move down etnaviv_gpu_recover_hang() in file (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9fcd7e9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/etnaviv: add HWDB entry for GC520 r5341 c204 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d333ee2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/etnaviv: add HWDB entry for VIP8000 Nano r8002 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fa01bce
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/etnaviv: slow down FE idle polling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 323ffa6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: etnaviv: Replace of_platform.h with explicit includes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f8e8e04
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: don't allow userspace to create a doorbell BO (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7c1e3ae
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: rename device_queue_manager_init_v10_navi10() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 75e0129
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: drop IOMMUv2 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1b99a24
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Use local64_try_cmpxchg in amdgpu_perf_read (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 138ead9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Add pci usage to nbio v7.9 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 29b9318
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Add pcie usage callback to nbio (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 723b3f9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Extend poison mode check to SDMA/VCN/JPEG (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0874abb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/buddy: Fix drm buddy info output format (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0b8fef9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/irq: Move irq resume to the beginning (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f666477
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: add RAS fatal error handler for NBIO v7.9 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6c0eec6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix identation issues in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b55995e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Get replay info from VSDB (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f94a93d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Add FRU sysfs nodes only if needed (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aadfb33
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in smu73_discrete.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 45785f8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in vcn_v3_0.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dcab0bb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in tonga_ih.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 99c4c1b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in gfx_v7_0.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 256bfc7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in vcn_v4_0.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 49acbf4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in uvd_v3_1.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 96455a9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in mxgpu_vi.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 01d444d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in nv.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0bb4797
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in amdgpu_virt.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 110865c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in amdgpu_ring.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 03eda90
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in amdgpu_trace.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c76f30f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in mes_v11_0.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1a38b6f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in amdgpu_atombios.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 15188ed
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in soc21.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a9f6fc8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in dce_v8_0.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a6393f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/jpeg: Clean up errors in vcn_v1_0.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 45c3481
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in mxgpu_nv.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 52d5222
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in dce_v10_0.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0ae221e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/jpeg: Clean up errors in jpeg_v2_0.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 788cbaf
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in uvd_v7_0.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a179681
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/atomfirmware: Clean up errors in amdgpu_atomfirmware.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5f0abf0
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in mmhub_v9_4.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a06099a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in vega20_ih.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5bdca27
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in ih_v6_0.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f188575
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in amdgpu_psp.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 55122e7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in vce_v3_0.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 144e2dc
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in cik_ih.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 627627a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Clean up errors in dce_clk_mgr.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bb5d110
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Clean up errors in display_mode_vba_30.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fb5958d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Clean up errors in dcn10_dpp_dscl.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b254ea4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Clean up errors in dc_stream.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e44f359
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Clean up errors in bios_parser2.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1cd7a1b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Clean up errors in dcn316_smu.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ed26573
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Clean up errors in dcn316_clk_mgr.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit febb06d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Clean up errors in dcn315_smu.c (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/drm-amd-display-Add-smu-write-msg-id-fail-retry-proc.patch.
- commit bc8d717
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Clean up errors in dce112_hw_sequencer.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 64b89fb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Clean up errors in dce110_hw_sequencer.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f247063
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Clean up errors in dce110_timing_generator.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 561013e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/dc: Clean up errors in hpd_regs.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2b22e24
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Clean up errors in ddc_regs.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f8b4e7a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Clean up errors in color_gamma.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5c38e25
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in amdgpu_pm.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0d2be93
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in sislands_smc.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8e5571a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in r600_dpm.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5be628b
* Wed Nov 29 2023 pjakobsson@suse.de
- drivers/amd/pm: Clean up errors in smu8_smumgr.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1685e0c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in smu75.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 999e1b8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in smu73.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 803021b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in hwmgr.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 65a0a38
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in hardwaremanager.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 940ffe4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in pp_thermal.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bf3524d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in smu7.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f5d5000
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in smu7_fusion.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d4e451a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in smu71.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d2c57a6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Remove many unnecessary NULL values (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e2ebe7d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in smu9_driver_if.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 050eba2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in polaris_baco.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e11d131
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in vega20_pptable.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 98fd74b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in vega12_hwmgr.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a52ea5d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm/powerplay/hwmgr/hwmgr: Clean up errors in hwmgr.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4d3e69d
* Wed Nov 29 2023 bwiedemann@suse.de
- Do not store build host name in initrd
  Without this patch, kernel-obs-build stored the build host name
  in its .build.initrd.kvm
  This patch allows for reproducible builds of kernel-obs-build and thus
  avoids re-publishing the kernel-obs-build.rpm when nothing changed.
  Note that this has no influence on the /etc/hosts file
  that is used during other OBS builds.
  https://bugzilla.opensuse.org/show_bug.cgi?id=1084909
- commit fd3a75e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in tonga_baco.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a1c10ad
* Wed Nov 29 2023 pjakobsson@suse.de
- gpu: amd: Clean up errors in ppatomfwctrl.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8da463b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/powerplay: Clean up errors in vega20_hwmgr.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 20630ed
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in vega20_baco.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ada2ecf
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in vega20_hwmgr.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a581e9a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/powerplay: Clean up errors in smu_helper.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 77af78d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Clean up errors in vega10_processpptables.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 602fb81
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Clean up errors in pptable_v1_0.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7053832
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Clean up errors in smu7_hwmgr.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c62ff78
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in vega10_pptable.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9d55307
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in ppatomctrl.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 16bc54a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in ci_baco.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9f765cf
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in smu_helper.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 50ac13c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in common_baco.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit df711d1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in smu7_powertune.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5a867c3
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in vega12_baco.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a6a00d3
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in vega12_pptable.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e9897c4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in vega10_powertune.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d46d954
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in fiji_baco.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f7cab30
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in smu10_hwmgr.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cd2aa69
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm/powerplay/hwmgr/ppevvmath: Clean up errors in ppevvmath.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5fa9a44
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in vega12_hwmgr.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 589b632
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in vega10_baco.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 25b6051
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in amd_powerplay.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 11d6fce
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in amdgpu_smu.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a2ae1e4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Clean up errors in smu_v13_0_5_ppt.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8fa3b39
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in smu_v13_0_5_ppt.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2a768ad
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in smu_v13_0_6_ppt.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7af29f0
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in aldebaran_ppt.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7b6ef2e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in smu_v13_0.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9765c0e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in smu_v13_0_7_ppt.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1b3452a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in smu_v11_0.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 50026d8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Remove a lot of unnecessary ternary operators (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 741b78c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Return value of function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c2f91d2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Report vbios version instead of PN (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1a61709
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Promote DAL to 3.2.246 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c69f602
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Change HDCP update sequence for DM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 16b4d11
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: rename acquire_idle_pipe_for_layer to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 27b0d5b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: move idle pipe allocation logic into dcn specific (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 174f816
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Use max memclk variable when setting max memclk (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 50095ac
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Add vendor Id for reference (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 16a0355
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Blocking invalid 420 modes on HDMI TMDS for DCN314 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6e03e34
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Blocking invalid 420 modes on HDMI TMDS for DCN31 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c72bcdf
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Revert "drm/amd/display: Read down-spread percentage (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c2c1834
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: do not treat clip_rect size change as a scaling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 46f46a9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: adjust visual confirm dpp height offset to be 1/240 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c708d40
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: update add plane to context logic with a new (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fb425a6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: always acquire MPO pipe for every blending tree (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8478bcd
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: support plane clip with zero recout size (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4e4159c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Use DTBCLK as refclk instead of DPREFCLK (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5848f4a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Set Stream Update Flags in commit_state_no_check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aa765fa
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Make mpc32 functions available to future DCNs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d2acaf5
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Fix a bug when searching for insert_above_mpcc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5fe864b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Enable DPIA trace with DC debug mask (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 654f103
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Add interface to enable DPIA trace (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit db06bed
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: fix a regression in blank pixel data caused by (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b7696dc
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: cleanup MES process level doorbells (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 867b694
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: use doorbell mgr for MES kernel doorbells (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fc38a8f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: remove unused functions and variables (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3d4009d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: use doorbell mgr for kfd process doorbells (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ad3572f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: use doorbell mgr for kfd kernel doorbells (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e3791d7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Read replay data from sink (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9169e9f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Add Freesync Panel DM code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b171e7e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: update smu_v13_0_6 message vf flag (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 762a0b2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Report Missing MES Firmware Versions with Sysfs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9cc3270
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: get absolute offset from doorbell index (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 293c784
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: create kernel doorbell pages (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 397a029
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Use nbio callback for nv and soc21 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f5a03b6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Add pci replay count to nbio v7.9 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a58c73c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: initialize ttm for doorbells (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6f8a022
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: accommodate DOMAIN/PL_DOORBELL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ec46125
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: Sign-extend TMA address in trap handler (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 984d1d8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: Relocate TBA/TMA to opposite side of VM hole (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 45f311c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: Sync trap handler binaries with source (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 03c63f8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: add UAPI for allocating doorbell memory (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1b4015e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: don't modify num_doorbells for mes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5afe1c4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Add pcie replay count callback to nbio (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bf34e78
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Promote DC to 2.3.245 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f34ae6f
* Wed Nov 29 2023 pjakobsson@suse.de
- Revert "drm/amd/display: Implement zpos property" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f9e56be
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Implement interface for notify cursor support change (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e2502e0
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Prefer pr_err/_warn/_notice over printk in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 651fd4b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Temporary Disable MST DP Colorspace Property (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 658a48b
* Wed Nov 29 2023 pjakobsson@suse.de
- Revert "drm/amdgpu: Prefer dev_* variant over printk in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9bfa607
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Clean up flip pending timeout handling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ce746a9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: init TA microcode for SRIOV VF when MP0 IP is 13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ce43aa4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: remove SRIOV VF FB location programming (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c38d4ca
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Add Functions to enable Freesync Panel Replay (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eafeb61
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: enable SDMA MGCG for SDMA 5.2.x (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 87cf23f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Issue ras enable_feature for gfx ip only (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 51d25bf
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Remove gfx v11_0_3 ras_late_init call (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e977177
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Clean up style problems in mmhub_v2_3.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e297261
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Move vram, gtt & flash defines to amdgpu_ ttm & _psp.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c30de76
* Wed Nov 29 2023 pjakobsson@suse.de
- Revert "drm/radeon: Prefer dev_* variant over printk" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f0b5e16
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Apply poison mode check to GFX IP only (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5c3306f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Only create err_count sysfs when hw_op is supported (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 50180da
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Add structs for Freesync Panel Replay (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c2c8ace
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Sort the includes in amdgpu/amdgpu_drv.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6a5f7cc
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Cleanup amdgpu/amdgpu_cgs.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a1b6b72
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix style issues in amdgpu_psp.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 28089d8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix style issues in amdgpu_debugfs.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 404974f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: fix pp_dpm_sclk node not displaying correctly (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cc80f66
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: avoid unmap dma address when svm_ranges are split (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0da8192
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Fix typo in enable and disable symclk_se (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0d41960
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Add symclk enable/disable during stream (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ef1a11b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/discovery: add ih 6.1.0 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f30acee
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: add ih 6.1 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5c29797
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: add ih 6.1 registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 73b8ea4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/discovery: add smuio 14.0.0 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 972b09f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/discovery: add hdp 6.1.0 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 99b9933
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/discovery: enable sdma6 for SDMA 6.1.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f4b1685
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/sdma6: initialize sdma 6.1.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7845cd3
* Wed Nov 29 2023 pjakobsson@suse.de
- drm:rcar-du: Enable ABGR and XBGR formats (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cbfe01b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: rcar-du: Add more formats to DRM_MODE_BLEND_PIXEL_NONE support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f301ee8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/renesas: Convert to devm_platform_ioremap_resource() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ba138f8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: rcar-du: Use dev_err_probe() to record cause of KMS init errors (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c4a2938
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: rcar-du: Replace DRM_INFO() with drm_info() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 084e728
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mediatek/mtk_disp_ccorr: Remove half completed incorrect struct (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8c3c24c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mediatek/mtk_disp_aal: Remove half completed incorrect struct (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit db605ff
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mediatek: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d5f83fc
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mediatek: Do not check for 0 return after calling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2636bb2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mediatek: dp: Don't register HPD interrupt handler for eDP case (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e0f4e9d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mediatek: dp: Add .wait_hpd_asserted() for AUX bus (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b5c4b29
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mediatek: dp: Add support for embedded DisplayPort aux-bus (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9707eba
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mediatek: dp: Move PHY registration to new function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 94dd21f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mediatek: dp: Avoid mutex locks if audio is not supported/enabled (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1410a87
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mediatek: dp: Enable event interrupt only when bridge attached (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c72db08
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mediatek: dp: Move AUX_P0 setting to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 62f5d61
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mediatek: dp: Use devm variant of drm_bridge_add() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0fd002d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mediatek: dp: Change logging to dev for mtk_dp_aux_transfer() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a31cd2d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mediatek: dp: Move AUX and panel poweron/off sequence to function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ce39f87
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mediatek: mtk_dpi: Compress struct of_device_id entries (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e4a9a07
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mediatek: mtk_dpi: Use devm_platform_ioremap_resource() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5626424
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mediatek: mtk_dpi: Switch to .remove_new() void callback (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 93dca07
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mediatek: mtk_dpi: Switch to devm_drm_of_get_bridge() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ebdfd46
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mediatek: mtk_dpi: Simplify with dev_err_probe() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a883921
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mediatek: mtk_dpi: Simplify with devm_drm_bridge_add() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d5f0f5a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/guc: Fix potential null pointer deref in GuC 'steal id' test (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fa01529
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/gt: Apply workaround 22016122933 correctly (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c7fa51d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Make i915_coherent_map_type GT-centric (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a7eaeb0
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/gt: Simplify shmem_create_from_object map_type selection (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 595d662
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/irq: move all PCH irq postinstall calls to display code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a986ef
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/irq: add ilk_de_irq_postinstall() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 71c4fc4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/irq: add dg1_de_irq_postinstall() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f14b6fd
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/irq: add dedicated intel_display_irq_init() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c158412
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: debug log when GMD ID indicates there's no display (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 347ce07
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/display: pre-initialize some values in probe_gmdid_display() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bf22e31
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/adls: s/ADLS_RPLS/RAPTORLAKE_S in platform and subplatform (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4ad4e41
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/adln: s/ADLP/ALDERLAKE_P in ADLN defines (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dc1e51a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/rplu: s/ADLP_RPLU/RAPTORLAKE_U in RPLU defines (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1858210
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/rplp: s/ADLP_RPLP/RAPTORLAKE_P for RPLP defines (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bfdc798
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/adlp: s/ADLP/ALDERLAKE_P for display and graphics step (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 670a2b7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/tgl: s/TGL/TIGERLAKE for platform/subplatform defines (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5ba5274
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/jsl: s/JSL/JASPERLAKE for platform/subplatform defines (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 62eb1b3
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/rkl: s/RKL/ROCKETLAKE for platform/subplatform defines (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4ddf3a4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/cml: s/CML/COMETLAKE for platform/subplatform defines (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9a66f4b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/cfl: s/CFL/COFFEELAKE for platform/subplatform defines (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fbc6f5a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/kbl: s/KBL/KABYLAKE for platform/subplatform defines (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8c34a1d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/skl: s/SKL/SKYLAKE for platform/subplatform defines (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 270265d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/bdw: s/BDW/BROADWELL for platform/subplatform defines (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f4c5258
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/hsw: s/HSW/HASWELL for platform/subplatform defines (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5e3959a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/fbc: Moved fence related code away from intel_fbc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 49ccbcc
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/fbc: Make FBC check stolen at use time (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c388fb6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Move stolen memory handling into i915_gem_stolen (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dd04480
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/sdvo: ignore returned broken edid on (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f51cecb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ttm: Remove two unused function declarations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b2f59a6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/test: drm_exec: fix memory leak on object prepare (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6c6d89f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: atmel-hlcdc: Support inverting the pixel clock polarity (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9bf1b47
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panfrost: Sync IRQ by job's timeout handler (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6c27ec1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/exec: add test case for using a drm_exec multiple times (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a6f24ad
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/exec: use unique instead of local label (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit caadabb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ttm/tests: Add tests for ttm_pool (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4d1b1eb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ttm/tests: Add tests for ttm_device (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aa0bbd1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ttm: Introduce KUnit test (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ba29275
* Wed Nov 29 2023 pjakobsson@suse.de
- accel/ivpu: Refactor memory ranges logic (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9742a3a
* Wed Nov 29 2023 pjakobsson@suse.de
- accel/ivpu: Extend get_param ioctl to identify capabilities (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 01bebf5
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau/sched: Don't pass user flags to drm_syncobj_find_fence() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 40e3a15
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: uvmm: remove dedicated VM pointer from VMAs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7bb1cd4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: uvmm: remove incorrect calls to mas_unlock() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 004cab1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: remove incorrect __user annotations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 79f9429
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: nvkm: vmm: silence warning from cast (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 94db6c3
* Wed Nov 29 2023 pjakobsson@suse.de
- nouveau/dmem: fix copy-paste error in nouveau_dmem_migrate_chunk() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9e3836b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mcde: remove redundant of_match_ptr (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 658d627
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tve200: remove redundant of_match_ptr (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c496827
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: debugfs: implement DRM GPU VA debugfs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d31b698
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: implement new VM_BIND uAPI (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3b325b3
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: nvkm/vmm: implement raw ops to manage uvmm (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1fc2b06
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: chan: provide nouveau_channel_kill() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit edb2adb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: fence: fail to emit when fence context is killed (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fbbc216
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: fence: separate fence alloc and emit (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3653482
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: move usercopy helpers to nouveau_drv.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0c40b6f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: bo: initialize GEM GPU VA interface (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1f5b724
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: get vmm via nouveau_cli_vmm() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ac6f9c9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: new VM_BIND uAPI interfaces (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c6bd6f8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau: fixup the uapi header file. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9aca85e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/gem: fix lockdep check for dma-resv lock (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eb5827e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: Drop select FRAMEBUFFER_CONSOLE for DRM_FBDEV_EMULATION (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2f1fd01
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/xilinxfb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 52b5b23
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/vesafb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 36a954d
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/valkyriefb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9bbd344
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/uvesafb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6a1ad73
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/sunxvr2500: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f30f4fd
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/sunxvr1000: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d51e6ae
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/sstfb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bfba48d
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/simplefb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c4eebc8
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/sh7760fb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 861e211
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/s3cfb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 373616b
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/q40fb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8d1b66a
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/pxafb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 53c9de2
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/pxa168fb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a340c69
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/pmagb-b-fb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6a1c979
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/pmag-ba-fb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d9762d4
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/pmag-aa-fb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 94c49b3
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/platinumfb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aba0253
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/omapfb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4ffcc6b
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/offb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 689e5e2
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/ocfb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 50c187c
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/mx3fb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f0e6acd
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/mmpfb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0d8a747
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/mb862xxfb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 73ee82e
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/maxinefb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a4c7625
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/macfb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ec41eb8
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/kyro: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d4adc9e
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/imxfb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ca329a5
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/i740fb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d5b2571
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/gxt4500: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7a8492b
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/grvga: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 62a419e
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/goldfishfb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f7203d7
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/geode/lxfb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 051019b
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/geode/gxfb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d26dfec
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/geode/gx1fb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit df4f81d
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/g364fb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2392e89
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/fsl-diu-fb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a551bab
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/fm2fb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 298d9f6
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/efifb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 94d5910
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/da8xx-fb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c083df4
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/chipsfb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1a78107
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/carminefb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d157b23
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/aty128fb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1928941
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/atmel_lcdfb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aa2d36d
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/asiliantfb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1c3baf4
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/acornfb: Use fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 734f51e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: sitronix-st7789v: add jasonic jt240mhqs-hwt-ek-e3 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 25efe81
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: sitronix-st7789v: add support for partial mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c599baf
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: sitronix-st7789v: add panel orientation support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 58ac529
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: sitronix-st7789v: fix indentation in drm_panel_funcs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1914f1e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: bridge: dw_hdmi: Fix ELD is not updated issue (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dfc4ede
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/loongson: Add a check for lsdc_bo_create() errors (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit feecccb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/doc: fix underline for section "DRM Sync Objects" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 07e884e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/exynos: remove redundant of_match_ptr (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5891630
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/exynos: fix a possible null-pointer dereference due to data race (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fa84703
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Remove unnecessary include (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cba28e5
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Invalidate the TLBs on each GT (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit de0d775
* Wed Nov 29 2023 pjakobsson@suse.de
- i915/drm/gt: Move the gt defines in the gt directory (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 829daf2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/gt: Move TLB invalidation to its own file (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2bcf31f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/selftest/gsc: Ensure GSC Proxy init completes before (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6aadf7c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Use the i915_vma_flush_writes helper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 97bcfcb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Replace i915->gt0 with to_gt(i915) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3a2d9f8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: use direct alias for i915 in requests (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ba6ddc4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/huc: check HuC and GuC version compatibility on MTL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a4d64c0
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Expose RPS thresholds in sysfs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dd1a7f2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Add helpers for managing rps thresholds (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b03c6e3
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Record default rps threshold values (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ff9fa89
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Move setting of rps thresholds to init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f89f671
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/gt: Do not use stolen on MTL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f01c0e1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/mtl: Update cache coherency setting for context structure (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 60a424c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/guc: Dump perf_limit_reasons for debug (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f110152
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Remove some dead "code" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3293a8e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/gt: Also check set bits in clr_set() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b0cf0d8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/gt: Remove bogus comment on IVB_FBC_RT_BASE_UPPER (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c59a88d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/gt: Enable read back on XEHP_FF_MODE2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2103951
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/gt: Drop read from GEN8_L3CNTLREG in ICL workaround (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bc1c09d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/gt: Fix context workarounds with non-masked regs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dc0012e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/gt: Clear all bits from GEN12_FF_MODE2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a70fc82
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/gt: Move wal_get_fw_for_rmw() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7171e88
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Replace kmap() with kmap_local_page() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a12e8ef
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Extend Wa_14015795083 platforms (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 380f587
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/mtl: Update workaround 14018778641 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 16276de
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/gsc: Fix intel_gsc_uc_fw_proxy_init_done with directed (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit da3f228
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/mtl/gsc: Add a gsc_info debugfs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1652e32
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/mtl/gsc: query the GSC FW for its compatibility version (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2e10575
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/mtl/gsc: extract release and security versions from the gsc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c8b6706
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/gsc: fixes and updates for GSC memory allocation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 908a032
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Fix a VMA UAF for multi-gt platform (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a97f282
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/uncore: fix race around i915->params.mmio_debug (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e63d491
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/uncore: split unclaimed_reg_debug() to header and footer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cebd2e9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Add function to clear scanout flag for vmas (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9da98e0
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/display: Remove i915_gem_object_types.h from (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a04382c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Add getter/setter for i915_gem_object->frontbuffer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 525d907
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Add macros to get i915 device from i915_gem_object (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dc6f202
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/color: Downscale degamma lut values read from hardware (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f2b9c31
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/color: Upscale degamma values for MTL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit df8042c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/hotplug: Reduce SHPD_FILTER to 250us (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 674cba9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Simplify expression &to_i915(dev)->drm (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1ef7023
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Start using plane scale factor for relative data rate (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0b37a3b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/display: Do not use stolen on MTL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a75a536
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/vdsc: Remove FIXME in intel_dsc_compute_config (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 69f0f01
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/dsc: Add rc_range_parameter calculation for YCbCr420 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7ec52cb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/drm: Fix comment for YCbCr20 qp table declaration (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bb7b573
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/dsc: Move rc param calculation for native_420 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f5c59c2
* Wed Nov 29 2023 pjakobsson@suse.de
- i915/display/hotplug: use drm_kms_helper_connector_hotplug_event() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ad8f107
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Don't rely that 2 VDSC engines are always enough for pixel (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 51cffb0
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Add helper function for getting number of VDSC engines (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit df2d5b6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Try to initialize DDI/ICL+ DSI ports for every VBT child (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a4b4463
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/bios: Extract intel_bios_encoder_port() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 088be40
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Remove AUX CH sanitation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 18b1483
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Remove DDC pin sanitation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0361771
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Only populate aux_ch if really needed (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cb19e55
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Initialize dig_port->aux_ch to NONE to be sure (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0b71c19
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Fail if DSC compression requirement is less than platform (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d50b703
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/dram: replace __raw_uncore_read32() with (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1c766d4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/uncore: add intel_uncore_regs() helper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c59a1f1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: make device info a const pointer to rodata (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ad4fb2d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: move display device and runtime info to struct (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 94c8366
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: fix display info usage (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 97df2d1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: separate display info printing from the rest (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d0d0175
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: move platform_engine_mask and memory_regions to device info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 80b266e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Remove prototype for intel_cx0_phy_ddi_vswing_sequence() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3ff6e6f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/doc: fix duplicate declaration warning (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit de0909f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Prevent needless toggling of DC states during modesets (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 73b12aa
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Add way to specify the power-off delay of a display power (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fdac847
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Remove redundant forward declarations from display power (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4cc76b6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/hdcp: Add a debug statement at hdcp2 capability check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 42bc19c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/mtl: Skip using vbt hdmi_level_shifter selection on MTL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d9dc382
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/mtl: Add new vswing table for C20 phy to support DP 1.4 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f8da2f9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/mtl: update DP 2.0 vswing table for C20 phy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e60fc93
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Convert HSW/BDW to use port_mask for DDI probe (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6449f3e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Init DDI outputs based on port_mask on skl+ (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 24570a7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Beef up SDVO/HDMI port checks (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c275f39
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Assert that the port being initialized is valid (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7371a54
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Assert that device info bitmasks have enough bits (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f26f2e7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Introduce device info port_mask (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 55d6381
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Remove bogus DDI-F from hsw/bdw output init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6bddfa5
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/psr: Re-enable PSR1 on hsw/bdw (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 26e4a4e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/psr: Allow PSR with sprite enabled on hsw/bdw (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f2de9f3
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/psr: Don't skip both TP1 and TP2/3 on hsw/bdw (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fd0ee6d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/psr: Do no mask display register writes on hsw/bdw (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8b2a6d1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/psr: Implement WaPsrDPRSUnmaskVBlankInSRD:hsw (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7e7c9eb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/psr: Implement WaPsrDPAMaskVBlankInSRD:hsw (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1c5c702
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/psr: Restore PSR interrupt handler for HSW (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 45ab5e3
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/psr: HSW/BDW have no PSR2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2343131
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/psr: Bring back HSW/BDW PSR AUX CH registers/setup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aa7143e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/psr: Reintroduce HSW PSR1 registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9c21736
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/psr: Wrap PSR1 register with functions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0f3dafc
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Re-init clock gating on coming out of PC8+ (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8fb1c6d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/mtl: Cleanup usage of phy lane reset (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 78ccd90
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/hdcp: Modify hdcp_gsc_message msg sending mechanism (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b1f6a34
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/dsi: Remove weird has_pch_encoder asserts (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 95767d3
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/dsi: Grab the crtc from the customary place (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 034f810
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/dsi: Move panel reset+power off to be the last thing (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0858323
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/dsi: Respect power_off_delay on icl+ (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d35308c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/dsi: Do DSC/scaler disable earlier on icl+ (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 07e1247
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/dsi: Move most things from .disable() into .post_disable() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bfacdc5
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/dsi: Implement encoder->shutdown() for icl+ (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c8ffc2c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/dsi: Respect power cycle delay on icl+ (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0be8bcf
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/dsi: Gate DSI clocks earlier (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5449fba
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/dsi: Split icl+ D-PHY vs. DSI timing steps (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit becb7aa
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/dsi: Print the VBT MIPI sequence delay duration (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d31f23e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/dsi: Do display on sequence later on icl+ (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6cfe0ec
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/dsi: Do panel power on + reset deassert earlier on icl+ (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1d89b73
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915/gmch: avoid unused variable warning (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8ce9713
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/ps3fb: Build without kernel device (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f3b9ff8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/doc: document that PRIME import/export is always supported (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8833490
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/doc: document drm_event and its types (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b7e9055
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/doc: add warning about connector_type_id stability (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3c566b1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/doc: use proper cross-references for sections (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f710bd3
* Wed Nov 29 2023 pjakobsson@suse.de
- fbcon: Make fbcon_registered_fb and fbcon_num_registered_fb static (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7bcd44f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/drm_plane.h: fix grammar of the comment (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c57a12e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: bridge: dw_hdmi: Add cec suspend/resume functions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5a55e1e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel-simple: Add Innolux G156HCE-L01 panel entry (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e7b810f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: Fix todo indentation for panel prepared/enabled cleanup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ac87aa1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: Fix kernel-doc typo for `follower_lock` (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c6a38fd
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tiny: panel-mipi-dbi: Allow sharing the D/C GPIO (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 63f8cc7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mipi-dbi: Lock SPI bus before setting D/C GPIO (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3499f43
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: Add debugfs print for bridge chains (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4659152
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: Add a way for other devices to follow panel state (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2a5ab63
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: Check for already prepared/enabled in drm_panel (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 46a0a32
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel-edp: Add enable timings for N140HCA-EAC panel (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2092d1c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: sitronix-st7789v: Check display ID (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8e9c7c8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: sitronix-st7789v: Add EDT ET028013DMA panel support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7cd0bfe
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: sitronix-st7789v: Clarify a definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8b28196
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: sitronix-st7789v: Use 9 bits per spi word by default (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eeb06a1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: sitronix-st7789v: add Inanbo T28CP45TN89 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bfee63e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: sitronix-st7789v: avoid hardcoding polarity info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 66c8cb3
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: sitronix-st7789v: avoid hardcoding invert mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 162e49f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: sitronix-st7789v: add media bus format (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a75d367
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: sitronix-st7789v: avoid hardcoding panel size (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4888077
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: sitronix-st7789v: avoid hardcoding mode info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d5cbcc6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: sitronix-st7789v: improve error handling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ff70c7a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: sitronix-st7789v: simplify st7789v_spi_write (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a2eedcf
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: sitronix-st7789v: make reset GPIO optional (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 30f3624
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: sitronix-st7789v: remove unused constants (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 674e16d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: sitronix-st7789v: add SPI ID table (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b741341
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tests: Alloc drm_device on drm_exec tests (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 706217b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/virtio: Support sync objects (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 831798d
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Align deferred I/O with naming of helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b696d52
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Use _DMAMEM_ infix for DMA-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3662914
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Use _SYSMEM_ infix for system-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6496dc4
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Use _IOMEM_ infix for I/O-memory helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 27f5009
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: Support for startek-kd070fhfid015 MIPI-DSI panel (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fafa60b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: ilitek-ili9881c: Add TDO TL050HDV35 LCD panel (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dadec3d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: panel: simple: specify bpc for powertip_ph800480t013_idf02 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a430a9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: r66451: select CONFIG_DRM_DISPLAY_DP_HELPER (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5260952
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/vc4: tests: pv-muxing: Document test scenario (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2cfc6ff
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/vc4: tests: Switch to atomic state allocation helper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a4a328b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/vc4: tests: pv-muxing: Switch to managed locking init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b515ed5
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/vc4: tests: mock: Use a kunit action to unregister DRM device (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit af3ac14
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/vc4: tests: pv-muxing: Remove call to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e15fd33
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tests: helpers: Create a helper to allocate an atomic state (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit adcacda
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tests: helpers: Create a helper to allocate a locking ctx (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f5cfe1e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tests: probe-helper: Remove call to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bec27ca
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tests: modes: Remove call to drm_kunit_helper_free_device() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9cd286c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tests: client-modeset: Remove call to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 280cb78
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tests: helpers: Switch to kunit actions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b8b3c17
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ssd130x: clean up some inconsistent indenting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fe12b62
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: Fix references to drm_plane_helper_check_state() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 33279fc
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/todo: Convert list of fbconv links to footnotes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 88d5a79
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/todo: Add atomic modesetting references (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit db94af5
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: Spelling s/randevouz/rendez-vous/ (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 69aff4f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: Spelling s/sempahore/semaphore/ (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8e184c4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/udl: Convert to drm_crtc_helper_atomic_check() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ee2f8db
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge_connector: Handle drm_connector_init_with_ddc() failures (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2ffa0bc
* Wed Nov 29 2023 pjakobsson@suse.de
- gpu: ipu-v3: prg: Convert to devm_platform_ioremap_resource() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8c7e4ea
* Wed Nov 29 2023 pjakobsson@suse.de
- gpu: ipu-v3: pre: Convert to devm_platform_ioremap_resource() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 63773c8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/imx/ipuv3: ipuv3-plane: reuse local variable height in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8e032d6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/imx/dcss: Use dev_err_probe (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ebb58fd
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: simple: Simplify matching using of_device_get_match_data() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2711515
* Wed Nov 29 2023 pjakobsson@suse.de
- video: logo: LOGO should depend on FB_CORE i.s.o. FB (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6cb8553
* Wed Nov 29 2023 pjakobsson@suse.de
- Revert "fbcon: Use kzalloc() in fbcon_prepare_logo()" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2cef5e4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/vkms: Fix race-condition between the hrtimer and the atomic (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6af482c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/vkms: Add support to 1D gamma LUT (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5d4c645
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tegra: sor: Convert to devm_platform_ioremap_resource() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5b9e7be
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tegra: hdmi: Convert to devm_platform_ioremap_resource() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit beb4e39
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tegra: output: hdmi: Support bridge/connector (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9998518
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tegra: Enable runtime PM during probe (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0f8263a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tegra: dpaux: Use devm_platform_ioremap_resource() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4749140
* Wed Nov 29 2023 pjakobsson@suse.de
- gpu: host1x: Return error when context device not attached to IOMMU (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 21ed0ae
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tegra: Add error check for NVDEC firmware memory allocation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 45b5644
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Avoid -Wconstant-logical-operand in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 86ee25c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/v3d: Avoid -Wconstant-logical-operand in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cb84a72
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ssd130x: Use shadow-buffer helpers when managing plane's state (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit edab47f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: xlnx: zynqmp_dpsub: Use devm_platform_ioremap_resource_byname() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 24490ef
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: xlnx: zynqmp_dpsub: Use dev_err_probe instead of dev_err (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 93896f6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/xlnx/zynqmp_dp: Fix function name zynqmp_dp_link_train() -> (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 59d5cd2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: correct vmhub index in GMC v10/11 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cdd39f4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix non-standard format specifiers in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 90caeb8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: set completion status as preempted for the resubmission (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1e5b481
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon: Fix ENOSYS with better fitting error codes in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a827a3e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon: Remove unnecessary NULL test before kfree in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2aae7e3
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Use parentheses for sizeof *numa_info in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c18a31f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix unnecessary else after return in 'amdgpu_eeprom_xfer' (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4ce0726
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/discovery: enable PSP 14.0.0 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ecd5ef8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: add PSP 14.0.0 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 986dbf6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon: Fix format error (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a9a7212
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: fix and enable ttmp setup for gfx11 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5a3ece9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Move externs to amdgpu.h file from amdgpu_drv.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2bc1a9b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Prefer dev_* variant over printk in amdgpu_atpx_handler.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 653e64b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix no new typedefs for enum _AMDGPU_DOORBELL_* (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 83861fa
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix ENOSYS means 'invalid syscall nr' in amdgpu_device.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4dfff54
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: remove repeat code for mes_add_queue_pkt (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b10b31d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Checkpoint and Restore VRAM BOs without VA (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d06261d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: enable trap of each kfd vmid for gfx v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1ef12ad
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: open brace '{' following struct go on the same line (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 93dc34f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: open brace '{' following function definitions go on the (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 013bbb2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: that open brace { should be on the previous line (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8a47185
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in arcturus_ppt.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ca11d69
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in arcturus_ppt.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e48f777
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Clean up errors in navi10_ppt.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4d84a0d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: add missing spaces before '(' (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bec02db
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon: Move assignment outside if condition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4798838
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon: that open brace { should be on the previous line (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7783345
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon: that open brace { should be on the previous line (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0e34a30
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon: add missing spaces after ',' and else should follow close (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3fed5bd
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon: add missing spaces before ';' (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6b06db7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon/si_dpm: open brace '{' following struct go on the same (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 29c3fa5
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: Vangogh: Add new gpu_metrics_v2_4 to acquire gpu_metrics (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 33cc0f5
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: load sdma ucode in the guest machine (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 701291a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Use seq_puts() instead of seq_printf() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2c27823
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Remove else after return in 'is_fru_eeprom_supported' (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9af2cfb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Remove else after return in 'dm_vblank_get_counter' (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 08c8e7e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Add -ENOMEM error handling when there is no memory (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b386519
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Check APU flag to disable RAS (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bd2f1a9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: fix the indexing issue during rlcg access ctrl init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f5df6f2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: add VISIBLE info in amdgpu_bo_print_info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0bf4a8f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: avoid svm dump when dynamic debug disabled (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ebc2915
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon: ERROR: "foo * bar" should be "foo *bar" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6104195
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: open brace '{' following struct go on the same line (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4488dca
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: open brace '{' following struct go on the same line (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dd8fe74
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: open brace '{' following struct go on the same line (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6fb2d67
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: 3.2.244 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ead3e73
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Fix underflow issue on 175hz timing (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4b97e6e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Add interface to modify DMUB panel power options (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0b99c49
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Rearrange dmub_cmd defs order (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 37cb26c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Remove check for default eDP panel_mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f76bdeb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix style issues in amdgpu_gem.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d449e5c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Add new sequence for 4-lane HBR3 on vendor specific (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 719cfc9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Update DPG test pattern programming (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a876938
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Correct unit conversion for vstartup
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 454d046
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Refactor recout calculation with a more generic (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e794682
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Read down-spread percentage from lut to adjust (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 22873ff
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Prevent invalid pipe connections (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1fffd4e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Update ring scheduler info as needed (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9e5493a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Enabling FW workaround through shared memory for VCN4_0_2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 261d0dc
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Add VESA SCR case for default aux backlight (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9d2c5d7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon: Prefer dev_* variant over printk (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d5877a6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon: Fix style issues in radeon _encoders.c & _gart.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 74398cb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/amdgpu: Fix warnings in amdgpu/amdgpu_display.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3e3a03c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon: Avoid externs & do not initialize globals to 0 in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4bcfc1c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Correct grammar mistakes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 785bd04
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Return -ENOMEM when there is no memory in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1654426
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix do not add new typedefs in amdgpu_fw_attestation.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d7f8392
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Prefer #if IS_ENABLED over #if defined in amdgpu_drv.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit baae507
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: enable cooperative groups for gfx11 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7a5440f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: set sw state to gfxoff after SR-IOV reset (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dbe4c6a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix one kernel-doc comment (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9f1ed40
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Program xcp_ctl registers as needed (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5a83804
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Allow building DC with clang on RISC-V (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e3fbbcb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: remove an unused file (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 519a329
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon: Prefer pr_err/_info over printk (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1de20f5
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: allow secure submission on VCN4 ring (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b6aa4c6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Avoid reading the VBIOS part number twice (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fda2f9e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Add RLCG interface driver implementation for gfx v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a124c4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Promote DAL to 3.2.243 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3f2e43b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Add missing triggers for full updates (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 35b6f08
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: ABM pause toggle (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 97f0ac0
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Fix ASIC check in aux timeout workaround (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f32bae8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Add link encoding to timing BW calculation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 27584f5
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Add stream overhead in BW calculations for 128b/132b (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 179397b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Initialize necessary uninitialized variables (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4bad940
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Add helpers to get DMUB FW boot options (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e78b39b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Promote DAL to 3.2.242 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 783fc6e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Update 128b/132b downspread factor to 0.3%% (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit edd50e4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Fix race condition when turning off an output alone (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0fe89d6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: add additional refresh rate conditions for SubVP (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3008066
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: refine to decide the verified link setting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8ffaef0
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Fix DP2 link training failure with RCO (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ad159f7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Cache backlight_millinits in link structure and (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3d86bfb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Reenable all root clock gating options (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a9e4df1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Update SW cursor fallback for subvp high refresh (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e72efdb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Skip querying caps when DMCUB emulation is in use (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 97c09e0
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Update scaler recout data for visual confirm (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d6832ff
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Skip enabling DMCUB when using emulation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 508bec8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Reduce stack size (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 70178bb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Hardcode vco_freq for dcn316 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 966a55c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Add missing static (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9ee4bfa
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Remove unused function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4559837
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Improve the include of header file (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f71a98f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Re-add aux intercept disable delay generically for (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 17aa4fe
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Use is_dig_enable function instead of dcn10 hardcode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2dbe713
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Setup stream encoder before link enable for TMDS (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9b8007b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: create a new file for doorbell manager (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7e4b13d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Add dcdebugmask option to enable DPIA trace (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e344d61
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Disable RAS by default on APU flatform (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dd97747
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Enable aqua vanjaram RAS (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ad66a9a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Avoid possiblity of kernel crash in 'gmc_v8_0, (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ea09927
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Eliminate warnings in amdgpu_dm_helpers.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dcec46e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Clean up style problems in amdgpu_dm_hdcp.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d09d525
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Implement zpos property (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3a4a519
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Enable 3 plane for DCN 3.01 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5ea97a2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Expose more formats for overlay planes on DCN (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e25ebd9
* Wed Nov 29 2023 pjakobsson@suse.de
- Revert "drm/amdgpu:update kernel vcn ring test" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5f089c4
* Wed Nov 29 2023 pjakobsson@suse.de
- Revert "drm/amdgpu: update kernel vcn ring test" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit adec383
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix error & warnings in gmc_v8_0.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b2daa41
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Rename to amdgpu_vm_tlb_seq_struct (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9338bd2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: Fix stack size in 'amdgpu_amdkfd_unmap_hiq' (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 528c8a6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: report dispatch id always saved in ttmps after gc9.4.2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 32e2bb7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: update kernel vcn ring test (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 932bd40
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu:update kernel vcn ring test (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3b323da
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: add watchdog timer enablement for gfx_v9_4_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9bee1ae
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: Update CWSR grace period for GFX9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fe0e194
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon: ERROR: "(foo*)" should be "(foo *)" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 73466ed
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon: ERROR: that open brace { should be on the previous line (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a9940d0
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon: ERROR: "(foo*)" should be "(foo *)" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 49a8b69
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon: ERROR: "(foo*)" should be "(foo *)" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 87f9c7b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/radeon: ERROR: "foo * bar" should be "foo *bar" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ebc9d69
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: use psp_execute_load_ip_fw instead (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b5cad4e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: rename psp_execute_non_psp_fw_load and make it global (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit de5efba
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: add multi-process debugging support for GC v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f4646d0
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: enable watch points globally for gfx943 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ea10c46
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: restore debugger additional info for gfx v9_4_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0a655f4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: add kfd2kgd debugger callbacks for GC v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 68b0192
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Increase soft IH ring size (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 686cc56
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/gfx10: move update_spm_vmid() out of rlc_init() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 77d6f54
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/gfx9: move update_spm_vmid() out of rlc_init() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 234df01
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix errors & warnings in gfx_v10_0.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cf748eb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix warnings in gfxhub_ v3_0, v3_0_3.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3e3a4df
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix warnings in gmc_v8_0.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 96581b1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/pm: disbale dcefclk device sysnode on GFX v9.4.3 chip (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0eb34dc
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu/vkms: drop redundant set of fb_modifiers_not_supported (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 06d678c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Remove else after return statement in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 613db86
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix warnings in gmc_v11_0.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e3485cb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Remove else after return statement in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8ee5ce2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix warnings in gfxhub_v2_1.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d49da36
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix errors & warnings in gmc_ v6_0, v7_0.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c33614f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix warnings in gmc_v10_0.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b6e4141
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Prefer dev_warn over printk (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c82f8a9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix warnings in gfxhub_v2_0.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 37b495e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Remove redundant GFX v9.4.3 sequence (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b48a00a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix warnings in gfxhub_ v1_0, v1_2.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9ee0ecc
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Block optimize on consecutive FAMS enables (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1597052
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Fix error & warnings in gmc_v9_0.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f9dccd1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Change golden settings for GFX v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e03daa7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: Skip handle mapping SVM range with no GPU access (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8477aab
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/amdgpu: Add cu_occupancy sysfs file to GFX9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fe02625
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: have bos for PDs/PTS cpu accessible when kfd uses cpu to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 909192c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: Use KIQ to unmap HIQ (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ef49739
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Clean up warnings in amdgpu_dm _mst_types, _plane, (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ee880e0
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Remove unnecessary casts in amdgpu_dm_helpers.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2f25065
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Clean up warnings in amdgpu_dm_pp_smu.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 126ae0a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: skip address adjustment for GFX RAS injection (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 297bff1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Update invalid PTE flag setting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1c60de9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: return an error if query_video_caps is not set (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 800c1a4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdkfd: Access gpuvm_export_dmabuf() API to get Dmabuf (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 85776dc
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: adjust whitespace for amdgpu_psp.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 262c697
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Detect IFWI or PD upgrade support in psp_early_init() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8cbe487
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Add documentation for how to flash a dGPU (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d54c4f5
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Convert USB-C PD F/W attributes into groups (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 65f8cf9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Make flashing messages quieter (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0296b9b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd: Use attribute groups for PSP flashing attributes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5a0b2e4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: fix comment typo (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b109605
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Use seq_puts() in 'amdgpu_current_colorspace_show()' (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5d3eeab
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Remove redundant braces in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c590c8f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Clean up style problems in amdgpu_dm_irq.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b9cb92a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Remove else after return in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1c6fbc9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amd/display: Remove else after return statement in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3f99186
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Rename aqua_vanjaram_reg_init.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fdd923b
* Wed Nov 29 2023 pjakobsson@suse.de
- dma-buf: Fix the typo in DMA-BUF statistics doc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 13cf6f4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ssd130x: Allocate buffer in the plane's .atomic_check() callback (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 958888c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ssd130x: Inline the ssd130x_buf_{alloc, free}() function helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c9613b1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ast: Do not enable PCI resources multiple times (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0e037fe
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: ld9040: add backlight Kconfig dependency (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 499e82b
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Harmonize some comments in <linux/fb.h> (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 29509e3
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Remove FB_DEFAULT_SYS_OPS (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2992fbc
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/omapdrm: Set fbdev FBINFO_VIRTFB flag (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 59746a6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/omapdrm: Use GEM mmap for fbdev emulation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 82bed15
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/omapdrm: Set VM flags in GEM-object mmap function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f025097
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/exynos: Set fbdev FBINFO_VIRTFB flag (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e494471
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/exynos: Use fbdev DMA helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2d6878a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tegra: Store pointer to vmap'ed framebuffer in screen_buffer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b8aa8e9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tegra: Set fbdev FBINFO_VIRTFB flag (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 51d390c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tegra: Use fbdev DMA helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0bf4739
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/fbdev-dma: Use fbdev DMA helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 154ed75
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Add fb_ops init macros for framebuffers in DMA-able
  memory (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh patches.suse/fbdev-Update-fbdev-source-file-paths.patch.
- commit 1a238ca
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: db7430: remove unused variables (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f3ff447
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Document that framebuffer_alloc() returns zero'ed data (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a943c8
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Remove FBINFO_DEFAULT and FBINFO_FLAG_DEFAULT (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5312a6a
* Wed Nov 29 2023 pjakobsson@suse.de
- vfio-mdev: Remove flag FBINFO_DEFAULT from fbdev sample driver (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 082f5b7
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/pxafb: Remove flag FBINFO_FLAG_DEFAULT (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a53440f
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/atafb: Remove flag FBINFO_FLAG_DEFAULT (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7cd4e71
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Remove FBINFO_FLAG_DEFAULT from framebuffer_alloc()'ed structs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8c84118
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Remove FBINFO_FLAG_DEFAULT from kzalloc()'ed structs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a482610
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/fsl-diu-fb: Remove flag FBINFO_DEFAULT (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2a8e673
* Wed Nov 29 2023 pjakobsson@suse.de
- auxdisplay: Remove flag FBINFO_FLAG_DEFAULT from fbdev drivers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 813952e
* Wed Nov 29 2023 pjakobsson@suse.de
- hid/picolcd: Remove flag FBINFO_FLAG_DEFAULT from fbdev driver (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9f76926
* Wed Nov 29 2023 pjakobsson@suse.de
- media: Remove flag FBINFO_FLAG_DEFAULT from fbdev drivers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2bccf05
* Wed Nov 29 2023 pjakobsson@suse.de
- staging: Remove flag FBINFO_FLAG_DEFAULT from fbdev drivers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8d589f4
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Remove FBINFO_DEFAULT from framebuffer_alloc()'ed structs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aa04250
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Remove FBINFO_DEFAULT from devm_kzalloc()'ed structs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 98d7662
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Remove FBINFO_DEFAULT from kzalloc()'ed structs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5689e57
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Remove FBINFO_DEFAULT from static structs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7b5ba4b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: Remove flag FBINFO_DEFAULT from fbdev emulation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 29d4930
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/managed: Clean up GFP_ flag usage in drmm_kmalloc() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bd5d950
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: Remove redundant i2c_client in anx7625/it6505 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e6354da
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: it6505: Fix Kconfig indentation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eb6c702
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: Make FB_CORE to be selected if DRM fbdev emulation is enabled (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ec9262c
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Split frame buffer support in FB and FB_CORE symbols (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit baeb4cc
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Move core fbdev symbols to a separate Kconfig file (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6da4910
* Wed Nov 29 2023 pjakobsson@suse.de
- video: Add auxiliary display drivers to Graphics support menu (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2df63b6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ssd130x: Fix pitch calculation in ssd130x_fb_blit_rect() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 20b5369
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: tc358767: give VSDELAY some positive value (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 03abf73
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: tc358767: increase PLL lock time delay (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 47eb9e2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/arm/komeda: Remove component framework and add a simple encoder (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 424351c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: Explicitly include correct DT includes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a0f4f63
* Wed Nov 29 2023 pjakobsson@suse.de
- gpu/host1x: Explicitly include correct DT includes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e99a8b8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: debugfs: Silence warning from cast (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1305306
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: manager: Fix printk format for size_t (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 97576f2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: simple: Drop prepared_time (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6e01236
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/syncobj: add IOCTL to register an eventfd (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 563d55a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: debugfs: provide infrastructure to dump a DRM GPU VA space (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 67ececb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: manager to keep track of GPUs VA mappings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a22608a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/file: use explicit values for enum drm_minor_type (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b7c359e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/drv: use enum drm_minor_type when appropriate (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 05ab145
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: ld9040: Register a backlight device (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e87433c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: ld9040: Use better magic values (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 225674a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ssd130x: Change pixel format used to compute the buffer size (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6ac0843
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/loongson: Remove a useless check in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7bbd641
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: use the new drm_exec object for CS v3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3b49ee2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: use drm_exec for MES testing (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8e5d5ab
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: use drm_exec for GEM and CSA handling v2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7810948
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: add drm_exec selftests v4 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 501f324
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: execution context for GEM buffers v7 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d6427a5
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/hyperv_fb: Include <linux/screen_info.h> (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b5b6fdd
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/arm: Make ARM devices menu depend on DRM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3158123
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ttm: Use init_on_free to delay release TTM BOs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 018515d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: cdns-mhdp8546: Fix the interrupt enable/disable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 211938a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tidss: Update encoder/bridge chain connect model (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9998db5
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: sii902x: Set input_bus_flags in atomic_check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fc9fe00
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: sii902x: Support format negotiation hooks (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1cded5c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: mhdp8546: Set input_bus_flags from atomic_check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d561fea
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: mhdp8546: Add minimal format negotiation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7b843ef
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: tfp410: Set input_bus_flags in atomic_check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2baeb95
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: tfp410: Support format negotiation hooks (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 668fcc8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: tc358767: Use devm_clk_get_enabled() helper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 730a500
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau/disp: use drm_kms_helper_connector_hotplug_event() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8439496
* Wed Nov 29 2023 pjakobsson@suse.de
- nouveau/dispnv50: add cursor pitch check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7badd07
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/virtio: Conditionally allocate virtio_gpu_fence (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 806f2f3
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/xen-fbfront: Generate deferred I/O ops (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 15744d2
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/xen-fbfront: Select FB_SYS_HELPERS_DEFERRED (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 01d5e02
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/ssd1307fb: Generate deferred I/O ops (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2ef0955
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/ssd1307fb: Select FB_SYS_HELPERS_DEFERRED (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dbe32f9
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/metronomefb: Generate deferred I/O ops (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8d568ae
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/metronomefb: Select FB_SYS_HELPERS_DEFERRED (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 33d9265
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/hecubafb: Generate deferred I/O ops (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7c6aec7
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/hecubafb: Select FB_SYS_HELPERS_DEFERRED (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4755571
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/broadsheetfb: Generate deferred I/O ops (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 31b0892
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/broadsheetfb: Select FB_SYS_HELPERS_DEFERRED (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4346cdd
* Wed Nov 29 2023 pjakobsson@suse.de
- sysfb: Do not include <linux/screen_info.h> from sysfb header (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 96a6eac
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/sm712fb: Do not include <linux/screen_info.h> (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b3ceb5f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau/disp: drop unused argument in nv50_dp_mode_valid (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 380b88e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau/kms: don't call drm_dp_cec_set_edid() on TMDS (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4efdee7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau/nvif: fix potential double-free (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 71d4e95
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau/fifo/ga100-: add per-runlist nonstall intr handling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3576097
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau/fifo/ga100-: remove individual runlists rather than (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 829a0e0
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau/fifo: return ERR_PTR from nvkm_runl_new() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 553d330
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau/fifo: remove left-over references to nvkm_fifo_chan (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7203dcc
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau/fb/ga102-: construct vidmem heap via new gp102 paths (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 790f83b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau/fb/gp102-ga100: switch to simpler vram size detection (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1b8133d
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau/nvkm: punt spurious irq messages to debug level (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1a6a02e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/nouveau/nvkm: fini object children in reverse order (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit be0c2f3
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: Add kms driver for loongson display controller (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fb09f02
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/drm_gem.c: Remove surplus else after return (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9dd4f0b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/gud: use vmalloc_array and vcalloc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 83767b2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: bridge: samsung-dsim: Drain command transfer FIFO before (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8ee9f13
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/edid: Add quirk for OSVR HDK 2.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0eb8d3a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tests: Fix swapped drm_framebuffer tests parameter names (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6a86cb7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/edid: make read-only const array static (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e7e8ac1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ast: Merge config and chip detection (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2f33ae7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ast: Move widescreen and tx-chip detection into separate helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f9f7014
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ast: Detect AST 2510 model (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8edb418
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ast: Detect AST 1400 model (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 729268b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ast: Detect AST 1300 model (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5b5b697
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ast: Distinguish among chip generations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 181acce
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ast: Set up release action right after enabling MMIO (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cb50d55
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ast: Enable and unlock device access early during init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c91d325
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ast: Set PCI config before accessing I/O registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a9c7a81
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ast: Remove device POSTing and config from chip detection (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3556383
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ast: Remove dead else branch in POST code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c09219a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ast: Implement register helpers in ast_drv.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d8017e7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ast: Remove vga2_clone field (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit caff45a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ttm: Don't shadow the operation context (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e635097
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Make support for userspace interfaces configurable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 496f3d3
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/core: Rework fb init code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 14ba907
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/core: Move file-I/O code into separate file (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9e997e0
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/core: Move procfs code to separate file (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d700660
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/core: Add fb_device_{create,destroy}() (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh patches.suse/fbdev-Update-fbdev-source-file-paths.patch.
- commit 347dc1b
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/core: Move framebuffer and backlight helpers into separate (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3d9c3b4
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/core: Pass Linux device to pm_vt_switch_*() functions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 21a0428
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/tdfxfb: Set i2c adapter parent to hardware device (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bb1555a
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/smscufx: Detect registered fb_info from refcount (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0057565
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/sm501fb: Output message with fb_err() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cd87e47
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/sh7760fb: Use hardware device with dev_() output during probe (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c5f283b
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/sh7760fb: Alloc DMA memory from hardware device (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3588205
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/sh7760fb: Output messages with fb_dbg() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 090cc78
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/sh7760fb: Use fb_dbg() in sh7760fb_get_color_info() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a288808
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/rivafb: Use hardware device as backlight parent (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b8a23c8
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/rivafb: Reorder backlight and framebuffer init/cleanup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5516076
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/radeonfb: Use hardware device as backlight parent (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit effc54c
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/radeonfb: Reorder backlight and framebuffer cleanup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 610e23f
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/pxa168fb: Do not assign to struct fb_info.dev (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 63adb05
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/nvidiafb: Use hardware device as backlight parent (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c72c6cc
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/nvidiafb: Reorder backlight and framebuffer init/cleanup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2c1b2a1
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/metronomefb: Use hardware device for dev_err() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e96f9a0
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/mb862xxfb: Output messages with fb_dbg() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3205fd3
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/fsl-diu-fb: Output messages with fb_*() helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 55f4f65
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/ep93xx-fb: Output messages with fb_info() and fb_err() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6295d3f
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/ep93xx-fb: Alloc DMA memory from hardware device (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 63f7c74
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/broadsheetfb: Call device_remove_file() with hardware device (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ab9c4fc
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/aty128fb: Use hardware device as backlight parent (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ecfb033
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/aty128fb: Reorder backlight and framebuffer init/cleanup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 238ace4
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/atyfb: Use hardware device as backlight parent (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0e32f8d
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev/atyfb: Reorder backlight and framebuffer init/cleanup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d8dc846
* Wed Nov 29 2023 pjakobsson@suse.de
- backlight/lv5207lp: Rename struct lv5207lp_platform_data.fbdev to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fc64cf8
* Wed Nov 29 2023 pjakobsson@suse.de
- backlight/gpio_backlight: Rename field 'fbdev' to 'dev' (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8dfbebb
* Wed Nov 29 2023 pjakobsson@suse.de
- backlight/bd6107: Rename struct bd6107_platform_data.fbdev to 'dev' (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 139d94c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: dw-hdmi: remove dead code and fix indentation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5a6bab6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: dw-hdmi: truly enforce 420-only formats when drm mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 58650ea
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: dw-hdmi: change YUV420 selection logic at clock setup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 412ab0c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: Clear fd/handle callbacks in struct drm_driver
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 bsc#1212533 bsc#1212533).
- commit 0682bea
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/vkms: Isolate writeback pixel conversion functions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dfc41f8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/vkms: Enable ARGB8888 support for writeback (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c6897bb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/vkms: Reduce critical section (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit afd698b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: ps8640: Drop the ability of ps8640 to fetch the EDID (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a30eb7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/kms: log when querying an object not included in lease (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bbec67c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/atomic: log errors in drm_mode_atomic_ioctl() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2cccebe
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/atomic: log when page-flip is requested without CRTCs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bf41925
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/atomic: log on attempt to set legacy DPMS property (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f3a8f40
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/atomic: log when CRTC_ID prop value is invalid (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a3c536
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/atomic: log when getting/setting unknown properties (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 03fe55f
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/atomic: drop extra bracket from log messages (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 166c22b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/atomic: log drm_atomic_replace_property_blob_from_id() errors (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3930600
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge_connector: use drm_kms_helper_connector_hotplug_event() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1a9fce9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/sysfs: rename drm_sysfs_connector_status_event() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 61c44ee
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: fix code style for embedded structs in hdr_metadata_infoframe (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0a89952
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mgag200: set variable mgag200_modeset storage-class-specifier to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2e421ab
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i2c: Switch i2c drivers back to use .probe() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c71867b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: tc358762: Handle HS/VS polarity (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b537bb4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: tc358762: Guess the meaning of LCDCTRL bits (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 827de55
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: tc358762: Instruct DSI host to generate HSE packets (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4d11ee2
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: tc358762: Switch to atomic ops (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a82c782
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: tc358762: Split register programming from pre-enable to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e7cd4d1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: tc358764: Use BIT() macro for actual bits (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 06bd23b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/shmem-helper: Switch to reservation lock (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d1a0581
* Wed Nov 29 2023 pjakobsson@suse.de
- dma-buf: Change locking policy for mmap() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ac2396c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: Don't assert held reservation lock for dma-buf mmapping (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a932e37
* Wed Nov 29 2023 pjakobsson@suse.de
- udmabuf: Don't assert held reservation lock for dma-buf mmapping (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1e66319
* Wed Nov 29 2023 pjakobsson@suse.de
- dma-buf/heaps: Don't assert held reservation lock for dma-buf (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b27aa6c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/bridge: lt9611uxc: Add MODULE_FIRMWARE macro (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1f3e719
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/vkms: Fix all kernel-doc warnings of the vkms_composer file (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8fb61dc
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/vkms: Add kernel-doc to the function vkms_compose_row() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f3240bb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/amdgpu: Remove struct drm_driver.gem_prime_mmap
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit a8c3bd6
* Wed Nov 29 2023 pjakobsson@suse.de
- drm: Remove struct drm_driver.gem_prime_mmap (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a5b75d1
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/msm: Initialize mmap offset after constructing the buffer object (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 37a6146
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tidss: Add support for AM625 DSS (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fb43c66
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ingenic: Kconfig: select REGMAP and REGMAP_MMIO (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 57e6e57
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ssd130x: Remove hardcoded bits-per-pixel in ssd130x_buf_alloc() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 960f287
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ssd130x: Don't allocate buffers on each plane update (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4c2e920
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ssd130x: Set the page height value in the device info data (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9dc9f5c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/ssd130x: Make default width and height to be controller dependent (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d0eb063
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/omap: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a7db0d4
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tilcdc: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3984872
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/rcar-du: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aeeeed8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/xlnx/zynqmp_dpsub: Convert to platform remove callback returning (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d1812c0
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/vc4: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d7708dc
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/v3d: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4586137
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tve200: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 42a6a4b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tiny: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9e85153
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/tidss: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 11e86cd
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/sun4i: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5b9ee38
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/stm: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ff3979a
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/sti: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 41e902e
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/rockchip: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 64f75ef
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panfrost: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f422724
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cde21fd
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mxsfb: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0278c8b
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/meson: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 40b20f7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/mcde: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8415c9c
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/logicvc: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c609196
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/lima: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 008a0ed
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/hisilicon: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3cb3636
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/fsl-dcu: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d642fc9
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/atmel-hlcdc: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6d97778
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/aspeed: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 660a848
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/arm/malidp: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5225e88
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/arm/hdlcd: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c2e0de8
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/komeda: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cd20618
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: Add driver for Visionox r66451 panel (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 45d98bb
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel: s6d7aa0: remove the unneeded variable in s6d7aa0_lock (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a034f60
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/panel-edp: Add AUO B116XAB01.4 edp panel entry (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ddfadf7
* Wed Nov 29 2023 pjakobsson@suse.de
- drm/i915: Move abs_diff() to math.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1065525
* Wed Nov 29 2023 pjakobsson@suse.de
- minmax: add in_range() macro (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8aa39d7
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Rename fb_mem*() helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 623f5ce
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Move framebuffer I/O helpers into <asm/fb.h> (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3677e17
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Include <linux/fb.h> instead of <asm/fb.h> (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7b99b28
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Include <linux/io.h> in various drivers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b6f13a5
* Wed Nov 29 2023 pjakobsson@suse.de
- arch/x86: Include <asm/fb.h> in fbdev source file (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ba9d5aa
* Wed Nov 29 2023 pjakobsson@suse.de
- arch/sparc: Implement <asm/fb.h> with generic helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bc778c5
* Wed Nov 29 2023 pjakobsson@suse.de
- arch/mips: Implement <asm/fb.h> with generic helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 099db9c
* Wed Nov 29 2023 pjakobsson@suse.de
- arch/loongarch: Implement <asm/fb.h> with generic helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 42e92f7
* Wed Nov 29 2023 pjakobsson@suse.de
- arch/ia64: Implement <asm/fb.h> with generic helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fca35d0
* Wed Nov 29 2023 pjakobsson@suse.de
- arch/sparc: Implement fb_is_primary_device() in source file (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8fa5c8c
* Wed Nov 29 2023 pjakobsson@suse.de
- arch/arm64: Implement <asm/fb.h> with generic helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 56f1e53
* Wed Nov 29 2023 pjakobsson@suse.de
- arch/powerpc: Implement <asm/fb.h> with generic helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 34b3f04
* Wed Nov 29 2023 pjakobsson@suse.de
- arch/x86: Implement <asm/fb.h> with generic helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0164da8
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Prepare generic architecture helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a7d5a6f
* Wed Nov 29 2023 pjakobsson@suse.de
- fbdev: Simplify fb_is_primary_device for x86 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fcdb57b
* Wed Nov 29 2023 pjakobsson@suse.de
- kunit: Add kunit_add_action() to defer a call until test exit (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9e287dc
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-fix-the-ability-to-use-lower-resolut.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8404fa8
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/i915-pmu-Move-execlist-stats-initialization-to-execl.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2fd6ed4
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-virtio-clean-out_fence-on-complete_submit.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 738fc58
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-meson-fix-memory-leak-on-hpd_notify-callback.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2c12b17
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-tests-Fix-incorrect-argument-in-drm_test_mm_inse.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c561b23
* Wed Nov 29 2023 pjakobsson@suse.de
- Update patches.suse/drm-tests-helpers-Avoid-a-driver-uaf.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 47616ce
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-radeon-make-fence-wait-in-suballocator-uninterrr.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2f1fe41
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Only-check-eDP-HPD-when-AUX-CH-is-shared.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6df7557
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-fix-the-white-screen-issue-when-64GB.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4d88cb6
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-gm12u320-Fix-the-timeout-usage-for-usb_bulk_msg.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9c9c815
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-Make-fence-wait-in-suballocator-uninterrupti.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4481783
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-prevent-potential-division-by-zero-e.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8ee87e7
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-enable-cursor-degamma-for-DCN3-DRM-l.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d7269a0
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/Revert-drm-amd-display-Remove-v_startup-workaround-f.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 22fc7e2
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-always-switch-off-ODM-before-committ.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 325c0a3
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Remove-wait-while-locked.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1cd430d
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Add-smu-write-msg-id-fail-retry-proc.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 1378da5
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-register-edp_backlight_control-for-D.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4244f35
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-fix-mode-scaling-RMX_.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 681b74c
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-mark-requests-for-GuC-virtual-engines-to-av.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fed52bf
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-gvt-Drop-unused-helper-intel_vgpu_reset_gtt.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 959b2ba
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-gvt-Put-the-page-reference-obtained-by-KVM-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 162958b
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-gvt-Verify-pfn-is-valid-before-dereferencin.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 248c2eb
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/backlight-gpio_backlight-Drop-output-GPIO-direction-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c8813fe
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/backlight-lp855x-Initialize-PWM-state-on-first-brigh.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 14664b8
* Wed Nov 29 2023 pjakobsson@suse.de
- Update patches.suse/fbdev-Update-fbdev-source-file-paths.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 77328b5
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-radeon-Use-RMW-accessors-for-changing-LNKCTL.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fd18279
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Use-RMW-accessors-for-changing-LNKCTL.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3d35ea3
* Wed Nov 29 2023 pjakobsson@suse.de
- Update patches.suse/drm-msm-a690-Switch-to-a660_gmu.bin.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 042bead
* Wed Nov 29 2023 pjakobsson@suse.de
- Update patches.suse/drm-msm-a6xx-Fix-GMU-lockdep-splat.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c92d672
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-a2xx-Call-adreno_gpu_init-earlier.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 824fe06
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dpu-fix-the-irq-index-in-dpu_encoder_phys_wb.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 58fd4bd
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-mdp5-Don-t-leak-some-plane-state.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b731701
* Wed Nov 29 2023 pjakobsson@suse.de
- Delete
  patches.suse/drm-msm-dpu-fix-DSC-1.2-enc-subblock-length.patch.
  Patch will be added back at the end of the series
- commit 1bb4eb2
* Wed Nov 29 2023 pjakobsson@suse.de
- Delete patches.suse/drm-msm-dpu-fix-DSC-1.2-block-lengths.patch.
  Patch will be added back at the end of the series
- commit 737c54e
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dpu-increase-memtype-count-to-16-for-sm8550.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 05c3d3a
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-Update-dev-core-dump-to-not-print-backwards.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0fdccff
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-etnaviv-fix-dumping-of-active-MMU-context.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b886c30
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-ensure-async-flips-are-only-accepted.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2f02292
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-pm-fix-variable-dereferenced-issue-in-amdgpu.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 370cff5
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-mediatek-Fix-void-pointer-to-enum-cast-warning.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a241211
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-mediatek-Fix-potential-memory-leak-if-vmap-fail.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 531cb9f
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-mediatek-Fix-dereference-before-null-check.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d9053c7
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-mediatek-Add-cnt-checking-for-coverity-issue.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 120f8f0
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-mediatek-Remove-freeing-not-dynamic-allocated-me.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cf71ba4
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-mediatek-dp-Add-missing-error-checks-in-mtk_dp_p.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 252686f
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-mediatek-Fix-uninitialized-symbol.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0398059
* Wed Nov 29 2023 pjakobsson@suse.de
- Delete
  patches.suse/drm-i915-gsc-Fix-intel_gsc_uc_fw_proxy_init_done-wit.patch.
  Patch will be added back at the end of the series
- commit 0cec422
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-panel-simple-Add-missing-connector-type-and-pixe.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 480b1c5
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-fix-Wunused-const-variable-warning.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 831c067
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-Remove-references-to-removed-transitional-helper.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 70797bf
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-repaper-Reduce-temporary-buffer-size-in-repaper_.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c408677
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-armada-Fix-off-by-one-error-in-armada_overlay_ge.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 265854d
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-ast-report-connection-status-on-Display-Port.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit be87d58
* Wed Nov 29 2023 pjakobsson@suse.de
- Update patches.suse/drm-ast-Add-BMC-virtual-connector.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b7b8af8
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-gem-fb-helper-Consistenly-use-drm_dbg_kms.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a8046c
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-atomic-helper-Update-reference-to-drm_crtc_force.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 880633f
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-tegra-dpaux-Fix-incorrect-return-value-of-platfo.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6b85e49
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-xlnx-zynqmp_dpsub-Add-missing-check-for-dma_set_.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9894150
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Update-min-to-min_t-in-amdgpu_info_ioctl.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 43fcd0c
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-dc.h-eliminate-kernel-doc-warnings.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4508ddb
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-avoid-integer-overflow-warning-in-amdgpu_.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ad4bf25
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Do-not-set-drr-on-pipe-commit.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b5e023d
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-anx7625-Drop-device-lock-before-drm_helpe.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c1a25ce
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-adv7511-Fix-low-refresh-rate-register-for-ADV753.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e60c131
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-anx7625-Use-common-macros-for-HDCP-capabi.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 54dfcaa
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-anx7625-Use-common-macros-for-DP-power-se.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c418a3a
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-hyperv-Fix-a-compilation-issue-because-of-not-in.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3a2847f
* Wed Nov 29 2023 pjakobsson@suse.de
- Update patches.suse/drm-ast-Fix-DRAM-init-on-AST2200.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e51853b
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/fbdev-ep93xx-fb-Do-not-assign-to-struct-fb_info.dev.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5be18a2
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/backlight-lv5207lp-Compare-against-struct-fb_info.de.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 980e082
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/backlight-gpio_backlight-Compare-against-struct-fb_i.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f4f179b
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/backlight-bd6107-Compare-against-struct-fb_info.devi.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 830534c
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/0001-drm-prime-Unexport-helpers-for-fd-handle-conversion.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a625538
* Wed Nov 29 2023 pjakobsson@suse.de
- Delete
  patches.suse/0001-drm-Clear-fd-handle-callbacks-in-struct-drm_driver.patch.
  Patch will be added back at the end of the series
- commit 3250a1d
* Wed Nov 29 2023 oneukum@suse.com
- thunderbolt: Set lane bonding bit only for downstream port
  (git-fixes).
- commit 26a8c0c
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-mxsfb-Disable-overlay-plane-in-mxsfb_plane_overl.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bb05cb3
* Wed Nov 29 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-dw-mipi-dsi-Fix-enable-disable-of-DSI-con.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8e41e9d
* Wed Nov 29 2023 oneukum@suse.com
- thunderbolt: Use weight constants in
  tb_usb3_consumed_bandwidth() (git-fixes).
- commit c9839f2
* Wed Nov 29 2023 oneukum@suse.com
- thunderbolt: Use constants for path weight and priority
  (git-fixes).
- commit 38fefd9
* Wed Nov 29 2023 oneukum@suse.com
- thunderbolt: Fix typo of HPD bit for Hot Plug Detect
  (git-fixes).
- commit 10dd7d1
* Wed Nov 29 2023 tiwai@suse.de
- Update ath11k hibernation patches from the latest code (bsc#1207948)
- commit 625056b
* Wed Nov 29 2023 oneukum@suse.com
- thunderbolt: Fix debug log when DisplayPort adapter not
  available for pairing (git-fixes).
- commit 5d790f3
* Wed Nov 29 2023 mkubecek@suse.cz
- Update
  patches.suse/netfilter-conntrack-dccp-copy-entire-header-to-.patch
  references (add CVE-2023-39197 bsc#1216976).
- commit fa8e914
* Wed Nov 29 2023 mkubecek@suse.cz
- Update
  patches.suse/netfilter-nf_tables-fix-GC-transaction-races-w.patch
  references (add CVE-2023-4244 bsc#1215420).
- commit 3e08695
* Wed Nov 29 2023 tiwai@suse.de
- tty: Fix uninit-value access in ppp_sync_receive() (git-fixes).
- pwm: Fix double shift bug (git-fixes).
- sbsa_gwdt: Calculate timeout with 64-bit math (git-fixes).
- soundwire: dmi-quirks: update HP Omen match (git-fixes).
- thunderbolt: Apply USB 3.x bandwidth quirk only in software
  connection manager (git-fixes).
- usb: gadget: f_ncm: Always set current gadget in ncm_bind()
  (git-fixes).
- usb: host: xhci: Avoid XHCI resume delay if SSUSB device is
  not present (git-fixes).
- usb: ucsi: glink: use the connector orientation GPIO to provide
  switch events (git-fixes).
- usb: dwc3: core: configure TX/RX threshold for DWC3_IP
  (git-fixes).
- tty: vcc: Add check for kstrdup() in vcc_probe() (git-fixes).
- selftests/efivarfs: create-read: fix a resource leak
  (git-fixes).
- platform/x86: thinkpad_acpi: Add battery quirk for Thinkpad
  X120e (git-fixes).
- platform/chrome: kunit: initialize lock for fake ec_dev
  (git-fixes).
- powercap: intel_rapl: Downgrade BIOS locked limits pr_warn()
  to pr_debug() (git-fixes).
- wifi: iwlwifi: mvm: fix size check for fw_link_id (git-fixes).
- wifi: ath10k: Don't touch the CE interrupt registers after
  power up (git-fixes).
- wifi: ath12k: mhi: fix potential memory leak in
  ath12k_mhi_register() (git-fixes).
- wifi: mt76: mt7921e: Support MT7992 IP in Xiaomi Redmibook 15
  Pro (2023) (git-fixes).
- wifi: ath12k: fix possible out-of-bound write in
  ath12k_wmi_ext_hal_reg_caps() (git-fixes).
- wifi: ath10k: fix clang-specific fortify warning (git-fixes).
- wifi: ath12k: fix possible out-of-bound read in
  ath12k_htt_pull_ppdu_stats() (git-fixes).
- wifi: ath9k: fix clang-specific fortify warnings (git-fixes).
- wifi: ath12k: Ignore fragments from uninitialized peer in  dp
  (git-fixes).
- wifi: mac80211: don't return unset power in
  ieee80211_get_tx_power() (git-fixes).
- wifi: mac80211_hwsim: fix clang-specific fortify warning
  (git-fixes).
- wifi: plfxlc: fix clang-specific fortify warning (git-fixes).
- selftests/lkdtm: Disable CONFIG_UBSAN_TRAP in test config
  (git-fixes).
- commit cf64eb4
* Wed Nov 29 2023 tiwai@suse.de
- media: imon: fix access to invalid resource for the second
  interface (git-fixes).
- media: ccs: Fix driver quirk struct documentation (git-fixes).
- media: cobalt: Use FIELD_GET() to extract Link Width
  (git-fixes).
- media: vivid: avoid integer overflow (git-fixes).
- media: gspca: cpia1: shift-out-of-bounds in set_flicker
  (git-fixes).
- i3c: master: mipi-i3c-hci: Fix a kernel panic for accessing
  DAT_data (git-fixes).
- phy: qualcomm: phy-qcom-eusb2-repeater: Zero out untouched
  tuning regs (git-fixes).
- phy: qualcomm: phy-qcom-eusb2-repeater: Use regmap_fields
  (git-fixes).
- iio: adc: stm32-adc: harden against NULL pointer deref in
  stm32_adc_probe() (git-fixes).
- mfd: intel-lpss: Add Intel Lunar Lake-M PCI IDs (git-fixes).
- PCI: Use FIELD_GET() in Sapphire RX 5600 XT Pulse quirk
  (git-fixes).
- PCI: Use FIELD_GET() to extract Link Width (git-fixes).
- PCI: mvebu: Use FIELD_PREP() with Link Width (git-fixes).
- PCI: tegra194: Use FIELD_GET()/FIELD_PREP() with Link Width
  fields (git-fixes).
- PCI: Do error check on own line to split long "if" conditions
  (git-fixes).
- misc: pci_endpoint_test: Add Device ID for R-Car S4-8 PCIe
  controller (git-fixes).
- PCI: dwc: Add missing PCI_EXP_LNKCAP_MLW handling (git-fixes).
- PCI: dwc: Add dw_pcie_link_set_max_link_width() (git-fixes).
- PCI: Disable ATS for specific Intel IPU E2000 devices
  (git-fixes).
- PCI: Extract ATS disabling to a helper function (git-fixes).
- commit 14c7271
* Wed Nov 29 2023 tiwai@suse.de
- ASoC: ti: omap-mcbsp: Fix runtime PM underflow warnings
  (git-fixes).
- i2c: dev: copy userspace array safely (git-fixes).
- i2c: sun6i-p2wi: Prevent potential division by zero (git-fixes).
- i2c: fix memleak in i2c_new_client_device() (git-fixes).
- i3c: mipi-i3c-hci: Fix out of bounds access in
  hci_dma_irq_handler (git-fixes).
- 9p: v9fs_listxattr: fix %%s null argument warning (git-fixes).
- 9p/trans_fd: Annotate data-racy writes to file::f_flags
  (git-fixes).
- crypto: hisilicon/qm - prevent soft lockup in receive loop
  (git-fixes).
- crypto: x86/sha - load modules based on CPU features
  (git-fixes).
- crypto: pcrypt - Fix hungtask for PADATA_RESET (git-fixes).
- ARM: 9320/1: fix stack depot IRQ stack filter (git-fixes).
- ASoC: Intel: soc-acpi-cht: Add Lenovo Yoga Tab 3 Pro YT3-X90
  quirk (git-fixes).
- gpiolib: of: Add quirk for mt2701-cs42448 ASoC sound
  (git-fixes).
- ASoC: SOF: ipc4: handle EXCEPTION_CAUGHT notification from
  firmware (git-fixes).
- ASoC: SOF: Pass PCI SSID to machine driver (git-fixes).
- ASoC: soc-card: Add storage for PCI SSID (git-fixes).
- ASoC: mediatek: mt8188-mt6359: support dynamic pinctrl
  (git-fixes).
- ALSA: hda: Fix possible null-ptr-deref when assigning a stream
  (git-fixes).
- HID: lenovo: Detect quirk-free fw on cptkbd and stop applying
  workaround (git-fixes).
- HID: Add quirk for Dell Pro Wireless Keyboard and Mouse KM5221W
  (git-fixes).
- atm: iphase: Do PCI error checks on own line (git-fixes).
- string.h: add array-wrappers for (v)memdup_user() (git-fixes).
- gpiolib: acpi: Add a ignore interrupt quirk for Peaq C1010
  (git-fixes).
- ACPI: EC: Add quirk for HP 250 G7 Notebook PC (git-fixes).
- ACPI: APEI: Fix AER info corruption when error status data
  has multiple sections (git-fixes).
- Bluetooth: btusb: Add date->evt_skb is NULL check (git-fixes).
- atl1c: Work around the DMA RX overflow issue (git-fixes).
- clocksource/drivers/timer-atmel-tcb: Fix initialization on
  SAM9 hardware (git-fixes).
- clocksource/drivers/timer-imx-gpt: Fix potential memory leak
  (git-fixes).
- commit 3ef9447
* Tue Nov 28 2023 tbogendoerfer@suse.de
- nf_tables: fix NULL pointer dereference in
  nft_expr_inner_parse() (bsc#1217473 CVE-2023-5972).
- nf_tables: fix NULL pointer dereference in nft_inner_init()
  (bsc#1217473 CVE-2023-5972).
- commit 426f5f1
* Tue Nov 28 2023 tbogendoerfer@suse.de
- mlx5: Fix type of mode parameter in mlx5_dpll_device_mode_get()
  (jsc#PED-3311).
- commit a1db2ea
* Tue Nov 28 2023 tbogendoerfer@suse.de
- mlx5: Implement SyncE support using DPLL infrastructure
  (jsc#PED-3311).
- Update config files.
- supported.conf: marked mlx5_dpll as supported
- commit 329a356
* Tue Nov 28 2023 mfranc@suse.cz
- s390/dasd: use correct number of retries for ERP requests
  (git-fixes bsc#1217591).
- commit 8ac2855
* Tue Nov 28 2023 nik.borisov@suse.com
- x86/shstk: Delay signal entry SSP write until after user accesses (git-fixes).
- commit b625f6e
* Tue Nov 28 2023 nik.borisov@suse.com
- x86/shstk: Remove useless clone error handling (git-fixes).
- commit 68f810b
* Tue Nov 28 2023 nik.borisov@suse.com
- x86/shstk: Handle vfork clone failure correctly (git-fixes).
- commit d02edac
* Tue Nov 28 2023 tiwai@suse.de
- media: v4l2-subdev: Fix a 64bit bug (git-fixes).
- lockdep: Fix block chain corruption (git-fixes).
- commit cabedb7
* Tue Nov 28 2023 tiwai@suse.de
- Re-enable CONFIG_IA32_EMULATION_DEFAULT_DISABLED (jsc#PED-3184)
- commit 41264f0
* Mon Nov 27 2023 tbogendoerfer@suse.de
- i40e: Fix adding unsupported cloud filters (jsc#PED-4874).
- ice: restore timestamp configuration after device reset
  (jsc#PED-4876).
- ice: unify logic for programming PFINT_TSYN_MSK (jsc#PED-4876).
- ice: remove ptp_tx ring parameter flag (jsc#PED-4876).
- octeontx2-pf: Fix ntuple rule creation to direct packet to VF
  with higher Rx queue than its PF (jsc#PED-6931).
- dpll: Fix potential msg memleak when genlmsg_put_reply failed
  (jsc#PED-6079).
- octeontx2-pf: Fix memory leak during interface down
  (jsc#PED-6931).
- ice: fix DDP package download for packages without signature
  segment (jsc#PED-4876).
- ice: dpll: fix output pin capabilities (jsc#PED-4876).
- ice: dpll: fix check for dpll input priority range
  (jsc#PED-4876).
- ice: dpll: fix initial lock status of dpll (jsc#PED-4876).
- ice: Fix VF-VF direction matching in drop rule in switchdev
  (jsc#PED-4876).
- ice: Fix VF-VF filter rules in switchdev mode (jsc#PED-4876).
- ice: lag: in RCU, use atomic allocation (jsc#PED-4876).
- ice: Fix SRIOV LAG disable on non-compliant aggregate
  (jsc#PED-4876).
- i40e: Fix devlink port unregistering (jsc#PED-4874).
- i40e: Do not call devlink_port_type_clear() (jsc#PED-4874).
- net: ethtool: Fix documentation of ethtool_sprintf()
  (jsc#PED-5734).
- chelsio: Do not include crypto/algapi.h (jsc#PED-6951).
- ice: Hook up 4 E830 devices by adding their IDs (jsc#PED-4876).
- ice: Remove redundant zeroing of the fields (jsc#PED-4876).
- ice: Add support for E830 DDP package segment (jsc#PED-4876).
- ice: Add ice_get_link_status_datalen (jsc#PED-4876).
- ice: Add 200G speed/phy type use (jsc#PED-4876).
- ice: Add E830 device IDs, MAC type and registers (jsc#PED-4876).
- bnxt_en: Fix 2 stray ethtool -S counters (jsc#PED-5742).
- bnxt_en: extend media types to supported and autoneg modes
  (jsc#PED-5742).
- bnxt_en: convert to linkmode_set_bit() API (jsc#PED-5742).
- bnxt_en: Refactor NRZ/PAM4 link speed related logic
  (jsc#PED-5742).
- bnxt_en: refactor speed independent ethtool modes
  (jsc#PED-5742).
- bnxt_en: support lane configuration via ethtool (jsc#PED-5742).
- bnxt_en: add infrastructure to lookup ethtool link mode
  (jsc#PED-5742).
- bnxt_en: Fix invoking hwmon_notify_event (jsc#PED-5742).
- bnxt_en: Do not call sleeping hwmon_notify_event() from NAPI
  (jsc#PED-5742).
- ice: cleanup ice_find_netlist_node (jsc#PED-4876).
- ice: make ice_get_pf_c827_idx static (jsc#PED-4876).
- ice: manage VFs MSI-X using resource tracking (jsc#PED-4876).
- ice: set MSI-X vector count on VF (jsc#PED-4876).
- ice: add bitmap to track VF MSI-X usage (jsc#PED-4876).
- ice: implement num_msix field per VF (jsc#PED-4876).
- ice: store VF's pci_dev ptr in ice_vf (jsc#PED-4876).
- ice: add drop rule matching on not active lport (jsc#PED-4876).
- ice: remove unused ice_flow_entry fields (jsc#PED-4876).
- ethtool: untangle the linkmode and ethtool headers
  (jsc#PED-5734).
- qed: devlink health: use retained error fmsg API (jsc#PED-5734).
- bnxt_en: devlink health: use retained error fmsg API
  (jsc#PED-5742).
- i40e: Align devlink info versions with ice driver and add docs
  (jsc#PED-4874).
- igc: replace deprecated strncpy with strscpy (jsc#PED-4860).
- igbvf: replace deprecated strncpy with strscpy (jsc#PED-4866).
- igb: replace deprecated strncpy with strscpy (jsc#PED-4866).
- i40e: use scnprintf over strncpy+strncat (jsc#PED-4874).
- ice: Refactor finding advertised link speed (jsc#PED-4876).
- qede: Refactor qede_forced_speed_maps_init() (jsc#PED-5734).
- ethtool: Add forced speed to supported link modes maps
  (jsc#PED-5734).
- eth: bnxt: fix backward compatibility with older devices
  (jsc#PED-5742).
- dpll: netlink/core: change pin frequency set behavior
  (jsc#PED-6079).
- ice: dpll: implement phase related callbacks (jsc#PED-4876).
- dpll: netlink/core: add support for pin-dpll signal phase
  offset/adjust (jsc#PED-6079).
- dpll: spec: add support for pin-dpll signal phase offset/adjust
  (jsc#PED-6079).
- dpll: docs: add support for pin signal phase offset/adjust
  (jsc#PED-6079).
- i40e: Add PBA as board id info to devlink .info_get
  (jsc#PED-4874).
- i40e: Refactor and rename i40e_read_pba_string() (jsc#PED-4874).
- i40e: Add handler for devlink .info_get (jsc#PED-4874).
- i40e: Split and refactor i40e_nvm_version_str() (jsc#PED-4874).
- i40e: Add initial devlink support (jsc#PED-4874).
- sfc: support offloading ct(nat) action in RHS rules
  (jsc#PED-6894).
- sfc: parse mangle actions (NAT) in conntrack entries
  (jsc#PED-6894).
- qed: replace uses of strncpy (jsc#PED-5734).
- sfc: replace deprecated strncpy with strscpy (jsc#PED-6894).
- net/mlx4_core: replace deprecated strncpy with strscpy
  (jsc#PED-3309).
- netdev: replace napi_reschedule with napi_schedule
  (jsc#PED-3309).
- netdev: make napi_schedule return bool on NAPI successful
  schedule (jsc#PED-3309).
- bna: replace deprecated strncpy with strscpy_pad (jsc#PED-6884).
- netlink: specs: remove redundant type keys from attributes in
  subsets (jsc#PED-6079).
- i40e: Move DDP specific macros and structures to i40e_ddp.c
  (jsc#PED-4874).
- i40e: Remove circular header dependencies and fix headers
  (jsc#PED-4874).
- i40e: Split i40e_osdep.h (jsc#PED-4874).
- i40e: Move memory allocation structures to i40e_alloc.h
  (jsc#PED-4874).
- i40e: Simplify memory allocation functions (jsc#PED-4874).
- i40e: Refactor I40E_MDIO_CLAUSE* macros (jsc#PED-4874).
- i40e: Move I40E_MASK macro to i40e_register.h (jsc#PED-4874).
- i40e: Remove back pointer from i40e_hw structure (jsc#PED-4874).
- sfc: support TC rules which require OR-AR-CT-AR flow
  (jsc#PED-6894).
- sfc: ensure an extack msg from efx_tc_flower_replace_foreign
  EOPNOTSUPPs (jsc#PED-6894).
- sfc: offload foreign RHS rules without an encap match
  (jsc#PED-6894).
- sfc: support TC left-hand-side rules on foreign netdevs
  (jsc#PED-6894).
- i40e: Add rx_missed_errors for buffer exhaustion (jsc#PED-4874).
- cxgb4: Annotate struct smt_data with __counted_by
  (jsc#PED-6951).
- cxgb4: Annotate struct sched_table with __counted_by
  (jsc#PED-6951).
- cxgb4: Annotate struct cxgb4_tc_u32_table with __counted_by
  (jsc#PED-6951).
- cxgb4: Annotate struct clip_tbl with __counted_by
  (jsc#PED-6951).
- chelsio/l2t: Annotate struct l2t_data with __counted_by
  (jsc#PED-6951).
- Revert "bnxt_en: Support QOS and TPID settings for the SRIOV
  VLAN" (jsc#PED-5742).
- ice: fix linking when CONFIG_PTP_1588_CLOCK=n (jsc#PED-4876).
- bnxt_en: Update VNIC resource calculation for VFs
  (jsc#PED-5742).
- bnxt_en: Support QOS and TPID settings for the SRIOV VLAN
  (jsc#PED-5742).
- bnxt_en: Event handler for Thermal event (jsc#PED-5742).
- bnxt_en: Use non-standard attribute to expose shutdown
  temperature (jsc#PED-5742).
- bnxt_en: Expose threshold temperatures through hwmon
  (jsc#PED-5742).
- bnxt_en: Modify the driver to use
  hwmon_device_register_with_info (jsc#PED-5742).
- bnxt_en: Move hwmon functions into a dedicated file
  (jsc#PED-5742).
- bnxt_en: Enhance hwmon temperature reporting (jsc#PED-5742).
- bnxt_en: Update firmware interface to 1.10.2.171 (jsc#PED-5742).
- Documentation: dpll: wrap DPLL_CMD_PIN_GET output in a code
  block (jsc#PED-6079).
- Documentation: dpll: Fix code blocks (jsc#PED-6079).
- ice: make use of DEFINE_FLEX() in ice_switch.c (jsc#PED-4876).
- ice: make use of DEFINE_FLEX() for struct ice_aqc_dis_txq_item
  (jsc#PED-4876).
- ice: make use of DEFINE_FLEX() for struct ice_aqc_add_tx_qgrp
  (jsc#PED-4876).
- ice: make use of DEFINE_FLEX() in ice_ddp.c (jsc#PED-4876).
- ice: drop two params of ice_aq_move_sched_elems()
  (jsc#PED-4876).
- ice: ice_sched_remove_elems: replace 1 elem array param by u32
  (jsc#PED-4876).
- overflow: add DEFINE_FLEX() for on-stack allocs (jsc#PED-4876).
- ice: Remove the FW shared parameters (jsc#PED-4876).
- ice: PTP: add clock domain number to auxiliary interface
  (jsc#PED-4876).
- ice: Use PTP auxbus for all PHYs restart in E822 (jsc#PED-4876).
- ice: Auxbus devices & driver for E822 TS (jsc#PED-4876).
- netdev: Remove unneeded semicolon (jsc#PED-6079).
- ice: check netlist before enabling ICE_F_GNSS (jsc#PED-4876).
- ice: introduce ice_pf_src_tmr_owned (jsc#PED-4876).
- ice: fix pin assignment for E810-T without SMA control
  (jsc#PED-4876).
- ice: remove ICE_F_PTP_EXTTS feature flag (jsc#PED-4876).
- ice: PTP: move quad value check inside ice_fill_phy_msg_e822
  (jsc#PED-4876).
- ice: PTP: Rename macros used for PHY/QUAD port definitions
  (jsc#PED-4876).
- ice: PTP: Clean up timestamp registers correctly (jsc#PED-4876).
- ice: introduce hw->phy_model for handling PTP PHY differences
  (jsc#PED-4876).
- ice: Support cross-timestamping for E823 devices (jsc#PED-4876).
- ice: retry acquiring hardware semaphore during cross-timestamp
  request (jsc#PED-4876).
- ice: prefix clock timer command enumeration values with ICE_PTP
  (jsc#PED-4876).
- net/mlx5: Lift reload limitation when SFs are present
  (jsc#PED-3311).
- net/mlx5: Disable eswitch as the first thing in mlx5_unload()
  (jsc#PED-3311).
- ice: implement dpll interface to control cgu (jsc#PED-4876).
- ice: add admin commands to access cgu configuration
  (jsc#PED-4876).
- netdev: expose DPLL pin handle for netdevice (jsc#PED-6079).
- dpll: netlink: Add DPLL framework base functions (jsc#PED-6079).
- dpll: core: Add DPLL framework base functions (jsc#PED-6079).
- dpll: spec: Add Netlink spec in YAML (jsc#PED-6079).
- dpll: documentation on DPLL subsystem interface (jsc#PED-6079).
- ice: Check CRC strip requirement for VLAN strip (jsc#PED-4876).
- ice: Support FCS/CRC strip disable for VF (jsc#PED-4876).
- sfc: make coding style of PTP addresses consistent with core
  (jsc#PED-6894).
- i40e: fix potential memory leaks in i40e_remove()
  (jsc#PED-4874).
- i40e: Fix wrong check for I40E_TXR_FLAGS_WB_ON_ITR
  (jsc#PED-4874).
- sfc: cleanup and reduce netlink error messages (jsc#PED-6894).
- net: chelsio: cxgb4: add an error code check in t4_load_phy_fw
  (jsc#PED-6951).
- i40e: sync next_to_clean and next_to_process for programming
  status desc (jsc#PED-4874).
- igc: Fix ambiguity in the ethtool advertising (jsc#PED-4860).
- igb: Fix potential memory leak in igb_add_ethtool_nfc_entry
  (jsc#PED-4866).
- i40e: Fix I40E_FLAG_VF_VLAN_PRUNING value (jsc#PED-4874).
- i40e: xsk: remove count_mask (jsc#PED-4874).
- vdpa/mlx5: Fix firmware error on creation of 1k VQs
  (jsc#PED-3311).
- vdpa/mlx5: Fix double release of debugfs entry (jsc#PED-3311).
- qed: fix LL2 RX buffer allocation (jsc#PED-5734).
- net/mlx5e: Fix VF representors reporting zero counters to
  "ip -s" command (jsc#PED-3311).
- net/mlx5e: Don't offload internal port if filter device is
  out device (jsc#PED-3311).
- net/mlx5e: Take RTNL lock before triggering netdev notifiers
  (jsc#PED-3311).
- net/mlx5e: XDP, Fix XDP_REDIRECT mpwqe page fragment leaks on
  shutdown (jsc#PED-3311).
- net/mlx5e: RX, Fix page_pool allocation failure recovery for
  legacy rq (jsc#PED-3311).
- net/mlx5e: RX, Fix page_pool allocation failure recovery for
  striding rq (jsc#PED-3311).
- net/mlx5: Handle fw tracer change ownership event based on MTRC
  (jsc#PED-3311).
- net/mlx5: Bridge, fix peer entry ageing in LAG mode
  (jsc#PED-3311).
- net/mlx5: E-switch, register event handler before arming the
  event (jsc#PED-3311).
- net/mlx5: Perform DMA operations in the right locations
  (jsc#PED-3311).
- ice: Fix safe mode when DDP is missing (jsc#PED-4876).
- ice: reset first in crash dump kernels (jsc#PED-4876).
- i40e: prevent crash on probe if hw registers have invalid values
  (jsc#PED-4874).
- ice: fix over-shifted variable (jsc#PED-4876).
- net/mlx5e: Again mutually exclude RX-FCS and RX-port-timestamp
  (jsc#PED-3311).
- net/mlx5e: macsec: use update_pn flag instead of PN comparation
  (jsc#PED-3311).
- ice: block default rule setting on LAG interface (jsc#PED-4876).
- devlink: remove converted commands from small ops
  (jsc#PED-3311).
- devlink: remove duplicate temporary netlink callback prototypes
  (jsc#PED-3311).
- devlink: pass flags as an arg of dump_one() callback
  (jsc#PED-3311).
- devlink: introduce dumpit callbacks for split ops
  (jsc#PED-3311).
- devlink: rename doit callbacks for per-instance dump commands
  (jsc#PED-3311).
- devlink: introduce devlink_nl_pre_doit_port*() helper functions
  (jsc#PED-3311).
- devlink: parse rate attrs in doit() callbacks (jsc#PED-3311).
- devlink: parse linecard attr in doit() callbacks (jsc#PED-3311).
- devlink: clear flag on port register error path (jsc#PED-3311).
- devlink: use generated split ops and remove duplicated commands
  from small ops (jsc#PED-3311).
- devlink: include the generated netlink header (jsc#PED-3311).
- devlink: add split ops generated according to spec
  (jsc#PED-3311).
- devlink: un-static devlink_nl_pre/post_doit() (jsc#PED-3311).
- devlink: introduce couple of dumpit callbacks for split ops
  (jsc#PED-3311).
- devlink: rename couple of doit netlink callbacks to match
  generated names (jsc#PED-3311).
- devlink: rename devlink_nl_ops to devlink_nl_small_ops
  (jsc#PED-3311).
- devlink: remove reload failed checks in params get/set callbacks
  (jsc#PED-3311).
- tools: ynl: generate code for the devlink family (jsc#PED-3311).
- tools: ynl: generate code for the handshake family
  (jsc#PED-3311).
- tools: ynl: support fou and netdev in C (jsc#PED-3311).
- tools: ynl: user space helpers (jsc#PED-3311).
- commit d1397b2
* Mon Nov 27 2023 mfranc@suse.cz
- KVM: s390: pv: Allow AP-instructions for pv-guests
  (jsc#PED-5441).
- KVM: s390: Add UV feature negotiation (jsc#PED-5441).
- s390/uv: UV feature check utility (jsc#PED-5441).
- KVM: s390: pv: relax WARN_ONCE condition for destroy fast
  (jsc#PED-5441).
- commit 4d04ae4
* Mon Nov 27 2023 mfranc@suse.cz
- s390/vfio-ap: make sure nib is shared (jsc#PED-5441).
- KVM: s390: export kvm_s390_pv*_is_protected functions
  (jsc#PED-5441).
- s390/uv: export uv_pin_shared for direct usage (jsc#PED-5441).
- s390/vfio-ap: check for TAPQ response codes 0x35 and 0x36
  (jsc#PED-5441).
- s390/vfio-ap: handle queue state change in progress on reset
  (jsc#PED-5441).
- s390/vfio-ap: use work struct to verify queue reset
  (jsc#PED-5441).
- s390/vfio-ap: store entire AP queue status word with the queue
  object (jsc#PED-5441).
- s390/vfio-ap: remove upper limit on wait for queue reset to
  complete (jsc#PED-5441).
- s390/vfio-ap: allow deconfigured queue to be passed through
  to a guest (jsc#PED-5441).
- s390/vfio-ap: wait for response code 05 to clear on queue reset
  (jsc#PED-5441).
- s390/vfio-ap: clean up irq resources if possible (jsc#PED-5441).
- s390/vfio-ap: no need to check the 'E' and 'I' bits in APQSW
  after TAPQ (jsc#PED-5441).
- commit ce9cd9c
* Mon Nov 27 2023 oneukum@suse.com
- Update
  patches.suse/net-usb-lan78xx-reorder-cleanup-operations-to-.patch
  (bsc#1217068 CVE-2023-6039).
  Reference updated. Bug retroactively declared a security issue.
- commit 1d8baa2
* Mon Nov 27 2023 mfranc@suse.cz
- s390/ipl: add missing IPL_TYPE_ECKD_DUMP case to ipl_init()
  (git-fixes bsc#1217510).
- commit 074bb1e
* Mon Nov 27 2023 ohering@suse.de
- hv_netvsc: Mark VF as slave before exposing it to user-mode
  (git-fixes).
- hv_netvsc: Fix race of register_netdevice_notifier and VF
  register (git-fixes).
- hv_netvsc: fix race of netvsc and VF register_netdevice
  (git-fixes).
- x86/hyperv: Use atomic_try_cmpxchg() to micro-optimize
  hv_nmi_unknown() (git-fixes).
- x86/hyperv: Fix the detection of E820_TYPE_PRAM in a Gen2 VM
  (git-fixes).
- hv/hv_kvp_daemon: Some small fixes for handling NM keyfiles
  (git-fixes).
- commit 5d419c2
* Sun Nov 26 2023 tiwai@suse.de
- xhci: Enable RPM on controllers that support low-power states
  (git-fixes).
- commit 5ca8a90
* Sun Nov 26 2023 tiwai@suse.de
- USB: serial: option: fix FM101R-GL defines (git-fixes).
- USB: dwc3: qcom: fix ACPI platform device leak (git-fixes).
- USB: dwc3: qcom: fix software node leak on probe errors
  (git-fixes).
- USB: dwc3: qcom: fix resource leaks on probe deferral
  (git-fixes).
- USB: dwc3: qcom: fix wakeup after probe deferral (git-fixes).
- dt-bindings: usb: qcom,dwc3: fix example wakeup interrupt types
  (git-fixes).
- usb: dwc3: set the dma max_seg_size (git-fixes).
- usb: config: fix iteration issue in 'usb_get_bos_descriptor()'
  (git-fixes).
- usb: cdnsp: Fix deadlock issue during using NCM gadget
  (git-fixes).
- usb: dwc3: Fix default mode initialization (git-fixes).
- usb: typec: tcpm: Skip hard reset when in error recovery
  (git-fixes).
- dt-bindings: usb: hcd: add missing phy name to example
  (git-fixes).
- kselftest/arm64: Fix output formatting for za-fork (git-fixes).
- arm64: mm: Fix "rodata=on" when
  CONFIG_RODATA_FULL_DEFAULT_ENABLED=y (git-fixes).
- arm/xen: fix xen_vcpu_info allocation alignment (git-fixes).
- commit 5dff477
* Sat Nov 25 2023 tiwai@suse.de
- Update config files: refreshed vanilla config again
- commit 18c6bad
* Fri Nov 24 2023 tiwai@suse.de
- Trim the old entries in changelogs, start from 6.4 fork
- commit f25abaa
* Fri Nov 24 2023 tbogendoerfer@suse.de
- igb: Fix an end of loop test (jsc#PED-4872).
- commit 071f08c
* Fri Nov 24 2023 petr.pavlu@suse.com
- rpm/kernel-source.changes.old: Remove old changelog entries
  The RPM changelog has grown to ~400k lines which unnecessarily increases
  size of the resulting packages, especially because the same changelog is
  at the moment used for all built packages. For instance, size of the
  kernel-macros package is now at ~12MB while the actual content is ~30kB.
  To reduce the size, bump the cut-off commit for the changelog to the
  predecessor of 126b9a7394d ("Change to SLE15-SP6 branch
  (jsc#PED-4593)").
  Note that the auto-generated changelog currently relies on author dates.
  Some commits that were cherry-picked on the branch have their author
  date earlier than the commit 126b9a7394d and hence appear before this
  commit in the produced changelog as well.
- commit f2af818
* Fri Nov 24 2023 tbogendoerfer@suse.de
- iavf: delete the iavf client interface (jsc#PED-4937).
- iavf: add a common function for undoing the interrupt scheme
  (jsc#PED-4937).
- iavf: use unregister_netdev (jsc#PED-4937).
- iavf: rely on netdev's own registered state (jsc#PED-4937).
- iavf: fix the waiting time for initial reset (jsc#PED-4937).
- iavf: in iavf_down, don't queue watchdog_task if comms failed
  (jsc#PED-4937).
- iavf: simplify mutex_trylock+sleep loops (jsc#PED-4937).
- iavf: fix comments about old bit locks (jsc#PED-4937).
- ixgbe: fix end of loop test in ixgbe_set_vf_macvlan()
  (jsc#PED-4872).
- iavf: delete unused iavf_mac_info fields (jsc#PED-4937).
- intel: fix format warnings (jsc#PED-4872).
- intel: fix string truncation warnings (jsc#PED-4937).
- ionic: replace deprecated strncpy with strscpy (jsc#PED-6953).
- virtchnl: Add header dependencies (jsc#PED-4937).
- iavf: remove "inline" functions from iavf_txrx.c (jsc#PED-4937).
- net: Tree wide: Replace xdp_do_flush_map() with xdp_do_flush()
  (jsc#PED-4872).
- ethernet/intel: Use list_for_each_entry() helper (jsc#PED-4872).
- ionic: expand the descriptor bufs array (jsc#PED-6953).
- ionic: add a check for max SGs and SKB frags (jsc#PED-6953).
- ionic: count SGs in packet to minimize linearize (jsc#PED-6953).
- iavf: Add ability to turn off CRC stripping for VF
  (jsc#PED-4937).
- virtchnl: Add CRC stripping capability (jsc#PED-4937).
- iavf: Fix promiscuous mode configuration flow messages
  (jsc#PED-4937).
- iavf: in iavf_down, disable queues when removing the driver
  (jsc#PED-4937).
- iavf: initialize waitqueues before starting watchdog_task
  (jsc#PED-4937).
- ixgbe: fix crash with empty VF macvlan list (jsc#PED-4872).
- ionic: fix 16bit math issue when PAGE_SIZE >= 64KB
  (jsc#PED-6953).
- ixgbe: fix timestamp configuration code (jsc#PED-4872).
- e1000e: Add support for the next LOM generation (jsc#PED-4868).
- ionic: Remove unused declarations (jsc#PED-6953).
- e1000e: Use PME poll to circumvent unreliable ACPI wake
  (jsc#PED-4868).
- net: e1000e: Remove unused declarations (jsc#PED-4868).
- rtnetlink: remove redundant checks for nlattr IFLA_BRIDGE_MODE
  (jsc#PED-4872).
- ixgbe: Remove unused function declarations (jsc#PED-4872).
- ionic: add FLR recovery support (jsc#PED-6953).
- ionic: pull out common bits from fw_up (jsc#PED-6953).
- ionic: extract common bits from ionic_probe (jsc#PED-6953).
- ionic: extract common bits from ionic_remove (jsc#PED-6953).
- ionic: remove dead device fail path (jsc#PED-6953).
- ionic: use vmalloc_array and vcalloc (jsc#PED-6953).
- ionic: add support for ethtool extended stat link_down_count
  (jsc#PED-6953).
- e1000e: Add @adapter description to kdoc (jsc#PED-4868).
- commit 91e995b
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/shstk: Change order of __user in type (jsc#PED-6018).
- commit 0107db9
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/ibt: Convert IBT selftest to asm (jsc#PED-6018).
- commit 134cc83
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/shstk: Don't retry vm_munmap() on -EINTR (jsc#PED-6018).
- commit 2d18a08
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/kbuild: Fix Documentation/ reference (jsc#PED-6018).
- commit 3171868
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/shstk: Move arch detail comment out of core mm (jsc#PED-6018).
- commit 480c637
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/shstk: Add ARCH_SHSTK_STATUS (jsc#PED-6018).
- commit 2938766
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/shstk: Add ARCH_SHSTK_UNLOCK (jsc#PED-6018).
- commit dcfff9e
* Fri Nov 24 2023 nik.borisov@suse.com
- x86: Add PTRACE interface for shadow stack (jsc#PED-6018).
- commit f572a94
* Fri Nov 24 2023 nik.borisov@suse.com
- selftests/x86: Add shadow stack test (jsc#PED-6018).
- commit e6a828d
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/cpufeatures: Enable CET CR4 bit for shadow stack (jsc#PED-6018).
- commit f024116
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/shstk: Wire in shadow stack interface (jsc#PED-6018).
- commit 75d6c19
* Fri Nov 24 2023 nik.borisov@suse.com
- x86: Expose thread features in /proc/$PID/status (jsc#PED-6018).
- commit 2652028
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/shstk: Support WRSS for userspace (jsc#PED-6018).
- commit da1f8ce
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/shstk: Introduce map_shadow_stack syscall (jsc#PED-6018).
- Refresh patches.suse/x86-Remove-the-arch_calc_vm_prot_bits-macro-from-the-UAPI.patch.
- commit 9a5d440
* Fri Nov 24 2023 mfranc@suse.cz
- s390/dasd: protect device queue against concurrent access
  (git-fixes bsc#1217481).
- commit 55f7a58
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/shstk: Check that signal frame is shadow stack mem (jsc#PED-6018).
- commit 6123f67
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/shstk: Check that SSP is aligned on sigreturn (jsc#PED-6018).
- commit 84f44b1
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/shstk: Handle signals for shadow stack (jsc#PED-6018).
- commit 75bc417
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/shstk: Introduce routines modifying shstk (jsc#PED-6018).
- commit 5a66753
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/shstk: Handle thread shadow stack (jsc#PED-6018).
- commit fbc0ee7
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/shstk: Add user-mode shadow stack support (jsc#PED-6018).
- commit f8f3c51
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/shstk: Add user control-protection fault handler (jsc#PED-6018).
- Refresh patches.suse/kabi-reserve-cpuid-leaves.patch.
- commit 677fca7
* Fri Nov 24 2023 nik.borisov@suse.com
- x86: Introduce userspace API for shadow stack (jsc#PED-6018).
- commit e1b906b
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/fpu: Add helper for modifying xstate (jsc#PED-6018).
- commit 84b123e
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/fpu/xstate: Introduce CET MSR and XSAVES supervisor states (jsc#PED-6018).
- commit 5c1ce43
* Fri Nov 24 2023 nik.borisov@suse.com
- Documentation/x86: Add CET shadow stack description (jsc#PED-6018).
- commit db3df55
* Fri Nov 24 2023 nik.borisov@suse.com
- mm: Don't allow write GUPs to shadow stack memory (jsc#PED-6018).
- commit 2df8433
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/mm: Teach pte_mkwrite() about stack memory (jsc#PED-6018).
- commit aa2b115
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/mm: Introduce MAP_ABOVE4G (jsc#PED-6018).
- Refresh patches.suse/x86-Remove-the-arch_calc_vm_prot_bits-macro-from-the-UAPI.patch.
- commit 9d9379d
* Fri Nov 24 2023 nik.borisov@suse.com
- mm/mmap: Add shadow stack pages to memory accounting (jsc#PED-6018).
- commit 1d2d642
* Fri Nov 24 2023 nik.borisov@suse.com
- x86/mm: Warn if create Write=0,Dirty=1 with raw prot (jsc#PED-6018).
- commit f6fee82
* Fri Nov 24 2023 nik.borisov@suse.com
- mm: Warn on shadow stack memory in wrong vma (jsc#PED-6018).
- commit 07bece3
* Fri Nov 24 2023 nik.borisov@suse.com
- mm: Add guard pages around a shadow stack (jsc#PED-6018).
- commit 0d78258
* Fri Nov 24 2023 fcrozat@suse.com
- Ensure ia32_emulation is always enabled for kernel-obs-build
  If ia32_emulation is disabled by default, ensure it is enabled
  back for OBS kernel to allow building 32bit binaries (jsc#PED-3184)
  [ms: Always pass the parameter, no need to grep through the config which
  may not be very reliable]
- commit 56a2c2f
* Fri Nov 24 2023 tiwai@suse.de
- ata: pata_isapnp: Add missing error check for devm_ioport_map()
  (git-fixes).
- HID: fix HID device resource race between HID core and debugging
  support (git-fixes).
- net: usb: ax88179_178a: fix failed operations during
  ax88179_reset (git-fixes).
- commit 4731042
* Thu Nov 23 2023 tiwai@suse.de
- Update config files: fix vanilla config again
- commit 30db8eb
* Thu Nov 23 2023 nik.borisov@suse.com
- x86/mm: Check shadow stack page fault errors (jsc#PED-6018).
- commit 64b7940
* Thu Nov 23 2023 nik.borisov@suse.com
- mm: Introduce VM_SHADOW_STACK for shadow stack memory (jsc#PED-6018).
- commit 6889091
* Thu Nov 23 2023 nik.borisov@suse.com
- x86/mm: Remove _PAGE_DIRTY from kernel RO pages (jsc#PED-6018).
- commit 4155b6a
* Thu Nov 23 2023 nik.borisov@suse.com
- x86/mm: Start actually marking _PAGE_SAVED_DIRTY (jsc#PED-6018).
- commit 806180b
* Thu Nov 23 2023 nik.borisov@suse.com
- x86/mm: Update ptep/pmdp_set_wrprotect() for _PAGE_SAVED_DIRTY (jsc#PED-6018).
- commit 81aee3e
* Thu Nov 23 2023 nik.borisov@suse.com
- x86/mm: Introduce _PAGE_SAVED_DIRTY (jsc#PED-6018).
- commit 72a3b8f
* Thu Nov 23 2023 tbogendoerfer@suse.de
- octeontx2-af: cn10k: Set NIX DWRR MTU for CN10KB silicon
  (jsc#PED-6931).
- Refresh
  patches.suse/page_pool-split-types-and-declarations-from-page_poo.patch.
- commit 9853343
* Thu Nov 23 2023 tbogendoerfer@suse.de
- octeontx2-pf: Free pending and dropped SQEs (jsc#PED-6931).
- octeontx2-pf: Fix holes in error code (jsc#PED-6931).
- octeontx2-pf: Fix error codes (jsc#PED-6931).
- page_pool: remove PP_FLAG_PAGE_FRAG (jsc#PED-6931).
- octeon_ep: assert hardware structure sizes (jsc#PED-6954).
- octeontx2-af: devlink health: use retained error fmsg API
  (jsc#PED-6931).
- octeontx2-af: Enable hardware timestamping for VFs
  (jsc#PED-6931).
- octeontx2-af: replace deprecated strncpy with strscpy
  (jsc#PED-6931).
- net: add DEV_STATS_READ() helper (jsc#PED-6931).
- octeontx2-pf: Tc flower offload support for MPLS (jsc#PED-6931).
- octeon_ep: restructured interrupt handlers (jsc#PED-6954).
- octeon_ep: support to fetch firmware info (jsc#PED-6954).
- octeontx2-pf: Enable PTP PPS output support (jsc#PED-6931).
- octeon_ep: update BQL sent bytes before ringing doorbell
  (jsc#PED-6954).
- octeontx2-pf: Fix page pool frag allocation warning
  (jsc#PED-6931).
- octeontx2-pf: mcs: update PN only when update_pn is true
  (jsc#PED-6931).
- net: macsec: indicate next pn update when offloading
  (jsc#PED-6931).
- octeontx2-pf: Do xdp_do_flush() after redirects (jsc#PED-6931).
- octeon_ep: fix tx dma unmap len values in SG (jsc#PED-6954).
- octeontx2-pf: Fix page pool cache index corruption
  (jsc#PED-6931).
- octeontx2-af: Fix truncation of smq in CN10K NIX AQ enqueue
  mbox handler (jsc#PED-6931).
- Revert "net: macsec: preserve ingress frame ordering"
  (jsc#PED-6931).
- cteonxt2-pf: Fix backpressure config for multiple PFC priorities
  to work simultaneously (jsc#PED-6931).
- octeontx2-af: CN10KB: fix PFC configuration (jsc#PED-6931).
- octeontx2-pf: Fix PFC TX scheduler free (jsc#PED-6931).
- octeontx2-pf: fix page_pool creation fail for rings > 32k
  (jsc#PED-6931).
- octeontx2-af: print error message incase of invalid pf mapping
  (jsc#PED-6931).
- octeontx2-af: Add validation of lmac (jsc#PED-6931).
- octeontx2-af: Don't treat lack of CGX interfaces as error
  (jsc#PED-6931).
- octeontx2-af: CN10KB: Add USGMII LMAC mode (jsc#PED-6931).
- octeontx2-pf: Use PTP HW timestamp counter atomic update feature
  (jsc#PED-6931).
- net: macsec: Use helper functions to update stats
  (jsc#PED-6931).
- octeontx2-pf: Allow both ntuple and TC features on the interface
  (jsc#PED-6931).
- octeon_ep: Add control plane host and firmware versions
  (jsc#PED-6954).
- octeontx2-af: Harden rule validation (jsc#PED-6931).
- octeontx2-af: Remove redundant functions rvu_npc_exact_mac2u64()
  (jsc#PED-6931).
- octeontx2-af: Use u64_to_ether_addr() to convert ethernet
  address (jsc#PED-6931).
- octeontx2-af: Remove redundant functions mac2u64() and cfg2mac()
  (jsc#PED-6931).
- octeontx2-af: TC flower offload support for inner VLAN
  (jsc#PED-6931).
- octeontx2-af: Code restructure to handle TC outer VLAN offload
  (jsc#PED-6931).
- octeontx2: Remove unnecessary ternary operators (jsc#PED-6931).
- octeontx2-pf: TC flower offload support for SPI field
  (jsc#PED-6931).
- tc: flower: Enable offload support IPSEC SPI field
  (jsc#PED-6931).
- net: flow_dissector: Add IPSEC dissector (jsc#PED-6931).
- octeontx2-af: Initialize 'cntr_val' to fix uninitialized symbol
  error (jsc#PED-6931).
- octeontx2-af: Install TC filter rules in hardware based on
  priority (jsc#PED-6931).
- octeontx2-pf: htb offload support for Round Robin scheduling
  (jsc#PED-6931).
- octeontx2-pf: implement transmit schedular allocation algorithm
  (jsc#PED-6931).
- octeontx2-pf: mcs: Generate hash key using ecb(aes)
  (jsc#PED-6931).
- octeon_ep: use vmalloc_array and vcalloc (jsc#PED-6954).
- octeontx2-pf: TC flower offload support for rxqueue mapping
  (jsc#PED-6931).
- octeontx2-af: Set XOFF on other child transmit schedulers
  during SMQ flush (jsc#PED-6931).
- octeontx2-af: add option to toggle DROP_RE enable in rx cfg
  (jsc#PED-6931).
- octeontx2-af: Enable LBK links only when switch mode is on
  (jsc#PED-6931).
- octeontx2-af: extend RSS supported offload types (jsc#PED-6931).
- octeontx2-af: Add devlink option to adjust mcam high prio zone
  entries (jsc#PED-6931).
- net: flow_dissector: add support for cfm packets (jsc#PED-6931).
- octeontx2-pf: Add support for page pool (jsc#PED-6931).
- octeontx2-pf: mcs: Support VLAN in clear text (jsc#PED-6931).
- octeontx2-pf: mcs: Remove unneeded semicolon (jsc#PED-6931).
- octeontx2-pf: ethtool expose qos stats (jsc#PED-6931).
- octeontx2-pf: Add support for HTB offload (jsc#PED-6931).
- octeontx2-pf: Prepare for QOS offload (jsc#PED-6931).
- octeontx2-pf: Refactor schedular queue alloc/free calls
  (jsc#PED-6931).
- octeontx2-pf: qos send queues management (jsc#PED-6931).
- octeontx2-pf: Rename tot_tx_queues to non_qos_queues
  (jsc#PED-6931).
- octeontx2-pf: mcs: Offload extended packet number(XPN) feature
  (jsc#PED-6931).
- net: octeontx2: Use alloc_ordered_workqueue() to create ordered
  workqueues (jsc#PED-6931).
- commit 72b73a0
* Thu Nov 23 2023 nik.borisov@suse.com
- x86/mm: Move pmd_write(), pud_write() up in the file (jsc#PED-6018).
- commit 01f99e3
* Thu Nov 23 2023 nik.borisov@suse.com
- x86/cpufeatures: Add CPU feature flags for shadow stacks (jsc#PED-6018).
- commit de97834
* Thu Nov 23 2023 nik.borisov@suse.com
- x86/traps: Move control protection handler to separate file (jsc#PED-6018).
- commit 8795a47
* Thu Nov 23 2023 nik.borisov@suse.com
- x86/shstk: Add Kconfig option for shadow stack (jsc#PED-6018).
- commit ae7b58e
* Thu Nov 23 2023 nik.borisov@suse.com
- mm: Move VM_UFFD_MINOR_BIT from 37 to 38 (jsc#PED-6018).
- commit 482ef18
* Thu Nov 23 2023 nik.borisov@suse.com
- mm: Re-introduce vm_flags to do_mmap() (jsc#PED-6018).
- commit b4652a8
* Thu Nov 23 2023 nik.borisov@suse.com
- mm: Make pte_mkwrite() take a VMA (jsc#PED-6018).
- commit bb00ef0
* Thu Nov 23 2023 nik.borisov@suse.com
- mm: Move pte/pmd_mkwrite() callers with no VMA to _novma() (jsc#PED-6018).
- commit c09c22f
* Thu Nov 23 2023 nik.borisov@suse.com
- mm: Rename arch pte_mkwrite()'s to pte_mkwrite_novma() (jsc#PED-6018).
- commit 898949c
* Wed Nov 22 2023 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_WSA883X=m for Thinkpad X13s audio (bsc#1217412)
- commit 72eb62b
* Wed Nov 22 2023 nik.borisov@suse.com
- x86/microcode/AMD: Rip out static buffers (jsc#PED-5525).
- Refresh patches.suse/x86-cpu-Fix-amd_check_microcode-declaration.patch.
- commit aca1f5e
* Wed Nov 22 2023 nik.borisov@suse.com
- EDAC/amd64: Add support for AMD family 1Ah models 00h-1Fh and 40h-4Fh (jsc#PED-5524).
- commit f369b43
* Wed Nov 22 2023 nik.borisov@suse.com
- hwmon: (k10temp) Add thermal support for AMD Family 1Ah-based models (jsc#PED-5524).
- commit 76f4f91
* Wed Nov 22 2023 nik.borisov@suse.com
- x86/amd_nb: Add PCI IDs for AMD Family 1Ah-based models (jsc#PED-5524).
- Refresh patches.suse/PCI-Prevent-xHCI-driver-from-claiming-AMD-VanGogh-US.patch.
- commit d4e29d6
* Wed Nov 22 2023 mfranc@suse.cz
- s390/uv: Update query for secret-UVCs (jsc#PED-3289
  jsc#PED-5417).
- s390/uv: replace scnprintf with sysfs_emit (jsc#PED-3289
  jsc#PED-5417).
- s390/uvdevice: Add 'Lock Secret Store' UVC (jsc#PED-3289
  jsc#PED-5417).
- s390/uvdevice: Add 'List Secrets' UVC (jsc#PED-3289
  jsc#PED-5417).
- s390/uvdevice: Add 'Add Secret' UVC (jsc#PED-3289 jsc#PED-5417).
- s390/uvdevice: Add info IOCTL (jsc#PED-3289 jsc#PED-5417).
- s390/uv: Always export uv_info (jsc#PED-3289 jsc#PED-5417).
- commit 278af04
* Wed Nov 22 2023 mfranc@suse.cz
- s390/paes: fix PKEY_TYPE_EP11_AES handling for secure keyblobs
  (git-fixes bsc#1217410).
- commit b3d3c85
* Wed Nov 22 2023 jgross@suse.com
- KVM: SVM: Fix build error when using
  - Werror=unused-but-set-variable (jsc#PED-7322).
- commit 2b98018
* Wed Nov 22 2023 jgross@suse.com
- x86: KVM: SVM: refresh AVIC inhibition in svm_leave_nested()
  (jsc#PED-7322).
- commit ce7c103
* Wed Nov 22 2023 jgross@suse.com
- x86: KVM: SVM: add support for Invalid IPI Vector interception
  (jsc#PED-7322).
- commit ccd8a47
* Wed Nov 22 2023 petr.pavlu@suse.com
- arm64: Prevent misaligned patch-site warnings (bsc#1214934).
  The DYNAMIC_FTRACE_WITH_CALL_OPS optimization uses the compiler option
  - falign-functions=8 with the expectation that functions will get aligned
  on 8-byte boundary. However, GCC treats this option only as a hint and
  in certain situations doesn't align the functions. This then results in
  in warnings about misaligned patch-sites during system boot.
  Unset DYNAMIC_FTRACE_WITH_CALL_OPS for now to prevent these warnings
  until the kernel+GCC have a way to set the needed alignment properly.
  Unfortunately, DYNAMIC_FTRACE_WITH_CALL_OPS cannot be unset only in the
  arm64 config file because the option is promtless and gets automatically
  reset to the value of HAVE_DYNAMIC_FTRACE_WITH_CALL_OPS. Make therefore
  sure the latter is unset first by patching the respective Kconfig.
- commit 0db2d14
* Wed Nov 22 2023 jgross@suse.com
- x86: KVM: SVM: always update the x2avic msr interception
  (jsc#PED-7322).
- commit 7ea5c62
* Wed Nov 22 2023 jgross@suse.com
- KVM: x86: Constrain guest-supported xfeatures only at
  KVM_GET_XSAVE{2} (jsc#PED-7322).
- commit 311b967
* Wed Nov 22 2023 tbogendoerfer@suse.de
- idpf: add SRIOV support and other ndo_ops (jsc#PED-6716).
- Update config files.
- supported.conf: marked idpf as supported
- commit 2317135
* Wed Nov 22 2023 tbogendoerfer@suse.de
- idpf: fix potential use-after-free in idpf_tso() (jsc#PED-6716).
- net: page_pool: add missing free_percpu when page_pool_init fail
  (jsc#PED-6716).
- page_pool: update document about fragment API (jsc#PED-6716).
- page_pool: introduce page_pool_alloc() API (jsc#PED-6716).
- page_pool: unify frag_count handling in page_pool_is_last_frag()
  (jsc#PED-6716).
- idpf: cancel mailbox work in error path (jsc#PED-6716).
- idpf: set scheduling mode for completion queue (jsc#PED-6716).
- page_pool: fragment API support for 32-bit arch with 64-bit DMA
  (jsc#PED-6716).
- idpf: add ethtool callbacks (jsc#PED-6716).
- idpf: add singleq start_xmit and napi poll (jsc#PED-6716).
- idpf: add RX splitq napi poll support (jsc#PED-6716).
- idpf: add TX splitq napi poll support (jsc#PED-6716).
- idpf: add splitq start_xmit (jsc#PED-6716).
- idpf: initialize interrupts and enable vport (jsc#PED-6716).
- idpf: configure resources for RX queues (jsc#PED-6716).
- idpf: configure resources for TX queues (jsc#PED-6716).
- idpf: add ptypes and MAC filter support (jsc#PED-6716).
- idpf: add create vport and netdev configuration (jsc#PED-6716).
- idpf: add core init and interrupt request (jsc#PED-6716).
- idpf: add controlq init and reset checks (jsc#PED-6716).
- idpf: add module register and probe functionality
  (jsc#PED-6716).
- virtchnl: add virtchnl version 2 ops (jsc#PED-6716).
- page_pool: fix documentation typos (jsc#PED-6716).
- docs: net: page_pool: de-duplicate the intro comment
  (jsc#PED-6716).
- page_pool: add a lockdep check for recycling in hardirq
  (jsc#PED-6716).
- page_pool: place frag_* fields in one cacheline (jsc#PED-6716).
- net: skbuff: don't include <net/page_pool/types.h> to
  <linux/skbuff.h> (jsc#PED-6716).
- page_pool: split types and declarations from page_pool.h
  (jsc#PED-6716).
- docs: net: page_pool: use kdoc to avoid duplicating the
  information (jsc#PED-6716).
- net: page_pool: merge page_pool_release_page() with
  page_pool_return_page() (jsc#PED-6716).
- net: page_pool: hide page_pool_release_page() (jsc#PED-6716).
- eth: stmmac: let page recycling happen with skbs (jsc#PED-6716).
- eth: tsnep: let page recycling happen with skbs (jsc#PED-6716).
- commit 7d16fc6
* Wed Nov 22 2023 jgross@suse.com
- x86/fpu: Allow caller to constrain xfeatures when copying to
  uabi buffer (jsc#PED-7322).
- commit 6ec8afd
* Wed Nov 22 2023 jgross@suse.com
- KVM: x86/pmu: Synthesize at most one PMI per VM-exit
  (jsc#PED-7322).
- commit c54b9f9
* Wed Nov 22 2023 jgross@suse.com
- KVM: x86: Mask LVTPC when handling a PMI (jsc#PED-7322).
- commit 38f87fd
* Wed Nov 22 2023 msuchanek@suse.de
- rpm: Define git commit as macro
- commit bcc92c8
* Wed Nov 22 2023 jgross@suse.com
- KVM: x86/pmu: Truncate counter value to allowed width on write
  (jsc#PED-7322).
- commit b3a4bf5
* Wed Nov 22 2023 jgross@suse.com
- x86/sev: Change npages to unsigned long in snp_accept_memory()
  (jsc#PED-7322).
- commit 851ed71
* Wed Nov 22 2023 tiwai@suse.de
- platform/x86/amd: pmc: Use pm_pr_dbg() for suspend related
  messages (bsc#1217382).
- include/linux/suspend.h: Only show pm_pr_dbg messages at
  suspend/resume (bsc#1217382).
- commit e8774c4
* Wed Nov 22 2023 jgross@suse.com
- x86/sev: Use the GHCB protocol when available for SNP CPUID
  requests (jsc#PED-7322).
- commit ed834cf
* Wed Nov 22 2023 msuchanek@suse.de
- kernel-source: Move provides after sources
- commit dbbf742
* Wed Nov 22 2023 jgross@suse.com
- KVM: SVM: Do not use user return MSR support for virtualized
  TSC_AUX (jsc#PED-7322).
- commit 1162f08
* Wed Nov 22 2023 tiwai@suse.de
- Update config files: just refreshing
- commit 2edd057
* Wed Nov 22 2023 tiwai@suse.de
- platform/x86/amd/pmc: adjust getting DRAM size behavior
  (bsc#1217382).
- platform/x86/amd/hsmp: Fix iomem handling (bsc#1217382).
- platform/x86/amd/pmc: Add dump_custom_stb module parameter
  (bsc#1217382).
- platform/x86/amd/pmc: Handle overflow cases where the
  num_samples range is higher (bsc#1217382).
- platform/x86/amd/pmc: Use flex array when calling
  amd_pmc_stb_debugfs_open_v2() (bsc#1217382).
- platform/x86/amd/hsmp: improve the error log (bsc#1217382).
- platform/x86/amd/hsmp: add support for metrics tbl
  (bsc#1217382).
- platform/x86/amd/hsmp: create plat specific struct
  (bsc#1217382).
- platform/x86/amd/pmc: Add PMFW command id to support S2D force
  flush (bsc#1217382).
- platform/x86: Add s2idle quirk for more Lenovo laptops
  (bsc#1217382).
- uapi: stddef.h: Fix header guard location (bsc#1217382).
- platform/x86/amd/pmc: Fix build error with randconfig
  (bsc#1217382).
- platform/x86/amd/pmc: Move PMC driver to separate directory
  (bsc#1217382).
- platform/x86/amd/pmf: Use str_on_off() helper (bsc#1217382).
- Compiler Attributes: counted_by: Adjust name and identifier
  expansion (bsc#1217382).
- platform/x86/amd: pmc: Use release_mem_region() to undo
  request_mem_region_muxed() (bsc#1217382).
- platform/x86/amd: pmf: Add new ACPI ID AMDI0103 (bsc#1217382).
- platform/x86/amd: pmc: Add new ACPI ID AMDI000A (bsc#1217382).
- platform/x86/amd: pmc: Apply nvme quirk to HP 15s-eq2xxx
  (bsc#1217382).
- platform/x86: Move s2idle quirk from thinkpad-acpi to amd-pmc
  (bsc#1217382).
- lib/string_helpers: Split out string_choices.h (bsc#1217382).
- platform/x86/amd: pmc: Update metrics table info for Pink
  Sardine (bsc#1217382).
- platform/x86/amd: pmc: Add helper function to check the cpu id
  (bsc#1217382).
- platform/x86/amd: pmc: Get STB DRAM size from PMFW
  (bsc#1217382).
- platform/x86/amd: pmc: Pass true/false to bool argument
  (bsc#1217382).
- Compiler Attributes: Add __counted_by macro (bsc#1217382).
- commit bc41d9e
* Wed Nov 22 2023 jgross@suse.com
- KVM: x86/mmu: Stop zapping invalidated TDP MMU roots
  asynchronously (jsc#PED-7322).
- commit 885e45c
* Wed Nov 22 2023 jgross@suse.com
- KVM: x86/mmu: Do not filter address spaces in
  for_each_tdp_mmu_root_yield_safe() (jsc#PED-7322).
- commit bc3d564
* Wed Nov 22 2023 jgross@suse.com
- KVM: x86/mmu: Open code leaf invalidation from mmu_notifier
  (jsc#PED-7322).
- commit fa07165
* Wed Nov 22 2023 jgross@suse.com
- KVM: x86/mmu: Use dummy root, backed by zero page, for !visible
  guest roots (jsc#PED-7322).
- commit 1cb5a4a
* Wed Nov 22 2023 jgross@suse.com
- KVM: x86/mmu: Disallow guest from using !visible slots for
  page tables (jsc#PED-7322).
- commit e4de09c
* Wed Nov 22 2023 jgross@suse.com
- KVM: x86/mmu: Harden TDP MMU iteration against root w/o shadow
  page (jsc#PED-7322).
- commit a2abdae
* Wed Nov 22 2023 jgross@suse.com
- KVM: x86/mmu: Harden new PGD against roots without shadow pages
  (jsc#PED-7322).
- commit 81cc556
* Wed Nov 22 2023 jgross@suse.com
- KVM: x86/mmu: Add helper to convert root hpa to shadow page
  (jsc#PED-7322).
- commit 9f5cccc
* Wed Nov 22 2023 jgross@suse.com
- KVM: x86/mmu: Handle KVM bookkeeping in page-track APIs,
  not callers (jsc#PED-7322).
- commit b426979
* Wed Nov 22 2023 jgross@suse.com
- KVM: x86/mmu: Drop @slot param from exported/external page-track
  APIs (jsc#PED-7322).
- commit f60a53a
* Wed Nov 22 2023 jgross@suse.com
- KVM: x86/mmu: Bug the VM if write-tracking is used but not
  enabled (jsc#PED-7322).
- commit 9a0fd92
* Wed Nov 22 2023 jgross@suse.com
- KVM: x86/mmu: Assert that correct locks are held for page
  write-tracking (jsc#PED-7322).
- commit 4c2f351
* Wed Nov 22 2023 jgross@suse.com
- KVM: x86/mmu: Rename page-track APIs to reflect the new reality
  (jsc#PED-7322).
- commit 6294c39
* Wed Nov 22 2023 jgross@suse.com
- KVM: x86/mmu: Drop infrastructure for multiple page-track modes
  (jsc#PED-7322).
- commit f8f8636
* Wed Nov 22 2023 jgross@suse.com
- KVM: x86/mmu: Use page-track notifiers iff there are external
  users (jsc#PED-7322).
- commit 88d749b
* Wed Nov 22 2023 jgross@suse.com
- KVM: x86/mmu: Move KVM-only page-track declarations to internal
  header (jsc#PED-7322).
- commit 890548b
* Wed Nov 22 2023 jgross@suse.com
- KVM: x86: Remove the unused page-track hook track_flush_slot()
  (jsc#PED-7322).
- commit 21fdf4a
* Tue Nov 21 2023 jgross@suse.com
- drm/i915/gvt: switch from ->track_flush_slot() to
  - >track_remove_region() (jsc#PED-7322).
- commit 485ec9a
* Tue Nov 21 2023 jgross@suse.com
- KVM: x86: Add a new page-track hook to handle memslot deletion
  (jsc#PED-7322).
- commit 120d16f
* Tue Nov 21 2023 jgross@suse.com
- drm/i915/gvt: Don't bother removing write-protection on
  to-be-deleted slot (jsc#PED-7322).
- commit ad319bd
* Tue Nov 21 2023 jgross@suse.com
- KVM: x86: Reject memslot MOVE operations if KVMGT is attached
  (jsc#PED-7322).
- commit 07041be
* Tue Nov 21 2023 jgross@suse.com
- KVM: drm/i915/gvt: Drop @vcpu from KVM's ->track_write() hook
  (jsc#PED-7322).
- commit a40a090
* Tue Nov 21 2023 jgross@suse.com
- KVM: x86/mmu: Don't bounce through page-track mechanism for
  guest PTEs (jsc#PED-7322).
- commit 000dab9
* Tue Nov 21 2023 jgross@suse.com
- KVM: x86/mmu: Don't rely on page-track mechanism to flush on
  memslot change (jsc#PED-7322).
- commit df05e91
* Tue Nov 21 2023 ailiop@suse.com
- xfs: allow inode inactivation during a ro mount log recovery
  (git-fixes).
- commit eb5b88b
* Tue Nov 21 2023 jgross@suse.com
- KVM: x86/mmu: Move kvm_arch_flush_shadow_{all,memslot}()
  to mmu.c (jsc#PED-7322).
- commit c587251
* Tue Nov 21 2023 jgross@suse.com
- drm/i915/gvt: Protect gfn hash table with vgpu_lock
  (jsc#PED-7322).
- commit 482fee2
* Tue Nov 21 2023 jgross@suse.com
- drm/i915/gvt: Use an "unsigned long" to iterate over memslot
  gfns (jsc#PED-7322).
- commit 549b1d3
* Tue Nov 21 2023 jgross@suse.com
- drm/i915/gvt: Don't rely on KVM's gfn_to_pfn() to query possible
  2M GTT (jsc#PED-7322).
- commit d9cb58b
* Tue Nov 21 2023 jgross@suse.com
- drm/i915/gvt: Error out on an attempt to shadowing an unknown
  GTT entry type (jsc#PED-7322).
- commit 4212804
* Tue Nov 21 2023 jgross@suse.com
- drm/i915/gvt: Explicitly check that vGPU is attached before
  shadowing (jsc#PED-7322).
- commit 022343b
* Tue Nov 21 2023 jgross@suse.com
- drm/i915/gvt: Don't try to unpin an empty page range
  (jsc#PED-7322).
- commit 206703b
* Tue Nov 21 2023 jgross@suse.com
- drm/i915/gvt: Verify hugepages are contiguous in physical
  address space (jsc#PED-7322).
- commit 6312ded
* Tue Nov 21 2023 jgross@suse.com
- drm/i915/gvt: remove interface intel_gvt_is_valid_gfn
  (jsc#PED-7322).
- commit bea1f04
* Tue Nov 21 2023 jgross@suse.com
- KVM: x86/mmu: BUG() in rmap helpers iff
  CONFIG_BUG_ON_DATA_CORRUPTION=y (jsc#PED-7322).
- commit cf85326
* Tue Nov 21 2023 tiwai@suse.de
- wifi: iwlwifi: mvm: change iwl_mvm_flush_sta() API (git-fixes).
- commit b356cb3
* Tue Nov 21 2023 tiwai@suse.de
- irqchip/gic-v3-its: Flush ITS tables correctly in non-coherent
  GIC designs (git-fixes).
- gve: Fixes for napi_poll when budget is 0 (git-fixes).
- rtc: pcf85363: fix wrong mask/val parameters in
  regmap_update_bits call (git-fixes).
- KEYS: Include linux/errno.h in linux/verification.h (git-fixes).
- hid: cp2112: Fix IRQ shutdown stopping polling for all IRQs
  on chip (git-fixes).
- module/decompress: use kvmalloc() consistently (git-fixes).
- soc: qcom: pmic_glink: fix connector type to be DisplayPort
  (git-fixes).
- soc: qcom: llcc: Handle a second device without data corruption
  (git-fixes).
- clk: renesas: rzg2l: Fix computation formula (git-fixes).
- clk: renesas: rzg2l: Use FIELD_GET() for PLL register fields
  (git-fixes).
- clk: qcom: apss-ipq-pll: Use stromer plus ops for stromer plus
  pll (git-fixes).
- clk: qcom: clk-alpha-pll: introduce stromer plus ops
  (git-fixes).
- hwmon: (sch5627) Disallow write access if virtual registers
  are locked (git-fixes).
- hwmon: (sch5627) Use bit macros when accessing the control
  register (git-fixes).
- spi: omap2-mcspi: Fix hardcoded reference clock (git-fixes).
- spi: omap2-mcspi: switch to use modern name (git-fixes).
- wifi: iwlwifi: mvm: fix netif csum flags (git-fixes).
- wifi: iwlwifi: mvm: fix iwl_mvm_mac_flush_sta() (git-fixes).
- wifi: iwlwifi: mvm: Don't always bind/link the P2P Device
  interface (git-fixes).
- wifi: mt76: fix per-band IEEE80211_CONF_MONITOR flag comparison
  (git-fixes).
- wifi: mt76: get rid of false alamrs of tx emission issues
  (git-fixes).
- wifi: mt76: mt7996: set correct wcid in txp (git-fixes).
- wifi: mt76: remove unused error path in
  mt76_connac_tx_complete_skb (git-fixes).
- wifi: cfg80211: fix kernel-doc for wiphy_delayed_work_flush()
  (git-fixes).
- wifi: iwlwifi: increase number of RX buffers for EHT devices
  (git-fixes).
- wifi: mac80211: move sched-scan stop work to wiphy work
  (git-fixes).
- wifi: mac80211: move offchannel works to wiphy work (git-fixes).
- wifi: mac80211: move scan work to wiphy work (git-fixes).
- wifi: mac80211: move radar detect work to wiphy work
  (git-fixes).
- wifi: cfg80211: add flush functions for wiphy work (git-fixes).
- gve: Use size_add() in call to struct_size() (git-fixes).
- rtc: pcf85363: Allow to wake up system without IRQ (git-fixes).
- HID: cp2112: Make irq_chip immutable (git-fixes).
- wifi: mt76: connac: move connac3 definitions in
  mt76_connac3_mac.h (git-fixes).
- spi: omap2-mcspi: remove redundant dev_err_probe() (git-fixes).
- commit d64fd89
* Tue Nov 21 2023 jgross@suse.com
- KVM: x86/mmu: Plumb "struct kvm" all the way to
  pte_list_remove() (jsc#PED-7322).
- commit 513e4f4
* Tue Nov 21 2023 jgross@suse.com
- KVM: x86/mmu: Use BUILD_BUG_ON_INVALID() for KVM_MMU_WARN_ON()
  stub (jsc#PED-7322).
- commit c9fb2cf
* Tue Nov 21 2023 jgross@suse.com
- KVM: x86/mmu: Replace MMU_DEBUG with proper KVM_PROVE_MMU
  Kconfig (jsc#PED-7322).
- update config
- commit f004b77
* Tue Nov 21 2023 jgross@suse.com
- KVM: x86/mmu: Bug the VM if a vCPU ends up in long mode without
  PAE enabled (jsc#PED-7322).
- commit 7d62f44
* Tue Nov 21 2023 jgross@suse.com
- KVM: x86/mmu: Convert "runtime" WARN_ON() assertions to
  WARN_ON_ONCE() (jsc#PED-7322).
- commit 5ab00fb
* Tue Nov 21 2023 jgross@suse.com
- KVM: x86/mmu: Rename MMU_WARN_ON() to KVM_MMU_WARN_ON()
  (jsc#PED-7322).
- commit a09fb69
* Tue Nov 21 2023 jgross@suse.com
- KVM: x86/mmu: Cleanup sanity check of SPTEs at SP free
  (jsc#PED-7322).
- commit 4bf9e14
* Tue Nov 21 2023 jgross@suse.com
- KVM: x86/mmu: Avoid pointer arithmetic when iterating over SPTEs
  (jsc#PED-7322).
- commit a10cc31
* Tue Nov 21 2023 jgross@suse.com
- KVM: x86/mmu: Delete the "dbg" module param (jsc#PED-7322).
- commit cd5af0a
* Tue Nov 21 2023 jgross@suse.com
- KVM: x86/mmu: Delete rmap_printk() and all its usage
  (jsc#PED-7322).
- commit c0a0a72
* Tue Nov 21 2023 jgross@suse.com
- KVM: x86/mmu: Delete pgprintk() and all its usage
  (jsc#PED-7322).
- commit 33d28b6
* Tue Nov 21 2023 jgross@suse.com
- KVM: x86/mmu: Move the lockdep_assert of mmu_lock to inside
  clear_dirty_pt_masked() (jsc#PED-7322).
- commit 2be22f3
* Tue Nov 21 2023 jgross@suse.com
- KVM: VMX: Delete ancient pr_warn() about KVM_SET_TSS_ADDR not
  being set (jsc#PED-7322).
- commit 45a383f
* Tue Nov 21 2023 ailiop@suse.com
- xfs: abort intent items when recovery intents fail (git-fixes).
- commit 8c58e35
* Tue Nov 21 2023 ailiop@suse.com
- xfs: factor out xfs_defer_pending_abort (git-fixes).
- commit c11ee61
* Tue Nov 21 2023 ailiop@suse.com
- xfs: recovery should not clear di_flushiter unconditionally
  (git-fixes).
- commit 127d2ec
* Tue Nov 21 2023 jgross@suse.com
- KVM: SVM: Require nrips support for SEV guests (and beyond)
  (jsc#PED-7322).
- commit c1ca735
* Tue Nov 21 2023 ailiop@suse.com
- xfs: up(ic_sema) if flushing data device fails (git-fixes).
- commit 7ac0b39
* Tue Nov 21 2023 ailiop@suse.com
- xfs: only remap the written blocks in xfs_reflink_end_cow_extent
  (git-fixes).
- commit e4edf9a
* Tue Nov 21 2023 ailiop@suse.com
- xfs: make sure maxlen is still congruent with prod when rounding
  down (git-fixes).
- commit c4c4007
* Tue Nov 21 2023 ailiop@suse.com
- xfs: fix units conversion error in xfs_bmap_del_extent_delay
  (git-fixes).
- commit 5b9b3d4
* Tue Nov 21 2023 ailiop@suse.com
- xfs: adjust the incore perag block_count when shrinking
  (git-fixes).
- commit d1fc147
* Tue Nov 21 2023 ailiop@suse.com
- xfs: require a relatively recent V5 filesystem for LARP mode
  (git-fixes).
- commit 62ce09a
* Mon Nov 20 2023 ailiop@suse.com
- xfs: reserve less log space when recovering log intent items
  (git-fixes).
- commit 2df5f25
* Mon Nov 20 2023 ailiop@suse.com
- xfs: fix log recovery when unknown rocompat bits are set
  (git-fixes).
- commit 0b95382
* Mon Nov 20 2023 ailiop@suse.com
- xfs: use per-mount cpumask to track nonempty percpu inodegc
  lists (git-fixes).
- commit 85b92c2
* Mon Nov 20 2023 ailiop@suse.com
- xfs: fix per-cpu CIL structure aggregation racing with dying
  cpus (git-fixes).
- commit d1f8099
* Mon Nov 20 2023 ailiop@suse.com
- xfs: fix an agbno overflow in __xfs_getfsmap_datadev
  (git-fixes).
- commit 2369f5b
* Mon Nov 20 2023 ailiop@suse.com
- xfs: fix dqiterate thinko (git-fixes).
- commit d463542
* Mon Nov 20 2023 jgross@suse.com
- KVM: x86: Disallow guest CPUID lookups when IRQs are disabled
  (jsc#PED-7322).
- commit 6bbb6e4
* Mon Nov 20 2023 ailiop@suse.com
- xfs: fix agf_fllast when repairing an empty AGFL (git-fixes).
- commit d00a02c
* Mon Nov 20 2023 jgross@suse.com
- KVM: nSVM: Use KVM-governed feature framework to track "vNMI
  enabled" (jsc#PED-7322).
- commit 574073b
* Mon Nov 20 2023 jgross@suse.com
- KVM: nSVM: Use KVM-governed feature framework to track "vGIF
  enabled" (jsc#PED-7322).
- commit 5f38203
* Mon Nov 20 2023 jgross@suse.com
- KVM: nSVM: Use KVM-governed feature framework to track "Pause
  Filter enabled" (jsc#PED-7322).
- commit ebf0cbb
* Mon Nov 20 2023 jgross@suse.com
- KVM: nSVM: Use KVM-governed feature framework to track "LBRv
  enabled" (jsc#PED-7322).
- commit 71ab721
* Mon Nov 20 2023 ailiop@suse.com
- fs: ocfs2: namei: check return value of ocfs2_add_entry()
  (git-fixes).
- commit 792fc1a
* Mon Nov 20 2023 jgross@suse.com
- KVM: nSVM: Use KVM-governed feature framework to track
  "vVM{SAVE,LOAD} enabled" (jsc#PED-7322).
- commit 3388e7f
* Mon Nov 20 2023 jgross@suse.com
- KVM: nSVM: Use KVM-governed feature framework to track "TSC
  scaling enabled" (jsc#PED-7322).
- commit 9c63e90
* Mon Nov 20 2023 jgross@suse.com
- KVM: nSVM: Use KVM-governed feature framework to track "NRIPS
  enabled" (jsc#PED-7322).
- commit 8449389
* Mon Nov 20 2023 jgross@suse.com
- KVM: nVMX: Use KVM-governed feature framework to track "nested
  VMX enabled" (jsc#PED-7322).
- commit 8ec7550
* Mon Nov 20 2023 jgross@suse.com
- KVM: x86: Use KVM-governed feature framework to track "XSAVES
  enabled" (jsc#PED-7322).
- Refresh
  patches.suse/KVM-SVM-Fix-TSC_AUX-virtualization-setup.patch.
- commit 4542bb1
* Mon Nov 20 2023 jgross@suse.com
- KVM: VMX: Rename XSAVES control to follow KVM's preferred
  "ENABLE_XYZ" (jsc#PED-7322).
- commit 6830ffb
* Mon Nov 20 2023 jgross@suse.com
- KVM: VMX: Check KVM CPU caps, not just VMX MSR support, for
  XSAVE enabling (jsc#PED-7322).
- commit 652e9dd
* Mon Nov 20 2023 jgross@suse.com
- KVM: VMX: Recompute "XSAVES enabled" only after CPUID update
  (jsc#PED-7322).
- commit 16a8f99
* Mon Nov 20 2023 jgross@suse.com
- KVM: x86/mmu: Use KVM-governed feature framework to track
  "GBPAGES enabled" (jsc#PED-7322).
- commit c52c867
* Mon Nov 20 2023 jgross@suse.com
- KVM: x86: Add a framework for enabling KVM-governed x86 features
  (jsc#PED-7322).
- commit 6cced89
* Mon Nov 20 2023 jgross@suse.com
- x86: kvm: x86: Remove unnecessary initial values of variables
  (jsc#PED-7322).
- commit ba5f3e4
* Mon Nov 20 2023 jgross@suse.com
- KVM: VMX: Rename vmx_get_max_tdp_level() to
  vmx_get_max_ept_level() (jsc#PED-7322).
- commit 9fc841c
* Mon Nov 20 2023 jgross@suse.com
- KVM: x86: Remove WARN sanity check on hypervisor timer
  vs. UNINITIALIZED vCPU (jsc#PED-7322).
- commit 987d422
* Mon Nov 20 2023 jgross@suse.com
- KVM: x86: Remove break statements that will never be executed
  (jsc#PED-7322).
- commit 19bb15f
* Mon Nov 20 2023 jgross@suse.com
- KVM: Wrap kvm_{gfn,hva}_range.pte in a per-action union
  (jsc#PED-7322).
- commit 9fcdb4e
* Mon Nov 20 2023 jgross@suse.com
- KVM: arm64: Use kvm_arch_flush_remote_tlbs() (jsc#PED-7322).
- commit 685780b
* Mon Nov 20 2023 jgross@suse.com
- KVM: Move kvm_arch_flush_remote_tlbs_memslot() to common code
  (jsc#PED-7322).
- commit c993bcc
* Mon Nov 20 2023 jgross@suse.com
- KVM: Allow range-based TLB invalidation from common code
  (jsc#PED-7322).
- commit 4179168
* Mon Nov 20 2023 jgross@suse.com
- KVM: Declare kvm_arch_flush_remote_tlbs() globally
  (jsc#PED-7322).
- commit 04da59a
* Sun Nov 19 2023 jgross@suse.com
- KVM: Rename kvm_arch_flush_remote_tlb() to
  kvm_arch_flush_remote_tlbs() (jsc#PED-7322).
- commit 351a707
* Sun Nov 19 2023 jgross@suse.com
- x86/sev: Do not handle #VC for DR7 read/write (jsc#PED-7322).
- commit a9a776c
* Sun Nov 19 2023 jgross@suse.com
- KVM: nSVM: Skip writes to MSR_AMD64_TSC_RATIO if guest state
  isn't loaded (jsc#PED-7322).
- commit 81530d1
* Sun Nov 19 2023 jgross@suse.com
- KVM: x86: Always write vCPU's current TSC offset/ratio in
  vendor hooks (jsc#PED-7322).
- commit 9ad9c95
* Sun Nov 19 2023 jgross@suse.com
- KVM: SVM: Clean up preemption toggling related to
  MSR_AMD64_TSC_RATIO (jsc#PED-7322).
- commit 841dae0
* Sun Nov 19 2023 jgross@suse.com
- KVM: nSVM: Use the "outer" helper for writing multiplier to
  MSR_AMD64_TSC_RATIO (jsc#PED-7322).
- commit e3261fa
* Sun Nov 19 2023 jgross@suse.com
- KVM: x86: Advertise AMX-COMPLEX CPUID to userspace
  (jsc#PED-7322).
- commit 9edc054
* Sun Nov 19 2023 jgross@suse.com
- KVM: VMX: Skip VMCLEAR logic during emergency reboots if
  CR4.VMXE=0 (jsc#PED-7322).
- commit 47a29cf
* Sun Nov 19 2023 jgross@suse.com
- KVM: SVM: Use "standard" stgi() helper when disabling SVM
  (jsc#PED-7322).
- commit dbe2300
* Sun Nov 19 2023 jgross@suse.com
- KVM: x86: Force kvm_rebooting=true during emergency reboot/crash
  (jsc#PED-7322).
- commit 0092171
* Sun Nov 19 2023 jgross@suse.com
- x86/virt: KVM: Move "disable SVM" helper into KVM SVM
  (jsc#PED-7322).
- commit c4273ba
* Sun Nov 19 2023 jgross@suse.com
- KVM: VMX: Ensure CPU is stable when probing basic VMX support
  (jsc#PED-7322).
- commit b977b90
* Sun Nov 19 2023 jgross@suse.com
- KVM: SVM: Check that the current CPU supports SVM in
  kvm_is_svm_supported() (jsc#PED-7322).
- Refresh
  patches.suse/x86-cpu-Clear-SVM-feature-if-disabled-by-BIOS.patch.
- commit 9bada09
* Sun Nov 19 2023 tiwai@suse.de
- Revert "i2c: pxa: move to generic GPIO recovery" (git-fixes).
- commit 0f0ffd2
* Sun Nov 19 2023 jgross@suse.com
- x86/virt: KVM: Open code cpu_has_svm() into
  kvm_is_svm_supported() (jsc#PED-7322).
- Refresh
  patches.suse/x86-cpu-Clear-SVM-feature-if-disabled-by-BIOS.patch.
- commit 48ec546
* Sat Nov 18 2023 jgross@suse.com
- KVM: SVM: Make KVM_AMD depend on CPU_SUP_AMD or CPU_SUP_HYGON
  (jsc#PED-7322).
- commit 14c13bb
* Sat Nov 18 2023 jgross@suse.com
- x86/virt: KVM: Move VMXOFF helpers into KVM VMX (jsc#PED-7322).
- commit e383ee5
* Sat Nov 18 2023 jgross@suse.com
- x86/virt: KVM: Open code cpu_has_vmx() in KVM VMX
  (jsc#PED-7322).
- commit 7d47a34
* Sat Nov 18 2023 jgross@suse.com
- x86/reboot: Expose VMCS crash hooks if and only if
  KVM_{INTEL,AMD} is enabled (jsc#PED-7322).
- commit b8ccd40
* Sat Nov 18 2023 jgross@suse.com
- x86/reboot: Disable virtualization during reboot iff callback
  is registered (jsc#PED-7322).
- commit 51e28f6
* Sat Nov 18 2023 jgross@suse.com
- x86/reboot: Hoist "disable virt" helpers above "emergency
  reboot" path (jsc#PED-7322).
- commit 2ae38a5
* Sat Nov 18 2023 jgross@suse.com
- x86/reboot: KVM: Disable SVM during reboot via virt/KVM reboot
  callback (jsc#PED-7322).
- commit 82d368e
* Sat Nov 18 2023 jgross@suse.com
- x86/reboot: KVM: Handle VMXOFF in KVM's reboot callback
  (jsc#PED-7322).
- commit 74463ec
* Sat Nov 18 2023 jgross@suse.com
- x86/reboot: Harden virtualization hooks for emergency reboot
  (jsc#PED-7322).
- commit 3e513e8
* Sat Nov 18 2023 jgross@suse.com
- x86/reboot: VMCLEAR active VMCSes before emergency reboot
  (jsc#PED-7322).
- commit e3124aa
* Fri Nov 17 2023 jgross@suse.com
- KVM: x86: Retry APIC optimized map recalc if vCPU is
  added/enabled (jsc#PED-7322).
- commit ff5641d
* Fri Nov 17 2023 jgross@suse.com
- KVM: x86/pmu: Move .hw_event_available() check out of PMC
  filter helper (jsc#PED-7322).
- commit 78cfd97
* Fri Nov 17 2023 jgross@suse.com
- KVM: x86/pmu: Require nr fixed_pmc_events to match nr max
  fixed counters (jsc#PED-7322).
- commit 33e7647
* Fri Nov 17 2023 jgross@suse.com
- KVM: x86/pmu: Simplify intel_hw_event_available()
  (jsc#PED-7322).
- commit ae027fa
* Fri Nov 17 2023 jgross@suse.com
- KVM: x86/pmu: Use enums instead of hardcoded magic for arch
  event indices (jsc#PED-7322).
- commit dccb63e
* Fri Nov 17 2023 jgross@suse.com
- KVM: SVM: Use svm_get_lbr_vmcb() helper to handle writes to
  DEBUGCTL (jsc#PED-7322).
- commit fe05910
* Fri Nov 17 2023 jgross@suse.com
- KVM: SVM: Clean up handling of LBR virtualization enabled
  (jsc#PED-7322).
- commit ca10c6d
* Fri Nov 17 2023 jgross@suse.com
- KVM: SVM: Fix dead KVM_BUG() code in LBR MSR virtualization
  (jsc#PED-7322).
- commit a8580a7
* Fri Nov 17 2023 tiwai@suse.de
- ALSA: hda/realtek: Add quirks for HP Laptops (git-fixes).
- ALSA: hda/realtek: Add quirks for ASUS 2024 Zenbooks
  (git-fixes).
- ALSA: hda/realtek: Enable Mute LED on HP 255 G10 (git-fixes).
- ALSA: hda/realtek - Enable internal speaker of ASUS K6500ZC
  (git-fixes).
- ALSA: hda/realtek: Enable Mute LED on HP 255 G8 (git-fixes).
- ALSA: hda/realtek - Add Dell ALC295 to pin fall back table
  (git-fixes).
- commit e078e4b
* Fri Nov 17 2023 jgross@suse.com
- KVM: VMX: Drop manual TLB flush when migrating
  vmcs.APIC_ACCESS_ADDR (jsc#PED-7322).
- commit 9882cc6
* Fri Nov 17 2023 nik.borisov@suse.com
- dmaengine: ioat: Free up __cleanup() name (jsc#PED-7167).
- commit b1b6a91
* Fri Nov 17 2023 jgross@suse.com
- KVM: VMX: Drop unnecessary vmx_fb_clear_ctrl_available "cache"
  (jsc#PED-7322).
- commit c440a2c
* Fri Nov 17 2023 jgross@suse.com
- KVM: x86: Snapshot host's MSR_IA32_ARCH_CAPABILITIES
  (jsc#PED-7322).
- commit aa0df00
* Fri Nov 17 2023 nik.borisov@suse.com
- cleanup: Make no_free_ptr() __must_check (jsc#PED-7167).
- commit 3dd1359
* Fri Nov 17 2023 nik.borisov@suse.com
- locking: Introduce __cleanup() based infrastructure (jsc#PED-7167).
- commit 1036fd2
* Fri Nov 17 2023 nik.borisov@suse.com
- virt: tdx-guest: Add Quote generation support using TSM_REPORTS  (jsc#PED-7167).
- Update config files.
- commit a2c35cc
* Fri Nov 17 2023 nik.borisov@suse.com
- virt: sevguest: Add TSM_REPORTS support for SNP_GET_EXT_REPORT (jsc#PED-7167).
- commit e16a069
* Fri Nov 17 2023 nik.borisov@suse.com
- virt: sevguest: Prep for kernel internal get_ext_report() (jsc#PED-7167).
- commit dc2d8c4
* Fri Nov 17 2023 nik.borisov@suse.com
- configfs-tsm: Introduce a shared ABI for attestation reports (jsc#PED-7167).
- commit bfe5573
* Fri Nov 17 2023 nik.borisov@suse.com
- virt: coco: Add a coco/Makefile and coco/Kconfig (jsc#PED-7167).
- commit 6e8031f
* Fri Nov 17 2023 nik.borisov@suse.com
- virt: sevguest: Fix passing a stack buffer as a scatterlist target (jsc#PED-7167).
- commit 52d5bdb
* Fri Nov 17 2023 nik.borisov@suse.com
- x86/tdx: Mark TSC reliable (jsc#PED-7167).
- commit 8675487
* Fri Nov 17 2023 jgross@suse.com
- KVM: x86: Advertise host CPUID 0x80000005 in
  KVM_GET_SUPPORTED_CPUID (jsc#PED-7322).
- commit 8c9b80c
* Fri Nov 17 2023 jgross@suse.com
- KVM: x86: Remove x86_emulate_ops::guest_has_long_mode
  (jsc#PED-7322).
- commit f5da26c
* Fri Nov 17 2023 jgross@suse.com
- KVM: x86: Use sysfs_emit() instead of sprintf() (jsc#PED-7322).
- commit e7d27fe
* Fri Nov 17 2023 jgross@suse.com
- KVM: SVM: Don't try to pointlessly single-step SEV-ES guests
  for NMI window (jsc#PED-7322).
- commit cac6d67
* Fri Nov 17 2023 vkarasulli@suse.de
- ravb: Fix use-after-free issue in ravb_tx_timeout_work()
  (bsc#1212514 CVE-2023-35827).
- ravb: Fix up dma_free_coherent() call in ravb_remove()
  (bsc#1212514 CVE-2023-35827).
- commit e41ee33
* Fri Nov 17 2023 jgross@suse.com
- KVM: SEV-ES: Eliminate #DB intercept when DebugSwap enabled
  (jsc#PED-7322).
- commit 5d193a3
* Fri Nov 17 2023 jgross@suse.com
- KVM: SEV: Enable data breakpoints in SEV-ES (jsc#PED-7322).
- commit dc5754f
* Fri Nov 17 2023 jgross@suse.com
- KVM: SVM/SEV/SEV-ES: Rework intercepts (jsc#PED-7322).
- Refresh
  patches.suse/KVM-SVM-Fix-TSC_AUX-virtualization-setup.patch.
- commit cd7fccd
* Fri Nov 17 2023 jgross@suse.com
- KVM: SEV-ES: explicitly disable debug (jsc#PED-7322).
- commit 33a326d
* Fri Nov 17 2023 jgross@suse.com
- KVM: SVM: Rewrite sev_es_prepare_switch_to_guest()'s comment
  about swap types (jsc#PED-7322).
- commit 3bb9fda
* Fri Nov 17 2023 tzimmermann@suse.com
- drm/vmwgfx: Keep a gem reference to user bos in surfaces (CVE-2023-5633, bsc#1216527)
- commit d4cf539
* Fri Nov 17 2023 tiwai@suse.de
- i2c: i801: Add support for Intel Birch Stream SoC (jsc#PED-6040
  jsc#PED-6048).
- commit 54e234b
* Fri Nov 17 2023 tiwai@suse.de
- Update patch reference for SPI patch (jsc#PED-6040 jsc#PED-6048)
- commit e9cca4e
* Fri Nov 17 2023 jgross@suse.com
- KVM: SEV: Move SEV's GP_VECTOR intercept setup to SEV
  (jsc#PED-7322).
- commit 289d0b4
* Fri Nov 17 2023 jgross@suse.com
- KVM: SEV: move set_dr_intercepts/clr_dr_intercepts from the
  header (jsc#PED-7322).
- commit e5993c1
* Thu Nov 16 2023 tiwai@suse.de
- Update config files: fix build breakage of vanilla flavors
- commit d1c18a5
* Thu Nov 16 2023 mhocko@suse.com
- Update
  patches.suse/vringh-don-t-use-vringh_kiov_advance-in-vringh_iov_x.patch
  (git-fixes, bsc#1215710, CVE-2023-5158).
- commit 28b6595
* Thu Nov 16 2023 jgross@suse.com
- KVM: VMX: Use vmread_error() to report VM-Fail in "goto" path
  (jsc#PED-7322).
- commit 6e729ae
* Thu Nov 16 2023 mgorman@suse.de
- mm/page_alloc: remove unnecessary next_page in
  break_down_buddy_pages (bsc#1212886 (MM functional and
  performance backports)).
- mm/page_alloc: remove unnecessary check in
  break_down_buddy_pages (bsc#1212886 (MM functional and
  performance backports)).
- mm/compaction: factor out code to test if we should run
  compaction for target order (bsc#1212886 (MM functional and
  performance backports)).
- mm/compaction: improve comment of is_via_compact_memory
  (bsc#1212886 (MM functional and performance backports)).
- mm/compaction: remove repeat compact_blockskip_flush check
  in reset_isolation_suitable (bsc#1212886 (MM functional and
  performance backports)).
- mm/compaction: correctly return failure with bogus
  compound_order in strict mode (bsc#1212886 (MM functional and
  performance backports)).
- mm/compaction: call list_is_{first}/{last} more intuitively
  in move_freelist_{head}/{tail} (bsc#1212886 (MM functional
  and performance backports)).
- mm/compaction: use correct list in move_freelist_{head}/{tail}
  (bsc#1212886 (MM functional and performance backports)).
- cpufreq: Rebuild sched-domains when removing cpufreq driver
  (bsc#1212887 (Scheduler functional and performance backports)).
- cpufreq: schedutil: Merge initialization code of sg_cpu in
  single loop (bsc#1212887 (Scheduler functional and performance
  backports)).
- sched/fair: Remove SIS_PROP (bsc#1184587, bsc#1212887 (Scheduler
  functional and performance backports)).
- sched/fair: Use candidate prev/recent_used CPU if scanning
  failed for cluster wakeup (bsc#1184587, bsc#1212887 (Scheduler
  functional and performance backports)).
- sched/fair: Scan cluster before scanning LLC in wake-up path
  (bsc#1184587, bsc#1212887 (Scheduler functional and performance
  backports)).
- sched: Add cpus_share_resources API (bsc#1184587, bsc#1212887
  (Scheduler functional and performance backports)).
- sched/nohz: Update comments about NEWILB_KICK (bsc#1212887
  (Scheduler functional and performance backports)).
- sched/fair: Remove duplicate #include (bsc#1212887 (Scheduler
  functional and performance backports)).
- =?UTF-8?q?sched/psi:=20Update=20poll=20=3D>=20rtpoll=20in?=
  =?UTF-8?q?=20relevant=C2=A0comments?= (bsc#1212887 (Scheduler
  functional and performance backports)).
- sched: Make PELT acronym definition searchable (bsc#1212887
  (Scheduler functional and performance backports)).
- sched: Fix stop_one_cpu_nowait() vs hotplug (bsc#1212887
  (Scheduler functional and performance backports)).
- sched/psi: Bail out early from irq time accounting (bsc#1212887
  (Scheduler functional and performance backports)).
- sched/topology: Move the declaration of 'schedutil_gov' to
  kernel/sched/sched.h (bsc#1212887 (Scheduler functional and
  performance backports)).
- sched/topology: Change behaviour of the 'sched_energy_aware'
  sysctl, based on the platform (bsc#1212887 (Scheduler functional
  and performance backports)).
- sched/topology: Remove the EM_MAX_COMPLEXITY limit (bsc#1212887
  (Scheduler functional and performance backports)).
- sched/topology: Consolidate and clean up access to a CPU's
  max compute capacity (bsc#1184587, bsc#1212887 (Scheduler
  functional and performance backports)).
- sched/core: Update stale comment in try_to_wake_up()
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/debug: Add new tracepoint to track compute energy
  computation (bsc#1212887 (Scheduler functional and performance
  backports)).
- sched/uclamp: Ignore (util == 0) optimization in feec()
  when p_util_max = 0 (bsc#1213179 (PREEMPT_RT functional and
  performance backports)).
- sched/uclamp: Set max_spare_cap_cpu even if max_spare_cap is 0
  (bsc#1213179 (PREEMPT_RT functional and performance backports)).
- sched/debug: Avoid checking in_atomic_preempt_off() twice
  in schedule_debug() (bsc#1212887 (Scheduler functional and
  performance backports)).
- sched/fair: Rename check_preempt_curr() to wakeup_preempt()
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/fair: Rename check_preempt_wakeup() to
  check_preempt_wakeup_fair() (bsc#1212887 (Scheduler functional
  and performance backports)).
- sched/headers: Remove duplicated includes in
  kernel/sched/sched.h (bsc#1212887 (Scheduler functional and
  performance backports)).
- freezer,sched: Use saved_state to reduce some spurious wakeups
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/core: Remove ifdeffery for saved_state (bsc#1212887
  (Scheduler functional and performance backports)).
- mm/page_alloc: correct start page when guard page debug is
  enabled (bsc#1212886 (MM functional and performance backports)).
- cpufreq: schedutil: Update next_freq when cpufreq_limits change
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/rt: Fix live lock between select_fallback_rq() and RT push
  (bsc#1213179 (PREEMPT_RT functional and performance backports)).
- mm/compaction: remove unused parameter pgdata of
  fragmentation_score_wmark (bsc#1212886 (MM functional and
  performance backports)).
- mm/page_alloc: remove unnecessary parameter batch of nr_pcp_free
  (bsc#1212886 (MM functional and performance backports)).
- mm/page_alloc: remove track of active PCP lists range in bulk
  free (bsc#1212886 (MM functional and performance backports)).
- mm/page_alloc: avoid unneeded alike_pages calculation
  (bsc#1212886 (MM functional and performance backports)).
- commit 41dc481
* Thu Nov 16 2023 jgross@suse.com
- KVM: VMX: Make VMREAD error path play nice with noinstr
  (jsc#PED-7322).
- commit bdf4743
* Thu Nov 16 2023 jgross@suse.com
- KVM: x86/irq: Conditionally register IRQ bypass consumer again
  (jsc#PED-7322).
- commit 0b61d3f
* Thu Nov 16 2023 jgross@suse.com
- KVM: X86: Use GFP_KERNEL_ACCOUNT for pid_table in ipiv
  (jsc#PED-7322).
- commit db6111a
* Thu Nov 16 2023 jgross@suse.com
- KVM: x86: check the kvm_cpu_get_interrupt result before using it
  (jsc#PED-7322).
- commit 748ea0b
* Thu Nov 16 2023 jgross@suse.com
- KVM: x86: VMX: set irr_pending in kvm_apic_update_irr
  (jsc#PED-7322).
- commit bb7e9f2
* Thu Nov 16 2023 jgross@suse.com
- KVM: x86: VMX: __kvm_apic_update_irr must update the IRR
  atomically (jsc#PED-7322).
- commit 7d7f61c
* Thu Nov 16 2023 jgross@suse.com
- KVM: x86: Remove PRIx* definitions as they are solely for user
  space (jsc#PED-7322).
- commit d9a47ed
* Thu Nov 16 2023 jgross@suse.com
- KVM: SVM: WARN, but continue, if misc_cg_set_capacity() fails
  (jsc#PED-7322).
- commit 8bf89b7
* Thu Nov 16 2023 jgross@suse.com
- KVM: x86/mmu: Add "never" option to allow sticky disabling of
  nx_huge_pages (jsc#PED-7322).
- commit ab03076
* Thu Nov 16 2023 jgross@suse.com
- KVM: x86: Update comments about MSR lists exposed to userspace
  (jsc#PED-7322).
- commit 1507087
* Thu Nov 16 2023 jgross@suse.com
- KVM: x86/cpuid: Add AMD CPUID ExtPerfMonAndDbg leaf 0x80000022
  (jsc#PED-7322).
- Refresh patches.suse/x86-srso-Add-SRSO_NO-support.patch.
- commit 68fcef6
* Thu Nov 16 2023 jgross@suse.com
- KVM: x86/svm/pmu: Add AMD PerfMonV2 support (jsc#PED-7322).
- commit 13a75fa
* Thu Nov 16 2023 jgross@suse.com
- KVM: x86/cpuid: Add a KVM-only leaf to redirect AMD PerfMonV2
  flag (jsc#PED-7322).
- commit e5d63c4
* Thu Nov 16 2023 jgross@suse.com
- KVM: x86/pmu: Constrain the num of guest counters with
  kvm_pmu_cap (jsc#PED-7322).
- commit 69969fd
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86/pmu: Advertise PERFCTR_CORE iff the min nr of counters
  is met (jsc#PED-7322).
- commit 6edee2c
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86/pmu: Disable vPMU if the minimum num of counters
  isn't met (jsc#PED-7322).
- commit 199733e
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86: Explicitly zero cpuid "0xa" leaf when PMU is disabled
  (jsc#PED-7322).
- commit ab5f3e4
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86/pmu: Provide Intel PMU's pmc_is_enabled() as generic
  x86 code (jsc#PED-7322).
- commit fdb8fa6
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86/pmu: Move handling PERF_GLOBAL_CTRL and friends to
  common x86 (jsc#PED-7322).
- commit 8fd326a
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86/pmu: Reject userspace attempts to set reserved
  GLOBAL_STATUS bits (jsc#PED-7322).
- commit f4f31af
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86/pmu: Move reprogram_counters() to pmu.h (jsc#PED-7322).
- commit 6ed2f9e
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86/pmu: Rename global_ovf_ctrl_mask to global_status_mask
  (jsc#PED-7322).
- commit b6e40eb
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86: Clean up: remove redundant bool conversions
  (jsc#PED-7322).
- commit c6ebf77
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86: Use cpu_feature_enabled() for PKU instead of #ifdef
  (jsc#PED-7322).
- commit 77c31a2
* Wed Nov 15 2023 jgross@suse.com
- KVM: Clean up kvm_vm_ioctl_create_vcpu() (jsc#PED-7322).
- commit f204490
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86/mmu: Trigger APIC-access page reload iff vendor code
  cares (jsc#PED-7322).
- commit 9906ec2
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86: Use standard mmu_notifier invalidate hooks for APIC
  access page (jsc#PED-7322).
- commit f5d1e35
* Wed Nov 15 2023 jgross@suse.com
- KVM: VMX: Retry APIC-access page reload if invalidation is
  in-progress (jsc#PED-7322).
- commit c5d63a5
* Wed Nov 15 2023 tiwai@suse.de
- ASoC: cs35l41: Use modern pm_ops (bsc#1213745).
- ASoC: cs35l41: Make use of dev_err_probe() (bsc#1213745).
- commit 057e20a
* Wed Nov 15 2023 tiwai@suse.de
- Update patch reference for ALSA fixes (bsc#1213745)
- commit ecf4282
* Wed Nov 15 2023 jgross@suse.com
- KVM: SVM: enhance info printk's in SEV init (jsc#PED-7322).
- commit 4cb4282
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86: Correct the name for skipping VMENTER l1d flush
  (jsc#PED-7322).
- commit 13e86f3
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86: Update number of entries for KVM_GET_CPUID2 on
  success, not failure (jsc#PED-7322).
- commit a353e10
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86/pmu: Remove redundant check for MSR_IA32_DS_AREA set
  handler (jsc#PED-7322).
- commit 12ad0a7
* Wed Nov 15 2023 dwagner@suse.de
- config: enable tls for nvme-tcp (bsc#1193201)
  Enable CONFIG_NVME_TCP_TLS and CONFIG_NVME_TARGET_TCP_TLS
  Update config files:
  config/arm64/default
  config/armv7hl/default
  config/ppc64le/default
  config/s390x/default
  config/x86_64/default
- commit 96f0023
* Wed Nov 15 2023 dwagner@suse.de
- security/keys: export key_lookup() (bsc#1193203 jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- commit 463e716
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86: Fix poll command (jsc#PED-7322).
- commit 54c1199
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86: Move common handling of PAT MSR writes to
  kvm_set_msr_common() (jsc#PED-7322).
- commit d7b3999
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86: Make kvm_mtrr_valid() static now that there are no
  external users (jsc#PED-7322).
- commit a22909f
* Wed Nov 15 2023 dwagner@suse.de
- nvme-tcp: enable TLS handshake upcall (bsc#1193203 jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
  Disable CONFIG_NVME_TCP_TLS for the time being, because
  there is a bug in Kconfig which is fixed later on.
  Refresh:
  - patches.suse/nvme-tcp-add-recovery_delay-to-sysfs.patch
  Update:
  config/arm64/default
  config/armv7hl/default
  config/ppc64le/default
  config/s390x/default
  config/s390x/zfcpdump
  config/x86_64/default
- commit 5e8fdaa
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86: Move PAT MSR handling out of mtrr.c (jsc#PED-7322).
- commit 4901174
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86: Use MTRR macros to define possible MTRR MSR ranges
  (jsc#PED-7322).
- commit bef7bcd
* Wed Nov 15 2023 ohering@suse.de
- hv_netvsc: fix netvsc_send_completion to avoid multiple message
  length checks (git-fixes).
- commit 5c686ef
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86: Add helper to get variable MTRR range from MSR index
  (jsc#PED-7322).
- commit c0ff7be
* Wed Nov 15 2023 dwagner@suse.de
- nvme: keyring: fix conditional compilation (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: common: make keyring and auth separate modules
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: start keep-alive after admin queue setup (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-loop: always quiesce and cancel commands before destroying
  admin q (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-tcp: avoid open-coding nvme_tcp_teardown_admin_queue()
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-auth: always set valid seq_num in dhchap reply
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-auth: add flag for bi-directional auth (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-auth: auth success1 msg always includes resp (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-tcp: Fix a memory leak (jsc#PED-6252 jsc#PED-5728
  jsc#PED-5062 jsc#PED-3535).
- nvme-auth: use crypto_shash_tfm_digest() (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-auth: allow mixing of secret and hash lengths (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-auth: use transformed key size to create resp (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-auth: alloc nvme_dhchap_key as single buffer (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvmet-tcp: use 'spin_lock_bh' for state_lock() (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: rework NVME_AUTH Kconfig selection (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
  Update:
  config/arm64/default
  config/armv7hl/default
  config/ppc64le/default
  config/s390x/default
  config/x86_64/default
- nvmet-tcp: peek icreq before starting TLS (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvmet-tcp: control messages for recvmsg() (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvmet-tcp: enable TLS handshake upcall (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
  Disable CONFIG_NVME_TARGET_TCP_TLS for the time being, because
  there is a bug in Kconfig which is fixed later on.
  Update:
  config/arm64/default
  config/armv7hl/default
  config/ppc64le/default
  config/s390x/default
  config/s390x/zfcpdump
  config/x86_64/default
  - --
- nvmet: Set 'TREQ' to 'required' when TLS is enabled
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvmet-tcp: allocate socket file (jsc#PED-6252 jsc#PED-5728
  jsc#PED-5062 jsc#PED-3535).
- nvmet-tcp: make nvmet_tcp_alloc_queue() a void function
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvmet: make TCP sectype settable via configfs (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-fabrics: parse options 'keyring' and 'tls_key'
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
  Refresh:
  - patches.suse/nvme-tcp-add-recovery_delay-to-sysfs.patch
- nvme-tcp: improve icreq/icresp logging (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-tcp: control message handling for recvmsg() (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-tcp: allocate socket file (jsc#PED-6252 jsc#PED-5728
  jsc#PED-5062 jsc#PED-3535).
- nvme-keyring: implement nvme_tls_psk_default() (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-tcp: add definitions for TLS cipher suites (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: add TCP TSAS definitions (jsc#PED-6254 jsc#PED-5728
  jsc#PED-5062 jsc#PED-3535).
  Move patches.suse/0012-nvme-add-TCP-TSAS-definitions.patch
  to sorted section.
- nvme-keyring: define a 'psk' keytype (jsc#PED-6252 jsc#PED-5728
  jsc#PED-5062 jsc#PED-3535).
- nvme-keyring: register '.nvme' keyring (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-pci: add BOGUS_NID for Intel 0a54 device (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvmet-auth: complete a request only after freeing the dhchap
  pointers (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: sanitize metadata bounce buffer for reads (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-auth: use chap->s2 to indicate bidirectional authentication
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-rdma: do not try to stop unallocated queues (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: avoid bogus CRTO values (jsc#PED-6252 jsc#PED-5728
  jsc#PED-5062 jsc#PED-3535).
- nvme-pci: do not set the NUMA node of device if it has none
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: host: hwmon: constify pointers to hwmon_channel_info
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- net/handshake: Trace events for TLS Alert helpers (bsc#1193203
  jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- SUNRPC: Use new helpers to handle TLS Alerts (bsc#1193203
  jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- net/handshake: Add helpers for parsing incoming TLS Alerts
  (bsc#1193203 jsc#PED-6252 jsc#PED-5728 jsc#PED-5062
  jsc#PED-3535).
- SUNRPC: Send TLS Closure alerts before closing a TCP
  socket (bsc#1193203 jsc#PED-6252 jsc#PED-5728 jsc#PED-5062
  jsc#PED-3535).
- net/handshake: Add API for sending TLS Closure alerts
  (bsc#1193203 jsc#PED-6252 jsc#PED-5728 jsc#PED-5062
  jsc#PED-3535).
- net/tls: Add TLS Alert definitions (bsc#1193203 jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- net/tls: Move TLS protocol elements to a separate header
  (bsc#1193203 jsc#PED-6252 jsc#PED-5728 jsc#PED-5062
  jsc#PED-3535).
- scsi: nvme: zns: Set zone limits before revalidating zones
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: ensure disabling pairs with unquiesce (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-fc: fix race between error recovery and creating
  association (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062
  jsc#PED-3535).
- nvme-fc: return non-zero status code when fails to create
  association (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062
  jsc#PED-3535).
- nvme: fix parameter check in nvme_fault_inject_init()
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: warn only once for legacy uuid attribute (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvmet: use PAGE_SECTORS_SHIFT (jsc#PED-6252 jsc#PED-5728
  jsc#PED-5062 jsc#PED-3535).
- nvme: add BOGUS_NID quirk for Samsung SM953 (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
  Refresh:
  - patches.suse/nvme-pci-add-NVME_QUIRK_BOGUS_NID-for-Samsung-.patch
- nvme: disable controller on reset state failure (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: sync timeout work on failed reset (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: ensure unquiesce on teardown (jsc#PED-6252 jsc#PED-5728
  jsc#PED-5062 jsc#PED-3535).
- nvme-mpath: fix I/O failure with EAGAIN when failing over I/O
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: host: fix command name spelling (jsc#PED-6252 jsc#PED-5728
  jsc#PED-5062 jsc#PED-3535).
- nvmet: Reorder fields in 'struct nvmet_ns' (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: Print capabilities changes just once (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- NFS: Add an "xprtsec=" NFS mount option (bsc#1193203
  jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- NFS: Have struct nfs_client carry a TLS policy field
  (bsc#1193203 jsc#PED-6252 jsc#PED-5728 jsc#PED-5062
  jsc#PED-3535).
- SUNRPC: Add a TCP-with-TLS RPC transport class (bsc#1193203
  jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- SUNRPC: Capture CMSG metadata on client-side receive
  (bsc#1193203 jsc#PED-6252 jsc#PED-5728 jsc#PED-5062
  jsc#PED-3535).
- SUNRPC: Ignore data_ready callbacks during TLS handshakes
  (bsc#1193203 jsc#PED-6252 jsc#PED-5728 jsc#PED-5062
  jsc#PED-3535).
- SUNRPC: Add RPC client support for the RPC_AUTH_TLS auth
  flavor (bsc#1193203 jsc#PED-6252 jsc#PED-5728 jsc#PED-5062
  jsc#PED-3535).
- SUNRPC: Trace the rpc_create_args (bsc#1193203 jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- SUNRPC: Plumb an API for setting transport layer security
  (bsc#1193203 jsc#PED-6252 jsc#PED-5728 jsc#PED-5062
  jsc#PED-3535).
- NFS: Improvements for fs_context-related tracepoints
  (#bsc#1193203 jsc#PED-6252 jsc#PED-5728 jsc#PED-5062
  jsc#PED-3535).
- nvme: forward port sysfs delete fix (jsc#PED-6252 jsc#PED-5728
  jsc#PED-5062 jsc#PED-3535).
- nvme: skip optional id ctrl csi if it failed (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-core: use nvme_ns_head_multipath instead of ns->head->disk
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvmet-fcloop: Do not wait on completion when unregister fails
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-fabrics: open code __nvmf_host_find() (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-fabrics: error out to unlock the mutex (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: Increase block size variable size to 32-bit (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-fcloop: no need to return from void function (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvmet-auth: remove unnecessary break after goto (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvmet-auth: remove some dead code (jsc#PED-6252 jsc#PED-5728
  jsc#PED-5062 jsc#PED-3535).
- nvme-core: remove redundant check from nvme_init_ns_head
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: move sysfs code to a dedicated sysfs.c file (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
  Refresh:
  - patches.suse/nvme-Move-pr-code-to-it-s-own-file.patch
  - patches.suse/nvme-tcp-add-recovery_delay-to-sysfs.patch
- nvme-fabrics: prevent overriding of existing host (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-fabrics: check hostid using uuid_equal (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-fabrics: unify common code in admin and io queue connect
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvmet: reorder fields in 'struct nvmefc_fcp_req' (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvmet: reorder fields in 'struct nvme_dhchap_queue_context'
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvmet: reorder fields in 'struct nvmf_ctrl_options'
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme: reorder fields in 'struct nvme_ctrl' (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvmet: reorder fields in 'struct nvmet_sq' (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-fabrics: add queue setup helpers (jsc#PED-6252 jsc#PED-5728
  jsc#PED-5062 jsc#PED-3535).
- nvme-pci: cleaning up nvme_pci_init_request (jsc#PED-6252
  jsc#PED-5728 jsc#PED-5062 jsc#PED-3535).
- nvme-rdma: fix typo in comment (jsc#PED-6252 jsc#PED-5728
  jsc#PED-5062 jsc#PED-3535).
- commit 262d1d0
* Wed Nov 15 2023 jgross@suse.com
- KVM: x86: Add helper to query if variable MTRR MSR is base
  (versus mask) (jsc#PED-7322).
- commit 4ecc863
* Wed Nov 15 2023 jgross@suse.com
- KVM: SVM: Use kvm_pat_valid() directly instead of
  kvm_mtrr_valid() (jsc#PED-7322).
- commit f7f75bb
* Wed Nov 15 2023 iivanov@suse.de
- arm64: dts: imx: Add imx8mm-prt8mm.dtb to build (git-fixes)
- commit 736bf94
* Wed Nov 15 2023 iivanov@suse.de
- arm64: cpufeature: Fix CLRBHB and BC detection (git-fixes)
- commit b4172c3
* Wed Nov 15 2023 jgross@suse.com
- KVM: VMX: Open code writing vCPU's PAT in VMX's MSR handler
  (jsc#PED-7322).
- commit cd1aca0
* Wed Nov 15 2023 jgross@suse.com
- KVM: allow KVM_BUG/KVM_BUG_ON to handle 64-bit cond
  (jsc#PED-7322).
- commit 87f7261
* Tue Nov 14 2023 jgross@suse.com
- KVM: VMX: Use proper accessor to read guest CR4 in handle_desc()
  (jsc#PED-7322).
- commit c112bd5
* Tue Nov 14 2023 jgross@suse.com
- KVM: VMX: Move the comment of CR4.MCE handling right above
  the code (jsc#PED-7322).
- Refresh
  patches.suse/KVM-VMX-Don-t-fudge-CR0-and-CR4-for-restricted-.patch.
- commit d949c89
* Tue Nov 14 2023 jgross@suse.com
- KVM: VMX: Treat UMIP as emulated if and only if the host
  doesn't have UMIP (jsc#PED-7322).
- commit f14c556
* Tue Nov 14 2023 jgross@suse.com
- KVM: VMX: Use kvm_read_cr4() to get cr4 value (jsc#PED-7322).
- commit 8066ed9
* Tue Nov 14 2023 jgross@suse.com
- KVM: x86/mmu: Assert on @mmu in the __kvm_mmu_invalidate_addr()
  (jsc#PED-7322).
- commit a4b8f0e
* Tue Nov 14 2023 jgross@suse.com
- KVM: x86/mmu: Add comment on try_cmpxchg64 usage in
  tdp_mmu_set_spte_atomic (jsc#PED-7322).
- commit acb7b2c
* Tue Nov 14 2023 mkoutny@suse.com
- cgroup: Remove duplicates in cgroup v1 tasks file (bsc#1211307).
- commit ae63067
* Tue Nov 14 2023 jgross@suse.com
- x86/sev: Get rid of special sev_es_enable_key (jsc#PED-7322).
- commit 55f727d
* Tue Nov 14 2023 jgross@suse.com
- x86/coco: Mark cc_platform_has() and descendants noinstr
  (jsc#PED-7322).
- Refresh
  patches.suse/msft-hv-2822-x86-coco-Get-rid-of-accessor-functions.patch.
- commit 706e3c1
* Tue Nov 14 2023 mfranc@suse.cz
- s390/ap: re-init AP queues on config on (git-fixes bsc#1217132).
- commit bbbdea7
* Tue Nov 14 2023 dwagner@suse.de
- scsi: lpfc: Update lpfc version to 14.2.0.15 (bsc#1217124
  jsc#PED-6252 jsc#PED-5728).
- scsi: lpfc: Introduce LOG_NODE_VERBOSE messaging flag
  (bsc#1217124 jsc#PED-6252 jsc#PED-5728).
- scsi: lpfc: Validate ELS LS_ACC completion payload (bsc#1217124
  jsc#PED-6252 jsc#PED-5728).
- scsi: lpfc: Reject received PRLIs with only initiator fcn role
  for NPIV ports (bsc#1217124 jsc#PED-6252 jsc#PED-5728).
- scsi: lpfc: Treat IOERR_SLI_DOWN I/O completion status the
  same as pci offline (bsc#1217124 jsc#PED-6252 jsc#PED-5728).
- scsi: lpfc: Remove unnecessary zero return code assignment in
  lpfc_sli4_hba_setup (bsc#1217124 jsc#PED-6252 jsc#PED-5728).
- scsi: lpfc: Prevent use-after-free during rmmod with mapped
  NVMe rports (bsc#1217124 jsc#PED-6252 jsc#PED-5728).
- scsi: lpfc: Early return after marking final NLP_DROPPED flag
  in dev_loss_tmo (bsc#1217124 jsc#PED-6252 jsc#PED-5728).
- commit 6aad84d
* Tue Nov 14 2023 dwagner@suse.de
- Update
  patches.suse/scsi-qla2xxx-Update-version-to-10.02.09.100-k.patch
  (bsc#1214928 jsc#PED-5063 jsc#PED-6878 jsc#PED-6252
  jsc#PED-5728).
- commit 4fc35e1
* Tue Nov 14 2023 tonyj@suse.de
- powerpc/perf/hv-24x7: Update domain value check (bsc#1215931).
- commit e9c382b
* Tue Nov 14 2023 nik.borisov@suse.com
- Documentation/x86: Document resctrl's new sparse_masks (jsc#PED-6016).
- commit b5bd5e7
* Tue Nov 14 2023 nik.borisov@suse.com
- x86/resctrl: Add sparse_masks file in info (jsc#PED-6016).
- commit 503e62f
* Tue Nov 14 2023 nik.borisov@suse.com
- x86/resctrl: Enable non-contiguous CBMs in Intel CAT (jsc#PED-6016).
- commit c9afc8e
* Tue Nov 14 2023 nik.borisov@suse.com
- x86/resctrl: Rename arch_has_sparse_bitmaps (jsc#PED-6016).
- commit 988a4aa
* Mon Nov 13 2023 mfranc@suse.cz
- s390/cmma: fix handling of swapper_pg_dir and invalid_pg_dir
  (LTC#203998 bsc#1217090).
- commit 4781bdc
* Mon Nov 13 2023 mfranc@suse.cz
- s390/cmma: fix detection of DAT pages (LTC#203998 bsc#1217090).
- commit 9f7f14f
* Mon Nov 13 2023 mfranc@suse.cz
- s390/mm: add missing arch_set_page_dat() call to gmap
  allocations (LTC#203998 bsc#1217090).
- commit 96c498d
* Mon Nov 13 2023 mfranc@suse.cz
- s390/mm: add missing arch_set_page_dat() call to
  vmem_crst_alloc() (LTC#203998 bsc#1217090).
- commit bec6f3f
* Mon Nov 13 2023 dwagner@suse.de
- nvme: update firmware version after commit (bsc#1215291).
- commit 164c5ac
* Mon Nov 13 2023 mfranc@suse.cz
- s390/cmma: fix initial kernel address space page table walk
  (LTC#203998 bsc#1217090).
- commit fbdf8df
* Mon Nov 13 2023 schwab@suse.de
- rpm/check-for-config-changes: add HAVE_SHADOW_CALL_STACK to IGNORED_CONFIGS_RE
  Not supported by our compiler.
- commit eb32b5a
* Mon Nov 13 2023 dwagner@suse.de
- qla0xxx: add debug log for unmaintained hw detected
  (bsc#1216033, jsc#PED-6878, jsc#PED-6930).
- commit f03aff2
* Mon Nov 13 2023 tzimmermann@suse.com
- config: Enable support for sysfb infrastructure on armv7hl (jsc#PED-1117, bsc#1216864)
- commit 8b528ba
* Mon Nov 13 2023 tzimmermann@suse.com
- config: Enable support for sysfb infrastructure on arm64 (jsc#PED-1117, bsc#1216864)
- commit 6b6ada0
* Mon Nov 13 2023 tiwai@suse.de
- supported.conf: Move lz4-related modules to kernel-*-extra (bsc#1217030)
- commit ad6609a
* Mon Nov 13 2023 tiwai@suse.de
- net: Avoid address overwrite in kernel_connect (bsc#1216861).
- commit 0b11b1e
* Mon Nov 13 2023 tbogendoerfer@suse.de
- Update
  patches.suse/igb-set-max-size-RX-buffer-when-store-bad-packet-is-.patch
  (jsc#PED-4082 bsc#1216259 CVE-2023-45871).
  Added CVE reference.
- commit d155aca
* Sat Nov 11 2023 tiwai@suse.de
- scsi: sd: Introduce manage_shutdown device flag (git-fixes).
- commit 4dbfc08
* Sat Nov 11 2023 tiwai@suse.de
- PM: hibernate: Clean up sync_read handling in
  snapshot_write_next() (git-fixes).
- Refresh
  patches.suse/0007-PM-hibernate-encrypt-hidden-area.patch.
- Refresh
  patches.suse/0008-PM-hibernate-Generate-and-verify-signature-for-snaps.patch.
- commit 57d38a1
* Sat Nov 11 2023 tiwai@suse.de
- spi: Fix null dereference on suspend (git-fixes).
- mmc: sdhci-pci-gli: GL9750: Mask the replay timer timeout of
  AER (git-fixes).
- mmc: sdhci-pci-gli: GL9755: Mask the replay timer timeout of
  AER (git-fixes).
- mmc: Add quirk MMC_QUIRK_BROKEN_CACHE_FLUSH for Micron eMMC
  Q2J54A (git-fixes).
- i2c: designware: Disable TX_EMPTY irq while waiting for block
  length byte (git-fixes).
- i2c: i801: fix potential race in
  i801_block_transaction_byte_by_byte (git-fixes).
- i3c: master: svc: fix random hot join failure since timeout
  error (git-fixes).
- mtd: cfi_cmdset_0001: Byte swap OTP info (git-fixes).
- kernel/reboot: emergency_restart: Set correct system_state
  (git-fixes).
- PCI: qcom-ep: Add dedicated callback for writing to DBI2
  registers (git-fixes).
- PCI: Lengthen reset delay for VideoPropulsion Torrent QN16e card
  (git-fixes).
- ima: detect changes to the backing overlay file (git-fixes).
- ima: annotate iint mutex to avoid lockdep false positive
  warnings (git-fixes).
- selftests/resctrl: Move _GNU_SOURCE define into Makefile
  (git-fixes).
- selftests/resctrl: Remove duplicate feature check from CMT test
  (git-fixes).
- mmc: sdhci-pci-gli: A workaround to allow GL9750 to enter ASPM
  L1.2 (git-fixes).
- arm64: Restrict CPU_BIG_ENDIAN to GNU as or LLVM IAS 15.x or
  newer (git-fixes).
- regmap: Ensure range selector registers are updated after
  cache sync (git-fixes).
- ACPI: resource: Do IRQ override on TongFang GMxXGxx (git-fixes).
- Bluetooth: btusb: Add 0bda:b85b for Fn-Link RTL8852BE
  (git-fixes).
- usb: typec: ucsi: Fix missing link removal (git-fixes).
- usb: misc: onboard_hub: add support for Microchip USB2412 USB
  2.0 hub (git-fixes).
- ata: libata-scsi: Fix delayed scsi_rescan_device() execution
  (git-fixes).
- ata: libata-scsi: Disable scsi device manage_system_start_stop
  (git-fixes).
- ata: libata-scsi: link ata port and scsi device (git-fixes).
- ata: libata-eh: fix reset timeout type (git-fixes).
- lib: test_scanf: Add explicit type cast to result initialization
  in test_number_prefix() (git-fixes).
- arm64: dts: qcom: sdm845-db845c: Mark cont splash memory region
  as reserved (git-fixes).
- X.509: if signature is unsupported skip validation (git-fixes).
- spi: Rename SPI_MASTER_GPIO_SS to SPI_CONTROLLER_GPIO_SS
  (git-fixes).
- spi: Get rid of old SPI_MASTER_MUST_TX & SPI_MASTER_MUST_RX
  (git-fixes).
- spi: Get rid of old SPI_MASTER_NO_TX & SPI_MASTER_NO_RX
  (git-fixes).
- commit cb45743
* Sat Nov 11 2023 tiwai@suse.de
- ALSA: hda: ASUS UM5302LA: Added quirks for cs35L41/10431A83
  on i2c bus (git-fixes).
- ALSA: info: Fix potential deadlock at disconnection (git-fixes).
- ALSA: hda: Add ASRock X670E Taichi to denylist (git-fixes).
- ALSA: hda/realtek: Add quirk for ASUS UX7602ZM (git-fixes).
- commit 163245c
* Sat Nov 11 2023 tiwai@suse.de
- lsm: fix default return value for vm_enough_memory (git-fixes).
- commit 5592231
* Sat Nov 11 2023 tiwai@suse.de
- arm64/arm: arm_pmuv3: perf: Don't truncate 64-bit registers
  (git-fixes).
- ASoC: SOF: sof-client: trivial: fix comment typo (git-fixes).
- ASoC: dapm: fix clock get name (git-fixes).
- ASoC: hdmi-codec: register hpd callback on component probe
  (git-fixes).
- ASoC: mediatek: mt8186_mt6366_rt1019_rt5682s: trivial: fix
  error messages (git-fixes).
- ALSA: hda/realtek: Add support dual speaker for Dell
  (git-fixes).
- spi: spi-zynq-qspi: add spi-mem to driver kconfig dependencies
  (git-fixes).
- Revert "mmc: core: Capture correct oemid-bits for eMMC cards"
  (git-fixes).
- mmc: vub300: fix an error code (git-fixes).
- mmc: sdhci_am654: fix start loop index for TAP value parsing
  (git-fixes).
- lsm: fix default return value for inode_getsecctx (git-fixes).
- commit 1c5dac0
* Fri Nov 10 2023 msuchanek@suse.de
- powerpc/rtas: Serialize firmware activation sequences
  (jsc#PED-4486).
- commit ccdd6c9
* Fri Nov 10 2023 msuchanek@suse.de
- powerpc/rtas: Facilitate high-level call sequences
  (jsc#PED-4486).
- commit 6c17a9b
* Fri Nov 10 2023 msuchanek@suse.de
- powerpc/rtas: Factor out function descriptor lookup
  (jsc#PED-4486).
- commit 01cd933
* Fri Nov 10 2023 tiwai@suse.de
- Bluetooth: ISO: Use defer setup to separate PA sync and BIG sync
  (git-fixes).
- Refresh
  patches.suse/Bluetooth-hci_sync-always-check-if-connection-is-ali.patch.
- commit 4bc4bad
* Fri Nov 10 2023 tiwai@suse.de
- Bluetooth: Make handle of hci_conn be unique (git-fixes).
- Bluetooth: ISO: Pass BIG encryption info through QoS
  (git-fixes).
- commit 0637142
* Fri Nov 10 2023 tiwai@suse.de
- Bluetooth: btrtl: Ignore error return for hci_devcd_register()
  (git-fixes).
- commit dfe20be
* Fri Nov 10 2023 tiwai@suse.de
- Bluetooth: btrtl: Load FW v2 otherwise FW v1 for RTL8852C
  (git-fixes).
- Bluetooth: btrtl: Correct the length of the HCI command for
  drop fw (git-fixes).
- Bluetooth: btrtl: Add Realtek devcoredump support (git-fixes).
- commit e021641
* Fri Nov 10 2023 msuchanek@suse.de
- powerpc/selftests: Add test for papr-sysparm (jsc#PED-4486).
- powerpc/pseries/papr-sysparm: Expose character device to user
  space (jsc#PED-4486).
- powerpc/pseries/papr-sysparm: Validate buffer object lengths
  (jsc#PED-4486).
- commit 9c23c8f
* Fri Nov 10 2023 msuchanek@suse.de
- powerpc/pseries: Add papr-vpd character driver for VPD retrieval (jsc#PED-4486).
  Refresh to current upstream submission.
- commit 38bae06
* Fri Nov 10 2023 tiwai@suse.de
- ASoC: cs35l41: Detect CSPL errors when sending CSPL commands
  (git-fixes).
- commit 6a51af5
* Fri Nov 10 2023 tiwai@suse.de
- ALSA: hda: cs35l41: Support mute notifications for CS35L41 HDA
  (git-fixes).
- Refresh
  patches.suse/ASoC-cs35l41-Fix-broken-shared-boost-activation.patch.
- commit 30a890a
* Fri Nov 10 2023 tiwai@suse.de
- ALSA: hda: cs35l41: Fix missing error code in
  cs35l41_smart_amp() (git-fixes).
- ALSA: hda: cs35l41: mark cs35l41_verify_id() static (git-fixes).
- ALSA: hda: cs35l41: Check CSPL state after loading firmware
  (git-fixes).
- ALSA: hda: cs35l41: Do not unload firmware before reset in
  system suspend (git-fixes).
- ALSA: hda: cs35l41: Force a software reset after hardware reset
  (git-fixes).
- ALSA: hda: cs35l41: Run boot process during resume callbacks
  (git-fixes).
- ALSA: hda: cs35l41: Assert Reset prior to de-asserting in
  probe and system resume (git-fixes).
- ALSA: hda: cs35l41: Assert reset before system suspend
  (git-fixes).
- ALSA: hda: cs35l41: Use reset label to get GPIO for HP Zbook
  Fury 17 G9 (git-fixes).
- ALSA: hda: cs35l41: Consistently use dev_err_probe()
  (git-fixes).
- ALSA: hda: cs35l41: Add read-only ALSA control for forced mute
  (git-fixes).
- ALSA: hda/realtek: Support ACPI Notification framework via
  component binding (git-fixes).
- ALSA: hda: cs35l41: Add notification support into component
  binding (git-fixes).
- commit 2b0e0de
* Fri Nov 10 2023 tiwai@suse.de
- Update patch reference for QXL fix (CVE-2023-39198 bsc#1216965)
- commit 1010980
* Fri Nov 10 2023 jack@suse.cz
- Add tag to
  patches.suse/RDMA-irdma-Prevent-zero-length-STAG-registration.patch
  (git-fixes CVE-2023-25775).
- commit db23c56
* Fri Nov 10 2023 tiwai@suse.de
- selftests: pmtu.sh: fix result checking (git-fixes).
- Fix termination state for idr_for_each_entry_ul() (git-fixes).
- net: dsa: lan9303: consequently nested-lock physical MDIO
  (git-fixes).
- Input: synaptics-rmi4 - fix use after free in
  rmi_unregister_function() (git-fixes).
- i2c: iproc: handle invalid slave state (git-fixes).
- watchdog: ixp4xx: Make sure restart always works (git-fixes).
- watchdog: of_xilinx_wdt: Remove unnecessary clock disable call
  in the remove path (git-fixes).
- pwm: brcmstb: Utilize appropriate clock APIs in suspend/resume
  (git-fixes).
- pwm: sti: Reduce number of allocations and drop usage of
  chip_data (git-fixes).
- commit bbb7764
* Thu Nov  9 2023 tiwai@suse.de
- Update ath11k hibernation fix patch set (bsc#1207948)
  Refreshed patches from the latest subsystem tree
- commit 9792e08
* Thu Nov  9 2023 jgross@suse.com
- x86/xen: Set default memory type for PV guests to WB
  (bsc#1216611).
- commit 1fb865a
* Thu Nov  9 2023 jgross@suse.com
- x86/mtrr: Remove unused code (bsc#1216611).
- commit 51227c2
* Thu Nov  9 2023 jgross@suse.com
- x86/mm: Only check uniform after calling mtrr_type_lookup()
  (bsc#1216611).
- commit 730fe1e
* Thu Nov  9 2023 jgross@suse.com
- x86/mtrr: Don't let mtrr_type_lookup() return MTRR_TYPE_INVALID
  (bsc#1216611).
- commit 567033f
* Thu Nov  9 2023 jgross@suse.com
- x86/mtrr: Use new cache_map in mtrr_type_lookup() (bsc#1216611).
- commit 8d9ece0
* Thu Nov  9 2023 jgross@suse.com
- x86/mtrr: Add mtrr=debug command line option (bsc#1216611).
- commit 05b029d
* Thu Nov  9 2023 jgross@suse.com
- x86/mtrr: Construct a memory map with cache modes (bsc#1216611).
- commit 88ed34b
* Thu Nov  9 2023 jgross@suse.com
- x86/mtrr: Add get_effective_type() service function
  (bsc#1216611).
- commit f135ec2
* Thu Nov  9 2023 jgross@suse.com
- x86/mtrr: Allocate mtrr_value array dynamically (bsc#1216611).
- commit 26e92d9
* Thu Nov  9 2023 jgross@suse.com
- x86/mtrr: Move 32-bit code from mtrr.c to legacy.c
  (bsc#1216611).
- commit dbf2dd7
* Thu Nov  9 2023 jgross@suse.com
- x86/mtrr: Have only one set_mtrr() variant (bsc#1216611).
- commit 2940cc3
* Thu Nov  9 2023 jgross@suse.com
- x86/mtrr: Replace vendor tests in MTRR code (bsc#1216611).
- commit 77388db
* Thu Nov  9 2023 tiwai@suse.de
- usb: storage: set 1.50 as the lower bcdDevice for older "Super
  Top" compatibility (git-fixes).
- tty: 8250: Add support for Intashield IX cards (git-fixes).
- tty: 8250: Add support for additional Brainboxes PX cards
  (git-fixes).
- tty: 8250: Add support for Intashield IS-100 (git-fixes).
- tty: 8250: Add support for Brainboxes UP cards (git-fixes).
- tty: 8250: Add support for additional Brainboxes UC cards
  (git-fixes).
- misc: pci_endpoint_test: Add deviceID for J721S2 PCIe EP device
  support (git-fixes).
- ASoC: SOF: sof-pci-dev: Fix community key quirk detection
  (git-fixes).
- ALSA: usb-audio: add quirk flag to enable native DSD for
  McIntosh devices (git-fixes).
- ALSA: hda: intel-dsp-config: Fix JSL Chromebook quirk detection
  (git-fixes).
- PCI: Prevent xHCI driver from claiming AMD VanGogh USB3 DRD
  device (git-fixes).
- r8152: Check for unplug in r8153b_ups_en() / r8153c_ups_en()
  (git-fixes).
- r8152: Check for unplug in rtl_phy_patch_request() (git-fixes).
- efi: fix memory leak in krealloc failure handling (git-fixes).
- ASoC: da7219: Correct the process of setting up Gnd switch in
  AAD (git-fixes).
- ASoC: codecs: tas2780: Fix log of failed reset via I2C
  (git-fixes).
- ASoC: rt5650: fix the wrong result of key button (git-fixes).
- ASoC: soc-dapm: Add helper for comparing widget name
  (git-fixes).
- spi: npcm-fiu: Fix UMA reads when dummy.nbytes == 0 (git-fixes).
- Input: synaptics-rmi4 - handle reset delay when using SMBus
  trsnsport (git-fixes).
- dmaengine: ste_dma40: Fix PM disable depth imbalance in
  d40_probe (git-fixes).
- media: i2c: ov8858: Don't set fwnode in the driver (git-fixes).
- can: flexcan: remove the auto stop mode for IMX93 (git-fixes).
- arm64: dts: imx93: add the Flex-CAN stop mode by GPR
  (git-fixes).
- irqchip/stm32-exti: add missing DT IRQ flag translation
  (git-fixes).
- ASoC: tlv320adc3xxx: BUG: Correct micbias setting (git-fixes).
- ASoC: core: Do not call link_exit() on uninitialized rtd objects
  (git-fixes).
- ASoC: simple-card: fixup asoc_simple_probe() error handling
  (git-fixes).
- commit a07dd6a
* Wed Nov  8 2023 lhenriques@suse.de
- netfs: Only call folio_start_fscache() one time for each folio
  (bsc#1216954).
- commit edff202
* Wed Nov  8 2023 tiwai@suse.de
- regmap: prevent noinc writes from clobbering cache (git-fixes).
- pcmcia: ds: fix possible name leak in error path in
  pcmcia_device_add() (git-fixes).
- pcmcia: ds: fix refcount leak in pcmcia_device_add()
  (git-fixes).
- pcmcia: cs: fix possible hung task and memory leak pccardd()
  (git-fixes).
- commit 2de7d14
* Tue Nov  7 2023 tiwai@suse.de
- media: venus: hfi_parser: Add check to keep the number of
  codecs within range (git-fixes).
- media: venus: hfi: add checks to handle capabilities from
  firmware (git-fixes).
- media: venus: hfi: fix the check to handle session buffer
  requirement (git-fixes).
- media: venus: hfi: add checks to perform sanity on queue
  pointers (git-fixes).
- media: cec: meson: always include meson sub-directory in
  Makefile (git-fixes).
- media: platform: mtk-mdp3: fix uninitialized variable in
  mdp_path_config() (git-fixes).
- media: imx-jpeg: notify source chagne event when the first
  picture parsed (git-fixes).
- media: siano: Drop unnecessary error check for
  debugfs_create_dir/file() (git-fixes).
- media: aspeed: Drop unnecessary error check for
  debugfs_create_file() (git-fixes).
- media: dvb-usb-v2: af9035: fix missing unlock (git-fixes).
- media: cadence: csi2rx: Unregister v4l2 async notifier
  (git-fixes).
- staging: media: ipu3: remove ftrace-like logging (git-fixes).
- media: lirc: drop trailing space from scancode transmit
  (git-fixes).
- media: sharp: fix sharp encoding (git-fixes).
- media: ccs: Correctly initialise try compose rectangle
  (git-fixes).
- media: cedrus: Fix clock/reset sequence (git-fixes).
- media: vidtv: mux: Add check and kfree for kstrdup (git-fixes).
- media: vidtv: psi: Add check for kstrdup (git-fixes).
- media: s3c-camif: Avoid inappropriate kfree() (git-fixes).
- media: mtk-jpegenc: Fix bug in JPEG encode quality selection
  (git-fixes).
- media: amphion: handle firmware debug message (git-fixes).
- media: bttv: fix use after free error due to btv->timeout timer
  (git-fixes).
- media: ov5640: Fix a memory leak when ov5640_probe fails
  (git-fixes).
- media: i2c: max9286: Fix some redundant of_node_put() calls
  (git-fixes).
- media: verisilicon: Do not enable G2 postproc downscale if
  source is narrower than destination (git-fixes).
- media: hantro: Check whether reset op is defined before use
  (git-fixes).
- media: imx-jpeg: initiate a drain of the capture queue in
  dynamic resolution change (git-fixes).
- media: qcom: camss: Fix csid-gen2 for test pattern generator
  (git-fixes).
- media: qcom: camss: Fix set CSI2_RX_CFG1_VC_MODE when VC is
  greater than 3 (git-fixes).
- media: qcom: camss: Fix invalid clock enable bit disjunction
  (git-fixes).
- media: qcom: camss: Fix missing vfe_lite clocks check
  (git-fixes).
- media: qcom: camss: Fix VFE-480 vfe_disable_output()
  (git-fixes).
- media: qcom: camss: Fix VFE-17x vfe_disable_output()
  (git-fixes).
- media: qcom: camss: Fix vfe_get() error jump (git-fixes).
- media: qcom: camss: Fix pm_domain_on sequence in probe
  (git-fixes).
- commit dd330a0
* Mon Nov  6 2023 tiwai@suse.de
- rtc: efi: fixed typo in efi_procfs() (git-fixes).
- rtc: brcmstb-waketimer: support level alarm_irq (git-fixes).
- commit 74519c3
* Sun Nov  5 2023 tiwai@suse.de
- i3c: master: svc: fix SDA keep low when polling IBIWON timeout
  happen (git-fixes).
- i3c: master: svc: fix check wrong status register in irq handler
  (git-fixes).
- i3c: master: svc: fix ibi may not return mandatory data byte
  (git-fixes).
- i3c: master: svc: fix wrong data return when IBI happen during
  start frame (git-fixes).
- i3c: master: svc: fix race condition in ibi work thread
  (git-fixes).
- i3c: Fix potential refcount leak in
  i3c_master_register_new_i3c_devs (git-fixes).
- i3c: master: cdns: Fix reading status register (git-fixes).
- cxl/region: Fix x1 root-decoder granularity calculations
  (git-fixes).
- cxl/region: Fix cxl_region_rwsem lock held when returning to
  user space (git-fixes).
- cxl/region: Do not try to cleanup after
  cxl_region_setup_targets() fails (git-fixes).
- cxl/mem: Fix shutdown order (git-fixes).
- mtd: rawnand: meson: check return value of devm_kasprintf()
  (git-fixes).
- mtd: rawnand: intel: check return value of devm_kasprintf()
  (git-fixes).
- mtd: rawnand: arasan: Include ECC syndrome along with in-band
  data while checking for ECC failure (git-fixes).
- mtd: rawnand: tegra: add missing check for platform_get_irq()
  (git-fixes).
- 9p/net: fix possible memory leak in p9_check_errors()
  (git-fixes).
- modpost: fix ishtp MODULE_DEVICE_TABLE built on big-endian host
  (git-fixes).
- modpost: fix tee MODULE_DEVICE_TABLE built on big-endian host
  (git-fixes).
- pinctrl: renesas: rzg2l: Make reverse order of enable() for
  disable() (git-fixes).
- dmaengine: stm32-mdma: correct desc prep when channel running
  (git-fixes).
- dmaengine: pxa_dma: Remove an erroneous BUG_ON() in
  pxad_free_desc() (git-fixes).
- dmaengine: ti: edma: handle irq_of_parse_and_map() errors
  (git-fixes).
- dmaengine: idxd: Register dsa_bus_type before registering idxd
  sub-drivers (git-fixes).
- commit 0e1ee29
* Sat Nov  4 2023 tiwai@suse.de
- usb: raw-gadget: properly handle interrupted requests
  (git-fixes).
- usb: typec: tcpm: Fix NULL pointer dereference in tcpm_pd_svdm()
  (git-fixes).
- usb: typec: tcpm: Add additional checks for contaminant
  (git-fixes).
- usb: host: xhci-plat: fix possible kernel oops while resuming
  (git-fixes).
- xhci: Loosen RPM as default policy to cover for AMD xHC 1.1
  (git-fixes).
- USB: usbip: fix stub_dev hub disconnect (git-fixes).
- usb: dwc3: document gfladj_refclk_lpm_sel field (git-fixes).
- usb: chipidea: Simplify Tegra DMA alignment code (git-fixes).
- usb: chipidea: Fix DMA overwrite for Tegra (git-fixes).
- dt-bindings: usb: qcom,dwc3: Fix SDX65 clocks (git-fixes).
- usb: dwc2: fix possible NULL pointer dereference caused by
  driver concurrency (git-fixes).
- tty: n_gsm: fix race condition in status line change on dead
  connections (git-fixes).
- tty: 8250: Add Brainboxes Oxford Semiconductor-based quirks
  (git-fixes).
- tty: 8250: Fix up PX-803/PX-857 (git-fixes).
- tty: 8250: Fix port count of PX-257 (git-fixes).
- tty: 8250: Remove UC-257 and UC-431 (git-fixes).
- dt-bindings: serial: rs485: Add rs485-rts-active-high
  (git-fixes).
- tty: serial: samsung_tty: remove dead code (git-fixes).
- tty: serial: meson: fix hard LOCKUP on crtscts mode (git-fixes).
- tty/sysrq: replace smp_processor_id() with get_cpu()
  (git-fixes).
- dt-bindings: serial: fix regex pattern for matching serial
  node children (git-fixes).
- serial: exar: Revert "serial: exar: Add support for Sealevel
  7xxxC serial cards" (git-fixes).
- tty: tty_jobctrl: fix pid memleak in disassociate_ctty()
  (git-fixes).
- driver core: Release all resources during unbind before updating
  device links (git-fixes).
- device property: Replace custom implementation of COUNT_ARGS()
  (git-fixes).
- driver core: Add missing parameter description to
  __fwnode_link_add() (git-fixes).
- iio: frequency: adf4350: Use device managed functions and fix
  power down issue (git-fixes).
- misc: st_core: Do not call kfree_skb() under spin_lock_irqsave()
  (git-fixes).
- apparmor: fix invalid reference on profile->disconnected
  (git-fixes).
- seq_buf: fix a misleading comment (git-fixes).
- verification/dot2k: Delete duplicate imports (git-fixes).
- scripts/gdb: fix usage of MOD_TEXT not defined when
  CONFIG_MODULES=n (git-fixes).
- selftests/clone3: Fix broken test under !CONFIG_TIME_NS
  (git-fixes).
- kselftest: vm: fix mdwe's mmap_FIXED test case (git-fixes).
- ata: libata-eh: Fix compilation warning in ata_eh_link_report()
  (git-fixes).
- ata: libata-core: Fix compilation warning in
  ata_dev_config_ncq() (git-fixes).
- ata: sata_mv: Fix incorrect string length computation in
  mv_dump_mem() (git-fixes).
- kernel.h: split out COUNT_ARGS() and CONCATENATE() to args.h
  (git-fixes).
- commit 7857243
* Sat Nov  4 2023 tiwai@suse.de
- Move upstreamed patches into sorted section
- commit 266765d
* Fri Nov  3 2023 lduncan@suse.com
- scsi: qedf: Remove unused declaration (jsc#PED-6887).
- scsi: mpi3mr: Update driver version to 8.5.0.0.0 (jsc#PED-6833).
- scsi: mpi3mr: Enhance handling of devices removed after
  controller reset (jsc#PED-6833).
- scsi: mpi3mr: WRITE SAME implementation (jsc#PED-6833).
- scsi: mpi3mr: Add support for more than 1MB I/O (jsc#PED-6833).
- scsi: mpi3mr: Update MPI Headers to version 3.00.28
  (jsc#PED-6833).
- scsi: mpi3mr: Invoke soft reset upon TSU or event ack time out
  (jsc#PED-6833).
- scsi: mpi3mr: Fix the type used for pointers to bitmap
  (jsc#PED-6833).
- scsi: mpi3mr: Use -ENOMEM instead of -1 in mpi3mr_expander_add()
  (jsc#PED-6833).
- scsi: bnx2i: Replace all non-returning strlcpy with strscpy
  (jsc#PED-6881).
- commit e96a6ce
* Fri Nov  3 2023 tabraham@suse.com
- x86/cpu: Clear SVM feature if disabled by BIOS (bsc#1214700).
- commit 84980be
* Fri Nov  3 2023 iivanov@suse.de
- genirq: Fix software resend lockup and nested resend (bsc#1216838)
- commit 89cd9f2
* Fri Nov  3 2023 iivanov@suse.de
- tpm_tis_spi: Add hardware wait polling (bsc#1213534)
- commit ec3c751
* Fri Nov  3 2023 iivanov@suse.de
- iommu/arm-smmu-v3: Fix soft lockup triggered by (bsc#1215921)
- commit 7166c48
* Fri Nov  3 2023 iivanov@suse.de
- arm64/smmu: use TLBI ASID when invalidating entire range (bsc#1215921)
- commit d16cd96
* Fri Nov  3 2023 iivanov@suse.de
- genirq: Use a maple tree for interrupt descriptor management (bsc#1216838)
- commit 7eccb48
* Fri Nov  3 2023 iivanov@suse.de
- genirq: Encapsulate sparse bitmap handling (bsc#1216838)
- commit 85b3f80
* Fri Nov  3 2023 iivanov@suse.de
- genirq: Use hlist for managing resend handlers (bsc#1216838)
- commit 3f03452
* Fri Nov  3 2023 iivanov@suse.de
- perf: arm_cspmu: Add missing MODULE_DEVICE_TABLE (bsc#1216837)
- commit e992f19
* Fri Nov  3 2023 iivanov@suse.de
- perf/arm_cspmu: Decouple APMT dependency (bsc#1216837)
- commit 8252670
* Fri Nov  3 2023 iivanov@suse.de
- perf/arm_cspmu: Clean up ACPI dependency (bsc#1216837)
- commit 22cdbfa
* Fri Nov  3 2023 tiwai@suse.de
- padata: Fix refcnt handling in padata_free_shell() (git-fixes).
- leds: trigger: ledtrig-cpu:: Fix 'output may be truncated'
  issue for 'cpu' (git-fixes).
- leds: pwm: Don't disable the PWM when the LED should be off
  (git-fixes).
- leds: turris-omnia: Do not use SMBUS calls (git-fixes).
- mfd: arizona-spi: Set pdata.hpdet_channel for ACPI enumerated
  devs (git-fixes).
- mfd: qcom-spmi-pmic: Fix revid implementation (git-fixes).
- mfd: qcom-spmi-pmic: Fix reference leaks in revid helper
  (git-fixes).
- mfd: dln2: Fix double put in dln2_probe (git-fixes).
- mfd: core: Ensure disabled devices are skipped without aborting
  (git-fixes).
- mfd: core: Un-constify mfd_cell.of_reg (git-fixes).
- i2c: core: Run atomic i2c xfer when !preemptible (git-fixes).
- PCI: endpoint: Fix double free in __pci_epc_create()
  (git-fixes).
- x86/PCI: Avoid PME from D3hot/D3cold for AMD Rembrandt and
  Phoenix USB4 (git-fixes).
- PCI/sysfs: Protect driver's D3cold preference from user space
  (git-fixes).
- PCI: keystone: Don't discard .probe() callback (git-fixes).
- PCI: keystone: Don't discard .remove() callback (git-fixes).
- PCI: kirin: Don't discard .remove() callback (git-fixes).
- PCI: exynos: Don't discard .remove() callback (git-fixes).
- PCI: vmd: Correct PCI Header Type Register's multi-function
  check (git-fixes).
- PCI/ASPM: Fix L1 substate handling in aspm_attr_store_common()
  (git-fixes).
- module/decompress: use vmalloc() for gzip decompression
  workspace (git-fixes).
- watchdog: move softlockup_panic back to early_param (git-fixes).
- proc: sysctl: prevent aliased sysctls from getting passed to
  init (git-fixes).
- r8169: fix rare issue with broken rx after link-down on RTL8125
  (git-fixes).
- r8169: fix the KCSAN reported data race in rtl_rx while reading
  desc->opts1 (git-fixes).
- r8169: fix the KCSAN reported data-race in rtl_tx while reading
  TxDescArray[entry].opts1 (git-fixes).
- r8169: fix the KCSAN reported data-race in rtl_tx() while
  reading tp->cur_tx (git-fixes).
- commit 6cdb862
* Fri Nov  3 2023 tiwai@suse.de
- crypto: qat - fix deadlock in backlog processing (git-fixes).
- crypto: hisilicon/qm - fix EQ/AEQ interrupt issue (git-fixes).
- crypto: qat - fix double free during reset (git-fixes).
- crypto: hisilicon/qm - fix PF queue parameter issue (git-fixes).
- crypto: qat - increase size of buffers (git-fixes).
- crypto: caam/jr - fix Chacha20 + Poly1305 self test failure
  (git-fixes).
- crypto: caam/qi2 - fix Chacha20 + Poly1305 self test failure
  (git-fixes).
- hwrng: geode - fix accessing registers (git-fixes).
- hwrng: bcm2835 - Fix hwrng throughput regression (git-fixes).
- dt-bindings: leds: Last color ID is now 14 (LED_COLOR_ID_LIME)
  (git-fixes).
- dt-bindings: mfd: mt6397: Split out compatible for MediaTek
  MT6366 PMIC (git-fixes).
- HID: uclogic: Fix a work->entry not empty bug in __queue_work()
  (git-fixes).
- HID: uclogic: Fix user-memory-access bug in
  uclogic_params_ugee_v2_init_event_hooks() (git-fixes).
- HID: logitech-hidpp: Move get_wireless_feature_index() check
  to hidpp_connect_event() (git-fixes).
- HID: logitech-hidpp: Revert "Don't restart communication if
  not necessary" (git-fixes).
- HID: logitech-hidpp: Don't restart IO, instead defer
  hid_connect() only (git-fixes).
- hid: lenovo: Resend all settings on reset_resume for compact
  keyboards (git-fixes).
- hid: cp2112: Fix duplicate workqueue initialization (git-fixes).
- gtp: fix fragmentation needed check with gso (git-fixes).
- gtp: uapi: fix GTPA_MAX (git-fixes).
- commit a4c70dd
* Fri Nov  3 2023 tiwai@suse.de
- certs: Break circular dependency when selftest is modular
  (git-fixes).
- Refresh
  patches.suse/0002-PKCS-7-Check-codeSigning-EKU-for-kernel-module-and-k.patch.
- commit dfb1cad
* Fri Nov  3 2023 tiwai@suse.de
- crypto: qat - fix unregistration of crypto algorithms
  (git-fixes).
- crypto: qat - ignore subsequent state up commands (git-fixes).
- crypto: qat - fix state machines cleanup paths (git-fixes).
- crypto: hisilicon/hpre - Fix a erroneous check after snprintf()
  (git-fixes).
- ARM: 9323/1: mm: Fix ARCH_LOW_ADDRESS_LIMIT when CONFIG_ZONE_DMA
  (git-fixes).
- ARM: 9321/1: memset: cast the constant byte to unsigned char
  (git-fixes).
- backlight: pwm_bl: Disable PWM on shutdown, suspend and remove
  (git-fixes).
- ASoC: Intel: Skylake: Fix mem leak when parsing UUIDs fails
  (git-fixes).
- ASoC: fsl: Fix PM disable depth imbalance in fsl_easrc_probe
  (git-fixes).
- ASoC: ams-delta.c: use component after check (git-fixes).
- ASoC: intel: sof_sdw: Stop processing CODECs when enough are
  found (git-fixes).
- ASoC: Intel: sof_sdw_rt_sdca_jack_common: add rt713 support
  (git-fixes).
- ASoC: fsl-asoc-card: Add comment for mclk in the codec_priv
  (git-fixes).
- ASoC: fsl: mpc5200_dma.c: Fix warning of Function parameter
  or member not described (git-fixes).
- ASoC: codecs: wsa-macro: fix uninitialized stack variables
  with name prefix (git-fixes).
- ASoC: SOF: ipc4-topology: Use size_add() in call to
  struct_size() (git-fixes).
- ASoC: doc: Update codec to codec examples (git-fixes).
- ASoC: soc-pcm.c: Make sure DAI parameters cleared if the DAI
  becomes inactive (git-fixes).
- ALSA: hda: cs35l41: Undo runtime PM changes at driver exit time
  (git-fixes).
- ALSA: hda: cs35l41: Fix unbalanced pm_runtime_get() (git-fixes).
- ASoC: cs35l41: Undo runtime PM changes at driver exit time
  (git-fixes).
- ASoC: cs35l41: Verify PM runtime resume errors in IRQ handler
  (git-fixes).
- ASoC: cs35l41: Fix broken shared boost activation (git-fixes).
- ASoC: cs35l41: Initialize completion object before requesting
  IRQ (git-fixes).
- ASoC: cs35l41: Handle mdsync_up reg write errors (git-fixes).
- ASoC: cs35l41: Handle mdsync_down reg write errors (git-fixes).
- ASoC: SOF: core: Ensure sof_ops_free() is still called when
  probe never ran (git-fixes).
- commit e345c76
* Thu Nov  2 2023 msuchanek@suse.de
- Refresh sorted patches.
- commit 60c433a
* Thu Nov  2 2023 msuchanek@suse.de
- powerpc/vas: Limit open window failure messages in log bufffer
  (bsc#1216687 ltc#203927).
- commit ebbc65f
* Thu Nov  2 2023 hare@suse.de
- ata: pata_octeon_cf: fix error return code in (bsc#1216435).
- commit 0f8e43f
* Thu Nov  2 2023 ggherdovich@suse.cz
- platform/x86/intel/tpmi: Prevent overflow for cap_offset
  (jsc#PED-5555 jsc#PED-5557).
- commit 1a30c51
* Thu Nov  2 2023 ggherdovich@suse.cz
- platform/x86/intel: tpmi: Remove hardcoded unit and offset
  (jsc#PED-5555 jsc#PED-5557).
- commit 2815b7f
* Thu Nov  2 2023 ggherdovich@suse.cz
- platform/x86/intel-uncore-freq: tpmi: Provide cluster level
  control (jsc#PED-4901 jsc#PED-4961).
- commit d195bba
* Thu Nov  2 2023 ggherdovich@suse.cz
- platform/x86/intel-uncore-freq: Support for cluster level
  controls (jsc#PED-4901 jsc#PED-4961).
- commit 698bea8
* Thu Nov  2 2023 ggherdovich@suse.cz
- platform/x86/intel-uncore-freq: Uncore frequency control via
  TPMI (jsc#PED-4901 jsc#PED-4961).
- commit ab99025
* Thu Nov  2 2023 ggherdovich@suse.cz
- cpufreq: intel_pstate: Fix scaling for hybrid-capable systems
  with disabled E-cores (jsc#PED-4927 jsc#PED-4929).
- commit 7d3ce95
* Thu Nov  2 2023 tiwai@suse.de
- scripts/kernel-doc: Fix the regex for matching -Werror flag
  (git-fixes).
- commit 7fb028b
* Thu Nov  2 2023 tiwai@suse.de
- docs: usb: fix reference to nonexistent file in UVC Gadget
  (git-fixes).
- scripts/kernel-doc: match -Werror flag strictly (git-fixes).
- docs: admin-guide: sysctl: fix details of struct dentry_stat_t
  (git-fixes).
- selftests/resctrl: Reduce failures due to outliers in MBA/MBM
  tests (git-fixes).
- selftests/resctrl: Fix uninitialized .sa_flags (git-fixes).
- selftests/resctrl: Ensure the benchmark commands fits to its
  array (git-fixes).
- selftests/pidfd: Fix ksft print formats (git-fixes).
- kunit: Fix missed memory release in kunit_free_suite_set()
  (git-fixes).
- firmware: raspberrypi: Fix devm_rpi_firmware_get documentation
  (git-fixes).
- firmware: ti_sci: Mark driver as non removable (git-fixes).
- firmware: qcom_scm: use 64-bit calling convention only when
  client is 64-bit (git-fixes).
- firmware: tegra: Add suspend hook and reset BPMP IPC early on
  resume (git-fixes).
- firmware: arm_ffa: Allow the FF-A drivers to use 32bit mode
  of messaging (git-fixes).
- firmware: arm_ffa: Assign the missing IDR allocation ID to
  the FFA device (git-fixes).
- clk: scmi: Free scmi_clk allocated when the clocks with invalid
  info are skipped (git-fixes).
- ARM64: dts: marvell: cn9310: Use appropriate label for spi1 pins
  (git-fixes).
- arm64: dts: ti: k3-am62a7-sk: Drop i2c-1 to 100Khz (git-fixes).
- arm64: dts: ti: k3-am625-beagleplay: Fix typo in ramoops reg
  (git-fixes).
- arm64: dts: meson: a1: reorder gpio_intc node definition
  (git-fixes).
- arm64: dts: qcom: apq8016-sbc: Add missing ADV7533 regulators
  (git-fixes).
- arm64: dts: qcom: msm8976: Fix ipc bit shifts (git-fixes).
- arm64: dts: qcom: ipq6018: Fix tcsr_mutex register size
  (git-fixes).
- arm64: dts: qcom: ipq6018: Fix hwlock index for SMEM
  (git-fixes).
- arm64: dts: qcom: ipq5332: Fix hwlock index for SMEM
  (git-fixes).
- arm64: dts: qcom: ipq8074: Fix hwlock index for SMEM
  (git-fixes).
- arm64: dts: qcom: sdm845-mtp: fix WiFi configuration
  (git-fixes).
- arm64: dts: qcom: sm8350: fix pinctrl for UART18 (git-fixes).
- arm64: dts: qcom: sm8150: add ref clock to PCIe PHYs
  (git-fixes).
- arm64: dts: qcom: qrb2210-rb1: Swap UART index (git-fixes).
- arm64: dts: qcom: sc7280: Add missing LMH interrupts
  (git-fixes).
- arm64: dts: qcom: sm6125: Sort spmi_bus node numerically by reg
  (git-fixes).
- arm64: dts: qcom: sm6125: Pad APPS IOMMU address to 8 characters
  (git-fixes).
- arm64: dts: qcom: msm8992-libra: drop duplicated reserved memory
  (git-fixes).
- arm64: dts: qcom: msm8916: Fix iommu local address range
  (git-fixes).
- arm64: dts: qcom: sc7280: link
  usb3_phy_wrapper_gcc_usb30_pipe_clk (git-fixes).
- arm64: dts: qcom: sdm845: cheza doesn't support LMh node
  (git-fixes).
- arm64: dts: qcom: sdm845: Fix PSCI power domain names
  (git-fixes).
- arm64: dts: imx8mn: Add sound-dai-cells to micfil node
  (git-fixes).
- arm64: dts: imx8mm: Add sound-dai-cells to micfil node
  (git-fixes).
- arm64: dts: imx8mp-debix-model-a: Remove USB hub reset-gpios
  (git-fixes).
- arm64: dts: imx8qm-ss-img: Fix jpegenc compatible entry
  (git-fixes).
- arm64: tegra: Use correct interrupts for Tegra234 TKE
  (git-fixes).
- arm64: tegra: Fix P3767 QSPI speed (git-fixes).
- arm64: tegra: Fix P3767 card detect polarity (git-fixes).
- mmc: meson-gx: Remove setting of CMD_CFG_ERROR (git-fixes).
- arm64/arm: xen: enlighten: Fix KPTI checks (git-fixes).
- arm64: module: Fix PLT counting when CONFIG_RANDOMIZE_BASE=n
  (git-fixes).
- clocksource/drivers/arm_arch_timer: limit XGene-1 workaround
  (git-fixes).
- accel/habanalabs/gaudi2: Fix incorrect string length computation
  in gaudi2_psoc_razwi_get_engines() (git-fixes).
- commit 431e850
* Wed Nov  1 2023 tiwai@suse.de
- wifi: ath12k: fix htt mlo-offset event locking (git-fixes).
- wifi: ath12k: fix dfs-radar and temperature event locking
  (git-fixes).
- wifi: ath11k: fix gtk offload status event locking (git-fixes).
- wifi: ath11k: fix htt pktlog locking (git-fixes).
- wifi: ath11k: fix dfs radar event locking (git-fixes).
- wifi: ath11k: fix temperature event locking (git-fixes).
- wifi: iwlwifi: empty overflow queue during flush (git-fixes).
- wifi: iwlwifi: mvm: update IGTK in mvmvif upon D3 resume
  (git-fixes).
- wifi: iwlwifi: pcie: synchronize IRQs before NAPI (git-fixes).
- wifi: iwlwifi: mvm: remove TDLS stations from FW (git-fixes).
- wifi: iwlwifi: mvm: Fix key flags for IGTK on AP interface
  (git-fixes).
- wifi: iwlwifi: mvm: Correctly set link configuration
  (git-fixes).
- wifi: iwlwifi: yoyo: swap cdb and jacket bits values
  (git-fixes).
- wifi: mac80211: Fix setting vif links (git-fixes).
- wifi: mac80211: don't recreate driver link debugfs in reconfig
  (git-fixes).
- wifi: iwlwifi: mvm: use correct sta ID for IGTK/BIGTK
  (git-fixes).
- wifi: iwlwifi: mvm: fix removing pasn station for responder
  (git-fixes).
- wifi: iwlwifi: mvm: update station's MFP flag after association
  (git-fixes).
- wifi: wilc1000: use vmm_table as array in wilc struct
  (git-fixes).
- wifi: rtw88: Remove duplicate NULL check before calling
  usb_kill/free_urb() (git-fixes).
- wifi: wfx: fix case where rates are out of order (git-fixes).
- wifi: ath11k: fix Tx power value during active CAC (git-fixes).
- wifi: ath: dfs_pattern_detector: Fix a memory initialization
  issue (git-fixes).
- wifi: mt76: Drop unnecessary error check for
  debugfs_create_dir() (git-fixes).
- commit c7c9050
* Wed Nov  1 2023 tiwai@suse.de
- spi: nxp-fspi: use the correct ioremap function (git-fixes).
- spi: mpc52xx-psc: Make mpc52xx_psc_spi_transfer_one_message()
  static (git-fixes).
- thermal/qcom/tsens: Drop ops_v0_1 (git-fixes).
- thermal/drivers/mediatek: Fix probe for THERMAL_V2 (git-fixes).
- thermal: intel: powerclamp: fix mismatch in get function for
  max_idle (git-fixes).
- thermal: ACPI: Include the right header file (git-fixes).
- thermal: core: Don't update trip points inside the hysteresis
  range (git-fixes).
- thermal: core: prevent potential string overflow (git-fixes).
- wifi: mt76: mt7915: fix beamforming availability check
  (git-fixes).
- wifi: mt76: mt7996: fix TWT command format (git-fixes).
- wifi: mt76: mt7996: fix rx rate report for CBW320-2 (git-fixes).
- wifi: mt76: mt7996: fix wmm queue mapping (git-fixes).
- wifi: mt76: mt7996: fix beamformee ss subfield in EHT PHY cap
  (git-fixes).
- wifi: mt76: mt7996: fix beamform mcu cmd configuration
  (git-fixes).
- wifi: mt76: mt7603: improve stuck beacon handling (git-fixes).
- wifi: mt76: mt7603: improve watchdog reset reliablity
  (git-fixes).
- wifi: mt76: mt7603: rework/fix rx pse hang check (git-fixes).
- wifi: rtlwifi: fix EDCA limit set by BT coexistence (git-fixes).
- wifi: ath12k: fix DMA unmap warning on NULL DMA address
  (git-fixes).
- wifi: ath12k: fix undefined behavior with __fls in dp
  (git-fixes).
- wifi: mac80211: fix check for unusable RX result (git-fixes).
- wifi: rtw88: debug: Fix the NULL vs IS_ERR() bug for
  debugfs_create_file() (git-fixes).
- wifi: iwlwifi: Use FW rate for non-data frames (git-fixes).
- wifi: iwlwifi: don't use an uninitialized variable (git-fixes).
- wifi: iwlwifi: honor the enable_ini value (git-fixes).
- wifi: mac80211: fix # of MSDU in A-MSDU calculation (git-fixes).
- wifi: cfg80211: fix off-by-one in element defrag (git-fixes).
- wifi: mac80211: fix RCU usage warning in mesh fast-xmit
  (git-fixes).
- string: Adjust strtomem() logic to allow for smaller sources
  (git-fixes).
- usb: atm: Use size_add() in call to struct_size() (git-fixes).
- commit 6ae6091
* Wed Nov  1 2023 tiwai@suse.de
- power: supply: core: Use blocking_notifier_call_chain to avoid
  RCU complaint (git-fixes).
- hte: tegra: Fix missing error code in tegra_hte_test_probe()
  (git-fixes).
- platform/x86: wmi: Fix opening of char device (git-fixes).
- platform/x86: wmi: Fix probe failure when failing to register
  WMI devices (git-fixes).
- Revert "hwmon: (sch56xx-common) Add automatic module loading
  on supported devices" (git-fixes).
- Revert "hwmon: (sch56xx-common) Add DMI override table"
  (git-fixes).
- hwmon: (nct6775) Fix incorrect variable reuse in fan_div
  calculation (git-fixes).
- hwmon: (coretemp) Fix potentially truncated sysfs attribute name
  (git-fixes).
- hwmon: (axi-fan-control) Fix possible NULL pointer dereference
  (git-fixes).
- spi: tegra: Fix missing IRQ check in tegra_slink_probe()
  (git-fixes).
- regulator: qcom-rpmh: Fix smps4 regulator for pm8550ve
  (git-fixes).
- regmap: debugfs: Fix a erroneous check after snprintf()
  (git-fixes).
- gpio: mockup: remove unused field (git-fixes).
- PM: hibernate: Use __get_safe_page() rather than touching the
  list (git-fixes).
- PM / devfreq: rockchip-dfi: Make pmu regmap mandatory
  (git-fixes).
- keys: Remove unused extern declarations (git-fixes).
- KEYS: trusted: tee: Refactor register SHM usage (git-fixes).
- KEYS: trusted: Rollback init_trusted() consistently (git-fixes).
- pstore/platform: Add check for kstrdup (git-fixes).
- commit 4216161
* Wed Nov  1 2023 tiwai@suse.de
- clk: npcm7xx: Fix incorrect kfree (git-fixes).
- clk: ti: fix double free in of_ti_divider_clk_setup()
  (git-fixes).
- clk: keystone: pll: fix a couple NULL vs IS_ERR() checks
  (git-fixes).
- clk: asm9620: Remove 'hw' local variable that isn't checked
  (git-fixes).
- clk: Drive clk_leaf_mux_set_rate_parent test from clk_ops
  (git-fixes).
- clk: renesas: rzg2l: Trust value returned by hardware
  (git-fixes).
- clk: renesas: rzg2l: Lock around writes to mux register
  (git-fixes).
- clk: renesas: rzg2l: Wait for status bit of SD mux before
  continuing (git-fixes).
- clk: renesas: rcar-gen3: Extend SDnH divider table (git-fixes).
- clk: qcom: ipq5332: drop the CLK_SET_RATE_PARENT flag from
  GPLL clocks (git-fixes).
- clk: qcom: ipq9574: drop the CLK_SET_RATE_PARENT flag from
  GPLL clocks (git-fixes).
- clk: qcom: ipq6018: drop the CLK_SET_RATE_PARENT flag from
  PLL clocks (git-fixes).
- clk: qcom: ipq8074: drop the CLK_SET_RATE_PARENT flag from
  PLL clocks (git-fixes).
- clk: qcom: apss-ipq-pll: Fix 'l' value for ipq5332_pll_config
  (git-fixes).
- clk: qcom: config IPQ_APSS_6018 should depend on QCOM_SMEM
  (git-fixes).
- clk: qcom: gcc-sm8150: Fix gcc_sdcc2_apps_clk_src (git-fixes).
- clk: qcom: mmcc-msm8974: remove ocmemcx_ahb_clk (git-fixes).
- clk: qcom: mmcc-msm8998: Fix the SMMU GDSC (git-fixes).
- clk: qcom: mmcc-msm8998: Don't check halt bit on some branch
  clks (git-fixes).
- clk: qcom: clk-rcg2: Fix clock rate overflow for high parent
  frequencies (git-fixes).
- clk: qcom: gcc-msm8996: Remove RPM bus clocks (git-fixes).
- clk: qcom: ipq5332: Drop set rate parent from gpll0 dependent
  clocks (git-fixes).
- clk: socfpga: Fix undefined behavior bug in struct
  stratix10_clock_data (git-fixes).
- clk: visconti: Fix undefined behavior bug in struct
  visconti_pll_provider (git-fixes).
- clk: imx: imx8qxp: Fix elcdif_pll clock (git-fixes).
- clk: imx: imx8dxl-rsrc: keep sorted in the ascending order
  (git-fixes).
- gpio: mockup: fix kerneldoc (git-fixes).
- cpufreq: tegra194: fix warning due to missing opp_put
  (git-fixes).
- cpufreq: stats: Fix buffer overflow detection in trans_stats()
  (git-fixes).
- commit a94ed03
* Wed Nov  1 2023 tiwai@suse.de
- clk: imx: imx8mq: correct error handling path (git-fixes).
- clk: imx: Select MXC_CLK for CLK_IMX8QXP (git-fixes).
- clk: mediatek: fix double free in mtk_clk_register_pllfh()
  (git-fixes).
- clk: mediatek: clk-mt2701: Add check for mtk_alloc_clk_data
  (git-fixes).
- clk: mediatek: clk-mt7629: Add check for mtk_alloc_clk_data
  (git-fixes).
- clk: mediatek: clk-mt7629-eth: Add check for mtk_alloc_clk_data
  (git-fixes).
- clk: mediatek: clk-mt6797: Add check for mtk_alloc_clk_data
  (git-fixes).
- clk: mediatek: clk-mt6779: Add check for mtk_alloc_clk_data
  (git-fixes).
- clk: mediatek: clk-mt6765: Add check for mtk_alloc_clk_data
  (git-fixes).
- clk: linux/clk-provider.h: fix kernel-doc warnings and typos
  (git-fixes).
- ACPI: sysfs: Fix create_pnp_modalias() and create_of_modalias()
  (git-fixes).
- =?UTF-8?q?ACPI:=20video:=20Add=20acpi=5Fbacklight=3Dvendo?=
  =?UTF-8?q?r=20quirk=20for=20Toshiba=20Port=C3=A9g=C3=A9=20R100?=
  (git-fixes).
- ACPI: property: Allow _DSD buffer data only for byte accessors
  (git-fixes).
- ACPI: FPDT: properly handle invalid FPDT subtables (git-fixes).
- Bluetooth: hci_sync: Fix Opcode prints in bt_dev_dbg/err
  (git-fixes).
- Bluetooth: hci_bcm4377: Mark bcm4378/bcm4387 as BROKEN_LE_CODED
  (git-fixes).
- can: dev: can_put_echo_skb(): don't crash kernel if
  can_priv::echo_skb is accessed out of bounds (git-fixes).
- can: dev: can_restart(): fix race condition between controller
  restart and netif_carrier_on() (git-fixes).
- can: dev: can_restart(): don't crash kernel if carrier is OK
  (git-fixes).
- can: etas_es58x: add missing a blank line after declaration
  (git-fixes).
- can: etas_es58x: rework the version check logic to silence
  - Wformat-truncation (git-fixes).
- can: sja1000: Fix comment (git-fixes).
- commit 4c5a896
* Wed Nov  1 2023 jslaby@suse.cz
- rpm/check-for-config-changes: add AS_WRUSS to IGNORED_CONFIGS_RE
  Add AS_WRUSS as an IGNORED_CONFIGS_RE entry in check-for-config-changes
  to fix build on x86_32.
  There was a fix submitted to upstream but it was not accepted:
  https://lore.kernel.org/all/20231031140504.GCZUEJkMPXSrEDh3MA@fat_crate.local/
  So carry this in IGNORED_CONFIGS_RE instead.
- commit 7acca37
* Tue Oct 31 2023 krisman@suse.de
- io_uring: kiocb_done() should *not* trust ->ki_pos if
  - >{read,write}_iter() failed (git-fixes).
- io_uring/fdinfo: lock SQ thread while retrieving thread cpu/pid
  (bsc#1216693 CVE-2023-46862).
- io_uring: fix crash with IORING_SETUP_NO_MMAP and invalid SQ
  ring address (git-fixes).
- commit 6d923bd
* Tue Oct 31 2023 krisman@suse.de
- io-wq: fully initialize wqe before calling
  cpuhp_state_add_instance_nocalls() (git-fixes).
- commit 8ccfa86
* Tue Oct 31 2023 mkoutny@suse.com
- cgroup/cpuset: Inherit parent's load balance state in v2
  (bsc#1216760).
- commit 03391cc
* Tue Oct 31 2023 mkoutny@suse.com
- net-memcg: Fix scope of sockmem pressure indicators
  (bsc#1216759).
- commit 8c6b513
* Tue Oct 31 2023 jlee@suse.com
- x86/efistub: Avoid legacy decompressor when doing EFI boot
  (jsc#PED-5458).
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch.
- x86/efistub: Perform SNP feature test while running in the
  firmware (jsc#PED-5458).
- efi/libstub: Add limit argument to efi_random_alloc()
  (jsc#PED-5458).
- x86/decompressor: Factor out kernel decompression and relocation
  (jsc#PED-5458).
- x86/decompressor: Move global symbol references to C code
  (jsc#PED-5458).
- decompress: Use 8 byte alignment (jsc#PED-5458).
- x86/efistub: Prefer EFI memory attributes protocol over DXE
  services (jsc#PED-5458).
- x86/efistub: Perform 4/5 level paging switch from the stub
  (jsc#PED-5458).
- x86/decompressor: Merge trampoline cleanup with switching code
  (jsc#PED-5458).
- x86/decompressor: Pass pgtable address to trampoline directly
  (jsc#PED-5458).
- x86/decompressor: Only call the trampoline when changing paging
  levels (jsc#PED-5458).
- x86/decompressor: Call trampoline directly from C code
  (jsc#PED-5458).
- x86/decompressor: Avoid the need for a stack in the 32-bit
  trampoline (jsc#PED-5458).
- x86/decompressor: Use standard calling convention for trampoline
  (jsc#PED-5458).
- x86/decompressor: Call trampoline as a normal function
  (jsc#PED-5458).
- x86/decompressor: Assign paging related global variables earlier
  (jsc#PED-5458).
- x86/decompressor: Store boot_params pointer in callee save
  register (jsc#PED-5458).
- x86/efistub: Clear BSS in EFI handover protocol entrypoint
  (jsc#PED-5458).
- x86/decompressor: Avoid magic offsets for EFI handover
  entrypoint (jsc#PED-5458).
- x86/efistub: Simplify and clean up handover entry code
  (jsc#PED-5458).
- x86/efistub: Branch straight to kernel entry point from C code
  (jsc#PED-5458).
- x86/head_64: Store boot_params pointer in callee save register
  (jsc#PED-5458).
- commit f5ec8bb
* Tue Oct 31 2023 tiwai@suse.de
- drivers/clocksource/timer-ti-dm: Don't call clk_get_rate()
  in stop function (git-fixes).
- dt-bindings: timer: renesas,rz-mtu3: Fix overflow/underflow
  interrupt names (git-fixes).
- PCI/MSI: Provide stubs for IMS functions (git-fixes).
- selftests/x86/lam: Zero out buffer for readlink() (git-fixes).
- objtool: Propagate early errors (git-fixes).
- iov_iter, x86: Be consistent about the __user tag on
  copy_mc_to_user() (git-fixes).
- commit 2039524
* Tue Oct 31 2023 tonyj@suse.de
- perf/core: Fix potential NULL deref (bsc#1216584 CVE-2023-5717).
- commit a0baaba
* Mon Oct 30 2023 lduncan@suse.com
- scsi: pm80xx: Avoid leaking tags when processing
  OPC_INB_SET_CONTROLLER_CONFIG command (jsc#PED-6874).
- scsi: pm80xx: Use phy-specific SAS address when sending
  PHY_START command (jsc#PED-6874).
- scsi: libsas: Delete sas_ssp_task.task_prio (jsc#PED-6874).
- scsi: libsas: Delete sas_ssp_task.enable_first_burst
  (jsc#PED-6874).
- scsi: libsas: Delete struct scsi_core (jsc#PED-6874).
- scsi: libsas: Delete enum sas_phy_type (jsc#PED-6874).
- scsi: libsas: Delete enum sas_class (jsc#PED-6874).
- scsi: libsas: Delete sas_ha_struct.lldd_module (jsc#PED-6874).
- scsi: pm80xx: Set RETFIS when requested by libsas
  (jsc#PED-6874).
- scsi: libsas: Add return_fis_on_success to sas_ata_task
  (jsc#PED-6874).
- scsi: pm8001: Remove unused declarations (jsc#PED-6874).
- scsi: pm80xx: Fix error return code in pm8001_pci_probe()
  (jsc#PED-6874).
- scsi: aacraid: Avoid -Warray-bounds warning (jsc#PED-6875).
- scsi: pm80xx: Add fatal error checks (jsc#PED-6874).
- scsi: pm80xx: Add GET_NVMD timeout during probe (jsc#PED-6874).
- scsi: pm80xx: Update PHY state after hard reset (jsc#PED-6874).
- scsi: pm80xx: Log port state during HW event (jsc#PED-6874).
- scsi: pm80xx: Log phy_id and port_id in the device registration
  request (jsc#PED-6874).
- scsi: pm80xx: Print port_id in HW events (jsc#PED-6874).
- scsi: pm80xx: Enable init logging (jsc#PED-6874).
- scsi: pm80xx: Log some HW events by default (jsc#PED-6874).
- scsi: aacraid: Replace all non-returning strlcpy with strscpy
  (jsc#PED-6875).
- commit ddefe4e
* Mon Oct 30 2023 tonyj@suse.de
- perf: Disallow mis-matched inherited group reads (bsc#1216584
  CVE-2023-5717).
- commit 9197206
* Mon Oct 30 2023 svarbanov@suse.de
- pinctrl: tegra: avoid duplicate field initializers (bsc#1216215)
- commit ef05e40
* Mon Oct 30 2023 svarbanov@suse.de
- config/arm64: Enable Tegra234 pinmux driver (bsc#1216215)
  Add a config to enable building of Tegra234 pinmux driver.
- commit d69049b
* Mon Oct 30 2023 svarbanov@suse.de
- pinctrl: tegra: Add Tegra234 pinmux driver (bsc#1216215)
- commit 519eedc
* Mon Oct 30 2023 dwagner@suse.de
- nvmet-tcp: Fix a possible UAF in queue intialization setup
  (bsc#1215768 CVE-2023-5178).
- commit ea9717a
* Sun Oct 29 2023 tiwai@suse.de
- iio: afe: rescale: Accept only offset channels (git-fixes).
- iio: exynos-adc: request second interupt only when touchscreen
  mode is used (git-fixes).
- iio: adc: xilinx-xadc: Correct temperature offset/scale for
  UltraScale (git-fixes).
- iio: adc: xilinx-xadc: Don't clobber preset voltage/temperature
  thresholds (git-fixes).
- misc: fastrpc: Unmap only if buffer is unmapped from DSP
  (git-fixes).
- misc: fastrpc: Clean buffers on remote invocation failures
  (git-fixes).
- misc: fastrpc: Free DMA handles for RPC calls with no arguments
  (git-fixes).
- misc: fastrpc: Reset metadata buffer to avoid incorrect free
  (git-fixes).
- i2c: stm32f7: Fix PEC handling in case of SMBUS transfers
  (git-fixes).
- i2c: muxes: i2c-mux-gpmux: Use of_get_i2c_adapter_by_node()
  (git-fixes).
- i2c: muxes: i2c-demux-pinctrl: Use of_get_i2c_adapter_by_node()
  (git-fixes).
- i2c: muxes: i2c-mux-pinctrl: Use of_get_i2c_adapter_by_node()
  (git-fixes).
- i2c: aspeed: Fix i2c bus hang in slave read (git-fixes).
- ARM: OMAP: timer32K: fix all kernel-doc warnings (git-fixes).
- arm64: dts: rockchip: Fix i2s0 pin conflict on ROCK Pi 4 boards
  (git-fixes).
- arm64: dts: rockchip: Add i2s0-2ch-bus-bclk-off pins to RK3399
  (git-fixes).
- arm64: dts: rockchip: set codec system-clock-fixed on
  px30-ringneck-haikou (git-fixes).
- arm64: dts: rockchip: use codec as clock master on
  px30-ringneck-haikou (git-fixes).
- arm64: dts: qcom: msm8996-xiaomi: fix missing clock populate
  (git-fixes).
- arm64: dts: qcom: apq8096-db820c: fix missing clock populate
  (git-fixes).
- arm64: dts: qcom: sa8775p: correct PMIC GPIO label in
  gpio-ranges (git-fixes).
- firmware/imx-dsp: Fix use_after_free in imx_dsp_setup_channels()
  (git-fixes).
- wifi: mac80211: don't drop all unprotected public action frames
  (git-fixes).
- wifi: cfg80211: fix assoc response warning on failed links
  (git-fixes).
- wifi: cfg80211: pass correct pointer to rdev_inform_bss()
  (git-fixes).
- r8152: Release firmware if we have an error in probe
  (git-fixes).
- r8152: Cancel hw_phy_work if we have an error in probe
  (git-fixes).
- r8152: Run the unload routine if we have errors during probe
  (git-fixes).
- r8152: Increase USB control msg timeout to 5000ms as per spec
  (git-fixes).
- net: usb: smsc95xx: Fix uninit-value access in smsc95xx_read_reg
  (git-fixes).
- net: ieee802154: adf7242: Fix some potential buffer overflow
  in adf7242_stats_show() (git-fixes).
- treewide: Spelling fix in comment (git-fixes).
- commit fcf0a1e
* Fri Oct 27 2023 msuchanek@suse.de
- powerpc/stacktrace: Fix arch_stack_walk_reliable()
  (bsc#1215199).
- commit e0a2d02
* Fri Oct 27 2023 msuchanek@suse.de
- powerpc/pseries: Fix STK_PARAM access in the hcall tracing code
  (bsc#1215199).
- commit 17dca43
* Fri Oct 27 2023 msuchanek@suse.de
- powerpc/qspinlock: Fix stale propagated yield_cpu (bsc#1215199).
- commit 3d91081
* Fri Oct 27 2023 msuchanek@suse.de
- powerpc/pseries: use kfree_sensitive() in plpks_gen_password()
  (bsc#1215199).
- commit 928df42
* Fri Oct 27 2023 msuchanek@suse.de
- Refresh patches.suse/integrity-powerpc-Do-not-select-CA_MACHINE_KEYRING.patch.
  Update patch metadata.
- commit 42c8385
* Fri Oct 27 2023 clin@suse.com
- supported.conf: Add ultrasoc-smb support (jsc#PED-4733)
- commit a3bd516
* Fri Oct 27 2023 vkarasulli@suse.de
- Update
  patches.suse/0001-x86-sev-Disable-MMIO-emulation-from-user-mode.patch
  (bsc#1212649 CVE-2023-46813).
- Update
  patches.suse/0002-x86-sev-Check-IOBM-for-IOIO-exceptions-from-user-spa.patch
  (bsc#1212649 CVE-2023-46813).
- Update
  patches.suse/0003-x86-sev-Check-for-user-space-IOIO-pointing-to-kernel.patch
  (bsc#1212649 CVE-2023-46813).
- commit 5ed02d6
* Thu Oct 26 2023 jack@suse.cz
- quota: rename dquot_active() to inode_quota_active()
  (bsc#1214997).
- commit 7b1c518
* Thu Oct 26 2023 jack@suse.cz
- quota: Fix slow quotaoff (bsc#1216621)
- commit 8f9ab60
* Thu Oct 26 2023 jack@suse.cz
- quota: fix dqput() to follow the guarantees dquot_srcu should
  provide (bsc#1214963).
- commit bd9f623
* Thu Oct 26 2023 jack@suse.cz
- quota: add new helper dquot_active() (bsc#1214998).
- commit a6eddf2
* Thu Oct 26 2023 jack@suse.cz
- quota: factor out dquot_write_dquot() (bsc#1214995).
- commit 580a3c6
* Thu Oct 26 2023 jack@suse.cz
- jbd2: correct the end of the journal recovery scan range
  (bsc#1214955).
- commit 2b92f59
* Thu Oct 26 2023 jack@suse.cz
- jbd2: check 'jh->b_transaction' before removing it from
  checkpoint (bsc#1214953).
- commit 9e3e6a0
* Thu Oct 26 2023 jack@suse.cz
- jbd2: fix checkpoint cleanup performance regression
  (bsc#1214952).
- commit ef5fb7d
* Thu Oct 26 2023 jack@suse.cz
- ext4: avoid potential data overflow in next_linear_group
  (bsc#1214951).
- commit 785ff8e
* Thu Oct 26 2023 jack@suse.cz
- block/mq-deadline: use correct way to throttling write requests
  (bsc#1214993).
- commit 6d6927a
* Thu Oct 26 2023 vkarasulli@suse.de
- x86/sev: Check for user-space IOIO pointing to kernel space
  (bsc#1212649).
- x86/sev: Check IOBM for IOIO exceptions from user-space
  (bsc#1212649).
- x86/sev: Disable MMIO emulation from user mode (bsc#1212649).
- commit ccb5459
* Thu Oct 26 2023 tiwai@suse.de
- Disable CONFIG_IA32_EMULATION_DEFAULT_DISABLED again (jsc#PED-3184)
- commit f4027be
* Thu Oct 26 2023 hare@suse.de
- ata: libata-eh: do not clear ATA_PFLAG_EH_PENDING in
  ata_eh_reset() (bsc#1216436).
- commit c6250f7
* Thu Oct 26 2023 hare@suse.de
- ata: libata: remove references to non-existing error_handler()
  (bsc#1216436).
- Refresh
  patches.suse/ata-libata-core-Fix-port-and-device-removal.patch.
- commit 69b2823
* Thu Oct 26 2023 hare@suse.de
- PM: hibernate: fix resume_store() return value when hibernation
  not available (bsc#1216436).
- commit 2d0c292
* Thu Oct 26 2023 tiwai@suse.de
- net: rfkill: reduce data->mtx scope in rfkill_fop_open
  (git-fixes).
- commit e434c5e
* Thu Oct 26 2023 hare@suse.de
- ata: libata-core: fix when to fetch sense data for successful
  commands (bsc#1216436).
- commit 5246ba2
* Thu Oct 26 2023 tiwai@suse.de
- Bluetooth: hci_sync: delete CIS in BT_OPEN/CONNECT/BOUND when
  aborting (git-fixes).
- Refresh
  patches.suse/Bluetooth-hci_sync-Fix-UAF-in-hci_disconnect_all_syn.patch.
- Refresh
  patches.suse/Bluetooth-hci_sync-Fix-UAF-on-hci_abort_conn_sync.patch.
- commit a7663b4
* Thu Oct 26 2023 tiwai@suse.de
- selftests/ftrace: Add new test case which checks non unique
  symbol (git-fixes).
- platform/x86: asus-wmi: Map 0x2a code, Ignore 0x2b and 0x2c
  events (git-fixes).
- platform/x86: asus-wmi: Only map brightness codes when using
  asus-wmi backlight control (git-fixes).
- platform/x86: asus-wmi: Change ASUS_WMI_BRN_DOWN code from
  0x20 to 0x2e (git-fixes).
- USB: serial: option: add Fibocom to DELL custom modem FM101R-GL
  (git-fixes).
- USB: serial: option: add entry for Sierra EM9191 with new
  firmware (git-fixes).
- USB: serial: option: add Telit LE910C4-WWX 0x1035 composition
  (git-fixes).
- mmc: core: Capture correct oemid-bits for eMMC cards
  (git-fixes).
- mmc: core: Fix error propagation for some ioctl commands
  (git-fixes).
- Bluetooth: hci_sock: Correctly bounds check and pad
  HCI_MON_NEW_INDEX name (git-fixes).
- Bluetooth: avoid memcmp() out of bounds warning (git-fixes).
- Bluetooth: hci_sock: fix slab oob read in create_monitor_event
  (git-fixes).
- Bluetooth: hci_event: Fix coding style (git-fixes).
- Bluetooth: hci_sync: always check if connection is alive before
  deleting (git-fixes).
- Bluetooth: Reject connection with the device which has same
  BD_ADDR (git-fixes).
- Bluetooth: ISO: Fix invalid context error (git-fixes).
- Bluetooth: vhci: Fix race when opening vhci device (git-fixes).
- platform/x86: touchscreen_dmi: Add info for the Positivo C4128B
  (git-fixes).
- platform/x86: touchscreen_dmi: Add info for the BUSH Bush
  Windows tablet (git-fixes).
- HID: Add quirk to ignore the touchscreen battery on HP ENVY
  15-eu0556ng (git-fixes).
- HID: nintendo: reinitialize USB Pro Controller after resuming
  from suspend (git-fixes).
- HID: multitouch: Add required quirk for Synaptics 0xcd7e device
  (git-fixes).
- HID: holtek: fix slab-out-of-bounds Write in
  holtek_kbd_input_event (git-fixes).
- HID: logitech-hidpp: Add Bluetooth ID for the Logitech M720
  Triathlon mouse (git-fixes).
- wifi: cfg80211: avoid leaking stack data into trace (git-fixes).
- wifi: mac80211: allow transmitting EAPOL frames with tainted
  key (git-fixes).
- wifi: mac80211: work around Cisco AP 9115 VHT MPDU length
  (git-fixes).
- wifi: cfg80211: Fix 6GHz scan configuration (git-fixes).
- rfkill: sync before userspace visibility/changes (git-fixes).
- wifi: iwlwifi: Ensure ack flag is properly cleared (git-fixes).
- wifi: cfg80211: validate AP phy operation before starting it
  (git-fixes).
- wifi: mwifiex: Sanity check tlv_len and tlv_bitmap_len
  (git-fixes).
- Bluetooth: hci_core: Fix build warnings (git-fixes).
- Bluetooth: Avoid redundant authentication (git-fixes).
- Bluetooth: btusb: add shutdown function for QCA6174 (git-fixes).
- selftests/mm: fix awk usage in charge_reserved_hugetlb.sh and
  hugetlb_reparenting_test.sh that may cause error (git-fixes).
- i2c: mux: Avoid potential false error message in
  i2c_mux_add_adapter (git-fixes).
- accel/ivpu: Don't flood dmesg with VPU ready message
  (git-fixes).
- gpio: timberdale: Fix potential deadlock on &tgpio->lock
  (git-fixes).
- Bluetooth: hci_sync: Introduce PTR_UINT/UINT_PTR macros
  (git-fixes).
- Bluetooth: hci_conn: Fix modifying handle while aborting
  (git-fixes).
- Bluetooth: hci_sync: Fix not handling ISO_LINK in
  hci_abort_conn_sync (git-fixes).
- commit 6c9ea2b
* Thu Oct 26 2023 hare@suse.de
- fs: buffer: use __bio_add_page to add single page to bio
  (bsc#1216436).
- dm: dm-zoned: use __bio_add_page for adding single metadata page
  (bsc#1216436).
- commit 6413c7c
* Thu Oct 26 2023 hare@suse.de
- floppy: use __bio_add_page for adding single page to bio
  (bsc#1216436).
- zram: use __bio_add_page for adding single page to bio
  (bsc#1216436).
- zonefs: use __bio_add_page for adding single page to bio
  (bsc#1216436).
- gfs2: use __bio_add_page for adding single page to bio
  (bsc#1216436).
- jfs: logmgr: use __bio_add_page to add single page to bio
  (bsc#1216436).
- md: raid5: use __bio_add_page to add single page to new bio
  (bsc#1216436).
- md: raid5-log: use __bio_add_page to add single page
  (bsc#1216436).
- md: use __bio_add_page to add single page (bsc#1216436).
- swap: use __bio_add_page to add page to bio (bsc#1216436).
- commit 936fc88
* Wed Oct 25 2023 lduncan@suse.com
- scsi: pmcraid: Use pci_dev_id() to simplify the code
  (jsc#PED-6876).
- commit b91c280
* Wed Oct 25 2023 tiwai@suse.de
- maple_tree: add GFP_KERNEL to allocations in
  mas_expected_entries() (git-fixes).
- commit 7b18b6a
* Tue Oct 24 2023 mwilck@suse.com
- nvme-fc: Prevent null pointer dereference in
  nvme_fc_io_getuuid() (bsc#1214842).
- commit 5b24bcd
* Tue Oct 24 2023 tiwai@suse.de
- ubi: Refuse attaching if mtd's erasesize is 0 (CVE-2023-31085
  bsc#1210778).
- commit fe27c91
* Tue Oct 24 2023 hare@suse.de
- ata: libata-core: fetch sense data for successful commands
  iff CDL enabled (bsc#1216436).
- ata: libata-eh: do not thaw the port twice in ata_eh_reset() (bsc#1216436).
- commit 8140c93
* Tue Oct 24 2023 hare@suse.de
- ata: libata: remove deprecated EH callbacks (bsc#1216436).
- ata: libata-core: remove ata_bus_probe() (bsc#1216436).
- ata: sata_sx4: drop already completed TODO (bsc#1216436).
- ata,scsi: remove ata_sas_port_init() (bsc#1216436).
- ata,scsi: cleanup __ata_port_probe() (bsc#1216436).
- ata: libata-core: inline ata_port_probe() (bsc#1216436).
- ata: libata-sata: remove ata_sas_sync_probe() (bsc#1216436).
- ata,scsi: remove ata_sas_port_destroy() (bsc#1216436).
- ata,scsi: remove ata_sas_port_{start,stop} callbacks (bsc#1216436).
- commit 479419d
* Tue Oct 24 2023 hare@suse.de
- ata: libata-sata: Improve ata_change_queue_depth()
  (bsc#1216436).
- commit 7abb4aa
* Tue Oct 24 2023 hare@suse.de
- ata: ahci_octeon: Remove unnecessary include (bsc#1216436).
- ata: pata_octeon_cf: Add missing header include (bsc#1216436).
- ata: ahci: Cleanup ahci_reset_controller() (bsc#1216436).
- ata: Use of_property_read_reg() to parse "reg" (bsc#1216436).
- ata: libata-scsi: Use ata_ncq_supported in (bsc#1216436).
- ata: libata-eh: Use ata_ncq_enabled() in ata_eh_speed_down()
  (bsc#1216436).
- ata: libata-sata: Simplify ata_change_queue_depth()
  (bsc#1216436).
- commit a819779
* Tue Oct 24 2023 hare@suse.de
- ata: libata-eh: Clarify ata_eh_qc_retry() behavior at call
  (bsc#1216436).
- commit fda3e7d
* Tue Oct 24 2023 hare@suse.de
- block: uapi: Fix compilation errors using ioprio.h with C++
  (bsc#1216436).
- block: fix rootwait= again (bsc#1216436).
- commit 40a1246
* Tue Oct 24 2023 hare@suse.de
- PM: hibernate: Fix writing maj:min to /sys/power/resume
  (bsc#1216436).
- scsi: block: Improve ioprio value validity checks (bsc#1216436).
- scsi: ata: libata-scsi: Fix ata_msense_control kdoc comment
  (bsc#1216436).
- block: don't return -EINVAL for not found names in
  (bsc#1216436).
- block: fix rootwait= (bsc#1216436).
- commit caf530a
* Tue Oct 24 2023 tiwai@suse.de
- net: rfkill: gpio: prevent value glitch during probe
  (git-fixes).
- net: usb: smsc95xx: Fix an error code in smsc95xx_reset()
  (git-fixes).
- gve: Do not fully free QPL pages on prefill errors (git-fixes).
- commit 8715cb1
* Mon Oct 23 2023 lduncan@suse.com
- scsi: qla2xxx: Fix double free of dsd_list during driver load
  (git-fixes).
- commit 6a26394
* Mon Oct 23 2023 mwilck@suse.com
- scsi: mpt3sas: Fix in error path (bsc#1216435, jsc#PED-6835,
  jsc#PED-6936).
- scsi: mpt3sas: Remove volatile qualifier (bsc#1216435,
  jsc#PED-6835, jsc#PED-6936).
- commit f8805cf
* Mon Oct 23 2023 mwilck@suse.com
- scsi: megaraid_sas: Driver version update to 07.727.03.00-rc1
  (bsc#1216435, jsc#PED-6384, jsc#PED-6937).
- scsi: megaraid_sas: Log message when controller reset
  is requested but not issued (bsc#1216435, jsc#PED-6384,
  jsc#PED-6937).
- scsi: megaraid_sas: Increase register read retry rount from
  3 to 30 for selected registers (bsc#1216435, jsc#PED-6384,
  jsc#PED-6937).
- commit 37d282c
* Mon Oct 23 2023 mwilck@suse.com
- scsi: megaraid: Pass in NULL scb for host reset (bsc#1216435,
  jsc#PED-6384, jsc#PED-6937).
- commit 87b74dd
* Mon Oct 23 2023 mwilck@suse.com
- scsi: megaraid_sas: Fix deadlock on firmware crashdump
  (bsc#1216435, jsc#PED-6384, jsc#PED-6937).
- scsi: megaraid: Use pci_dev_id() to simplify the code
  (bsc#1216435, jsc#PED-6384, jsc#PED-6937).
- scsi: megaraid_sas: Use pci_dev_id() to simplify the code
  (bsc#1216435, jsc#PED-6384, jsc#PED-6937).
- scsi: Add HAS_IOPORT dependencies (bsc#1216435, jsc#PED-6384,
  jsc#PED-6937).
- scsi: megaraid_sas: Convert union megasas_sgl to flex-arrays
  (bsc#1216435, jsc#PED-6384, jsc#PED-6937).
- commit 67b8176
* Mon Oct 23 2023 mfranc@suse.cz
- s390/pci: fix iommu bitmap allocation (git-fixes bsc#1216507).
- commit ad465bf
* Mon Oct 23 2023 mfranc@suse.cz
- s390/cio: fix a memleak in css_alloc_subchannel (git-fixes
  bsc#1216505).
- commit 5731d29
* Mon Oct 23 2023 tiwai@suse.de
- Update vanilla config files to fix build breakage
- commit 3ddde7f
* Mon Oct 23 2023 tiwai@suse.de
- phy: qcom-qmp-combo: initialize PCS_USB registers (git-fixes).
- phy: qcom-qmp-combo: Square out 8550 POWER_STATE_CONFIG1
  (git-fixes).
- phy: qcom-qmp-usb: initialize PCS_USB registers (git-fixes).
- phy: mapphone-mdm6600: Fix pinctrl_pm handling for sleep pins
  (git-fixes).
- phy: mapphone-mdm6600: Fix runtime PM for remove (git-fixes).
- phy: mapphone-mdm6600: Fix runtime disable on probe (git-fixes).
- efi/unaccepted: Fix soft lockups caused by parallel memory
  acceptance (git-fixes).
- efi/x86: Ensure that EFI_RUNTIME_MAP is enabled for kexec
  (git-fixes).
- commit dd0ca5b
* Mon Oct 23 2023 hare@suse.de
- Update
  patches.suse/blk-flush-fix-rq-flush.seq-for-post-flush-requests.patch
  (jsc#PED-5728).
- Update
  patches.suse/blk-ioc-fix-recursive-spin_lock-unlock_irq-in-ioc_cl.patch
  (jsc#PED-5728).
- Update
  patches.suse/blk-ioc-protect-ioc_destroy_icq-by-queue_lock.patch
  (jsc#PED-5728).
- Update
  patches.suse/blk-mq-defer-to-the-normal-submission-path-for-non-f.patch
  (jsc#PED-5728).
- Update
  patches.suse/blk-mq-defer-to-the-normal-submission-path-for-post-.patch
  (jsc#PED-5728).
- Update
  patches.suse/blk-mq-do-not-do-head-insertions-post-pre-flush-comm.patch
  (jsc#PED-5728).
- Update
  patches.suse/blk-mq-don-t-use-the-requeue-list-to-queue-flush-com.patch
  (jsc#PED-5728).
- Update
  patches.suse/blk-mq-factor-out-a-blk_rq_init_flush-helper.patch
  (jsc#PED-5728).
- Update
  patches.suse/blk-mq-fix-two-misuses-on-RQF_USE_SCHED.patch
  (jsc#PED-5728).
- Update
  patches.suse/blk-mq-make-sure-elevator-callbacks-aren-t-called-fo.patch
  (jsc#PED-5728).
- Update patches.suse/blk-mq-reflow-blk_insert_flush.patch
  (jsc#PED-5728).
- Update
  patches.suse/blk-mq-release-scheduler-resource-when-request-compl.patch
  (jsc#PED-5728).
- Update patches.suse/blk-mq-remove-RQF_ELVPRIV.patch
  (jsc#PED-5728).
- Update
  patches.suse/blk-mq-use-the-I-O-scheduler-for-writes-from-the-flu.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-Add-PR-callouts-for-read-keys-and-reservation.patch
  (jsc#PED-5728).
- Update patches.suse/block-BFQ-Add-several-invariant-checks.patch
  (jsc#PED-5728).
- Update patches.suse/block-BFQ-Move-an-invariant-check.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-Introduce-blk_rq_is_seq_zoned_write.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-Introduce-op_needs_zoned_write_locking.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-Rename-BLK_STS_NEXUS-to-BLK_STS_RESV_CONFLICT.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-Replace-all-non-returning-strlcpy-with-strscpy.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-Simplify-blk_req_needs_zone_write_lock.patch
  (jsc#PED-5728).
- Update patches.suse/block-add-a-mark_dead-holder-operation.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-avoid-repeated-work-in-blk_mark_disk_dead.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-consolidate-the-shutdown-logic-in-blk_mark_dis.patch
  (jsc#PED-5728).
- Update patches.suse/block-constify-partition-prober-array.patch
  (jsc#PED-5728).
- Update patches.suse/block-constify-struct-part_attr_group.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-constify-struct-part_type-part_type.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-constify-the-whole_disk-device_attribute.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-delete-partitions-later-in-del_gendisk.patch
  (jsc#PED-5728).
- Update patches.suse/block-don-t-plug-in-blkdev_write_iter.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-factor-out-a-bd_end_claim-helper-from-blkdev_p.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-introduce-block_io_start-block_io_done-tracepo.patch
  (jsc#PED-5728).
- Update patches.suse/block-introduce-holder-ops.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-mq-deadline-Add-a-word-in-a-source-code-commen.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-mq-deadline-Clean-up-deadline_check_fifo.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-mq-deadline-Fix-a-bug-in-deadline_from_pos.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-mq-deadline-Fix-handling-of-at-head-zoned-writ.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-mq-deadline-Handle-requeued-requests-correctly.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-mq-deadline-Reduce-lock-contention.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-mq-deadline-Simplify-deadline_skip_seq_writes.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-mq-deadline-Track-the-dispatch-position.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-queue-data-commands-from-the-flush-state-machi.patch
  (jsc#PED-5728).
- Update patches.suse/block-refactor-bd_may_claim.patch
  (jsc#PED-5728).
- Update patches.suse/block-remove-blk_drop_partitions.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-remove-redundant-req_op-in-blk_rq_is_passthrou.patch
  (jsc#PED-5728).
- Update patches.suse/block-turn-bdev_lock-into-a-mutex.patch
  (jsc#PED-5728).
- Update
  patches.suse/block-unhash-the-inode-earlier-in-delete_partition.patch
  (jsc#PED-5728).
- Update
  patches.suse/dm-Add-support-for-block-PR-read-keys-reservation.patch
  (jsc#PED-5728).
- Update
  patches.suse/fs-remove-the-special-CONFIG_BLOCK-def_blk_fops.patch
  (jsc#PED-5728).
- Update patches.suse/nvme-Add-a-nvme_pr_type-enum.patch
  (jsc#PED-5728).
- Update patches.suse/nvme-Add-helper-to-send-pr-command.patch
  (jsc#PED-5728).
- Update patches.suse/nvme-Add-pr_ops-read_keys-support.patch
  (jsc#PED-5728).
- Update
  patches.suse/nvme-Add-pr_ops-read_reservation-support.patch
  (jsc#PED-5728).
- Update
  patches.suse/nvme-Don-t-hardcode-the-data-len-for-pr-commands.patch
  (jsc#PED-5728).
- Update
  patches.suse/nvme-Fix-reservation-status-related-structs.patch
  (jsc#PED-5728).
- Update patches.suse/nvme-Move-pr-code-to-it-s-own-file.patch
  (jsc#PED-5728).
- Update
  patches.suse/scsi-Add-support-for-block-PR-read-keys-reservation.patch
  (jsc#PED-5728).
- Update patches.suse/scsi-Move-sd_pr_type-to-scsi_common.patch
  (jsc#PED-5728).
- Update patches.suse/scsi-Rename-sd_pr_command.patch
  (jsc#PED-5728).
- Update
  patches.suse/scsi-target-Add-block-PR-support-to-iblock.patch
  (jsc#PED-5728).
- Update
  patches.suse/scsi-target-Allow-backends-to-hook-into-PR-handling.patch
  (jsc#PED-5728).
- Update
  patches.suse/scsi-target-Pass-struct-target_opcode_descriptor-to-.patch
  (jsc#PED-5728).
- Update
  patches.suse/scsi-target-Rename-sbc_ops-to-exec_cmd_ops.patch
  (jsc#PED-5728).
- Update
  patches.suse/scsi-target-Report-and-detect-unsupported-PR-command.patch
  (jsc#PED5728).
- commit 5348bdb
* Sun Oct 22 2023 tiwai@suse.de
- gpiolib: acpi: Add missing memset(0) to
  acpi_get_gpiod_from_data() (git-fixes).
- gpio: vf610: set value before the direction to avoid a glitch
  (git-fixes).
- gpio: vf610: mask the gpio irq in system suspend and support
  wakeup (git-fixes).
- rust: error: Markdown style nit (git-fixes).
- rust: error: fix the description for `ECHILD` (git-fixes).
- apple-gmux: Hard Code max brightness for MMIO gmux (git-fixes).
- platform/surface: platform_profile: Propagate error if profile
  registration fails (git-fixes).
- platform/x86: msi-ec: Fix the 3rd config (git-fixes).
- platform/x86: intel-uncore-freq: Conditionally create attribute
  for read frequency (git-fixes).
- thunderbolt: Call tb_switch_put() once DisplayPort bandwidth
  request is finished (git-fixes).
- KEYS: asymmetric: Fix sign/verify on pkcs1pad without a hash
  (git-fixes).
- commit 26b3332
* Sat Oct 21 2023 tiwai@suse.de
- ALSA: hda/realtek - Fixed ASUS platform headset Mic issue
  (git-fixes).
- ALSA: hda/realtek: Add quirk for ASUS ROG GU603ZV (git-fixes).
- ALSA: hda/relatek: Enable Mute LED on HP Laptop 15s-fq5xxx
  (git-fixes).
- commit 67f74c9
* Sat Oct 21 2023 tiwai@suse.de
- ACPI: irq: Fix incorrect return value in acpi_register_gsi()
  (git-fixes).
- ACPI: bus: Move acpi_arm_init() to the place of after
  acpi_ghes_init() (git-fixes).
- Revert "pinctrl: avoid unsafe code pattern in find_pinctrl()"
  (git-fixes).
- pinctrl: qcom: lpass-lpi: fix concurrent register updates
  (git-fixes).
- mtd: rawnand: Ensure the nand chip supports cached reads
  (git-fixes).
- mtd: rawnand: qcom: Unmap the right resource upon probe failure
  (git-fixes).
- mtd: rawnand: pl353: Ensure program page operations are
  successful (git-fixes).
- mtd: rawnand: arasan: Ensure program page operations are
  successful (git-fixes).
- mtd: spinand: micron: correct bitmask for ecc status
  (git-fixes).
- mtd: physmap-core: Restore map_rom fallback (git-fixes).
- mtd: rawnand: marvell: Ensure program page operations are
  successful (git-fixes).
- mmc: mtk-sd: Use readl_poll_timeout_atomic in msdc_reset_hw
  (git-fixes).
- mmc: sdhci-pci-gli: fix LPM negotiation so x86/S0ix SoCs can
  suspend (git-fixes).
- mmc: core: sdio: hold retuning if sdio in 1-bit mode
  (git-fixes).
- dt-bindings: mmc: sdhci-msm: correct minimum number of clocks
  (git-fixes).
- ASoC: cs42l42: Fix missing include of gpio/consumer.h
  (git-fixes).
- ASoC: cs35l56: ASP1 DOUT must default to Hi-Z when not
  transmitting (git-fixes).
- ASoC: codecs: wcd938x-sdw: fix runtime PM imbalance on probe
  errors (git-fixes).
- ASoC: codecs: wcd938x-sdw: fix use after free on driver unbind
  (git-fixes).
- ASoC: codecs: wcd938x: fix runtime PM imbalance on remove
  (git-fixes).
- ASoC: codecs: wcd938x: fix regulator leaks on probe errors
  (git-fixes).
- ASoC: codecs: wcd938x: fix resource leaks on bind errors
  (git-fixes).
- ASoC: codecs: wcd938x: fix unbind tear down order (git-fixes).
- ASoC: codecs: wcd938x: drop bogus bind error handling
  (git-fixes).
- ASoC: pxa: fix a memory leak in probe() (git-fixes).
- ASoC: cs35l56: Fix illegal use of init_completion() (git-fixes).
- Revert "accel/ivpu: Use cached buffers for FW loading"
  (git-fixes).
- commit 14a1c75
* Fri Oct 20 2023 mwilck@suse.com
- qedf: Wait for stag work during unload (bsc#1214852).
- qedf: Don't process stag work during unload (bsc#1214852).
- commit dcc092a
* Fri Oct 20 2023 jwiesner@suse.de
- bonding: Return pointer to data after pull on skb (bsc#1214754).
- commit 03a709a
* Fri Oct 20 2023 tiwai@suse.de
- usb: cdns3: Modify the return value of cdns_set_active ()
  to void when CONFIG_PM_SLEEP is disabled (git-fixes).
- commit 67c5409
* Fri Oct 20 2023 tiwai@suse.de
- usb: hub: Guard against accesses to uninitialized BOS
  descriptors (git-fixes).
- thunderbolt: Check that lane 1 is in CL0 before enabling lane
  bonding (git-fixes).
- thunderbolt: Workaround an IOMMU fault on certain systems with
  Intel Maple Ridge (git-fixes).
- Input: powermate - fix use-after-free in
  powermate_config_complete (git-fixes).
- Input: xpad - add PXN V900 support (git-fixes).
- Input: goodix - ensure int GPIO is in input for gpio_count ==
  1 && gpio_int_idx == 0 case (git-fixes).
- Input: i8042 - add Fujitsu Lifebook E5411 to i8042 quirk table
  (git-fixes).
- pinctrl: avoid unsafe code pattern in find_pinctrl()
  (git-fixes).
- of: dynamic: Fix potential memory leak in of_changeset_action()
  (git-fixes).
- wifi: brcmfmac: Replace 1-element arrays with flexible arrays
  (git-fixes).
- wifi: cfg80211: add missing kernel-doc for cqm_rssi_work
  (git-fixes).
- power: supply: ab8500: Set typing and props (git-fixes).
- media: vb2: frame_vector.c: replace WARN_ONCE with a comment
  (git-fixes).
- spi: stm32: add a delay before SPI disable (git-fixes).
- spi: nxp-fspi: reset the FLSHxCR1 registers (git-fixes).
- thermal/of: add missing of_node_put() (git-fixes).
- platform/x86: asus-wmi: Support 2023 ROG X16 tablet mode
  (git-fixes).
- spi: sun6i: fix race between DMA RX transfer completion and
  RX FIFO drain (git-fixes).
- spi: sun6i: reduce DMA RX transfer width to single byte
  (git-fixes).
- mtd: spi-nor: Correct flags for Winbond w25q128 (git-fixes).
- media: pci: cx23885: replace BUG with error return (git-fixes).
- media: tuners: qt1010: replace BUG_ON with a regular error
  (git-fixes).
- media: dvb-usb-v2: gl861: Fix null-ptr-deref in
  gl861_i2c_master_xfer (git-fixes).
- media: az6007: Fix null-ptr-deref in az6007_i2c_xfer()
  (git-fixes).
- media: anysee: fix null-ptr-deref in anysee_master_xfer
  (git-fixes).
- media: af9005: Fix null-ptr-deref in af9005_i2c_xfer
  (git-fixes).
- media: dw2102: Fix null-ptr-deref in dw2102_i2c_transfer()
  (git-fixes).
- media: dvb-usb-v2: af9035: Fix null-ptr-deref in
  af9035_i2c_master_xfer (git-fixes).
- media: mdp3: Fix resource leaks in of_find_device_by_node
  (git-fixes).
- usb: chipidea: add workaround for chipidea PEC bug (git-fixes).
- usb: ehci: add workaround for chipidea PORTSC.PEC bug
  (git-fixes).
- usb: gadget: fsl_qe_udc: validate endpoint index for ch9 udc
  (git-fixes).
- usb: cdns3: Put the cdns set active part outside the spin lock
  (git-fixes).
- wifi: ath12k: add check max message length while scanning with
  extraie (git-fixes).
- wifi: ath12k: Fix memory leak in rx_desc and tx_desc
  (git-fixes).
- wifi: mac80211_hwsim: drop short frames (git-fixes).
- wifi: mac80211: check for station first in client probe
  (git-fixes).
- wifi: cfg80211: ocb: don't leave if not joined (git-fixes).
- wifi: cfg80211: reject auth/assoc to AP with our address
  (git-fixes).
- wifi: mac80211: check S1G action frame size (git-fixes).
- wifi: iwlwifi: pcie: avoid a warning in case prepare card failed
  (git-fixes).
- wifi: ath12k: avoid array overflow of hw mode for
  preferred_hw_mode (git-fixes).
- wifi: ath12k: Fix a NULL pointer dereference in
  ath12k_mac_op_hw_scan() (git-fixes).
- wifi: wil6210: fix fortify warnings (git-fixes).
- wifi: ath9k: fix printk specifier (git-fixes).
- wifi: ath9k: fix fortify warnings (git-fixes).
- mt76: mt7921: don't assume adequate headroom for SDIO headers
  (git-fixes).
- wifi: mwifiex: fix fortify warning (git-fixes).
- wifi: rtw88: delete timer and free skb queue when unloading
  (git-fixes).
- mmc: sdhci-esdhc-imx: improve ESDHC_FLAG_ERR010450 (git-fixes).
- tpm_tis: Resend command to recover from data transfer errors
  (git-fixes).
- commit 5c51dbd
* Fri Oct 20 2023 tiwai@suse.de
- HID: logitech-hidpp: Fix kernel crash on receiver USB disconnect
  (git-fixes).
- ASoC: Intel: soc-acpi: Add entry for HDMI_In capture support
  in MTL match table (git-fixes).
- ASoC: Intel: soc-acpi: Add entry for sof_es8336 in MTL match
  table (git-fixes).
- ASoC: Intel: sof_sdw: add support for SKU 0B14 (git-fixes).
- bus: ti-sysc: Fix SYSC_QUIRK_SWSUP_SIDLE_ACT handling for uart
  wake-up (git-fixes).
- ASoC: SOF: Intel: MTL: Reduce the DSP init timeout (git-fixes).
- ASoC: SOF: sof-audio: Fix DSP core put imbalance on widget
  setup failure (git-fixes).
- ASoC: imx-rpmsg: Set ignore_pmdown_time for dai_link
  (git-fixes).
- ASoC: cs42l42: Avoid stale SoundWire ATTACH after hard reset
  (git-fixes).
- ASoC: cs42l42: Don't rely on GPIOD_OUT_LOW to set RESET
  initially low (git-fixes).
- ASoC: cs42l42: Ensure a reset pulse meets minimum pulse width
  (git-fixes).
- ASoC: wm_adsp: Fix missing locking in wm_adsp_[read|write]_ctl()
  (git-fixes).
- firmware: cirrus: cs_dsp: Only log list of algorithms in debug
  build (git-fixes).
- ASoC: rt5640: Only cancel jack-detect work on suspend if active
  (git-fixes).
- ASoC: cs35l56: Disable low-power hibernation mode (git-fixes).
- ASoC: fsl: imx-pcm-rpmsg: Add SNDRV_PCM_INFO_BATCH flag
  (git-fixes).
- Add DMI ID for MSI Bravo 15 B7ED (git-fixes).
- ASoC: cs35l56: Call pm_runtime_dont_use_autosuspend()
  (git-fixes).
- Input: tca6416-keypad - fix interrupt enable disbalance
  (git-fixes).
- Input: tca6416-keypad - always expect proper IRQ number in
  i2c client (git-fixes).
- ata: ahci: Add Elkhart Lake AHCI controller (git-fixes).
- bus: ti-sysc: Configure uart quirks for k3 SoC (git-fixes).
- firmware: arm_scmi: Harden perf domain info access (git-fixes).
- Fix nomenclature for USB and PCI wireless devices (git-fixes).
- Bluetooth: btusb: Add support for another MediaTek 7922 VID/PID
  (git-fixes).
- Bluetooth: Fix hci_suspend_sync crash (git-fixes).
- Bluetooth: btusb: Add new VID/PID 04ca/3804 for MT7922
  (git-fixes).
- Bluetooth: btusb: Add new VID/PID 0489/e102 for MT7922
  (git-fixes).
- Bluetooth: btusb: Add a new VID/PID 0489/e0f6 for MT7922
  (git-fixes).
- Bluetooth: btusb: Add device 0489:e0f5 as MT7922 device
  (git-fixes).
- commit b65853c
* Fri Oct 20 2023 tiwai@suse.de
- ACPI: resource: Add TongFang GM6BGEQ, GM6BG5Q and GM6BG0Q to
  irq1_edge_low_force_override[] (git-fixes).
- ACPI: resource: Skip IRQ override on ASUS ExpertBook B1402CBA
  (git-fixes).
- ACPI: EC: Add quirk for the HP Pavilion Gaming 15-dk1xxx
  (git-fixes).
- ALSA: usb-audio: Fix microphone sound on Nexigo webcam
  (git-fixes).
- ALSA: usb-audio: Fix microphone sound on Opencomm2 Headset
  (git-fixes).
- alx: fix OOB-read compiler warning (git-fixes).
- ACPI: x86: s2idle: Catch multiple ACPI_TYPE_PACKAGE objects
  (git-fixes).
- ACPI: video: Add backlight=native DMI quirk for Apple iMac12,1
  and iMac12,2 (git-fixes).
- ACPICA: Add AML_NO_OPERAND_RESOLVE flag to Timer (git-fixes).
- commit cf1d1d0
* Fri Oct 20 2023 hare@suse.de
- PM: hibernate: don't use early_lookup_bdev in resume_store
  (bsc#1216436).
- dm: only call early_lookup_bdev from early boot context
  (bsc#1216436).
- dm: remove dm_get_dev_t (bsc#1216436).
- dm: open code dm_get_dev_t in dm_init_init (bsc#1216436).
- dm-snap: simplify the origin_dev == cow_dev check in
  snapshot_ctr (bsc#1216436).
- block: move more code to early-lookup.c (bsc#1216436).
- block: move the code to do early boot lookup of block devices
  to block/ (bsc#1216436).
- init: clear root_wait on all invalid root= strings
  (bsc#1216436).
- init: improve the name_to_dev_t interface (bsc#1216436).
- init: move the nfs/cifs/ram special cases out of name_to_dev_t
  (bsc#1216436).
- init: factor the root_wait logic in prepare_namespace into a
  helper (bsc#1216436).
- init: handle ubi/mtd root mounting like all other root types
  (bsc#1216436).
- init: don't remove the /dev/ prefix from error messages
  (bsc#1216436).
- init: pass root_device_name explicitly (bsc#1216436).
- init: refactor mount_root (bsc#1216436).
- init: rename mount_block_root to mount_root_generic
  (bsc#1216436).
- init: remove pointless Root_* values (bsc#1216436).
- PM: hibernate: move finding the resume device out of
  software_resume (bsc#1216436).
- commit a10eb49
* Fri Oct 20 2023 hare@suse.de
- PM: hibernate: remove the global snapshot_test variable
  (bsc#1216436).
- Refresh
  patches.suse/0007-PM-hibernate-encrypt-hidden-area.patch.
- commit af576bb
* Fri Oct 20 2023 hare@suse.de
- PM: hibernate: factor out a helper to find the resume device
  (bsc#1216436).
- driver core: return bool from driver_probe_done (bsc#1216436).
- commit cab67f3
* Fri Oct 20 2023 hare@suse.de
- gfs2: Don't use filemap_splice_read (bsc#1216396).
- nfsd: Fix reading via splice (bsc#1216396).
- shmem: minor fixes to splice-read implementation (bsc#1216396).
- block: Fix dio_cleanup() to advance the head index
  (bsc#1216396).
- commit 4153b2a
* Fri Oct 20 2023 jack@suse.cz
- Enable CONFIG_DEBUG_CREDENTIALS (jsc#PED-6721)
- commit c6c6196
* Fri Oct 20 2023 jack@suse.cz
- Enable CONFIG_DEBUG_SG (jsc#PED-6719).
- commit d87ed97
* Fri Oct 20 2023 hare@suse.de
- ext4: wire up the ->mark_dead holder operation for log devices
  (bsc#1216436).
- ext4: wire up sops->shutdown (bsc#1216436).
- commit be93c9b
* Fri Oct 20 2023 hare@suse.de
- ext4: split ext4_shutdown (bsc#1216436).
- Refresh
  patches.suse/ext4-fix-to-check-return-value-of-freeze_bdev-i.patch.
- commit 7192c4c
* Fri Oct 20 2023 hare@suse.de
- xfs: wire up the ->mark_dead holder operation for log and RT
  devices (bsc#1216436).
- xfs: wire up sops->shutdown (bsc#1216436).
- commit acb6e5e
* Fri Oct 20 2023 hare@suse.de
- fs: add a method to shut down the file system (bsc#1216436).
- Refresh patches.suse/vfs-add-super_operations-get_inode_dev.
- commit 665d59b
* Fri Oct 20 2023 hare@suse.de
- block: mark bio_add_folio as __must_check (bsc#1216436).
- commit 158b336
* Fri Oct 20 2023 hare@suse.de
- fs: iomap: use bio_add_folio_nofail where possible
  (bsc#1216436).
- Refresh
  patches.suse/iomap-Rename-iomap_page-to-iomap_folio_state-and-others.patch.
- commit 35f9aa2
* Fri Oct 20 2023 hare@suse.de
- block: add bio_add_folio_nofail (bsc#1216436).
- block: mark bio_add_page as __must_check (bsc#1216436).
- dm-crypt: use __bio_add_page to add single page to clone bio
  (bsc#1216436).
- md: raid1: check if adding pages to resync bio fails
  (bsc#1216436).
- md: raid1: use __bio_add_page for adding single page to bio
  (bsc#1216436).
- md: check for failure when adding pages in
  alloc_behind_master_bio (bsc#1216436).
- commit e90ff1b
* Fri Oct 20 2023 hare@suse.de
- scsi: core: ata: Do no try to probe for CDL on old drives
  (bsc#1216435).
- scsi: libsas: Add return_fis_on_success to sas_ata_task
  (bsc#1216435).
- commit 52e719b
* Fri Oct 20 2023 hare@suse.de
- scsi: ata: libata: Handle completion of CDL commands using
  policy 0xD (bsc#1216435).
- scsi: ata: libata: Set read/write commands CDL index
  (bsc#1216435).
- scsi: ata: libata: Add ATA feature control sub-page translation
  (bsc#1216435).
- scsi: ata: libata-scsi: Add support for CDL pages mode sense
  (bsc#1216435).
- scsi: ata: libata-scsi: Handle CDL bits in ata_scsiop_maint_in()
  (bsc#1216435).
- scsi: ata: libata: Detect support for command duration limits
  (bsc#1216435).
- scsi: ata: libata: Change ata_eh_request_sense() to not set
  CHECK_CONDITION (bsc#1216435).
- scsi: ata: libata-scsi: Remove unnecessary !cmd checks
  (bsc#1216435).
- scsi: sd: Handle read/write CDL timeout failures (bsc#1216435).
- scsi: sd: Set read/write command CDL index (bsc#1216435).
- scsi: core: Allow enabling and disabling command duration limits
  (bsc#1216435).
- commit 69aa7a3
* Fri Oct 20 2023 hare@suse.de
- scsi: core: Detect support for command duration limits
  (bsc#1216435).
- Refresh
  patches.suse/scsi-Do-not-attempt-to-rescan-suspended-devices.patch.
- commit 2174f78
* Fri Oct 20 2023 hare@suse.de
- scsi: core: Support Service Action in scsi_report_opcode()
  (bsc#1216435).
- scsi: core: Support retrieving sub-pages of mode pages
  (bsc#1216435).
- scsi: core: Rename and move get_scsi_ml_byte() (bsc#1216435).
- scsi: core: Allow libata to complete successful commands via EH
  (bsc#1216435).
- scsi: block: Introduce BLK_STS_DURATION_LIMIT (bsc#1216435).
- scsi: block: Introduce ioprio hints (bsc#1216435).
- scsi: block: ioprio: Clean up interface definition
  (bsc#1216435).
- commit a45bd09
* Fri Oct 20 2023 tiwai@suse.de
- selftests: mptcp: join: no RST when rm subflow/addr (git-fixes).
- wifi: cfg80211: use system_unbound_wq for wiphy work
  (git-fixes).
- net: phy: bcm7xxx: Add missing 16nm EPHY statistics (git-fixes).
- Bluetooth: hci_event: Fix using memcmp when comparing keys
  (git-fixes).
- Bluetooth: Fix a refcnt underflow problem for hci_conn
  (git-fixes).
- Bluetooth: hci_event: Ignore NULL link key (git-fixes).
- nfc: nci: fix possible NULL pointer dereference in
  send_acknowledge() (git-fixes).
- selftests: openvswitch: Fix the ct_tuple for v4 (git-fixes).
- selftests: openvswitch: Catch cases where the tests are killed
  (git-fixes).
- selftests: openvswitch: Add version check for pyroute2
  (git-fixes).
- docs: fix info about representor identification (git-fixes).
- selftests/powerpc: Fix emit_tests to work with run_kselftest.sh
  (git-fixes).
- commit 96142ad
* Fri Oct 20 2023 hare@suse.de
- Refresh
  patches.suse/mm-gup-add-missing-gup_must_unshare-check-to-gup_huge_pgd.patch.
- commit 9284a43
* Thu Oct 19 2023 mbrugger@suse.com
- arm64: Update config files. (bsc#1216523)
  Make iMX93 clock and pinctrl driver build-in.
- commit 09c889a
* Thu Oct 19 2023 nmorey@suse.com
- SUNRPC: Fix the recent bv_offset fix (bsc#1216396)
- commit 0bab547
* Thu Oct 19 2023 nmorey@suse.com
- crypto: fix uninit-value in af_alg_free_resources (bsc#1216396)
- commit d4bf8b0
* Thu Oct 19 2023 nmorey@suse.com
- crypto: af_alg - Fix missing initialisation affecting gcm-aes-s390 (bsc#1216396)
- commit f6818fc
* Thu Oct 19 2023 nmorey@suse.com
- crypto: Fix af_alg_sendmsg(MSG_SPLICE_PAGES) sglist limit (bsc#1216396)
- commit f4767f4
* Thu Oct 19 2023 nmorey@suse.com
- kcm: Fix unnecessary psock unreservation. (bsc#1216396)
- commit e3f83d9
* Thu Oct 19 2023 nmorey@suse.com
- ip, ip6: Fix splice to raw and ping sockets (bsc#1216396)
- commit 7633d3f
* Thu Oct 19 2023 nmorey@suse.com
- splice, net: Fix splice_to_socket() to handle pipe bufs larger than a page (bsc#1216396)
- commit 0e2c116
* Thu Oct 19 2023 nmorey@suse.com
- drbd: swap bvec_set_page len and offset (bsc#1216396)
- commit 98a0211
* Thu Oct 19 2023 nmorey@suse.com
- sunrpc: set the bv_offset of first bvec in svc_tcp_sendmsg (bsc#1216396)
- commit 7da5d0a
* Thu Oct 19 2023 nmorey@suse.com
- net: tls: set MSG_SPLICE_PAGES consistently (bsc#1216396)
- commit fb18afe
* Thu Oct 19 2023 nmorey@suse.com
- udp6: Fix __ip6_append_data()'s handling of MSG_SPLICE_PAGES (bsc#1216396)
- commit d1f0111
* Thu Oct 19 2023 nmorey@suse.com
- udp: Fix __ip_append_data()'s handling of MSG_SPLICE_PAGES (bsc#1216396)
- commit b95d993
* Thu Oct 19 2023 nmorey@suse.com
- splice, net: Fix splice_to_socket() for O_NONBLOCK socket (bsc#1216396)
- commit ede475b
* Thu Oct 19 2023 nmorey@suse.com
- perf beauty: Update copy of linux/socket.h with the kernel sources (bsc#1216396)
- commit 9c84033
* Thu Oct 19 2023 nmorey@suse.com
- crypto: algif_hash - Fix race between MORE and non-MORE sends (bsc#1216396)
- commit af859fa
* Thu Oct 19 2023 nmorey@suse.com
- crypto: af_alg/hash: Fix recvmsg() after sendmsg(MSG_MORE) (bsc#1216396)
- commit b15c021
* Thu Oct 19 2023 nmorey@suse.com
- crypto: af_alg - Fix merging of written data into spliced pages (bsc#1216396)
- commit e0c6887
* Thu Oct 19 2023 nmorey@suse.com
- nvme-tcp: Fix comma-related oops (bsc#1216396)
- commit 8fb1409
* Thu Oct 19 2023 nmorey@suse.com
- libceph: Partially revert changes to support MSG_SPLICE_PAGES (bsc#1216396)
- commit 5ac4d7b
* Thu Oct 19 2023 nmorey@suse.com
- perf trace: fix MSG_SPLICE_PAGES build error (bsc#1216396)
- commit af42c7b
* Thu Oct 19 2023 nmorey@suse.com
- net: Kill MSG_SENDPAGE_NOTLAST (bsc#1216396)
- commit dbaaf08
* Thu Oct 19 2023 nmorey@suse.com
- sock: Remove ->sendpage*() in favour of sendmsg(MSG_SPLICE_PAGES) (bsc#1216396)
- commit 65346bf
* Thu Oct 19 2023 nmorey@suse.com
- ocfs2: Use sendmsg(MSG_SPLICE_PAGES) rather than sendpage() (bsc#1216396)
- commit 806190c
* Thu Oct 19 2023 nmorey@suse.com
- scsi: target: iscsi: Use sendmsg(MSG_SPLICE_PAGES) rather than sendpage (bsc#1216396)
- commit 6796e48
* Thu Oct 19 2023 nmorey@suse.com
- scsi: iscsi_tcp: Use sendmsg(MSG_SPLICE_PAGES) rather than sendpage (bsc#1216396)
- commit 68eb15b
* Thu Oct 19 2023 nmorey@suse.com
- drbd: Use sendmsg(MSG_SPLICE_PAGES) rather than sendpage() (bsc#1216396)
- commit 77f6ffe
* Thu Oct 19 2023 nmorey@suse.com
- smc: Drop smc_sendpage() in favour of smc_sendmsg() + MSG_SPLICE_PAGES (bsc#1216396)
- commit 7d6c8d0
* Thu Oct 19 2023 nmorey@suse.com
- nvmet-tcp: Use sendmsg(MSG_SPLICE_PAGES) rather then sendpage (bsc#1216396)
- commit 3769e90
* Thu Oct 19 2023 nmorey@suse.com
- nvme-tcp: Use sendmsg(MSG_SPLICE_PAGES) rather then sendpage (bsc#1216396)
- commit b80950a
* Thu Oct 19 2023 nmorey@suse.com
- dlm: Use sendmsg(MSG_SPLICE_PAGES) rather than sendpage (bsc#1216396)
- commit 090e5e1
* Thu Oct 19 2023 nmorey@suse.com
- rds: Use sendmsg(MSG_SPLICE_PAGES) rather than sendpage (bsc#1216396)
- commit b3f9468
* Thu Oct 19 2023 nmorey@suse.com
- ceph: Use sendmsg(MSG_SPLICE_PAGES) rather than sendpage() (bsc#1216396)
- commit 0f390d4
* Thu Oct 19 2023 nmorey@suse.com
- ceph: Use sendmsg(MSG_SPLICE_PAGES) rather than sendpage (bsc#1216396)
- commit ce165ef
* Thu Oct 19 2023 nmorey@suse.com
- net: Use sendmsg(MSG_SPLICE_PAGES) not sendpage in skb_send_sock() (bsc#1216396)
- commit 1512d4b
* Thu Oct 19 2023 nmorey@suse.com
- tcp_bpf, smc, tls, espintcp, siw: Reduce MSG_SENDPAGE_NOTLAST usage (bsc#1216396)
- commit edd381a
* Thu Oct 19 2023 nmorey@suse.com
- kcm: Send multiple frags in one sendmsg() (bsc#1216396)
- commit abcba7f
* Thu Oct 19 2023 nmorey@suse.com
- kcm: Use sendmsg(MSG_SPLICE_PAGES) rather then sendpage (bsc#1216396)
- commit a791e49
* Thu Oct 19 2023 nmorey@suse.com
- tcp_bpf: Make tcp_bpf_sendpage() go through tcp_bpf_sendmsg(MSG_SPLICE_PAGES) (bsc#1216396)
- commit c34fb39
* Thu Oct 19 2023 nmorey@suse.com
- sunrpc: Use sendmsg(MSG_SPLICE_PAGES) rather then sendpage (bsc#1216396)
- commit ee8f1a6
* Thu Oct 19 2023 nmorey@suse.com
- algif: Remove hash_sendpage*() (bsc#1216396)
- commit 3242e29
* Thu Oct 19 2023 nmorey@suse.com
- Remove file->f_op->sendpage (bsc#1216396)
- commit 3d3afbc
* Thu Oct 19 2023 hare@suse.de
- tls/device: Convert tls_device_sendpage() to use
  MSG_SPLICE_PAGES (bsc#1216396).
- tls/device: Support MSG_SPLICE_PAGES (bsc#1216396).
- tls/sw: Convert tls_sw_sendpage() to use MSG_SPLICE_PAGES
  (bsc#1216396).
- tls/sw: Support MSG_SPLICE_PAGES (bsc#1216396).
- splice, net: Fix SPLICE_F_MORE signalling in
  splice_direct_to_actor() (bsc#1216396).
- kcm: Use splice_eof() to flush (bsc#1216396).
- chelsio/chtls: Use splice_eof() to flush (bsc#1216396).
- ipv4, ipv6: Use splice_eof() to flush (bsc#1216396).
- tls/device: Use splice_eof() to flush (bsc#1216396).
- tls/sw: Use splice_eof() to flush (bsc#1216396).
- splice, net: Add a splice_eof op to file-ops and socket-ops
  (bsc#1216396).
- splice, net: Use sendmsg(MSG_SPLICE_PAGES) rather than
  - >sendpage() (bsc#1216396).
- commit 0872e02
* Thu Oct 19 2023 hare@suse.de
- tls: Allow MSG_SPLICE_PAGES but treat it as normal sendmsg
  (bsc#1216396).
- net: Block MSG_SENDPAGE_* from being passed to sendmsg()
  by userspace (bsc#1216396).
- commit 5429db8
* Thu Oct 19 2023 hare@suse.de
- crypto: af_alg/hash: Support MSG_SPLICE_PAGES (bsc#1216396).
- crypto: af_alg: Convert af_alg_sendpage() to use
  MSG_SPLICE_PAGES (bsc#1216396).
- crypto: af_alg: Support MSG_SPLICE_PAGES (bsc#1216396).
- crypto: af_alg: Indent the loop in af_alg_sendmsg()
  (bsc#1216396).
- crypto: af_alg: Use extract_iter_to_sg() to create scatterlists
  (bsc#1216396).
- crypto: af_alg: Pin pages rather than ref'ing if appropriate
  (bsc#1216396).
- commit dc4f265
* Thu Oct 19 2023 hare@suse.de
- Move netfs_extract_iter_to_sg() to lib/scatterlist.c
  (bsc#1216396).
- Refresh
  patches.suse/crypto-cifs-fix-error-handling-in-extract_iter.patch.
- commit 5ee67fd
* Thu Oct 19 2023 hare@suse.de
- Wrap lines at 80 (bsc#1216396).
- Fix a couple of spelling mistakes (bsc#1216396).
- Drop the netfs_ prefix from netfs_extract_iter_to_sg()
  (bsc#1216396).
- commit d9781c6
* Thu Oct 19 2023 hare@suse.de
- kcm: Convert kcm_sendpage() to use MSG_SPLICE_PAGES
  (bsc#1216396).
- kcm: Support MSG_SPLICE_PAGES (bsc#1216396).
- commit b35a878
* Thu Oct 19 2023 hare@suse.de
- chelsio: Convert chtls_sendpage() to use MSG_SPLICE_PAGES
  (bsc#1216396).
- chelsio: Support MSG_SPLICE_PAGES (bsc#1216396).
- commit ecc4c7a
* Thu Oct 19 2023 tiwai@suse.de
- regmap: fix NULL deref on lookup (git-fixes).
- usb: typec: altmodes/displayport: Signal hpd low when exiting
  mode (git-fixes).
- xhci: Preserve RsvdP bits in ERSTBA register correctly
  (git-fixes).
- xhci: Clear EHB bit only at end of interrupt handler
  (git-fixes).
- xhci: track port suspend state correctly in unsuccessful resume
  cases (git-fixes).
- usb: xhci: xhci-ring: Use sysdev for mapping bounce buffer
  (git-fixes).
- usb: typec: ucsi: Clear EVENT_PENDING bit if ucsi_send_command
  fails (git-fixes).
- usb: gadget: ncm: Handle decoding of multiple NTB's in unwrap
  call (git-fixes).
- usb: musb: Get the musb_qh poniter after musb_giveback
  (git-fixes).
- usb: musb: Modify the "HWVers" register address (git-fixes).
- usb: cdnsp: Fixes issue with dequeuing not queued requests
  (git-fixes).
- thunderbolt: Restart XDomain discovery handshake after failure
  (git-fixes).
- thunderbolt: Correct TMU mode initialization from hardware
  (git-fixes).
- serial: Reduce spinlocked portion of uart_rs485_config()
  (git-fixes).
- iio: pressure: ms5611: ms5611_prom_is_valid false negative bug
  (git-fixes).
- Input: psmouse - fix fast_reconnect function for PS/2 mode
  (git-fixes).
- media: subdev: Don't report V4L2_SUBDEV_CAP_STREAMS when the
  streams API is disabled (git-fixes).
- power: supply: qcom_battmgr: fix enable request endianness
  (git-fixes).
- power: supply: qcom_battmgr: fix battery_id type (git-fixes).
- nfc: nci: assert requested protocol is valid (git-fixes).
- net: usb: dm9601: fix uninitialized variable use in
  dm9601_mdio_read (git-fixes).
- net: nfc: fix races in nfc_llcp_sock_get() and
  nfc_llcp_sock_get_sn() (git-fixes).
- phy: lynx-28g: serialize concurrent phy_set_mode_ext() calls
  to shared registers (git-fixes).
- phy: lynx-28g: lock PHY while performing CDR lock workaround
  (git-fixes).
- phy: lynx-28g: cancel the CDR check work item on the remove path
  (git-fixes).
- pinctrl: renesas: rzn1: Enable missing PINMUX (git-fixes).
- pinctrl: starfive: jh7110: Fix failure to set irq after
  CONFIG_PM is enabled (git-fixes).
- pinctrl: nuvoton: wpcm450: fix out of bounds write (git-fixes).
- KEYS: trusted: Remove redundant static calls usage (git-fixes).
- irqchip: renesas-rzg2l: Fix logic to clear TINT interrupt source
  (git-fixes).
- commit 7f41ba4
* Thu Oct 19 2023 tiwai@suse.de
- iio: adc: ad7192: Correct reference voltage (git-fixes).
- iio: addac: Kconfig: update ad74413r selections (git-fixes).
- iio: pressure: dps310: Adjust Timeout Settings (git-fixes).
- iio: imu: bno055: Fix missing Kconfig dependencies (git-fixes).
- iio: adc: imx8qxp: Fix address for command buffer registers
  (git-fixes).
- iio: cros_ec: fix an use-after-free in
  cros_ec_sensors_push_data() (git-fixes).
- iio: admv1013: add mixer_vgate corner cases (git-fixes).
- iio: pressure: bmp280: Fix NULL pointer exception (git-fixes).
- iio: dac: ad3552r: Correct device IDs (git-fixes).
- dmaengine: stm32-dma: fix residue in case of MDMA chaining
  (git-fixes).
- dmaengine: stm32-dma: fix stm32_dma_prep_slave_sg in case of
  MDMA chaining (git-fixes).
- dmaengine: stm32-mdma: set in_flight_bytes in case CRQA flag
  is set (git-fixes).
- dmaengine: stm32-mdma: use Link Address Register to compute
  residue (git-fixes).
- dmaengine: stm32-mdma: abort resume if no ongoing transfer
  (git-fixes).
- dmaengine: mediatek: Fix deadlock caused by synchronize_irq()
  (git-fixes).
- dmaengine: idxd: use spin_lock_irqsave before
  wait_event_lock_irq (git-fixes).
- dt-bindings: dmaengine: zynqmp_dma: add xlnx,bus-width required
  property (git-fixes).
- ieee802154: ca8210: Fix a potential UAF in ca8210_probe
  (git-fixes).
- dt-bindings: interrupt-controller: renesas,rzg2l-irqc: Update
  description for '#interrupt-cells' property (git-fixes).
- commit 273ec57
* Thu Oct 19 2023 tiwai@suse.de
- counter: microchip-tcb-capture: Fix the use of internal GCLK
  logic (git-fixes).
- counter: chrdev: fix getting array extensions (git-fixes).
- can: isotp: isotp_sendmsg(): fix TX state detection and wait
  behavior (git-fixes).
- arm64: dts: mediatek: mt8195: Set DSU PMU status to fail
  (git-fixes).
- arm64: dts: mediatek: fix t-phy unit name (git-fixes).
- arm64: dts: mediatek: mt8195-demo: update and reorder reserved
  memory regions (git-fixes).
- arm64: dts: mediatek: mt8195-demo: fix the memory size to 8GB
  (git-fixes).
- ata: pata_parport: implement set_devctl (git-fixes).
- ata: pata_parport: fix pata_parport_devchk (git-fixes).
- arm64: dts: qcom: sm8150: extend the size of the PDC resource
  (git-fixes).
- ASoC: amd: yc: Fix non-functional mic on Lenovo 82YM
  (git-fixes).
- ASoC: hdmi-codec: Fix broken channel map reporting (git-fixes).
- ALSA: hda/realtek: Change model for Intel RVP board (git-fixes).
- ALSA: hda: cs35l41: Cleanup and fix double free in firmware
  request (git-fixes).
- ASoC: SOF: amd: fix for firmware reload failure after playback
  (git-fixes).
- ASoC: fsl_sai: Don't disable bitclock for i.MX8MP (git-fixes).
- ASoC: simple-card-utils: fixup simple_util_startup() error
  handling (git-fixes).
- ASoC: Intel: soc-acpi: fix Dell SKU 0B34 (git-fixes).
- ALSA: hda/realtek - ALC287 merge RTK codec with CS CS35L41 AMP
  (git-fixes).
- commit 4cbb4f2
* Thu Oct 19 2023 hare@suse.de
- net: fix signedness bug in skb_splice_from_iter() (bsc#1216396).
- block: Use iov_iter_extract_pages() and page pinning in
  direct-io.c (bsc#1216396).
- mm: Provide a function to get an additional pin on a page
  (bsc#1216396).
- mm: Don't pin ZERO_PAGE in pin_user_pages() (bsc#1216396).
- block: convert bio_map_user_iov to use iov_iter_extract_pages
  (bsc#1216396).
- block: Convert bio_iov_iter_get_pages to use
  iov_iter_extract_pages (bsc#1216396).
- block: Add BIO_PAGE_PINNED and associated infrastructure
  (bsc#1216396).
- block: Replace BIO_NO_PAGE_REF with BIO_PAGE_REFFED with
  inverted logic (bsc#1216396).
- block: Fix bio_flagged() so that gcc can better optimise it
  (bsc#1216396).
- iomap: Don't get an reference on ZERO_PAGE for direct I/O
  block zeroing (bsc#1216396).
- commit 0c6b192
* Thu Oct 19 2023 hare@suse.de
- splice: kdoc for filemap_splice_read() and copy_splice_read()
  (bsc#1216396).
- iov_iter: Kill ITER_PIPE (bsc#1216396).
- splice: Remove generic_file_splice_read() (bsc#1216396).
- splice: Use filemap_splice_read() instead of (bsc#1216396).
- cifs: Use filemap_splice_read() (bsc#1216396).
- trace: Convert trace/seq to use copy_splice_read()
  (bsc#1216396).
- zonefs: Provide a splice-read wrapper (bsc#1216396).
- xfs: Provide a splice-read wrapper (bsc#1216396).
- orangefs: Provide a splice-read wrapper (bsc#1216396).
- ocfs2: Provide a splice-read wrapper (bsc#1216396).
- ntfs3: Provide a splice-read wrapper (bsc#1216396).
- nfs: Provide a splice-read wrapper (bsc#1216396).
- f2fs: Provide a splice-read wrapper (bsc#1216396).
- ext4: Provide a splice-read wrapper (bsc#1216396).
- ecryptfs: Provide a splice-read wrapper (bsc#1216396).
- ceph: Provide a splice-read wrapper (bsc#1216396).
- afs: Provide a splice-read wrapper (bsc#1216396).
- 9p: Add splice_read wrapper (bsc#1216396).
- net: Make sock_splice_read() use copy_splice_read() by
  (bsc#1216396).
- tty, proc, kernfs, random: Use copy_splice_read() (bsc#1216396).
- coda: Implement splice-read (bsc#1216396).
- overlayfs: Implement splice-read (bsc#1216396).
- shmem: Implement splice-read (bsc#1216396).
- splice: Make splice from a DAX file use copy_splice_read()
  (bsc#1216396).
- splice: Make splice from an O_DIRECT fd use (bsc#1216396).
- splice: Check for zero count in vfs_splice_read() (bsc#1216396).
- splice: Make do_splice_to() generic and export it (bsc#1216396).
- commit 4891151
* Thu Oct 19 2023 hare@suse.de
- splice: Clean up copy_splice_read() a bit (bsc#1216396).
- Refresh
  patches.suse/splice-don-t-call-file_accessed-in-copy_splice_.patch.
- commit 664e8a5
* Thu Oct 19 2023 hare@suse.de
- splice: Rename direct_splice_read() to copy_splice_read()
  (bsc#1216396).
- splice: Make filemap_splice_read() check s_maxbytes
  (bsc#1216396).
- commit a541fa9
* Thu Oct 19 2023 hare@suse.de
- unix: Convert unix_stream_sendpage() to use MSG_SPLICE_PAGES
  (bsc#1216396).
- Delete
  patches.suse/af_unix-Fix-null-ptr-deref-in-unix_stream_send.patch.
- commit e25becd
* Thu Oct 19 2023 hare@suse.de
- af_unix: Support MSG_SPLICE_PAGES (bsc#1216396).
- commit f1ae971
* Thu Oct 19 2023 hare@suse.de
- ip: Remove ip_append_page() (bsc#1216396).
- udp: Convert udp_sendpage() to use MSG_SPLICE_PAGES
  (bsc#1216396).
- ip6, udp6: Support MSG_SPLICE_PAGES (bsc#1216396).
- ip, udp: Support MSG_SPLICE_PAGES (bsc#1216396).
- tcp: Fold do_tcp_sendpages() into tcp_sendpage_locked()
  (bsc#1216396).
- siw: Inline do_tcp_sendpages() (bsc#1216396).
- tls: Inline do_tcp_sendpages() (bsc#1216396).
- espintcp: Inline do_tcp_sendpages() (bsc#1216396).
- tcp_bpf: Inline do_tcp_sendpages as it's now a wrapper around
  tcp_sendmsg (bsc#1216396).
- tcp: Convert do_tcp_sendpages() to use MSG_SPLICE_PAGES
  (bsc#1216396).
- tcp: Support MSG_SPLICE_PAGES (bsc#1216396).
- net: Add a function to splice pages into an skbuff for
  MSG_SPLICE_PAGES (bsc#1216396).
- net: Pass max frags into skb_append_pagefrags() (bsc#1216396).
- net: Declare MSG_SPLICE_PAGES internal sendmsg() flag
  (bsc#1216396).
- net/tcp: optimise io_uring zc ubuf refcounting (bsc#1216396).
- net/tcp: don't peek at tail for io_uring zc (bsc#1216396).
- commit 1cbac60
* Wed Oct 18 2023 hare@suse.de
- blk-flush: fix rq->flush.seq for post-flush requests (PED-5728).
- commit 331daeb
* Wed Oct 18 2023 hare@suse.de
- blk-mq: release scheduler resource when request completes
  (PED-5728).
- block: queue data commands from the flush state machine at
  the head (PED-5728).
- block/mq-deadline: Fix a bug in deadline_from_pos() (PED-5728).
- blk-mq: fix two misuses on RQF_USE_SCHED (PED-5728).
- blk-ioc: fix recursive spin_lock/unlock_irq() in
  ioc_clear_queue() (PED-5728).
- commit 6d273e4
* Wed Oct 18 2023 mfranc@suse.cz
- KVM: s390: fix gisa destroy operation might lead to cpu stalls
  (git-fixes).
- commit 27384f0
* Tue Oct 17 2023 osalvador@suse.de
- Crash: add lock to serialize crash hotplug handling
  (jsc-PED#5077).
- commit 5a5c5bb
* Tue Oct 17 2023 msuchanek@suse.de
- Refresh SED OPAL patches to current version.
- commit 8de998c
* Tue Oct 17 2023 osalvador@suse.de
- x86/crash: optimize CPU changes (jsc#PED-5077).
- commit f30f3fe
* Tue Oct 17 2023 osalvador@suse.de
- crash: change crash_prepare_elf64_headers() to
  for_each_possible_cpu() (jsc#PED-5077).
- commit e79d809
* Tue Oct 17 2023 osalvador@suse.de
- x86/crash: add x86 crash hotplug support (jsc#PED-5077).
  Update config files
- commit d5e636c
* Tue Oct 17 2023 osalvador@suse.de
- crash: memory and CPU hotplug sysfs attributes (jsc#PED-5077).
- commit 82db65e
* Tue Oct 17 2023 osalvador@suse.de
- kexec: exclude elfcorehdr from the segment digest
  (jsc#PED-5077).
- commit 2859a0e
* Tue Oct 17 2023 osalvador@suse.de
- crash: add generic infrastructure for crash hotplug support
  (jsc#PED-5077).
- Refresh
  patches.suse/add-product-identifying-information-to-vmcoreinfo.patch.
- commit 374d01d
* Tue Oct 17 2023 osalvador@suse.de
- crash: move a few code bits to setup support of crash hotplug
  (jsc#PED-5077).
- Refresh
  patches.suse/add-product-identifying-information-to-vmcoreinfo.patch.
- commit 563a4f9
* Tue Oct 17 2023 oneukum@suse.com
- usb: typec: ucsi: Use GET_CAPABILITY attributes data to set
  power supply scope (git-fixes).
- commit f685c38
* Tue Oct 17 2023 oneukum@suse.com
- usb: gadget: udc-xilinx: replace memcpy with memcpy_toio
  (git-fixes).
- commit eb4f8c3
* Tue Oct 17 2023 oneukum@suse.com
- usb: gadget: udc-xilinx: fix incorrect type in assignment
  warning (git-fixes).
- commit 0c5300f
* Tue Oct 17 2023 oneukum@suse.com
- usb: gadget: udc-xilinx: fix cast from restricted __le16 warning
  (git-fixes).
- commit 0e0e0a8
* Tue Oct 17 2023 oneukum@suse.com
- usb: gadget: udc-xilinx: fix restricted __le16 degrades to
  integer warning (git-fixes).
- commit 54667be
* Tue Oct 17 2023 oneukum@suse.com
- usb: gadget: udc: udc-xilinx: Use
  devm_platform_get_and_ioremap_resource() (git-fixes).
- commit 5cb0f73
* Tue Oct 17 2023 hare@suse.de
- scsi: target: Pass struct target_opcode_descriptor to enabled
  (PED-5728).
- commit a0c7a7a
* Tue Oct 17 2023 lhenriques@suse.de
- ceph: remove unnecessary check for NULL in parse_longname()
  (bsc#1216331).
- commit fea4023
* Tue Oct 17 2023 oneukum@suse.com
- usb: Explicitly include correct DT includes (git-fixes).
  parts for qcom driver not backported removed
- commit 27319fe
* Tue Oct 17 2023 oneukum@suse.com
- usb: gadget/udc-xilinx: Convert to platform remove callback
  returning void (git-fixes).
- commit 110ff09
* Tue Oct 17 2023 oneukum@suse.com
- usb: gadget: udc: udc-xilinx: Add identifier to read_fn function
  arg (git-fixes).
- commit 0db2eea
* Tue Oct 17 2023 oneukum@suse.com
- usb: dwc3: Soft reset phy on probe for host (git-fixes).
- commit 47c619c
* Tue Oct 17 2023 jgross@suse.com
- KVM: SVM: Fix TSC_AUX virtualization setup (git-fixes).
- commit f04f3c5
* Tue Oct 17 2023 lhenriques@suse.de
- ceph: fix type promotion bug on 32bit systems (bsc#1216327).
- libceph: use kernel_connect() (bsc#1216326).
- ceph: fix incorrect revoked caps assert in ceph_fill_file_size()
  (bsc#1216325).
- commit 211b7b9
* Tue Oct 17 2023 jgross@suse.com
- KVM: SVM: INTERCEPT_RDTSCP is never intercepted anyway
  (git-fixes).
- commit 8d2756e
* Tue Oct 17 2023 jgross@suse.com
- vringh: don't use vringh_kiov_advance() in vringh_iov_xfer()
  (git-fixes).
- commit 5373e91
* Tue Oct 17 2023 jgross@suse.com
- xen-netback: use default TX queue size for vifs (git-fixes).
- commit 2ad4e6c
* Tue Oct 17 2023 lduncan@suse.com
- scsi: Do not rescan devices with a suspended queue (git-fixes).
- commit c0a7368
* Mon Oct 16 2023 lduncan@suse.com
- scsi: Do not attempt to rescan suspended devices (git-fixes).
- scsi: sd: Differentiate system and runtime start/stop management
  (git-fixes).
- scsi: iscsi_tcp: restrict to TCP sockets (git-fixes).
- scsi: lpfc: Fix the NULL vs IS_ERR() bug for
  debugfs_create_file() (git-fixes).
- scsi: pm8001: Setup IRQs on resume (git-fixes).
- commit afc950d
* Mon Oct 16 2023 hare@suse.de
- block: add a mark_dead holder operation (PED-5728).
- block: introduce holder ops (PED-5728).
- block: remove blk_drop_partitions (PED-5728).
- block: delete partitions later in del_gendisk (PED-5728).
- block: unhash the inode earlier in delete_partition (PED-5728).
- block: avoid repeated work in blk_mark_disk_dead (PED-5728).
- block: consolidate the shutdown logic in blk_mark_disk_dead
  and del_gendisk (PED-5728).
- block: turn bdev_lock into a mutex (PED-5728).
- block: refactor bd_may_claim (PED-5728).
- block: factor out a bd_end_claim helper from blkdev_put
  (PED-5728).
- block: Replace all non-returning strlcpy with strscpy
  (PED-5728).
- blk-ioc: protect ioc_destroy_icq() by 'queue_lock' (PED-5728).
- block: constify the whole_disk device_attribute (PED-5728).
- block: constify struct part_attr_group (PED-5728).
- block: constify struct part_type part_type (PED-5728).
- block: constify partition prober array (PED-5728).
- commit 00b3f62
* Mon Oct 16 2023 hare@suse.de
- block: introduce block_io_start/block_io_done tracepoints
  (PED-5728).
- block: remove redundant req_op in blk_rq_is_passthrough
  (PED-5728).
- block: don't plug in blkdev_write_iter (PED-5728).
- block: BFQ: Move an invariant check (PED-5728).
- commit ff11de8
* Mon Oct 16 2023 hare@suse.de
- blk-mq: don't use the requeue list to queue flush commands
  (PED-5728).
- blk-mq: do not do head insertions post-pre-flush commands
  (PED-5728).
- blk-mq: defer to the normal submission path for post-flush
  requests (PED-5728).
- blk-mq: use the I/O scheduler for writes from the flush state
  machine (PED-5728).
- blk-mq: defer to the normal submission path for non-flush
  flush commands (PED-5728).
- blk-mq: reflow blk_insert_flush (PED-5728).
- blk-mq: factor out a blk_rq_init_flush helper (PED-5728).
- fs: remove the special !CONFIG_BLOCK def_blk_fops (PED-5728).
- commit f3ede31
* Mon Oct 16 2023 hare@suse.de
- block: BFQ: Add several invariant checks (PED-5728).
- block: mq-deadline: Fix handling of at-head zoned writes
  (PED-5728).
- block: mq-deadline: Handle requeued requests correctly
  (PED-5728).
- block: mq-deadline: Track the dispatch position (PED-5728).
- block: mq-deadline: Reduce lock contention (PED-5728).
- block: mq-deadline: Simplify deadline_skip_seq_writes()
  (PED-5728).
- block: mq-deadline: Clean up deadline_check_fifo() (PED-5728).
- block: Introduce blk_rq_is_seq_zoned_write() (PED-5728).
- block: Introduce op_needs_zoned_write_locking() (PED-5728).
- block: Simplify blk_req_needs_zone_write_lock() (PED-5728).
- block: mq-deadline: Add a word in a source code comment
  (PED-5728).
- commit 37cc91c
* Mon Oct 16 2023 hare@suse.de
- blk-mq: make sure elevator callbacks aren't called for
  passthrough request (PED-5728).
- blk-mq: remove RQF_ELVPRIV (PED-5728).
- commit 1dd7720
* Mon Oct 16 2023 hare@suse.de
- scsi: target: Add block PR support to iblock (PED-5728).
- scsi: target: Report and detect unsupported PR commands
  (PED-5728).
- scsi: target: Allow backends to hook into PR handling
  (PED-5728).
- scsi: target: Rename sbc_ops to exec_cmd_ops (PED-5728).
- nvme: Add pr_ops read_reservation support (PED-5728).
- nvme: Add a nvme_pr_type enum (PED-5728).
- nvme: Add pr_ops read_keys support (PED-5728).
- nvme: Add helper to send pr command (PED-5728).
- nvme: Move pr code to it's own file (PED-5728).
- nvme: Don't hardcode the data len for pr commands (PED-5728).
- nvme: Fix reservation status related structs (PED-5728).
- dm: Add support for block PR read keys/reservation (PED-5728).
- scsi: Add support for block PR read keys/reservation (PED-5728).
- scsi: Move sd_pr_type to scsi_common (PED-5728).
- scsi: Rename sd_pr_command (PED-5728).
- block: Rename BLK_STS_NEXUS to BLK_STS_RESV_CONFLICT (PED-5728).
- block: Add PR callouts for read keys and reservation (PED-5728).
- commit 83e6b70
* Mon Oct 16 2023 mgorman@suse.de
- sched/psi: Delete the 'update_total' function parameter from
  update_triggers() (bsc#1212887 (Scheduler functional and
  performance backports)).
- sched/psi: Avoid updating PSI triggers and ->rtpoll_total when
  there are no state changes (bsc#1212887 (Scheduler functional
  and performance backports)).
- sched/headers: Remove comment referring to rq::cpu_load, since
  this has been removed (bsc#1212887 (Scheduler functional and
  performance backports)).
- sched/numa: Complete scanning of inactive VMAs when there
  is no alternative (bsc#1212887 (Scheduler functional and
  performance backports)).
- sched/numa: Complete scanning of partial VMAs regardless of
  PID activity (bsc#1212887 (Scheduler functional and performance
  backports)).
- sched/numa: Move up the access pid reset logic (bsc#1212887
  (Scheduler functional and performance backports)).
- sched/numa: Trace decisions related to skipping VMAs
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/numa: Rename vma_numab_state::access_pids[] =>
  ::pids_active[], ::next_pid_reset => ::pids_active_reset
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/numa: Document vma_numab_state fields (bsc#1212887
  (Scheduler functional and performance backports)).
- sched/psi: Change update_triggers() to a 'void' function
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/rt: Change the type of 'sysctl_sched_rt_period' from
  'unsigned int' to 'int' (bsc#1212887 (Scheduler functional
  and performance backports)).
- sched/nohz: Remove unnecessarily complex error handling pattern
  from find_new_ilb() (bsc#1212887 (Scheduler functional and
  performance backports)).
- sched/nohz: Use consistent variable names in find_new_ilb() and
  kick_ilb() (bsc#1212887 (Scheduler functional and performance
  backports)).
- sched/nohz: Update idle load-balancing (ILB) comments
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/debug: Print 'tgid' in sched_show_task() (bsc#1212887
  (Scheduler functional and performance backports)).
- sched/rt/docs: Use 'real-time' instead of 'realtime'
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/rt/docs: Clarify & fix sched_rt_* sysctl docs (bsc#1212887
  (Scheduler functional and performance backports)).
- sched/rt: Disallow writing invalid values to sched_rt_period_us
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/deadline: Make dl_rq->pushable_dl_tasks update drive
  dl_rq->overloaded (bsc#1212887 (Scheduler functional and
  performance backports)).
- sched/rt: Make rt_rq->pushable_tasks updates drive rto_mask
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/core: Refactor the task_flags check for worker sleeping
  in sched_submit_work() (bsc#1212887 (Scheduler functional and
  performance backports)).
- sched/fair: Fix warning in bandwidth distribution (bsc#1212887
  (Scheduler functional and performance backports)).
- sched/fair: Make cfs_rq->throttled_csd_list available on !SMP
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/core: Optimize in_task() and in_interrupt() a bit
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/fair: Ratelimit update to tg->load_avg (bsc#1212887
  (Scheduler functional and performance backports)).
- sched/core: Use do-while instead of for loop in
  set_nr_if_polling() (bsc#1212887 (Scheduler functional and
  performance backports)).
- sched/fair: Fix cfs_rq_is_decayed() on !SMP (bsc#1212887
  (Scheduler functional and performance backports)).
- sched/topology: Fix sched_numa_find_nth_cpu() comment
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/topology: Handle NUMA_NO_NODE in sched_numa_find_nth_cpu()
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/topology: Fix sched_numa_find_nth_cpu() in non-NUMA case
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/topology: Fix sched_numa_find_nth_cpu() in CPU-less case
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/fair: Fix open-coded numa_nearest_node() (bsc#1212887
  (Scheduler functional and performance backports)).
- numa: Generalize numa_map_to_online_node() (bsc#1212887
  (Scheduler functional and performance backports)).
- commit bd1fdcf
* Mon Oct 16 2023 ohering@suse.de
- hv/hv_kvp_daemon:Support for keyfile based connection profile
  (git-fixes).
- hyperv: reduce size of ms_hyperv_info (git-fixes).
- x86/hyperv: Add common print prefix "Hyper-V" in hv_init
  (git-fixes).
- x86/hyperv: Remove hv_vtl_early_init initcall (git-fixes).
- x86/hyperv: Restrict get_vtl to only VTL platforms (git-fixes).
- net: mana: Fix oversized sge0 for GSO packets (git-fixes).
- net: mana: Fix the tso_bytes calculation (git-fixes).
- net: mana: Fix TX CQE error handling (git-fixes).
- commit dc3936e
* Mon Oct 16 2023 mhocko@suse.com
- rcu: dump vmalloc memory info safely (git-fixes).
- mm/vmalloc: add a safer version of find_vm_area() for debug
  (git-fixes).
- mm: hugetlb: use flush_hugetlb_tlb_range() in
  move_hugetlb_page_tables() (git-fixes).
- mm: don't drop VMA locks in mm_drop_all_locks() (git-fixes).
- mm: hugetlb_vmemmap: fix a race between vmemmap pmd split
  (git-fixes).
- madvise:madvise_free_huge_pmd(): don't use mapcount() against
  large folio for sharing check (git-fixes).
- smaps: use vm_normal_page_pmd() instead of
  follow_trans_huge_pmd() (git-fixes).
- mm/hugetlb: fix pgtable lock on pmd sharing (git-fixes).
- commit 0b9afbb
* Mon Oct 16 2023 mhocko@suse.com
- mm: memcontrol: fix GFP_NOFS recursion in memory.high
  enforcement (git-fixes).
- memcontrol: ensure memcg acquired by id is properly set up
  (git-fixes).
- commit 76715d0
* Fri Oct 13 2023 mfranc@suse.cz
- s390/bpf: Fix unwinding past the trampoline (git-fixes
  bsc#1216214).
- commit 7d2a51f
* Fri Oct 13 2023 mfranc@suse.cz
- s390/bpf: Fix clobbering the caller's backchain in the
  trampoline (git-fixes bsc#1216213).
- commit 053aa82
* Thu Oct 12 2023 rhopkins@suse.de
- KVM: SEV: remove ghcb variable declarations (CVE-2023-4155
  bsc#1214022).
- commit 0ec9b57
* Wed Oct 11 2023 tbogendoerfer@suse.de
- gve: Support IPv6 Big TCP on DQ (bsc#1214479).
- Refresh patches.suse/gve-unify-driver-name-usage.patch.
- commit ff50f3e
* Wed Oct 11 2023 tbogendoerfer@suse.de
- gve: RX path for DQO-QPL (bsc#1214479).
- gve: Tx path for DQO-QPL (bsc#1214479).
- gve: Control path for DQO-QPL (bsc#1214479).
- gve: trivial spell fix Recive to Receive (bsc#1214479).
- gve: use vmalloc_array and vcalloc (bsc#1214479).
- commit 6799c0b
* Wed Oct 11 2023 mwilck@suse.com
- scsi: core: Improve warning message in scsi_device_block()
  (bsc#1209284).
- scsi: core: Replace scsi_target_block() with
  scsi_block_targets() (bsc#1209284).
- scsi: core: Don't wait for quiesce in scsi_device_block()
  (bsc#1209284).
- scsi: core: Don't wait for quiesce in scsi_stop_queue()
  (bsc#1209284).
- scsi: core: Merge scsi_internal_device_block() and
  device_block() (bsc#1209284).
- scsi: sg: Increase number of devices (bsc#1209284).
- scsi: bsg: Increase number of devices (bsc#1209284).
- commit 62d1aaa
* Wed Oct 11 2023 mfranc@suse.cz
- s390/dasd: fix hanging device after request requeue (git-fixes
  LTC#203629 bsc#1215124).
- commit f7703bd
* Wed Oct 11 2023 jgross@suse.com
- xen/events: replace evtchn_rwlock with RCU (bsc#1215745,
  xsa-441, cve-2023-34324).
- commit 4249e3a
* Wed Oct 11 2023 msuchanek@suse.de
- scsi: ibmvfc: Implement channel queue depth and event buffer
  accounting (bsc#1209834 ltc#202097).
- scsi: ibmvfc: Remove BUG_ON in the case of an empty event pool
  (bsc#1209834 ltc#202097).
- commit ee84b98
* Wed Oct 11 2023 tiwai@suse.de
- Resurrect x86 UV patches that were mistakenly dropped (bsc#1215696)
- commit 6f640d6
* Wed Oct 11 2023 krisman@suse.de
- io_uring: don't allow IORING_SETUP_NO_MMAP rings on highmem
  pages (git-fixes).
- io_uring: ensure io_lockdep_assert_cq_locked() handles disabled
  rings (git-fixes).
- io_uring/kbuf: don't allow registered buffer rings on highmem
  pages (git-fixes).
- commit 7c0dd42
* Tue Oct 10 2023 tbogendoerfer@suse.de
- rdma: fix INFINIBAND_USER_ACCESS dependency (jsc#PED-6864).
- net: enetc: reset taprio stats when taprio is deleted
  (jsc#PED-4860).
- commit 584e676
* Tue Oct 10 2023 tiwai@suse.de
- Refresh patches.suse/iwlwifi-cfg-Add-missing-MODULE_FIRMWARE-for-pnvm.patch (jsc#PED-6081 jsc#PED-6130)
  Add entries for more *.pnvm files
- commit a47aae0
* Tue Oct 10 2023 mgorman@suse.de
- locking/rtmutex: Add a lockdep assert to catch potential nested
  blocking (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- locking/rtmutex: Use rt_mutex specific scheduler helpers
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- sched: Provide rt_mutex specific scheduler helpers (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- sched: Extract __schedule_loop() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- locking/rtmutex: Avoid unconditional slowpath for
  DEBUG_RT_MUTEXES (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- sched: Constrain locks in sched_submit_work() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tick/rcu: Fix false positive "softirq work is pending" messages
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 1d28f04
* Tue Oct 10 2023 vkarasulli@suse.de
- netfilter: nfnetlink_osf: avoid OOB read (bsc#1216046
  CVE-2023-39189).
- commit ea34632
* Tue Oct 10 2023 tbogendoerfer@suse.de
- RDMA/irdma: Allow accurate reporting on QP max send/recv WR
  (jsc#PED-6864).
- Refresh
  patches.suse/RDMA-Remove-unnecessary-ternary-operators.patch.
- Refresh
  patches.suse/RDMA-irdma-Drop-unused-kernel-push-code.patch.
- commit 06f966d
* Tue Oct 10 2023 tbogendoerfer@suse.de
- RDMA/bnxt_re: Initialize Doorbell pacing feature (jsc#PED-6864).
- Refresh
  patches.suse/RDMA-bnxt_re-Fix-max_qp-count-for-virtual-functions.patch.
- Refresh patches.suse/RDMA-bnxt_re-Remove-a-redundant-flag.patch.
- commit d397127
* Tue Oct 10 2023 tbogendoerfer@suse.de
- RDMA/rxe: Send last wqe reached event on qp cleanup
  (jsc#PED-6864).
- Refresh
  patches.suse/RDMA-rxe-Fix-unsafe-drain-work-queue-code.patch.
- commit c7d93ae
* Tue Oct 10 2023 tbogendoerfer@suse.de
- igc: Add XDP hints kfuncs for RX timestamp (jsc#PED-4860).
- Refresh
  patches.suse/igc-Fix-TX-Hang-issue-when-QBV-Gate-is-closed.patch.
- commit 1039403
* Tue Oct 10 2023 vkarasulli@suse.de
- Update
  patches.suse/Input-cyttsp4_core-change-del_timer_sync-to-tim.patch
  (bsc#1012628 bsc#1213971 CVE-2023-4134).
- commit 879ed5d
* Tue Oct 10 2023 tbogendoerfer@suse.de
- RDMA/bnxt_re: Decrement resource stats correctly (jsc#PED-6864).
- RDMA/bnxt_re: Fix the handling of control path response data
  (jsc#PED-6864).
- RDMA/erdma: Fix NULL pointer access in regmr_cmd (jsc#PED-6864).
- RDMA/erdma: Fix error code in erdma_create_scatter_mtt()
  (jsc#PED-6864).
- qed/red_ll2: Fix undefined behavior bug in struct qed_ll2_info
  (jsc#PED-5734).
- ice: always add legacy 32byte RXDID in supported_rxdids
  (jsc#PED-4876).
- sfc: handle error pointers returned by
  rhashtable_lookup_get_insert_fast() (jsc#PED-6894).
- igc: Expose tx-usecs coalesce setting to user (jsc#PED-4860).
- bnxt_en: Flush XDP for bnxt_poll_nitroa0()'s NAPI
  (jsc#PED-5742).
- igc: Fix infinite initialization loop with early XDP redirect
  (jsc#PED-4860).
- igb: clean up in all error paths when enabling SR-IOV
  (jsc#PED-4866).
- igb: Change IGB_MIN to allow set rx/tx value between 64 and 80
  (jsc#PED-4866).
- igbvf: Change IGBVF_MIN to allow set rx/tx value between 64
  and 80 (jsc#PED-4866).
- igc: Change IGC_MIN to allow set rx/tx value between 64 and 80
  (jsc#PED-4860).
- igb: disable virtualization features on 82580 (jsc#PED-4866).
- sfc: check for zero length in EF10 RX prefix (jsc#PED-6894).
- IB/hfi1: Reduce printing of errors during driver shut down
  (jsc#PED-6864).
- RDMA/hfi1: Move user SDMA system memory pinning code to its
  own file (jsc#PED-6864).
- RDMA/hfi1: Use list_for_each_entry() helper (jsc#PED-6864).
- RDMA/mlx5: Fix trailing */ formatting in block comment
  (jsc#PED-6864).
- RDMA/rxe: Fix redundant break statement in switch-case
  (jsc#PED-6864).
- RDMA/siw: Call llist_reverse_order in siw_run_sq (jsc#PED-6864).
- RDMA/bnxt_re: Fix kernel doc errors (jsc#PED-6864).
- RDMA/erdma: Implement hierarchical MTT (jsc#PED-6864).
- RDMA/erdma: Refactor the storage structure of MTT entries
  (jsc#PED-6864).
- RDMA/erdma: Renaming variable names and field names of struct
  erdma_mem (jsc#PED-6864).
- RDMA/hns: Support hns HW stats (jsc#PED-6864).
- RDMA/hns: Dump whole QP/CQ/MR resource in raw (jsc#PED-6864).
- RDMA/irdma: Add missing kernel-doc in irdma_setup_umode_qp()
  (jsc#PED-6864).
- RDMA/mlx4: Copy union directly (jsc#PED-6864).
- RDMA/bnxt_re: Add support for dmabuf pinned memory regions
  (jsc#PED-6864).
- RDMA/bnxt_re: Protect the PD table bitmap (jsc#PED-6864).
- RDMA/bnxt_re: Initialize mutex dbq_lock (jsc#PED-6864).
- IB/core: Add more speed parsing in ib_get_width_and_speed()
  (jsc#PED-6864).
- RDMA/cxgb4: Set sq_sig_type correctly (jsc#PED-6864).
- RDMA/hns: Remove unused declaration hns_roce_modify_srq()
  (jsc#PED-6864).
- RDMA: Make all 'class' structures const (jsc#PED-6864).
- RDMA: Remove unnecessary NULL values (jsc#PED-6864).
- RDMA/hns: Fix port active speed (jsc#PED-6864).
- RDMA/bnxt_re: Remove unnecessary variable initializations
  (jsc#PED-6864).
- RDMA/bnxt_re: Avoid unnecessary memset (jsc#PED-6864).
- RDMA/bnxt_re: Cleanup bnxt_re_process_raw_qp_pkt_rx() function
  (jsc#PED-6864).
- RDMA/bnxt_re: Fix the sideband buffer size handling for FW
  commands (jsc#PED-6864).
- RDMA/hns: Remove unused function declarations (jsc#PED-6864).
- IB/mlx5: Add HW counter called rx_dct_connect (jsc#PED-6864).
- RDMA/mthca: Remove unnecessary NULL assignments (jsc#PED-6864).
- RDMA/irdma: Fix one kernel-doc comment (jsc#PED-6864).
- RDMA/siw: Fix tx thread initialization (jsc#PED-6864).
- RDMA/mlx: Remove unnecessary variable initializations
  (jsc#PED-6864).
- RDMA/irdma: Use HW specific minimum WQ size (jsc#PED-6864).
- RDMA/core: Get IB width and speed from netdev (jsc#PED-6864).
- bnxt_re: Update the debug counters for doorbell pacing
  (jsc#PED-6864).
- bnxt_re: Expose the missing hw counters (jsc#PED-6864).
- bnxt_re: Update the hw counters for resource stats
  (jsc#PED-6864).
- bnxt_re: Reorganize the resource stats (jsc#PED-6864).
- RDMA/irdma: Cleanup and rename irdma_netdev_vlan_ipv6()
  (jsc#PED-6864).
- RDMA/irdma: Add table based lookup for CQ pointer during an
  event (jsc#PED-6864).
- RDMA/irdma: Refactor error handling in create CQP
  (jsc#PED-6864).
- RDMA/irdma: Drop a local in irdma_sc_get_next_aeqe
  (jsc#PED-6864).
- IB/hfi1: Use struct_size() (jsc#PED-6864).
- RDMA/hns: Remove VF extend configuration (jsc#PED-6864).
- RDMA/hns: Support get XRCD number from firmware (jsc#PED-6864).
- RDMA/qedr: Remove duplicate assignments of va (jsc#PED-6864).
- RDMA/qedr: Remove a duplicate assignment in qedr_create_gsi_qp()
  (jsc#PED-6864).
- RDMA/bnxt_re: Add a new uapi for driver notification
  (jsc#PED-6864).
- RDMA/bnxt_re: Implement doorbell pacing algorithm
  (jsc#PED-6864).
- RDMA/bnxt_re: Update alloc_page uapi for pacing (jsc#PED-6864).
- RDMA/bnxt_re: Enable pacing support for the user apps
  (jsc#PED-6864).
- bnxt_en: Share the bar0 address with the RoCE driver
  (jsc#PED-5742).
- bnxt_en: Update HW interface headers (jsc#PED-5742).
- RDMA/cma: Avoid GID lookups on iWARP devices (jsc#PED-6864).
- RDMA/cma: Deduplicate error flow in cma_validate_port()
  (jsc#PED-6864).
- RDMA/core: Set gid_attr.ndev for iWARP devices (jsc#PED-6864).
- RDMA/bnxt_re: use vmalloc_array and vcalloc (jsc#PED-6864).
- RDMA/siw: use vmalloc_array and vcalloc (jsc#PED-6864).
- RDMA/erdma: use vmalloc_array and vcalloc (jsc#PED-6864).
- RDMA/irdma: Fix building without IPv6 (jsc#PED-6864).
- RDMA/irdma: Implement egress VLAN priority (jsc#PED-6864).
- RDMA/efa: Add RDMA write HW statistics counters (jsc#PED-6864).
- RDMA/mlx5: align MR mem allocation size to power-of-two
  (jsc#PED-6864).
- sfc: Check firmware supports Ethernet PTP filter (jsc#PED-6894).
- sfc: extend pedit add action to handle decrement ipv6 hop limit
  (jsc#PED-6894).
- sfc: introduce pedit add actions on the ipv4 ttl field
  (jsc#PED-6894).
- sfc: add decrement ipv6 hop limit by offloading set hop limit
  actions (jsc#PED-6894).
- sfc: add decrement ttl by offloading set ipv4 ttl actions
  (jsc#PED-6894).
- sfc: add mac source and destination pedit action offload
  (jsc#PED-6894).
- sfc: introduce ethernet pedit set action infrastructure
  (jsc#PED-6894).
- IB/core: Reorder GID delete code for RoCE (jsc#PED-6864).
- bnxt: use the NAPI skb allocation cache (jsc#PED-5742).
- bnxt_en: Add tx_resets ring counter (jsc#PED-5742).
- bnxt_en: Display the ring error counters under ethtool -S
  (jsc#PED-5742).
- bnxt_en: Save ring error counters across reset (jsc#PED-5742).
- bnxt_en: Increment rx_resets counter in bnxt_disable_napi()
  (jsc#PED-5742).
- bnxt_en: Let the page pool manage the DMA mapping
  (jsc#PED-5742).
- bnxt_en: Use the unified RX page pool buffers for XDP and
  non-XDP (jsc#PED-5742).
- sfc: Remove unneeded semicolon (jsc#PED-6894).
- sfc: offload left-hand side rules for conntrack (jsc#PED-6894).
- sfc: conntrack state matches in TC rules (jsc#PED-6894).
- sfc: handle non-zero chain_index on TC rules (jsc#PED-6894).
- sfc: offload conntrack flow entries (match only) from CT zones
  (jsc#PED-6894).
- sfc: functions to insert/remove conntrack entries to MAE
  hardware (jsc#PED-6894).
- sfc: functions to register for conntrack zone offload
  (jsc#PED-6894).
- sfc: add MAE table machinery for conntrack table (jsc#PED-6894).
- bnxt_en: Fix W=stringop-overflow warning in bnxt_dcb.c
  (jsc#PED-5742).
- bnxt_en: Fix W=1 warning in bnxt_dcb.c from fortify memcpy()
  (jsc#PED-5742).
- eth: add missing xdp.h includes in drivers (jsc#PED-4860).
- eth: bnxt: fix warning for define in struct_group
  (jsc#PED-5742).
- eth: bnxt: fix one of the W=1 warnings about fortified memcpy()
  (jsc#PED-5742).
- sfc: Remove vfdi.h (jsc#PED-6894).
- sfc: Cleanups in io.h (jsc#PED-6894).
- sfc: Miscellaneous comment removals (jsc#PED-6894).
- sfc: Remove struct efx_special_buffer (jsc#PED-6894).
- sfc: Filter cleanups for Falcon and Siena (jsc#PED-6894).
- sfc: Remove some NIC type indirections that are no longer needed
  (jsc#PED-6894).
- sfc: Remove PTP code for Siena (jsc#PED-6894).
- sfc: Remove EFX_REV_SIENA_A0 (jsc#PED-6894).
- sfc: Remove support for siena high priority queue
  (jsc#PED-6894).
- sfc: Remove siena_nic_data and stats (jsc#PED-6894).
- sfc: Remove falcon references (jsc#PED-6894).
- net/mlx4: clean up a type issue (jsc#PED-3309).
- eth: bnxt: handle invalid Tx completions more gracefully
  (jsc#PED-5742).
- eth: bnxt: take the bit to set as argument of
  bnxt_queue_sp_work() (jsc#PED-5742).
- eth: bnxt: move and rename reset helpers (jsc#PED-5742).
- net: bna: Remove unnecessary (void*) conversions (jsc#PED-6884).
- igc: Add TransmissionOverrun counter (jsc#PED-4860).
- bnxt_en: use dev_consume_skb_any() in bnxt_tx_int
  (jsc#PED-5742).
- infiniband: convert to ctime accessor functions (jsc#PED-6864).
- fs: add ctime accessors infrastructure (jsc#PED-6864).
- sfc: allocate a big enough SKB for loopback selftest packet
  (jsc#PED-6894).
- RDMA/bnxt_re: Initialize dpi_tbl_lock mutex (jsc#PED-6864).
- sfc: fix field-spanning memcpy in selftest (jsc#PED-6894).
- RDMA/rxe: Fix an error handling path in rxe_bind_mw()
  (jsc#PED-6864).
- bna: Remove error checking for debugfs_create_dir()
  (jsc#PED-6884).
- RDMA/bnxt_re: Fix an IS_ERR() vs NULL check (jsc#PED-6864).
- RDMA/bnxt_re: Fix spelling mistake "priviledged" -> "privileged"
  (jsc#PED-6864).
- RDMA/bnxt_re: Remove duplicated include in bnxt_re/main.c
  (jsc#PED-6864).
- RDMA/bnxt_re: Refactor code around bnxt_qplib_map_rc()
  (jsc#PED-6864).
- RDMA/bnxt_re: Remove incorrect return check from slow path
  (jsc#PED-6864).
- RDMA/bnxt_re: Enable low latency push (jsc#PED-6864).
- RDMA/bnxt_re: Reorg the bar mapping (jsc#PED-6864).
- RDMA/bnxt_re: Move the interface version to chip context
  structure (jsc#PED-6864).
- RDMA/bnxt_re: Query function capabilities from firmware
  (jsc#PED-6864).
- RDMA/bnxt_re: Optimize the bnxt_re_init_hwrm_hdr usage
  (jsc#PED-6864).
- RDMA/bnxt_re: Add disassociate ucontext support (jsc#PED-6864).
- RDMA/bnxt_re: Use the common mmap helper functions
  (jsc#PED-6864).
- RDMA/bnxt_re: Initialize opcode while sending message
  (jsc#PED-6864).
- RDMA/cma: Remove NULL check before dev_{put, hold}
  (jsc#PED-6864).
- RDMA/rxe: Simplify cq->notify code (jsc#PED-6864).
- RDMA/rxe: Fixes mr access supported list (jsc#PED-6864).
- RDMA/bnxt_re: optimize the parameters passed to helper functions
  (jsc#PED-6864).
- RDMA/bnxt_re: remove redundant cmdq_bitmap (jsc#PED-6864).
- RDMA/bnxt_re: use firmware provided max request timeout
  (jsc#PED-6864).
- RDMA/bnxt_re: cancel all control path command waiters upon error
  (jsc#PED-6864).
- RDMA/bnxt_re: post destroy_ah for delayed completion of AH
  creation (jsc#PED-6864).
- RDMA/bnxt_re: Add firmware stall check detection (jsc#PED-6864).
- RDMA/bnxt_re: handle command completions after driver detect
  a timedout (jsc#PED-6864).
- RDMA/bnxt_re: set fixed command queue depth (jsc#PED-6864).
- RDMA/bnxt_re: remove virt_func check while creating RoCE FW
  channel (jsc#PED-6864).
- RDMA/erdma: Refactor the original doorbell allocation mechanism
  (jsc#PED-6864).
- RDMA/erdma: Associate QPs/CQs with doorbells for authorization
  (jsc#PED-6864).
- RDMA/erdma: Allocate doorbell resources from hardware
  (jsc#PED-6864).
- RDMA/erdma: Configure PAGE_SIZE to hardware (jsc#PED-6864).
- RDMA/rxe: Implement rereg_user_mr (jsc#PED-6864).
- RDMA/rxe: Let rkey == lkey for local access (jsc#PED-6864).
- RDMA/rxe: Introduce rxe access supported flags (jsc#PED-6864).
- RDMA//rxe: Optimize send path in rxe_resp.c (jsc#PED-6864).
- RDMA/rxe: Rename IB_ACCESS_REMOTE (jsc#PED-6864).
- RDMA/hns: Add clear_hem return value to log (jsc#PED-6864).
- RDMA/hns: Remove unnecessary QP type checks (jsc#PED-6864).
- IB/hfi1: Remove unused struct mmu_rb_ops fields .insert,
  .invalidate (jsc#PED-6864).
- IB/hfi1: Add mmu_rb_node refcount to hfi1_mmu_rb_template
  tracepoints (jsc#PED-6864).
- RDMA/rtrs: Remove duplicate cq_num assignment (jsc#PED-6864).
- RDMA/rxe: Fix comments about removed tasklets (jsc#PED-6864).
- RDMA/rxe: Add workqueue support for rxe tasks (jsc#PED-6864).
- sfc: falcon: use padding to fix alignment in loopback test
  (jsc#PED-6894).
- sfc: siena: use padding to fix alignment in loopback test
  (jsc#PED-6894).
- sfc: use padding to fix alignment in loopback test
  (jsc#PED-6894).
- sfc: keep alive neighbour entries while a TC encap action is
  using them (jsc#PED-6894).
- bnxt_en: Link representors to PCI device (jsc#PED-5742).
- sfc: fix uninitialized variable use (jsc#PED-6894).
- sfc: add CONFIG_INET dependency for TC offload (jsc#PED-6894).
- sfc: do not try to call tc functions when CONFIG_SFC_SRIOV=n
  (jsc#PED-6894).
- net/sched: taprio: report class offload stats per TXQ, not
  per TC (jsc#PED-4860).
- sfc: Add devlink dev info support for EF10 (jsc#PED-6894).
- sfc: generate encap headers for TC offload (jsc#PED-6894).
- sfc: neighbour lookup for TC encap action offload
  (jsc#PED-6894).
- sfc: MAE functions to create/update/delete encap headers
  (jsc#PED-6894).
- sfc: add function to atomically update a rule in the MAE
  (jsc#PED-6894).
- sfc: some plumbing towards TC encap action offload
  (jsc#PED-6894).
- net: enetc: report statistics counters for taprio
  (jsc#PED-4860).
- net: enetc: refactor enetc_setup_tc_taprio() to have a
  switch/case for cmd (jsc#PED-4860).
- net/sched: taprio: add netlink reporting for offload statistics
  counters (jsc#PED-4860).
- net/sched: taprio: don't overwrite "sch" variable in
  taprio_dump_class_stats() (jsc#PED-4860).
- sfc: handle VI shortage on ef100 by readjusting the channels
  (jsc#PED-6894).
- net/mlx4: Use bitmap_weight_and() (jsc#PED-3309).
- igb: Define igb_pm_ops conditionally on CONFIG_PM
  (jsc#PED-4866).
- net: remove __skb_frag_set_page() (jsc#PED-5742).
- sfc: support TC decap rules matching on enc_src_port
  (jsc#PED-6894).
- commit d69eedd
* Tue Oct 10 2023 tabraham@suse.com
- x86/platform/uv: Use alternate source for socket to node data
  (bsc#1215696).
- commit 1ce9cf2
* Tue Oct 10 2023 iivanov@suse.de
- KVM: arm64: Avoid soft lockups due to I-cache maintenance (bsc#1215880)
- commit a486709
* Tue Oct 10 2023 iivanov@suse.de
- KVM: arm64: Drop is_kernel_in_hyp_mode() from (bsc#1215880)
- commit 5a1d7a4
* Tue Oct 10 2023 iivanov@suse.de
- arm64: tlbflush: Rename MAX_TLBI_OPS (bsc#1215880)
- commit a4d53b2
* Mon Oct  9 2023 mkoutny@suse.com
- mm, memcg: reconsider kmem.limit_in_bytes deprecation
  (bsc#1208788 bsc#1213705).
- commit 8678375
* Mon Oct  9 2023 mkoutny@suse.com
- Revert "Delete patches.suse/memcg-drop-kmem-limit_in_bytes.patch."
  This reverts commit 52c1db3eb4e2acbdd91aaaefddc26b7207cd4c90.
  It'll be fixed differently in a following commit.
  Restore the commit with upstream commit already for proper sorting.
- commit dcac9e6
* Mon Oct  9 2023 mkoutny@suse.com
- blk-cgroup: Fix NULL deref caused by blkg_policy_data being
  installed before init (bsc#1216062).
- commit 82eb0da
* Mon Oct  9 2023 tiwai@suse.de
- HID: sony: remove duplicate NULL check before calling
  usb_free_urb() (git-fixes).
- commit 4e63039
* Mon Oct  9 2023 tiwai@suse.de
- PCI/PM: Mark devices disconnected if upstream PCIe link is
  down on resume (git-fixes).
- PCI: qcom: Fix IPQ8074 enumeration (git-fixes).
- platform/x86: hp-wmi:: Mark driver struct with __refdata to
  prevent section mismatch warning (git-fixes).
- platform/mellanox: tmfifo: fix kernel-doc warnings (git-fixes).
- platform/x86/intel/ifs: release cpus_read_lock() (git-fixes).
- platform/x86: think-lmi: Fix reference leak (git-fixes).
- net: lan743x: also select PHYLIB (git-fixes).
- wifi: iwlwifi: mvm: Fix incorrect usage of scan API (git-fixes).
- wifi: mac80211: Create resources for disabled links (git-fixes).
- wifi: mac80211: fix potential key use-after-free (git-fixes).
- wifi: mt76: mt76x02: fix MT76x0 external LNA gain handling
  (git-fixes).
- wifi: mwifiex: Fix oob check condition in
  mwifiex_process_rx_packet (git-fixes).
- wifi: rtw88: rtw8723d: Fix MAC address offset in EEPROM
  (git-fixes).
- wifi: mac80211: fix mesh id corruption on 32 bit systems
  (git-fixes).
- wifi: iwlwifi: mvm: Fix a memory corruption issue (git-fixes).
- wifi: iwlwifi: dbg_ini: fix structure packing (git-fixes).
- wifi: cfg80211/mac80211: hold link BSSes when assoc fails for
  MLO connection (git-fixes).
- wifi: mwifiex: Fix tlv_buf_left calculation (git-fixes).
- wifi: mt76: fix lock dependency problem for wed_lock
  (git-fixes).
- net: nfc: llcp: Add lock when modifying device list (git-fixes).
- regulator/core: Revert "fix kobject release warning and memory
  leak in regulator_register()" (git-fixes).
- regulator/core: regulator_register: set device->class earlier
  (git-fixes).
- regmap: rbtree: Fix wrong register marked as in-cache when
  creating new node (git-fixes).
- nilfs2: fix potential use after free in
  nilfs_gccache_submit_read_data() (git-fixes).
- Revert "tty: n_gsm: fix UAF in gsm_cleanup_mux" (git-fixes).
- serial: 8250_port: Check IRQ data before use (git-fixes).
- soc: imx8m: Enable OCOTP clock for imx8mm before reading
  registers (git-fixes).
- power: supply: rk817: Fix node refcount leak (git-fixes).
- power: supply: core: fix use after free in uevent (git-fixes).
- power: supply: rt9467: Fix rt9467_run_aicl() (git-fixes).
- power: supply: rk817: Add missing module alias (git-fixes).
- power: supply: ucs1002: fix error code in ucs1002_get_property()
  (git-fixes).
- power: supply: mt6370: Fix missing error code in
  mt6370_chg_toggle_cfo() (git-fixes).
- spi: spi-gxp: BUG: Correct spi write return value (git-fixes).
- commit 411dd64
* Mon Oct  9 2023 tiwai@suse.de
- dt-bindings: trivial-devices: Fix MEMSIC MXC4005 compatible
  string (git-fixes).
- media: dt-bindings: imx7-csi: Make power-domains not required
  for imx8mq (git-fixes).
- dt-bindings: media: renesas,vin: Fix field-even-active spelling
  (git-fixes).
- gpio: aspeed: fix the GPIO number passed to
  pinctrl_gpio_set_config() (git-fixes).
- gpio: pxa: disable pinctrl calls for MMP_GPIO (git-fixes).
- HID: intel-ish-hid: ipc: Disable and reenable ACPI GPE bit
  (git-fixes).
- HID: sony: Fix a potential memory leak in sony_probe()
  (git-fixes).
- iwlwifi: mvm: handle PS changes in vif_cfg_changed (git-fixes).
- net: usb: smsc75xx: Fix uninit-value access in
  __smsc75xx_read_reg (git-fixes).
- leds: Drop BUG_ON check for LED_COLOR_ID_MULTI (git-fixes).
- modpost: add missing else to the "of" check (git-fixes).
- firmware: arm_scmi: Fixup perf power-cost/microwatt support
  (git-fixes).
- firmware: arm_ffa: Don't set the memory region attributes for
  MEM_LEND (git-fixes).
- firmware: imx-dsp: Fix an error handling path in
  imx_dsp_setup_channels() (git-fixes).
- bus: ti-sysc: Fix missing AM35xx SoC matching (git-fixes).
- i2c: npcm7xx: Fix callback completion ordering (git-fixes).
- gpio: pmic-eic-sprd: Add can_sleep flag for PMIC EIC chip
  (git-fixes).
- clk: tegra: fix error return case for recalc_rate (git-fixes).
- clk: si521xx: Fix regmap write accessor (git-fixes).
- clk: si521xx: Use REGCACHE_FLAT instead of NONE (git-fixes).
- clk: sprd: Fix thm_parents incorrect configuration (git-fixes).
- cxl/region: Match auto-discovered region decoders by HPA range
  (git-fixes).
- cxl/pci: Fix appropriate checking for _OSC while handling CXL
  RAS registers (git-fixes).
- gpio: tb10x: Fix an error handling path in tb10x_gpio_probe()
  (git-fixes).
- i2c: xiic: Correct return value check for xiic_reinit()
  (git-fixes).
- i2c: mux: gpio: Add missing fwnode_handle_put() (git-fixes).
- i2c: mux: demux-pinctrl: check the return value of
  devm_kstrdup() (git-fixes).
- i2c: i801: unregister tco_pdev in i801_probe() error path
  (git-fixes).
- gve: fix frag_list chaining (git-fixes).
- net: usb: qmi_wwan: add Quectel EM05GV2 (git-fixes).
- commit 144b2b0
* Mon Oct  9 2023 tiwai@suse.de
- Bluetooth: hci_codec: Fix leaking content of local_codecs
  (git-fixes).
- Bluetooth: ISO: Fix handling of listen for unicast (git-fixes).
- Bluetooth: Fix hci_link_tx_to RCU lock usage (git-fixes).
- Bluetooth: hci_sync: Fix handling of
  HCI_QUIRK_STRICT_DUPLICATE_FILTER (git-fixes).
- Bluetooth: Delete unused hci_req_prepare_suspend() declaration
  (git-fixes).
- ACPI: NFIT: Fix incorrect calculation of idt size (git-fixes).
- arm64: defconfig: remove CONFIG_COMMON_CLK_NPCM8XX=y
  (git-fixes).
- bus: ti-sysc: Use fsleep() instead of usleep_range() in
  sysc_reset() (git-fixes).
- ARM: uniphier: fix cache kernel-doc warnings (git-fixes).
- ata: libata-core: Do not register PM operations for SAS ports
  (git-fixes).
- ata: libata-core: Fix port and device removal (git-fixes).
- ata: libata-core: Fix ata_port_request_pm() locking (git-fixes).
- ata: libata-sata: increase PMP SRST timeout to 10s (git-fixes).
- ata: libata-scsi: ignore reserved bits for REPORT SUPPORTED
  OPERATION CODES (git-fixes).
- accel/ivpu: Use cached buffers for FW loading (git-fixes).
- accel/ivpu: Do not use wait event interruptible (git-fixes).
- commit 8671b07
* Mon Oct  9 2023 tiwai@suse.de
- misc: rtsx: Fix some platforms can not boot and move the l1ss
  judgment to probe (bsc#1214397,bsc#1214428).
- commit cb63da0
* Mon Oct  9 2023 tiwai@suse.de
- Drop the downstream revert patch for rtsx driver (bsc#1214397,bsc#1214428)
  The upstream fix will follow
- commit 12a98ef
* Mon Oct  9 2023 svarbanov@suse.de
- config/arm64: Unset default IOMMU passthrough option (jsc#PED-7009)
  This will effectively enable ARM64 SMMU translation by default,
  which will help to avoid installation and runtime issues on some
  platforms. The passtrhough mode could still be enabled by kernel
  cmdline.
- commit 8b95409
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/mlx5: Remove not-used cache disable flag (git-fixes)
- commit d265793
* Mon Oct  9 2023 schwab@suse.de
- mkspec-dtb: add toplevel symlinks also on arm
- commit ed29cae
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/core: Require admin capabilities to set system parameters (git-fixes)
- commit ba648d8
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/cma: Initialize ib_sa_multicast structure to 0 when join (git-fixes)
- commit 4975d08
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/mlx5: Fix mkey cache possible deadlock on cleanup (git-fixes)
- commit 36b7bc4
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/mlx5: Fix NULL string error (git-fixes)
- commit 997bcef
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/mlx5: Fix mutex unlocking on error flow for steering anchor creation (git-fixes)
- commit 386907d
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/mlx5: Fix assigning access flags to cache mkeys (git-fixes)
- commit 48eb599
* Mon Oct  9 2023 nmorey@suse.com
- IB/mlx4: Fix the size of a buffer in add_port_entries() (git-fixes)
- commit db2e278
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/cma: Fix truncation compilation warning in make_cma_ports (git-fixes)
- commit d432eb1
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/uverbs: Fix typo of sizeof argument (git-fixes)
- commit e989827
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/cxgb4: Check skb value for failure to allocate (git-fixes)
- commit c91349a
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/siw: Fix connection failure handling (git-fixes)
- commit 0c6c2d5
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/srp: Do not call scsi_done() from srp_abort() (git-fixes)
- commit decf5af
* Mon Oct  9 2023 nmorey@suse.com
- scsi: RDMA/srp: Fix residual handling (git-fixes)
- commit e8f13ae
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/efa: Fix wrong resources deallocation order (git-fixes)
- commit ee5fede
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/siw: Correct wrong debug message (git-fixes)
- commit db9b78b
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/siw: Balance the reference of cep->kref in the error path (git-fixes)
- commit 870a58d
* Mon Oct  9 2023 nmorey@suse.com
- Revert "IB/isert: Fix incorrect release of isert connection" (git-fixes)
- commit 2517e23
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/irdma: Prevent zero-length STAG registration (git-fixes)
- commit 301ea4d
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/irdma: Drop unused kernel push code (git-fixes)
- commit 9786b53
* Mon Oct  9 2023 nmorey@suse.com
- RDMA: Remove unnecessary ternary operators (git-fixes)
- commit b3ae7a5
* Mon Oct  9 2023 trenn@suse.com
- platform/x86: ISST: Fix usage counter (jsc#PED-6156).
- commit f576773
* Mon Oct  9 2023 trenn@suse.com
- platform/x86: ISST: Reset default callback on unregister
  (jsc#PED-6156).
- commit 7c37bca
* Mon Oct  9 2023 nmorey@suse.com
- IB/uverbs: Fix an potential error pointer dereference (git-fixes)
- commit ae6bd28
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/hns: Fix CQ and QP cache affinity (git-fixes)
- commit fc1cada
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/hns: Fix inaccurate error label name in init instance (git-fixes)
- commit 34aadc0
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/hns: Fix incorrect post-send with direct wqe of wr-list (git-fixes)
- commit ff3c701
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/bnxt_re: Remove a redundant flag (git-fixes)
- commit 001b6a1
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/bnxt_re: Fix max_qp count for virtual functions (git-fixes)
- commit cc851d8
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/irdma: Replace one-element array with flexible-array member (git-fixes)
- commit 2f666f0
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/rxe: Fix incomplete state save in rxe_requester (git-fixes)
- commit 7b5bacf
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/rxe: Fix rxe_modify_srq (git-fixes)
- commit 7c8a1be
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/rxe: Fix unsafe drain work queue code (git-fixes)
- commit d04f3ed
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/rxe: Move work queue code to subroutines (git-fixes)
- commit 069a48c
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/siw: Fabricate a GID on tun and loopback devices (git-fixes)
- commit 58aadd5
* Mon Oct  9 2023 nmorey@suse.com
- RDMA/qedr: Remove a duplicate assignment in irdma_query_ah() (git-fixes)
- commit 8fd5f7d
* Mon Oct  9 2023 osalvador@suse.de
- remove ARCH_DEFAULT_KEXEC from Kconfig.kexec (jsc#PED-5077).
  - Update config files.
- commit a2c1b41
* Mon Oct  9 2023 osalvador@suse.de
- kexec: rename ARCH_HAS_KEXEC_PURGATORY (jsc#PED-5077).
  - Update config files.
- commit 4e0f1dd
* Mon Oct  9 2023 osalvador@suse.de
- sh/kexec: refactor for kernel/Kconfig.kexec (jsc#PED-5077).
- commit d29693b
* Mon Oct  9 2023 osalvador@suse.de
- s390/kexec: refactor for kernel/Kconfig.kexec (jsc#PED-5077).
  - Update config files.
- commit 0e6748b
* Mon Oct  9 2023 osalvador@suse.de
- riscv/kexec: refactor for kernel/Kconfig.kexec (jsc#PED-5077).
- commit bbf5fbe
* Mon Oct  9 2023 osalvador@suse.de
- powerpc/kexec: refactor for kernel/Kconfig.kexec (jsc#PED-5077).
  - Update config files.
  - Refresh
  patches.suse/powerpc-kexec_file-Add-KEXEC_SIG-support.patch.
- commit 077b3fb
* Mon Oct  9 2023 osalvador@suse.de
- parisc/kexec: refactor for kernel/Kconfig.kexec (jsc#PED-5077).
- commit c64a611
* Mon Oct  9 2023 osalvador@suse.de
- mips/kexec: refactor for kernel/Kconfig.kexec (jsc#PED-5077).
- commit 1ae0d67
* Mon Oct  9 2023 osalvador@suse.de
- m68k/kexec: refactor for kernel/Kconfig.kexec (jsc#PED-5077).
- commit 6e42e37
* Mon Oct  9 2023 osalvador@suse.de
- loongarch/kexec: refactor for kernel/Kconfig.kexec
  (jsc#PED-5077).
- commit 6db9a98
* Mon Oct  9 2023 osalvador@suse.de
- arm64/kexec: refactor for kernel/Kconfig.kexec (jsc#PED-5077).
  Update config files.
- commit 7a2ece0
* Mon Oct  9 2023 osalvador@suse.de
- ia64/kexec: refactor for kernel/Kconfig.kexec (jsc#PED-5077).
- commit 1ec163c
* Sat Oct  7 2023 petr.pavlu@suse.com
- doc/README.PATCH-POLICY.SUSE: Convert the document to Markdown
  (jsc#PED-5021)
- commit c05cfc9
* Sat Oct  7 2023 petr.pavlu@suse.com
- doc/README.SUSE: Convert the document to Markdown (jsc#PED-5021)
- commit bff5e3e
* Fri Oct  6 2023 tonyj@suse.de
- docs: ABI: sysfs-bus-event_source-devices-hv_gpci:
  Document affinity_domain_via_partition sysfs interface file
  (jsc#PED-5059).
- powerpc/hv_gpci: Add sysfs file inside hv_gpci device to show
  affinity domain via partition information (jsc#PED-5059).
- docs: ABI: sysfs-bus-event_source-devices-hv_gpci: Document
  affinity_domain_via_domain sysfs interface file (jsc#PED-5059).
- powerpc/hv_gpci: Add sysfs file inside hv_gpci device to show
  affinity domain via domain information (jsc#PED-5059).
- docs: ABI: sysfs-bus-event_source-devices-hv_gpci: Document
  affinity_domain_via_virtual_processor sysfs interface file
  (jsc#PED-5059).
- powerpc/hv_gpci: Add sysfs file inside hv_gpci device to
  show affinity domain via virtual processor information
  (jsc#PED-5059).
- docs: ABI: sysfs-bus-event_source-devices-hv_gpci: Document
  processor_config sysfs interface file (jsc#PED-5059).
- powerpc/hv_gpci: Add sysfs file inside hv_gpci device to show
  processor config information (jsc#PED-5059).
- docs: ABI: sysfs-bus-event_source-devices-hv_gpci: Document
  processor_bus_topology sysfs interface file (jsc#PED-5059).
- powerpc/hv_gpci: Add sysfs file inside hv_gpci device to show
  processor bus topology information (jsc#PED-5059).
- commit 4340580
* Fri Oct  6 2023 osalvador@suse.de
- arm/kexec: refactor for kernel/Kconfig.kexec (jsc#PED-5077).
- Update config files.
- commit 9b5f79b
* Fri Oct  6 2023 osalvador@suse.de
- x86/kexec: refactor for kernel/Kconfig.kexec (jsc#PED-5077).
- Update config files.
- commit cce285e
* Fri Oct  6 2023 petr.pavlu@suse.com
- tracing/user_events: Align set_bit() address for all archs
  (git-fixes).
- commit 0517cb9
* Fri Oct  6 2023 trenn@suse.com
- powercap: intel_rapl: Fix invalid setting of Power Limit 4
  (jsc#PED-4897).
- commit 93c416d
* Fri Oct  6 2023 petr.pavlu@suse.com
- ring-buffer: Update "shortest_full" in polling (git-fixes).
- commit b94b97e
* Fri Oct  6 2023 osalvador@suse.de
- kexec: consolidate kexec and crash options into (jsc#PED-5077).
  Update config files
- commit c2b1332
* Fri Oct  6 2023 petr.pavlu@suse.com
- ring-buffer: Fix bytes info in per_cpu buffer stats (git-fixes).
- commit bba0794
* Fri Oct  6 2023 petr.pavlu@suse.com
- bpf: Add override check to kprobe multi link attach (git-fixes).
- commit 2bdd913
* Fri Oct  6 2023 petr.pavlu@suse.com
- tracing/synthetic: Print out u64 values properly (git-fixes).
- commit 7459811
* Fri Oct  6 2023 petr.pavlu@suse.com
- tracing/synthetic: Fix order of struct trace_dynamic_info
  (git-fixes).
- commit 9637422
* Fri Oct  6 2023 petr.pavlu@suse.com
- tracing: Have event inject files inc the trace array ref count
  (git-fixes).
- commit 6d09b7b
* Fri Oct  6 2023 petr.pavlu@suse.com
- tracing: Have option files inc the trace array ref count
  (git-fixes).
- commit a16dcad
* Fri Oct  6 2023 petr.pavlu@suse.com
- tracing: Have current_trace inc the trace array ref count
  (git-fixes).
- commit e5136de
* Fri Oct  6 2023 petr.pavlu@suse.com
- tracing: Have tracing_max_latency inc the trace array ref count
  (git-fixes).
- commit 468c799
* Fri Oct  6 2023 petr.pavlu@suse.com
- tracing: Increase trace array ref count on enable and filter
  files (git-fixes).
- commit 2d3bc8b
* Fri Oct  6 2023 petr.pavlu@suse.com
- tracing: Fix race issue between cpu buffer write and swap
  (git-fixes).
- commit 4e2c5ec
* Fri Oct  6 2023 petr.pavlu@suse.com
- tracing: Remove extra space at the end of hwlat_detector/mode
  (git-fixes).
- commit 08c501c
* Fri Oct  6 2023 petr.pavlu@suse.com
- tracing: Remove unnecessary copying of tr->current_trace
  (git-fixes).
- commit b14a2bd
* Fri Oct  6 2023 mfranc@suse.cz
- s390/bpf: Let arch_prepare_bpf_trampoline return program size
  (git-fixes bsc#1216004).
- commit d65e779
* Fri Oct  6 2023 petr.pavlu@suse.com
- powerpc/ftrace: Fix dropping weak symbols with older toolchains
  (git-fixes).
- commit 8cbedc1
* Fri Oct  6 2023 petr.pavlu@suse.com
- bpf: Clear the probe_addr for uprobe (git-fixes).
- commit a128a8f
* Fri Oct  6 2023 trenn@suse.com
- powercap: intel_rapl: Introduce RAPL TPMI interface driver (jsc#PED-4897).
- powercap: RAPL: Fix a NULL vs IS_ERR() bug (jsc#PED-4897).
- Update config files.
- supported.conf:
- commit 0f77921
* Fri Oct  6 2023 trenn@suse.com
- powercap: intel_rapl: Introduce core support for TPMI interface
  (jsc#PED-4897).
- commit f7281be
* Fri Oct  6 2023 trenn@suse.com
- powercap: intel_rapl: Introduce RAPL I/F type (jsc#PED-4897).
- commit 9639227
* Fri Oct  6 2023 trenn@suse.com
- powercap: intel_rapl: Make cpu optional for rapl_package
  (jsc#PED-4897).
- commit 28bdcc2
* Fri Oct  6 2023 trenn@suse.com
- powercap: intel_rapl: Remove redundant cpu parameter
  (jsc#PED-4897).
- commit 3651b8f
* Fri Oct  6 2023 trenn@suse.com
- powercap: intel_rapl: Add support for lock bit per Power Limit
  (jsc#PED-4897).
- commit 977316b
* Fri Oct  6 2023 trenn@suse.com
- powercap: intel_rapl: Cleanup Power Limits support
  (jsc#PED-4897).
- commit c7a8fb1
* Fri Oct  6 2023 trenn@suse.com
- powercap: intel_rapl: Use bitmap for Power Limits
  (jsc#PED-4897).
- commit 66103f9
* Fri Oct  6 2023 trenn@suse.com
- powercap: intel_rapl: Change primitive order (jsc#PED-4897).
- commit d24fd48
* Fri Oct  6 2023 trenn@suse.com
- powercap: intel_rapl: Use index to initialize primitive
  information (jsc#PED-4897).
- commit 3c01ff3
* Fri Oct  6 2023 trenn@suse.com
- powercap: intel_rapl: Support per domain energy/power/time unit
  (jsc#PED-4897).
- commit c42816c
* Fri Oct  6 2023 trenn@suse.com
- powercap: intel_rapl: Support per Interface primitive
  information (jsc#PED-4897).
- commit dd80bd7
* Fri Oct  6 2023 tbogendoerfer@suse.de
- i40e: Fix VF VLAN offloading when port VLAN is configured
  (jsc#PED-4874).
- iavf: schedule a request immediately after add/delete vlan
  (jsc#PED-4937).
- iavf: add iavf_schedule_aq_request() helper (jsc#PED-4937).
- iavf: do not process adminq tasks when __IAVF_IN_REMOVE_TASK
  is set (jsc#PED-4937).
- xsk: Fix xsk_build_skb() error: 'skb' dereferencing possible
  ERR_PTR() (jsc#PED-4876).
- ice: avoid executing commands on other ports when driving sync
  (jsc#PED-4876).
- qed/qede: Remove unused declarations (jsc#PED-5734).
- ice: split ice_aq_wait_for_event() func into two (jsc#PED-4876).
- ice: embed &ice_rq_event_info event into struct ice_aq_task
  (jsc#PED-4876).
- ice: ice_aq_check_events: fix off-by-one check when filling
  buffer (jsc#PED-4876).
- ice: drop two params from ice_aq_alloc_free_res()
  (jsc#PED-4876).
- ice: use list_for_each_entry() helper (jsc#PED-4876).
- ice: Remove redundant VSI configuration in eswitch setup
  (jsc#PED-4876).
- ice: move E810T functions to before device agnostic ones
  (jsc#PED-4876).
- ice: refactor ice_vsi_is_vlan_pruning_ena (jsc#PED-4876).
- ice: refactor ice_ptp_hw to make functions static
  (jsc#PED-4876).
- ice: refactor ice_sched to make functions static (jsc#PED-4876).
- ice: Utilize assign_bit() helper (jsc#PED-4876).
- ice: refactor ice_vf_lib to make functions static
  (jsc#PED-4876).
- ice: refactor ice_lib to make functions static (jsc#PED-4876).
- ice: refactor ice_ddp to make functions static (jsc#PED-4876).
- ice: remove unused methods (jsc#PED-4876).
- virtchnl: fix fake 1-elem arrays for structures allocated as
  `nents` (jsc#PED-4876).
- virtchnl: fix fake 1-elem arrays in structures allocated as
  `nents + 1` (jsc#PED-4876).
- virtchnl: fix fake 1-elem arrays in structs allocated as
  `nents + 1` - 1 (jsc#PED-4876).
- qed: remove unused 'resp_size' calculation (jsc#PED-5734).
- i40e: Replace one-element array with flex-array member in
  struct i40e_profile_aq_section (jsc#PED-4874).
- i40e: Replace one-element array with flex-array member in
  struct i40e_section_table (jsc#PED-4874).
- i40e: Replace one-element array with flex-array member in
  struct i40e_profile_segment (jsc#PED-4874).
- i40e: Replace one-element array with flex-array member in
  struct i40e_package_header (jsc#PED-4874).
- ice: clean up __ice_aq_get_set_rss_lut() (jsc#PED-4876).
- ice: add FW load wait (jsc#PED-4876).
- ice: Add get C827 PHY index function (jsc#PED-4876).
- ice: Rename enum ice_pkt_flags values (jsc#PED-4876).
- ice: Add direction metadata (jsc#PED-4876).
- ice: Accept LAG netdevs in bridge offloads (jsc#PED-4876).
- i40e: Remove unused function declarations (jsc#PED-4874).
- net: move struct netdev_rx_queue out of netdevice.h
  (jsc#PED-4876).
- i40e: remove i40e_status (jsc#PED-4874).
- ice: update reset path for SRIOV LAG support (jsc#PED-4876).
- ice: enforce no DCB config changing when in bond (jsc#PED-4876).
- ice: enforce interface eligibility and add messaging for SRIOV
  LAG (jsc#PED-4876).
- ice: support non-standard teardown of bond interface
  (jsc#PED-4876).
- ice: Flesh out implementation of support for SRIOV on bonded
  interface (jsc#PED-4876).
- ice: process events created by lag netdev event handler
  (jsc#PED-4876).
- ice: implement lag netdev event handler (jsc#PED-4876).
- ice: changes to the interface with the HW and FW for
  SRIOV_VF+LAG (jsc#PED-4876).
- ice: Add driver support for firmware changes for LAG
  (jsc#PED-4876).
- ice: Correctly initialize queue context values (jsc#PED-4876).
- ice: add tracepoints for the switchdev bridge (jsc#PED-4876).
- ice: implement static version of ageing (jsc#PED-4876).
- ice: implement bridge port vlan (jsc#PED-4876).
- ice: Add VLAN FDB support in switchdev mode (jsc#PED-4876).
- ice: Add guard rule when creating FDB in switchdev
  (jsc#PED-4876).
- ice: Switchdev FDB events support (jsc#PED-4876).
- ice: Implement basic eswitch bridge setup (jsc#PED-4876).
- ice: Unset src prune on uplink VSI (jsc#PED-4876).
- ice: Disable vlan pruning for uplink VSI (jsc#PED-4876).
- ice: Don't tx before switchdev is fully configured
  (jsc#PED-4876).
- ice: Prohibit rx mode change in switchdev mode (jsc#PED-4876).
- ice: Skip adv rules removal upon switchdev release
  (jsc#PED-4876).
- net: add missing net_device::xdp_zc_max_segs description
  (jsc#PED-4876).
- i40e: xsk: add TX multi-buffer support (jsc#PED-4874).
- ice: xsk: Tx multi-buffer support (jsc#PED-4876).
- i40e: xsk: add RX multi-buffer support (jsc#PED-4874).
- ice: xsk: add RX multi-buffer support (jsc#PED-4876).
- xsk: support mbuf on ZC RX (jsc#PED-4876).
- xsk: add new netlink attribute dedicated for ZC max frags
  (jsc#PED-4876).
- xsk: add support for AF_XDP multi-buffer on Tx path
  (jsc#PED-4876).
- xsk: allow core/drivers to test EOP bit (jsc#PED-4876).
- xsk: introduce wrappers and helpers for supporting multi-buffer
  in Tx path (jsc#PED-4876).
- xsk: add support for AF_XDP multi-buffer on Rx path
  (jsc#PED-4876).
- xsk: move xdp_buff's data length check to xsk_rcv_check
  (jsc#PED-4876).
- xsk: prepare both copy and zero-copy modes to co-exist
  (jsc#PED-4876).
- xsk: introduce XSK_USE_SG bind flag for xsk socket
  (jsc#PED-4876).
- xsk: prepare 'options' in xdp_desc for multi-buffer use
  (jsc#PED-4876).
- i40e: Wait for pending VF reset in VF set callbacks
  (jsc#PED-4874).
- i40e: Add helper for VF inited state check with timeout
  (jsc#PED-4874).
- ice: remove unnecessary (void*) conversions (jsc#PED-4876).
- kbuild: Drop -Wdeclaration-after-statement (jsc#PED-3311).
- commit 90ab4c5
* Fri Oct  6 2023 ykaukab@suse.de
- config: s390x: vanilla: fix build issue
- commit 9aaa9b5
* Fri Oct  6 2023 trenn@suse.com
- powercap: intel_rapl: Support per Interface rapl_defaults
  (jsc#PED-4897).
- commit 950dab1
* Fri Oct  6 2023 ykaukab@suse.de
- Revert "config: s390x: fix vanilla build issue"
  This reverts commit 140a1914f728f337b738db7821eac8fd32ee581c.
  Fix is incorrect. Next commit will fix the build using ./run_oldconfig.sh --vanilla
- commit d6bed17
* Fri Oct  6 2023 trenn@suse.com
- powercap: intel_rapl: Allow probing without CPUID match
  (jsc#PED-4897).
- commit cd0b9eb
* Thu Oct  5 2023 msuchanek@suse.de
- Refresh SED Opal patches to current version.
- Refresh patches.suse/block-sed-opal-SED-Opal-keystore.patch.
- Refresh patches.suse/block-sed-opal-keystore-access-for-SED-Opal-keys.patch.
- Refresh patches.suse/powerpc-pseries-PLPKS-SED-Opal-keystore-support.patch.
- commit af23332
* Thu Oct  5 2023 ykaukab@suse.de
- config: s390x: fix vanilla build issue
- commit 140a191
* Thu Oct  5 2023 tbogendoerfer@suse.de
- sfc: fix use-after-free in efx_tc_flower_record_encap_match()
  (jsc#PED-3311).
- commit 66a3362
* Thu Oct  5 2023 tbogendoerfer@suse.de
- net/mlx5e: Move MACsec flow steering operations to be used as
  core library (jsc#PED-3311).
- Update config files.
- commit 980e37c
* Thu Oct  5 2023 tbogendoerfer@suse.de
- mlx5/core: E-Switch, Create ACL FT for eswitch manager in
  switchdev mode (jsc#PED-3311).
- net/mlx5e: Clear mirred devices array if the rule is split
  (jsc#PED-3311).
- vdpa/mlx5: Remove unused function declarations (jsc#PED-3311).
- net/mlx5: Convert PCI error values to generic errnos
  (jsc#PED-3311).
- net/mlx5: Use RMW accessors for changing LNKCTL (jsc#PED-3311).
- net/mlx5: Dynamic cyclecounter shift calculation for PTP free
  running clock (jsc#PED-3311).
- net/mlx5: Implement devlink port function cmds to control
  ipsec_packet (jsc#PED-3311).
- net/mlx5: Implement devlink port function cmds to control
  ipsec_crypto (jsc#PED-3311).
- net/mlx5: Provide an interface to block change of IPsec
  capabilities (jsc#PED-3311).
- net/mlx5: Add IFC bits to support IPsec enable/disable
  (jsc#PED-3311).
- net/mlx5e: Rewrite IPsec vs. TC block interface (jsc#PED-3311).
- net/mlx5: Drop extra layer of locks in IPsec (jsc#PED-3311).
- devlink: Expose port function commands to control IPsec packet
  offloads (jsc#PED-3311).
- devlink: Expose port function commands to control IPsec crypto
  offloads (jsc#PED-3311).
- net/mlx5e: fix up for "net/mlx5e: Move MACsec flow steering
  operations to be used as core library" (jsc#PED-3311).
- RDMA/mlx5: Handles RoCE MACsec steering rules addition and
  deletion (jsc#PED-3311).
- net/mlx5: Add RoCE MACsec steering infrastructure in core
  (jsc#PED-3311).
- net/mlx5: Configure MACsec steering for ingress RoCEv2 traffic
  (jsc#PED-3311).
- net/mlx5: Configure MACsec steering for egress RoCEv2 traffic
  (jsc#PED-3311).
- net/mlx5: Add MACsec priorities in RDMA namespaces
  (jsc#PED-3311).
- RDMA/mlx5: Implement MACsec gid addition and deletion
  (jsc#PED-3311).
- net/mlx5: Maintain fs_id xarray per MACsec device inside macsec
  steering (jsc#PED-3311).
- net/mlx5: Remove netdevice from MACsec steering (jsc#PED-3311).
- net/mlx5e: Move MACsec flow steering and statistics database
  from ethernet to core (jsc#PED-3311).
- net/mlx5e: Rename MACsec flow steering functions/parameters
  to suit core naming style (jsc#PED-3311).
- net/mlx5: Remove dependency of macsec flow steering on ethernet
  (jsc#PED-3311).
- macsec: add functions to get macsec real netdevice and check
  offload (jsc#PED-3311).
- net/mlx5e: Support IPsec upper TCP protocol selector
  (jsc#PED-3311).
- net/mlx5e: Support IPsec upper protocol selector field offload
  for RX (jsc#PED-3311).
- net/mlx5: Store vport in struct mlx5_devlink_port and use it
  in port ops (jsc#PED-3311).
- net/mlx5: Check vhca_resource_manager capability in each op
  and add extack msg (jsc#PED-3311).
- net/mlx5: Relax mlx5_devlink_eswitch_get() return value checking
  (jsc#PED-3311).
- net/mlx5: Return -EOPNOTSUPP in
  mlx5_devlink_port_fn_migratable_set() directly (jsc#PED-3311).
- net/mlx5: Reduce number of vport lookups passing vport pointer
  instead of index (jsc#PED-3311).
- net/mlx5: Embed struct devlink_port into driver structure
  (jsc#PED-3311).
- net/mlx5: Don't register ops for non-PF/VF/SF port and avoid
  checks in ops (jsc#PED-3311).
- net/mlx5: Remove no longer used
  mlx5_esw_offloads_sf_vport_enable/disable() (jsc#PED-3311).
- net/mlx5: Introduce mlx5_eswitch_load/unload_sf_vport() and
  use it from SF code (jsc#PED-3311).
- net/mlx5: Allow mlx5_esw_offloads_devlink_port_register()
  to register SFs (jsc#PED-3311).
- net/mlx5: Push devlink port PF/VF init/cleanup calls out of
  devlink_port_register/unregister() (jsc#PED-3311).
- net/mlx5: Push out SF devlink port init and cleanup code to
  separate helpers (jsc#PED-3311).
- net/mlx5: Rework devlink port alloc/free into init/cleanup
  (jsc#PED-3311).
- net/mlx5: Devcom, only use devcom after NULL check in
  mlx5_devcom_send_event() (jsc#PED-3311).
- net/mlx5: DR, Supporting inline WQE when possible
  (jsc#PED-3311).
- net/mlx5: Rename devlink port ops struct for PFs/VFs
  (jsc#PED-3311).
- net/mlx5: Remove VPORT_UPLINK handling from devlink_port.c
  (jsc#PED-3311).
- net/mlx5: Call mlx5_esw_offloads_rep_load/unload() for uplink
  port directly (jsc#PED-3311).
- net/mlx5: Remove health syndrome enum duplication
  (jsc#PED-3311).
- net/mlx5: DR, Remove unneeded local variable (jsc#PED-3311).
- net/mlx5: DR, Fix code indentation (jsc#PED-3311).
- net/mlx5: IRQ, consolidate irq and affinity mask allocation
  (jsc#PED-3311).
- net/mlx5e: Fix spelling mistake "Faided" -> "Failed"
  (jsc#PED-3311).
- net/mlx5e: aRFS, Introduce ethtool stats (jsc#PED-3311).
- net/mlx5e: aRFS, Warn if aRFS table does not exist for aRFS rule
  (jsc#PED-3311).
- net/mlx5e: aRFS, Prevent repeated kernel rule migrations
  requests (jsc#PED-3311).
- net/mlx5: Don't query MAX caps twice (jsc#PED-3311).
- net/mlx5: Remove unused MAX HCA capabilities (jsc#PED-3311).
- net/mlx5: Remove unused CAPs (jsc#PED-3311).
- net/mlx5: Fix error message in
  mlx5_sf_dev_state_change_handler() (jsc#PED-3311).
- net/mlx5: Remove redundant check of mlx5_vhca_event_supported()
  (jsc#PED-3311).
- net/mlx5: Use mlx5_sf_start_function_id() helper instead of
  directly calling MLX5_CAP_GEN() (jsc#PED-3311).
- net/mlx5: Remove redundant SF supported check from
  mlx5_sf_hw_table_init() (jsc#PED-3311).
- net/mlx5: Use auxiliary_device_uninit() instead of device_put()
  (jsc#PED-3311).
- net/mlx5: E-switch, Add checking for flow rule destinations
  (jsc#PED-3311).
- net/mlx5: Check with FW that sync reset completed successfully
  (jsc#PED-3311).
- net/mlx5: Expose max possible SFs via devlink resource
  (jsc#PED-3311).
- net/mlx5e: Add recovery flow for tx devlink health reporter
  for unhealthy PTP SQ (jsc#PED-3311).
- net/mlx5e: Make tx_port_ts logic resilient to out-of-order CQEs
  (jsc#PED-3311).
- net/mlx5: Consolidate devlink documentation in devlink/mlx5.rst
  (jsc#PED-3311).
- net/mlx5: Expose NIC temperature via hardware monitoring kernel
  API (jsc#PED-3311).
- net/mlx5: Expose port.c/mlx5_query_module_num() function
  (jsc#PED-3311).
- net/mlx5: Bridge, Only handle registered netdev bridge events
  (jsc#PED-3311).
- net/mlx5: E-Switch, Remove redundant arg ignore_flow_lvl
  (jsc#PED-3311).
- net/mlx5: Fix typo reminder -> remainder (jsc#PED-3311).
- net/mlx5: Allocate completion EQs dynamically (jsc#PED-3311).
- net/mlx5: Handle SF IRQ request in the absence of SF IRQ pool
  (jsc#PED-3311).
- net/mlx5: Rename mlx5_comp_vectors_count() to
  mlx5_comp_vectors_max() (jsc#PED-3311).
- net/mlx5: Add IRQ vector to CPU lookup function (jsc#PED-3311).
- net/mlx5: Introduce mlx5_cpumask_default_spread (jsc#PED-3311).
- net/mlx5: Implement single completion EQ create/destroy methods
  (jsc#PED-3311).
- net/mlx5: Use xarray to store and manage completion EQs
  (jsc#PED-3311).
- net/mlx5: Refactor completion IRQ request/release handlers in
  EQ layer (jsc#PED-3311).
- net/mlx5: Use xarray to store and manage completion IRQs
  (jsc#PED-3311).
- net/mlx5: Refactor completion IRQ request/release API
  (jsc#PED-3311).
- net/mlx5: Track the current number of completion EQs
  (jsc#PED-3311).
- net/mlx5e: Make TC and IPsec offloads mutually exclusive on
  a netdev (jsc#PED-3311).
- net/mlx5e: Add get IPsec offload stats for uplink representor
  (jsc#PED-3311).
- net/mlx5e: Modify and restore TC rules for IPSec TX rules
  (jsc#PED-3311).
- net/mlx5e: Make IPsec offload work together with eswitch and TC
  (jsc#PED-3311).
- net/mlx5: Compare with old_dest param to modify rule destination
  (jsc#PED-3311).
- net/mlx5e: Support IPsec packet offload for TX in switchdev mode
  (jsc#PED-3311).
- net/mlx5e: Refactor IPsec TX tables creation (jsc#PED-3311).
- net/mlx5e: Handle IPsec offload for RX datapath in switchdev
  mode (jsc#PED-3311).
- net/mlx5e: Support IPsec packet offload for RX in switchdev mode
  (jsc#PED-3311).
- net/mlx5e: Refactor IPsec RX tables creation and destruction
  (jsc#PED-3311).
- net/mlx5e: Prepare IPsec packet offload for switchdev mode
  (jsc#PED-3311).
- net/mlx5e: Change the parameter of IPsec RX skb handle function
  (jsc#PED-3311).
- net/mlx5e: Add function to get IPsec offload namespace
  (jsc#PED-3311).
- net: flow_dissector: Use 64bits for used_keys (jsc#PED-3311).
- net/mlx5: Give esw_offloads_load/unload_rep() "mlx5_" prefix
  (jsc#PED-3311).
- net/mlx5: Make mlx5_eswitch_load/unload_vport() static
  (jsc#PED-3311).
- net/mlx5: Make mlx5_esw_offloads_rep_load/unload() static
  (jsc#PED-3311).
- net/mlx5: Remove pointless devlink_rate checks (jsc#PED-3311).
- net/mlx5: Don't check vport->enabled in port ops (jsc#PED-3311).
- net/mlx5e: Make flow classification filters static
  (jsc#PED-3311).
- net/mlx5e: Remove duplicate code for user flow (jsc#PED-3311).
- net/mlx5: Allocate command stats with xarray (jsc#PED-3311).
- net/mlx5: split mlx5_cmd_init() to probe and reload routines
  (jsc#PED-3311).
- net/mlx5: Remove redundant cmdif revision check (jsc#PED-3311).
- net/mlx5: Re-organize mlx5_cmd struct (jsc#PED-3311).
- net/mlx5e: E-Switch, Allow devcom initialization on more vports
  (jsc#PED-3311).
- net/mlx5e: E-Switch, Register devcom device with switch id key
  (jsc#PED-3311).
- net/mlx5: Devcom, Infrastructure changes (jsc#PED-3311).
- net/mlx5: Use shared code for checking lag is supported
  (jsc#PED-3311).
- net/mlx5: Fix flowhash key set/get for custom RSS
  (jsc#PED-3311).
- net/mlx5e: Support IPsec NAT-T functionality (jsc#PED-3311).
- net/mlx5e: Check for IPsec NAT-T support (jsc#PED-3311).
- net/mlx5: Add relevant capabilities bits to support NAT-T
  (jsc#PED-3311).
- sch_htb: Allow HTB quantum parameter in offload mode
  (jsc#PED-3311).
- mlxsw: spectrum_flower: Add ability to match on port ranges
  (jsc#PED-3311).
- mlxsw: spectrum_acl: Pass main driver structure to
  mlxsw_sp_acl_rulei_destroy() (jsc#PED-3311).
- mlxsw: spectrum_acl: Add port range key element (jsc#PED-3311).
- mlxsw: spectrum_port_range: Add port range core (jsc#PED-3311).
- mlxsw: resource: Add resource identifier for port range
  registers (jsc#PED-3311).
- mlxsw: reg: Add Policy-Engine Port Range Register
  (jsc#PED-3311).
- ptp: Make max_phase_adjustment sysfs device attribute invisible
  when not supported (jsc#PED-3311).
- net/mlx5: Fix SFs kernel documentation error (jsc#PED-3311).
- mlxsw: spectrum_flower: Add ability to match on layer 2 miss
  (jsc#PED-3311).
- mlxsw: spectrum_flower: Do not force matching on iif
  (jsc#PED-3311).
- mlxsw: spectrum_flower: Split iif parsing to a separate function
  (jsc#PED-3311).
- devlink: save devlink_port_ops into a variable in
  devlink_port_function_validate() (jsc#PED-3311).
- sfc: support TC decap rules matching on enc_ip_tos
  (jsc#PED-3311).
- sfc: populate enc_ip_tos matches in MAE outer rules
  (jsc#PED-3311).
- commit d4d7288
* Wed Oct  4 2023 mfranc@suse.cz
- scsi: zfcp: Fix a double put in zfcp_port_enqueue() (git-fixes
  bsc#1215938).
- commit 2f8f411
* Wed Oct  4 2023 tbogendoerfer@suse.de
- net/mlx5: Update the driver with the recent thermal changes
  (jsc#PED-3311).
- Refresh
  patches.suse/net-mlx5-Register-a-unique-thermal-zone-per-dev.patch.
- commit d703dfe
* Wed Oct  4 2023 tbogendoerfer@suse.de
- devlink: bring port new reply back (jsc#PED-3311).
- blacklist.conf: removed temp blacklist for this commit
- commit becfbcb
* Wed Oct  4 2023 tbogendoerfer@suse.de
- net/mlx5: Fix mlx5_cmd_update_root_ft() error flow
  (jsc#PED-3311).
- commit f123e4d
* Wed Oct  4 2023 tbogendoerfer@suse.de
- vdpa/mlx5: Fix crash on shutdown for when no ndev exists
  (jsc#PED-3311).
- vdpa/mlx5: Correct default number of queues when MQ is on
  (jsc#PED-3311).
- net/mlx5e: Add capability check for vnic counters
  (jsc#PED-3311).
- net/mlx5: Fix devlink controller number for ECVF (jsc#PED-3311).
- net/mlx5: Return correct EC_VF function ID (jsc#PED-3311).
- net/mlx5: DR, Fix peer domain namespace setting (jsc#PED-3311).
- net/mlx5: Bridge, set debugfs access right to root-only
  (jsc#PED-3311).
- vdpa/mlx5: Support interrupt bypassing (jsc#PED-3311).
- net/mlx5: Rely on dev->link_active_reporting (jsc#PED-3311).
- RDMA/mlx5: Handle DCT QP logic separately from low level QP
  interface (jsc#PED-3311).
- RDMA/mlx5: Reduce QP table exposure (jsc#PED-3311).
- net/mlx5: Nullify qp->dbg pointer post destruction
  (jsc#PED-3311).
- net/mlx5: Remove pointless vport lookup from
  mlx5_esw_check_port_type() (jsc#PED-3311).
- net/mlx5: Remove redundant check from
  mlx5_esw_query_vport_vhca_id() (jsc#PED-3311).
- net/mlx5: Remove redundant is_mdev_switchdev_mode() check from
  is_ib_rep_supported() (jsc#PED-3311).
- net/mlx5: Remove redundant MLX5_ESWITCH_MANAGER() check from
  is_ib_rep_supported() (jsc#PED-3311).
- net/mlx5e: E-Switch, Fix shared fdb error flow (jsc#PED-3311).
- net/mlx5e: Remove redundant comment (jsc#PED-3311).
- net/mlx5e: E-Switch, Pass other_vport flag if vport is not 0
  (jsc#PED-3311).
- net/mlx5e: E-Switch, Use xarray for devcom paired device index
  (jsc#PED-3311).
- net/mlx5e: E-Switch, Add peer fdb miss rules for vport manager
  or ecpf (jsc#PED-3311).
- net/mlx5e: Use vhca_id for device index in vport rx rules
  (jsc#PED-3311).
- net/mlx5: Lag, Remove duplicate code checking lag is supported
  (jsc#PED-3311).
- net/mlx5: Fix error code in mlx5_is_reset_now_capable()
  (jsc#PED-3311).
- net/mlx5: Fix reserved at offset in hca_cap register
  (jsc#PED-3311).
- net/mlx5: Fix UAF in mlx5_eswitch_cleanup() (jsc#PED-3311).
- net/mlx5: Add .getmaxphase ptp_clock_info callback
  (jsc#PED-3311).
- ptp: Add .getmaxphase callback to ptp_clock_info (jsc#PED-3311).
- ptp: Clarify ptp_clock_info .adjphase expects an internal
  servo to be used (jsc#PED-3311).
- net/mlx5: Remove unused ecpu field from struct mlx5_sf_table
  (jsc#PED-3311).
- net/mlx5: Add header file for events (jsc#PED-3311).
- net/mlx5: DR, update query of HCA caps for EC VFs
  (jsc#PED-3311).
- net/mlx5: Fix the macro for accessing EC VF vports
  (jsc#PED-3311).
- net/mlx5e: Add local loopback counter to vport stats
  (jsc#PED-3311).
- net/mlx5: Expose bits for local loopback counter (jsc#PED-3311).
- net/mlx5e: Remove mlx5e_dbg() and msglvl support (jsc#PED-3311).
- net/mlx5: E-Switch, remove redundant else statements
  (jsc#PED-3311).
- net/mlx5: Bridge, expose FDB state via debugfs (jsc#PED-3311).
- net/mlx5: Bridge, pass net device when linking vport to bridge
  (jsc#PED-3311).
- net/mlx5: Create eswitch debugfs root directory (jsc#PED-3311).
- net/mlx5: Handle sync reset unload event (jsc#PED-3311).
- net/mlx5: Check DTOR entry value is not zero (jsc#PED-3311).
- net/mlx5: Expose timeout for sync reset unload stage
  (jsc#PED-3311).
- net/mlx5: Ack on sync_reset_request only if PF can do reset_now
  (jsc#PED-3311).
- net: tls: make the offload check helper take skb not socket
  (jsc#PED-3311).
- net/mlx5e: Remove a useless function call (jsc#PED-3311).
- net/mlx5: Light probe local SFs (jsc#PED-3311).
- net/mlx5: Move esw multiport devlink param to eswitch code
  (jsc#PED-3311).
- net/mlx5: Split function_setup() to enable and open functions
  (jsc#PED-3311).
- net/mlx5: Set max number of embedded CPU VFs (jsc#PED-3311).
- net/mlx5: Update SRIOV enable/disable to handle EC/VFs
  (jsc#PED-3311).
- net/mlx5: Query correct caps for min msix vectors
  (jsc#PED-3311).
- net/mlx5: Use correct vport when restoring GUIDs (jsc#PED-3311).
- net/mlx5: Add new page type for EC VF pages (jsc#PED-3311).
- net/mlx5: Add/remove peer miss rules for EC VFs (jsc#PED-3311).
- net/mlx5: Add management of EC VF vports (jsc#PED-3311).
- net/mlx5: Update vport caps query/set for EC VFs (jsc#PED-3311).
- net/mlx5: Enable devlink port for embedded cpu VF vports
  (jsc#PED-3311).
- net/mlx5: mlx5_ifc updates for embedded CPU SRIOV
  (jsc#PED-3311).
- net/mlx5: Simplify unload all rep code (jsc#PED-3311).
- net/mlx5e: simplify condition after napi budget handling change
  (jsc#PED-3311).
- mlx5/core: E-Switch, Allocate ECPF vport if it's an eswitch
  manager (jsc#PED-3311).
- net/mlx5: Skip inline mode check after
  mlx5_eswitch_enable_locked() failure (jsc#PED-3311).
- net/mlx5e: TC, refactor access to hash key (jsc#PED-3311).
- net/mlx5e: Remove RX page cache leftovers (jsc#PED-3311).
- net/mlx5e: Expose catastrophic steering error counters
  (jsc#PED-3311).
- net/mlx5: Enable 4 ports VF LAG (jsc#PED-3311).
- net/mlx5: LAG, block multiport eswitch LAG in case ldev have
  more than 2 ports (jsc#PED-3311).
- net/mlx5: LAG, block multipath LAG in case ldev have more than
  2 ports (jsc#PED-3311).
- net/mlx5: LAG, change mlx5_shared_fdb_supported() to static
  (jsc#PED-3311).
- net/mlx5: LAG, generalize handling of shared FDB (jsc#PED-3311).
- net/mlx5: LAG, check if all eswitches are paired for shared FDB
  (jsc#PED-3311).
- {net/RDMA}/mlx5: introduce lag_for_each_peer (jsc#PED-3311).
- RDMA/mlx5: Free second uplink ib port (jsc#PED-3311).
- net/mlx5: Devcom, extend mlx5_devcom_send_event to work with
  more than two devices (jsc#PED-3311).
- net/mlx5: Devcom, introduce devcom_for_each_peer_entry
  (jsc#PED-3311).
- net/mlx5: E-switch, mark devcom as not ready when all eswitches
  are unpaired (jsc#PED-3311).
- net/mlx5: Devcom, Rename paired to ready (jsc#PED-3311).
- net/mlx5: DR, handle more than one peer domain (jsc#PED-3311).
- net/mlx5: E-switch, generalize shared FDB creation
  (jsc#PED-3311).
- net/mlx5: E-switch, Handle multiple master egress rules
  (jsc#PED-3311).
- net/mlx5: E-switch, refactor FDB miss rule add/remove
  (jsc#PED-3311).
- net/mlx5: E-switch, enlarge peer miss group table
  (jsc#PED-3311).
- net/mlx5e: Handle offloads flows per peer (jsc#PED-3311).
- net/mlx5e: en_tc, re-factor query route port (jsc#PED-3311).
- net/mlx5e: rep, store send to vport rules per peer
  (jsc#PED-3311).
- net/mlx5e: tc, Refactor peer add/del flow (jsc#PED-3311).
- net/mlx5e: en_tc, Extend peer flows to a list (jsc#PED-3311).
- flow_offload: Reject matching on layer 2 miss (jsc#PED-3311).
- flow_dissector: Dissect layer 2 miss from tc skb extension
  (jsc#PED-3311).
- skbuff: bridge: Add layer 2 miss indication (jsc#PED-3311).
- devlink: move port_del() to devlink_port_ops (jsc#PED-3311).
- devlink: move port_fn_state_get/set() to devlink_port_ops
  (jsc#PED-3311).
- devlink: move port_fn_migratable_get/set() to devlink_port_ops
  (jsc#PED-3311).
- devlink: move port_fn_roce_get/set() to devlink_port_ops
  (jsc#PED-3311).
- devlink: move port_fn_hw_addr_get/set() to devlink_port_ops
  (jsc#PED-3311).
- mlx5: register devlink ports with ops (jsc#PED-3311).
- sfc: register devlink port with ops (jsc#PED-3311).
- devlink: move port_type_set() op into devlink_port_ops
  (jsc#PED-3311).
- mlx4: register devlink port with ops (jsc#PED-3311).
- devlink: remove no longer true locking comment from
  port_new/del() (jsc#PED-3311).
- net/mlx5e: E-Switch, Initialize E-Switch for eswitch manager
  (jsc#PED-3311).
- net/mlx5: devlink, Only show PF related devlink warning when
  needed (jsc#PED-3311).
- net/mlx5: E-Switch, Use metadata matching for RoCE loopback rule
  (jsc#PED-3311).
- net/mlx5: E-Switch, Use RoCE version 2 for loopback traffic
  (jsc#PED-3311).
- net/mlx5e: E-Switch, Add a check that log_max_l2_table is valid
  (jsc#PED-3311).
- net/mlx5e: E-Switch: move debug print of adding mac to correct
  place (jsc#PED-3311).
- net/mlx5e: E-Switch, Check device is PF when stopping esw
  offloads (jsc#PED-3311).
- net/mlx5: Remove redundant vport_group_manager cap check
  (jsc#PED-3311).
- net/mlx5e: E-Switch, Use metadata for vport matching in
  send-to-vport rules (jsc#PED-3311).
- net/mlx5e: E-Switch, Allow get vport api if esw exists
  (jsc#PED-3311).
- net/mlx5e: E-Switch, Update when to set other vport context
  (jsc#PED-3311).
- net/mlx5e: Remove redundant __func__ arg from fs_err() calls
  (jsc#PED-3311).
- net/mlx5e: E-Switch, Remove flow_source check for metadata
  matching (jsc#PED-3311).
- net/mlx5: E-Switch, Remove redundant check (jsc#PED-3311).
- net/mlx5: Remove redundant esw multiport validate function
  (jsc#PED-3311).
- sch_htb: Allow HTB priority parameter in offload mode
  (jsc#PED-3311).
- net: introduce and use skb_frag_fill_page_desc() (jsc#PED-3311).
- macsec: Use helper macsec_netdev_priv for offload drivers
  (jsc#PED-3311).
- commit ff2baea
* Wed Oct  4 2023 mkubecek@suse.cz
- netfilter: xt_sctp: validate the flag_info count (CVE-2023-39193
  bsc#1215860).
- commit 1bae227
* Wed Oct  4 2023 mkubecek@suse.cz
- netfilter: xt_u32: validate user space input (CVE-2023-39192
  bsc#1215858).
- commit 8c838db
* Wed Oct  4 2023 mkubecek@suse.cz
- ipv4: fix null-deref in ipv4_link_failure (CVE-2023-42754
  bsc#1215467).
- commit de82205
* Tue Oct  3 2023 jlee@suse.com
- crypto: akcipher - Do not copy dst if it is NULL (jsc#PED-5460).
- crypto: sig - Fix verify call (jsc#PED-5460).
- crypto: akcipher - Set request tfm on sync path (jsc#PED-5460).
- commit d75a995
* Tue Oct  3 2023 palcantara@suse.de
- fs/smb/client: Reset password pointer to NULL (bsc#1215899
  CVE-2023-5345).
- commit 5ddd22d
* Tue Oct  3 2023 jlee@suse.com
- crypto: sm2 - Fix crash caused by uninitialized context
  (jsc#PED-5460).
- KEYS: asymmetric: Fix error codes (jsc#PED-5460).
- crypto: sm2 - Provide sm2_compute_z_digest when sm2 is disabled
  (jsc#PED-5460).
- KEYS: asymmetric: Use new crypto interface without scatterlists
  (jsc#PED-5460).
- KEYS: asymmetric: Move sm2 code into x509_public_key
  (jsc#PED-5460).
- commit 253faa7
* Tue Oct  3 2023 msuchanek@suse.de
- supported.conf: Add new p10 crypto modules (jsc#PED-5089).
- commit 1cbe2fd
* Tue Oct  3 2023 petr.pavlu@suse.com
- doc/README.PATCH-POLICY.SUSE: Remove the list of links (jsc#PED-5021)
  All links have been incorporated into the text. Remove now unnecessary
  list at the end of the document.
- commit 43d62b1
* Tue Oct  3 2023 jlee@suse.com
- KEYS: Add forward declaration in asymmetric-parser.h
  (jsc#PED-5460).
- crypto: sig - Add interface for sign/verify (jsc#PED-5460).
- Update config files.
  Add CONFIG_CRYPTO_SIG2
- crypto: akcipher - Add sync interface without SG lists
  (jsc#PED-5460).
- crypto: algboss - Add missing dependency on RNG2 (jsc#PED-5460).
- commit 746bfd1
* Tue Oct  3 2023 petr.pavlu@suse.com
- doc/README.SUSE: Adjust heading style (jsc#PED-5021)
  * Underscore all headings as a preparation for Markdown conversion.
  * Use title-style capitalization for the document name and
  sentence-style capitalization for section headings, as recommended in
  the current SUSE Documentation Style Guide.
- commit 11e3267
* Tue Oct  3 2023 msuchanek@suse.de
- crypto: powerpc/chacha20,poly1305-p10 - Add dependency on VSX
  (jsc#PED-5089).
- commit a08f0f4
* Tue Oct  3 2023 msuchanek@suse.de
- crypto: vmx - Improved AES/XTS performance of 6-way unrolling
  for ppc (jsc#PED-5089).
- crypto: powerpc - Add chacha20/poly1305-p10 to Kconfig and
  Makefile (jsc#PED-5089).
- Update config files.
- crypto: poly1305-p10 - Glue code for optmized Poly1305
  implementation for ppc64le (jsc#PED-5089).
- crypto: poly1305-p10 - An optimized Poly1305 implementation
  with 4-way unrolling for ppc64le (jsc#PED-5089).
- crypt: chacha20-p10 - Glue code for optmized Chacha20
  implementation for ppc64le (jsc#PED-5089).
- crypto: chacha20-p10 - An optimized Chacha20 implementation
  with 8-way unrolling for ppc64le (jsc#PED-5089).
- commit 7745266
* Tue Oct  3 2023 mkubecek@suse.cz
- Update
  patches.suse/tcp-Reduce-chance-of-collisions-in-inet6_hashfn.patch
  references (add CVE-2023-1206 bsc#1212703).
- commit 06ff030
* Tue Oct  3 2023 mkubecek@suse.cz
- netfilter: ipset: add the missing IP_SET_HASH_WITH_NET0 macro
  for ip_set_hash_netportnet.c (CVE-2023-42753 bsc#1215150).
- commit 695ac3b
* Tue Oct  3 2023 mkubecek@suse.cz
- netfilter: ipset: Fix race between IPSET_CMD_CREATE and
  IPSET_CMD_SWAP (CVE-2023-42756 bsc#1215767).
- commit fd797f5
* Tue Oct  3 2023 krisman@suse.de
- io_uring/fs: remove sqe->rw_flags checking from LINKAT
  (git-fixes).
- commit 244bd5e
* Mon Oct  2 2023 ohering@suse.de
- Update patch headers to reflect state of TDX for Hyper-V (bsc#1206453).
- commit 4f4b833
* Mon Oct  2 2023 pmladek@suse.com
- printk: ringbuffer: Fix truncating buffer size min_t cast
  (bsc#1215875).
- commit 4ef741a
* Mon Oct  2 2023 msuchanek@suse.de
- Update patches.suse/security-integrity-fix-pointer-to-ESL-data-and-.patch
  (bsc#1012628 jsc#PED-5085).
- commit 516edff
* Sat Sep 30 2023 tabraham@suse.com
- scsi: qedf: Add synchronization between I/O completions and
  abort (bsc#1210658).
- commit dd4f718
* Fri Sep 29 2023 mwilck@suse.com
- supported.conf: drop pata_arasan and pata_pcmcia
  These drivers have been disabled previously.
- commit 6d49f4c
* Fri Sep 29 2023 mfranc@suse.cz
- Update patches.suse/s390-zcrypt_ep11misc-support-API-ordinal-6-with-empty-pin-blob.patch
  (jsc#PED-6375 jsc#PED-6542).
- commit 317c6a0
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_SCSI_WD719X (jsc#PED-963)
- commit c664ee9
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_SCSI_DC395x (jsc#PED-963)
- commit 028cd1f
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_SCSI_QLOGIC_1280 (jsc#PED-963)
- commit 4bb7fca
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_SCSI_STEX (jsc#PED-963)
- commit 93ec76a
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_SCSI_IMM (jsc#PED-963)
- commit 2228946
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_SCSI_PPA (jsc#PED-963)
- commit 646bbee
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_SCSI_INITIO (jsc#PED-963)
- commit 70f083e
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_SCSI_IPS (jsc#PED-963)
- commit 95311f3
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_SCSI_FDOMAIN_PCI (jsc#PED-963)
- commit 8723fb4
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_SCSI_DMX3191D (jsc#PED-963)
- commit 0aa2575
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_SCSI_MYRS (jsc#PED-963)
- commit 0da6939
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_SCSI_MYRB (jsc#PED-963)
- commit 780fc45
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_SCSI_BUSLOGIC (jsc#PED-963)
- commit d9a6eeb
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_SCSI_MVUMI (jsc#PED-963)
- commit fda498e
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_SCSI_ARCMSR (jsc#PED-963)
- commit 6c0d263
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_SCSI_ADVANSYS (jsc#PED-963)
- commit 3aa6bc9
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_SCSI_ACARD (jsc#PED-963)
- commit e33e775
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_SCSI_HPTIOP (jsc#PED-963)
- commit 1c10c2b
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_MEGARAID_LEGACY (jsc#PED-963)
- commit f3403af
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_MEGARAID_NEWGEN (jsc#PED-963)
- commit 40ae98d
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_MEGARAID_MM (jsc#PED-963)
- commit 92b25a8
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_ATA_GENERIC (jsc#PED-963)
- commit 012036d
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_OF_PLATFORM
- commit 47c8a83
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_IMX (jsc#PED-963)
- commit 9f75693
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_ACPI (jsc#PED-963)
- commit d0706d8
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_PARPORT (jsc#PED-963)
- commit 9a6c6b2
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_RZ1000 (jsc#PED-963)
- commit a1f59b6
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_OPTI (jsc#PED-963)
- commit fa6a9fa
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_NS87410 (jsc#PED-963)
- commit b708147
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_MPIIX (jsc#PED-963)
- commit c4c1366
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_CMD640_PCI (jsc#PED-963)
- commit 3ba52ca
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_WINBOND (jsc#PED-963)
- commit ac43df1
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_VIA (jsc#PED-963)
- commit cff597d
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_TRIFLEX (jsc#PED-963)
- commit 1464d21
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_TOSHIBA (jsc#PED-963)
- commit e734d47
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_SIL680 (jsc#PED-963)
- commit 955aad9
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_SERVERWORKS (jsc#PED-963)
- commit f9bbe90
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_SCH (jsc#PED-963)
- commit 01bc677
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_RDC (jsc#PED-963)
- commit ce9d214
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_RADISYS (jsc#PED-963)
- commit ceddb59
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_PDC_OLD (jsc#PED-963)
- commit 4776aba
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_PDC2027X (jsc#PED-963)
- commit 0d0c866
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_OPTIDMA (jsc#PED-963)
- commit ff28cae
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_OLDPIIX (jsc#PED-963)
- commit 660fcd8
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_NS87415 (jsc#PED-963)
- commit 4249b06
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_NINJA32 (jsc#PED-963)
- commit 00f6d83
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_NETCELL (jsc#PED-963)
- commit 1aeafbe
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_MARVELL (jsc#PED-963)
- commit 388ed43
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_JMICRON (jsc#PED-963)
- commit aa75e16
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_IT821X (jsc#PED-963)
- commit 045c173
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_IT8213 (jsc#PED-963)
- commit 1d4c25b
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_HPT3X3 (jsc#PED-963)
- commit 6496fda
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_HPT3X2N (jsc#PED-963)
- commit d4c19a3
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_HPT37X (jsc#PED-963)
- commit 74fe9ec
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_HPT366 (jsc#PED-963)
- commit 7d08917
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_EFAR (jsc#PED-963)
- commit 8a1bd3c
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_CYPRESS (jsc#PED-963)
- commit bede53a
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_CMD64X (jsc#PED-963)
- commit 665f8c4
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_ATP867X (jsc#PED-963)
- commit 394df89
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_ATIIXP (jsc#PED-963)
- commit 09cad5c
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_ARTOP (jsc#PED-963)
- commit 67a8f3e
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_AMD (jsc#PED-963)
- commit 040e3e1
* Thu Sep 28 2023 mwilck@suse.com
- Update config files: disable CONFIG_PATA_ALI (jsc#PED-963)
- commit f88fe2c
* Wed Sep 27 2023 andrea.porta@suse.com
- kselftest/arm64: Validate that changing one VL type does not
  affect another (jsc#PED-4126).
- kselftest/arm64: Add a test case for SVE VL changes with SME
  active (jsc#PED-4126).
- arm64/fpsimd: Don't flush SME register hardware state along
  with thread (jsc#PED-4126).
- arm64: Use CPACR_EL1 format to set CPTR_EL2 when E2H is set
  (jsc#PED-4126).
- arm64: Allow EL1 physical timer access when running VHE
  (jsc#PED-4126).
- arm64/fpsimd: Exit streaming mode when flushing tasks
  (jsc#PED-4126).
- commit fffd4de
* Wed Sep 27 2023 denis.kirjanov@suse.com
- net: sched: sch_qfq: Fix UAF in qfq_dequeue() (CVE-2023-4921
  bsc#1215275).
- commit 90dfe5e
* Wed Sep 27 2023 neilb@suse.de
- NFSv4.1: fix pnfs MDS=DS session trunking (git-fixes).
- Revert "SUNRPC: Fail faster on bad verifier" (git-fixes).
- SUNRPC: Mark the cred for revalidation if the server rejects it
  (git-fixes).
- NFS/pNFS: Report EINVAL errors from connect() to the server
  (git-fixes).
- pNFS: Fix assignment of xprtdata.cred (git-fixes).
- NFSv4.2: fix handling of COPY ERR_OFFLOAD_NO_REQ (git-fixes).
- NFS: Guard against READDIR loop when entry names exceed
  MAXNAMELEN (git-fixes).
- nfs/blocklayout: Use the passed in gfp flags (git-fixes).
- NFSv4.2: Rework scratch handling for READ_PLUS (again)
  (git-fixes).
- NFSv4.2: Fix READ_PLUS size calculations (git-fixes).
- NFSv4.2: Fix READ_PLUS smatch warnings (git-fixes).
- NFSD: da_addr_body field missing in some GETDEVICEINFO replies
  (git-fixes).
- fs: lockd: avoid possible wrong NULL parameter (git-fixes).
- nfsd: Fix creation time serialization order (git-fixes).
- commit 9b452cc
* Tue Sep 26 2023 jlee@suse.com
- efi/unaccepted: Make sure unaccepted table is mapped
  (jsc#PED-5458).
- commit e4960be
* Tue Sep 26 2023 petr.pavlu@suse.com
- doc/README.PATCH-POLICY.SUSE: Reflow text to 80-column width
  (jsc#PED-5021)
- commit be0158c
* Tue Sep 26 2023 petr.pavlu@suse.com
- doc/README.PATCH-POLICY.SUSE: Update information about the tools
  (jsc#PED-5021)
  * Replace bugzilla.novell.com with bugzilla.suse.com and FATE with Jira.
  * Limit the range of commits in the exportpatch example to prevent it
  from running for too long.
  * Incorporate URLs directly into the text.
  * Fix typos and improve some wording, in particular avoid use of "there
  is/are" and prefer the present tense over the future one.
- commit c0bea0c
* Tue Sep 26 2023 petr.pavlu@suse.com
- doc/README.PATCH-POLICY.SUSE: Update information about the patch
  format (jsc#PED-5021)
  * Replace bugzilla.novell.com with bugzilla.suse.com and FATE with Jira.
  * Remove references to links to the patchtools and kernel source. They
  are incorporated in other parts of the text.
  * Use sentence-style capitalization for section headings, as recommended
  in the current SUSE Documentation Style Guide.
  * Fix typos and some wording, in particular avoid use of "there is/are".
- commit ce98345
* Tue Sep 26 2023 petr.pavlu@suse.com
- doc/README.PATCH-POLICY.SUSE: Update the summary and background
  (jsc#PED-5021)
  * Drop information about patches being split into directories per
  a subsystem because that is no longer the case.
  * Remove the mention that the expanded tree is present since SLE11-SP2
  as that is now only a historical detail.
  * Incorporate URLs and additional information in parenthenses directly
  into the text.
  * Fix typos and improve some wording.
- commit 640988f
* Tue Sep 26 2023 jlee@suse.com
- arm64: Fix dangling references to Documentation/arm64
  (jsc#PED-5458).
- arm64: efi: add efi_handle_corrupted_x18 prototype
  (jsc#PED-5458).
- commit cf69994
* Tue Sep 26 2023 jlee@suse.com
- efivarfs: fix statfs() on efivarfs (jsc#PED-5458).
- efi/unaccepted: Use ACPI reclaim memory for unaccepted memory
  table (jsc#PED-5458).
- efi/esrt: Allow ESRT access without CAP_SYS_ADMIN
  (jsc#PED-5458).
- efivarfs: expose used and total size (jsc#PED-5458).
- efi: make kobj_type structure constant (jsc#PED-5458).
- efi: x86: make kobj_type structure constant (jsc#PED-5458).
- x86/efi: Safely enable unaccepted memory in UEFI (jsc#PED-5458).
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch.
- efi/unaccepted: Avoid load_unaligned_zeropad() stepping into
  unaccepted memory (jsc#PED-5458).
- efi: Add unaccepted memory support (jsc#PED-5458).
- efi/libstub: Implement support for unaccepted memory
  (jsc#PED-5458).
- efi/x86: Get full memory map in allocate_e820() (jsc#PED-5458).
- commit 1a4d2a9
* Mon Sep 25 2023 msuchanek@suse.de
- kernel-binary: Move build-time definitions together
  Move source list and build architecture to buildrequires to aid in
  future reorganization of the spec template.
- commit 30e2cef
* Mon Sep 25 2023 nik.borisov@suse.com
- memblock tests: Fix compilation errors (git-fixes).
- commit 8e3aeb1
* Mon Sep 25 2023 jlee@suse.com
- ACPI: Move AMBA bus scan handling into arm64 specific directory
  (jsc#PED-6741).
- ACPI: scan: Use the acpi_match_acpi_device() helper
  (jsc#PED-6741).
- ACPI: platform: Move SMB0001 HID to the header and reuse
  (jsc#PED-6741).
- ACPI: scan: fix undeclared variable warnings by including
  sleep.h (jsc#PED-6741).
- ACPI: scan: Move acpi_root to internal header (jsc#PED-6741).
- ACPI: tables: Print RINTC information when MADT is parsed
  (jsc#PED-6741).
- ACPI: EC: Fix acpi_ec_dispatch_gpe() (jsc#PED-6741).
- acpi: Replace struct acpi_table_slit 1-element array with
  flex-array (jsc#PED-6741).
- ACPI: x86: Add pm_debug_messages for LPS0 _DSM state tracking
  (jsc#PED-6741).
- ACPI: FFH: Drop the inclusion of linux/arm-smccc.h
  (jsc#PED-6741).
- ACPI: PAD: mark Zhaoxin CPUs NONSTOP TSC correctly
  (jsc#PED-6741).
- ACPI: APEI: mark bert_disable as __initdata (jsc#PED-6741).
- ACPI: APEI: GHES: Remove unused ghes_estatus_pool_size_request()
  (jsc#PED-6741).
- ACPI: bus: Simplify installation and removal of notify callback
  (jsc#PED-6741).
- ACPI: tiny-power-button: Eliminate the driver notify callback
  (jsc#PED-6741).
- ACPI: button: Use different notify handlers for lid and buttons
  (jsc#PED-6741).
- ACPI: button: Eliminate the driver notify callback
  (jsc#PED-6741).
- ACPI: thermal: Drop struct acpi_thermal_flags (jsc#PED-6741).
- ACPI: thermal: Drop struct acpi_thermal_state (jsc#PED-6741).
- ACPI: thermal: Eliminate struct acpi_thermal_state_flags
  (jsc#PED-6741).
- ACPI: thermal: Move acpi_thermal_driver definition
  (jsc#PED-6741).
- ACPI: thermal: Move symbol definitions to one place
  (jsc#PED-6741).
- ACPI: thermal: Drop redundant ACPI_TRIPS_REFRESH_DEVICES symbol
  (jsc#PED-6741).
- ACPI: thermal: Use BIT() macro for defining flags
  (jsc#PED-6741).
- ACPI: NFIT: Add declaration in a local header (jsc#PED-6741).
- ACPI: LPSS: Add pwm_lookup_table entry for second PWM on
  CHT/BSW devices (jsc#PED-6741).
- ACPI: video: Stop trying to use vendor backlight control on
  laptops from after ~2012 (jsc#PED-6741).
- ACPI: EC: Clear GPE on interrupt handling only (jsc#PED-6741).
- ACPI: x86: s2idle: Adjust Microsoft LPS0 _DSM handling sequence
  (jsc#PED-6741).
- ACPI: PM: s2idle: fix section mismatch warning (jsc#PED-6741).
- ACPI: scan: Reduce overhead related to devices with dependencies
  (jsc#PED-6741).
- ACPI: bus: Consolidate all arm specific initialisation into
  acpi_arm_init() (jsc#PED-6741).
- ACPI/APMT: Don't register invalid resource (jsc#PED-6741).
- x86/acpi: Remove unused extern declaration
  acpi_copy_wakeup_routine() (jsc#PED-6741).
- commit 77d191a
* Mon Sep 25 2023 nik.borisov@suse.com
- x86,static_call: Fix static-call vs return-thunk (git-fixes).
- commit 8cd97f9
* Mon Sep 25 2023 nik.borisov@suse.com
- x86/srso: Fix srso_show_state() side effect (git-fixes).
- commit 8afecb5
* Mon Sep 25 2023 nik.borisov@suse.com
- x86/srso: Fix SBPB enablement for spec_rstack_overflow=off (git-fixes).
- commit 5709d02
* Mon Sep 25 2023 nik.borisov@suse.com
- x86/srso: Don't probe microcode in a guest (git-fixes).
- commit af07748
* Mon Sep 25 2023 nik.borisov@suse.com
- x86/srso: Set CPUID feature bits independently of bug or mitigation  status (git-fixes).
- commit 3c92c43
* Mon Sep 25 2023 msuchanek@suse.de
- Refresh sorted patches.
- commit faca79b
* Mon Sep 25 2023 mgorman@suse.de
- mm: page_alloc: fix CMA and HIGHATOMIC landing on the wrong
  buddy list (git fixes (mm/pgalloc)).
- kernel/sched: Modify initial boot task idle setup (git fixes
  (sched/core)).
- commit 9d1497b
* Mon Sep 25 2023 msuchanek@suse.de
- powerpc/fadump: make is_kdump_kernel() return false when fadump
  is active (bsc#1212639 ltc#202582).
- vmcore: remove dependency with is_kdump_kernel() for exporting
  vmcore (bsc#1212639 ltc#202582).
- commit 4a28b74
* Mon Sep 25 2023 osalvador@suse.de
- Update references for jsc#PED-5859
  Updated:
  patches.suse/mm-enable-page-walking-API-to-lock-vmas-during.patch
  patches.suse/mm-memory-failure-avoid-false-hwpoison-page-ma.patch
  patches.suse/mm-memory-failure-fix-hardware-poison-check-in-.patch
  patches.suse/mm-memory-failure-fix-potential-unexpected-ret.patch
  patches.suse/mm-memory-failure-fix-unexpected-return-value-.patch
  patches.suse/mm-memory-failure-move-sysctl-register-in-memory_failure_init.patch
  patches.suse/mm-page_alloc-move-mirrored_kernelcore-into-mm_init.c.patch
  patches.suse/mm-various-give-up-if-pte_offset_map-_lock-fails.patch
- commit 75204a6
* Mon Sep 25 2023 dwagner@suse.de
- nvmet-tcp: pass iov_len instead of sg->length to bvec_set_page()
  (git-fixes).
- nvme: core: don't hold rcu read lock in
  nvme_ns_chr_uring_cmd_iopoll (git-fixes).
- commit d723891
* Mon Sep 25 2023 pjakobsson@suse.de
- drm/amd/display: fix the ability to use lower resolution modes
  on eDP (git-fixes).
- commit eecd96a
* Mon Sep 25 2023 pjakobsson@suse.de
- drm/virtio: clean out_fence on complete_submit (git-fixes).
- commit 0fce30c
* Mon Sep 25 2023 pjakobsson@suse.de
- drm/i915/gsc: Fix intel_gsc_uc_fw_proxy_init_done with directed
  wakerefs (git-fixes).
- commit 0df651f
* Mon Sep 25 2023 pjakobsson@suse.de
- drm/i915: Only check eDP HPD when AUX CH is shared (git-fixes).
- commit 557208e
* Mon Sep 25 2023 pjakobsson@suse.de
- drm/amd/display: fix mode scaling (RMX_.*) (git-fixes).
- commit 88040aa
* Mon Sep 25 2023 pjakobsson@suse.de
- drm/msm/a690: Switch to a660_gmu.bin (git-fixes).
- commit 6ed05a1
* Mon Sep 25 2023 pjakobsson@suse.de
- drm/msm/dpu: fix DSC 1.2 enc subblock length (git-fixes).
- commit 7e9c38c
* Mon Sep 25 2023 pjakobsson@suse.de
- drm/msm/dpu: fix DSC 1.2 block lengths (git-fixes).
- commit bff5896
* Mon Sep 25 2023 pjakobsson@suse.de
- drm/gem-fb-helper: Consistenly use drm_dbg_kms() (git-fixes).
- commit 66aae33
* Mon Sep 25 2023 pjakobsson@suse.de
- backlight: lp855x: Initialize PWM state on first brightness
  change (git-fixes).
- commit 66f3aae
* Mon Sep 25 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1740-drm-amdgpu-Fix-infinite-loop-in-gfxhub_v1_2_xcc_gart.patch
  Alt-commit
- commit 3282a51
* Mon Sep 25 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1715-drm-amdgpu-fix-slab-out-of-bounds-issue-in-amdgpu_vm.patch
  Alt-commit
- commit 3ae623b
* Mon Sep 25 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1714-drm-amdgpu-Allocate-root-PD-on-correct-partition.patch
  Alt-commit
- commit 0074e90
* Mon Sep 25 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1702-drm-amd-display-add-DCN301-specific-logic-for-OTG-pr.patch
  Alt-commit
- commit 5123631
* Mon Sep 25 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1701-drm-amd-display-export-some-optc-function-for-reuse.patch
  Alt-commit
- commit df6cf8d
* Mon Sep 25 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1699-Revert-drm-i915-use-localized-__diag_ignore_all-inst.patch
  Alt-commit
- commit f2ff283
* Mon Sep 25 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1684-drm-i915-Remove-dead-code-from-gen8_pte_encode.patch
  Alt-commit
- commit 0bf86fb
* Mon Sep 25 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1675-drm-i915-use-mock-device-info-for-creating-mock-devi.patch
  Alt-commit
- commit 1600dd8
* Mon Sep 25 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1599-drm-i915-hdcp-Assign-correct-hdcp-content-type.patch
  Alt-commit
- commit bdbce62
* Mon Sep 25 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1596-drm-i915-mtl-Fix-SSC-selection-for-MPLLA.patch
  Alt-commit
- commit 065052f
* Mon Sep 25 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1595-drm-i915-adlp-Allow-DC-states-along-with-PW2-only-fo.patch
  Alt-commit
- commit e0c7378
* Mon Sep 25 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1584-drm-i915-Fix-a-NULL-vs-IS_ERR-bug.patch
  Alt-commit
- commit 300032a
* Mon Sep 25 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1583-drm-i915-make-i915_drm_client_fdinfo-reference-condi.patch
  Alt-commit
- commit 4dbab7b
* Mon Sep 25 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1582-drm-i915-huc-Fix-missing-error-code-in-intel_huc_ini.patch
  Alt-commit
- commit 60505d1
* Mon Sep 25 2023 pjakobsson@suse.de
- Refresh
  patches.suse/1581-drm-i915-gsc-take-a-wakeref-for-the-proxy-init-compl.patch
  Alt-commit
- commit 6b6fc16
* Sat Sep 23 2023 tiwai@suse.de
- thermal: sysfs: Fix trip_point_hyst_store() (git-fixes).
- i915/pmu: Move execlist stats initialization to execlist
  specific setup (git-fixes).
- drm/meson: fix memory leak on ->hpd_notify callback (git-fixes).
- drm/tests: Fix incorrect argument in drm_test_mm_insert_range
  (git-fixes).
- platform/x86: intel_scu_ipc: Fail IPC send if still busy
  (git-fixes).
- platform/x86: intel_scu_ipc: Don't override scu in
  intel_scu_ipc_dev_simple_command() (git-fixes).
- platform/x86: intel_scu_ipc: Check status upon timeout in
  ipc_wait_for_interrupt() (git-fixes).
- platform/x86: intel_scu_ipc: Check status after timeout in
  busy_loop() (git-fixes).
- commit 1c71447
* Fri Sep 22 2023 tiwai@suse.de
- Bluetooth: Add support for Intel Misty Peak - 8087:0038
  (jsc#PED-6023 jsc#PED-6065).
- commit 236139d
* Fri Sep 22 2023 pjakobsson@suse.de
- supported.conf: Add supported entry for mei_gsc_proxy
- commit 4dabdd6
* Fri Sep 22 2023 pjakobsson@suse.de
- supported.conf: Add supported entry form amdxcp
- commit ff92ee3
* Fri Sep 22 2023 tiwai@suse.de
- ASoC: soc-utils: Export snd_soc_dai_is_dummy() symbol
  (git-fixes).
- commit 9962c24
* Fri Sep 22 2023 lhenriques@suse.de
- fuse: nlookup missing decrement in fuse_direntplus_link
  (bsc#1215613).
- Revert "fuse: in fuse_flush only wait if someone wants the
  return  code" (bsc#1215612).
- commit 4e4e0df
* Fri Sep 22 2023 pjakobsson@suse.de
- supported.conf: Add entry for meson_dw_mipi_dsi
- commit 431d315
* Fri Sep 22 2023 tiwai@suse.de
- ALSA: hda/realtek - ALC287 Realtek I2S speaker platform support
  (git-fixes).
- ALSA: hda: generic: Check potential mixer name string truncation
  (git-fixes).
- ALSA: hda: Disable power save for solving pop issue on Lenovo
  ThinkCentre M70q (git-fixes).
- ALSA: hda: cs35l56: Don't 'return ret' if ret is always zero
  (git-fixes).
- ALSA: hda: intel-sdw-acpi: Use u8 type for link index
  (git-fixes).
- ALSA: hda: cs35l56: Disable low-power hibernation mode
  (git-fixes).
- commit 4ca03bc
* Fri Sep 22 2023 tiwai@suse.de
- Update config files: CONFIG_IPU_BRIDGE=m
- supported.conf: add ipu-bridge
- commit d65e142
* Fri Sep 22 2023 tiwai@suse.de
- media: ipu3-cio2: allow ipu_bridge to be a module again
  (git-fixes).
- commit 1f81030
* Fri Sep 22 2023 tiwai@suse.de
- media: ipu3-cio2: rename cio2 bridge to ipu bridge and move
  out of ipu3 (git-fixes).
- Refresh
  patches.suse/media-ipu-bridge-Do-not-use-on-stack-memory-for-soft.patch.
- Refresh
  patches.suse/media-ipu-bridge-Fix-null-pointer-deref-on-SSDB-PLD-.patch.
- commit 730c95a
* Fri Sep 22 2023 tiwai@suse.de
- selftests: tls: swap the TX and RX sockets in some tests
  (git-fixes).
- ASoC: SOF: core: Only call sof_ops_free() on remove if the
  probe was successful (git-fixes).
- ASoC: imx-audmix: Fix return error with devm_clk_get()
  (git-fixes).
- ASoC: hdaudio.c: Add missing check for devm_kstrdup (git-fixes).
- ASoC: SOF: ipc4-topology: fix wrong sizeof argument (git-fixes).
- ASoC: rt5640: Fix IRQ not being free-ed for HDA jack detect mode
  (git-fixes).
- ASoC: rt5640: Enable the IRQ on resume after configuring
  jack-detect (git-fixes).
- ASoC: rt5640: Do not disable/enable IRQ twice on suspend/resume
  (git-fixes).
- ASoC: rt5640: Fix sleep in atomic context (git-fixes).
- ASoC: rt5640: Revert "Fix sleep in atomic context" (git-fixes).
- ASoC: amd: yc: Fix non-functional mic on Lenovo 82QF and 82UG
  (git-fixes).
- ASoC: tegra: Fix redundant PLLA and PLLA_OUT0 updates
  (git-fixes).
- ASoC: meson: spdifin: start hw on dai probe (git-fixes).
- ALSA: hda: cs35l56: Use the new RUNTIME_PM_OPS() macro
  (git-fixes).
- ALSA: rawmidi: Fix NULL dereference at proc read (git-fixes).
- ALSA: seq: ump: Fix -Wformat-truncation warning (git-fixes).
- ALSA: hda: cs35l56: Fix missing RESET GPIO if _SUB is missing
  (git-fixes).
- ALSA: hda/realtek: Splitting the UX3402 into two separate models
  (git-fixes).
- ALSA: hda/realtek - Fixed two speaker platform (git-fixes).
- ALSA: seq: Avoid delivery of events for disabled UMP groups
  (git-fixes).
- ALSA: docs: Fix a typo of midi2_ump_probe option for
  snd-usb-audio (git-fixes).
- ALSA: hda: cs35l56: Call pm_runtime_dont_use_autosuspend()
  (git-fixes).
- commit 9ce31b2
* Fri Sep 22 2023 tiwai@suse.de
- Move upstreamed SPI patch into sorted section
- commit 5fe2406
* Fri Sep 22 2023 pjakobsson@suse.de
- drm/amdgpu: support partition drm devices (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- commit 0d0dce1
* Fri Sep 22 2023 dwagner@suse.de
- scsi: lpfc: Do not abuse UUID APIs and LPFC_COMPRESS_VMID_SIZE
  (bsc#1213756 jsc#PED-3616 jsc#PED-5064).
- scsi: lpfc: Modify when a node should be put in device recovery
  mode during RSCN (bsc#1213756 jsc#PED-3616 jsc#PED-5064).
- scsi: lpfc: Copyright updates for 14.2.0.14 patches (bsc#1213756
  jsc#PED-3616 jsc#PED-5064).
- scsi: lpfc: Update lpfc version to 14.2.0.14 (bsc#1213756
  jsc#PED-3616 jsc#PED-5064).
- scsi: lpfc: Clean up SLI-4 sysfs resource reporting (bsc#1213756
  jsc#PED-3616 jsc#PED-5064).
- scsi: lpfc: Refactor cpu affinity assignment paths (bsc#1213756
  jsc#PED-3616 jsc#PED-5064).
- scsi: lpfc: Abort outstanding ELS cmds when mailbox timeout
  error is detected (bsc#1213756 jsc#PED-3616 jsc#PED-5064).
- scsi: lpfc: Make fabric zone discovery more robust when handling
  unsolicited LOGO (bsc#1213756 jsc#PED-3616 jsc#PED-5064).
- scsi: lpfc: Set Establish Image Pair service parameter only
  for Target Functions (bsc#1213756 jsc#PED-3616 jsc#PED-5064).
- scsi: lpfc: Revise ndlp kref handling for dev_loss_tmo_callbk
  and lpfc_drop_node (bsc#1213756 jsc#PED-3616 jsc#PED-5064).
- scsi: lpfc: Qualify ndlp discovery state when processing RSCN
  (bsc#1213756 jsc#PED-3616 jsc#PED-5064).
- scsi: lpfc: Remove extra ndlp kref decrement in FLOGI cmpl
  for loop topology (bsc#1213756 jsc#PED-3616 jsc#PED-5064).
- scsi: lpfc: Simplify fcp_abort transport callback log message
  (bsc#1213756 jsc#PED-3616 jsc#PED-5064).
- scsi: lpfc: Pull out fw diagnostic dump log message from
  driver's trace buffer (bsc#1213756 jsc#PED-3616 jsc#PED-5064).
- scsi: lpfc: Remove reftag check in DIF paths (bsc#1213756
  jsc#PED-3616 jsc#PED-5064).
- commit 73ce139
* Fri Sep 22 2023 msuchanek@suse.de
- powerpc/dexcr: Move HASHCHK trap handler (jsc#PED-5452
  git-fixes).
- commit 48a4d15
* Fri Sep 22 2023 msuchanek@suse.de
- Refresh patches.suse/integrity-powerpc-Do-not-select-CA_MACHINE_KEYRING.patch.
- commit 8343fa7
* Fri Sep 22 2023 pjakobsson@suse.de
- drm/amd/amdgpu: introduce DRM_AMDGPU_WERROR (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Update config files.
- commit cf3a39d
* Fri Sep 22 2023 pjakobsson@suse.de
- drm/meson: add support for MIPI-DSI transceiver (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Update config files.
- commit d8bd8d3
* Fri Sep 22 2023 pjakobsson@suse.de
- drm/i915: Implement dedicated fbdev I/O helpers (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Update config files.
- commit 3412ae7
* Fri Sep 22 2023 pjakobsson@suse.de
- mei: gsc_proxy: add gsc proxy driver (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Update config files.
- commit 07c6f50
* Fri Sep 22 2023 pjakobsson@suse.de
- drm/panel: Add Samsung S6D7AA0 panel controller driver
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Update config files.
- commit c27af61
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Fix HPD polling, reenabling the output poll work as needed (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eb6a241
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: fix Sphinx indentation warning (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b490a01
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: bridge: samsung-dsim: Fix init during host transfer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fe9095c
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: atmel_lcdfb: Remove redundant of_match_ptr() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bf6ee9d
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: kyro: Remove unused declarations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 58082f1
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: ssd1307fb: Print the PWM's label instead of its number (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit edbbb54
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: amifb: Replace zero-length arrays with DECLARE_FLEX_ARRAY() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aa6bc19
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: skip xcp drm device allocation when out of drm resource (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e9ad20a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Update pci link width for smu v13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1d8a1c9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: disable mcbp if parameter zero is set (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit adce214
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: disallow the fan setting if there is no fan on smu 13.0.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3021e39
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/panel: JDI LT070ME05000 simplify with dev_err_probe() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0e6240e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: fix display probe for IVB Q and IVB D GT2 server (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f61d9e5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: disable IOMMUv2 support for Raven (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d929805
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: disable IOMMUv2 support for KV/CZ (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5f283c2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: ignore crat by default (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b6373c3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/gfx11: only enable CP GFX shadowing on SR-IOV (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 27ca2a9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Fix SMU v13.0.6 energy reporting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 514f828
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: disable the SMU13 OD feature support temporarily (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ccf6fca
* Thu Sep 21 2023 pjakobsson@suse.de
- Revert "drm/bridge: lt9611: Do not generate HFP/HBP/HSA and EOT (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 39df3c8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/gvt: Fix bug in getting msg length in AUX CH registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4e0f8a5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/panel: samsung-s6d7aa0: Add MODULE_DEVICE_TABLE (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ce1b0b1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/a690: Remove revn and name (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b870595
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/adreno: Fix warn splat for devices without revn (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 35c55a7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Restore HQD persistent state register (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c449b09
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Don't apply FIFO resync W/A if rdivider = 0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 80a3a07
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix infinite loop in gfxhub_v1_2_xcc_gart_enable (v2) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9610a25
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: fix trap handling work around for debugging (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 092ee0d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/fb-helper: Remove unused inline function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dd3d564
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: Explicitly include correct DT includes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 608b77e
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: ep93xx-fb: fix return value check in ep93xxfb_probe (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 51f7d8a
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: kyro: make some const read-only arrays static and reduce type (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1dfd1d4
* Thu Sep 21 2023 pjakobsson@suse.de
- fbcon: remove unused display (p) from fbcon_redraw() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit da6039e
* Thu Sep 21 2023 pjakobsson@suse.de
- sticon: make sticon_set_def_font() void and remove op parameter (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9ad197e
* Thu Sep 21 2023 pjakobsson@suse.de
- vgacon: cache vc_cell_height in vgacon_cursor() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1142d7a
* Thu Sep 21 2023 pjakobsson@suse.de
- vgacon: let vgacon_doresize() return void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1ad5e89
* Thu Sep 21 2023 pjakobsson@suse.de
- vgacon: remove unused xpos from vgacon_set_cursor_size() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 898d521
* Thu Sep 21 2023 pjakobsson@suse.de
- vgacon: remove unneeded forward declarations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 953193b
* Thu Sep 21 2023 pjakobsson@suse.de
- vgacon: switch vgacon_scrolldelta() and vgacon_restore_screen() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6ac1ac5
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: imxfb: remove unneeded labels (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dd9ee8d
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: imxfb: Convert to devm_platform_ioremap_resource() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 91edeb4
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: imxfb: Convert to devm_kmalloc_array() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4d84a0d
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: imxfb: switch to DEFINE_SIMPLE_DEV_PM_OPS (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b24d1e1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: use a macro to define no xcp partition case (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 16e9fc5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/vm: use the same xcp_id from root PD (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a174dae
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: fix slab-out-of-bounds issue in amdgpu_vm_pt_create (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2239d3d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Allocate root PD on correct partition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 14033e0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Allow the initramfs generator to include psp_13_0_6_ta (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d2ecb88
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: add DCN301 specific logic for OTG programming (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 57c249e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: export some optc function for reuse (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1ba3544
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd: Use amdgpu_device_pcie_dynamic_switching_supported() for (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 57bc8dd
* Thu Sep 21 2023 pjakobsson@suse.de
- Revert "drm/i915: use localized __diag_ignore_all() instead of per (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c41ead6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Remove dead code from gen8_pte_encode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f505a42
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/perf: Consider OA buffer boundary when zeroing out reports (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 02a53d3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/client: Send hotplug event after registering a client (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b14eb41
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/panel: Fine tune Starry-ili9882t panel HFP and HBP (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 03f8e7a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: use mock device info for creating mock device (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1a1a4b8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: avoid unintentional shutdown due to temperature momentary (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2a3f5d4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: 3.2.241 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 617135d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Take full update path if number of planes changed (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f119dff
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Create debugging mechanism for Gaming FAMS (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4746f1e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: For new fast update path, loop through each surface (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d32c724
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Limit new fast update path to addr and gamma / color (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0c77773
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Fix the delta clamping for shaper LUT (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ea951c2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Keep non-psp path for partition switch (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 153b7dd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: program DPP shaper and 3D LUT if updated (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d24c093
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: share drm device for pci amdgpu device with 1st partition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 60153e5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Add GFX v9.4.3 unique id to sysfs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 858411d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Enable pp_feature attribute (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 65e6b7b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: Need to unpause dpg before stop dpg (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b63fb49
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: remove duplicated doorbell range init for sdma v4.4.2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 91144ad
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: gpu recovers from fatal error in poison mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 102fca6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: enable mcbp by default on gfx9 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ff19a3d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: make mcbp a per device setting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 133d763
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd: Don't initialize PSP twice for Navi3x (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d926350
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: fulfill the missing enablement for vega12/vega20 L2H and (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3d6b1a5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Remove asserts (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bf5ecfe
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Work around bad DPCD state on link loss (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d7bd628
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: port SRIOV VF missed changes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1c76c54
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Update interrupt handling for GFX 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 28d120a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Provide energy data in 15.625mJ units (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 842bd47
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Modify for_each_inst macro (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e9e740f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu:Remove sdma halt/unhalt during frontdoor load (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fee2356
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: remove vm sanity check from amdgpu_vm_make_compute (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e9b2c95
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Enable GWS on GFX9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ef1d336
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: 3.2.240 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 70cde26
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Enable dc mode clock switching for DCN32x (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e5882b7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: fix odm k2 div calculation (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/drm-amd-display-Remove-Phantom-Pipe-Check-When-.patch.
- commit 3847ca2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Add MST Preferred Link Setting Entry (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 33d3998
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Disable DC Mode Capping On DCN321 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 981aaa5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: enable the new fast update path for supported ASICs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8a029f9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Clear update flags at end of flip (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/drm-amd-display-Remove-wait-while-locked.patch.
- commit 1a87062
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Fix pipe check condition for manual trigger (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 09f351f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: add missing ABM registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 99d25dc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Add Clock Table Entry With Max DC Values (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit caf5812
* Thu Sep 21 2023 pjakobsson@suse.de
- Revert "drm/amd/display: Move DCN314 DOMAIN power control to DMCUB" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8fff5d1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: disable RCO for DCN314 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bcdb152
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: disable power gating for DCN314 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d4dbb1f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Skip TMR for MP0_HWIP 13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 384c9b3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Move clocks closer to its only usage in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dfdefb6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: set coherent host access capability flag (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c747077
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add vbios attribute only if supported (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 961eb80
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/atomfirmware: fix LPDDR5 width reporting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fea976d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Remove CONFIG_DEBUG_FS guard around body of (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e81c262
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: remove unneeded variable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2e25958
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Move calculation of xcp per memory node (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5a97070
* Thu Sep 21 2023 pjakobsson@suse.de
- amd/display/dc: remove repeating expression (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f94d6fa
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Add missing forward declarations/includes to display power (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7031cf6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/hdcp: Assign correct hdcp content type (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b4dec50
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Fix SSC selection for MPLLA (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3f7b00b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/adlp+: Allow DC states along with PW2 only for PWB (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b6b9c8c
* Thu Sep 21 2023 pjakobsson@suse.de
- mei: bus-fixup: fix buffer type (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8e46089
* Thu Sep 21 2023 pjakobsson@suse.de
- mei: bus: drop useless cldev null check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 83b20d5
* Thu Sep 21 2023 pjakobsson@suse.de
- backlight: led_bl: Take led_access lock when required (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0dfb654
* Thu Sep 21 2023 pjakobsson@suse.de
- video: backlight: lp855x: Get PWM for PWM mode during probe (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1ce71d3
* Thu Sep 21 2023 pjakobsson@suse.de
- backlight: pwm_bl: Remove unneeded checks for valid GPIOs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9354552
* Thu Sep 21 2023 pjakobsson@suse.de
- backlight: Switch i2c drivers back to use .probe() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 06e6e4d
* Thu Sep 21 2023 pjakobsson@suse.de
- backlight: lm3630a: Turn off both led strings when display is blank (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5e02663
* Thu Sep 21 2023 pjakobsson@suse.de
- sticon/parisc: Fix STI console on 64-bit only machines (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 40622b5
* Thu Sep 21 2023 pjakobsson@suse.de
- sticon/parisc: Allow 64-bit STI calls in PDC firmware abstration (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit abd3994
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/nouveau: stop using is_swiotlb_active (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 546d058
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Fix a NULL vs IS_ERR() bug (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bcf16e8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: make i915_drm_client_fdinfo() reference conditional
  again (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/0001-drm-Clear-fd-handle-callbacks-in-struct-drm_driver.patch.
- commit 261bbcb
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/huc: Fix missing error code in intel_huc_init() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c0cb606
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/gsc: take a wakeref for the proxy-init-completion check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 39d63f0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/a6xx: Add A610 speedbin support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 245b6f3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/a6xx: Add A619_holi speedbin support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1237553
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/a6xx: Use adreno_is_aXYZ macros in speedbin matching (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7174c97
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/a6xx: Use "else if" in GPU speedbin rev matching (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1dba738
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/a6xx: Fix some A619 tunables (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eeb2a01
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/a6xx: Add A610 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 70877ea
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/a6xx: Add support for A619_holi (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6cc54e4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/adreno: Disable has_cached_coherent in GMU wrapper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 886a124
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/a6xx: Introduce GMU wrapper support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6eca567
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/a6xx: Move CX GMU power counter enablement to hw_init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bdc1cdc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/a6xx: Extend and explain UBWC config (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5851d46
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/a6xx: Remove both GBIF and RBBM GBIF halt on hw init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fcf3bc8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/a6xx: Add a helper for software-resetting the GPU (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 87004be
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/a6xx: Improve a6xx_bus_clear_pending_transactions() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 16dec6a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/a6xx: Move a6xx_bus_clear_pending_transactions to a6xx_gpu (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 81dc1a8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/a6xx: Move force keepalive vote removal to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 775f3bd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/a6xx: Remove static keyword from sptprac en/disable functions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c0956a6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/adreno: Use adreno_is_revn for A690 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 031d3d3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dsi: split dsi_ctrl_config() function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d87bcb7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dsi: dsi_host: drop unused clocks (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a8f2145
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: remove unused INTF_NONE interfaces (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8fabb94
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: Set DATA_COMPRESS on command mode for DCE/DSC 1.2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 76a1e53
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: Add DPU_INTF_DATA_COMPRESS feature flag for DPU >= 7.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 16b130d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dsi: Reduce pclk rate for compression (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 85b6f49
* Thu Sep 21 2023 pjakobsson@suse.de
- msm/drm/dsi: Round up DSC hdisplay calculation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2782021
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: add DSC 1.2 hw blocks for relevant chipsets
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/drm-msm-dpu-fix-sc7280-and-sc7180-PINGPONG-done.patch.
- commit a86fa8e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: add support for DSC encoder v1.2 engine (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1a38953
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dsi: update hdisplay calculation for dsi_timing_setup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a7ae7a7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dsi: Use MSM and DRM DSC helper methods (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/drm-msm-dsi-Remove-incorrect-references-to-slic.patch.
- commit cb63699
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: Use fixed DRM DSC helper for det_thresh_flatness (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0cbae87
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm: Add MSM-specific DSC helper methods (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 70c914b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dsi: use DRM DSC helpers for DSC setup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f2ef9d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/display/dsc: Add drm_dsc_get_bpp_int helper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5030bfa
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/display/dsc: add helper to set semi-const parameters (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fb24b8f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/display/dsc: Add flatness and initial scale value calculations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 524ae02
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu/catalog: define DSPP blocks found on sdm845 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5df1d18
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/adreno: make adreno_is_a690()'s argument const (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cf867e3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/adreno: change adreno_is_* functions to accept const argument (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4131008
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/adreno: warn if chip revn is verified before being set (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 47e0311
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/a6xx: Fix a690 CP_PROTECT settings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 031cf8c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/adreno: Add Adreno A690 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3ca0171
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm: Move cmdstream dumping out of sched kthread (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1bd27f2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm: drop unused ring variable in msm_ioctl_gem_submit() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5a20d33
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/mdp5: Add MDP5 configuration for MSM8226 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 02bdc02
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dsi: Add phy configuration for MSM8226 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9fa880e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dsi: Add configuration for MSM8226 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8905ad6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: drop (mostly) unused DPU_NAME_SIZE define (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ccba20e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: drop dpu_encoder_phys_ops::late_register() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3393cd1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dsi: use mult_frac for pclk_bpp calculation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e7f2f30
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dsi: remove extra call to dsi_get_pclk_rate() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3584fc4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dsi: More properly handle errors in regards to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8a48596
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dsi: Stop unconditionally powering up DSI hosts at modeset (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ebc2c64
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dp: Clean up pdev/dev duplication in dp_power (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7022a77
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dp: Clean up logs dp_power module (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 29f4983
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dp: remove most of usbpd-related remains (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e74e7ec
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: tidy up some error checking (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dbff974
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: add DSC blocks to the catalog of MSM8998 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 932caaf
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: Add SM6375 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e6e814c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: Add SM6350 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5d3297e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: use PINGPONG_NONE to unbind WB from PP (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 15127f2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: use PINGPONG_NONE to unbind INTF from PP (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c83f734
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: simplify dpu_encoder_phys_wb_init() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ddd4411
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: drop temp variable from dpu_encoder_phys_cmd_init() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3c6e7f3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: call dpu_rm_get_intf() from dpu_encoder_get_intf() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 201f6ec
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: inline dpu_encoder_get_wb() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 00b1dde
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: drop duplicated intf/wb indices from encoder structs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 52d4d00
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: separate common function to init physical encoder (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5ebce4f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: merge dpu_encoder_init() and dpu_encoder_setup() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4d20ebb
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: Tear down DSC datapath on encoder cleanup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ac468c1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: separate DSC flush update out of interface (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c80390f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: Introduce PINGPONG_NONE to disconnect DSC from PINGPONG (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 736a687
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: Guard PINGPONG DSC ops behind DPU_PINGPONG_DSC bit (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5578444
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: add DPU_PINGPONG_DSC feature bit for DPU < 7.0.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 516e9b2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: use common helper for WB and SSPP QoS setup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e6bc86f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: remove struct dpu_hw_pipe_qos_cfg (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 40ad280
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: drop DPU_PLANE_QOS_PANIC_CTRL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b8fb61c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: simplify qos_ctrl handling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8377e17
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: drop DPU_PLANE_QOS_VBLANK_CTRL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 50b44b4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: rearrange QoS setting code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 65ea2b6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: fix the condition for (not) applying QoS to CURSOR SSPP (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 30919b4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: simplify CDP programming (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bc89bd9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: fix SSPP register definitions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5476dcc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: move PINGPONG_NONE check to dpu_lm_init() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 876c314
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: use PINGPONG_NONE for LMs with no PP attached (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7a86813
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: remove futile checks from dpu_rm_init() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1c692fc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: replace IS_ERR_OR_NULL with IS_ERR during DSC init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ed32641
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: access CSC/CSC10 registers directly (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 270fbc1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: access QSEED registers directly (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c55347f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: drop SSPP's SRC subblock (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dfdaec8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: Remove intr_rdptr from DPU >= 5.0.0 pingpong config (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5205034
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: Implement tearcheck support on INTF block (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0c15d98
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: Merge setup_- and enable_tearcheck pingpong callbacks (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9167de1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: Add TEAR-READ-pointer interrupt to INTF block (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d1a5f40
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: Describe TEAR interrupt registers for DSI interfaces (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ebfa739
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: Factor out shared interrupt register in INTF_BLK macro (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e0fc2b3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: Move dpu_hw_{tear_check, pp_vsync_info} to dpu_hw_mdss.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 38395b1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: Disable MDP vsync source selection on DPU 5.0.0 and (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0cd6176
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: Take INTF index as parameter in interrupt register (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a7983da
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: Sort INTF registers numerically (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 19dbc2a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: Remove extraneous register define indentation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3c267f1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: add writeback support for sc7280 (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/drm-msm-dpu-fix-sc7280-and-sc7180-PINGPONG-done.patch.
- commit 37e7cb5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: drop unused SSPP sub-block information (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8214a78
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: drop DSPP_MSM8998_MASK from hw catalog (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7d4c6ff
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: remove GC and IGC related code from dpu catalog (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3dfefed
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: remove DPU_DSPP_IGC handling in dspp flush (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 92fdc69
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: remove DPU_DSPP_GC handling in dspp flush (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2d62c59
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: Pass catalog pointers in RM to replace for-loop
  ID lookups (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/drm-msm-dpu-add-missing-flush-and-fetch-bits-fo.patch.
- commit 0104236
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: Drop unused members from HW structs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit faf8237
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: stop mapping the regdma region (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 245057e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: set max cursor width to 512x512 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d220614
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: use hsync/vsync polarity set by the encoder (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ada24a4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: add HDMI output support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 70c0ff0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: simplify intf allocation code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 07f5cfc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: use CTL_SC7280_MASK for sm8450's ctl_0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c8846a9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: enable DSPP and DSC on sc8180x (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9d863e9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm/dpu: enable DPU_CTL_SPLIT_DISPLAY for sc8280xp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3a98d9d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm: mdss: Add SM6375 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bc89640
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm: mdss: Add SM6350 support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0e3fa0f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm: Remove unnecessary (void*) conversions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5babd25
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Increase hmm range get pages timeout (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 06300fd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Enable translate further for GC v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9e4c7a1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Remove unused NBIO interface (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c231e3c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: bump kfd ioctl minor version for event age availability (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2bc6f9b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: update user space last_event_age (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 201b714
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: set activated flag true when event age unmatchs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 013860f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: add event_age tracking when receiving interrupt (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3ad716e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: add event age tracking (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8598fed
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/scheduler: avoid infinite loop if entity's dependency is a (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4d0faba
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add entity error check in amdgpu_ctx_get_entity (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 61f3421
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add VM generation token (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4ae3591
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: reset VM when an error is detected (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7a407e8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: abort submissions during prepare on error (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e6d2025
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: mark soft recovered fences with -ENODATA (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bcc32e4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: mark force completed fences with -ECANCELED (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bc775b5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add amdgpu_error_* debugfs file (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6601558
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: mark GC 9.4.3 experimental for now (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 690da62
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Use PSP FW API for partition switch (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7098393
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Change nbio v7.9 xcp status definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7d3f291
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add checking mc_vram_size (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5e930a3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Optimize checking ras supported (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2f948ae
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add channel_dis_num to ras init flags (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ad76bf8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Update total channel number for umc v8_10 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit afb6b0f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Align eccinfo table structure with smu v13_0_0 interface (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b132bfa
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Convert to kdoc formats in dc/core/dc.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2ec659c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: decrement queue count on mes queue destroy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e7e3657
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: enable more Pstates profile levels for SMU v13.0.5 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d870d66
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/radeon: Fix missing prototypes in radeon_atpx_handler.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 917c0dd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Report ras_num_recs in debugfs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d681a84
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Remove DUMMY_VRAM_SIZE (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9204969
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Release SDMAv4.4.2 ecc irq properly (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ed68f44
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add wait_for helper for spirom update (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7ebf52b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Clean up dcn10_optc.c kdoc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9ef9ef5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Correct kdoc formats in dcn32_resource_helpers.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5c6e22e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Provide function name for 'optc32_enable_crtc()' (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b8c8b02
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Correct and remove excess function parameter names (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8f94d1c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Correct kdoc formats in dcn10_opp.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 90edc8a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add missing function parameter 'optc' & 'enable' to kdoc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5ced4c0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Print client id for the unregistered interrupt resource (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 46e7fd5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: To enable traps for GC_11_0_4 and up (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2aa2e43
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: don't free stolen console memory during suspend (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d4ef45a
* Thu Sep 21 2023 pjakobsson@suse.de
- Revert "drm/amd/display: fix dpms_off issue when disabling bios mode" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b5b2f13
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: fix null queue check on debug setting exceptions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bae36de
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: enable vclk and dclk Pstates for SMU v13.0.5 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5561a37
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: fix vclk setting failed for SMU v13.0.5 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3484b75
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: 3.2.239 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3e76914
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: fix pixel rate update sequence (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/drm-amd-display-Remove-Phantom-Pipe-Check-When-.patch.
- commit dbf8467
* Thu Sep 21 2023 pjakobsson@suse.de
- Revert "drm/amd/display: reallocate DET for dual displays with high (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 85df74f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Include CSC updates in new fast update path (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6d6f4d8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Limit Minimum FreeSync Refresh Rate (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 65109be
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Bug fix in dcn315_populate_dml_pipes_from_context (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3763e82
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Block SubVP + DRR if the DRR is PSR capable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9b329e5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Do not disable phantom pipes in driver (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f447857
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Re-enable SubVP high refresh (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 42ece08
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Re-enable DPP/HUBP Power Gating (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4baaca2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: SubVP high refresh only if all displays >= 120hz (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aa22157
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Fix disbling PSR slow response issue (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3523714
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Promote DAL to 3.2.238 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 939fb3a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Add Error Code for Dml Validation Failure (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 13b59ce
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Add DP2 Metrics (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 47821db
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: add debugfs for allow_edp_hotplug_detection (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8493253
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: expose num_hops and num_links xgmi info through dev attr (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9b5aed8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/amdgpu: enable W=1 for amdgpu (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6c97631
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix kdoc warning (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 907fbce
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Rename DRM schedulers in amdgpu TTM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1f9d6a4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display/amdgpu_dm/amdgpu_dm_helpers: Move
  SYNAPTICS_DEVICE_ID into CONFIG_DRM_AMD_DC_DCN ifdef
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/drm-amd-display-Add-monitor-specific-edid-quirk.patch.
- commit a8b4743
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: Use /* */ comment in initializer macro (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 17e0d90
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/selftests: add local workqueue for SW fence selftest (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 905ae09
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: add a dedicated workqueue inside drm_i915_private (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0c4bb61
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: use pointer to i915 instead of rpm in wakeref (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dcd389d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: re-enable -Wunused-but-set-variable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 276cd08
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: Include of display limits doesn't need 'display/' (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6ae8277
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Add support for PM DEMAND (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 96425ed
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: find the best QGV point for the SAGV configuration (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 597666d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: modify max_bw to return index to intel_bw_info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9e1fdf3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: extract intel_bw_check_qgv_points() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0a190fd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: store the peak bw per QGV point (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2f257fa
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: update the QGV point frequency calculations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0fd6d31
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: fix the derating percentage for MTL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 606b6ee
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/dp: Fix log level for "CDS interlane align done" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 823eb4a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: annotate maybe unused but set intel_crtc_state variables (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 62010ea
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: annotate maybe unused but set intel_plane_state variables (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0f03e13
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/selftest: annotate maybe unused but set variable unused (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b5f3739
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/gem: annotate maybe unused but set variable c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5825114
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/gem: drop unused but set variable unpinned (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 374f2e3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/gt/uc: drop unused but set variable sseu (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit be5b742
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/irq: drop unused but set variable tmp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4098b78
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/fb: drop unused but set variable cpp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fc4c069
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/dpll: drop unused but set variables bestn and bestm1 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d873be9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/dsi: drop unused but set variable vbp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fb73665
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/dsi: drop unused but set variable data (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 56e83a9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/ddi: drop unused but set variable intel_dp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6eb7bc7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/plane: warn on non-zero plane offset (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 285380d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/debugfs: stop using edid_blob_ptr (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7b3f9f1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Fix error handling if driver creation fails during probe (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0bc61bb
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: Extract display init from (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 51e9c7c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: No 10bit gamma on desktop gen3 parts (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0634012
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: Print useful information on error (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a2b2f17
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Filter out AC mode frequencies on DC mode systems (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 36a8fd2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: DSC Programming Deltas (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ae9ea7b
* Thu Sep 21 2023 pjakobsson@suse.de
- Revert "drm/amd/display: cache trace buffer size" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4955b3d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: add NULL pointer check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 99db488
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: enable more Pstates profile levels for yellow_carp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 628b84d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add option params to enforce process isolation between (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bcf8470
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Wrap -Wunused-but-set-variable in cc-option (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit df7de6f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add the accelerator PCIe class (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a32ac03
* Thu Sep 21 2023 pjakobsson@suse.de
- Revert "Revert drm/amd/display: Enable Freesync Video Mode by (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f319f49
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: fix and enable debugging for gfx11 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3b5ddf0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: enable more Pstates profile levels for SMU v13.0.4 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0081158
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: enable vclk and dclk Pstates for SMU v13.0.4 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2bcf895
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: fix vclk setting failed for SMU v13.0.4 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 80c9b9f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: skip to resume rlcg for gc 9.4.3 in vf side (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6f9c921
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: disable virtual display support on APP device (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 13390a7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Refactor avi_info_frame colorimetry determination (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5890ef8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Add debugfs for testing output colorspace (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 03a028f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Always set crtcinfo from create_stream_for_sink (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 76c41d7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Send correct DP colorspace infopacket (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6dad5f3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Signal mode_changed if colorspace changed (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9aff5b9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Register Colorspace property for DP and HDMI (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f3b0177
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Always pass connector_state to stream validation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fcc7459
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/connector: Allow drivers to pass list of supported colorspaces (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fce27fb
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/connector: Print connector colorspace in state debugfs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3ccf155
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/connector: Use common colorspace_names array (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 28c9d1f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/connector: Pull out common create_colorspace_property code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2140d9f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/connector: Add enum documentation to drm_colorspace (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c4e3c52
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/connector: Convert DRM_MODE_COLORIMETRY to enum (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a5f52c6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Fix reserved SDMA queues handling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9ef9f1b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd: Check that a system is a NUMA system before looking for SRAT (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ebce45c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: fix vmfault signalling with additional data. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4d2d7c1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Set EEPROM ras info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a7f0ad7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Calculate EEPROM table ras info bytes sum (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 967894c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add support EEPROM table v2.1 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ec519c4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Support setting EEPROM table version (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4b3f7be
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add RAS table v2.1 macro definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c4d0c66
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Rename ras table version (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 34dfb5d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/mmsch: Correct the definition for mmsch init header (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 860c628
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: potential error pointer dereference in ioctl (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5d4d154
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Only use ODM2:1 policy for high pixel rate displays (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit df4c078
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Fix memory some memory corruption (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 36adb58
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: display/Kconfig: replace leading spaces with tab (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d86e61f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: mark dml314's UseMinimumDCFCLK() as (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 027b3de
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: mark dml31's UseMinimumDCFCLK() as (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fe348d0
* Thu Sep 21 2023 pjakobsson@suse.de
- =?UTF-8?q?drm/amd/display:=20Fix=20unused=20variable=20=E2=80=98s?= (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cc0ed53
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Add control flag to dc_stream_state to skip eDP BL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 434c176
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Wrong index type for pipe iterator (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 743c524
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Refactor fast update to use new HWSS build
  sequence (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/drm-amd-display-Remove-wait-while-locked.patch.
- commit c982684
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: convert vcn/jpeg logical mask to physical mask (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9bb0570
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: support check vcn jpeg block mask (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bdae00b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: pass xcc mask to ras ta (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2473afc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: update smu-driver if header for smu 13.0.0 and smu (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b30c829
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/pm: notify driver unloading to PMFW for SMU v13.0.6 dGPU (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 53e5df2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Mark 'kgd_gfx_aldebaran_clear_address_watch' & (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4da1705
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Program OTG vtotal min/max selectors unconditionally (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 543306f
* Thu Sep 21 2023 pjakobsson@suse.de
- Revert "drm/amd/display: Only use ODM2:1 policy for high pixel rate (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ac74771
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Add gnu_printf format attribute for snprintf_count() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6f38be4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Address kdoc warnings in dcn30_fpu.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0131cfa
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: fix compilation error due to shifting negative value (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 505e545
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/discovery: Replace fake flex-arrays with flexible-array (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bd3f427
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: fix debug wait on idle for gfx9.4.1 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2772585
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: clean up some inconsistent indenting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3f6187f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Fix dc/dcn20/dcn20_optc.c kdoc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 81cdc1a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: fulfill the OD support for SMU13.0.7 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6c07e8d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Fill metrics data for SMUv13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8dfc73c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: fulfill the OD support for SMU13.0.0 (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/drm-amd-pm-correct-the-pcie-width-for-smu-13.0.patch.
- commit fca9f12
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: fulfill SMU13 OD settings init and restore (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c10c97b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: bump kfd ioctl minor version for debug api availability (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4943e88
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: add debug device snapshot operation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 00d315b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: add debug queue snapshot operation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 90c8430
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: add debug query exception info operation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2b23982
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: add debug query event operation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fb80f7d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: add debug set flags operation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 623fc04
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: add debug set and clear address watch points operation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8b254ed
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: add debug suspend and resume process queues operation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 15691eb
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: add debug wave launch mode operation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 600b1e9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: add debug wave launch override operation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f43ad3d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: add debug set exceptions enabled operation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ee14591
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: update process interrupt handling for debug events (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0b55c7c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: update SMU13 header files for coming OD support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 70d207c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: add debug trap enabled flag to tma (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f80d222
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: add runtime enable operation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 07eca42
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: add send exception operation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2dc8c8b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: add raise exception event function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7b6b161
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: apply trap workaround for gfx11 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d7892b7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: add per process hw trap enable and disable functions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f999c91
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: expose debug api for mes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f523edb
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: prepare map process for multi-process debug devices (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f7dc470
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: prepare map process for single process debug devices (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9adf7e8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add configurable grace period for unmap queues (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 064ae8f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add gfx11 hw debug mode enable and disable calls (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6c7456b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add gfx9.4.2 hw debug mode enable and disable calls (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c9753ab
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add gfx10 hw debug mode enable and disable calls (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e86c352
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: fix kfd_suspend_all_processes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 57b625f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add gfx9.4.1 hw debug mode enable and disable calls (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 81e477b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add gfx9 hw debug mode enable and disable calls (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6f092e2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: clean up one inconsistent indenting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6ad8189
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Drop unused DCN_BASE variable in dcn314_resource.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f0f92d2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: setup hw debug registers on driver initialization (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f622c7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add kgd hw debug mode setting interface (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a1d1490
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: prepare per-process debug enable and disable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 671af51
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: display debug capabilities (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 03c57f8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: add debug and runtime enable interface (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cb417e8
* Thu Sep 21 2023 pjakobsson@suse.de
- amd/amdkfd: drop unused KFD_IOCTL_SVM_FLAG_UNCACHED flag (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 96a7a25
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: add unique serial number support for smu_v13_0_6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 945afd8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Fix SMUv13.0.6 throttle status report (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/drm-amd-pm-Fix-temperature-unit-of-SMU-v13.0.6.patch.
- commit 1d7e76c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Update SMUv13.0.6 PMFW headers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1722741
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add function parameter 'event' to kdoc in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7574c12
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix up kdoc in amdgpu_device.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aa40ed0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix up kdoc 'ring' parameter in sdma_v6_0_ring_pad_ib (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d898b2a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Fix up kdoc formatting in display_mode_vba.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 551b14b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: remove unused sq_int_priv variable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 16c6ce4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Correct kdoc formatting for (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aba09d4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Fix up missing 'dc' & 'pipe_ctx' kdoc parameters in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 56d8616
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Fix up kdoc formatting in dcn32_resource_helpers.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit db1eda8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdxcp: fix Makefile to build amdxcp module (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a512a0d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix up missing parameters kdoc in svm_migrate_vma_to_ram (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5bc669e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: set finished fence error if job timedout (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 67bfcb4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix missing parameter desc for 'xcp_id' in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a383c95
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix up missing parameter in kdoc for 'inst' in gmc_ v7, (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f6fa360
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix up missing kdoc parameter 'inst' in get_wave_count() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d009bf2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix missing parameter desc for 'xcc_id' in gfx_v7_0.c & (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8821a72
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: flag added to handle errors from svm validate and map (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 64b0049
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Initialize xcc mask (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 55ef45a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Fix up kdoc formats in dcn32_fpu.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e948b67
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Add missing kdoc entries in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2286e21
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix create_dmamap_sg_bo kdoc warnings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1ad11b4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Fix MEC pipe interrupt enablement (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fc4ec0c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Add new gfx_target_versions for GC 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bf7f562
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix up missing kdoc in sdma_v6_0.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a123db2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix up kdoc in amdgpu_acpi.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 20b5f75
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix up kdoc in sdma_v4_4_2.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5fc7a3d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: fix gfx_target_version for certain 11.0.3 devices (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2881941
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/amdgpu: Fix up locking etc in amdgpu_debugfs_gprwave_ioctl() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6664081
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: remove unused definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 50af796
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: use amdxcp platform device as spatial partition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5153f80
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: remove unused definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3bbe90e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdxcp: add platform device driver for amdxcp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 92ea889
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Mark mmhub_v1_8_mmea_err_status_reg as __maybe_unused (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 506dd00
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: remove unused definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7df5a59
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: clean up some inconsistent indenting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ffdfcd2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: remove unused definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e576c05
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: clean up some inconsistent indenting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1760b9d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: remove unused definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 83f439e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: remove unused definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d66482d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: remove unused definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f2d0805
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add the accelerator pcie class (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c699e5f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: save/restore part of xcp drm_device fields (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1bb8498
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: set the APU flag based on package type (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 57dd272
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/jpeg: add init value for num_jpeg_rings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5f90afe
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: complement the 4, 6 and 8 XCC cases (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 34ab697
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: golden settings for ASIC rev_id 0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5ec92e0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: bypass bios dependent operations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8a140e8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: remove unused definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7c3245d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: remove unused definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6a6d3bc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix unused variable in amdgpu_gfx.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7dcd2c7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix defined but not used gfx9_cs_data in gfx_v9_4_3.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3611f5e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix return types of certain NBIOv7.9 callbacks (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 510270b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: remove unused definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e87237f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd: Drop debugfs access to the DPCD (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d1791ba
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: remove unused definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cdc892d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: remove unused definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2091d58
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: remove unused definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f4fa34e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Use single copy per SDMA instance type (v2) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8a3096b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: switch to unified amdgpu_ring_test_helper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b4c2117
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/gfx: set sched.ready status after ring/IB test in gfx (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8b8ddb0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/sdma: set sched.ready status after ring/IB test in sdma (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 518428c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix warnings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 79f8e53
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Set event interrupt class for GFX 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2ac9185
* Thu Sep 21 2023 pjakobsson@suse.de
- Revert "drm/amd/display: Do not set drr on pipe commit"
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/drm-amd-display-Do-not-set-drr-on-pipe-commit.patch.
- commit ce52bc4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/amdgpu: Fix warnings in amdgpu_irq.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 53c9f7c
* Thu Sep 21 2023 pjakobsson@suse.de
- Revert "drm/amd/display: Block optimize on consecutive FAMS
  enables" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/drm-amd-display-Do-not-set-drr-on-pipe-commit.patch.
- commit 7f12a28
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add a low priority scheduler for VRAM clearing (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 29807d2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: Modify mismatched function name (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d48716c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Modify mismatched function name (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bb1cddd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Remove duplicate include (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3cec6e2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: remove unused variables res_create_maximus_funcs and (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b1d137f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: avoid calling missing .resync_fifo_dccg_dio() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8651061
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Align partition memory size to page size (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3c3ff70
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: remove unused variable num_xcc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e283d4e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: fix acpi build warnings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8ea4f9f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: use %%pad format string for dma_addr_t (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 927d156
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu:mark aqua_vanjaram_reg_init.c function as static (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a60f4db
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: mark local functions as static (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 32e1e8f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: mark irq functions as 'static' (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bdc9d81
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix unsigned comparison with zero in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6df0f85
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix a couple of spelling mistakes in info and debug (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 443dfe7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Disable interrupt tracker on NBIOv7.9 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 58b4066
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/radeon: stop including swiotlb.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 653ef00
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: init the XCC_DOORBELL_FENCE regs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0984e5e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: remove unused definition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5939e84
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix uninitialized variable in gfxhub_v1_2_xcp_resume (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e86b9d9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix unused amdgpu_acpi_get_numa_info function in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8112d29
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: 3.2.237 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0fa2f2a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: cache trace buffer size (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bf5941f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Reorganize DCN30 Makefile (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ce93b40
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Trigger DIO FIFO resync on commit streams for DCN32 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f6fe06
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Clean FPGA code in dc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a2a9c0b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Fix possible underflow for displays with large
  vblank (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/drm-amd-display-Prevent-vtotal-from-being-set-t.patch.
- commit 0c205e1
* Thu Sep 21 2023 dwagner@suse.de
- scsi: qla2xxx: Fix NULL vs IS_ERR() bug for debugfs_create_dir()
  (bsc#1214928 jsc#PED-5063).
- scsi: qla2xxx: Use raw_smp_processor_id() instead of
  smp_processor_id() (bsc#1214928 jsc#PED-5063).
- scsi: qla2xxx: Correct endianness for rqstlen and rsplen
  (bsc#1214928 jsc#PED-5063).
- scsi: qla2xxx: Fix unused variable warning in
  qla2xxx_process_purls_pkt() (bsc#1214928 jsc#PED-5063).
- scsi: qla2xxx: Fix spelling mistake "tranport" -> "transport"
  (bsc#1214928 jsc#PED-5063).
- scsi: qla2xxx: Remove unused variables in
  qla24xx_build_scsi_type_6_iocbs() (bsc#1214928 jsc#PED-5063).
- scsi: qla2xxx: Fix nvme_fc_rcv_ls_req() undefined error
  (bsc#1214928 jsc#PED-5063).
- scsi: qla2xxx: Update version to 10.02.09.100-k (bsc#1214928
  jsc#PED-5063).
- scsi: qla2xxx: Fix smatch warn for qla_init_iocb_limit()
  (bsc#1214928 jsc#PED-5063).
- scsi: qla2xxx: Remove unsupported ql2xenabledif option
  (bsc#1214928 jsc#PED-5063).
- scsi: qla2xxx: Add logs for SFP temperature monitoring
  (bsc#1214928 jsc#PED-5063).
- scsi: qla2xxx: Add Unsolicited LS Request and Response Support
  for NVMe (bsc#1214928 jsc#PED-5063).
  Refresh:
  - patches.suse/scsi-qla2xxx-Fix-firmware-resource-tracking.patch
- scsi: qla2xxx: Allow 32-byte CDBs (bsc#1214928 jsc#PED-5063).
- scsi: qla2xxx: Move resource to allow code reuse (bsc#1214928
  jsc#PED-5063).
- scsi: qla2xxx: Remove unused declarations (bsc#1214928
  jsc#PED-5063).
- scsi: qla2xxx: Update version to 10.02.08.500-k (bsc#1214928
  jsc#PED-5063).
- scsi: qla2xxx: fix inconsistent TMF timeout (bsc#1214928
  jsc#PED-5063).
- scsi: qla2xxx: Turn off noisy message log (bsc#1214928
  jsc#PED-5063).
- scsi: qla2xxx: Fix erroneous link up failure (bsc#1214928
  jsc#PED-5063).
- scsi: qla2xxx: Adjust IOCB resource on qpair create (bsc#1214928
  jsc#PED-5063).
  Refresh:
  - patches.suse/scsi-qla2xxx-Fix-firmware-resource-tracking.patch
- commit 885ad29
* Thu Sep 21 2023 tiwai@suse.de
- Update config files: correct leftover merge artifacts
- commit e8fc63c
* Thu Sep 21 2023 tiwai@suse.de
- Update config files: reduce old sound drivers (jsc#PED-962)
- commit 4360381
* Thu Sep 21 2023 mfranc@suse.cz
- Update patches.suse/scsi-zfcp-Defer-fc_rport-blocking-until-after-.patch
  (bsc#1012628 jsc#PED-5433 bsc#1214371 bsc#1213978).
- commit 1a5ed2a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Revert vblank change that causes null pointer
  crash (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/drm-amd-display-Prevent-vtotal-from-being-set-t.patch.
- Delete
  patches.suse/Partially-revert-drm-amd-display-Fix-possible-underf.patch.
- commit 69bfe31
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Trigger DIO FIFO resync on commit streams (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 785b8f4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: fix dcn315 pixel rate crb scaling check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2678b77
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: lower dp link training message level (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5dd5e5d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Update SR watermarks for DCN314 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 063ec68
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: disable dcn315 pixel rate crb when scaling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f6f1e71
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Fix DMUB debugging print issue (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8474b11
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: stop including swiotlb.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 34e4d38
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix uninitalized variable in kgd2kfd_device_init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5790b40
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix uninitalized variable in jpeg_v4_0_3_is_idle & (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 498d01f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/amdgpu: Fix errors & warnings in mmhub_v1_8.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8a92c41
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: retire set_vga_state for some ASIC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 51abed7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: improve the message printed when loading DC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7933ebd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: fix vga_set_state NULL pointer issue (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c05d01a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix uninitialized variable in gfx_v9_4_3_cp_resume (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 42718de
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Remove IMU ucode in vf2pf (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8be7e0e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: fix the memory override in kiq ring struct (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 202f252
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add the smu_v13_0_6 and gfx_v9_4_3 ip block (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ad33448
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/radeon: Remove unnecessary (void*) conversions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f8c3888
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd: Update driver-misc.html for Rembrandt-R (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 005d910
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: remove unnecessary (void*) conversions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1864d3d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd: Update driver-misc.html for Dragon Range (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 88b4a1a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd: Update driver-misc.html for Phoenix (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ff0df5a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: fix incorrect pcie_gen_mask in passthrough case (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2d25e98
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: drop unused count variable in create_eml_sink() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 56bcf1f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: drop unused function set_abm_event() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5cf8d5d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: fix S3 issue if MQD in VRAM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b9a5c6c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix warnings in amdgpu _sdma, _ucode.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c28d85d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/amdgpu: Fix errors & warnings in amdgpu _uvd, _vce.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3ac5830
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: perform mode2 reset for sdma fed error on gfx v11_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3b983cd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/amdgpu: Fix errors & warnings in amdgpu_vcn.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b3855ca
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/amdgpu: Fix warnings in amdgpu_encoders.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit baeffda
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: fix stack size in svm_range_validate_and_map (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit abd63cf
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/amdgpu: Fix errors & warnings in amdgpu_ttm.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0f5f782
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/vcn4: fix endian conversion (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a819ce9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/gmc9: fix 64 bit division in partition code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f16f3c8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: initialize RAS for gfx_v9_4_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d1cbda8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add sq timeout status functions for gfx_v9_4_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e10aa03
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add RAS error count reset for gfx_v9_4_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 435ed9f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add RAS error count query for gfx_v9_4_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e6b63f0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add RAS error count definitions for gfx_v9_4_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c2b820f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add RAS definitions for GFX (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 51b23ce
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add gc v9_4_3 ras error status registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 801b5d6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add RAS status reset for gfx_v9_4_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit faa2e50
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add RAS status query for gfx_v9_4_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6a5668f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add GFX RAS common function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 61c8a2d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Do not access members of xcp w/o check (v2) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b6560ec
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Fix null ptr access (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 02554f0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add check for RAS instance mask (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d8e09b3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: remove RAS GFX injection for gfx_v9_4/gfx_v9_4_2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 525b8fb
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: reorganize RAS injection flow (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d80f8c8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add instance mask for RAS inject (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3d5c879
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: convert logical instance mask to physical one (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2e7933f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Enable IH CAM on GFX9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 49a6dcc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Correct get_xcp_mem_id calculation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bc2c71c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Refactor migrate init to support partition switch (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 08184d2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: route ioctls on primary node of XCPs to primary device (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 626d0e4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: APU mode set max svm range pages (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ab9b031
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Fix memory reporting on GFX 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cf10e82
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Move local_mem_info to kfd_node (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 86f8c8e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: use xcp partition ID for amdgpu_gem (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 72af3fc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: KFD graphics interop support compute partition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1010ff7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Store xcp partition id to amdgpu bo (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4e14f84
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: dGPU mode set VRAM range lpfn as exclusive (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e4465cb
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Alloc page table on correct memory partition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4fff200
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Update MTYPE for far memory partition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 71f31f5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: dGPU mode placement support memory partition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0c0331c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: SVM range allocation support memory partition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cf5046f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Alloc memory of GPU support memory partition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8e653cd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add memory partition mem_id to amdgpu_bo (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9bb9efd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Show KFD node memory partition info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 404d348
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add memory partition id to amdgpu_vm (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5783535
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Store drm node minor number for kfd nodes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 62bcbe9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add xcp manager num_xcp_per_mem_partition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 19842b9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: update ref_cnt before ctx free (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3195c4c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: run partition schedule if it is supported (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7c70169
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add partition schedule for GC(9, 4, 3) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b3aba65
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: keep amdgpu_ctx_mgr in ctx structure (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5bdf505
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add partition scheduler list update (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d3db2c3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: update header to support partition scheduling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fbafab0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add partition ID track in ring (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d2d9777
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: find partition ID when open device (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 98380c3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/bu: update mtype_local parameter settings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 14bbdd6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/bu: add mtype_local as a module parameter (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 83eac25
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Override MTYPE per page on GFXv9.4.3 APUs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 728d1f4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix per-BO MTYPE selection for GFXv9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f2501a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/bu: Add use_mtype_cc_wa module param (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 00ff24b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Use legacy TLB flush for gfx943 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 110612b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: For GFX 9.4.3 APU fix vram_usage value (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fe078f6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Enable NPS4 CPX mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ce99b84
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Move pgmap to amdgpu_kfd_dev structure (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 40bcd11
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Skip halting RLC on GFX v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 99d1154
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix register accesses in GFX v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7fa3258
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Increase queue number per process to 255 on GFX9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b4fa075
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Adjust the sequence to query ras error info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6a38ece
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Initialize jpeg v4_0_3 ras function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c398ff0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add reset_ras_error_count for jpeg v4_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f08bead
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add query_ras_error_count for jpeg v4_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3cd9edb
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Re-enable VCN RAS if DPG is enabled (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ec27932
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Initialize vcn v4_0_3 ras function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5901112
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add reset_ras_error_count for vcn v4_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 841deba
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add query_ras_error_count for vcn v4_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f4096f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add vcn/jpeg ras err status registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 26857c3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Checked if the pointer NULL before use it. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4131092
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Set memory partitions to 1 for SRIOV. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5989e4a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Skip using MC FB Offset when APU flag is set for SRIOV. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5b6fb99
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add PSP supporting PSP 13.0.6 SRIOV ucode init. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit db2d095
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add PSP spatial parition interface (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e571f9f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Return error on invalid compute mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fe5a669
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add compute mode descriptor function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2634b12
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix unmapping of aperture (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a21ef99
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix xGMI access P2P mapping failure on GFXIP 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fc3ad1b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Native mode memory partition support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e1bcc89
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Set TTM pools for memory partitions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 35d8eb6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/ttm: export ttm_pool_fini for cleanup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit efbd6bd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add auto mode for compute partition (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5c23797
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Check memory ranges for valid xcp mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit deeabdb
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Use xcc mask for identifying xcc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 89bba72
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Add xcp reference to kfd node (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ef1a727
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Move initialization of xcp before kfd (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7c700fc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fill xcp mem node in aquavanjaram (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 971492b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add callback to fill xcp memory id (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 14d5d66
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Initialize memory ranges for GC 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 83c110e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add memory partitions to gmc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit af74999
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add API to get numa information of XCC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e917725
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Store additional numa node information (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 277688a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Get supported memory partition modes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b669c19
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Move memory partition query to gmc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 17c5150
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add utility functions for xcp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9697763
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Use apt name for FW reserved region (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 197d860
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Use GPU VA space for IH v4.4.2 in APU (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f1b334e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Simplify aquavanjram instance mapping (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 06c5751
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: Use buffer object's deletion logic (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c529ed4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Use a different value than 0xDEADBEEF for jpeg ring test (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9499a3d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add a read after write DB_CTRL for vcn_v4_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 98812bd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: fixes a JPEG get write/read pointer bug (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d8be079
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: A workaround for JPEG_v4_0_3 ring test fail (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 11e6fad
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: use physical AID index for ring name (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit df1700d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: use dummy register selects AID for VCN_RAM ucode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ec7b567
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix harvest reporting of VCN (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c25b44e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Use logical ids for VCN/JPEG v4.0.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cf738b1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add VCN logical to physical id mapping (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 87d699f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add instance mask for VCN and JPEG (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fd219ae
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Load vcn_v4_0_3 ucode during early_init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 16f35e2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: preserve the num_links in case of reflection (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit db285b3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix discovery sys node harvest info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 645bbfa
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Flush TLB after unmapping for GFX v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c7a9adc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add fallback path for discovery info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0c8e909
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Read discovery info from system memory (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5fabbeb
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add API to get tmr info from acpi (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d49285c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add parsing of acpi xcc objects (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 67120d0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Enable SVM on Native mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6248034
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add FGCG for GFX v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3435d64
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Use transient mode during xcp switch (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9f57cb5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add flags for partition mode query (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4562290
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: fix wrong smu socclk value (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 301f2d8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add mode-2 reset in SMU v13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 33db90f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Notify PMFW about driver unload cases (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5a1b56d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Update PMFW headers for version 85.54 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3a22067
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Expose mem temperature for GC version 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0ffd729
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Update hw mon attributes for GC version 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit adb8bda
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Initialize power limit for SMU v13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fac79a5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Keep interface version in PMFW header (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ecd3969
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Add ih for SMU v13.0.6 thermal throttling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5c1bb87
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Update pmfw header files for SMU v13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c42cea5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Update gfx clock frequency for SMU v13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5b536dc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Update pmfw header files for SMU v13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 298a026
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: fix sdma instance (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1be47a9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: change the print level to warn for ip block disabled (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ed16d0f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Increase Max GPU instance to 64 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d16bb52
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: increase AMDGPU_MAX_RINGS (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d9f17d2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Create VRAM BOs on GTT for GFXIP9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 263b811
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Implement new dummy vram manager (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5d2ec2c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Handle VRAM dependencies on GFXIP9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c0cc910
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Enable CG for IH v4.4.2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3fa4741
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Enable persistent edc harvesting in APP APU (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 39315ce
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Initialize mmhub v1_8 ras function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bab35de
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add reset_ras_error_status for mmhub v1_8 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6528a7d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add query_ras_error_status for mmhub v1_8 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ef6811b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add reset_ras_error_count for mmhub v1_8 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6e75408
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add query_ras_error_count for mmhub v1_8 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6b7fa8f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add mmhub v1_8_0 ras err status registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a83f221
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Initialize sdma v4_4_2 ras function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 694bdca
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add reset_ras_error_count for sdma v4_4_2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 26cc78a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add query_ras_error_count for sdma v4_4_2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c8f6a7c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add sdma v4_4_2 ras registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8ab1e67
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add common helper to reset ras error (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f6611bf
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add common helper to query ras error (v2) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bfc85cb
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Enable MGCG on SDMAv4.4.2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1d82d8f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: enable context empty interrupt on sdma v4.4.2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a76731b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add vcn_4_0_3 codec query (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8bc910f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: bind cpu and hiveless gpu to a hive if xgmi connected (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2df792f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Cleanup KFD nodes creation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 60e438f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/ttm: add NUMA node id to the pool (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 690343f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix mqd init on GFX v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bed16b6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd: fix compiler error to support older compilers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bf9a0c7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Enable CGCG/LS for GC 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 78231c2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Use unique doorbell range per xcc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d206314
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Keep SDMAv4.4.2 active during reset (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a053965
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Report XGMI IOLINKs for GFXIP9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eec27f0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add num_xcps return (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 41f9a19
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: increase AMDGPU_MAX_HWIP_RINGS (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 506d46f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: vcn_v4_0_3 load vcn fw once for all AIDs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 352596e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Populate VCN/JPEG harvest information (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1c922f8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Correct dGPU MTYPE settings for gfx943 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 876ec70
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Remove SMU powergate message call for SDMA (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c633446
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: enable vcn/jpeg on vcn_v4_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6e8a596
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: enable indirect_sram mode on vcn_v4_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 14d74aa
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add unified queue support on vcn_v4_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 56665c1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add fwlog support on vcn_v4_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c22bee8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: increase MAX setting to hold more jpeg instances (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b0d16ba
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Use discovery to get XCC/SDMA mask (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 62decd3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Make VRAM discovery read optional (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0e5f050
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Allocate GART table in RAM for AMD APU (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 17f38dc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add FGCG logic for GFX v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a7c3031
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Make UTCL2 snoop CPU caches (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 511d203
* Thu Sep 21 2023 pjakobsson@suse.de
- amd/amdgpu: Set MTYPE_UC for access over PCIe (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b0e6513
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix GFX v9.4.3 EOP buffer allocation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 55bd2ba
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix GFX 9.4.3 dma address capability (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 63b4f35
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix semaphore release (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 830d513
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Setup current_logical_xcc_id in MQD (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c46c992
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Remove unnecessary return value check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1bf58a0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: correct the vmhub index when page fault occurs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 16b96f1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Update packet manager for GFX9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 62b850e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: set MTYPE in PTE for GFXIP 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 33278af
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Use mask for active clusters (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1ab8e36
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Derive active clusters from SDMA (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e5ce648
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Move generic logic to soc config (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e619a62
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix the KCQ hang when binding back (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 024716a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Skip TMR allocation if not required (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 616276f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add XCP IP callback funcs for each IP (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9776e6e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add XCP functions for GFX v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6703090
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add SDMA v4.4.2 XCP funcs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eaf66f9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add GFXHUB v1.2 XCP funcs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0a7e4c7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Switch to SOC partition funcs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit da815e2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add soc config init for GC9.4.3 ASICs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1e633cc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add SOC partition funcs for GC v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b4d8aed
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add initial version of XCP routines (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5734b6f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add sdma instance specific functions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit acd52a6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add xcc specific functions for gfxhub (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 994f11e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add xcc specific functions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 41d9b49
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Rename xcc specific functions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8a27359
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Check APU supports true APP mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 59b4f8b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: more GPU page fault info for GC v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 53374df
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: remove partition attributes sys file for gfx_v9_4_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5b892e8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: fix kcq mqd_backup buffer double free for multi-XCD (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aaf76ac
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Skip runtime db read for PSP 13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 465f295
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: fix vm context register assignment in mmhub v1.8 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 63e7cd0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Revert programming of CP_PSP_XCP_CTL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3fb2d1f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: detect current GPU memory partition mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b4cb7ad
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: init smuio funcs for smuio v13_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ccd92f6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: implement smuio v13_0_3 callbacks (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 97a7075
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add smuio v13_0_3 ip headers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d56b555
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: retire render backend setup from gfx_v9_4_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 128fd4c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/amdgpu: Update debugfs for XCC support (v3) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2a62edd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add SDMA v4.4.2 golden settings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f0dd560
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: init gfx_v9_4_3 external_rev_id (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 658bf81
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix interrupt handling in GFX v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ddbbb65
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: consolidate the access helpers in nbio v7_9 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fe1a75a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add helpers to access registers on different AIDs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 354ccea
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: parse base address from new ip discovery with 64bit ip (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3a93c78
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: upgrade amdgpu_discovery struct ip to ip_v4 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ed621cb
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: do some register access cleanup in nbio v7_9 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2dd212b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: extend max instances (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 932fe25
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: increase DISCOVERY_TMR_SIZE (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a163106
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: update ip discovery header to v4 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d0bbff2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: switch to aqua_vanjaram_doorbell_index_init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 13f1862
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Use SDMA instance table for aqua vanjaram (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fe4d5d4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add mask for SDMA instances (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d737891
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add IP instance map for aqua vanjaram (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8988eb6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add new doorbell assignment table for aqua_vanjaram (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 48b20e0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix register access on GC v9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 179f42c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix programming of initial XCP mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a6f98f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Update interrupt handling for GFX9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6ac27df
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix failure when switching to DPX mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5681e3f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Use instance table for GFX 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8e903cd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix SWS on multi-XCD GPU (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2574d49
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: drop redundant csb init for gfx943 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4d8d789
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: adjust s2a entry register for sdma doorbell trans (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 311f536
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Update SMI events for GFX9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9d88268
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Use status register for partition mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 30b55fd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: pass kfd_node ref to svm migration api (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a0470f1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Conform to SET_UCONFIG_REG spec (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3cac682
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: add vcn multiple AIDs support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7b583ca
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: update clock gate setting for VCN 4.0.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3ef368b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/jpeg: add JPEG multiple AIDs support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8fa2571
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/nbio: add vcn doorbell multiple AIDs support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5634c12
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix GRBM programming sequence (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f4603b3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Use instance table for sdma 4.4.2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7016e26
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add mask for SDMA instances (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1cec5e1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Use instance lookup table for GC 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f9e1990
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add map of logical to physical inst (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0d5c0a9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Add device repartition support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0f3755a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Rework kfd_locked handling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3ad7302
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: configure the doorbell settings for sdma on non-AID0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 82be392
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add indirect r/w interface for smn address greater than (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a43b4c4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: EOP Removal - Handle size 0 correctly (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c8471f1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: reflect psp xgmi topology info for gfx9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0784d0e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: update amdgpu_fw_shared to amdgpu_vcn4_fw_shared (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8988004
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: remove unused code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5435d18
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: update ucode setup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 98f49b1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: update new doorbell map (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b0e3c02
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/jpeg: update jpeg header to support multiple AIDs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 70a9445
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: update vcn header to support multiple AIDs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7ddd66e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: use vcn4 irqsrc header for VCN 4.0.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d42f572
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Change num_xcd to xcc_mask (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit de7d5dd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add the support of XGMI link for GC 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7c0d012
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add new vram type for dgpu (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e980d45
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Populate memory info before adding GPU node to topology (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8a7ca6c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Add SDMA info for SDMA 4.4.2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 10f1191
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Fix SDMA in CPX mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 483c737
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: add gpu compute cores io links for gfx9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9c786a4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: introduce new doorbell assignment table for GC 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dca185d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: program GRBM_MCM_ADDR for non-AID0 GRBM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cd744e2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: convert the doorbell_index to 2 dwords offset for kiq (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6f83308
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: set mmhub bitmask for multiple AIDs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7fd97c1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: complement the IH node_id table for multiple AIDs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e7ce72f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: correct the vmhub reference for each XCD in gfxhub init (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 91be675
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: do mmhub init for multiple AIDs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 22a1e5f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: assign the doorbell index for sdma on non-AID0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 586f3ac
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add support for SDMA on multiple AIDs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bcf082e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: adjust some basic elements for multiple AID case (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 769798b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: assign the doorbell index in 1st page to sdma page queue (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit af749c8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Set XNACK per process on GC 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b276f2d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Use new atomfirmware init for GC 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 59fe354
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Update coherence settings for svm ranges (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 25ef3d2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix CP_HYP_XCP_CTL register programming in CPX mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a3325c2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Update SDMA queue management for GFX9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3bd904a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Update sysfs node properties for multi XCC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit caf6cf4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Call DQM stop during DQM uninitialize (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 28fddb2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix VM fault reporting on XCC1 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a28d40e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Update context save handling for multi XCC setup (v2) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 108db58
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add XCC inst to PASID TLB flushing (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 47b102c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Add XCC instance to kgd2kfd interface (v3) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 718e506
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Add PM4 target XCC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f584faf
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Update MQD management on multi XCC setup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7ca6a46
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Add spatial partitioning support in KFD (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b7ca461
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Introduce kfd_node struct (v5) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 088b458
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add mode2 reset logic for v13.0.6 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 531578f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add some XCC programming (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3b68510
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add node_id to physical id conversion in EOP handler (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2db1301
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: enable the ring and IB test for slave kcq (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2beb0ff
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: support gc v9_4_3 ring_test running on all xcc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eab204d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: fix vcn doorbell range setting (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0ce5cdd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/jpeg: enable jpeg doorbell for jpeg4.0.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cb73840
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: enable vcn doorbell for vcn4.0.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 796bc87
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/nbio: update vcn doorbell range (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 715819f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Set F8_MODE for gc_v9_4_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f747e6b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/jpeg: add multiple jpeg rings support for vcn4_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 76b4371
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/jpeg: add multiple jpeg rings support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5f04e2e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: enable vcn DPG mode for VCN4_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c920679
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: enable vcn pg for VCN4_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 09da8e1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: enable vcn cg for VCN4_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 01ee657
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/jpeg: enable jpeg pg for VCN4_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ac8927b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/jpeg: enable jpeg cg for VCN4_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 69fe7ab
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/vcn: add vcn support for VCN4_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bfee820
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/jpeg: add jpeg support for VCN4_0_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8462eee
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add VCN4_0_3 firmware (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fb165d8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add vcn v4_0_3 ip headers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9dcd5f0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/: add more macro to support offset variant (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ca3f59d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Use the correct API to read register (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4fadf64
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add kgd2kfd for GC 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 385728a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: alloc vm inv engines for every vmhub (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4fa98c7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: override partition mode through module parameter (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit af06f1d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: make the WREG32_SOC15_xx macro to support multi GC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9d000d4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add sysfs node for compute partition mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bc74b50
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: assign different AMDGPU_GFXHUB for rings on each xcc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 04c93b9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: init vmhubs bitmask for GC 9.4.3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f685a7b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add bitmask to iterate vmhubs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6055555
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: assign register address for vmhub object on each XCD (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2cc89aa
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: introduce vmhub definition for multi-partition cases (v3) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e1795fc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: 3.2.236 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2cb1bdc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Remove unnecessary variable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2bd2041
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Make unbounded req update separate from dlg/ttu (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7444767
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Add visual confirm color support for MCLK switch (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bd0dafe
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Convert connector signal id to string (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6a06321
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Update vactive margin and max vblank for fpo + (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5058a80
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Only skip update for DCFCLK, UCLK, FCLK on overclock (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b655a9f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: improve wait logic at fence polling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5f894d7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Simplify the calculation of variables (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aaf3700
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/amdgpu: Fix warnings in amdgpu _object, _ring.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fa956a9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: release correct lock in amdgpu_gfx_enable_kgq() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d709969
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/display: Enable DC_FP for LoongArch (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 868f01c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Promote DAL to 3.2.235 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c13f8b2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Block SubVP on displays that have pixclk > 1800Mhz (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 300d4d5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Block SubVP high refresh when VRR active fixed (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c7c56de
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Check Vactive for VRR active for FPO + Vactive (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9a27d96
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: set default num_kcq to 2 under sriov (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4120ff0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Show the DCN/DCE version in the log (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e51728e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Remove the unused variable golden_settings_gc_9_4_3 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 34d7e89
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Don't trigger evictions unmapping dmabuf attachments (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a98b35a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Add additional pstate registers to HW state query (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 90649c1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: remove unneeded semicolon (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6bb7728
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: do gfxhub init for all XCDs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6f255cf
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: unlock on error in gfx_v9_4_3_kiq_resume() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4aea0ff
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: unlock the correct lock in amdgpu_gfx_enable_kcq() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a8953b4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: drop unused function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8d9f70f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: drop invalid IP revision (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 40e8d14
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: put MQDs in VRAM (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b9bde94
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/amdgpu: Fix errors & warnings in amdgpu _bios, _cs, _dma_buf, (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 57313b8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/gfx11: always restore kcq/kgq MQDs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e6aa7a8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: mark amdgpu_dm_connector_funcs_force static (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d3a4cdc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/gfx10: always restore kcq/kgq MQDs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f0fcc5d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/gfx9: always restore kcq MQDs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit adb9457
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/gfx8: always restore kcq MQDs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0f72c6b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/gfx11: drop unused variable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 04b1e1e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/gfx10: drop unused variable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3657604
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd: Downgrade message about watermarks table after s0i3 to debug (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7b6aabe
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/gfx11: use generic [en/dis]able_kgq() helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0597d12
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/gfx10: use generic [en/dis]able_kgq() helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6d9e0bf
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add [en/dis]able_kgq() functions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9b967e6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: 3.2.234 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9056fb4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.165.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 56ba4ff
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Add w/a to disable DP dual mode on certain ports (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a575d63
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: revert "Update scaler recout data for visual (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6b4b4da
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Adding debug option to override Z8 watermark values (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 72cc043
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Workaround wrong HDR colorimetry with some receivers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9e843d2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Add logging when DP link training Channel EQ is (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0aaa819
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/amdgpu: Fix style problems in amdgpu_psp.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5df4823
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/gfx10: drop old bring up code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0d686ce
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/gfx11: drop old bring up code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d990c68
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Optimize svm range map to GPU with XNACK on (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 32e2fcf
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Add logging for eDP v1.4 supported sink rates (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 48a111d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Fix possible NULL dereference in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5c21885
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/amdgpu: Fix style problems in amdgpu_debugfs.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0715995
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Enable mcbp under sriov by default (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 559f7c7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: remove pasid_src field from IV entry (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aff6098
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/amdgpu: Simplify switch case statements in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1f950f4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add SDMA_UTCL1_WR_FIFO_SED field for sdma_v4_4_ras_field (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 99e3c7c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Update KFD TTM mem limit (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 69c77d6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Set GTT size equal to TTM mem limit (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4ee62fd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/ttm: Helper function to get TTM mem limit (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b7f05b3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: mark gfx_v9_4_3_disable_gpa_mode() static (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 45479e4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: check correct allocated mqd_backup object after alloc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 43fe564
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: fix a build warning by a typo in amdgpu_gfx.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b0aa449
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: return status of dmub_srv_get_fw_boot_status (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 01225d6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: set variable custom_backlight_curve0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 93d40e8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/amdgpu: Fix style errors in amdgpu_display.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e8df70c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: DSC passthrough is for DP-HDMI pcon (SST pcon) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dce215a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add new flag to AMDGPU_CTX_QUERY2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d4edfd2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm:amd:amdgpu: Fix missing bo unlock in failure path (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 81a9d28
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: remove unused variables dispclk_delay_subtotal and (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 23fbee8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: support psp vbflash sysfs for MP0 13_0_10 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 64ac4c7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: 3.2.233 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2df3241
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Query GECC enable for SubVP disable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ed1c556
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Enable SubVP for high refresh rate displays (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bbe01b8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: For no plane case set pstate support in validation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c380cf5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Add p-state debugging (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ed6aebf
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Update scaler recout data for visual confirm (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4fac55a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Program OTG vtotal min/max selectors unconditionally (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 42eac4b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: add option to use custom backlight caps (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8423cad
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Enable SubVP on PSR panels if single stream (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eff8c77
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Restore rptr/wptr for DMCUB as workaround (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f49e072
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Update FW feature caps struct (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 93bb9cc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: implement force function in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b4ebfd5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: 3.2.232 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ea6d802
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.163.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 61d64fd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add debugfs interface for reading MQDs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8ac7a3b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: track MQD size for gfx and compute (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a5e5ffd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: bump driver version number for CP GFX shadow (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9f3b100
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdkfd: Fix an issue at userptr buffer validation process. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c98315a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: assign edid_blob_ptr with edid from debugfs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 263767f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add support for new GFX shadow size query (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 266df5e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add get_gfx_shadow_info callback for gfx11 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0991ea1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add gfx shadow callback (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b3af8db
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add UAPI to query GFX shadow sizes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7c3905b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: don't require a job for cond_exec and shadow (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 679ca88
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add gfx11 emit shadow callback (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9e5c100
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add gfx shadow CS IOCTL support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5ceef1c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/UAPI: add new CS chunk for GFX shadow buffers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fff1579
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/gfx11: check the CP FW version CP GFX shadow support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c276cd6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu/gfx11: add FW version check for new CP GFX shadow feature (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 82eced4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: dumb_abm_lcd: avoid missing-prototype warnings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 56c7ad2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: 3.2.231 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 675200d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Add FAMS related definitions and documenation for (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d9e3f19
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Add FAMS capability to DCN31 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b3f46b4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: fix dpms_off issue when disabling bios mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 666931d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: update GSP1 generic info packet for PSRSU (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f060959
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Adjust dmub outbox notification enable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5fcc831
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: 3-plane MPO enablement for DCN321 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5dce3e1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Add extra check for 444 16 format (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e0fb904
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: correct DML calc error (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3a5c491
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Limit nv21 dst_y (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 954ff4b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Add check for PState change in DCN32 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1aed7df
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Set DRAM clock if retraining is required (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9f4a607
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: add support for low bpc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bbda83f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/amdgpu: Fix style issues in amdgpu_discovery.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4f64331
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Remove unused variables in dcn21_hwseq.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 07026f7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: allocate doorbell index for multi-die case (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4cfcbab
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/amdgpu: Fix style errors in amdgpu_drv.c & amdgpu_device.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0b2af78
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/amdgpu: Fix spaces in array indexing and indentations in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3979f4b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Drop pcie_bif ras check from fatal error handler (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bbb99f0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: initialize num_xcd to 1 for gfx v9_0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 77880d1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add master/slave check in init phase (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c2afcbe
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Clear GPINT1 before taking DMCUB out of reset (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c292f3e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add xcc index argument to rlc safe_mode func (v4) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5207df8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add xcc index argument to select_sh_se function v2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0795290
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add xcc index argument to gfx v9_4_3 functions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5093050
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add multi-XCC initial support in gfx_v9_4_3.c (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5b1c963
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add xcc index argument to soc15_grbm_select (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d656861
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: split gc v9_4_3 functionality from gc v9_0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e68f63e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: add multi-xcc support to amdgpu_gfx interfaces (v4) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dc75659
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: separate the mqd_backup for kiq from kcq (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4891858
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: move queue_bitmap to an independent structure (v3) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fb8e0d4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: convert gfx.kiq to array type (v3) (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a897cae
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: remove unused variable oldest_index (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 43e14b6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Fix spelling mistake "aquire" -> "acquire" (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cd77318
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add support for querying the max ibs in a submission. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f946aa4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Add a max ibs per submission limit. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f4235d6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Increase GFX6 graphics ring size. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7e76b74
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Write TEST_EDID_CHECKSUM_WRITE for EDID tests (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 423ba24
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: add mechanism to skip DCN init (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/drm-amd-display-Set-minimum-requirement-for-usi.patch.
- commit 6c7b0ef
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: add extra dc odm debug options (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 13ee7f9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.162.0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6b71ea9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Enable FPO + Vactive (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dc4c701
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Set watermarks set D equal to A (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f43f7e1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Correct output color space during HW reinitialize (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ff231cf
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: DSC policy override when ODM combine is forced (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4f2f061
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Adding support for VESA SCR (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3a31437
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: drain dmub inbox if queue is full (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d807ece
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: refactor dmub commands into single
  function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/drm-amd-display-Set-minimum-requirement-for-usi.patch.
- commit ab21a66
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Only consider DISPCLK when using optimized boot path (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0b2cfa8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: update max streams per surface (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f184e0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Fix in disabling secure display (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 17eb970
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Block optimize on consecutive FAMS
  enables (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/drm-amd-display-Do-not-set-drr-on-pipe-commit.patch.
- commit 6ef2fed
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Do not set drr on pipe commit (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/drm-amd-display-Do-not-set-drr-on-pipe-commit.patch.
- commit 41e7d51
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Fix ABM pipe/backlight issues when change backlight (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9cc4480
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Check & log if receiver supports MST, DSC & FEC. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dba99a7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/display: Refactor ABM feature (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit be14e0c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/gsc: Fix error code in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ec82276
* Thu Sep 21 2023 pjakobsson@suse.de
- i915/perf: Do not add ggtt offset to hw_tail (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1d7fa39
* Thu Sep 21 2023 pjakobsson@suse.de
- i915/perf: Drop the aging_tail logic in perf OA (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9014880
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Allow user to set cache at BO creation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9b6d618
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/guc: Remove some obsolete definitions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c3d0d79
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: rename I915_PMU_MAX_GTS to I915_PMU_MAX_GT (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ca13f77
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Reduce I915_MAX_GT to 2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d93184b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Use the fdinfo helper (jsc#PED-3527 jsc#PED-5475
  jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/0001-drm-Clear-fd-handle-callbacks-in-struct-drm_driver.patch.
- commit b36a900
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/huc: define HuC FW version for MTL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 82006df
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl/huc: Use the media gt for the HuC getparam (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d09b48e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl/huc: auth HuC via GSC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3022383
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/huc: differentiate the 2 steps of the MTL HuC auth flow (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 516ec6e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/huc: Load GSC-enabled HuC via DMA xfer if the fuse says so (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5d0eb0c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/huc: Parse the GSC-enabled HuC binary (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9027300
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/uc: perma-pin firmwares (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ad8ceae
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/pxp: Fix size_t format specifier in gsccs_send_message() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5075c4e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/gt: limit lmem allocation size to succeed on SmallBars (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dd30e03
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/gt: Fix parameter in gmch_ggtt_insert_{entries, page}() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b6eb592
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/gt: Fix second parameter type of pre-gen8 pte_encode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b96fa49
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/pmu: Make PMU sample array two-dimensional (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 52373d6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/pmu: Turn off the timer to sample frequencies when GT is (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4cfaaff
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/guc: Drop legacy CTB definitions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e36bbbd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/guc: Track all sent actions to GuC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cd37380
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/guc: Update log for unsolicited CTB response (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5367a09
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/guc: Use FAST_REQUEST for non-blocking H2G calls (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 306501e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/gem: Use large rings for compute contexts (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cbf6444
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/gsc: use system include style for drm headers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b4fc6fc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Reset only one lane in case of MFD (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 530224c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Flush power delayed put when connector init failed (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4e1d494
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Remove i915_drm_suspend_mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a7805e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915_drm.h: fix a typo (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2f15edc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: switch the rest of the connectors to struct (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7230bbc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/display/dp_mst: convert to struct drm_edid (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 655ad8f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/edid: make drm_edid_duplicate() safe to call with NULL parameter (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d2afae4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/lvds: switch to drm_edid_read_switcheroo() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a4561db
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/edid: add drm_edid_read_switcheroo() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e0823f2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/sdvo: stop caching has_hdmi_audio in struct intel_sdvo (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e964241
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/sdvo: stop caching has_hdmi_monitor in struct intel_sdvo (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ba0d0a0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/hdmi: stop caching has_hdmi_sink in struct intel_hdmi (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 60d6489
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/hdmi: stop caching has_audio in struct intel_hdmi (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c0b94f5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/dp: stop caching has_hdmi_sink in struct intel_dp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3a54444
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/dp: stop caching has_audio in struct intel_dp (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 24a5a93
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/display/dp_mst: drop has_audio from struct drm_dp_mst_port (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b5e9ff4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/edid: parse display info has_audio similar to is_hdmi (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9216034
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: use localized __diag_ignore_all() instead of per file (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c5813e1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/hdcp: Rename comp_mutex to hdcp_mutex (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8a3079d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/hdcp: Move away from master naming to arbiter (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2252453
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/hdcp: Rename dev_priv to i915 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7921ee1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Implement CTM property support for VLV (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d6179eb
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Always enable CGM CSC on CHV (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1a891b8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Fix CHV CGM CSC coefficient sign handling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7de6cce
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Expose crtc CTM property on ilk/snb (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8dc828b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Fix clang -Wimplicit-fallthrough in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6cd1b01
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: Move feature test macros to intel_display_device.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 33fb907
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: Handle GMD_ID identification in display code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8f678b4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: Make display responsible for probing its own IP (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 98365b2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: Move display runtime info to display structure (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3a35d92
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Convert INTEL_INFO()->display to a pointer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6aed04f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Replace all non-returning strlcpy with strscpy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1924536
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Wait for active retire before i915_active_fini() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 080439c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Support Async Flip on Linear buffers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ea1165e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: constify pointers to hwmon_channel_info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a58ccd2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/display/dsc: add YCbCr 4:2:2 and 4:2:0 RC parameters (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 96ada7d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/display/dsc: include the rest of pre-SCR parameters (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5a1b5e1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/display/dsc: split DSC 1.2 and DSC 1.1 (pre-SCR) parameters (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 65b93ed
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/display/dsc: use flat array for rc_parameters lookup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b9b7a88
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/dsc: stop using interim structure for calculated params (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a4a225d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/dsc: move DSC tables to DRM DSC helper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c4afb4d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/dsc: move rc_buf_thresh values to common helper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 198d780
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/dsc: change DSC param tables to follow the DSC model (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a4b021a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/hdmi: C20 computed PLL frequencies (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e7287ee
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Add 16bit register/mask operators (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e43e0c3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Fix expected reg value for Thunderbolt PLL disabling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9c744c1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: tweak language in fastset pipe config compare logging (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 49d886e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: fix intel_display_irq.c include order (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8e17759
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/tc: Reset TypeC PHYs left enabled in DP-alt mode after the (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f198a63
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/tc: Call TypeC port flush_work/cleanup without modeset locks (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4f5b5a0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Factor out a helper for handling atomic modeset locks/state (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 78b5109
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/dp: Factor out intel_dp_get_active_pipes() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0328903
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/dp: Prevent link training fallback on disconnected port (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 27d546c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/dp: Convert link training error to debug message on (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a2cca75
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/dp: Add link training debug and error printing helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1b85a7c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Add support for disabling any CRTCs during HW (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f0add83
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Factor out set_encoder_for_connector() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0d63017
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Separate intel_crtc_disable_noatomic_begin/complete() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9a43328
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Update connector atomic state before crtc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e65bbbb
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Make the CRTC state consistent during sanitize-disabling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3ab5da6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Add helpers to reference/unreference a DPLL for a CRTC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 51e0a4f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/hdcp: Fill hdcp2_streamid_type and k in appropriate places (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9cba0ae
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/hdcp: Fix modeset locking issue in hdcp mst (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a11eb20
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/hdcp: Remove enforce_type0 check outside loop (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a931943
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/hdcp: add intel_atomic_state argument to hdcp_enable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3b41958
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/irq: split out display irq handling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 23d24c2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/irq: split out hotplug irq handling (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit accdfdd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/irq: convert gen8_de_irq_handler() to void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9609977
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: add i915 parameter to I915_STATE_WARN() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6df0dd7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: remove I915_STATE_WARN_ON() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 387bb30
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/crtc: replace I915_STATE_WARN_ON() with I915_STATE_WARN() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a6d4dac
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/dpll: drop a useless I915_STATE_WARN_ON() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d59113a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Add handling for MTL ccs modifiers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e5ed432
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/fourcc: define Intel Meteorlake related ccs modifiers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4aa5ffd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/bios: add helper for reading SPI (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 056ec6a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/gt: drop dependency on VLV_DISPLAY_BASE (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 08db04e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/irq: relocate gmbus and dp aux irq handlers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5787b7a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Nuke intel_bios_is_port_dp_dual_mode() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f154b1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Flip VBT DDC pin maps around (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c1b35b0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Split map_aux_ch() into per-platform arrays (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b0fe6ac
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Use REG_BIT() & co. for AUX CH registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1a09b2a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Define more PS_CTRL bits (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6f01be5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/hdcp: drop display/ prefix from include (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2c7d2d5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Fix wrong condition in bxt_set_cdclk for DG2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4ab799d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Pick one HDMI port for infoframe/audio transmission on g4x (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2603ae6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Move has_hdmi_sink out from intel_hdmi_compute_config() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3bb6952
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/dp: Rearrange check for illegal mode and comments in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5584967
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/dp: Add helper to get sink_format (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1b7935a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: Use sink_format instead of ycbcr420_output flag (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9384abd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/dp: Configure PCON for conversion of output_format to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ecd9dc1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/dp: Replace intel_dp.dfp members with the new crtc_state (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ed4cb1d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: Add new member to configure PCON color conversion (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 53402c7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Communicate display power demands to pcode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5ce821e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Use REG_BIT() & co. for pipe scaler registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d46bf4b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Define bitmasks for skl+ scaler window pos/size (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 364137c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: s/PS_COEE_INDEX_AUTO_INC/PS_COEF_INDEX_AUTO_INC/ (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3065e1a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Rename skl+ scaler binding bits (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e88a8a4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Remove dead scaler register defines (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 32166d6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Define bitmasks for ilk pfit window pos/size (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bbbea8c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display/dp: 128/132b LT requirement (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 98906b9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Enable TC ports (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f6e3c86
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Pin assignment for TypeC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e1e066f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: TypeC HPD live status query (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 09ed01b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Power up TCSS (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a0e7694
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Define mask for DDI AUX interrupts (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5863584
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Readout Thunderbolt HW state (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e3c0d14
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Enabling/disabling sequence Thunderbolt pll (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bf90af3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: For DP2.0 10G and 20G rates use MPLLA (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3ccbf74
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Add voltage swing sequence for C20 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4d0a27c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: C20 port clock calculation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0e68ef7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Dump C20 pll hw state (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3c5a2d7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: C20 HW readout (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7d0d8da
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: C20 PLL programming (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f7ac364
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: Increase AUX timeout for Type-C (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 697d5f8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/adlp+: Disable DC5/6 states for TC port DDI/AUX and for (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ddf1ea7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Skip pcode qgv restrictions for MTL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 22abb48
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Initialize dkl_phy spin lock from display code path (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b4c0669
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/psr: Sprinkle cpu_transcoder variables around (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aca1dca
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/psr: Include PSR_PERF_CNT in debugfs output on all platforms (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9185e85
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/psr: Add a FIXME for the PSR vs. AUX usage conflict (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 933197c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/psr: Define more PSR mask bits (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ded1379
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/psr: Use intel_de_rmw() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 79d4a74
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/psr: Clean up PSR register defininitions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c2dc04c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Clean up various display chicken registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 628bce4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Fix up whitespace in some display chicken registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 836b462
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Drop a useless forward declararion (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit abef2ca
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Use REG_BIT() & co. for ilk+ pfit registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1b098f0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Namespace pfit registers properly (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f73ae1a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Use REG_BIT() & co for the pre-ilk pfit registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f52b34a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Relocate skl_get_pfit_config() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 48d0835
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Relocate intel_atomic_setup_scalers() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1398bc9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Relocate VBLANK_EVASION_TIME_US (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0d25fdf
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: throw out struct intel_load_detect_pipe (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c515656
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: split out load detect to a separate file (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 67bb8c2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/wm: remove stale and unused ilk_wm_max_level() declaration (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 606af0f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Re-use ADL-P's "DC off" power well (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 67c002a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Use separate "DC off" power well for ADL-P and DG2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5a91437
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: use explicit includes for i915_reg.h and i915_irq.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9e58dbe
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Reuse <platform>_hotplug_mask() in .hpd_detection_setup() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7f39b35
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Check HPD live state during eDP probe (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 38e2173
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Introduce intel_hpd_enable_detection() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 50ccf93
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Introduce <platform>_hotplug_mask() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7e86d92
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/pps: use intel_de_rmw() for panel unlock (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 43a5f43
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: add intel_display_driver_early_probe() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6331d95
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: rename intel_display_driver_suspend/resume (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit baa39bd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: move display suspend/resume to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ca70a87
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: add intel_display_reset.[ch] (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 829bbd8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: rename intel_display_driver_* functions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5d4d226
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: move modeset probe/remove functions to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9afcefa
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: rename intel_modeset_probe_defer() -> (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 83c52ea
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: move intel_modeset_probe_defer() to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 74af2df
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: start high level display driver file (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 642a5d8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: remove intel_display_commit_duplicated_state() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 51c93ee
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Make intel_{mpllb,c10pll}_state_verify() safer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a04ccc6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Initial DDI port setup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3137522
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display/mtl: Fill port width in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4774efd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Add C10 phy programming for HDMI (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit becf1a1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl/display: Implement DisplayPort sequences (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 31f3fdb
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: MTL PICA hotplug detection (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c60a709
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Add vswing programming for C10 phys (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 90348be
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Add Support for C10 PHY message bus and pll programming (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c0172c7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Create separate reg file for PICA registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6f2e840
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Add DP rates (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1ed2917
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/debugfs: New debugfs for display clock frequencies (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 50cbcc6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Use min() instead of hand rolling it (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dedfd85
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Evade transcoder's vblank when doing seamless M/N changes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5cc75c2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Allow arbitrary refresh rates with VRR eDP panels (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0e33801
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Flag purely internal commits to not clear (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3e028b3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/vrr: Allow VRR to be toggled during fastsets (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 92957d8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/vrr: Relocate VRR enable/disable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6b6f153
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/vrr: Tell intel_crtc_update_active_timings() about VRR (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 45a4ffc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/vrr: Make delayed vblank operational in VRR mode on adl/dg2 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5ab5793
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/vrr: Eliminate redundant function arguments (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f8244ec
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Generalize planes_{enabling,disabling}() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ff1ef8b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: remove unnecessary i915_debugfs.h includes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ec1001f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Hook up csc into state checker (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1baa749
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Include the csc matrices in the crtc state dump (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 27f912a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Implement chv cgm csc readout (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5d9141b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Add hardware csc readout for ilk+ (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aa68db0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Sprinke a few sanity check WARNS during csc assignment (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit da4dd15
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Utilize crtc_state->csc on chv (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 00e0b1f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Store ilk+ csc matrices in the crtc state (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4bdb2ac
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Start using struct intel_csc_matrix for chv cgm csc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aba9f49
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Split chv_load_cgm_csc() into pieces (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9e88281
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Introduce intel_csc_matrix struct (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4856de8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/panel: simple: add support for Rocktech RK043FN48H panel (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 86e6bf2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/bridge: imx: turn imx8{qm,qxp}-ldb into single-object modules (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5e71f5b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/bridge: imx: fix mixed module-builtin object (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cd37a70
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/virtio: Wait for each dma-fence of in-fence array individually (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1efee29
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/virtio: Refactor and optimize job submission code path (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 37a930f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/meson: venc: include linux/bitfield.h (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 57a13b4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/meson: Remove unneeded semicolon (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4d924f7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/panel: Support for Starry-ili9882t TDDI MIPI-DSI panel (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 836b671
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/panel: Support for Starry-himax83102-j02 TDDI MIPI-DSI panel (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit affcbe9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/panel: khadas-ts050: update timings to achieve 60Hz refresh rate (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b39d2d6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/meson: add DSI encoder (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f599d43
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/meson: venc: add ENCL encoder setup for MIPI-DSI output (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4da3d20
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/meson: only use components with dw-hdmi (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 19696e1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/meson: fix unbind path if HDMI fails to bind (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b4597d2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/bridge: tc358762: Add reset GPIO support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ad1c659
* Thu Sep 21 2023 pjakobsson@suse.de
- accel/habanalabs: add description to several info ioctls (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e779988
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: Place Renesas drivers in a separate dir (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/0001-drm-Clear-fd-handle-callbacks-in-struct-drm_driver.patch.
- commit 58b8f81
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/fbdev-generic: Implement dedicated fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aa5b0e4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm: Use regular fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1a3b2a3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/fb-helper: Export helpers for marking damage areas (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f25c0ee
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/tegra: Use regular fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5839bc9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/omapdrm: Use regular fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 74a1685
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/fbdev-dma: Use regular fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fd9fec2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/radeon: Use regular fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 35a53c7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/gma500: Use regular fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 23666b8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/exynos: Use regular fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2d2af47
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/armada: Use regular fbdev I/O helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 92b8b6c
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: Add initializer macros for struct fb_ops (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh patches.suse/fbdev-Update-fbdev-source-file-paths.patch.
- commit 2ce308c
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: Add Kconfig options to select different fb_ops helpers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a56872e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: end support for set caching ioctl (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3e7359f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/pmu: Export counters from all tiles (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 573de38
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/pmu: Prepare for multi-tile non-engine counters (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5e2b2c9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/pmu: Add reference counting to the sampling timer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8a7637d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/pmu: Transform PMU parking code to be GT based (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f3419e6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/pmu: Skip sampling engines with no enabled counters (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b37de11
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/pmu: Support PMU for all engines (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1c15912
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/pmu: Change bitmask of enabled events to u32 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2b0f084
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Fix memory leaks in function live_nop_switch (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d3173e7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Extend Wa_16014892111 to MTL A-step (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/drm-i915-gt-Cleanup-aux-invalidation-registers.patch.
- Refresh
  patches.suse/drm-i915-gt-Support-aux-invalidation-on-all-en.patch.
- commit cbb902e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Add MTL performance tuning changes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2e27813
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: do not enable render power-gating on MTL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f6c0eee
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/guc/slpc: Disable rps_boost debugfs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ec64a3e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/guc: Dump error capture to dmesg on CTB error (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a86909c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Dump error capture to kernel log (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ae86dbf
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/hwmon: Silence UBSAN uninitialized bool variable warning (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bbff671
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/guc: Fix confused register capture list creation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8350aa7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i1915/guc: Fix probe injection CI failures after recent change (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0e41df1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/pxp: Enable PXP with MTL-GSC-CS (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5f82408
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/pxp: On MTL, KCR enabling doesn't wait on tee component (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e4b44cd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/uapi/pxp: Add a GET_PARAM for PXP (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8ba4dcc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/pxp: Add ARB session creation and cleanup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fd9b941
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/pxp: Add GSC-CS backend to send GSC fw messages (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 28c3618
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/pxp: Add MTL helpers to submit Heci-Cmd-Packet to GSC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fda3064
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/pxp: Add MTL hw-plumbing enabling for KCR operation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 020206d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/pxp: Add GSC-CS back-end resource init and cleanup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5494217
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: use pat_index instead of cache_level (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 67f502d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: preparation for using PAT index (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e538248
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Fix the wa number for Wa_22016670082 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1811f6f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Add MTL for remapping CCS FBs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f3b675a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Drop FLAT CCS check (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7711b50
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/uc: Make unexpected firmware versions an error in debug (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 689ac4e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/uc: Reject duplicate entries in firmware table (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 596451e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/uc: Enhancements to firmware table validation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f0bb450
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/guc: Print status register when waiting for GuC to load (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fa7695e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/guc: Decode another GuC load failure case (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 99953eb
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Define GuC firmware version for MTL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit baaa258
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/uc: Track patch level versions on reduced version firmware (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0313e24
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: use kernel-doc -Werror when CONFIG_DRM_I915_WERROR=y (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 55e87e0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/ttm: fix i915_ttm_to_gem() kernel-doc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 010d5a2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/scatterlist: fix kernel-doc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ff90eda
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/gem: fix function pointer member kernel-doc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fa43a8f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/vma: fix struct i915_vma_bindinfo kernel-doc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f9c7a1b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/gsc: add support for GSC proxy interrupt (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f774226
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/gsc: add initial support for GSC proxy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 08ae709
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Define GSC Proxy component interface (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ec6ebba
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/scatterlist: fix kernel-doc parameter documentation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 538c66d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/pxp: fix kernel-doc for member dev_link (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 597def3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/pmu: drop kernel-doc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9f69c23
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/active: fix kernel-doc for function parameters (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1ad5f93
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/guc: add intel_guc_state_capture member docs for (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5a9caeb
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/guc: drop lots of kernel-doc markers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cd639d8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/guc: add dbgfs_node member kernel-doc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 14b8f74
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/engine: hide preempt_hang selftest member from kernel-doc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9073a39
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/gtt: fix i915_vm_resv_put() kernel-doc parameter name (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 72fbae9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/context: fix kernel-doc parameter descriptions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5840462
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/engine: fix kernel-doc function name for (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9ab8f51
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/gem: fix i915_gem_object_lookup_rcu() kernel-doc parameter (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 99a695c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/request: drop kernel-doc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 34444d8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/error: fix i915_capture_error_state() kernel-doc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 18ac441
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/perf: fix i915_perf_ioctl_version() kernel-doc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 31594af
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/vma: document struct i915_vma_resource wakeref member (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b7de302
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/utils: drop kernel-doc from __wait_for() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f4db410
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/vma: fix kernel-doc function name for i915_vma_size() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4336bbd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/gvt: fix intel_vgpu_alloc_resource() kernel-doc parameter (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 05da320
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/guc: Fix error capture for virtual engines (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2279ca7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/guc: Capture list naming clean up (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2e01b71
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/guc: Consolidate duplicated capture list code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1268492
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/selftests: Use gt_err for GT info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8ce45ac
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/gt: Use gt_err for GT info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a690e7d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/fdinfo: Enable fdinfo for GuC backends (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e45d4b7
* Thu Sep 21 2023 pjakobsson@suse.de
- i915/pmu: Add support for total context runtime for GuC back-end (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 88fcc4e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/rc6: throw out set() wrapper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 42c1195
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/selftest: Update the SLPC selftest (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit de417ef
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Use correct huge page manager for MTL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 95c18b4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Migrate platform-dependent mock hugepage selftests to live (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8a455ff
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Implement Wa_14019141245 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b6e1580
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/hwmon: Block waiting for GuC reset to complete (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d3e2ba2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/guc: Disable PL1 power limit when loading GuC firmware (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 473cba9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/hwmon: Get mutex and rpm ref just once in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 80ef76b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Add workaround 14018778641 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 81069b1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/selftest: Record GT error for gt failure (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d6f548a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: workaround coherency issue for Media (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9c1f87d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Add PTE encode function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 20a840c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/i915_drv: Use i915 instead of dev_priv insied the file_priv (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 85645b5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/i915_drv: Use proper parameter naming in for_each_engine() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6ef7d88
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: fix mocs selftest (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d492acc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Define MOCS and PAT tables for MTL (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e652be8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Set has_llc=0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 090412c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: WA to clear RDOP clock gating (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c541b23
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Extend Wa_22011802037 to MTL A-step (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5fb7ff2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/selftests: Consider multi-gt instead of to_gt() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 084fb89
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/gem: Consider multi-gt instead of to_gt() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1194b47
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/gt: Consider multi-gt instead of to_gt() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9784ea7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Make IRQ reset and postinstall multi-gt aware (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 009d548
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/mtl: Disable stolen memory backed FB for A0 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0c3a8f2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: Implement fb_mmap callback function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fce1e5e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: Add helper func to get intel_fbdev from (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 295f0f1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915: Add a function to mmap framebuffer obj (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 348f22c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/display: Set I915_BO_ALLOC_USER for fb (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e56acd2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i915/ttm: Add I915_BO_PREALLOC (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ff7660d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/ttm: Remove redundant code in ttm_tt_init_fields (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c3f0f5e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/bridge: display-connector: handle hdmi-pwr supply (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 717826b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/bridge: display-connector: rename dp_pwr to connector_pwr (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d12f332
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/panel-edp: Convert to platform remove callback returning void (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 870aa5c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: Switch i2c drivers back to use .probe() (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/drm-bridge-fix-Wunused-const-variable-warning.patch.
- commit eabbf5f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: lcdif: Add i.MX93 LCDIF compatible string (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0e9ee4e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: lcdif: Add multiple encoders and first bridges support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1b3fd93
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: lcdif: Check consistent bus format and flags across first (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 73f4abd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: lcdif: Determine bus format and flags in ->atomic_check() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fe5ecb2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: lcdif: Drop unnecessary NULL pointer check on lcdif->bridge (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 55665bc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/stm: dsi: Use devm_platform_ioremap_resource() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1cc6b74
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/panel: simple: Add Ampire AM-800480L1TMQW-T00H (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 46ed3d8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: bridge: samsung-dsim: Support non-burst mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 476a002
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: bridge: samsung-dsim: Dynamically configure DPHY timing (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6b8b15d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: bridge: samsung-dsim: Select GENERIC_PHY_MIPI_DPHY (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 42d19e0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: bridge: samsung-dsim: Fetch pll-clock-frequency automatically (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 609ad2e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: bridge: samsung-dsim: fix blanking packet size calculation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1c499a9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Fix no-procfs build (jsc#PED-3527 jsc#PED-5475
  jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/0001-drm-Clear-fd-handle-callbacks-in-struct-drm_driver.patch.
- commit b06fb55
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: bridge: samsung-dsim: Fix i.MX8M enable flow to meet spec (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 06ae2c7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/bridge: tc358767: explicitly set readable registers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 730da03
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/doc: Relax fdinfo string constraints (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e78cf5a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm: Add memory stats to fdinfo (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5c180a7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: Add fdinfo memory stats (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1add9b1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amdgpu: Switch to fdinfo helper (jsc#PED-3527 jsc#PED-5475
  jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/0001-drm-Clear-fd-handle-callbacks-in-struct-drm_driver.patch.
- commit 5f52a01
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm: Switch to fdinfo helper (jsc#PED-3527 jsc#PED-5475
  jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/0001-drm-Clear-fd-handle-callbacks-in-struct-drm_driver.patch.
- commit 6da2893
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: Add common fdinfo helper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ec91dd8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/docs: Fix usage stats typos (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1d72c25
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: shmobile: Make DRM_SHMOBILE visible on Renesas SoC platforms (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 28d314a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: shmobile: Add missing call to drm_fbdev_generic_setup() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 093f71e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: shmobile: Switch to drm_crtc_init_with_planes() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 827b0e4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: shmobile: Add support for DRM_FORMAT_XRGB8888 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5f67e98
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: shmobile: Use %%p4cc to print fourcc codes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 58039f5
* Thu Sep 21 2023 pjakobsson@suse.de
- dma-buf/sw_sync: Replace all non-returning strlcpy with strscpy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 72d2700
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/panel: samsung-s6d7aa0: use pointer for drm_mode in panel desc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4516c6f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/bridge: dw-hdmi: Replace all non-returning strlcpy with strscpy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2562126
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/msm: Use struct fb_info.screen_buffer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f988ee7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/nouveau/acr/ga102: set variable ga102_gsps (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cdcdfa5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/nouveau: constify pointers to hwmon_channel_info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8b905d9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: bridge: samsung-dsim: Implement support for clock/data polarity (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c750127
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/sched: Rename to drm_sched_wakeup_if_can_queue() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9d2cec4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/sched: Rename to drm_sched_can_queue() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4f2eea1
* Thu Sep 21 2023 pjakobsson@suse.de
- ipu-v3: Include <linux/io.h> (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9625247
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev/matrox: Remove trailing whitespaces (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f31f266
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev/hitfb: Cast I/O offset to address (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bf54396
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/ttm: let struct ttm_device_funcs be placed in rodata (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b6b1db8
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/drm_atomic_helper.c: fix a typo (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5a5c836
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/panel: Modify innolux hj110iz panel initial code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e111d93
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/bridge: tc358768: remove unneeded semicolon (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c13dd7e
* Thu Sep 21 2023 pjakobsson@suse.de
- gpu: drm: bridge: No need to set device_driver owner (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 92c3bc4
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/panel: boe-tv101wum-nl6: Fine tune the panel power sequence (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f23d5d2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/panel: boe-tv101wum-nl6: Remove extra delay (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 80ba717
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/ssd130x: Fix include guard name (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e469fe3
* Thu Sep 21 2023 pjakobsson@suse.de
- drivers/firmware: Move sysfb_init() from device_initcall to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 52071cb
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/panel: panel-simple: Add BOE EV121WXM-N10-1850 panel support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bd9b040
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/panel: sharp-ls043t1le01: drop dummy functions and data fields (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e7e01d7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: sun4i: calculate proper DCLK rate for DSI (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 32d266b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm: sun4i: rename sun4i_dotclock to sun4i_tcon_dclk
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/drm-sun4i_tcon-use-devm_clk_get_enabled-in-sun4.patch.
- commit 5d04ac1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/connector: document enum drm_connector_tv_mode (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3d7879f
* Thu Sep 21 2023 pjakobsson@suse.de
- Documentation: vkms: clarify devres managed reference cleanup (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7b6c593
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/fb-helper: Use fb_{cfb,sys}_{read, write}() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fd8719c
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: Move I/O read and write code into helper functions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c84f471
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: Validate info->screen_{base, buffer} in fb_ops implementations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8f8217d
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: Don't re-validate info->state in fb_ops implementations (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 87a5316
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: Use screen_buffer in fb_sys_{read,write}() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3587c49
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: Return number of bytes read or written (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b49e207
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev/xen-fbfront: Use struct fb_info.screen_buffer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f118ebd
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev/vfb: Use struct fb_info.screen_buffer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8dcc6e8
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev/udlfb: Use struct fb_info.screen_buffer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a5231e3
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev/smscufx: Use struct fb_info.screen_buffer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2944797
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev/ps3fb: Use struct fb_info.screen_buffer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 392c852
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev/metronomefb: Use struct fb_info.screen_buffer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 66c9665
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev/hecubafb: Use struct fb_info.screen_buffer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fad06f9
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev/broadsheetfb: Use struct fb_info.screen_buffer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5fe3ed1
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev/au1200fb: Use struct fb_info.screen_buffer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1f2d602
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev/arcfb: Use struct fb_info.screen_buffer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2cb6876
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/vkms: drop "Rotation" TODO (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cda39d5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/vkms: add rotate-270 property (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1c13557
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/vkms: add rotate-90 property (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6f4334f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/vkms: add reflect-y and rotate-180 property (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7e9047d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/vkms: add rotate-0 and reflect-x property (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 781832d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/bridge: lt9611: Do not generate HFP/HBP/HSA and EOT packet (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4bddd95
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/bridge: lt9211: Do not generate HFP/HBP/HSA and EOT packet (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 664af0b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/bridge: tc358768: remove unused variable (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6aa97a0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/udl: delete dead code (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 26c56f9
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/scheduler: mark jobs without fence as canceled (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 025e471
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/rockchip: cdn-dp: call drm_connector_update_edid_property() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1109dba
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/sti/sti_hdmi: convert to using is_hdmi from display info (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5c6617f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/sysfs: Link DRM connectors to corresponding Type-C connectors (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5c452fe
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/sysfs: Expose DRM connector id in each connector sysfs (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2a27dbf
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/uapi: Document CTM matrix better (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e7882f6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/meson: set variables meson_hdmi_* storage-class-specifier to (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e29f6d7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/panel: st7703: Add Anbernic RG353V-V2 Panel Support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eec280f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/panel: st7703: Rename CMD_UNKNOWN_C6 to CMD_SETECO (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4f6bf41
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/doc/rfc: Introduce the merge plan for the Xe driver. (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f3945ed
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/vkms: drop full alpha blending TODO (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5e3bf19
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/vkms: allow full alpha blending on all planes (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit de7268d
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/vc4: hdmi: Add BT.2020 Support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b30a6b3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/vc4: hdmi: Add BT.601 Support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 525f0ea
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/vc4: hdmi: Add a function to retrieve the CSC matrix (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 193dde6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/vc4: hdmi: Rework the CSC matrices organization (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9f32745
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/vc4: hdmi: Swap CSC matrix channels for YUV444 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c8b6c46
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/vc4: hdmi: Rename full range helper (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 118d5f5
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/vc4: hdmi: Add Broadcast RGB property to allow override of RGB (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 456e9a7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/vc4: hdmi: Update all the planes if the TV margins are changed (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 01a707f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/vc4: Switch to container_of_const (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cdd81bd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/test: Add test cases for drm_rect_rotate_inv() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fad58c6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/tests: Add test cases for drm_rect_rotate() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2f8240f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/tests: Add test cases for drm_rect_calc_vscale() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b637bd6
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/tests: Add test cases for drm_rect_calc_hscale() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c5319ef
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/tests: Add test cases for drm_rect_intersect() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d1adc10
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/scheduler: add drm_sched_entity_error and use rcu
  for last_scheduled (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068
  jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/0007-drm-sched-Call-drm_sched_fence_set_parent-from-drm_s.patch.
- commit dd3c5f3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/scheduler: properly forward fence errors (jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Refresh
  patches.suse/0007-drm-sched-Call-drm_sched_fence_set_parent-from-drm_s.patch.
- commit a75f31e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/tve200: Use devm_platform_ioremap_resource() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cb64b5f
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/sti: Drop of_gpio header (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 85e980e
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/bridge: anx7625: Drop of_gpio header (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dc0c8c1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/display: Add missing OLED Vesa brightnesses definitions (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bf0d9eb
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/panel: simple: Add InnoLux G070ACE-L01 (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 354afc2
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/armada: Implement fbdev emulation as in-kernel client
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh
  patches.suse/0001-drm-Clear-fd-handle-callbacks-in-struct-drm_driver.patch.
- commit 05c1079
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/armada: Initialize fbdev DRM client (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cf4cd4b
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/armada: Hide fbdev support behind config option (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f85ca5a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/armada: Include <linux/of.h> (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8541bb1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/bridge: ti-sn65dsi86: Implement wait_hpd_asserted (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 387412c
* Thu Sep 21 2023 pjakobsson@suse.de
- arch/parisc: Implement fb_is_primary_device() under arch/parisc (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a419575
* Thu Sep 21 2023 pjakobsson@suse.de
- video: Move HP PARISC STI core code to shared location (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4b1b68f
* Thu Sep 21 2023 pjakobsson@suse.de
- video: Remove trailing whitespaces (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8c82969
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/gem: Check for valid formats (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9f1d3e7
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/nouveau/therm: Move an assignment statement behind a null pointer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 47c839c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/nouveau/pci: Move an expression into a function call parameter in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f862dc1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/nouveau/pci: Move a variable assignment behind condition checks (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 187b38a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/nouveau/clk: Move a variable assignment behind a null pointer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 55d57d0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/nouveau/bios/power_budget: Move an expression into a macro call (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0ad6247
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/nouveau/debugfs: Replace five seq_printf() calls by seq_puts() in (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a302c51
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/nouveau/debugfs: Use seq_putc() in nouveau_debugfs_pstate_get() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ac93009
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/nouveau/debugfs: Move a variable assignment behind a null pointer (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ebc2d98
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/nouveau/debugfs: Move an expression into a function call (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8c3e94a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/panel: nt36523: Add Lenovo J606F panel (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a6d0323
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/panel: nt36523: Get orientation from OF (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 790dd39
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/panel: nt36523: Add DCS backlight support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 65b5998
* Thu Sep 21 2023 pjakobsson@suse.de
- dma-buf/dma-resv.c: fix a typo (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8ff51f2
* Thu Sep 21 2023 pjakobsson@suse.de
- video/aperture: Provide a VGA helper for gma500 and internal use (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a26ebe6
* Thu Sep 21 2023 pjakobsson@suse.de
- video/aperture: Only remove sysfb on the default vga pci device (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a2ea954
* Thu Sep 21 2023 pjakobsson@suse.de
- video/aperture: Drop primary argument (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 056a332
* Thu Sep 21 2023 pjakobsson@suse.de
- video/aperture: Move vga handling to pci function (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit caf8b5a
* Thu Sep 21 2023 pjakobsson@suse.de
- video/aperture: Only kick vgacon when the pdev is decoding vga (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 61c43b3
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/aperture: Remove primary argument (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 992f35c
* Thu Sep 21 2023 pjakobsson@suse.de
- video/aperture: use generic code to figure out the vga default device (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8630e9c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/gma500: Use drm_aperture_remove_conflicting_pci_framebuffers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 24aa1bc
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/bridge: fsl-ldb: Add i.MX6SX support (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit faeb2af
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/vkms: Use drmm_mode_config_init() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a64fe7c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/vkms: Use drmm_crtc_init_with_planes() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 65bfea1
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: sh7760fb: Fix -Wimplicit-fallthrough warnings (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a098dd2
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: sh_mobile_lcdcfb: Fix ARGB32 overlay format typo (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 11263d7
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: hitfb: Use NULL for pointers (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 95edbfa
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: hitfb: Fix integer-to-pointer cast (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c4b7be6
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev/media: Use GPIO descriptors for VIA GPIO (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 386fed0
* Thu Sep 21 2023 pjakobsson@suse.de
- video/hdmi: Reorder fields in 'struct hdmi_avi_infoframe' (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8784f37
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: broadsheetfb: Add MODULE_FIRMWARE macro (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c9c2643
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: metronomefb: Add MODULE_FIRMWARE macro (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0b35350
* Thu Sep 21 2023 pjakobsson@suse.de
- fbdev: hitfb: Declare hitfb_blank() as static (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4842140
* Thu Sep 21 2023 pjakobsson@suse.de
- mm/gup: remove unused vmas parameter from get_user_pages() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 38d973a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/i2c: tda998x: Replace all non-returning strlcpy with strscpy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f411aa0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/sun4i: hdmi: Replace all non-returning strlcpy with strscpy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7531359
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/mediatek: Replace all non-returning strlcpy with strscpy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c87ee96
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/rockchip: Replace all non-returning strlcpy with strscpy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ee319cd
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/display/dp_mst: Replace all non-returning strlcpy with strscpy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 577e43a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/amd/pm: Replace all non-returning strlcpy with strscpy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f64afa0
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/radeon: Replace all non-returning strlcpy with strscpy (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1e0046a
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/sched: Call drm_sched_fence_set_parent() from (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9e8e20c
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/nouveau/kms/nv50-: Fix drm_dp_remove_payload() invocation (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7844614
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/ttm: fix warning that we shouldn't mix && and || (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1df97b1
* Thu Sep 21 2023 pjakobsson@suse.de
- drm/sched: Make sure we wait for all dependencies in kill_jobs_cb() (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cc6af70
* Thu Sep 21 2023 pjakobsson@suse.de
- Delete
  patches.suse/drm-i915-Fix-HPD-polling-reenabling-the-output.patch.
- commit f3cb1d6
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-Add-an-HPD-poll-helper-to-reschedule-the-p.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cdc81c5
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-dgfx-Enable-d3cold-at-s2idle.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 50a8fb3
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-vmwgfx-Fix-possible-invalid-drm-gem-put-ca.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bffabb2
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-vmwgfx-Fix-shader-stage-validation.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 36aad52
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/dma-buf-sw_sync-Avoid-recursive-lock-during-fe.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ab6d67f
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-display-dp-Fix-the-DP-DSC-Receiver-cap-siz.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 56e9aa8
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-panfrost-Skip-speed-binning-on-EOPNOTSUPP.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ec0c6a3
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/fbdev-goldfishfb-Do-not-check-0-for-platform_get_irq.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a33cd7
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/fbdev-mmp-fix-value-check-in-mmphw_probe.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit dd77dfe
* Thu Sep 21 2023 pjakobsson@suse.de
- Update patches.suse/drm-qxl-fix-UAF-on-handle-creation.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2797eb3
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/Revert-Revert-drm-amdgpu-display-change-pipe-p.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c739d4e
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-flush-any-delayed-gfxoff-on-suspend-en.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2af2128
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-skip-fence-GFX-interrupts-disable-e.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c0f4180
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-pm-Fix-temperature-unit-of-SMU-v13.0.6.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit b980d31
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-pm-fix-throttle_status-for-other-th.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9daddf7
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-panel-simple-Fix-AUO-G121EAN01-panel-timin.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b9050b5
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-sdvo-fix-panel_type-initialization.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5255a0b
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-guc-slpc-Restore-efficient-freq-earli.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b5bf63a
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-fix-possible-UAF-in-amdgpu_cs_pass1.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a1f540
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-check-attr-flag-before-set-cur.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e7592e3
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-pm-correct-the-pcie-width-for-smu-13.0.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 6d9172f
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Don-t-show-stack-trace-for-mis.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8cc1264
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Match-against-exact-bootloader-status.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a84eb74
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-pm-skip-the-RLC-stop-when-S0i3-suspend.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a4a8a14
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-shmem-helper-Reset-vma-vm_ops-before-calli.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5c673f7
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-rockchip-Don-t-spam-logs-in-atomic-check.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3d977b8
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-nouveau-disp-Revert-a-NULL-check-inside-no.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5fabbc5
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-nouveau-remove-unused-tu102_gr_load-functi.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4285a3f
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-nouveau-nvkm-dp-Add-workaround-to-fix-DP-1.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b0ebb96
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-nouveau-gr-enable-memory-loads-on-helper-i.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 21148bc
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-it6505-Check-power-state-with-it650.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d0c44a2
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Fix-premature-release-of-request-s-re.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 50670e4
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-gt-Support-aux-invalidation-on-all-en.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 457739a
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-gt-Poll-aux-invalidation-register-bit.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 79e4248
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-gt-Enable-the-CCS_FLUSH-bit-in-the-pi.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5e60d63
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-gt-Rename-flags-with-bit_group_X-acco.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 26058a1
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-gt-Ensure-memory-quiesced-before-inva.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8e45dda
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Add-the-gen12_needs_ccs_aux_inv-helpe.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bf5524e
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-gt-Cleanup-aux-invalidation-registers.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 72abda9
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-imx-ipuv3-Fix-front-porch-adjustment-upon-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4dcb263
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-ttm-check-null-pointer-before-accessing-wh.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 60e8590
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/locking-rtmutex-Fix-task-pi_waiters-integrity.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8287945
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-Disallow-submit-with-fence-id-0.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 77bc47a
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-Fix-hw_fence-error-path-cleanup.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0a8bda2
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-Fix-IS_ERR_OR_NULL-vs-NULL-check-in-a5x.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0631e11
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-adreno-Fix-snapshot-BINDLESS_DATA-size.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 86c35ec
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dsi-Drop-unused-regulators-from-QCM2290.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 641a895
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dpu-drop-enum-dpu_core_perf_data_bus_id.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 80c4c4b
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dpu-add-missing-flush-and-fetch-bits-fo.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit a536365
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-mdss-correct-UBWC-programming-for-SM855.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b3dcf4e
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Unlock-on-error-path-in-dm_hand.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 03321bf
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Exit-idle-optimizations-before-attem.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b3b1c47
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Guard-DCN31-PHYD32CLK-logic-against-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7dc03e7
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-smu-use-AverageGfxclkFrequency-to-replace-pr.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9904733
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-Fix-an-error-handling-mistake-in-psp_sw.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 772c0d3
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Fix-an-error-handling-path-in-igt_writ.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a81621a
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-dpt-Use-shmem-for-dpt-objects.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cd87620
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/fbdev-au1200fb-Fix-missing-IRQ-check-in-au1200f.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ff9f3d2
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/fbdev-imxfb-Removed-unneeded-release_mem_region.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4fc5332
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/fbdev-imxfb-warn-about-invalid-left-right-margi.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5a07223
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-atomic-Fix-potential-use-after-free-in-nonb.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 91bc00d
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Keep-PHY-active-for-DP-displays.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1fc74ae
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Prevent-vtotal-from-being-set-t.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d407717
* Thu Sep 21 2023 osalvador@suse.de
- mm/various: give up if pte_offset_map[_lock]() fails (jsc#5859).
- commit a2c5634
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Disable-MPC-split-by-default-on.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3d50689
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-check-TG-is-non-null-before-che.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4c43875
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Add-polling-method-to-handle-MS.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 349ce9d
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Clean-up-errors-warnings-in-amd.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bea04be
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-pm-make-mclk-consistent-for-smu-13.0.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b21505d
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-pm-make-gfxclock-consistent-for-sien.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3e7fbd4
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-only-accept-async-flips-for-fas.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1458a53
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-vkms-relax-timer-deactivation-by-hrt.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6176bca
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-perf-add-sentinel-to-xehp_oa_b_counter.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7350278
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-nouveau-kms-nv50-init-hpd_irq_lock-for-PIOR.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cad48b2
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-nouveau-disp-PIOR-DP-uses-GPIO-for-HPD-not-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d7aae87
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-nouveau-i2c-fix-number-of-aux-event-slots.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 66cddf5
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/dma-buf-dma-resv-Stop-leaking-on-krealloc-failu.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 03ede3f
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-client-Fix-memory-leak-in-drm_client_modese.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9577618
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-client-Fix-memory-leak-in-drm_client_target.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6fd85ba
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-Align-SMU11-SMU_MSG_OverridePcieParamet.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eb7252a
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-Move-helper-for-dynamic-speed-switch-ch.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a188a98
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-pm-conditionally-disable-pcie-lane-spee.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit cba8499
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-pm-share-the-code-around-SMU13-pcie-par.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 28d8f1a
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-avoid-restore-process-run-into-dead-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1f19763
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-pm-fix-smu-i2c-data-read-risk.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c131176
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Fix-one-wrong-caching-mode-enum-usage.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1708dda
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Don-t-preserve-dpll_hw_state-for-slave.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7bbcfc9
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-nouveau-bring-back-blit-subchannel-for-pre-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aac8434
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-nouveau-acr-Abort-loading-ACR-if-no-firmwar.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 849229a
* Thu Sep 21 2023 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-disp-g94-enable-HDMI.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 65f2b9c
* Thu Sep 21 2023 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-disp-fix-HDMI-on-gt215.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4db279e
* Thu Sep 21 2023 pjakobsson@suse.de
- Delete
  patches.suse/drm-client-Send-hotplug-event-after-registering.patch.
- commit 85c763a
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-psr-Fix-BDW-PSR-AUX-CH-data-register-o.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1445992
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Fix-potential-fence-use-after-free-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5d84df9
* Thu Sep 21 2023 pjakobsson@suse.de
- Delete
  patches.suse/drm-amd-pm-avoid-unintentional-shutdown-due-to.patch.
- commit 905061d
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-pm-expose-swctf-threshold-setting-for-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5ac5695
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Add-monitor-specific-edid-quirk.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit f7805d6
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Remove-Phantom-Pipe-Check-When-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 15493e2
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/Revert-drm-amd-display-edp-do-not-add-non-edid-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 98a38c2
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/Revert-drm-amd-Disable-PSR-SU-on-Parade-0803-TC.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 82df139
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Set-minimum-requirement-for-usi-cd2e31a.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c935476
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Set-minimum-requirement-for-usi.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 5807417
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Correct-DMUB_FW_VERSION-macro.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f25cc5e
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/Partially-revert-drm-amd-display-Fix-possible-underf.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1d28976
* Thu Sep 21 2023 pjakobsson@suse.de
- Delete
  patches.suse/Revert-drm-amd-display-Move-DCN314-DOMAIN-power.patch.
- commit ff988b2
* Thu Sep 21 2023 pjakobsson@suse.de
- Delete
  patches.suse/drm-amd-display-disable-RCO-for-DCN314.patch.
- commit 87f5650
* Thu Sep 21 2023 nik.borisov@suse.com
- x86/tdx: Wrap exit reason with hcall_func() (jsc#PED-6469).
- commit a8e9cdd
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-guc-slpc-Apply-min-softlimit-correctly.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 90c2cd0
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-psr-Use-hw.adjusted-mode-when-calculat.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 8f8534f
* Thu Sep 21 2023 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-correct-MERGE_3D-length.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit af5aa2a
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dpu-fix-sc7280-and-sc7180-PINGPONG-done.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit f07eedc
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dp-Free-resources-after-unregistering-t.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e901605
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dp-Drop-aux-devices-together-with-DP-co.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a14f578
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-provide-fb_dirty-implemenation.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d354885
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dsi-Remove-incorrect-references-to-slic.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 28af848
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dpu-Fix-slice_last_group_size-calculati.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 85b4937
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dpu-do-not-enable-color-management-if-D.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit da273fb
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-a5xx-really-check-for-A510-in-a5xx_gpu_.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9ff19db
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-a6xx-don-t-set-IO_PGTABLE_QUIRK_ARM_OUT.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 29a2955
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-adreno-fix-sparse-warnings-in-a6xx-code.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5ef9699
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dsi-don-t-allow-enabling-14nm-VCO-with-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit fd67414
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dpu-clean-up-dpu_kms_get_clk_rate-returns.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5f364a5
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dpu-always-clear-every-individual-pendi.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2ca52c8
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dpu-set-DSC-flush-bit-correctly-at-MDP-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1ed39f3
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dpu-Set-DPU_DATA_HCTL_EN-for-in-INTF_SC.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1ce1fc4
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dpu-Disable-pingpong-TE-on-DPU-5.0.0-an.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 35225aa
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dpu-Move-autorefresh-disable-from-CMD-e.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6dbd0c1
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dpu-Drop-unused-poll_timeout_wr_ptr-PIN.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aac0b58
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dpu-Use-V4.0-PCC-DSPP-sub-block-in-SC7-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a314cf6
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dpu-drop-the-regdma-configuration.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 783597c
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dpu-fix-cursor-block-register-bit-offse.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1edd13a
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-msm-dpu-enable-DSPP_2-3-for-LM_2-3-on-sm845.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a6a463a
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-dp_mst-Clear-MSG_RDY-flag-before-sending-ne.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3739ebb
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Fix-usage-of-UMC-fill-record-in-RAS.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c17fefe
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Fix-memcpy-in-sienna_cichlid_append_.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3af48e9
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Enable-dcn314-DPP-RCO.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f8d7a0b
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Skip-DPP-DTO-update-if-root-cl.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ca8c0e3
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-unmap-and-remove-csa_va-properly.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b590229
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-fix-dcn315-single-stream-crb-al.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 52b5e05
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/amdgpu-validate-offset_in_bo-of-drm_amdgpu_gem_.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c3ce66e
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-fix-seamless-odm-transitions.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 095f88b
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-keep-irq-count-in-amdgpu_irq_disabl.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2b71b8d
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-radeon-fix-possible-division-by-zero-errors.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 39a6e3a
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Update-correct-DCN314-register-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 337b904
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Apply-60us-prefetch-for-DCFCLK.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4e16e5e
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Fix-artifacting-on-eDP-panels-w.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 426883d
* Thu Sep 21 2023 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Validate-VM-ioctl-flags.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4a41100
* Thu Sep 21 2023 pjakobsson@suse.de
- Delete
  patches.suse/drm-amdgpu-Use-apt-name-for-FW-reserved-region.patch.
- commit d0f6d22
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Remove-v_startup-workaround-fo.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7c0293f
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Fix-possible-underflow-for-disp.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4dd1558
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amdkfd-Fix-potential-deallocation-of-previo.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit eac6c83
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-install-stub-fence-into-potential-u.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 64c8f82
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Fix-a-test-dml32_rq_dlg_get_rq_.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4857100
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Fix-a-test-CalculatePrefetchSch.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d8b9692
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/Revert-drm-amd-display-disable-SubVP-DRR-to-pr.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c0d9909
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Keep-disable-aux-i-delay-as-0.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6e074c1
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-update-extended-blank-for-dcn31.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d9676d4
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Fix-in-secure-display-context-c.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6440688
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-add-pixel-rate-based-CRB-alloca.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b0f6777
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Limit-DCN32-8-channel-or-less-p.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 1cc99ad
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Convert-Delaying-Aux-I-Disable-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 041b55d
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-fix-memory-leak-in-mes-self-test.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0bcc196
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-Fix-integer-overflow-in-amdgpu_cs_p.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 713b127
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-radeon-Fix-integer-overflow-in-radeon_cs_pa.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bc7e31b
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Explicitly-specify-update-type-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6eed812
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amdgpu-fix-calltrace-warning-in-amddrm_bud.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 22cce5a
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/radeon-avoid-double-free-in-ci_dpm_init.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 55327b2
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Update-DTBCLK-for-DCN32.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4f49020
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-fix-is_timing_changed-prototype.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 47aa280
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Add-logging-for-display-MALL-re.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit afa79e0
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Add-FAMS-validation-before-tryi.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5d2148e
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-amd-display-Unconditionally-print-when-DP-s.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e4b91fa
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-gt-Add-workaround-14016712196.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b8e13b8
* Thu Sep 21 2023 pjakobsson@suse.de
- Delete
  patches.suse/drm-i915-Convert-INTEL_INFO-display-to-a-pointe.patch.
- Delete
  patches.suse/drm-i915-Fix-error-handling-if-driver-creation.patch.
- Delete
  patches.suse/drm-i915-No-10bit-gamma-on-desktop-gen3-parts.patch.
- Delete
  patches.suse/drm-i915-display-Handle-GMD_ID-identification-.patch.
- Delete
  patches.suse/drm-i915-display-Make-display-responsible-for-p.patch.
- Delete
  patches.suse/drm-i915-display-Move-display-runtime-info-to-d.patch.
- Delete
  patches.suse/drm-i915-fix-display-probe-for-IVB-Q-and-IVB-D.patch.
- commit 083a721
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-display-Move-display-device-info-to-he.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e3d0397
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-hide-mkwrite_device_info-better.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b703d3a
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-Fix-limited-range-csc-matrix.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aa8d734
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-rcar-du-remove-R-Car-H3-ES1.-workarounds.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 05a7c9c
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-i915-guc-slpc-Provide-sysfs-for-efficient-f.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 328ead6
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-stm-ltdc-fix-late-dereference-check.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9a3fc4f
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-panel-simple-fix-active-size-for-Ampire-AM-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7c7d1ed
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-samsung-dsim-Fix-PMS-Calculator-on-i.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 367392a
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-ti-sn65dsi83-Fix-enable-disable-flow.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7df0588
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-anx7625-Prevent-endless-probe-loop.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 09277d6
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-nouveau-dispnv50-fix-missing-prototypes-war.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2739fa2
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-tc358767-Switch-to-devm-MIPI-DSI-hel.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2e12456
* Thu Sep 21 2023 pjakobsson@suse.de
- Update patches.suse/drm-vkms-Fix-RGB565-pixel-conversion.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f09d026
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-Add-fixed-point-helper-to-get-rounded-integ.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ff8912b
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-panel-sharp-ls043t1le01-adjust-mode-setting.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit bd2111f
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-sun4i_tcon-use-devm_clk_get_enabled-in-sun4.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 09f6b76
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-vram-helper-fix-function-names-in-vram-help.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit aa79077
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-tc358768-fix-THS_TRAILCNT-computatio.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c2dd507
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-tc358768-fix-TXTAGOCNT-computation.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 28fef06
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-tc358768-fix-THS_ZEROCNT-computation.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit b7ef295
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-tc358768-fix-TCLK_TRAILCNT-computati.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ce49b2c
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-tc358768-fix-TCLK_ZEROCNT-computatio.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e37954f
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-tc358768-fix-PLL-target-frequency.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit db4466a
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-tc358768-fix-PLL-parameters-computat.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 7272988
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-tc358768-always-enable-HS-video-mode.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6c954c6
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-rockchip-vop-Leave-vblank-enabled-in-self-r.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0bdff72
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-atomic-Allow-vblank-enabled-self-refresh-di.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit ba51667
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-ti-sn65dsi83-Fix-enable-error-path.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9bb47cf
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-it6505-Move-a-variable-assignment-be.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 9b8de80
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-tc358768-Add-atomic_get_input_bus_fm.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 0cef76b
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-vkms-isolate-pixel-conversion-functionality.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3d35ea4
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-scheduler-set-entity-to-NULL-in-drm_sched_.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit f5fdba7
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-imx-lcdc-fix-a-NULL-vs-IS_ERR-bug-in-probe.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit c89afa8
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/fbdev-fix-potential-OOB-read-in-fast_imageblit.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 988a714
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/fbdev-omapfb-lcd_mipid-Fix-an-error-handling-pa.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 5d69680
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/Input-ads7846-Convert-to-use-software-nodes.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e2c8ae5
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-ttm-never-consider-pinned-BOs-for-eviction-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit baec41f
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-fbdev-dma-Fix-documented-default-preferred_.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 2d8bd18
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/dma-buf-fix-an-error-pointer-vs-NULL-bug.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit e03ea41
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/dma-buf-keep-the-signaling-time-of-merged-fence.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 4aa1ebc
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-panel-simple-Add-Powertip-PH800480T013-drm_.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit d9195ac
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-ttm-Don-t-leak-a-resource-on-swapout-move-e.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit db4360d
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-ttm-Don-t-leak-a-resource-on-eviction-error.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a36557e
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-ti-sn65dsi86-Fix-auxiliary-bus-lifet.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 40cd161
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-ttm-fix-bulk_move-corruption-when-adding-a-.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 3eff7b1
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-bridge-dw_hdmi-fix-connector-access-for-scd.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit a3f95b4
* Thu Sep 21 2023 pjakobsson@suse.de
- Update
  patches.suse/drm-panel-simple-Add-connector_type-for-innolux.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477
  jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 6f78932
* Thu Sep 21 2023 tiwai@suse.de
- media: via: Use correct dependency for camera sensor drivers
  (git-fixes).
- media: v4l: Use correct dependency for camera sensor drivers
  (git-fixes).
- commit 0d8a265
* Thu Sep 21 2023 tiwai@suse.de
- Update config files: CONFIG_VIDEO_CAMERA_SENSOR=y
- commit 4008da7
* Thu Sep 21 2023 tiwai@suse.de
- media: uvcvideo: Fix OOB read (git-fixes).
- spi: zynqmp-gqspi: fix clock imbalance on probe failure
  (git-fixes).
- media: ipu-bridge: Do not use on stack memory for
  software_node.name field (git-fixes).
- media: ipu-bridge: Fix null pointer deref on SSDB/PLD parsing
  warnings (git-fixes).
- media: i2c: Add a camera sensor top level menu (git-fixes).
- commit f626750
* Wed Sep 20 2023 krisman@suse.de
- io_uring/net: fix iter retargeting for selected buf (git-fixes).
- commit e964e17
* Wed Sep 20 2023 krisman@suse.de
- io_uring: fix unprotected iopoll overflow (bsc#1215211).
- io_uring: break out of iowq iopoll on teardown (bsc#1215211).
- io_uring: add a sysctl to disable io_uring system-wide
  (bsc#1215211).
- io_uring/fdinfo: only print ->sq_array[] if it's there
  (bsc#1215211).
- io_uring: Don't set affinity on a dying sqpoll thread
  (bsc#1215211).
- io_uring: move iopoll ctx fields around (bsc#1215211).
- io_uring: move multishot cqe cache in ctx (bsc#1215211).
- io_uring: separate task_work/waiting cache line (bsc#1215211).
- io_uring: banish non-hot data to end of io_ring_ctx
  (bsc#1215211).
- io_uring: move non aligned field to the end (bsc#1215211).
- io_uring: add option to remove SQ indirection (bsc#1215211).
- io_uring: compact SQ/CQ heads/tails (bsc#1215211).
- io_uring: force inline io_fill_cqe_req (bsc#1215211).
- io_uring: merge iopoll and normal completion paths
  (bsc#1215211).
- io_uring: reorder cqring_flush and wakeups (bsc#1215211).
- io_uring: optimise extra io_get_cqe null check (bsc#1215211).
- io_uring: refactor __io_get_cqe() (bsc#1215211).
- io_uring: simplify big_cqe handling (bsc#1215211).
- io_uring: cqe init hardening (bsc#1215211).
- io_uring: improve cqe !tracing hot path (bsc#1215211).
- io_uring/sqpoll: fix io-wq affinity when IORING_SETUP_SQPOLL
  is used (bsc#1215211).
- io_uring: stop calling free_compound_page() (bsc#1215211).
- io_uring: rename kiocb_end_write() local helper (bsc#1215211).
- commit f091844
* Wed Sep 20 2023 krisman@suse.de
- io_uring: simplify io_run_task_work_sig return (bsc#1215211).
- io_uring/rsrc: keep one global dummy_ubuf (bsc#1215211).
- io_uring: never overflow io_aux_cqe (bsc#1215211).
- io_uring: remove return from io_req_cqe_overflow()
  (bsc#1215211).
- io_uring: open code io_fill_cqe_req() (bsc#1215211).
- commit 7948073
* Wed Sep 20 2023 krisman@suse.de
- io_uring/net: don't overflow multishot recv (bsc#1215211).
- io_uring/net: don't overflow multishot accept (bsc#1215211).
- io_uring/io-wq: don't gate worker wake up success on
  wake_up_process() (bsc#1215211).
- io_uring/io-wq: reduce frequency of acct->lock acquisitions
  (bsc#1215211).
- io_uring/io-wq: don't grab wq->lock for worker activation
  (bsc#1215211).
- io_uring: remove unnecessary forward declaration (bsc#1215211).
- commit 5c535c3
* Wed Sep 20 2023 mwilck@suse.com
- scsi: smartpqi: Change driver version to 2.1.24-046
  (bsc#1211732).
- scsi: smartpqi: Enhance error messages (bsc#1211732).
- scsi: smartpqi: Enhance controller offline notification
  (bsc#1211732).
- scsi: smartpqi: Enhance shutdown notification (bsc#1211732).
- scsi: smartpqi: Simplify lun_number assignment (bsc#1211732).
- scsi: smartpqi: Rename pciinfo to pci_info (bsc#1211732).
- scsi: smartpqi: Rename MACRO to clarify purpose (bsc#1211732).
- scsi: smartpqi: Add abort handler (bsc#1211732).
- commit 5218813
* Wed Sep 20 2023 mwilck@suse.com
- scsi: smartpqi: Replace one-element arrays with flexible-array
  members (bsc#1211732).
- commit eb9bb15
* Wed Sep 20 2023 mwilck@suse.com
- scsi: smartpqi: Replace all non-returning strlcpy() with
  strscpy() (bsc#1211732).
- scsi: smartpqi: Update version to 2.1.22-040 (bsc#1211732).
- scsi: smartpqi: Update copyright to 2023 (bsc#1211732).
- scsi: smartpqi: Add sysfs entry for NUMA node in
  /sys/block/sdX/device (bsc#1211732).
- scsi: smartpqi: Stop sending driver-initiated TURs
  (bsc#1211732).
- scsi: smartpqi: Fix byte aligned writew for ARM servers
  (bsc#1211732).
- scsi: smartpqi: Add support for RAID NCQ priority (bsc#1211732).
- scsi: smartpqi: Validate block layer host tag (bsc#1211732).
- scsi: smartpqi: Remove contention for raid_bypass_cnt
  (bsc#1211732).
- scsi: smartpqi: Fix rare SAS transport memory leak
  (bsc#1211732).
- scsi: smartpqi: Remove NULL pointer check (bsc#1211732).
- scsi: smartpqi: Add new controller PCI IDs (bsc#1211732).
- scsi: smartpqi: Map full length of PCI BAR 0 (bsc#1211732).
- commit df23c56
* Wed Sep 20 2023 mfranc@suse.cz
- s390/boot: account Real Memory Copy and Lowcore areas (git-fixes
  bsc#1215530).
- commit dca0063
* Wed Sep 20 2023 mfranc@suse.cz
- s390/mm: define Real Memory Copy size and mask macros (git-fixes
  bsc#1215529).
- commit d6f6439
* Wed Sep 20 2023 mfranc@suse.cz
- s390/boot: cleanup number of page table levels setup (git-fixes
  bsc#1215528).
- commit 2422def
* Wed Sep 20 2023 msuchanek@suse.de
- kernel-binary: python3 is needed for build
  At least scripts/bpf_helpers_doc.py requires python3 since Linux 4.18
  Other simimlar scripts may exist.
- commit c882efa
* Wed Sep 20 2023 osalvador@suse.de
- Update references tag for jsc#5859
  Updated:
  patches.suse/mm-enable-page-walking-API-to-lock-vmas-during.patch
  patches.suse/mm-memory-failure-avoid-false-hwpoison-page-ma.patch
  patches.suse/mm-memory-failure-fix-hardware-poison-check-in-.patch
  patches.suse/mm-memory-failure-fix-potential-unexpected-ret.patch
  patches.suse/mm-memory-failure-fix-unexpected-return-value-.patch
  patches.suse/mm-memory-failure-move-sysctl-register-in-memory_failure_init.patch
  patches.suse/mm-page_alloc-move-mirrored_kernelcore-into-mm_init.c.patch
- commit 01f8e06
* Wed Sep 20 2023 mgorman@suse.de
- sched/fair: Fix SMT4 group_smt_balance handling (bsc#1212887
  (Scheduler functional and performance backports)).
- sched/fair: Optimize should_we_balance() for large SMT systems
  (bsc#1212887 (Scheduler functional and performance backports)).
- commit 4b59090
* Wed Sep 20 2023 mkubecek@suse.cz
- Update
  patches.suse/af_unix-Fix-null-ptr-deref-in-unix_stream_send.patch
  references (add CVE-2023-4622 bsc#1215117).
- commit d305321
* Wed Sep 20 2023 mkubecek@suse.cz
- net/sched: sch_hfsc: Ensure inner classes have fsc curve
  (CVE-2023-4623 bsc#1215115).
- commit 9bbd8cc
* Tue Sep 19 2023 tiwai@suse.de
- supported.conf: add snd-ps-sdw-dma
- commit 5316338
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: soc-core.c: add index on snd_soc_of_get_dai_name()
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- Refresh patches.suse/ASoC-fsl-use-snd_soc_-of_-get_dlc.patch.
- Refresh patches.suse/ASoC-qcom-use-snd_soc_-of_-get_dlc.patch.
- Refresh
  patches.suse/ASoC-simple-card.c-use-snd_soc_-of_-get_dlc.patch.
- commit cb4d928
* Tue Sep 19 2023 tiwai@suse.de
- supported.conf: add HDA and ASoC Intel/AMD entries
- commit d1fdcf4
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: amd: yc: Fix a non-functional mic on Lenovo 82TL
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: avs: Provide support for fallback topology
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: yc: Add DMI entries to support Victus by HP Gaming
  Laptop 15-fb0xxx (8A3E) (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: hda/realtek - ALC287 I2S speaker platform support
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda/tas2781: Use standard clamp() macro (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: SOF: amd: clear panic mask status when panic occurs
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: amd: add conditional check for acp_clkmux_sel
  register (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: amd: remove redundant clock mux selection register
  write (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: amd: add module parameter for firmware debug
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: amd: enable ACP external global interrupt
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: amd: remove unused sha dma interrupt code
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-topology: Add module parameter to ignore the
  CPC value (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-topology: Modify the reference output valid_bits
  for copier (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-topology: Fix pipeline params at the output
  of copier (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit 4c3bb71
* Tue Sep 19 2023 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_SOF_AMD_VANGOGH=m
- commit 562ae88
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: SOF: ipc4-topology: Fix the output reference params
  for SRC (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-topology: Modify pipeline params based on
  SRC output format (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: amd: Enable signed firmware image loading for Vangogh
  platform (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: amd: Add support for signed fw image loading
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: amd: Add sof support for vangogh platform
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: acp: Add kcontrols and widgets per-codec in common
  code (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc3: Use devm_kmemdup to replace devm_kmalloc +
  memcpy (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: topology: Add a token for dropping widget name
  in kcontrol name (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: dapm: Add a flag for not having widget name in kcontrol
  name (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: RPL: Add entry for HDMI-In capture support on
  non-I2S codec boards (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: soc-acpi: add support for Dell SKU0C87 devices
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit 9d3a7d8
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: Intel: soc-acpi: Add entry for HDMI_In capture support
  in RPL match table (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: soc-acpi: Add entry for sof_es8336 in RPL match
  table (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: Refactor code for HDA stream creation
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: Add rpl_nau8318_8825 driver (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: SOF: Intel: Remove duplicated include in lnl.c
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: Initialize chip in hda_sdw_check_wakeen_irq()
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: sof_sdw: Simplify get_slave_info (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: intel: sof_sdw: Allow different devices on the same
  link (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: sof_sdw: Support multiple groups on the same
  link (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: sof_sdw: Device loop should not always start at
  adr_index (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: sof_sdw: Move range check of codec_conf into
  inner loop (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: sof_sdw: Update DLC index each time one is
  added (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: sof_sdw: Pull device loop up into
  create_sdw_dailink (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: sof_sdw: Add helper to create a single codec
  DLC (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: sof-sdw: Move check for valid group id to
  get_dailink_info (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: sof_sdw: Check link mask validity in
  get_dailink_info (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: sof_sdw: Remove duplicate NULL check on adr_link
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: sof_sdw: Printk's should end with a newline
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: acp3x-rt5682-max9836: Configure jack as not detecting
  Line Out (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: hda-mlink: add sublink to dev_dbg()
  log (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: IPC4: clarify 'pipeline_ids' usage and logs
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: hda-dai-ops: reset device count for SoundWire
  DAIs (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: hda-mlink: add helper to get sublink LSDIID
  register (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: add abstraction for SoundWire wake-ups
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: hda: add hw_params/free/trigger callbacks
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: hda-dai: add helpers for SoundWire callbacks
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit fab7f32
* Tue Sep 19 2023 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_SOF_LUNARLAKE=m
- commit 9762327
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: SOF: Intel: hda-dai-ops: add ops for SoundWire
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: hda-dai-ops: only allocate/release streams
  for first CPU DAI (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: hda-dai: add DMIC support (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: SOF: Intel: hda-dai: add ops for SSP (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: SOF: Intel: hda-dai-ops: add/select DMA ops for
  SSP (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: LNL: enable DMIC/SSP offload in probe/resume
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: split MTL and LNL operations (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: SOF: Intel: LNL: Add support for Lunarlake platform
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: hda: add interface definitions for ACE2.x
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-topology: restore gateway config length
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4: avoid uninitialized default instance 0
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc3-dtrace: Switch to memdup_user_nul() helper
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof_da7219_max98373: Map missing Line Out jack
  kcontrol (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: kbl_da7219_max98927: Map missing Line Out jack
  kcontrol (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: kbl_da7219_max98357a: Map missing Line Out jack
  kcontrol (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: bytcr_wm5102: Map missing Line Out jack kcontrol
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: bxt_da7219_max98357a: Map missing Line Out jack
  kcontrol (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: avs: da7219: Map missing jack kcontrols
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: acp3x-rt5682-max9836: Map missing jack kcontrols
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: acp: Map missing jack kcontrols (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- commit 60a1720
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: amd: acp-rt5645: Map missing jack kcontrols
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: acp-da7219-max98357a: Map missing jack kcontrols
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: mediatek: mt8186 modify dram type as non-cache
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: sof_sdw: Move group_generated logic (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: intel: sof_sdw: Merge codec_conf_alloc into dailink_info
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: sof_sdw: Clean up DAI link counting (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: Intel: sof_sdw: add cs35l56 codec info (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: intel: sof_sdw: Allow direct specification of CODEC
  name (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof_sdw: break earlier when a adr link contains
  different codecs (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: sof_sdw: Move amp_num initialisation to mc_probe
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: sof_sdw: Remove redundant parameters in dai
  creation (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: sof_sdw: Minor tidy up of mc_probe (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: intel: sof_sdw: Constify parameter to find_codec_part_info
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: sof_sdw: Simplify find_codec_info_acpi
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: sof_sdw: Use a module device table (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: intel: sof_sdw: Remove some extra line breaks
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: sof_sdw: Rename codec_idx to codec_dlc_index
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: sof_sdw: Use consistent variable naming for
  links (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof_sdw: add support for SKU 0AFE (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: Intel: sof_sdw: rename link_id to be_id (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: Intel: sof_sdw: allow mockup amplifier to provide
  feedback (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof_sdw: reorder SoundWire codecs in Kconfig
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof_sdw: Update BT offload config for soundwire
  config (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof_rt5682 add support for HDMI_In capture
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof_rt5682: add RPL support for MAX98357A
  speaker (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: soc-acpi: Add entry for rt711-sdca-sdw at link
  0 in RPL match table (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: acp5x-mach:add checks to avoid static analysis
  warnings (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: atom: remove static analysis false positive
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: bdw_rt286: add checks to avoid static analysis
  warnings (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: topology: simplify code to prevent static analysis
  warnings (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit 2a8e6bd
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: SOF: ipc3: add checks to prevent static analysis
  warnings (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: sof-client-probes-ipc4: add checks to prevent static
  analysis warnings (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc3: update dai_link_fixup for SOF_DAI_MEDIATEK_AFE
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: soc-acpi: move link_slaves_found() (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: SOF: Intel: start simplify the signature of
  link_slaves_found() (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: maxim-common: get codec number from ACPI
  table (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: avs: refactor strncpy usage in topology
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: Add missing dependency on CONFIG_EFI for Cirrus/TI
  sub-codecs (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda/realtek: Add quirk for mute LEDs on HP ENVY x360
  15-eu0xxx (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda/tas2781: Switch back to use struct i2c_driver's
  .probe() (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit 7e4e840
* Tue Sep 19 2023 tiwai@suse.de
- Update config files: CONFIG_SND_HDA_SCODEC_TAS2781_I2C=m
- commit f74361b
* Tue Sep 19 2023 tiwai@suse.de
- ALSA: hda/realtek: Add quirk for HP Victus 16-d1xxx to enable
  mute LED (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: cs35l41: Override the _DSD for HP Zbook Fury 17 G9
  to correct boost type (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: hda/tas2781: Fix PM refcount unbalance at
  tas2781_hda_bind() (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: hda/tas2781: Fix acpi device refcount leak at
  tas2781_read_acpi() (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: hda/realtek: Fix spelling mistake "powe" -> "power"
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda/tas2781: Add tas2781 HDA driver (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: hda: cs35l41: change cs35l41_prop_model to static
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: intel-dsp-cfg: Add Chromebook quirk to ADL/RPL
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit f614fcb
* Tue Sep 19 2023 tiwai@suse.de
- ALSA: hda: cs35l41: Fix the loop check in
  cs35l41_add_dsd_properties (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: cs35l41: Support systems with missing _DSD
  properties (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda/tegra: refactor deprecated strncpy (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: hda/i915: extend connectivity check to cover Intel
  ARL (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: intel-dsp-cfg: add LunarLake support (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: hda: intel-dsp-cfg: use common include for MeteorLake
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: add HD Audio PCI ID for Intel Arrow Lake-S
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- PCI: add ArrowLake-S PCI ID for Intel HDAudio subsystem
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: cs35l41: Print amp configuration after bind
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda/cs35l56: Reject I2C alias addresses (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: hda/cs35l56: Fail if .bin not found and firmware not
  patched (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit eb0ce74
* Tue Sep 19 2023 tiwai@suse.de
- Update config files: CONFIG_SND_HDA_SCODEC_CS35L56=m
- commit 3b4bbbb
* Tue Sep 19 2023 tiwai@suse.de
- ALSA: hda/cs35l56: Do not download firmware over existing RAM
  firmware (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda/cs35l56: cs_dsp_power_down() on cs35l56_hda_fw_load()
  error path (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda/cs35l56: Call cs_dsp_power_down() before calling
  cs_dsp_remove() (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: hda/cs35l56: Always power-up and start cs_dsp
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda/cs35l56: Call cs_dsp_power_down() before reloading
  firmware (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda/cs35l56: Do not mark cache dirty after REINIT
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda/cs35l56: Complete firmware reboot before calling
  cs_dsp_run() (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: hda/cs35l56: Do some clean up on probe error
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda/cs35l56: Add driver for Cirrus Logic CS35L56
  amplifier (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit 538cf18
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: cs35l56: Waiting for firmware to boot must be tolerant of
  I/O errors (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: cs35l56: Don't overwrite a patched firmware
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: wm_adsp: Support powering-up DSP without trying to load
  firmware (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: cs35l56: Call wm_adsp_power_down() before reloading
  firmware (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: wm_adsp: Expose the DSP power down actions as
  wm_adsp_power_down() (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: cs35l56: Wait for control port ready during system-resume
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: cs35l56: Don't rely on GPIOD_OUT_LOW to set RESET
  initially low (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: cs35l56: Avoid uninitialized variable in
  cs35l56_set_asp_slot_positions() (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: cs35l56: Make a common function to shutdown the
  DSP (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: cs35l56: Make common function for control port wait
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: cs35l56: Move part of cs35l56_init() to shared library
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: cs35l56: Move cs_dsp init into shared library
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: cs35l56: Move runtime suspend/resume to shared library
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: cs35l56: Move utility functions to shared file
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: cs35l56: Convert utility functions to use common data
  structure (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: cs35l56: Make cs35l56_system_reset() code more generic
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit 6aa9c77
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: cs35l56: Move shared data into a common data structure
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit 0f8b8c4
* Tue Sep 19 2023 tiwai@suse.de
- ALSA: hda: Fix missing header dependencies (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: cs35l56: Update to use maple tree register cache
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: cs35l56: Patch soft registers to defaults (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- commit 0f75826
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: amd: acp: fix SND_SOC_AMD_ACP_PCI depdenencies
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: acp: delete unnecessary NULL check (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: SOF: amd: Add Probe register offset for renoir and
  rembrandt platform (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Add acp-probe id to sof probe client driver
  for registration (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: amd: Add Probe functionality support for amd
  platforms (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: acp: clean up some inconsistent indentings
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof_rt5682: add jsl_rt5650 board config
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: ps-sdw-dma: Convert to platform remove callback
  returning void (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: acp: add pm ops support for rembrandt platform
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: acp: move pdm macros to common header file
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: acp: store the pdm stream channel mask
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: acp: export config_acp_dma() and
  config_pte_for_stream() symbols (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: acp: store xfer_resolution of the stream
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: acp: add pm ops support for acp pci driver
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: acp: store platform device reference created in pci
  probe call (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: acp: remove the redundant acp enable/disable
  interrupts functions (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: acp: add acp i2s master clock generation for
  rembrandt platform (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: acp: refactor the acp init and de-init sequence
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: Add new dmi entries to config entry (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: amd: Add acpi machine id's for vangogh platform
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit e0f6e64
* Tue Sep 19 2023 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_INTEL_AVS_MACH_RT5663=m
- commit b9578a0
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: amd: acp: Add machine driver support for max98388
  codec (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: acp: Add machine driver support for nau8821
  codec (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: vangogh: Add support for NAU8821/MAX98388 variant
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: vangogh: Use dmi_first_match() for DMI quirk
  handling (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: vangogh: Make use of DRV_NAME (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: Intel: avs: rt5682: Tidy up hw_params() (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: Intel: avs: rt5682: Add missing components (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: Intel: avs: Load rt5663 board on KBL-based platforms
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: avs: Add rt5663 machine board (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: Intel: avs: Load es8336 board on KBL-based platforms
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit 3fbf618
* Tue Sep 19 2023 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_INTEL_AVS_MACH_ES8336=m
- commit 5b3c4a1
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: Intel: avs: Add es8336 machine board (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: SOF: amd: refactor PSP smn_read (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: cs35l41: Ensure amp is only unmuted during
  playback (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: cs35l41: Add device_link between HDA and cs35l41_hda
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: cs35l41: Rework System Suspend to ensure correct call
  separation (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: cs35l41: Use pre and post playback hooks
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: hda_component: Add pre and post playback hooks
  to hda_component (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: cs35l41: Move Play and Pause into separate
  functions (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit 6c7942d
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: cs35l41: Update to use maple tree register cache
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: cs35l41: Ensure we pass up any errors during system
  suspend (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: cs35l41: Ensure we correctly re-sync regmap before
  system suspending (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: cs35l41: Check mailbox status of pause command
  after firmware load (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: cs35l41: Poll for Power Up/Down rather than waiting a
  fixed delay (bsc#1215284).
- ALSA: cs35l41: Use mbox command to enable speaker output
  for external boost (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- commit 3bd03af
* Tue Sep 19 2023 tiwai@suse.de
- ALSA: hda: add HDMI codec ID for Intel LNL (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: hda/hdmi: keep codec entries in numerical order
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sst: Convert to PCI device IDs defines
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: Convert to PCI device IDs defines
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: Skylake: Convert to PCI device IDs defines
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: avs: Convert to PCI device IDs defines
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: Convert to PCI device IDs defines (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: intel-dsp-config: Convert to PCI device IDs defines
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: Skylake: Use global PCI match macro (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: hda/i915: Use global PCI match macro (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: hda: Use global PCI match macro (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: Add controller matching macros (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: Remove unused Broxton PCI ID (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Remove unused Broxton PCI ID (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- PCI: Add Intel Audio DSP devices to pci_ids.h (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- PCI: Sort Intel PCI IDs by number (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: Explicitly include correct DT includes (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: hda: Use regcache_reg_cached() rather than open
  coding (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- regmap: Let users check if a register is cached (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- commit 22a05bd
* Tue Sep 19 2023 tiwai@suse.de
- supported.conf: update entries for UMP
- commit d3ef504
* Tue Sep 19 2023 tiwai@suse.de
- regcache: Push async I/O request down into the rbtree
  cache (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- regmap: Allow reads from write only registers with the flat
  cache (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- regmap: Drop early readability check (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- regmap: Add test to make sure we don't sync to read only
  registers (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- regmap: Add a test case for write only registers (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- regmap: Add test that writes to write only registers are
  prevented (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- regmap: Check for register readability before checking cache
  during read (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- regmap: Add debugfs file for forcing field writes
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- regmap: Provide basic KUnit coverage for the raw register
  I/O (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- regmap: Provide a ram backed regmap with raw support
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- regmap: Don't check for changes in regcache_set_val()
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- regmap: maple: Implement block sync for the maple tree
  cache (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- regmap: Add missing cache_only checks (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- regmap: mmio: Allow passing an empty config->reg_stride
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit 17d660d
* Tue Sep 19 2023 tiwai@suse.de
- ALSA: ump: Fix -Wformat-truncation warnings (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- commit 0970bc7
* Tue Sep 19 2023 tiwai@suse.de
- ALSA: seq: Fix snd_seq_expand_var_event() call to user-space
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: usb-audio: Fix potential memory leaks at error path for
  UMP open (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: ump: Don't create unused substreams for static blocks
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: ump: Fill group names for legacy rawmidi substreams
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: usb-audio: Attach legacy rawmidi after probing all
  UMP EPs (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit 00609a3
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: tas2781: fixed register access error when switching to
  other chips (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-topology: Update the basecfg for copier
  earlier (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof-sdw-cs42142: fix for codec button mapping
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof-sdw: update jack detection quirk for LunarLake
  RVP (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Fix incorrect use of sizeof in sof_ipc3_do_rx_work()
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: fsl: micfil: Use dual license micfil code (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt722-sdca: fix for JD event handling in ClockStop
  Mode0 (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: remove redundant unsigned comparison to zero
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: Fix memory leak at error path in
  snd_seq_create_port() (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: rt5640: Fix the issue of speaker noise (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: amd: ps: Fix extraneous error messages (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: core: suppress probe deferral errors (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: topology: suppress probe deferral errors (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: codecs: SND_SOC_WCD934X should select REGMAP_IRQ
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: qcom: q6afe-dai: fix Display Port Playback stream
  name (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: rt5645: check return value after reading device id
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: codecs: wcd934x: drop inline keywords (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: codecs: wcd934x: demote impedance printk (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: codecs: wcd938x: use dev_printk() for impedance
  logging (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: codecs: wcd938x: drop inline keywords (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: qdsp6: q6apm: use dai link pcm id as pcm device
  number (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: amd: add revision check for sending sha dma
  completion command (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: ps: fix byte count return value for invalid SoundWire
  manager instance (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: ps: add comments for DMA register mapping
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: ps: fix for position register set for AUDIO0 RX
  stream (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: ps: add fix for dma irq mask for rx streams for SDW0
  instance (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: ps: add comments for DMA irq bits mapping
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: ump: fix typo in system_2p_ev_to_ump_midi1()
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: ump: Correct wrong byte size at converting a UMP System
  message (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: stream: Make master_list ordered to prevent
  deadlocks (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: bus: Prevent lockdep asserts when stream has multiple
  buses (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: intel_ace2x: fix SND_SOC_SOF_HDA_MLINK dependency
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: debugfs: Add missing SCP registers (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- soundwire: stream: Remove unnecessary gotos (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- soundwire: stream: Invert logic on runtime alloc flags
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: stream: Remove unneeded checks for NULL bus
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: bandwidth allocation: Remove pointless variable
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: cadence: revisit parity injection (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- soundwire: intel/cadence: update hardware reset sequence
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: intel_bus_common: enable interrupts last
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: intel_bus_common: update error log (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- soundwire: amd: Improve error message in remove callback
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: qcom: set clk stop need reset flag at runtime
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: qcom: add software workaround for bus clash interrupt
  assertion (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: qcom: wait for fifo to be empty before suspend
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: qcom: drop unused struct qcom_swrm_ctrl members
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: intel: read AC timing control register before
  updating it (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: intel: use substream for .free callback
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: intel: remove .free callback implementation
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: intel: use substream for .trigger callback
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: intel: remove .trigger callback implementation
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF/soundwire: re-add substream in params_stream
  structure (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: intel_ace2x: add pre/post bank switch callbacks
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: intel_ace2x: add new_peripheral_assigned callback
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: bus: add new manager callback to deal with peripheral
  enumeration (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: intel_ace2x: add check_cmdsync_unlocked helper
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: intel_ace2x: enable wake support (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- soundwire: intel_ace2x: use common helpers for bus start/stop
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: intel_ace2x: add sync_arm/sync_go helpers
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit 9b394b1
* Tue Sep 19 2023 tiwai@suse.de
- soundwire: intel_ace2x: add DAI registration (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- soundwire: intel_ace2x: configure link PHY (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- soundwire: intel_ace2x: set SYNCPRD before powering-up
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: intel_ace2x: add link power-up/down helpers
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: intel_ace2x: add debugfs support (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- soundwire: intel_init: use eml_lock parameter (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: SOF: Intel: hda: retrieve SoundWire eml_lock and pass
  pointer (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: intel: add eml_lock in the interface for new
  platforms (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC/soundwire: intel: pass hdac_bus pointer for link
  management (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: intel/cadence: set ip_offset at run-time
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire/ASOC: Intel: update offsets for LunarLake
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: intel_ace2x: add empty new ops for LunarLake
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: intel: add ACE2.x SHIM definitions (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: SOF: Intel: shim: add enum for ACE 2.0 IP used in
  LunarLake (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: bus: Don't filter slave alerts (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- soundwire: qcom: use tabs for indentation in defines
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: qcom: add support for v2.0.0 controller
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: qcom: prepare for handling different register
  layouts (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- soundwire: qcom: allow 16-bit sample interval for ports
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: core: Always store of_node when getting DAI link
  component (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: tas2781: Fix error code in tas2781_load_calibration()
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: update pm_runtime enable sequence (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: tas2781: fix Kconfig dependencies (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: amd: acp: remove acp poweroff function (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: codecs: max98090: Allow dsp_a mode (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: qcom: common: add default jack dapm pins (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: tegra: Remove stale comments in AHUB (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- commit 803aadf
* Tue Sep 19 2023 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_WSA884X=m for arm64
- commit bf28db9
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: tegra: Use normal system sleep for ASRC (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: fsl-asoc-card: Allow passing the number of slots in
  use (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: codecs: wsa884x: Add WSA884x family of speakers
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof_rt5682: Add mtl support RT1019P speaker
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof_rt5682: reorder quirk table (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: amd: ps: add acp_reset flag check in acp pci driver
  pm ops (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: update comments in Kconfig file (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: amd: ps: enable SoundWire dma driver build (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: amd: ps: add pm ops support for SoundWire dma driver
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: ps: add support for SoundWire DMA interrupts
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit a9972e5
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: amd: ps: add SoundWire dma driver dma ops (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: amd: ps: add SoundWire dma driver (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: amd: ps: handle SoundWire interrupts in acp pci
  driver (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: ps: create platform devices based on acp config
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: simple-card.c: use snd_soc_{of_}get_dlc() (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: soc-core.c: use snd_soc_{of_}get_dlc() (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: samsung: use snd_soc_{of_}get_dlc() (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: meson: use snd_soc_{of_}get_dlc() (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: qcom: use snd_soc_{of_}get_dlc() (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- commit 699832e
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: fsl: use snd_soc_{of_}get_dlc() (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: soc-core.c: add snd_soc_{of_}get_dlc() (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: tas2781: Fix spelling mistake "calibraiton" ->
  "calibration" (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: q6dsp: q6apm-dai: Add mmap and copy compress DAI
  callbacks (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: q6dsp: q6apm-dai: Add compress set params and metadata DAI
  callbacks (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: q6dsp: q6apm-dai: Add trigger/pointer compress DAI
  callbacks (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: q6dsp: q6apm-dai: Add compress DAI and codec caps get
  callbacks (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: q6dsp: q6apm-dai: Add open/free compress DAI callbacks
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: q6dsp: audioreach: Add gapless feature support
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: q6dsp: audioreach: Add support to set compress format
  params (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: q6dsp: audioreach: Add placeholder decoder for compress
  playback (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: q6dsp: audioreach: add helper function to set u32
  param (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: q6dsp: q6apm: add end of stream events (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: qcom: SC7280: audioreach: Add sc7280 hardware param fixup
  callback (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: es8328: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: es8316: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt5682: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt5670: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt5668: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt5665: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt5660: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt5651: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt5645: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt5640: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt5631: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt5616: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt5514: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt1308: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- commit 1f02c2e
* Tue Sep 19 2023 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_TAS2781_*=m
- commit 9821c7a
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: rt1305: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt1019: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt1011: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: dwc: don't assign addr_width for dt configs
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: dwc: add DMA handshake control (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: max98388: fix error code in probe() (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: tas2781: Add tas2781 driver (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: tas2781: firmware lib (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: tas2781: Add Header file for tas2781 driver
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: max98363: Remove cache defaults for volatile registers
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: fsl-asoc-card: add nau8822 support (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: max98388: set variable soc_codec_dev_max98388
  storage-class-specifier to static (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: mtl: setup primary core info on MeteorLake
  platform (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: pm: Remove duplicated code in sof_suspend
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4: Switch to use the sof_debug:bit11 to dump
  message payload (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc3: Dump IPC message payload (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: SOF: Add new sof_debug flag to request message payload
  dump (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: sof-audio: test virtual widget in
  sof_walk_widgets_in_order (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- commit cc4b31a
* Tue Sep 19 2023 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_NAU8315=m CONFIG_SND_SOC_NAU8825=m for Arm
- commit 7f6b86a
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: SOF: sof-audio: add is_virtual_widget helper
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: codecs: wm0010: Add MODULE_FIRMWARE macros (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt5677: Add MODULE_FIRMWARE macro (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: max98388: fix unused function warnings (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: max98388: add amplifier driver (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: rt1318: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt1316: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt1308: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt722: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt715: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt712: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt711: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: rt700: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: simple_card_utils: remove unused cpus/codecs/platforms
  from props (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: simple-card-utils.c: share asoc_graph_parse_dai()
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit 30a025b
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: SOF: amd: Add support for IPC with a reply_size set
  to zero (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: remove old trigger ordering method (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: atmel: use use new trigger ordering method (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: amd: use use new trigger ordering method (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: add new trigger ordering method (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof_sdw: add dai_link_codec_ch_map (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: add N cpus to M codecs dai link support (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: cs35l30: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: cs43130: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: cs42l83: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: cs42l73: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: cs42l42: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: cs4234: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: cs35l35: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: cs35l34: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: cs35l33: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: cs35l32: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: siu: Add MODULE_FIRMWARE macro (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: avs-ssm4567: remove redundant dapm routes
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: avs-rt5682: remove redundant dapm routes
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: avs-rt298: remove redundant dapm routes
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: avs-rt286: remove redundant dapm routes
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: avs-rt274: remove redundant dapm routes
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: avs-nau8825: remove redundant dapm routes
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: avs-max98927: remove redundant dapm routes
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: avs-max98373: remove redundant dapm routes
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: avs-max98357a: remove redundant dapm routes
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: avs-hdaudio: remove redundant dapm routes
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: avs-dmic: remove redundant dapm routes
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit 47fd0d2
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: Switch two more i2c drivers back to use .probe()
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- Refresh patches.suse/ASoC-cs35l56-Add-an-ACPI-match-table.patch.
- commit 4323047
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: Intel: avs-da7219: remove redundant dapm routes
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: audio-graph-card2-custom-sample.dtsi: remove DT
  warning (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: audio-graph-card2-custom-sample: add missing CPU:Codec =
  1:N sample (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Add IPC3 Kernel Injector (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Refactor rx function for fuzzing (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: mediatek: mt8192-mt6359: Go back to old headphone pin
  name (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: mediatek: mt8188-mt6359: Use bitfield macros for
  registers (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: mediatek: mt8188-mt6359: Clean up log levels
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: mediatek: mt8188-mt6359: Cleanup return 0 disguised as
  return ret (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: mediatek: mt8188-mt6359: clean up a return in codec_init
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: mediatek: mt8188-mt6359: Compress of_device_id entries
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: tegra: Simplify code around clk_get_rate() handling
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: max98088: clean up some inconsistent indenting
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: codecs: wsa883x: use existing define instead of raw
  value (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: hda-pcm: remove kernel parameter init
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: mediatek: mt8188-mt6359: add i2c dependency
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: add snd_soc_get_stream_cpu() (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: soc.h: remove snd_soc_compr_ops :: trigger (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: Intel: soc-acpi: add Rex CS42l42 and MAX98363 SoundWire
  entries (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof_sdw: Add support for MAX98363 codec
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof_sdw: Modify maxim helper functions and
  structure names (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof_sdw: Rename sof_sdw_max98373.c file to
  sof_sdw_maxim.c (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof_sdw: Add helper function for cs42l42
  codec (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: Add rpl_rt1019_rt5682 driver (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: Intel: Sof_ssp_amp: Correcting author name (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: Intel: ADL: Moving amp only boards into end of the
  table (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: ADL: Enable HDMI-In capture feature support for
  non-I2S codec boards (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- commit f365978
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: Intel: sof-sdw: add Dell SKU 0B34 (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: Intel: soc-acpi: add tables for Dell SKU 0B34
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: soc-acpi: add table for RPL Dell SKU 0BDA
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof_sdw: increase sdw pin index for each sdw
  link (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof_sdw: add rt713 support (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: Intel: soc-acpi-intel-mtl-match: add rt712 ID
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: soc-acpi-intel-tgl-match: add rt712 ID
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof_sdw: add rt712 support (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: Intel: sof_sdw: make rt711_sdca be generic (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: Intel: sof_sdw: rename SOF_RT711_JDSRC to SOF_JACK_JDSRC
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit c698e7f
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: Intel: sdw_sof: append dai_type and remove codec_type
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit e0b457b
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: Intel: sof_sdw: add multi dailink support for a
  codec (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof_sdw: add codec_info pointer (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: Intel: sof_sdw: use predefine dailink id (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: Intel: sof_sdw: add dai info (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: sof_sdw: add missing exit callback (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: mediatek: mt8188-mt6359: support new board with
  nau88255 (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: soc-dapm.c: clean up debugfs for freed widget
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: mediatek: common: soundcard driver add dai_fmt support
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: mediatek: mt8188-mt6359: register hdmi/dp jack pins
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit 50b3774
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: SOF: Intel: hda-dai: add get_hlink callback
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- Refresh
  patches.suse/ASoC-SOF-intel-hda-Clean-up-link-DMA-for-IPC3-.patch.
- commit 4f70204
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: mediatek: mt8188: separate ADDA playback dai from capture
  dai (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: hda: add helper to extract SoundWire link
  count (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: mtl: prepare for code reuse (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: SOF: ipc4-topology: add DMA config TLV to IPC data
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-topology: introduce DMA config TLV
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-topology: extend ALH-specific data structure
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: hda-dai: add calc_stream_format callback
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: hda-dai: add codec_dai_set_stream callback
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: hda-dai: add error checks to prevent static
  analysis warnings (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: nau8825: Update output control for NAU8825C
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: nau8825: Update the calculation of FLL for NAU8825C
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: nau8825: Add registers patch for NAU8825C (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: SOF: mediatek: add adsp debug dump (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: soc-pcm.c: tidyup playback/capture_only at
  soc_get_playback_capture() (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: soc-pcm.c: use temporary variable at
  soc_get_playback_capture() (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: soc-pcm.c: cleanup soc_get_playback_capture() error
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: soc-pcm.c: use dai_link on soc_get_playback_capture()
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: soc-pcm.c: indicate error if stream has no playback no
  capture (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: nau8825: Add the management of headset detection for power
  saving (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: HDA: Limit the number of dai drivers
  for nocodec mode (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: topology: Use partial match for connecting DAI
  link and DAI widget (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: topology: Allow partial matching when finding DAI
  link (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: mediatek: add mt8188 audio support (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: ti: davinci-mcasp: Use pcm_for_each_format() macro
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: cs42l42: Add PLL ratio table values (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: cs35l45: Relicense to GPL only (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: da7219: Add Jack insertion detection polarity
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: sof: Improve sof_ipc4_bytes_ext_put function
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit 3b27a33
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: sof: Improve sof_ipc3_bytes_ext_put function
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: mediatek: mt6359: update route for lineout mux
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: mediatek: mt6359: add mtkaif gpio setting (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: mediatek: mt6359: fix kselftest error of playback
  gain (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: mediatek: mt6359: add supply for MTKAIF (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: use pm.h instead of runtime_pm.h (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: do not include pm_runtime.h if not used (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: SOF: Intel: tgl: unify core_put on IPC3 & IPC4 path
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: mtl: add core_get & put support on MeterLake
  platforms (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: hda-dai: Fix locking in hda_ipc4_pre_trigger()
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-topology: Fix an unsigned comparison which
  can never be negative (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: nau8825: Add pre-charge actions for input (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: topology: Remove redundant log (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: topology: Do not split message string on multiple
  lines (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: topology: Remove redundant logs (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: topology: Log control load errors in
  soc_tplg_control_load() (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-loader/topology: Query the CPC value from
  manifest (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-topology: Do not use the CPC value from
  topology (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-topology: Rename
  sof_ipc4_update_pipeline_mem_usage() to be generic
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit 754ffeb
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: SOF: ipc4-loader: Save a pointer to fm_config in
  sof_ipc4_fw_module (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-loader: Drop unused bss_size from struct
  sof_ipc4_fw_module (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: rt5682s: Use the devm_clk_get_optional() helper
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: cs53l30: Use the devm_clk_get_optional() helper
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: stm32: sai: Use the devm_clk_get_optional() helper
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: rt5659: Use the devm_clk_get_optional() helper
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: cs42l51: Use the devm_clk_get_optional() helper
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: atmel: sam9g20_wm8731: Remove the unneeded include
  <linux/i2c.h> (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: adau1761: Use the devm_clk_get_optional() helper
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: cs35l56: In secure mode skip SHUTDOWN and RESET around fw
  download (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: cs35l56: sdw_write_no_pm() should be performed under
  a pm_runtime request (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: codecs: rt722-sdca: do not store status in state
  container (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: codecs: rt715: do not store status in state container
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: codecs: rt715-sdca: do not store status in state
  container (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: codecs: rt712-sdca: do not store status in state
  container (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: codecs: rt712-sdca-dmic: do not store status in state
  container (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: codecs: rt711: do not store status in state container
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: codecs: rt711-sdca: do not store status in state
  container (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit c797784
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: mediatek: mt8188: refine APLL control (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- commit f2e5e40
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: codecs: rt700: do not store status in state container
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: codecs: rt5682: do not store status in state container
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: codecs: rt1318: do not store status in state container
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: codecs: rt1316: do not store status in state container
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: codecs: rt1308: do not store status in state container
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: mediatek: mt8192-mt6359: Remove " Jack" from Headphone
  pin name (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: tegra: tegra210_adx: fix snd_pcm_format_t type
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-topology: Modify input audio format selection
  logic (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-topology: New helper to check if all output
  formats are the same (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-topology: Modify the output format selection
  logic (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-topology: Add a new helper function to get the
  valid bits (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-topology: Handle output format special
  case (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-topology: Rename sof_ipc4_init_audio_fmt()
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-topology: Move the call to init output
  format (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-topology: Add a helper function for output
  format selection (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-topology: Handle input/output audio format
  special case (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: mediatek: mt8188: add required clocks (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: mediatek: mt8188: add bus protection (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: mediatek: mt8188: combine afe component registration
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: mediatek: mt8188: revise ETDM control flow (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: mediatek: mt8188: complete set_tdm_slot function
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: mediatek: mt8188: remove supply AUDIO_HIRES
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: wm_adsp: Update to use new component control notify
  helepr (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: ak4118: Update to use new component control notify
  helper (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: soc-component: Add notify control helper function
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: ipc4-pcm: reset all pipelines during FE DAI
  hw_free (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: hda-dai-ops: Split the get_hext_stream() op
  for IPC4 (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: remove mutual exclusion between NOCODEC and
  HDA_LINK (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: hda-dai: use HDA_LINK instead of
  HDA_AUDIO_CODEC (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- commit 4d058ad
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: SOF: Intel: hda-dai: remove use of cpu_dai->component
  drvdata (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- Refresh
  patches.suse/ASoC-SOF-intel-hda-Clean-up-link-DMA-for-IPC3-.patch.
- commit 5fb285a
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: SOF: Intel: hda-dai: mark functions as __maybe_unused
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: hda-dai: move hda_dai_prepare() code
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: Kconfig: move selection of PROBE_WORK_QUEUE
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: clarify initialization when HDA_AUDIO_CODEC
  is not used (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: Intel: fix DAI number mismatch (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: SOF: Intel: hda-dai: simplify .prepare callback
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: soc-acpi: add tables for LunarLake (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: Intel: sof_sdw: add new mapping for HP Spectre x360
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Intel: soc-acpi: add support for MTL SDCA boards
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit 98a7c8f
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: ssm3515: Add new amp driver (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- commit 51ab72a
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: amd: yc: Add MECHREVO Jiaolong Series MRID6 into DMI
  table (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit e8e4147
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: Intel: Add rpl_max98373_8825 driver (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: SOF: Simplify the calculation of variables (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: SOF: ipc4-topology: Use set_get_data() to send
  LARGE_CONFIG message (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: qcom: q6apm: add support to display ports in lpass
  dais (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: qcom: q6dsp: add support to more display ports
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: qcom: audioreach: add support for DISPLAY PORT SINK
  module (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: qcom: q6dsp-common: move channel allocation to common
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: jz4740-i2s: Add support for X1000 SoC (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- commit cc35052
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: fsl: use asoc_dummy_dlc (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- Refresh
  patches.suse/ASoC-imx-audmix-check-return-value-of-devm_kasp.patch.
- commit 7f494a7
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: soc-topology.c: add comment for Platform/Codec
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: simple_card_utils.c: use asoc_dummy_dlc (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: intel: skylake: use asoc_dummy_dlc (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: intel: sof: use asoc_dummy_dlc (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: intel: avs: use asoc_dummy_dlc (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: meson: use asoc_dummy_dlc (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: atmel: use asoc_dummy_dlc (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: qcom: use asoc_dummy_dlc (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: use asoc_dummy_dlc (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- commit 1734f11
* Tue Sep 19 2023 tiwai@suse.de
- Update config files: enable CONFIG_SND_SOC_RT722_SDCA_SDW
- commit f47d125
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: sof: use asoc_dummy_dlc (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: ti: use asoc_dummy_dlc (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: soc-utils.c: add asoc_dummy_dlc (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: rt722-sdca: Add RT722 SDCA driver (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: mediatek: mt8195-afe-pcm: Simplify with dev_err_probe()
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: mediatek: mt8195-afe-pcm: Simplify runtime PM during
  probe (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: mediatek: mt8195-afe-pcm: Clean up unnecessary functions
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: mediatek: mt8186: Use snd_sof_ipc_process_reply()
  helper (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: SOF: mediatek: mt8195: Use snd_sof_ipc_process_reply()
  helper (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: fsl_sai: MCLK bind with TX/RX enable bit (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- commit f24c873
* Tue Sep 19 2023 tiwai@suse.de
- ASoC: codecs: wcd938x: Remove unneeded semicolon (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: amd: ps: refactor acp power on and reset functions
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: amd: ps: remove the register read and write wrappers
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: Switch i2c drivers back to use .probe() (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: amd: ps: Update copyright notice (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: dwc: extend supported formats (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: rt5682: Use a maple tree based register cache
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: rt715: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ASoC: dwc: add optional reset support (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: hdmi-codec: fix channel info for compressed formats
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit 7f7fc6f
* Tue Sep 19 2023 tiwai@suse.de
- ALSA: pcm: fix ELD constraints for (E)AC3, DTS(-HD) and MLP
  formats (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: ump: Export MIDI1 / UMP conversion helpers (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: ump: Export snd_ump_receive_ump_val() (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: ump: Add no_process_stream flag (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: ump: Add helper to change MIDI protocol (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- sound: make all 'class' structures const (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: compress: allow setting codec params after next
  track (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: timer: minimize open-coded access to hw.resolution
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: docs: Update MIDI 2.0 documentation for UMP 1.1
  enhancement (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: ump: Add info flag bit for static blocks (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: seq: ump: Notify UMP protocol change to sequencer
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: ump: Notify port changes to system port
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: ump: Handle FB info update (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: ump: Handle groupless messages (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: usb-audio: Add midi2_ump_probe option (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: usb-audio: Parse UMP Endpoint and Function Blocks at
  first (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: ump: Support UMP Endpoint and Function Block parsing
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: ump: Add more attributes to UMP EP and FB info
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: firewire: use 'GPL' string for module license contributed
  by Clemens Ladisch (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: firewire: use 'GPL' string for module license contributed
  by Takashi Sakamoto (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: Use maple tree register cache (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- commit 54ef674
* Tue Sep 19 2023 tiwai@suse.de
- ALSA: hda/intel: Workaround for WALLCLK register for loongson
  controller (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: Workaround for SDnCTL register on loongson
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: Using polling mode for loongson controller by
  default (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: Add Loongson LS7A HD-Audio support (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: control: Keep the previous numid at snd_ctl_rename_id()
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda/realtek: Delete cs35l41 component master during
  free (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: hda: cs35l41: Fix endian conversions (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: hda: cs35l41: Clean up Firmware Load Controls
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: Avoid confusion of aligned read size (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: Switch i2c drivers back to use .probe() (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: ump: Fix parsing of 0xFx command (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: ump: Drop redundant check of note-on with zero velocity
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: ump: Correct snd_ump_midi1_msg_program definition
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: docs: Add MIDI 2.0 documentation (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: seq: Add UMP group filter (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: Print UMP Endpoint and Block information in proc
  outputs (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit 9cd2cae
* Tue Sep 19 2023 tiwai@suse.de
- Update config files: enable CONFIG_SND_SEQ_UMP
- commit a6d3569
* Tue Sep 19 2023 tiwai@suse.de
- ALSA: seq: Add ioctls for client UMP info query and setup
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: ump: Create UMP Endpoint port for broadcast
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: Bind UMP device (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: Allow suppressing UMP conversions (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: seq: Automatic conversion of UMP events (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: seq: Add UMP group number to snd_seq_port_info
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: Add port direction to snd_seq_port_info
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: Support MIDI 2.0 UMP Endpoint port (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: seq: Add port inactive flag (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: Add UMP support (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: Introduce SNDRV_SEQ_IOCTL_USER_PVERSION ioctl
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: Prohibit creating ports with special numbers
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: Check validity before creating a port object
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: Check the conflicting port at port creation
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: Drop dead code for the old broadcast support
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: Treat snd_seq_client object directly in client
  drivers (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: Add snd_seq_expand_var_event_at() helper
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: seq: Clear padded bytes at expanding events
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: usb-audio: Inform inconsistent protocols in GTBs
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: usb-audio: Enable the legacy raw MIDI support
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit a20cb16
* Tue Sep 19 2023 tiwai@suse.de
- Update config files: enable MIDI2 configs
- commit 0834a0b
* Tue Sep 19 2023 tiwai@suse.de
- ALSA: usb-audio: Use __le16 for 16bit USB descriptor fields
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: ump: Add legacy raw MIDI support (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: ump: Redirect rawmidi substream access via own helpers
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: usb-audio: Create UMP blocks from USB MIDI GTBs
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: usb-audio: Trim superfluous "MIDI" suffix from UMP EP
  name (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: usb-audio: Get UMP EP name string from USB interface
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: usb-audio: USB MIDI 2.0 UMP support (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: usb-audio: Define USB MIDI 2.0 specs (jsc#PED-6045
  jsc#PED-6036 jsc#PED-6104 jsc#PED-6114 jsc#PED-6067
  jsc#PED-6123).
- ALSA: usb-audio: Manage number of rawmidis globally
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: ump: Additional proc output (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: ump: Add ioctls to inquiry UMP EP and Block info via
  control API (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: rawmidi: Skip UMP devices at
  SNDRV_CTL_IOCTL_RAWMIDI_NEXT_DEVICE (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: rawmidi: UMP support (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: rawmidi: Add ioctl callback to snd_rawmidi_global_ops
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: rawmidi: Pass rawmidi directly to
  snd_rawmidi_kernel_open() (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: add HAS_IOPORT dependencies (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: mixart: Replace one-element arrays with simple
  object declarations (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104
  jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ALSA: compat_ioctl: use correct snd_ctl_elem_type_t type
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: uapi: pcm: control the filling of the silence samples
  for drain (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ALSA: core: update comment on snd_card.controls_rwsem
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: tlv320aic32x4: pll: Remove impossible condition in
  clk_aic32x4_pll_determine_rate() (jsc#PED-6045 jsc#PED-6036
  jsc#PED-6104 jsc#PED-6114 jsc#PED-6067 jsc#PED-6123).
- ASoC: tlv320aic32x4: div: Switch to determine_rate
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- ASoC: tlv320aic32x4: pll: Switch to determine_rate
  (jsc#PED-6045 jsc#PED-6036 jsc#PED-6104 jsc#PED-6114
  jsc#PED-6067 jsc#PED-6123).
- commit 63a9a52
* Tue Sep 19 2023 tiwai@suse.de
- spi: intel-pci: Add support for Granite Rapids SPI serial flash
  (jsc#PED-6106 jsc#PED-6090).
- commit 00c2e1f
* Tue Sep 19 2023 mfranc@suse.cz
- s390/ctcm: Convert sprintf/snprintf to scnprintf (jsc#PED-5436).
- commit b392a8a
* Tue Sep 19 2023 mfranc@suse.cz
- s390/ctcm: Convert sysfs sprintf to sysfs_emit (jsc#PED-5436).
- commit 6d42891
* Tue Sep 19 2023 mfranc@suse.cz
- s390/lcs: Convert sprintf to scnprintf (jsc#PED-5436).
- commit 9e4e74e
* Tue Sep 19 2023 mfranc@suse.cz
- s390/lcs: Convert sysfs sprintf to sysfs_emit (jsc#PED-5436).
- commit 715ef85
* Tue Sep 19 2023 mfranc@suse.cz
- s390/ism: Set DMA coherent mask (jsc#PED-5436).
- commit f59d174
* Tue Sep 19 2023 nik.borisov@suse.com
- x86/cpu: Fix Crestmont uarch (jsc#PED-6469).
- commit e882a7f
* Tue Sep 19 2023 nik.borisov@suse.com
- perf/x86/intel: Add Crestmont PMU (jsc#PED-6469).
- commit 058f4f4
* Tue Sep 19 2023 nik.borisov@suse.com
- x86/cpu: Add several Intel server CPU model numbers (jsc#PED-6469).
- commit 6d86f99
* Tue Sep 19 2023 jlee@suse.com
- Update config files. (jsc#PED-6528)
  Set CONFIG_IMA_KEYRINGS_PERMIT_SIGNED_BY_BUILTIN_OR_SECONDARY=n
  to arm64/default, armv7hl/default, s390x/default and x86_64/default.
  Let's disable CONFIG_IMA_KEYRINGS_PERMIT_SIGNED_BY_BUILTIN_OR_SECONDARY
  before we have conclusion on PED-6528. Which means that the
  .secondary_trusted_keys keyring can NOT be used to verify .ima/.evm
  keys. It also means that MOK in .machine keyring can not be used to
  verify .ima/.evm keys.
  This commit didn't change the value in ppc64le/default because it's
  handled by another jira jsc#PED-5085. PPC may be applied special setting
  for IBM. (jsc#PED-6528)
- commit dd2a1af
* Mon Sep 18 2023 jgross@suse.com
- KVM: x86/mmu: Include mmu.h in spte.h (git-fixes).
- commit 05d2771
* Mon Sep 18 2023 jgross@suse.com
- KVM: x86/mmu: Guard against collision with KVM-defined
  PFERR_IMPLICIT_ACCESS (git-fixes).
- commit fb0e117
* Mon Sep 18 2023 jgross@suse.com
- KVM: nSVM: Load L1's TSC multiplier based on L1 state, not L2
  state (git-fixes).
- commit 9a8cf6e
* Mon Sep 18 2023 jgross@suse.com
- KVM: nSVM: Check instead of asserting on nested TSC scaling
  support (git-fixes).
- commit 3b43cd9
* Mon Sep 18 2023 jgross@suse.com
- KVM: SVM: Set target pCPU during IRTE update if target vCPU
  is running (git-fixes).
- commit de8e951
* Mon Sep 18 2023 jgross@suse.com
- KVM: SVM: Take and hold ir_list_lock when updating vCPU's
  Physical ID entry (git-fixes).
- commit c8429d7
* Mon Sep 18 2023 jgross@suse.com
- KVM: SVM: Don't inject #UD if KVM attempts to skip SEV guest
  insn (git-fixes).
- commit d983b3c
* Mon Sep 18 2023 jgross@suse.com
- KVM: SVM: Skip VMSA init in sev_es_init_vmcb() if pointer is
  NULL (git-fixes).
- commit 80d1c46
* Mon Sep 18 2023 lhenriques@suse.de
- ceph: make num_fwd and num_retry to __u32 (jsc#SES-1880).
- rbd: use list_for_each_entry() helper (jsc#SES-1880).
- libceph: do not include crypto/algapi.h (jsc#SES-1880).
- ceph: switch ceph_lookup/atomic_open() to use new fscrypt helper
  (jsc#SES-1880).
- ceph: fix updating i_truncate_pagecache_size for fscrypt
  (jsc#SES-1880).
- ceph: wait for OSD requests' callbacks to finish when unmounting
  (jsc#SES-1880).
- ceph: drop messages from MDS when unmounting (jsc#SES-1880).
- ceph: prevent snapshot creation in encrypted locked directories
  (jsc#SES-1880).
- ceph: add support for encrypted snapshot names (jsc#SES-1880).
- ceph: invalidate pages when doing direct/sync writes
  (jsc#SES-1880).
- ceph: plumb in decryption during reads (jsc#SES-1880).
- ceph: add encryption support to writepage and writepages
  (jsc#SES-1880).
- ceph: add read/modify/write to ceph_sync_write (jsc#SES-1880).
- ceph: align data in pages in ceph_sync_write (jsc#SES-1880).
- ceph: don't use special DIO path for encrypted inodes
  (jsc#SES-1880).
- ceph: add truncate size handling support for fscrypt
  (jsc#SES-1880).
- ceph: add object version support for sync read (jsc#SES-1880).
- libceph: allow ceph_osdc_new_request to accept a multi-op read
  (jsc#SES-1880).
- libceph: add CEPH_OSD_OP_ASSERT_VER support (jsc#SES-1880).
- ceph: add infrastructure for file encryption and decryption
  (jsc#SES-1880).
- ceph: handle fscrypt fields in cap messages from MDS
  (jsc#SES-1880).
- ceph: size handling in MClientRequest, cap updates and inode
  traces (jsc#SES-1880).
- ceph: mark directory as non-complete after loading key
  (jsc#SES-1880).
- ceph: allow encrypting a directory while not having Ax caps
  (jsc#SES-1880).
- ceph: add some fscrypt guardrails (jsc#SES-1880).
- ceph: create symlinks with encrypted and base64-encoded targets
  (jsc#SES-1880).
- ceph: add support to readdir for encrypted names (jsc#SES-1880).
- ceph: pass the request to parse_reply_info_readdir()
  (jsc#SES-1880).
- ceph: make ceph_fill_trace and ceph_get_name decrypt names
  (jsc#SES-1880).
- ceph: add helpers for converting names for userland presentation
  (jsc#SES-1880).
- ceph: make d_revalidate call fscrypt revalidator for encrypted
  dentries (jsc#SES-1880).
- ceph: set DCACHE_NOKEY_NAME flag in ceph_lookup/atomic_open()
  (jsc#SES-1880).
- ceph: decode alternate_name in lease info (jsc#SES-1880).
- ceph: send alternate_name in MClientRequest (jsc#SES-1880).
- ceph: encode encrypted name in ceph_mdsc_build_path and dentry
  release (jsc#SES-1880).
- ceph: add base64 endcoding routines for encrypted names
  (jsc#SES-1880).
- ceph: make ioctl cmds more readable in debug log (jsc#SES-1880).
- ceph: add fscrypt ioctls and ceph.fscrypt.auth vxattr
  (jsc#SES-1880).
- ceph: implement -o test_dummy_encryption mount option
  (jsc#SES-1880).
- ceph: fscrypt_auth handling for ceph (jsc#SES-1880).
- ceph: use osd_req_op_extent_osd_iter for netfs reads
  (jsc#SES-1880).
- libceph: add new iov_iter-based ceph_msg_data_type and
  ceph_osd_data_type (jsc#SES-1880).
- ceph: make ceph_msdc_build_path use ref-walk (jsc#SES-1880).
- ceph: preallocate inode for ops that may create one
  (jsc#SES-1880).
- ceph: add new mount option to enable sparse reads
  (jsc#SES-1880).
- commit 80e2a90
* Mon Sep 18 2023 lhenriques@suse.de
- libceph: add sparse read support to OSD client (jsc#SES-1880).
- Refresh
  patches.suse/libceph-add-support-for-CMPEXT-compare-extent-reques.patch.
- commit cec7183
* Mon Sep 18 2023 lhenriques@suse.de
- libceph: add sparse read support to msgr1 (jsc#SES-1880).
- libceph: support sparse reads on msgr2 secure codepath
  (jsc#SES-1880).
- libceph: new sparse_read op, support sparse reads on msgr2
  crc  codepath (jsc#SES-1880).
- commit c1e90ef
* Mon Sep 18 2023 lhenriques@suse.de
- libceph: define struct ceph_sparse_extent and add some helpers
  (jsc#SES-1880).
- Refresh
  patches.suse/libceph-add-support-for-CMPEXT-compare-extent-reques.patch.
- commit 868cc0e
* Mon Sep 18 2023 lhenriques@suse.de
- libceph: add spinlock around osd->o_requests (jsc#SES-1880).
- commit 0e31a4c
* Mon Sep 18 2023 lhenriques@suse.de
- ceph: issue a cap release immediately if no cap exists
  (jsc#SES-1880).
- ceph: trigger to flush the buffer when making snapshot
  (jsc#SES-1880).
- ceph: voluntarily drop Xx caps for requests those touch parent
  mtime (jsc#SES-1880).
- ceph: only send metrics when the MDS rank is ready
  (jsc#SES-1880).
- commit 1d99e9d
* Mon Sep 18 2023 petr.pavlu@suse.com
- doc/README.SUSE: Reflow text to 80-column width (jsc#PED-5021)
- commit e8f2c67
* Mon Sep 18 2023 jgross@suse.com
- KVM: SVM: Get source vCPUs from source VM for SEV-ES intrahost
  migration (git-fixes).
- commit d8a362f
* Mon Sep 18 2023 ddiss@suse.de
- scsi: target: core: Fix target_cmd_counter leak (bsc#1214847).
- commit b9c2cf7
* Mon Sep 18 2023 jgross@suse.com
- KVM: SVM: Don't defer NMI unblocking until next exit for SEV-ES
  guests (git-fixes).
- commit 815118a
* Mon Sep 18 2023 jgross@suse.com
- KVM: VMX: Refresh available regs and IDT vectoring info before
  NMI handling (git-fixes).
- commit c8edde6
* Mon Sep 18 2023 nik.borisov@suse.com
- x86/virt/tdx: Make TDX_MODULE_CALL handle SEAMCALL #UD and #GP (jsc#PED-5824).
- commit 3990c40
* Mon Sep 18 2023 nik.borisov@suse.com
- x86/virt/tdx: Wire up basic SEAMCALL functions (jsc#PED-5824).
- commit 5a7d4d1
* Mon Sep 18 2023 nik.borisov@suse.com
- x86/tdx: Remove 'struct tdx_hypercall_args' (jsc#PED-5824).
- commit 35524da
* Mon Sep 18 2023 nik.borisov@suse.com
- x86/tdx: Reimplement __tdx_hypercall() using TDX_MODULE_CALL asm (jsc#PED-5824).
- commit ea49b7a
* Mon Sep 18 2023 nik.borisov@suse.com
- x86/tdx: Make TDX_HYPERCALL asm similar to TDX_MODULE_CALL (jsc#PED-5824).
- commit 68160e9
* Mon Sep 18 2023 nik.borisov@suse.com
- x86/tdx: Extend TDX_MODULE_CALL to support more TDCALL/SEAMCALL leafs (jsc#PED-5824).
- commit 81b9942
* Mon Sep 18 2023 nik.borisov@suse.com
- x86/tdx: Pass TDCALL/SEAMCALL input/output registers via a structure (jsc#PED-5824).
- commit e8d92e2
* Mon Sep 18 2023 nik.borisov@suse.com
- x86/tdx: Rename __tdx_module_call() to __tdcall() (jsc#PED-5824).
- commit 67b9b89
* Mon Sep 18 2023 nik.borisov@suse.com
- x86/tdx: Make macros of TDCALLs consistent with the spec (jsc#PED-5824).
- commit 2487143
* Mon Sep 18 2023 nik.borisov@suse.com
- x86/tdx: Skip saving output regs when SEAMCALL fails with VMFailInvalid (jsc#PED-5824).
- commit cc3a3ab
* Mon Sep 18 2023 nik.borisov@suse.com
- x86/tdx: Zero out the missing RSI in TDX_HYPERCALL macro (jsc#PED-5824).
- commit 117aa18
* Mon Sep 18 2023 nik.borisov@suse.com
- x86/tdx: Retry partially-completed page conversion hypercalls (jsc#PED-5824).
- commit f5ec3f4
* Mon Sep 18 2023 petr.pavlu@suse.com
- doc/README.SUSE: Minor content clean up (jsc#PED-5021)
  * Mark the user's build directory as a variable, not a command:
  'make -C $(your_build_dir)' -> 'make -C $YOUR_BUILD_DIR'.
  * Unify how to get the current directory: 'M=$(pwd)' -> 'M=$PWD'.
  * 'GIT' / 'git' -> 'Git'.
- commit 1cb4ec8
* Mon Sep 18 2023 jgross@suse.com
- KVM: x86: Fix KVM_CAP_SYNC_REGS's sync_regs() TOCTOU issues
  (git-fixes).
- commit 3b70d15
* Mon Sep 18 2023 jgross@suse.com
- Revert "KVM: SVM: Skip WRMSR fastpath on VM-Exit if next RIP
  isn't valid" (git-fixes).
- commit deeaff0
* Mon Sep 18 2023 jgross@suse.com
- KVM: x86: Acquire SRCU read lock when handling fastpath MSR
  writes (git-fixes).
- commit 6ec2da2
* Mon Sep 18 2023 nik.borisov@suse.com
- Update config files: Disable IA32_EMULATION by default (jsc#PED-3184)
- commit 358f807
* Mon Sep 18 2023 jgross@suse.com
- KVM: SVM: Invoke trace_kvm_exit() for fastpath VM-Exits
  (git-fixes).
- commit 0219953
* Mon Sep 18 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update information about module paths
  (jsc#PED-5021)
  * Use version variables to describe names of the
  /lib/modules/$VERSION-$RELEASE-$FLAVOR/... directories
  instead of using specific example versions which get outdated quickly.
  * Note: Keep the /lib/modules/ prefix instead of using the new
  /usr/lib/modules/ location for now. The updated README is expected to
  be incorporated to various branches that are not yet usrmerged.
- commit 7eba2f0
* Mon Sep 18 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update information about custom patches
  (jsc#PED-5021)
  * Replace mention of various patches.* directories with only
  patches.suse as the typical location for patches.
  * Replace i386 with x86_64 in the example how to define a config addon.
  * Fix some typos and wording.
- commit 2997d22
* Mon Sep 18 2023 jgross@suse.com
- KVM: SVM: Remove TSS reloading code after VMEXIT (git-fixes).
- commit cc99fca
* Mon Sep 18 2023 jgross@suse.com
- virtio_ring: fix avail_wrap_counter in virtqueue_add_packed
  (git-fixes).
- commit ff3b5c4
* Mon Sep 18 2023 jgross@suse.com
- virtio_vdpa: build affinity masks conditionally (git-fixes).
- commit 6c8cd83
* Mon Sep 18 2023 jgross@suse.com
- virtio_pmem: add the missing REQ_OP_WRITE for flush bio
  (git-fixes).
- commit 992fff8
* Mon Sep 18 2023 jgross@suse.com
- xen: remove a confusing comment on auto-translated guest I/O
  (git-fixes).
- commit e50901e
* Mon Sep 18 2023 tiwai@suse.de
- panic: Reenable preemption in WARN slowpath (git-fixes).
- ata: libahci: clear pending interrupt status (git-fixes).
- ata: libata: disallow dev-initiated LPM transitions to
  unsupported states (git-fixes).
- i2c: aspeed: Reset the i2c controller when timeout occurs
  (git-fixes).
- selftests: tracing: Fix to unmount tracefs for recovering
  environment (git-fixes).
- drm/tests: helpers: Avoid a driver uaf (git-fixes).
- drm/radeon: make fence wait in suballocator uninterrruptable
  (git-fixes).
- drm/amd/display: fix the white screen issue when >= 64GB DRAM
  (git-fixes).
- drm: gm12u320: Fix the timeout usage for usb_bulk_msg()
  (git-fixes).
- drm/amd: Make fence wait in suballocator uninterruptible
  (git-fixes).
- commit 69304d0
* Sun Sep 17 2023 andrea.porta@suse.com
- arm64: module: rework module VA range selection (bsc#1214304).
- arm64: module: mandate MODULE_PLTS (bsc#1214304).
- arm64: module: move module randomization to module.c (bsc#1214304).
- arm64: kaslr: split kaslr/module initialization (bsc#1214304).
- arm64: kasan: remove !KASAN_VMALLOC remnants (bsc#1214304).
- arm64: module: remove old !KASAN_VMALLOC logic (bsc#1214304).
- commit c682662
* Fri Sep 15 2023 tiwai@suse.de
- wifi: ieee80211: reorder presence checks in MLE per-STA profile
  (jsc#PED-6081 jsc#PED-6130).
- Refresh
  patches.suse/wifi-ieee80211-fix-erroneous-NSTR-bitmap-size-checks.patch.
- commit 2a2608b
* Fri Sep 15 2023 tiwai@suse.de
- wifi: ieee80211: fix erroneous NSTR bitmap size checks
  (jsc#PED-6081 jsc#PED-6130).
- commit c83f3a8
* Fri Sep 15 2023 tiwai@suse.de
- wifi: ieee80211: use default for medium synchronization delay
  (jsc#PED-6081 jsc#PED-6130).
- commit 9892e25
* Fri Sep 15 2023 tiwai@suse.de
- Bluetooth: btusb: Fix quirks table naming (jsc#PED-6081
  jsc#PED-6130).
- Bluetooth: btintel: Send new command for PPAG (jsc#PED-6081
  jsc#PED-6130).
- Bluetooth: btusb: Move btusb_recv_event_intel to btintel
  (jsc#PED-6081 jsc#PED-6130).
- Bluetooth: Add support for Gale Peak (8087:0036) (jsc#PED-6081
  jsc#PED-6130).
- Bluetooth: btintel: Add support for Gale Peak (jsc#PED-6081
  jsc#PED-6130).
- Bluetooth: btintel: Add support to reset bluetooth via ACPI DSM
  (jsc#PED-6081 jsc#PED-6130).
- commit d94b566
* Fri Sep 15 2023 tiwai@suse.de
- wifi: iwlwifi: remove 'use_tfh' config to fix crash
  (jsc#PED-6081 jsc#PED-6130).
- Bluetooth: hci_sysfs: make bt_class a static const structure
  (jsc#PED-6081 jsc#PED-6130).
- Bluetooth: ISO: Rework sync_interval to be sync_factor
  (jsc#PED-6081 jsc#PED-6130).
- Bluetooth: hci_event: fix Set CIG Parameters error status
  handling (jsc#PED-6081 jsc#PED-6130).
- Bluetooth: btqca: use le32_to_cpu for ver.soc_id (jsc#PED-6081
  jsc#PED-6130).
- commit 894ef0e
* Fri Sep 15 2023 tiwai@suse.de
- Bluetooth: btusb: Add device 6655:8771 to device tables
  (jsc#PED-6081 jsc#PED-6130).
- Bluetooth: btrtl: Add missing MODULE_FIRMWARE declarations
  (jsc#PED-6081 jsc#PED-6130).
- virtio_bt: call scheduler when we free unused buffs
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: Add support for IGTK in D3 resume flow
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: update two most recent GTKs on D3 resume
  flow (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: Refactor security key update after D3
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: mark keys as uploaded when added by the driver
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: remove support of A0 version of FM RF
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: cfg: clean up Bz module firmware lines
  (jsc#PED-6081 jsc#PED-6130).
- commit 8f10a16
* Fri Sep 15 2023 tiwai@suse.de
- wifi: iwlwifi: remove support for *nJ devices (jsc#PED-6081
  jsc#PED-6130).
- Refresh
  patches.suse/iwlwifi-cfg-Add-missing-MODULE_FIRMWARE-for-pnvm.patch.
- commit fd752ae
* Fri Sep 15 2023 tiwai@suse.de
- wifi: iwlwifi: bump FW API to 83 for AX/BZ/SC devices
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: cfg: remove trailing dash from FW_PRE constants
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: also unify Ma device configurations (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: also unify Sc device configurations (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: unify Bz/Gl device configurations (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: pcie: also drop jacket from info macro
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: don't load old firmware for 22000 (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: don't load old firmware for ax210 (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: don't load old firmware for Bz (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: don't load old firmware for Sc (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: give Sc devices their own family (jsc#PED-6081
  jsc#PED-6130).
- commit f8bdc92
* Fri Sep 15 2023 tiwai@suse.de
- wifi: iwlwifi: split 22000.c into multiple files (jsc#PED-6081
  jsc#PED-6130).
- Refresh
  patches.suse/iwlwifi-cfg-Add-missing-MODULE_FIRMWARE-for-pnvm.patch.
- commit b6d8129
* Fri Sep 15 2023 tiwai@suse.de
- wifi: iwlwifi: Add support for new CNVi (SC) (jsc#PED-6081
  jsc#PED-6130).
- Refresh
  patches.suse/iwlwifi-cfg-Add-missing-MODULE_FIRMWARE-for-pnvm.patch.
- commit 9d46e84
* Fri Sep 15 2023 tiwai@suse.de
- wifi: iwlwifi: Add support for new Bz version (jsc#PED-6081
  jsc#PED-6130).
- commit bbc566a
* Fri Sep 15 2023 tiwai@suse.de
- wifi: iwlwifi: mvm: Add support for scan version 17
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: adjust skip-over-dtim in D3 (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: mvm: support new flush_sta method (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: mvm: send LARI configuration earlier
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: remove disable_dummy_notification (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: limit EHT capabilities based on PCIe link speed
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: add EHT A-MPDU size exponent support
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: use min_t() for agg_size (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: mvm: use EHT maximum MPDU length on 2.4 GHz
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: nvm: handle EHT/320 MHz regulatory flag
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: make iwl_mvm_set_fw_mu_edca_params mld aware
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: fw: send marker cmd before suspend cmd
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: check the right csa_active (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: pcie: add size assertions (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: pcie: refactor RB status size calculation
  (jsc#PED-6081 jsc#PED-6130).
- commit c5d9cef
* Fri Sep 15 2023 tiwai@suse.de
- wifi: nl80211/reg: add no-EHT regulatory flag (jsc#PED-6081
  jsc#PED-6130).
- wifi: cfg80211: Retrieve PSD information from RNR AP information
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: fix CRC calculation for extended elems
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: avoid lockdep checking when removing deflink
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: always hold sdata lock in chanctx
  assign/unassign (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: store BSS param change count from assoc response
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: drop some unprotected action frames
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: move action length check up (jsc#PED-6081
  jsc#PED-6130).
- wifi: mac80211: drop unprotected robust mgmt before 4-way-HS
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: fix documentation config reference (jsc#PED-6081
  jsc#PED-6130).
- commit 6a1d79a
* Fri Sep 15 2023 tiwai@suse.de
- wifi: cfg80211: search all RNR elements for colocated APs
  (jsc#PED-6081 jsc#PED-6130).
- Refresh
  patches.suse/wifi-cfg80211-Fix-return-value-in-scan-logic.patch.
- commit b5ee4d8
* Fri Sep 15 2023 tiwai@suse.de
- wifi: mac80211: add eht_capa debugfs field (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: dvm: fix -Wunused-const-variable gcc warning
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: check EHT basic MCS/NSS set (jsc#PED-6081
  jsc#PED-6130).
- wifi: cfg80211: stop parsing after allocation failure
  (jsc#PED-6081 jsc#PED-6130).
- wifi: update multi-link element STA reconfig (jsc#PED-6081
  jsc#PED-6130).
- wifi: mac80211: agg-tx: prevent start/stop race (jsc#PED-6081
  jsc#PED-6130).
- wifi: mac80211: agg-tx: add a few locking assertions
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: Support link removal using Reconfiguration ML
  element (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: add set_active_links variant not locking sdata
  (jsc#PED-6081 jsc#PED-6130).
- commit 1384067
* Fri Sep 15 2023 mkubecek@suse.cz
- netfilter: nftables: exthdr: fix 4-byte stack OOB write
  (CVE-2023-4881 bsc#1215221).
- commit 5b503ee
* Fri Sep 15 2023 tiwai@suse.de
- wifi: mac80211: add ___ieee80211_disconnect variant not locking
  sdata (jsc#PED-6081 jsc#PED-6130).
- wifi: cfg80211/nl80211: Add support to indicate STA MLD setup
  links removal (jsc#PED-6081 jsc#PED-6130).
- wifi: cfg80211: do not scan disabled links on 6GHz (jsc#PED-6081
  jsc#PED-6130).
- wifi: cfg80211: handle BSS data contained in ML probe responses
  (jsc#PED-6081 jsc#PED-6130).
- wifi: cfg80211: use structs for TBTT information access
  (jsc#PED-6081 jsc#PED-6130).
- wifi: ieee80211: add structs for TBTT information access
  (jsc#PED-6081 jsc#PED-6130).
- wifi: cfg80211: use a struct for inform_single_bss data
  (jsc#PED-6081 jsc#PED-6130).
- wifi: ieee80211: add definitions for RNR MLD params
  (jsc#PED-6081 jsc#PED-6130).
- wifi: cfg80211: Always ignore ML element (jsc#PED-6081
  jsc#PED-6130).
- wifi: ieee80211: add helper to validate ML element type and size
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: Include Multi-Link in CRC calculation
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: Rename ieee80211_mle_sta_prof_size_ok()
  (jsc#PED-6081 jsc#PED-6130).
- commit 4fddada
* Fri Sep 15 2023 tiwai@suse.de
- wifi: mac80211: Add support for parsing Reconfiguration Multi
  Link element (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: Rename multi_link (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: use cfg80211 defragmentation helper
  (jsc#PED-6081 jsc#PED-6130).
- wifi: cfg80211: add element defragmentation helper (jsc#PED-6081
  jsc#PED-6130).
- wifi: cfg80211: ignore invalid TBTT info field types
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: use new inform_bss callback (jsc#PED-6081
  jsc#PED-6130).
- wifi: cfg80211: add inform_bss op to update BSS (jsc#PED-6081
  jsc#PED-6130).
- wifi: cfg80211: keep bss_lock held when informing (jsc#PED-6081
  jsc#PED-6130).
- wifi: cfg80211: move regulatory_hint_found_beacon to be earlier
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: feed the link_id to
  cfg80211_ch_switch_started_notify (jsc#PED-6081 jsc#PED-6130).
- commit 3d08fcc
* Fri Sep 15 2023 tiwai@suse.de
- wifi: mac80211: add consistency check for compat chandef
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: stop passing cbss to parser (jsc#PED-6081
  jsc#PED-6130).
- wifi: mac80211: Extend AID element addition for TDLS frames
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: Add HE and EHT capa elements in TDLS frames
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: handle TDLS data frames with MLO (jsc#PED-6081
  jsc#PED-6130).
- wifi: mac80211: handle TDLS negotiation with MLO (jsc#PED-6081
  jsc#PED-6130).
- wifi: cfg80211: make TDLS management link-aware (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: bump FW API to 81 for AX devices (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: mvm: Add support for SCAN API version 16
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: Don't access vif valid links directly
  (jsc#PED-6081 jsc#PED-6130).
- commit 3ec74b8
* Fri Sep 15 2023 tiwai@suse.de
- wifi: iwlwifi: handle eSR transitions (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: fix max number of fw active links (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: add a few rate index validity checks
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: Validate slots_num before allocating memory
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: Validate tid is in valid range before
  using it (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: track u-APSD misbehaving AP by AP address
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: implement WPFC ACPI table loading (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: add some FW misbehaviour check infrastructure
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: always send spec link ID in link commands
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: use array as array argument (jsc#PED-6081
  jsc#PED-6130).
- commit 4782c77
* Fri Sep 15 2023 tiwai@suse.de
- wifi: iwlwifi: mvm: store WMM params per link (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: mvm: check link during TX (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: mvm: add a NULL pointer check (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: fw: Add new FSEQ defines to fw dump (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: pcie: double-check ACK interrupt after timeout
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: use iwl_mvm_is_vendor_in_approved_list()
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: fw: make some ACPI functions static (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: Correctly indicate support for VHT TX STBC
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: remove new checksum code (jsc#PED-6081
  jsc#PED-6130).
- wifi: mac80211: Add debugfs entry to report dormant links
  (jsc#PED-6081 jsc#PED-6130).
- commit b83471d
* Fri Sep 15 2023 tiwai@suse.de
- wifi: iwlwifi: support version C0 of BZ and GL devices
  (jsc#PED-6081 jsc#PED-6130).
- Refresh
  patches.suse/iwlwifi-cfg-Add-missing-MODULE_FIRMWARE-for-pnvm.patch.
- commit ee9b8b1
* Fri Sep 15 2023 tiwai@suse.de
- wifi: mac80211: Support disabled links during association
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: dbg-tlv: clear FW debug memory on init
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: pcie: remove redundant argument (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: pcie: clear FW debug memory on init (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: dbg-tlv: fix DRAM data init (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: mvm: allow ADD_STA not to be advertised by the
  firwmare (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: put only a single IGTK into FW (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: mvm: Refactor iwl_mvm_get_lmac_id() (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: improve debug prints in iwl_read_ppag_table()
  (jsc#PED-6081 jsc#PED-6130).
- commit 5409bb1
* Fri Sep 15 2023 tiwai@suse.de
- wifi: mac80211: consistently use u64 for BSS changes
  (jsc#PED-6081 jsc#PED-6130).
- commit 1521a5d
* Fri Sep 15 2023 tiwai@suse.de
- wifi: mac80211: stop warning after reconfig failures
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: batch recalc during STA flush (jsc#PED-6081
  jsc#PED-6130).
- wifi: mac80211: move sta_info_move_state() up (jsc#PED-6081
  jsc#PED-6130).
- wifi: mac80211: refactor ieee80211_select_link_key()
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: use u64 to hold enum ieee80211_bss_change flags
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: implement proper AP MLD HW restart (jsc#PED-6081
  jsc#PED-6130).
- commit 753363d
* Fri Sep 15 2023 tiwai@suse.de
- wifi: iwlwifi: mvm: initialize the rx_vec before using it
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: rename BTM support flag and its TLV
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: support U-SIG EHT validate checks
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: Replace strlcpy with strscpy (jsc#PED-6081
  jsc#PED-6130).
- wifi: cfg80211: replace strlcpy() with strscpy() (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: mvm: Propagate ERP slot changes to FW
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: FTM responder MLO support (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: pass ESR parameters to the firmware (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: debugfs: add ppag capa to fw info file
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: always set MH len in offload_assist
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: provide a helper to fetch the medium
  synchronization delay (jsc#PED-6081 jsc#PED-6130).
- commit 6a7772a
* Fri Sep 15 2023 tiwai@suse.de
- wifi: iwlwifi: unify checks for HW error values (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: mvm: fix getting LDPC/STBC support (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: bump FW API to 79 for AX devices (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: update response for mcc_update command
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: FTM initiator MLO support (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: make debugfs entries link specific (jsc#PED-6081
  jsc#PED-6130).
- wifi: mac80211: Do not use "non-MLD AP" syntax (jsc#PED-6081
  jsc#PED-6130).
- wifi: cfg80211: Support association to AP MLD with disabled
  links (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: Add getter functions for vif MLD state
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: allow disabling SMPS debugfs controls
  (jsc#PED-6081 jsc#PED-6130).
- commit b403778
* Fri Sep 15 2023 tiwai@suse.de
- wifi: mac80211: don't update rx_stats.last_rate for NDP
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: fix CSA processing while scanning (jsc#PED-6081
  jsc#PED-6130).
- wifi: mac80211: mlme: clarify WMM messages (jsc#PED-6081
  jsc#PED-6130).
- wifi: mac80211: pass roc->sdata to
  drv_cancel_remain_on_channel() (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: include key action/command in tracing
  (jsc#PED-6081 jsc#PED-6130).
- wifi: cfg80211: S1G rate information and calculations
  (jsc#PED-6081 jsc#PED-6130).
- wifi: cfg80211: move scan done work to wiphy work (jsc#PED-6081
  jsc#PED-6130).
- wifi: cfg80211: move sched scan stop to wiphy work (jsc#PED-6081
  jsc#PED-6130).
- wifi: mac80211: mlme: move disconnects to wiphy work
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: ibss: move disconnect to wiphy work
  (jsc#PED-6081 jsc#PED-6130).
- commit a0083e7
* Fri Sep 15 2023 tiwai@suse.de
- wifi: mac80211: use wiphy work for channel switch (jsc#PED-6081
  jsc#PED-6130).
- wifi: mac80211: use wiphy work for SMPS (jsc#PED-6081
  jsc#PED-6130).
- wifi: mac80211: unregister netdevs through cfg80211
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: use wiphy work for sdata->work (jsc#PED-6081
  jsc#PED-6130).
- wifi: cfg80211: add a work abstraction with special semantics
  (jsc#PED-6081 jsc#PED-6130).
- wifi: cfg80211: hold wiphy lock when sending wiphy (jsc#PED-6081
  jsc#PED-6130).
- wifi: cfg80211: wext: hold wiphy lock in siwgenie (jsc#PED-6081
  jsc#PED-6130).
- wifi: cfg80211: move wowlan disable under locks (jsc#PED-6081
  jsc#PED-6130).
- wifi: cfg80211: hold wiphy lock in pmsr work (jsc#PED-6081
  jsc#PED-6130).
- wifi: cfg80211: hold wiphy lock in auto-disconnect (jsc#PED-6081
  jsc#PED-6130).
- commit e6208bf
* Fri Sep 15 2023 tiwai@suse.de
- wifi: mac80211: fetch and store the EML capability information
  (jsc#PED-6081 jsc#PED-6130).
- wifi: mac80211: skip EHT BSS membership selector (jsc#PED-6081
  jsc#PED-6130).
- wifi: mac80211: remove element scratch_len (jsc#PED-6081
  jsc#PED-6130).
- wifi: mac80211: HW restart for MLO (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: pnvm: handle memory descriptor tlv (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: fw: don't use constant size with efi.get_variable
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: fw: clean up PNVM loading code (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: Separate reading and parsing of reduce power
  table (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: Enable loading of reduce-power tables into
  several segments (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: Use iwl_pnvm_image in reduce power tables flow
  (jsc#PED-6081 jsc#PED-6130).
- commit 0c560aa
* Fri Sep 15 2023 tiwai@suse.de
- wifi: iwlwifi: Separate loading and setting of power reduce
  tables (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: Implement loading and setting of fragmented
  pnvm image (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: Add support for fragmented pnvm images
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: Allow trans_pcie track more than 1 pnvm DRAM
  region (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: Take loading and setting of pnvm image out of
  parsing part (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: Separate loading and setting of pnvm image into
  two functions (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: Generalize the parsing of the pnvm image
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: api: fix kernel-doc links (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: api: remove unused commands (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: api: use __le16 instead of u16 (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: api: link context action in kernel-doc
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: tell firmware about per-STA MFP enablement
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: remove warning for beacon filtering error
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: remove dead code in iwl_dump_ini_imr_get_size()
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: Add Dell to ppag approved list (jsc#PED-6081
  jsc#PED-6130).
- commit bef2178
* Fri Sep 15 2023 tiwai@suse.de
- wifi: iwlwifi: pcie: adjust Bz device timings (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: mvm: offload BTM response during D3 (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: do not log undefined DRAM buffers unnecessarily
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: acpi: add other Google OEMs to the ppag approved
  list (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: clarify EHT RU allocation bits (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: mvm: support injection rate control (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: Add vendors to TAS approved list (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: iwlmei: fix compilation error (jsc#PED-6081
  jsc#PED-6130).
- commit 09b5136
* Fri Sep 15 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update information about config files
  (jsc#PED-5021)
  * Use version variables to describe a name of the /boot/config-... file
  instead of using specific example versions which get outdated quickly.
  * Replace removed silentoldconfig with oldconfig.
  * Mention that oldconfig can automatically pick a base config from
  "/boot/config-$(uname -r)".
  * Avoid writing additional details in parentheses, incorporate them
  instead properly in the text.
- commit cba5807
* Fri Sep 15 2023 tiwai@suse.de
- wifi: iwlwifi: support PPAG in China for older FW cmd version
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: remove useless code (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: disable RX STBC when a device doesn't support it
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: fw: Add new ODM vendor to ppag approved list
  (jsc#PED-6081 jsc#PED-6130).
- commit a5ea8d0
* Fri Sep 15 2023 tiwai@suse.de
- wifi: iwlwifi: mvm: support PASN for MLO (jsc#PED-6081
  jsc#PED-6130).
- commit a8d85e8
* Fri Sep 15 2023 tiwai@suse.de
- wifi: iwlwifi: mvm: make internal callback structs const
  (jsc#PED-6081 jsc#PED-6130).
- commit f6d7c6e
* Fri Sep 15 2023 tiwai@suse.de
- wifi: iwlwifi: mvm: adjust csa notifications and commands to
  MLO (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: update the FW apis for LINK and MAC commands
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: Make iwl_mvm_diversity_iter() MLO aware
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: don't silently ignore missing suspend or resume
  ops (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: dissolve iwl_mvm_mac_add_interface_common()
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: mvm: use link ID in missed beacon notification
  (jsc#PED-6081 jsc#PED-6130).
- wifi: iwlwifi: cfg: freeze 22500 devices FW API (jsc#PED-6081
  jsc#PED-6130).
- wifi: iwlwifi: Use default @max_active for
  trans_pcie->rba.alloc_wq (jsc#PED-6081 jsc#PED-6130).
- commit 0e14ac5
* Fri Sep 15 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update the patch selection section
  (jsc#PED-5021)
  * Make the steps how to obtain expanded kernel source more generic in
  regards to version numbers.
  * Use '#' instead of '$' as the command line indicator to signal that
  the steps need to be run as root.
  * Update the format of linux-$SRCVERSION.tar.bz2 to xz.
  * Improve some wording.
- commit e14852c
* Fri Sep 15 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update information about (un)supported modules
  (jsc#PED-5021)
  * Update the list of taint flags. Convert it to a table that matches the
  upstream documentation format and describe specifically flags that are
  related to module support status.
  * Fix some typos and wording.
- commit e46f0df
* Fri Sep 15 2023 petr.pavlu@suse.com
- doc/README.SUSE: Bring information about compiling up to date
  (jsc#PED-5021)
  * When building the kernel, don't mention to initially change the
  current directory to /usr/src/linux because later description
  discourages it and specifies to use 'make -C /usr/src/linux'.
  * Avoid writing additional details in parentheses, incorporate them
  instead properly in the text.
  * Fix the obsolete name of /etc/modprobe.d/unsupported-modules ->
  /etc/modprobe.d/10-unsupported-modules.conf.
  * Drop a note that a newly built kernel should be added to the boot
  manager because that normally happens automatically when running
  'make install'.
  * Update a link to the Kernel Module Packages Manual.
  * When preparing a build for external modules, mention use of the
  upstream recommended 'make modules_prepare' instead of a pair of
  'make prepare' + 'make scripts'.
  * Fix some typos+grammar.
- commit b9b7e79
* Fri Sep 15 2023 tiwai@suse.de
- Update config files: version changed to 6.4 again
- commit 1360d10
* Fri Sep 15 2023 tiwai@suse.de
- selftest: tcp: Fix address length in bind_wildcard.c
  (git-fixes).
- r8152: check budget for r8152_poll() (git-fixes).
- selftests/ftrace: Fix dependencies for some of the synthetic
  event tests (git-fixes).
- Input: i8042 - add quirk for TUXEDO Gemini 17 Gen1/Clevo PD70PN
  (git-fixes).
- iommu: Remove kernel-doc warnings (git-fixes).
- iommu/amd/iommu_v2: Fix pasid_state refcount dec hit 0 warning
  on pasid unbind (git-fixes).
- iommu/vt-d: Fix to flush cache of PASID directory table
  (git-fixes).
- iommu/sprd: Add missing force_aperture (git-fixes).
- iommu/qcom: Disable and reset context bank before programming
  (git-fixes).
- iommu: rockchip: Fix directory table address encoding
  (git-fixes).
- iommu/mediatek: Fix two IOMMU share pagetable issue (git-fixes).
- interconnect: qcom: bcm-voter: Use enable_maks for keepalive
  voting (git-fixes).
- interconnect: qcom: bcm-voter: Improve enable_mask handling
  (git-fixes).
- kernfs: fix missing kernfs_iattr_rwsem locking (git-fixes).
- kernfs: add stub helper for kernfs_generic_poll() (git-fixes).
- serial: sc16is7xx: fix regression with GPIO configuration
  (git-fixes).
- serial: sc16is7xx: remove obsolete out_thread label (git-fixes).
- selftests/memfd: sysctl: fix MEMFD_NOEXEC_SCOPE_NOEXEC_ENFORCED
  (git-fixes).
- wifi: mt76: mt7915: fix capabilities in non-AP mode (git-fixes).
- wifi: mt76: mt7915: fix command timeout in AP stop period
  (git-fixes).
- mmc: renesas_sdhi: register irqs before registering controller
  (git-fixes).
- regmap: maple: Use alloc_flags for memory allocations
  (git-fixes).
- kbuild: rust_is_available: fix version check when CC has
  multiple arguments (git-fixes).
- kbuild: rust_is_available: remove -v option (git-fixes).
- platform/mellanox: Fix mlxbf-tmfifo not handling all virtio
  CONSOLE notifications (git-fixes).
- gpiolib: fix reference leaks when removing GPIO chips still
  in use (git-fixes).
- platform/x86/amd/pmf: Fix unsigned comparison with less than
  zero (git-fixes).
- wifi: ath12k: Fix buffer overflow when scanning with extraie
  (git-fixes).
- idmaengine: make FSL_EDMA and INTEL_IDMA64 depends on HAS_IOMEM
  (git-fixes).
- wifi: brcmfmac: Fix field-spanning write in
  brcmf_scan_params_v2_to_v1() (git-fixes).
- staging: fbtft: ili9341: use macro FBTFT_REGISTER_SPI_DRIVER
  (git-fixes).
- thermal: core: constify params in thermal_zone_device_register
  (git-fixes).
- security: keys: perform capable check only on privileged
  operations (git-fixes).
- phy: qcom-snps-femto-v2: use qcom_snps_hsphy_suspend/resume
  error code (git-fixes).
- platform/x86: huawei-wmi: Silence ambient light sensor
  (git-fixes).
- platform/x86: asus-wmi: Fix setting RGB mode on some TUF laptops
  (git-fixes).
- platform/x86: think-lmi: Use kfree_sensitive instead of kfree
  (git-fixes).
- platform/x86/intel/hid: Add HP Dragonfly G2 to VGBS DMI quirks
  (git-fixes).
- platform/x86: intel: hid: Always call BTNL ACPI method
  (git-fixes).
- media: pci: cx23885: fix error handling for cx23885 ATSC boards
  (git-fixes).
- media: pulse8-cec: handle possible ping error (git-fixes).
- media: imx-jpeg: Support to assign slot for encoder/decoder
  (git-fixes).
- media: amphion: use dev_err_probe (git-fixes).
- sbitmap: fix batching wakeup (git-fixes).
- Partially revert "drm/amd/display: Fix possible underflow for
  displays with large vblank" (git-fixes).
- regmap: Load register defaults in blocks rather than register
  by register (git-fixes).
- commit 6abb937
* Fri Sep 15 2023 tiwai@suse.de
- drm/msm/dpu: increase memtype count to 16 for sm8550
  (git-fixes).
- commit 081e740
* Fri Sep 15 2023 tiwai@suse.de
- dmaengine: idxd: Allow ATS disable update only for configurable
  devices (git-fixes).
- dmaengine: idxd: Expose ATS disable knob only when WQ ATS is
  supported (git-fixes).
- dmaengine: idxd: Simplify WQ attribute visibility checks
  (git-fixes).
- coresight: trbe: Fix TRBE potential sleep in atomic context
  (git-fixes).
- coresight: tmc: Explicit type conversions to prevent integer
  overflow (git-fixes).
- dt-bindings: clock: Update GCC clocks for QDU1000 and QRU1000
  SoCs (git-fixes).
- clk: qcom: gcc-sc8280xp: Add missing GDSCs (git-fixes).
- clk: qcom: gpucc-sm6350: Fix clock source names (git-fixes).
- clk: qcom: gpucc-sm6350: Introduce index-based clk lookup
  (git-fixes).
- drm/amd/display: ensure async flips are only accepted for fast
  updates (git-fixes).
- drm/amdgpu: Update min() to min_t() in 'amdgpu_info_ioctl'
  (git-fixes).
- crypto: stm32 - fix loop iterating through scatterlist for DMA
  (git-fixes).
- cpufreq: tegra194: remove opp table in exit hook (git-fixes).
- cpufreq: tegra194: add online/offline hooks (git-fixes).
- cpufreq: intel_pstate: set stale CPU frequency to minimum
  (git-fixes).
- fbdev: goldfishfb: Do not check 0 for platform_get_irq()
  (git-fixes).
- broadcom: b44: Use b44_writephy() return value (git-fixes).
- drm/amd/pm: Fix temperature unit of SMU v13.0.6 (git-fixes).
- drm/amdgpu: Match against exact bootloader status (git-fixes).
- clk: fixed-mmio: make COMMON_CLK_FIXED_MMIO depend on HAS_IOMEM
  (git-fixes).
- drm/amd/display: Exit idle optimizations before attempt to
  access PHY (git-fixes).
- drm/amd/display: Guard DCN31 PHYD32CLK logic against chip family
  (git-fixes).
- drm/amd/smu: use AverageGfxclkFrequency* to replace previous
  GFX Curr Clock (git-fixes).
- ethernet: atheros: fix return value check in atl1c_tso_csum()
  (git-fixes).
- drm/msm/dpu: drop the regdma configuration (git-fixes).
- commit 4e0044a
* Fri Sep 15 2023 tiwai@suse.de
- Bluetooth: hci_conn: Consolidate code for aborting connections
  (git-fixes).
- Refresh
  patches.suse/Bluetooth-Fix-double-free-in-hci_conn_cleanup.patch.
- commit 2d5d835
* Fri Sep 15 2023 tiwai@suse.de
- ASoC: cs35l56: Add an ACPI match table (git-fixes).
- commit 65a24dd
* Fri Sep 15 2023 tiwai@suse.de
- arm64: dts: qcom: apq8016-sbc: Rename ov5640 enable-gpios to
  powerdown-gpios (git-fixes).
- arm64: dts: qcom: sm8250-sony-xperia: correct GPIO keys wakeup
  again (git-fixes).
- arm64: dts: qcom: sm8250-edo: Rectify gpio-keys (git-fixes).
- arm64: dts: qcom: sm8250-edo: Add GPIO line names for PMIC GPIOs
  (git-fixes).
- arm64: dts: qcom: sm8250-edo: Add gpio line names for TLMM
  (git-fixes).
- Bluetooth: hci_conn: fail SCO/ISO via hci_conn_failed if ACL
  gone early (git-fixes).
- Bluetooth: hci_sync: Fix UAF in hci_disconnect_all_sync
  (git-fixes).
- Bluetooth: hci_event: drop only unbound CIS if Set CIG
  Parameters fails (git-fixes).
- Bluetooth: hci_sync: Avoid use-after-free in dbg for
  hci_add_adv_monitor() (git-fixes).
- Bluetooth: hci_conn: Fix hci_le_set_cig_params (git-fixes).
- Bluetooth: hci_sync: Fix UAF on hci_abort_conn_sync (git-fixes).
- Bluetooth: hci_sync: Don't double print name in add/remove
  adv_monitor (git-fixes).
- Bluetooth: ISO: Notify user space about failed bis connections
  (git-fixes).
- Bluetooth: hci_conn: Always allocate unique handles (git-fixes).
- Bluetooth: ISO: do not emit new LE Create CIS if previous is
  pending (git-fixes).
- Bluetooth: ISO: Add support for connecting multiple BISes
  (git-fixes).
- ASoC: rt1308-sdw: fix random louder sound (git-fixes).
- arm64: dts: rockchip: correct wifi interrupt flag in Box Demo
  (git-fixes).
- arm64: dts: rockchip: correct wifi interrupt flag in Rock Pi 4B
  (git-fixes).
- arm64: dts: rockchip: correct wifi interrupt flag in eaidk-610
  (git-fixes).
- ata: pata_arasan_cf: Use dev_err_probe() instead dev_err()
  in data_xfer() (git-fixes).
- 9p: virtio: make sure 'offs' is initialized in zc_request
  (git-fixes).
- 9p: virtio: fix unlikely null pointer deref in handle_rerror
  (git-fixes).
- ASoC: rt712-sdca: fix for JD event handling in ClockStop Mode0
  (git-fixes).
- ASoC: nau8821: Add DMI quirk mechanism for active-high
  jack-detect (git-fixes).
- Bluetooth: hci_event: Fix parsing of CIS Established Event
  (git-fixes).
- Bluetooth: hci_conn: Use kmemdup() to replace kzalloc + memcpy
  (git-fixes).
- ARM: dts: Add .dts files missing from the build (git-fixes).
- arm64: dts: qcom: msm8916: Rename &msmgpio -> &tlmm (git-fixes).
- arm64: dts: qcom: msm8916: Define regulator constraints next
  to usage (git-fixes).
- arm64: dts: qcom: msm8916: Disable audio codecs by default
  (git-fixes).
- arm64: dts: qcom: msm8916: Fix regulator constraints
  (git-fixes).
- arm64: dts: qcom: msm8916-longcheer-l8910: Add front flash LED
  (git-fixes).
- ARM: dts: stm32: Update to generic ADC channel binding on
  DHSOM systems (git-fixes).
- ARM: dts: stm32: adopt generic iio bindings for adc channels
  on emstamp-argon (git-fixes).
- ARM: dts: s5pv210: add dummy 5V regulator for backlight on
  SMDKv210 (git-fixes).
- commit 2753813
* Thu Sep 14 2023 nik.borisov@suse.com
- x86: Make IA32_EMULATION boot time configurable (jsc#PED-3184).
- commit 816d051
* Thu Sep 14 2023 nik.borisov@suse.com
- x86/entry: Make IA32 syscalls' availability depend on ia32_enabled() (jsc#PED-3184).
- commit d129cab
* Thu Sep 14 2023 nik.borisov@suse.com
- x86/elf: Make loading of 32bit processes depend on ia32_enabled() (jsc#PED-3184).
- commit b3c3c55
* Thu Sep 14 2023 nik.borisov@suse.com
- x86/entry: Compile entry_SYSCALL32_ignore() unconditionally (jsc#PED-3184).
- commit 3d9452a
* Thu Sep 14 2023 nik.borisov@suse.com
- x86/entry: Rename ignore_sysret() (jsc#PED-3184).
- commit 41cff48
* Thu Sep 14 2023 nik.borisov@suse.com
- x86: Introduce ia32_enabled() (jsc#PED-3184).
- commit 504ca1b
* Thu Sep 14 2023 mfranc@suse.cz
- s390/ipl: add missing secure/has_secure file to ipl type
  'unknown' (git-fixes bsc#1215345).
- commit a7273bc
* Thu Sep 14 2023 mfranc@suse.cz
- s390/dcssblk: fix kernel crash with list_add corruption
  (git-fixes bsc#1215344).
- commit 60ea829
* Thu Sep 14 2023 tiwai@suse.de
- Use base version 6.4
  Since our kernel is no longer based on 6.4.x stable but rather the
  mixture of all patches of our own, it's confusing to keep showing the
  base version 6.4.15.
  Let's drop the minor version and use 6.4 as the based version.
- commit 05a5919
* Thu Sep 14 2023 tiwai@suse.de
- Refresh patches.suse/thunderbolt-Add-support-for-enhanced-uni-directional.patch
  Correct the missing error handling
- commit 8489072
* Thu Sep 14 2023 msuchanek@suse.de
- Refresh patches.suse/powerpc-pseries-PLPKS-SED-Opal-keystore-support.patch.
  Fix crash on platforms that don't provide PKS.
- commit dc6b8a1
* Thu Sep 14 2023 krisman@suse.de
- io_uring: have io_file_put() take an io_kiocb rather than the
  file (bsc#1215211).
- io_uring/splice: use fput() directly (bsc#1215211).
- io_uring/fdinfo: get rid of ref tryget (bsc#1215211).
- io_uring: cleanup 'ret' handling in io_iopoll_check()
  (bsc#1215211).
- io_uring: break iopolling on signal (bsc#1215211).
- io_uring: fix false positive KASAN warnings (bsc#1215211).
- io_uring: fix drain stalls by invalid SQE (bsc#1215211).
- io_uring/rsrc: Remove unused declaration io_rsrc_put_tw()
  (bsc#1215211).
- io_uring: annotate the struct io_kiocb slab for appropriate
  user copy (bsc#1215211).
- commit 602ec65
* Wed Sep 13 2023 lduncan@suse.com
- scsi: qla2xxx: Error code did not return to upper layer
  (git-fixes).
- scsi: qla2xxx: Fix firmware resource tracking (git-fixes).
- commit 7eea791
* Wed Sep 13 2023 krisman@suse.de
- io_uring/cancel: wire up IORING_ASYNC_CANCEL_OP for sync cancel
  (bsc#1215211).
- io_uring/cancel: support opcode based lookup and cancelation
  (bsc#1215211).
- io_uring/cancel: add IORING_ASYNC_CANCEL_USERDATA (bsc#1215211).
- io_uring: use cancelation match helper for poll and timeout
  requests (bsc#1215211).
- io_uring/cancel: fix sequence matching for
  IORING_ASYNC_CANCEL_ANY (bsc#1215211).
- io_uring/cancel: abstract out request match helper
  (bsc#1215211).
- io_uring/timeout: always set 'ctx' in io_cancel_data
  (bsc#1215211).
- io_uring/poll: always set 'ctx' in io_cancel_data (bsc#1215211).
- commit 991e7db
* Wed Sep 13 2023 petr.pavlu@suse.com
- doc/README.SUSE: Bring the overview section up to date
  (jsc#PED-5021)
  * Update information in the overview section that was no longer
  accurate.
  * Improve wording and fix some typos+grammar.
- commit 798c075
* Wed Sep 13 2023 lduncan@suse.com
- scsi: mpt3sas: Perform additional retries if doorbell read
  returns 0 (git-fixes).
- Revert "scsi: qla2xxx: Fix buffer overrun" (git-fixes).
- scsi: qla2xxx: Flush mailbox commands on chip reset (git-fixes).
- scsi: fcoe: Fix potential deadlock on &fip->ctlr_lock
  (git-fixes).
- scsi: core: Use 32-bit hostnum in scsi_host_lookup()
  (git-fixes).
- scsi: qedf: Do not touch __user pointer in
  qedf_dbg_fp_int_cmd_read() directly (git-fixes).
- scsi: qedf: Do not touch __user pointer in
  qedf_dbg_debug_cmd_read() directly (git-fixes).
- scsi: qedf: Do not touch __user pointer in
  qedf_dbg_stop_io_on_error_cmd_read() directly (git-fixes).
- scsi: qla4xxx: Add length check when parsing nlattrs
  (git-fixes).
- scsi: be2iscsi: Add length check when parsing nlattrs
  (git-fixes).
- scsi: iscsi: Add strlen() check in iscsi_if_set{_host}_param()
  (git-fixes).
- scsi: iscsi: Add length check for nlattr payload (git-fixes).
- scsi: qla2xxx: Fix TMF leak through (git-fixes).
- scsi: qla2xxx: Fix session hang in gnl (git-fixes).
- scsi: qla2xxx: Fix command flush during TMF (git-fixes).
- scsi: qla2xxx: Limit TMF to 8 per function (git-fixes).
- scsi: qla2xxx: Fix deletion race condition (git-fixes).
- scsi: hisi_sas: Fix normally completed I/O analysed as failed
  (git-fixes).
- scsi: scsi_debug: Remove dead code (git-fixes).
- scsi: hisi_sas: Fix warnings detected by sparse (git-fixes).
- commit aa5199c
* Wed Sep 13 2023 tiwai@suse.de
- Sort all patches and clean up reverts/corrections
  For making easier to backport patches via git-fixes tracking, move
  all patches in patches.kernel.org/* into sorted section in
  patches.suse/*.   It essentially means that our kernel is a pot
  stewing all different fixes of our own choices, including the patches
  from existing stable trees.
  While transitioning to the flat structure, the commit ids are
  corrected in a couple of patches, a few reverted patches are simply
  dropped, and correction patches are folded into the original fix
  patches.
  The expanded result is exactly same as before this change.
- commit 9491f38
* Wed Sep 13 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update the references list (jsc#PED-5021)
  * Remove the reference to Linux Documentation Project. It has been
  inactive for years and mostly contains old manuals that aren't
  relevant for contemporary systems and hardware.
  * Update the name and link to LWN.net. The original name "Linux Weekly
  News" has been deemphasized over time by its authors.
  * Update the link to Kernel newbies website.
  * Update the reference to The Linux Kernel Module Programming Guide. The
  document has not been updated for over a decade but it looks its
  content is still relevant for today.
  * Point Kernel Module Packages Manual to the current version.
  * Add a reference to SUSE SolidDriver Program.
- commit 0edac75
* Wed Sep 13 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update title information (jsc#PED-5021)
  * Drop the mention of kernel versions from the readme title.
  * Remove information about the original authors of the document. Rely as
  in case of other readmes on Git metadata to get information about all
  contributions.
  * Strip the table of contents. The document is short and easy to
  navigate just by scrolling through it.
- commit 06f5139
* Wed Sep 13 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update information about DUD (jsc#PED-5021)
  Remove a dead link to description of Device Update Disks found
  previously on novell.com. Replace it with a short section summarizing
  what DUD is and reference the mkdud + mksusecd tools and their
  documentation for more information.
- commit 7eeba4e
* Wed Sep 13 2023 tiwai@suse.de
- platform/mellanox: NVSW_SN2201 should depend on ACPI
  (git-fixes).
- platform/mellanox: mlxbf-pmc: Fix reading of unprogrammed events
  (git-fixes).
- platform/mellanox: mlxbf-pmc: Fix potential buffer overflows
  (git-fixes).
- platform/mellanox: mlxbf-tmfifo: Drop jumbo frames (git-fixes).
- platform/mellanox: mlxbf-tmfifo: Drop the Rx packet if no more
  descriptors (git-fixes).
- selftests: Keep symlinks, when possible (git-fixes).
- kselftest/runner.sh: Propagate SIGTERM to runner child
  (git-fixes).
- kunit: Fix wild-memory-access bug in kunit_free_suite_set()
  (git-fixes).
- commit ed96bad
* Wed Sep 13 2023 tiwai@suse.de
- Remove stale comments in sorted section
- commit b97ff7e
* Wed Sep 13 2023 krisman@suse.de
- io_uring: flush offloaded and delayed task_work on exit
  (bsc#1215211).
- io_uring: remove io_fallback_tw() forward declaration
  (bsc#1215211).
- io_uring/net: use proper value for msg_inq (bsc#1215211).
- io_uring: merge conditional unlock flush helpers (bsc#1215211).
- io_uring: make io_cq_unlock_post static (bsc#1215211).
- io_uring: inline __io_cq_unlock (bsc#1215211).
- io_uring: fix acquire/release annotations (bsc#1215211).
- io_uring: kill io_cq_unlock() (bsc#1215211).
- io_uring: remove IOU_F_TWQ_FORCE_NORMAL (bsc#1215211).
- io_uring: don't batch task put on reqs free (bsc#1215211).
- io_uring: move io_clean_op() (bsc#1215211).
- io_uring: inline io_dismantle_req() (bsc#1215211).
- io_uring: remove io_free_req_tw (bsc#1215211).
- io_uring: open code io_put_req_find_next (bsc#1215211).
- commit 474274a
* Wed Sep 13 2023 krisman@suse.de
- io_uring: add helpers to decode the fixed file file_ptr
  (bsc#1215211).
- io_uring: use io_file_from_index in io_msg_grab_file
  (bsc#1215211).
- io_uring: use io_file_from_index in __io_sync_cancel
  (bsc#1215211).
- io_uring: return REQ_F_ flags from io_file_get_flags
  (bsc#1215211).
- io_uring: remove io_req_ffs_set (bsc#1215211).
- io_uring: remove a confusing comment above io_file_get_flags
  (bsc#1215211).
- io_uring: remove the mode variable in io_file_get_flags
  (bsc#1215211).
- io_uring: remove __io_file_supports_nowait (bsc#1215211).
- commit 477b728
* Wed Sep 13 2023 krisman@suse.de
- io_uring: get rid of unnecessary 'length' variable
  (bsc#1215211).
- io_uring: cleanup io_aux_cqe() API (bsc#1215211).
- io_uring: avoid indirect function calls for the hottest
  task_work (bsc#1215211).
- commit a422735
* Wed Sep 13 2023 krisman@suse.de
- nvme: optimise io_uring passthrough completion (bsc#1215211).
- io_uring/cmd: add cmd lazy tw wake helper (bsc#1215211).
- commit ce83753
* Tue Sep 12 2023 msuchanek@suse.de
- Delete patches.suse/genksyms-add-override-flag.diff.
  The override flag is no longer used in kernel-binary.
- commit 2e29826
* Tue Sep 12 2023 msuchanek@suse.de
- Refresh patches.suse/integrity-powerpc-Do-not-select-CA_MACHINE_KEYRING.patch.
- commit a01ab3d
* Tue Sep 12 2023 tiwai@suse.de
- Update config files: CONFIG_RTC_HCTOSYS=y for x86_64 and ppc64le (bsc#1214883)
  Enable it consistently on all possible archs.
- commit 4adfc00
* Tue Sep 12 2023 tiwai@suse.de
- Update config files: CONFIG_RESET_ATTACK_MITIGATION=y (bsc#1214883)
  Align with SLE15-SP6 configuration.
- commit 78d4022
* Tue Sep 12 2023 tiwai@suse.de
- Update config files: CONFIG_PERF_EVENTS_AMD_UNCORE=y (bsc#1214883)
  Align with SLE15-SP6 configuration.
- commit ef197cb
* Tue Sep 12 2023 mfranc@suse.cz
- s390/bpf: Pass through tail call counter in trampolines
  (git-fixes bsc#1215253).
- commit 9920b34
* Tue Sep 12 2023 tiwai@suse.de
- Update config files: enable CONFIG_SECURITY_DMESG_RESTRICT (bsc#1214883)
- commit 507ac2a
* Tue Sep 12 2023 mfranc@suse.cz
- s390/dasd: fix string length handling (git-fixes bsc#1215252).
- commit d32ce70
* Tue Sep 12 2023 tiwai@suse.de
- Update config files: enable missing NVMe features (bsc#1214883)
  CONFIG_NVME_AUTH=y, CONFIG_NVME_TARGET_PASSTHRU=y, CONFIG_NVME_TARGET_AUTH=y
- commit 09e32de
* Tue Sep 12 2023 jack@suse.cz
- ext4: drop dio overwrite only flag and associated warning
  (bsc#1215234).
- commit b4b1734
* Tue Sep 12 2023 jroedel@suse.de
- x86/sev: Make enc_dec_hypercall() accept a size instead of npages (bsc#1214635).
- commit 3282c63
* Tue Sep 12 2023 msuchanek@suse.de
- selftests/powerpc/dexcr: Add hashst/hashchk test (jsc#PED-5452).
- Documentation: Document PowerPC kernel DEXCR interface
  (jsc#PED-5452).
- powerpc/ptrace: Expose HASHKEYR register to ptrace
  (jsc#PED-5452).
- powerpc/ptrace: Expose DEXCR and HDEXCR registers to ptrace
  (jsc#PED-5452).
- powerpc/dexcr: Support userspace ROP protection (jsc#PED-5452).
- powerpc/dexcr: Handle hashchk exception (jsc#PED-5452).
- powerpc/dexcr: Add initial Dynamic Execution Control Register
  (DEXCR) support (jsc#PED-5452).
- powerpc/ptrace: Add missing <linux/regset.h> include
  (jsc#PED-5452).
- powerpc/book3s: Add missing <linux/sched.h> include
  (jsc#PED-5452).
- commit 512787e
* Tue Sep 12 2023 msuchanek@suse.de
- powerpc/pseries: PLPKS SED Opal keystore support (jsc#PED-3545).
  Update config files.
- block: sed-opal: keystore access for SED Opal keys
  (jsc#PED-3545).
- block:sed-opal: SED Opal keystore (jsc#PED-3545).
- commit 6e220a2
* Tue Sep 12 2023 petr.pavlu@suse.com
- rpm/kernel-binary.spec.in: Drop use of KBUILD_OVERRIDE=1
  Genksyms has functionality to specify an override for each type in
  a symtypes reference file. This override is then used instead of an
  actual type and allows to preserve modversions (CRCs) of symbols that
  reference the type. It is kind of an alternative to doing kABI fix-ups
  with '#ifndef __GENKSYMS__'. The functionality is hidden behind the
  genksyms --preserve option which primarily tells the tool to strictly
  verify modversions against a given reference file or fail.
  Downstream patch patches.suse/genksyms-add-override-flag.diff which is
  present in various kernel-source branches separates the override logic.
  It allows it to be enabled with a new --override flag and used without
  specifying the --preserve option. Setting KBUILD_OVERRIDE=1 in the spec
  file is then a way how the build is told that --override should be
  passed to all invocations of genksyms. This was needed for SUSE kernels
  because their build doesn't use --preserve but instead resulting CRCs
  are later checked by scripts/kabi.pl.
  However, this override functionality was not utilized much in practice
  and the only use currently to be found is in SLE11-SP1-LTSS. It means
  that no one should miss this option and KBUILD_OVERRIDE=1 together with
  patches.suse/genksyms-add-override-flag.diff can be removed.
  Notes for maintainers merging this commit to their branches:
  * Downstream patch patches.suse/genksyms-add-override-flag.diff can be
  dropped after merging this commit.
  * Branch SLE11-SP1-LTSS uses the mentioned override functionality and
  this commit should not be merged to it, or needs to be reverted
  afterwards.
- commit 4aa02b8
* Tue Sep 12 2023 jlee@suse.com
- Delete patches.suse/pstore_disable_efi_backend_by_default.patch.
  (bnc#804482, bsc#1198276)
  We enabled CONFIG_EFI_VARS_PSTORE_DEFAULT_DISABLE=y that it can be used
  to replace our downstream pstore_disable_efi_backend_by_default.patch
  patch to disable efi-pstore by default. So we removed
  pstore_disable_efi_backend_by_default.patch here.
- commit 5523168
* Tue Sep 12 2023 jlee@suse.com
- Update config files. (bnc#804482, bsc#1198276)
  Enable CONFIG_EFI_VARS_PSTORE_DEFAULT_DISABLE=y that it can be used
  to replace the downstream pstore_disable_efi_backend_by_default.patch
  patch to disable efi-pstore by default.
- commit f7a24c5
* Tue Sep 12 2023 jlee@suse.com
- Update config files. (jsc#PED-4365)
  Disabled hibernation verification because we removed the support
  in ALP. (jsc#PED-4365)
- Removed the following switches:
    CONFIG_HIBERNATE_VERIFICATION
    CONFIG_HIBERNATE_VERIFICATION_FORCE
- Disabled the following switches:
    CONFIG_EFI_SECRET_KEY=n
    CONFIG_HIDDEN_AREA=n
- commit cdef9ce
* Tue Sep 12 2023 jack@suse.cz
- ext4: do not mark inode dirty every time when appending using
  delalloc (bsc#1215234).
- commit 63674a0
* Tue Sep 12 2023 jack@suse.cz
- ext4: allow concurrent unaligned dio overwrites (bsc#1215234).
- commit cfe455c
* Tue Sep 12 2023 krisman@suse.de
- io_uring: support for user allocated memory for rings/sqes
  (bsc#1215211).
- commit 4014112
* Tue Sep 12 2023 krisman@suse.de
- io_uring: maintain ordering for DEFER_TASKRUN tw list
  (bsc#1215211).
- io_uring/net: don't retry recvmsg() unnecessarily (bsc#1215211).
- io_uring/net: push IORING_CQE_F_SOCK_NONEMPTY into
  io_recv_finish() (bsc#1215211).
- io_uring/net: initalize msghdr->msg_inq to known value
  (bsc#1215211).
- io_uring/net: initialize struct msghdr more sanely for io_recv()
  (bsc#1215211).
- io_uring: Add io_uring_setup flag to pre-register ring fd and
  never install it (bsc#1215211).
- io_uring: add ring freeing helper (bsc#1215211).
- io_uring: return error pointer from io_mem_alloc()
  (bsc#1215211).
- io_uring: remove sq/cq_off memset (bsc#1215211).
- io_uring: rely solely on FMODE_NOWAIT (bsc#1215211).
- block: mark bdev files as FMODE_NOWAIT if underlying device
  supports it (bsc#1215211).
- net: set FMODE_NOWAIT for sockets (bsc#1215211).
- commit c5f0cd7
* Mon Sep 11 2023 tiwai@suse.de
- pinctrl: intel: Add Intel Meteor Lake-S pin controller support
  (jsc#PED-6107, jsc#PED-6014).
- commit 7650815
* Mon Sep 11 2023 ohering@suse.de
- scsi: core: Improve type safety of scsi_rescan_device() (git-fixes).
- x86/hyperv: Remove duplicate include (git-fixes).
- x86/hyperv: Move the code in ivm.c around to avoid unnecessary ifdef's (git-fixes).
- x86/hyperv: Remove hv_isolation_type_en_snp (git-fixes).
- x86/hyperv: Use TDX GHCI to access some MSRs in a TDX VM with the paravisor (git-fixes).
- Drivers: hv: vmbus: Bring the post_msg_page back for TDX VMs with the paravisor (git-fixes).
- x86/hyperv: Introduce a global variable hyperv_paravisor_present (git-fixes).
- Drivers: hv: vmbus: Support >64 VPs for a fully enlightened TDX/SNP VM (git-fixes).
- x86/hyperv: Fix serial console interrupts for fully enlightened TDX guests (git-fixes).
- Drivers: hv: vmbus: Support fully enlightened TDX guests (git-fixes).
- x86/hyperv: Support hypercalls for fully enlightened TDX guests (git-fixes).
- x86/hyperv: Add hv_isolation_type_tdx() to detect TDX guests (git-fixes).
- x86/hyperv: Fix undefined reference to isolation_type_en_snp without CONFIG_HYPERV (git-fixes).
- x86/hyperv: Add missing 'inline' to hv_snp_boot_ap() stub (git-fixes).
- hv: hyperv.h: Replace one-element array with flexible-array member (git-fixes).
- Drivers: hv: vmbus: Don't dereference ACPI root object handle (git-fixes).
- x86/hyperv: Add hyperv-specific handling for VMMCALL under SEV-ES (git-fixes).
- x86/hyperv: Add smp support for SEV-SNP guest (git-fixes).
- clocksource: hyper-v: Mark hyperv tsc page unencrypted in sev-snp enlightened guest (git-fixes).
- x86/hyperv: Use vmmcall to implement Hyper-V hypercall in sev-snp enlightened guest (git-fixes).
- drivers: hv: Mark percpu hvcall input arg page unencrypted in SEV-SNP enlightened guest (git-fixes).
- x86/hyperv: Mark Hyper-V vp assist page unencrypted in SEV-SNP enlightened guest (git-fixes).
- x86/hyperv: Set Virtual Trust Level in VMBus init message (git-fixes).
- x86/hyperv: Add sev-snp enlightened guest static key (git-fixes).
- scsi: storvsc: Handle additional SRB status values (git-fixes).
- net: mana: Add gdma stats to ethtool output for mana (git-fixes).
- net/mlx5: remove many unnecessary NULL values (git-fixes).
- net: mana: Add page pool for RX buffers (git-fixes).
- net: mana: Configure hwc timeout from hardware (git-fixes).
- net: mana: Use the correct WQE count for ringing RQ doorbell (git-fixes).
- net: mana: Batch ringing RX queue doorbell on receiving packets (git-fixes).
- Drivers: hv: vmbus: Remove unused extern declaration vmbus_ontimer() (git-fixes).
- x86/hyperv: add noop functions to x86_init mpparse functions (git-fixes).
- vmbus_testing: fix wrong python syntax for integer value comparison (git-fixes).
- x86/hyperv: fix a warning in mshyperv.h (git-fixes).
- x86/hyperv: Improve code for referencing hyperv_pcpu_input_arg (git-fixes).
- Drivers: hv: Change hv_free_hyperv_page() to take void * argument (git-fixes).
- scsi: storvsc: Handle SRB status value 0x30 (git-fixes).
- net: mana: use vmalloc_array and vcalloc (git-fixes).
- hv_netvsc: Allocate rx indirection table size dynamically (git-fixes).
- clocksource: hyper-v: Adjust hv_read_tsc_page_tsc() to avoid special casing U64_MAX (git-fixes).
- x86/vdso: Fix gettimeofday masking (git-fixes).
- x86/coco: Get rid of accessor functions (git-fixes).
- clocksource/drivers/hyper-v: Rework clocksource and sched clock setup (git-fixes).
- commit 31e4022
* Mon Sep 11 2023 msuchanek@suse.de
- powerpc/iommu: Fix notifiers being shared by PCI and VIO buses
  (bsc#1065729).
- powerpc/xics: Remove unnecessary endian conversion
  (bsc#1065729).
- commit d30f4b4
* Mon Sep 11 2023 petr.pavlu@suse.com
- mlx4: Delete custom device management logic (bsc#1187236).
- mlx4: Connect the infiniband part to the auxiliary bus
  (bsc#1187236).
- mlx4: Connect the ethernet part to the auxiliary bus
  (bsc#1187236).
- mlx4: Register mlx4 devices to an auxiliary virtual bus
  (bsc#1187236).
- mlx4: Avoid resetting MLX4_INTFF_BONDING per driver
  (bsc#1187236).
- mlx4: Move the bond work to the core driver (bsc#1187236).
- mlx4: Get rid of the mlx4_interface.activate callback
  (bsc#1187236).
- mlx4: Replace the mlx4_interface.event callback with a notifier
  (bsc#1187236).
- mlx4: Use 'void *' as the event param of mlx4_dispatch_event()
  (bsc#1187236).
- mlx4: Rename member mlx4_en_dev.nb to netdev_nb (bsc#1187236).
- mlx4: Get rid of the mlx4_interface.get_dev callback
  (bsc#1187236).
- net/mlx4: Remove many unnecessary NULL values (bsc#1187236).
- commit e58c7a4
* Mon Sep 11 2023 msuchanek@suse.de
- powerpc/pseries: PLPK: undo kernel-doc comment notation
  (bsc#1215199).
- commit c1e63ba
* Mon Sep 11 2023 nik.borisov@suse.com
- kABI: Reserve extra space for future cpuid/bug ints (kABI).
- commit 4bfa4f1
* Mon Sep 11 2023 nik.borisov@suse.com
- x86/virt: Drop unnecessary check on extended CPUID level in cpu_has_svm() (git-fixes).
- commit 0b2e0cd
* Mon Sep 11 2023 nik.borisov@suse.com
- x86/speculation: Mark all Skylake CPUs as vulnerable to GDS (git-fixes).
- commit 61b85d3
* Mon Sep 11 2023 nik.borisov@suse.com
- x86/sgx: Break up long non-preemptible delays in sgx_vepc_release() (git-fixes).
- commit 97e9703
* Mon Sep 11 2023 nik.borisov@suse.com
- x86/mm: Fix PAT bit missing from page protection modify mask (git-fixes).
- commit 33d3430
* Mon Sep 11 2023 nik.borisov@suse.com
- x86/decompressor: Don't rely on upper 32 bits of GPRs being preserved (git-fixes).
- commit dd3eca0
* Mon Sep 11 2023 nik.borisov@suse.com
- x86/cpu: Fix amd_check_microcode() declaration (git-fixes).
- commit a4a58c5
* Mon Sep 11 2023 nik.borisov@suse.com
- x86/build: Fix linker fill bytes quirk/incompatibility for ld.lld (git-fixes).
- commit c103809
* Mon Sep 11 2023 nik.borisov@suse.com
- x86/alternative: Add a __alt_reloc_selftest() prototype (git-fixes).
- commit f671c66
* Mon Sep 11 2023 nik.borisov@suse.com
- x86: Remove the arch_calc_vm_prot_bits() macro from the UAPI (git-fixes).
- commit 2ca1850
* Mon Sep 11 2023 nik.borisov@suse.com
- x86/APM: drop the duplicate APM_MINOR_DEV macro (git-fixes).
- commit be5e14b
* Mon Sep 11 2023 nik.borisov@suse.com
- locking/arch: Avoid variable shadowing in local_try_cmpxchg() (git-fixes).
- commit 35707d1
* Mon Sep 11 2023 nik.borisov@suse.com
- KVM: SVM: correct the size of spec_ctrl field in VMCB save area (git-fixes).
- commit 5e2d83e
* Mon Sep 11 2023 tiwai@suse.de
- iov_iter: Fix iov_iter_extract_pages() with zero-sized entries
  (git-fixes).
- media: dvb: symbol fixup for dvb_attach() (git-fixes).
- Revert "PCI: Mark NVIDIA T4 GPUs to avoid bus reset"
  (git-fixes).
- PCI: Free released resource after coalescing (git-fixes).
- ntb: Fix calculation ntb_transport_tx_free_entry() (git-fixes).
- ntb: Drop packets when qp link is down (git-fixes).
- ntb: Clean up tx tail index on link down (git-fixes).
- idr: fix param name in idr_alloc_cyclic() doc (git-fixes).
- XArray: Do not return sibling entries from xa_load()
  (git-fixes).
- commit 02c4a14
* Sat Sep  9 2023 tiwai@suse.de
- ALSA: hda/cirrus: Fix broken audio on hardware with two CS42L42
  codecs (git-fixes).
- arm64: csum: Fix OoB access in IP checksum code for negative
  lengths (git-fixes).
- commit 83dedd5
* Fri Sep  8 2023 msuchanek@suse.de
- selftests/powerpc: add const qualification where possible
  (jsc#PED-4486).
- selftests/powerpc: Add more utility macros (jsc#PED-4486).
- commit 5daf13c
* Fri Sep  8 2023 mfranc@suse.cz
- s390/zcrypt_ep11misc: support API ordinal 6 with empty pin-blob
  (jsc#PED-6375).
- commit 2756530
* Fri Sep  8 2023 mfranc@suse.cz
- s390/pkey: fix PKEY_TYPE_EP11_AES handling for sysfs attributes
  (jsc#PED-6371).
- commit 565a508
* Fri Sep  8 2023 mfranc@suse.cz
- s390/pkey: fix PKEY_TYPE_EP11_AES handling in PKEY_KBLOB2PROTK
  (jsc#PED-6371).
- commit e5ba8eb
* Fri Sep  8 2023 mfranc@suse.cz
- s390/pkey: fix PKEY_TYPE_EP11_AES handling in PKEY_VERIFYKEY2
  IOCTL (jsc#PED-6371).
- commit 7e4d39b
* Fri Sep  8 2023 mfranc@suse.cz
- s390/pkey: fix PKEY_TYPE_EP11_AES handling in PKEY_CLR2SECK2
  IOCTL (jsc#PED-6371).
- commit 6bfc7d7
* Fri Sep  8 2023 mfranc@suse.cz
- s390/pkey: fix PKEY_TYPE_EP11_AES handling in PKEY_GENSECK2
  IOCTL (jsc#PED-6371).
- commit c2c7df8
* Fri Sep  8 2023 mfranc@suse.cz
- s390/pkey: fix/harmonize internal keyblob headers
  (jsc#PED-6371).
- commit 65550d5
* Fri Sep  8 2023 petr.pavlu@suse.com
- config/arm64: unset CONFIG_DEBUG_FORCE_FUNCTION_ALIGN_64B.
  Configuration option CONFIG_DEBUG_FORCE_FUNCTION_ALIGN_64B=y is used
  only in the arm64 configuration and appears to be a relic from the
  update procedure in commit 98da1c5f42d ("SLE15-SP4: Update the base
  kernel version to 5.14.").
  Unset it because the option is intended for debugging, not really useful
  for production and makes the text size of vmlinux unnecessarily bigger
  by ~10%%.
- commit 9b526eb
* Fri Sep  8 2023 mfranc@suse.cz
- s390/pkey: add support for ecc clear key (jsc#PED-6371).
- commit 4dc5d19
* Fri Sep  8 2023 mfranc@suse.cz
- s390/pkey: do not use struct pkey_protkey (jsc#PED-6371).
- commit 7f7a69f
* Fri Sep  8 2023 mfranc@suse.cz
- s390/pkey: introduce reverse x-mas trees (jsc#PED-6371).
- commit 30df220
* Fri Sep  8 2023 tiwai@suse.de
- Revert "modules: only allow symbol_get of EXPORT_SYMBOL_GPL
  modules" (bsc#1215155).
- blacklist.conf: add the entry for reverted commit
- commit e0404b9
* Fri Sep  8 2023 dwagner@suse.de
- nvme-tcp: add recovery_delay to sysfs (bsc#1201284).
- nvme-tcp: delay error recovery until the next KATO interval
  (bsc#1201284).
- nvme-tcp: make 'err_work' a delayed work (bsc#1201284).
- nvme-tcp: Do not terminate commands when in RESETTING
  (bsc#1201284).
- commit f07ef6b
* Fri Sep  8 2023 mfranc@suse.cz
- s390/zcrypt: don't leak memory if dev_set_name() fails
  (git-fixes bsc#1215143).
- commit 2fc4ca5
* Fri Sep  8 2023 tiwai@suse.de
- drm/amd/display: prevent potential division by zero errors
  (git-fixes).
- drm/amd/display: enable cursor degamma for DCN3+ DRM legacy
  gamma (git-fixes).
- Revert "drm/amd/display: Remove v_startup workaround for dcn3+"
  (git-fixes).
- drm/amd/display: always switch off ODM before committing more
  streams (git-fixes).
- drm/amd/display: Remove wait while locked (git-fixes).
- drm/amd/display: Add smu write msg id fail retry process
  (git-fixes).
- drm/amd/display: register edp_backlight_control() for DCN301
  (git-fixes).
- drm/i915: mark requests for GuC virtual engines to avoid
  use-after-free (git-fixes).
- accel/ivpu: refactor deprecated strncpy (git-fixes).
- af_unix: Fix data race around sk->sk_err (git-fixes).
- af_unix: Fix data-races around sk->sk_shutdown (git-fixes).
- af_unix: Fix data-race around unix_tot_inflight (git-fixes).
- af_unix: Fix data-races around user->unix_inflight (git-fixes).
- net: phy: micrel: Correct bit assignments for phy_device flags
  (git-fixes).
- pwm: lpc32xx: Remove handling of PWM channels (git-fixes).
- pwm: Remove outdated documentation for pwmchip_remove()
  (git-fixes).
- i3c: master: svc: fix probe failure when no i3c device exist
  (git-fixes).
- drm/i915/gvt: Drop unused helper intel_vgpu_reset_gtt()
  (git-fixes).
- drm/i915/gvt: Put the page reference obtained by KVM's
  gfn_to_pfn() (git-fixes).
- drm/i915/gvt: Verify pfn is "valid" before dereferencing
  "struct page" (git-fixes).
- commit 63b1a56
* Thu Sep  7 2023 msuchanek@suse.de
- integrity: PowerVM support for loading third party code signing
  keys (jsc#PED-5085).
- integrity: PowerVM machine keyring enablement (jsc#PED-5085).
- integrity: powerpc: Do not select CA_MACHINE_KEYRING
- Update config files.
- integrity: check whether imputed trust is enabled
  (jsc#PED-5085).
- integrity: remove global variable from machine_keyring.c
  (jsc#PED-5085).
- integrity: ignore keys failing CA restrictions on non-UEFI
  platform (jsc#PED-5085).
- integrity: PowerVM support for loading CA keys on machine
  keyring (jsc#PED-5085).
- integrity: Enforce digitalSignature usage in the ima and evm
  keyrings (jsc#PED-5085).
- KEYS: DigitalSignature link restriction (jsc#PED-5085).
- commit e3cf1f9
* Thu Sep  7 2023 jeffm@suse.com
- Delete patches.suse/xfs-repair-malformed-inode-items-during-log-recovery.patch.
  This was a fix for a regression that occurred in SLE12 SP1.
  Since we don't support upgrading to SLE15 from releases older than SLE12
  SP4, which contained this fix, we can safely drop it now.
- commit a7045a7
* Thu Sep  7 2023 tzimmermann@suse.com
- config/armv7hl: Bootup with DRM and simpledrm (jsc#PED-1117)
- commit 63428de
* Thu Sep  7 2023 tiwai@suse.de
- Update config files: only bump version to 6.4.15
- commit a4856c8
* Thu Sep  7 2023 tiwai@suse.de
- Input: iqs7222 - configure power mode before triggering ATI
  (git-fixes).
- watchdog: intel-mid_wdt: add MODULE_ALIAS() to allow auto-load
  (git-fixes).
- backlight: gpio_backlight: Drop output GPIO direction check
  for initial power state (git-fixes).
- commit 03904d5
* Thu Sep  7 2023 tiwai@suse.de
- Linux 6.4.15 (bsc#1012628).
- pinctrl: amd: Don't show `Invalid config param` errors
  (bsc#1012628 bsc#1214212).
- usb: typec: tcpci: clear the fault status bit (bsc#1012628).
  Drop patches.suse/usb-typec-tcpci-clear-the-fault-status-bit.patch
- nilfs2: fix WARNING in mark_buffer_dirty due to discarded
  buffer reuse (bsc#1012628).
  Drop patches.suse/nilfs2-fix-WARNING-in-mark_buffer_dirty-due-to-disca.patch
- dt-bindings: sc16is7xx: Add property to change GPIO function
  (bsc#1012628).
- tcpm: Avoid soft reset when partner does not support get_status
  (bsc#1012628).
  Drop patches.suse/tcpm-Avoid-soft-reset-when-partner-does-not-support-.patch
- fsi: master-ast-cf: Add MODULE_FIRMWARE macro (bsc#1012628).
  Drop patches.suse/fsi-master-ast-cf-Add-MODULE_FIRMWARE-macro.patch
- firmware: stratix10-svc: Fix an NULL vs IS_ERR() bug in probe
  (bsc#1012628).
  Drop patches.suse/firmware-stratix10-svc-Fix-an-NULL-vs-IS_ERR-bug-in-.patch
- serial: sc16is7xx: fix bug when first setting GPIO direction
  (bsc#1012628).
  Drop patches.suse/serial-sc16is7xx-fix-bug-when-first-setting-GPIO-dir.patch
- serial: sc16is7xx: fix broken port 0 uart init (bsc#1012628).
  Drop patches.suse/serial-sc16is7xx-fix-broken-port-0-uart-init.patch
- serial: qcom-geni: fix opp vote on shutdown (bsc#1012628).
  Drop patches.suse/serial-qcom-geni-fix-opp-vote-on-shutdown.patch
- wifi: ath11k: Cleanup mac80211 references on failure during
  tx_complete (bsc#1012628).
  Drop patches.suse/wifi-ath11k-Cleanup-mac80211-references-on-failure-d.patch
- wifi: ath11k: Don't drop tx_status when peer cannot be found
  (bsc#1012628).
  Drop patches.suse/wifi-ath11k-Don-t-drop-tx_status-when-peer-cannot-be.patch
- wifi: rtw88: usb: kill and free rx urbs on probe failure
  (bsc#1012628).
  Remove patches.suse/wifi-rtw88-usb-kill-and-free-rx-urbs-on-probe-failur.patch
- wifi: mt76: mt7921: fix skb leak by txs missing in AMSDU
  (bsc#1012628).
  patches.suse/wifi-mt76-mt7921-fix-skb-leak-by-txs-missing-in-AMSD.patch
- wifi: mt76: mt7921: do not support one stream on secondary
  antenna only (bsc#1012628).
  Drop patches.suse/wifi-mt76-mt7921-do-not-support-one-stream-on-second.patch
- staging: rtl8712: fix race condition (bsc#1012628).
  Drop patches.suse/staging-rtl8712-fix-race-condition.patch
- HID: wacom: remove the battery when the EKR is off
  (bsc#1012628).
  Drop patches.suse/HID-wacom-remove-the-battery-when-the-EKR-is-off.patch
- usb: chipidea: imx: improve logic if samsung,picophy-* parameter
  is 0 (bsc#1012628).
  Drop patches.suse/usb-chipidea-imx-improve-logic-if-samsung-picophy-pa.patch
- usb: dwc3: meson-g12a: do post init to fix broken usb after
  resumption (bsc#1012628).
  Drop patches.suse/usb-dwc3-meson-g12a-do-post-init-to-fix-broken-usb-a.patch
- ALSA: usb-audio: Fix init call orders for UAC1 (bsc#1012628).
- USB: serial: option: add FOXCONN T99W368/T99W373 product
  (bsc#1012628).
- USB: serial: option: add Quectel EM05G variant (0x030e)
  (bsc#1012628).
- modules: only allow symbol_get of EXPORT_SYMBOL_GPL modules
  (bsc#1012628).
- rtc: ds1685: use EXPORT_SYMBOL_GPL for ds1685_rtc_poweroff
  (bsc#1012628).
- net: enetc: use EXPORT_SYMBOL_GPL for enetc_phc_index
  (bsc#1012628).
- mmc: au1xmmc: force non-modular build and remove symbol_get
  usage (bsc#1012628).
- ARM: pxa: remove use of symbol_get() (bsc#1012628).
- ksmbd: reduce descriptor size if remaining bytes is less than
  request size (bsc#1012628).
- ksmbd: replace one-element array with flex-array member in
  struct smb2_ea_info (bsc#1012628).
- ksmbd: fix slub overflow in ksmbd_decode_ntlmssp_auth_blob()
  (bsc#1012628).
- ksmbd: fix wrong DataOffset validation of create context
  (bsc#1012628).
- erofs: ensure that the post-EOF tails are all zeroed
  (bsc#1012628).
- commit 603fb0d
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Check Intel vendor ID in tb_switch_get_generation()
  (jsc#PED-6061).
- commit 9040262
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Log a warning if device links are not found
  (jsc#PED-6061).
- commit 0080c7d
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Set variable tmu_params storage class specifier
  to static (jsc#PED-6061).
- commit 2311697
* Wed Sep  6 2023 oneukum@suse.com
- usb: misc: onboard-hub: support multiple power supplies
  (jsc#PED-6061).
- usb: host: xhci: Do not re-initialize the XHCI HC if being
  removed (jsc#PED-6061).
- thunderbolt: Add test case for 3 DisplayPort tunnels
  (jsc#PED-6118).
- commit 74e5760
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Add DisplayPort 2.x tunneling support
  (jsc#PED-6118).
- commit 5c47cef
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Make bandwidth allocation mode function names
  consistent (jsc#PED-6118).
- commit aebe5c3
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Enable CL2 low power state (jsc#PED-6057).
- commit 38017ba
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Add support for enhanced uni-directional TMU mode
  (jsc#PED-6061).
- commit 6788a0e
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Increase NVM_MAX_SIZE to support Intel Barlow
  Ridge controller (jsc#PED-6061).
- commit 76ff566
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Move constants related to NVM into nvm.c
  (jsc#PED-6061).
- commit 9e2eab8
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Fix PCIe adapter capability length for USB4 v2
  routers (jsc#PED-6061).
- commit 63af050
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Fix DisplayPort IN adapter capability length for
  USB4 v2 routers (jsc#PED-6061 jsc#PED-6118).
- commit 79f78db
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Add two additional double words for adapters TMU
  for USB4 v2 routers (jsc#PED-6061).
- commit 2382454
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Enable USB4 v2 PCIe TLP/DLLP extended encapsulation
  (jsc#PED-6061).
- commit 13c3320
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Announce USB4 v2 connection manager support
  (jsc#PED-6061).
- commit 2b7b8cb
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Reset USB4 v2 host router (jsc#PED-6061).
- commit da53ab5
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Add the new USB4 v2 notification types
  (jsc#PED-6061).
- thunderbolt: Add support for USB4 v2 80 Gb/s link
  (jsc#PED-6061).
- commit 81b59d1
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Identify USB4 v2 routers (jsc#PED-6061).
- commit 8f5f0bb
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Do not touch lane 1 adapter path config space
  (jsc#PED-6061).
- commit d47992e
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Ignore data CRC mismatch for USB4 routers
  (jsc#PED-6061).
- commit 6322c4a
* Wed Sep  6 2023 jlee@suse.com
- supported.conf: remove Unsupported tag of einj (bsc#1023051 CVE-2016-3695)
  Removed Unsupported tag of drivers/acpi/apei/einj to align with
  15-SP5. Like 15-SP5, 15-SP6 has backported downstream patch
  acpi-Disable-APEI-error-injection-if-the-kernel-is-lockeddown.patch.
  So it should be fine.
  For ALP, we turn-off CONFIG_ACPI_APEI_EINJ and also add Unsupported
  tag to einj driver. Because ALP is new and we do not need it in ALP
  currently.
- commit ba27138
* Wed Sep  6 2023 oneukum@suse.com
- usb: update the ctime as well when updating mtime after an ioctl
  (git-fixes).
- commit a1c1e20
* Wed Sep  6 2023 oneukum@suse.com
- usb: core: add sysfs entry for usb device state (jsc#PED-6061).
- commit 747c9c5
* Wed Sep  6 2023 oneukum@suse.com
- xhci: Stop unnecessary tracking of free trbs in a ring
  (jsc#PED-6061).
- commit e7a2864
* Wed Sep  6 2023 oneukum@suse.com
- xhci: Fix transfer ring expansion size calculation
  (jsc#PED-6061).
- commit 0c38cae
* Wed Sep  6 2023 oneukum@suse.com
- xhci: split allocate interrupter into separate alloacte and
  add parts (jsc#PED-6061).
- commit 98c2b9c
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Enable/disable sideband depending on USB4 port
  offline mode (jsc#PED-6061).
- commit 953c113
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Do not send UNSET_INBOUND_SBTX when retimer NVM
  authentication started (jsc#PED-6061).
- commit 2f36306
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Disable CL states when a DMA tunnel is established
  (jsc#PED-6057).
- commit b3ed9bb
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Make tb_switch_clx_disable() return CL states
  that were enabled (jsc#PED-6057).
- commit f883435
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Initialize CL states from the hardware
  (jsc#PED-6057.
- commit f123b6e
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Prefix CL state related log messages with "CLx:
  " (jsc#PED-6057).
- commit 000c1d2
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Prefix TMU post time log message with "TMU: "
  (jsc#PED-6061).
- commit 0fd3fed
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Do not call CLx functions from TMU code
  (jsc#PED-6057).
- thunderbolt: Check for first depth router in tb.c
  (jsc#PED-6057).
- commit f52c3cc
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Switch CL states from enum to a bitmask
  (jsc#PED-6057).
- commit 25ff961
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Move CLx enabling into tb_enable_clx()
  (jsc#PED-6061).
- commit fbe701d
* Wed Sep  6 2023 tiwai@suse.de
- Re-enable patches.suse/0003-Add-external-no-support-as-bad-taint-module.patch
- commit 179979d
* Wed Sep  6 2023 tiwai@suse.de
- Update config files: disable CONFIG_BLK_CGROUP_IOPRIO again (bsc#1214883)
- commit 7710a12
* Wed Sep  6 2023 denis.kirjanov@suse.com
- ixgbevf: Remove unused function declarations (jsc#PED-4102).
- commit d7b32c5
* Wed Sep  6 2023 denis.kirjanov@suse.com
- ethernet: tg3: remove unreachable code (jsc#PED-3526).
- commit cd65a79
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Get rid of __tb_switch_[en|dis]able_clx()
  (jsc#PED-6061).
- commit 265436e
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Move CLx support functions into clx.c
  (jsc#PED-6061).
- commit 9778ac2
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Check valid TMU configuration in
  tb_switch_tmu_configure() (jsc#PED-6061).
- commit 72e13bd
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Move tb_enable_tmu() close to other TMU functions
  (jsc#PED-6061).
- commit 677e0a0
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Move TMU configuration to tb_enable_tmu()
  (jsc#PED-6061).
- commit 0bdd5bf
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Get rid of tb_switch_enable_tmu_1st_child()
  (jsc#PED-6061).
- commit 5c56d8e
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Rework Titan Ridge TMU objection disable function
  (jsc#PED-6061).
- commit e8db754
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Drop useless 'unidirectional' parameter from
  tb_switch_tmu_is_enabled() (jsc#PED-6061).
- commit 4f100be
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Fix a couple of style issues in TMU code
  (jsc#PED-6061).
- commit 02653e5
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Introduce tb_xdomain_downstream_port()
  (jsc#PED-6061).
- commit 1cad062
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Introduce tb_switch_downstream_port()
  (jsc#PED-6061).
- commit 4fafc5b
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Log DisplayPort adapter rate and lanes on discovery
  (jsc#PED-6061).
- commit 1613acc
* Wed Sep  6 2023 tiwai@suse.de
- Bluetooth: HCI: Introduce HCI_QUIRK_BROKEN_LE_CODED
  (bsc#1213972).
- commit 7e8d545
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: dma_test: Update MODULE_DESCRIPTION (jsc#PED-6061).
- commit 7c7578c
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Add MODULE_DESCRIPTION (jsc#PED-6061).
- commit 036b91f
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Allow specifying custom credits for DMA tunnels
  (jsc#PED-6061).
- commit 4cd9a38
* Wed Sep  6 2023 oneukum@suse.com
- thunderbolt: Check for ring 0 in tb_tunnel_alloc_dma()
  (jsc#PED-6061).
- commit 9057218
* Wed Sep  6 2023 tiwai@suse.de
- ata: pata_falcon: fix IO base selection for Q40 (git-fixes).
- ata: sata_gemini: Add missing MODULE_DESCRIPTION (git-fixes).
- ata: pata_ftide010: Add missing MODULE_DESCRIPTION (git-fixes).
- mailbox: qcom-ipcc: fix incorrect num_chans counting
  (git-fixes).
- tpm: Enable hwrng only for Pluton on AMD CPUs (git-fixes).
- tpm_crb: Fix an error handling path in crb_acpi_add()
  (git-fixes).
- kconfig: fix possible buffer overflow (git-fixes).
- kbuild: do not run depmod for 'make modules_sign' (git-fixes).
- kbuild: rpm-pkg: define _arch conditionally (git-fixes).
- docs/mm: remove references to hmm_mirror ops and clean typos
  (git-fixes).
- commit e114715
* Wed Sep  6 2023 jlee@suse.com
- Update References tag
  patches.kernel.org/6.4.10-139-Bluetooth-L2CAP-Fix-use-after-free-in-l2cap_so.patch
  (bsc#1012628 bsc#1214233 CVE-2023-40283).
- commit 8f10909
* Wed Sep  6 2023 mkubecek@suse.cz
- update patch metadata
- update upstream references
  - patches.rpmify/Revert-kbuild-Hack-for-depmod-not-handling-X.Y-versi.patch
- commit 30a3314
* Tue Sep  5 2023 palcantara@suse.de
- cifs: Fix UAF in cifs_demultiplex_thread() (bsc#1208995
  CVE-2023-1192).
- commit 9c2a087
* Tue Sep  5 2023 ddiss@suse.de
- Update config files.
  CONFIG_TCM_RBD=m
- commit 6044036
* Tue Sep  5 2023 tbogendoerfer@suse.de
- RDMA/irdma: Move iw device ops initialization (jsc#PED-4862).
- RDMA/irdma: Return void from irdma_init_rdma_device()
  (jsc#PED-4862).
- RDMA/irdma: Return void from irdma_init_iw_device()
  (jsc#PED-4862).
- ice: use ice_down_up() where applicable (jsc#PED-4876).
- ice: Remove managed memory usage in ice_get_fw_log_cfg()
  (jsc#PED-4876).
- ice: remove null checks before devm_kfree() calls
  (jsc#PED-4876).
- ice: clean up freeing SR-IOV VFs (jsc#PED-4876).
- ice: allow hot-swapping XDP programs (jsc#PED-4876).
- ice: reduce initial wait for control queue messages
  (jsc#PED-4876).
- iavf: remove some unused functions and pointless wrappers
  (jsc#PED-4937).
- iavf: fix err handling for MAC replace (jsc#PED-4937).
- i40e, xsk: fix comment typo (jsc#PED-4874).
- ice: remove unnecessary check for old MAC == new MAC
  (jsc#PED-4876).
- i40e: remove unnecessary check for old MAC == new MAC
  (jsc#PED-4874).
- ice: do not re-enable miscellaneous interrupt until thread_fn
  completes (jsc#PED-4876).
- ice: trigger PFINT_OICR_TSYN_TX interrupt instead of polling
  (jsc#PED-4876).
- ice: introduce ICE_TX_TSTAMP_WORK enumeration (jsc#PED-4876).
- ice: always return IRQ_WAKE_THREAD in ice_misc_intr()
  (jsc#PED-4876).
- devlink: move port_split/unsplit() ops into devlink_port_ops
  (jsc#PED-4876).
- nfp: devlink: register devlink port with ops (jsc#PED-4876).
- mlxsw_core: register devlink port with ops (jsc#PED-4876).
- ice: register devlink port for PF with ops (jsc#PED-4876).
- devlink: introduce port ops placeholder (jsc#PED-4876).
- devlink: Spelling corrections (jsc#PED-4876).
- devlink: pass devlink_port pointer to ops->port_del() instead
  of index (jsc#PED-4876).
- devlink: remove duplicate port notification (jsc#PED-4876).
- ice: use src VSI instead of src MAC in slow-path (jsc#PED-4876).
- ice: allow matching on meta data (jsc#PED-4876).
- ice: specify field names in ice_prot_ext init (jsc#PED-4876).
- ice: remove redundant Rx field from rule info (jsc#PED-4876).
- ice: define meta data to match in switch (jsc#PED-4876).
- ice: Remove LAG+SRIOV mutual exclusion (jsc#PED-4876).
- ice: update PHY type to ethtool link mode mapping
  (jsc#PED-4876).
- ice: refactor PHY type to ethtool link mode (jsc#PED-4876).
- ice: update ICE_PHY_TYPE_HIGH_MAX_INDEX (jsc#PED-4876).
- ice: add dynamic interrupt allocation (jsc#PED-4876).
- ice: track interrupt vectors with xarray (jsc#PED-4876).
- ice: add individual interrupt allocation (jsc#PED-4876).
- ice: remove redundant SRIOV code (jsc#PED-4876).
- ice: refactor VF control VSI interrupt handling (jsc#PED-4876).
- ice: use preferred MSIX allocation api (jsc#PED-4876).
- ice: use pci_irq_vector helper function (jsc#PED-4876).
- ice: move interrupt related code to separate file
  (jsc#PED-4876).
- overflow: Add struct_size_t() helper (jsc#PED-4876).
- commit 36d3648
* Tue Sep  5 2023 tiwai@suse.de
- Update config files: turn off CONFIG_XFS_RT (bsc#1214883)
- commit fdec2c6
* Tue Sep  5 2023 tiwai@suse.de
- Update config files (bsc#1214883)
  CONFIG_BLK_CGROUP_IOPRIO=y, CONFIG_BLK_DEV_DRBD=n, CONFIG_F2FS_FS=n
- commit 04084cf
* Tue Sep  5 2023 ddiss@suse.de
- target: compare and write backend driver sense handling
  (bsc#1177719 bsc#1213026).
- target_core_rbd: fix leak and reduce kmalloc calls
  (bsc#1212873).
- target_core_rbd: fix rbd_img_request.snap_id assignment
  (bsc#1212857).
- target_core_rbd: remove snapshot existence validation code
  (bsc#1212857).
- commit f77b0ab
* Tue Sep  5 2023 ddiss@suse.de
- Refresh
  patches.suse/rbd-add-support-for-COMPARE_AND_WRITE-CMPEXT.patch.
- Refresh
  patches.suse/rbd-export-some-functions-used-by-lio-rbd-backend.patch.
- Refresh patches.suse/target-add-rbd-backend.patch.
- Update patches.suse/target-rbd-support-COMPARE_AND_WRITE.patch
  (fate#318836, bsc#1177090 bsc#1213026).
- commit 1b2260d
* Tue Sep  5 2023 nmorey@suse.com
- Remove SP6-NEED-REVIEW tag of patches.suse/mlx5-add-parameter-to-disable-enhanced-IPoIB.patch
- commit 4b4e24d
* Tue Sep  5 2023 msuchanek@suse.de
- Update config files.
  IPR is powerpc-only driver, disable on other architectures.
- commit e626b90
* Tue Sep  5 2023 msuchanek@suse.de
- Update config files.
  s390: CONFIG_SCSI_IPR=n - powerpc-only driver
- commit f1eac10
* Tue Sep  5 2023 oneukum@suse.com
- USB: core: Fix oversight in SuperSpeed initialization
  (bsc#1213123 CVE-2023-37453).
- commit 898ed7a
* Tue Sep  5 2023 oneukum@suse.com
- USB: core: Fix race by not overwriting udev->descriptor in
  hub_port_init() (bsc#1213123 CVE-2023-37453).
- commit a10e1a7
* Tue Sep  5 2023 oneukum@suse.com
- USB: core: Change usb_get_device_descriptor() API (bsc#1213123
  CVE-2023-37453).
- commit 0cbb8bf
* Tue Sep  5 2023 oneukum@suse.com
- USB: core: Unite old scheme and new scheme descriptor reads
  (bsc#1213123 CVE-2023-37453).
- commit 2d3dfbd
* Tue Sep  5 2023 oneukum@suse.com
- Refresh
  patches.suse/0001-kvm-Reintroduce-nopvspin-kernel-parameter.patch.
  fix compilation error on ALP-current
- commit b970105
* Tue Sep  5 2023 mkubecek@suse.cz
- series.conf: reenable patches.suse/net-allow-retransmitting-a-TCP-packet-if-original-is.patch
  Unfortunately we still need this workaround.
- commit 73322ec
* Tue Sep  5 2023 mkubecek@suse.cz
- Update
  patches.kernel.org/6.4.12-162-netfilter-nf_tables-fix-GC-transaction-races-w.patch
  references (add CVE-2023-4563 bsc#1214727).
- commit 9a226db
* Tue Sep  5 2023 tiwai@suse.de
- Update config files: make CONFIG_AUTOFS4_FS modular, drop superfluous FPGA SPI drivers (bsc#1214883)
- commit 32f293e
* Tue Sep  5 2023 tiwai@suse.de
- Update config files.
- supported.conf: move spi-loopback-test to optional (bsc#1214883)
- commit 6268c1d
* Tue Sep  5 2023 pmladek@suse.com
- Delete
  patches.suse/printk-panic-Avoid-deadlock-in-printk-after-stopping-CPUs-by-NMI.patch.
  Obsoleted by the commit d51507098ff91e863 ("printk: disable optimistic spin
  during panic") (bsc#1148712).
- commit 8cb11a0
* Tue Sep  5 2023 tiwai@suse.de
- Update config files.
- supported.conf: add leds-bcm63138 entry
- commit 79dfe00
* Tue Sep  5 2023 tiwai@suse.de
- cpufreq: Fix the race condition while updating the
  transition_task of policy (git-fixes).
- thermal/drivers/imx8mm: Suppress log message on probe deferral
  (git-fixes).
- thermal/drivers/mediatek/lvts_thermal: Manage threshold between
  sensors (git-fixes).
- thermal/drivers/mediatek/lvts_thermal: Don't leave threshold
  zeroed (git-fixes).
- thermal/drivers/mediatek/lvts_thermal: Disable undesired
  interrupts (git-fixes).
- thermal/drivers/mediatek/lvts_thermal: Use offset threshold
  for IRQ (git-fixes).
- thermal/drivers/mediatek/lvts_thermal: Honor sensors in
  immediate mode (git-fixes).
- thermal/drivers/mediatek/lvts_thermal: Handle IRQ on all
  controllers (git-fixes).
- dt-bindings: remoteproc: qcom,msm8996-mss-pil: Fix 8996 clocks
  (git-fixes).
- dt-bindings: remoteproc: qcom,adsp: bring back firmware-name
  (git-fixes).
- dt-bindings: remoteproc: qcom,sm8550-pas: require memory-region
  (git-fixes).
- dt-bindings: remoteproc: qcom,sm6115-pas: correct memory-region
  constraints (git-fixes).
- dt-bindings: remoteproc: qcom,pas: correct memory-region
  constraints (git-fixes).
- rpmsg: glink: Add check for kstrdup (git-fixes).
- hwspinlock: qcom: add missing regmap config for SFPB MMIO
  implementation (git-fixes).
- leds: turris-omnia: Drop unnecessary mutex locking (git-fixes).
- leds: trigger: tty: Do not use LED_ON/OFF constants, use
  led_blink_set_oneshot instead (git-fixes).
- leds: Fix BUG_ON check for LED_COLOR_ID_MULTI that is always
  false (git-fixes).
- leds: multicolor: Use rounded division when calculating color
  components (git-fixes).
- leds: bcm63138: Rename dependency symbol ARCH_BCM4908 to
  ARCH_BCMBCA (git-fixes).
- leds: pwm: Fix error code in led_pwm_create_fwnode()
  (git-fixes).
- docs: printk-formats: Treat char as always unsigned (git-fixes).
- docs: printk-formats: Fix hex printing of signed values
  (git-fixes).
- clocksource/drivers/arm_arch_timer: Disable timer before
  programming CVAL (git-fixes).
- commit 1808eb5
* Mon Sep  4 2023 mgorman@suse.de
- sched, cgroup: Restore meaning to hierarchical_quota (git
  fixes).
- sched/fair: remove util_est boosting (git fixes).
- commit efc3e36
* Mon Sep  4 2023 oneukum@suse.com
- Refresh
  patches.suse/0001-kvm-Reintroduce-nopvspin-kernel-parameter.patch.
  (bsc#1214939)
- commit 12ba24d
* Mon Sep  4 2023 tiwai@suse.de
- Move upstreamed rtw88 patches into sorted section
- commit 0992202
* Mon Sep  4 2023 mgorman@suse.de
- mm/page_alloc: use get_pfnblock_migratetype to avoid extra
  page_to_pfn (bsc#1212886 (MM functional and performance
  backports)).
- mm/page_alloc: remove unnecessary inner
  __get_pfnblock_flags_mask (bsc#1212886 (MM functional and
  performance backports)).
- mm: page_alloc: remove unused parameter from
  reserve_highatomic_pageblock() (bsc#1212886 (MM functional
  and performance backports)).
- mm/mm_init: use helper macro BITS_PER_LONG and BITS_PER_BYTE
  (bsc#1212886 (MM functional and performance backports)).
- mm/compaction: remove unnecessary return for void function
  (bsc#1212886 (MM functional and performance backports)).
- mm/compaction: correct comment to complete migration failure
  (bsc#1212886 (MM functional and performance backports)).
- mm/compaction: correct comment of cached migrate pfn update
  (bsc#1212886 (MM functional and performance backports)).
- mm/compaction: correct comment of fast_find_migrateblock
  in isolate_migratepages (bsc#1212886 (MM functional and
  performance backports)).
- mm/compaction: skip page block marked skip in
  isolate_migratepages_block (bsc#1212886 (MM functional and
  performance backports)).
- mm/compaction: correct last_migrated_pfn update in compact_zone
  (bsc#1212886 (MM functional and performance backports)).
- mm/compaction: remove unnecessary "else continue" at end of
  loop in isolate_freepages_block (bsc#1212886 (MM functional
  and performance backports)).
- mm/compaction: remove unnecessary cursor page in
  isolate_freepages_block (bsc#1212886 (MM functional and
  performance backports)).
- mm/compaction: merge end_pfn boundary check in
  isolate_freepages_range (bsc#1212886 (MM functional and
  performance backports)).
- mm/compaction: set compact_cached_free_pfn correctly in
  update_pageblock_skip (bsc#1212886 (MM functional and
  performance backports)).
- mm/page_alloc: remove unneeded variable base (bsc#1212886
  (MM functional and performance backports)).
- mm:vmscan: fix inaccurate reclaim during proactive reclaim
  (bsc#1212886 (MM functional and performance backports)).
- mm/compaction: avoid unneeded pageblock_end_pfn when
  no_set_skip_hint is set (bsc#1212886 (MM functional and
  performance backports)).
- mm/compaction: correct comment of candidate pfn in
  fast_isolate_freepages (bsc#1212886 (MM functional and
  performance backports)).
- mm/rmap: correct stale comment of rmap_walk_anon and
  rmap_walk_file (bsc#1212886 (MM functional and performance
  backports)).
- mm/mm_init.c: drop node_start_pfn from
  adjust_zone_range_for_zone_movable() (bsc#1212886 (MM functional
  and performance backports)).
- mm: compaction: skip the memory hole rapidly when isolating free
  pages (bsc#1212886 (MM functional and performance backports)).
- mm: compaction: use the correct type of list for free pages
  (bsc#1212886 (MM functional and performance backports)).
- mm: page_alloc: avoid false page outside zone error info
  (bsc#1212886 (MM functional and performance backports)).
- mm/page_alloc: use write_seqlock_irqsave() instead
  write_seqlock() + local_irq_save() (bsc#1213179 (PREEMPT_RT
  functional and performance backports)).
- mm/page_alloc: fix min_free_kbytes calculation regarding
  ZONE_MOVABLE (bsc#1212886 (MM functional and performance
  backports)).
- mm/filemap.c: fix update prev_pos after one read request done
  (bsc#1212886 (MM functional and performance backports)).
- mm/mm_init.c: update obsolete comment in get_pfn_range_for_nid()
  (bsc#1212886 (MM functional and performance backports)).
- mm: madvise: fix uneven accounting of psi (bsc#1212886 (MM
  functional and performance backports)).
- commit b392eb6
* Mon Sep  4 2023 mgorman@suse.de
- Revert "sched/fair: Move unused stub functions to header"
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/rt: sysctl_sched_rr_timeslice show default timeslice
  after reset (bsc#1212887 (Scheduler functional and performance
  backports)).
- sched/rt: Fix sysctl_sched_rr_timeslice intial value
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/fair: Block nohz tick_stop when cfs bandwidth in use
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/fair: Stabilize asym cpu capacity system idle cpu
  selection (bsc#1212887 (Scheduler functional and performance
  backports)).
- sched/debug: Dump domains' sched group flags (bsc#1212887
  (Scheduler functional and performance backports)).
- sched/fair: Consider the idle state of the whole core for load
  balance (bsc#1212887 (Scheduler functional and performance
  backports)).
- sched/fair: Implement prefer sibling imbalance calculation
  between asymmetric groups (bsc#1212887 (Scheduler functional
  and performance backports)).
- sched/topology: Record number of cores in sched group
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/fair: Determine active load balance for SMT sched groups
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/psi: make psi_cgroups_enabled static (bsc#1212887
  (Scheduler functional and performance backports)).
- sched/core: introduce sched_core_idle_cpu() (bsc#1212887
  (Scheduler functional and performance backports)).
- sched: add throttled time stat for throttled children
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched: don't account throttle time for empty groups (bsc#1212887
  (Scheduler functional and performance backports)).
- sched: add a few helpers to wake up tasks on the current cpu
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched: add WF_CURRENT_CPU and externise ttwu (bsc#1212887
  (Scheduler functional and performance backports)).
- commit e82e496
* Mon Sep  4 2023 iivanov@suse.de
- wifi: brcmfmac: wcc: Add debug messages (bsc#1214931)
- commit 7cfa155
* Mon Sep  4 2023 tzimmermann@suse.com
- config/ppc64le: Boot up with DRM and simpledrm/ofdrm (jsc#PED-1117)
- commit f6f8c7d
* Mon Sep  4 2023 tzimmermann@suse.com
- config/arm64: Bootup with DRM and simpledrm (jsc#PED-1117)
- commit 38d8860
* Mon Sep  4 2023 tzimmermann@suse.com
- config/x86_64: Boot up with DRM and simpledrm (jsc#PED-1117)
- commit cb0636e
* Mon Sep  4 2023 tiwai@suse.de
- Update config files: correct kconfigs while updating 6.4.x (bsc#1214883)
  Enable forgotten configs:
  CONFIG_ACPI_TINY_POWER_BUTTON, CONFIG_ADIN_PHY, CONFIG_DRM_SSD130X,
  CONFIG_MLX90614, CONFIG_TCG_TIS_SPI, CONFIG_SPI_AMD, CONFIG_RMI4_SPI,
  CONFIG_BATTERY_DS2780, CONFIG_MFD_MADERA_SPI, CONFIG_USB_CONN_GPIO,
  CONFIG_MMC_SDHCI_XENON
  Make modular:
  CONFIG_PCI_PF_STUB, CONFIG_USB4, CONFIG_USB4_NET, CONFIG_EFI_SECRET
- commit d98f6d8
* Mon Sep  4 2023 tiwai@suse.de
- Update config files: corret SCSI-related configs to modular (bsc#1214883)
- commit ffbfc94
* Mon Sep  4 2023 tiwai@suse.de
- phy/rockchip: inno-hdmi: do not power on rk3328 post pll on
  reg write (git-fixes).
- phy/rockchip: inno-hdmi: round fractal pixclock in rk3328
  recalc_rate (git-fixes).
- phy/rockchip: inno-hdmi: use correct vco_div_5 macro on rk3328
  (git-fixes).
- phy: qcom: qmp-combo: correct bias0_en programming (git-fixes).
- mtd: rawnand: fsmc: handle clk prepare error in
  fsmc_nand_resume() (git-fixes).
- mtd: rawnand: brcmnand: Fix mtd oobsize (git-fixes).
- mtd: rawnand: brcmnand: Fix potential out-of-bounds access in
  oob write (git-fixes).
- mtd: rawnand: brcmnand: Fix crash during the panic_write
  (git-fixes).
- mtd: rawnand: brcmnand: Fix potential false time out warning
  (git-fixes).
- drivers: usb: smsusb: fix error handling code in
  smsusb_init_device (git-fixes).
- serial: sc16is7xx: fix bug when first setting GPIO direction
  (git-fixes).
- serial: sc16is7xx: fix broken port 0 uart init (git-fixes).
- serial: tegra: handle clk prepare error in tegra_uart_hw_init()
  (git-fixes).
- tty: serial: qcom-geni-serial: Poll primary sequencer irq
  status after cancel_tx (git-fixes).
- serial: sprd: Fix DMA buffer leak issue (git-fixes).
- serial: sprd: Assign sprd_port after initialized to avoid
  wrong access (git-fixes).
- serial: qcom-geni: fix opp vote on shutdown (git-fixes).
- staging: rtl8712: fix race condition (git-fixes).
- tcpm: Avoid soft reset when partner does not support get_status
  (git-fixes).
- usb: typec: tcpm: set initial svdm version based on pd revision
  (git-fixes).
- usb: typec: tcpci: clear the fault status bit (git-fixes).
- usb: typec: bus: verify partner exists in
  typec_altmode_attention (git-fixes).
- usb: dwc3: meson-g12a: do post init to fix broken usb after
  resumption (git-fixes).
- USB: gadget: f_mass_storage: Fix unused variable warning
  (git-fixes).
- USB: gadget: core: Add missing kerneldoc for vbus_work
  (git-fixes).
- usb: phy: mxs: fix getting wrong state with
  mxs_phy_is_otg_host() (git-fixes).
- usb: chipidea: imx: improve logic if samsung,picophy-* parameter
  is 0 (git-fixes).
- platform/x86/amd/pmf: Fix a missing cleanup path (git-fixes).
- platform/x86: dell-sysman: Fix reference leak (git-fixes).
- commit 212631a
* Mon Sep  4 2023 tiwai@suse.de
- media: mediatek: vcodec: fix potential double free (git-fixes).
- commit cf82680
* Mon Sep  4 2023 tiwai@suse.de
- mtd: rawnand: brcmnand: Fix ECC level field setting for v7.2
  controller (git-fixes).
- mtd: spi-nor: Check bus width while setting QE bit (git-fixes).
- f2fs: fix spelling in ABI documentation (git-fixes).
- HID: wacom: remove the battery when the EKR is off (git-fixes).
- HID: logitech-hidpp: rework one more time the retries attempts
  (git-fixes).
- HID: logitech-dj: Fix error handling in
  logi_dj_recv_switch_to_dj_mode() (git-fixes).
- HID: multitouch: Correct devm device reference for hidinput
  input_dev name (git-fixes).
- HID: uclogic: Correct devm device reference for hidinput
  input_dev name (git-fixes).
- HID: input: Support devices sending Eraser without Invert
  (git-fixes).
- media: i2c: rdacm21: Fix uninitialized value (git-fixes).
- media: i2c: ccs: Check rules is non-NULL (git-fixes).
- media: ov2680: Fix regulators being left enabled on
  ov2680_power_on() errors (git-fixes).
- media: ov2680: Fix ov2680_set_fmt() which ==
  V4L2_SUBDEV_FORMAT_TRY not working (git-fixes).
- media: ov2680: Add ov2680_fill_format() helper function
  (git-fixes).
- media: ov2680: Don't take the lock for try_fmt calls
  (git-fixes).
- media: ov2680: Remove VIDEO_V4L2_SUBDEV_API ifdef-s (git-fixes).
- media: ov2680: Fix vflip / hflip set functions (git-fixes).
- media: ov2680: Fix ov2680_bayer_order() (git-fixes).
- media: ov2680: Remove auto-gain and auto-exposure controls
  (git-fixes).
- media: Documentation: Fix [GS]_ROUTING documentation
  (git-fixes).
- media: ov5640: Fix initial RESETB state and annotate timings
  (git-fixes).
- media: ov5640: Enable MIPI interface in ov5640_set_power_mipi()
  (git-fixes).
- media: nxp: Fix wrong return pointer check in
  mxc_isi_crossbar_init() (git-fixes).
- media: venus: hfi_venus: Write to VIDC_CTRL_INIT after unmasking
  interrupts (git-fixes).
- media: venus: hfi_venus: Only consider sys_idle_indicator on V1
  (git-fixes).
- media: go7007: Remove redundant if statement (git-fixes).
- media: cec: core: add adap_unconfigured() callback (git-fixes).
- media: cec: core: add adap_nb_transmit_canceled() callback
  (git-fixes).
- media: mediatek: vcodec: Return NULL if no vdec_fb is found
  (git-fixes).
- media: amphion: ensure the bitops don't cross boundaries
  (git-fixes).
- media: amphion: fix UNUSED_VALUE issue reported by coverity
  (git-fixes).
- media: amphion: fix UNINIT issues reported by coverity
  (git-fixes).
- media: amphion: fix REVERSE_INULL issues reported by coverity
  (git-fixes).
- media: amphion: fix CHECKED_RETURN issues reported by coverity
  (git-fixes).
- media: rkvdec: increase max supported height for H.264
  (git-fixes).
- media: amphion: decoder support display delay for all formats
  (git-fixes).
- media: mtk-jpeg: Fix use after free bug due to uncanceled work
  (git-fixes).
- media: verisilicon: Fix TRY_FMT on encoder OUTPUT (git-fixes).
- media: amphion: add helper function to get id name (git-fixes).
- media: amphion: reinit vpu if reqbufs output 0 (git-fixes).
- media: cx24120: Add retval check for cx24120_message_send()
  (git-fixes).
- media: dvb-usb: m920x: Fix a potential memory leak in
  m920x_i2c_xfer() (git-fixes).
- media: dib7000p: Fix potential division by zero (git-fixes).
- media: v4l2-core: Fix a potential resource leak in
  v4l2_fwnode_parse_link() (git-fixes).
- media: i2c: tvp5150: check return value of devm_kasprintf()
  (git-fixes).
- media: ad5820: Drop unsupported ad5823 from i2c_ and
  of_device_id tables (git-fixes).
- media: i2c: imx290: drop format param from imx290_ctrl_update
  (git-fixes).
- media: ov5640: fix low resolution image abnormal issue
  (git-fixes).
- fbdev: Update fbdev source file paths (git-fixes).
- interconnect: qcom: sm8450: Enable sync_state (git-fixes).
- interconnect: qcom: qcm2290: Enable sync state (git-fixes).
- misc: fastrpc: Pass proper scm arguments for static process init
  (git-fixes).
- misc: fastrpc: Fix incorrect DMA mapping unmap request
  (git-fixes).
- misc: fastrpc: Fix remote heap allocation request (git-fixes).
- extcon: cht_wc: add POWER_SUPPLY dependency (git-fixes).
- dt-bindings: extcon: maxim,max77843: restrict connector
  properties (git-fixes).
- fsi: master-ast-cf: Add MODULE_FIRMWARE macro (git-fixes).
- fsi: aspeed: Reset master errors after CFAM reset (git-fixes).
- iio: accel: adxl313: Fix adxl313_i2c_id[] table (git-fixes).
- firmware: stratix10-svc: Fix an NULL vs IS_ERR() bug in probe
  (git-fixes).
- driver core: Call dma_cleanup() on the test_remove path
  (git-fixes).
- driver core: test_async: fix an error code (git-fixes).
- Documentation: devices.txt: Fix minors for ttyCPM* (git-fixes).
- Documentation: devices.txt: Remove ttySIOC* (git-fixes).
- Documentation: devices.txt: Remove ttyIOC* (git-fixes).
- dt-bindings: usb: samsung,exynos-dwc3: Fix Exynos5433 compatible
  (git-fixes).
- dt-bindings: usb: samsung,exynos-dwc3: fix order of clocks on
  Exynos5433 (git-fixes).
- commit ec55be8
* Mon Sep  4 2023 tiwai@suse.de
- dmaengine: idxd: Fix issues with PRS disable sysfs knob
  (git-fixes).
- dmaengine: ste_dma40: Add missing IRQ check in d40_probe
  (git-fixes).
- dmaengine: idxd: Modify the dependence of attribute
  pasid_enabled (git-fixes).
- dmaengine: sh: rz-dmac: Fix destination and source data size
  setting (git-fixes).
- arm64: defconfig: Drop CONFIG_VIDEO_IMX_MEDIA (git-fixes).
- amba: bus: fix refcount leak (git-fixes).
- bus: mhi: host: Skip MHI reset if device is in RDDM (git-fixes).
- docs: ABI: fix spelling/grammar in SBEFIFO timeout interface
  (git-fixes).
- dma-buf/sync_file: Fix docs syntax (git-fixes).
- commit e8e8eff
* Sun Sep  3 2023 tiwai@suse.de
- Update config files: only version bump to 6.4.14
- commit a305aac
* Sun Sep  3 2023 tiwai@suse.de
- Linux 6.4.14 (bsc#1012628).
- thunderbolt: Fix a backport error for display flickering issue
  (bsc#1012628).
- kallsyms: Fix kallsyms_selftest failure (bsc#1012628).
  Dropped patches.suse/kallsyms-Fix-kallsyms_selftest-failure.patch
- parisc: sys_parisc: parisc_personality() is called from asm code
  (bsc#1012628).
- lockdep: fix static memory detection even more (bsc#1012628).
  Dropped patches.suse/lockdep-fix-static-memory-detection-even-more.patch
- ARM: module: Use module_init_layout_section() to spot init
  sections (bsc#1012628).
  Dropped patches.suse/ARM-module-Use-module_init_layout_section-to-spot-in.patch
- arm64: module: Use module_init_layout_section() to spot init
  sections (bsc#1012628).
- arm64: module-plts: inline linux/moduleloader.h (bsc#1012628).
- module: Expose module_init_layout_section() (bsc#1012628).
  Dropped patches.suse/module-Expose-module_init_layout_section.patch
- module/decompress: use vmalloc() for zstd decompression
  workspace (bsc#1012628).
  Dropped patches.suse/module-decompress-use-vmalloc-for-zstd-decompression.patch
- ACPI: thermal: Drop nocrt parameter (bsc#1012628).
  Dropped patches.suse/ACPI-thermal-Drop-nocrt-parameter.patch
- commit 25c76ad
* Sat Sep  2 2023 tiwai@suse.de
- supported.conf: fix the dependency for snd-sof
- commit 056f677
* Fri Sep  1 2023 ailiop@suse.com
- iomap: Add per-block dirty state tracking to improve performance
  (jsc#PED-5453).
- commit dc444ac
* Fri Sep  1 2023 ailiop@suse.com
- iomap: Allocate ifs in ->write_begin() early (jsc#PED-5453).
- commit 759ea54
* Fri Sep  1 2023 ailiop@suse.com
- iomap: Refactor iomap_write_delalloc_punch() function out
  (jsc#PED-5453).
- commit 54e20b5
* Fri Sep  1 2023 ailiop@suse.com
- iomap: Use iomap_punch_t typedef (jsc#PED-5453).
- commit 42ab42f
* Fri Sep  1 2023 ailiop@suse.com
- iomap: Fix possible overflow condition in
  iomap_write_delalloc_scan (jsc#PED-5453).
- commit e8c8c98
* Fri Sep  1 2023 ailiop@suse.com
- iomap: Add some uptodate state handling helpers for ifs state
  bitmap (jsc#PED-5453).
- commit f30e2be
* Fri Sep  1 2023 ailiop@suse.com
- iomap: Drop ifs argument from iomap_set_range_uptodate()
  (jsc#PED-5453).
- commit 2117a2e
* Fri Sep  1 2023 ailiop@suse.com
- iomap: Rename iomap_page to iomap_folio_state and others
  (jsc#PED-5453).
- commit 0650e04
* Fri Sep  1 2023 ailiop@suse.com
- iomap: Remove unnecessary test from iomap_release_folio()
  (jsc#PED-5453).
- commit 8702c3c
* Fri Sep  1 2023 ailiop@suse.com
- iomap: Remove large folio handling in iomap_invalidate_folio()
  (jsc#PED-5453).
- commit 221954e
* Fri Sep  1 2023 tiwai@suse.de
- supported.conf: update for sound drivers (bsc#1214891)
- commit 61819c4
* Fri Sep  1 2023 tiwai@suse.de
- Update config files: enable missing ASoC Intel AVS (bsc#1214883)
- commit c6b3355
* Fri Sep  1 2023 tiwai@suse.de
- Update config files: CHT/BYT modularization, enable missing AMD features (bsc#1214883)
- commit b369d38
* Fri Sep  1 2023 denis.kirjanov@suse.com
- igb: set max size RX buffer when store bad packet is enabled
  (jsc#PED-4082).
- commit 1fd1f97
* Fri Sep  1 2023 denis.kirjanov@suse.com
- Update metadata
- commit 94184dc
* Fri Sep  1 2023 tiwai@suse.de
- ARM: 9318/1: locomo: move kernel-doc to prevent warnings
  (git-fixes).
- PCI: hv: Fix a crash in hv_pci_restore_msi_msg() during
  hibernation (git-fixes).
- drm/mediatek: dp: Add missing error checks in
  mtk_dp_parse_capabilities (git-fixes).
- drm/bridge: fix -Wunused-const-variable= warning (git-fixes).
- lockdep: fix static memory detection even more (git-fixes).
- scripts/gdb: fix 'lx-lsmod' show the wrong size (git-fixes).
- selftests: memfd: error out test process when child test fails
  (git-fixes).
- selftests/bpf: Clean up fmod_ret in bench_rename test script
  (git-fixes).
- selftests/bpf: Fix repeat option when kfunc_call verification
  fails (git-fixes).
- selftests/bpf: fix static assert compilation issue for
  test_cls_*.c (git-fixes).
- selftests/bpf: Fix bpf_nf failure upon test rerun (git-fixes).
- kbuild: rust_is_available: fix confusion when a version appears
  in the path (git-fixes).
- kbuild: rust_is_available: add check for `bindgen` invocation
  (git-fixes).
- selftests/futex: Order calls to futex_lock_pi (git-fixes).
- selftests/resctrl: Close perf value read fd on errors
  (git-fixes).
- selftests/resctrl: Unmount resctrl FS if child fails to run
  benchmark (git-fixes).
- selftests/resctrl: Don't leak buffer in fill_cache()
  (git-fixes).
- selftests/resctrl: Add resctrl.h into build deps (git-fixes).
- kallsyms: Fix kallsyms_selftest failure (git-fixes).
- selftests/harness: Actually report SKIP for signal tests
  (git-fixes).
- selftests/nolibc: drop test chmod_net (git-fixes).
- rust: delete `ForeignOwnable::borrow_mut` (git-fixes).
- ata,scsi: do not issue START STOP UNIT on resume (git-fixes).
- kconfig: gconfig: drop the Show Debug Info help text
  (git-fixes).
- Revert "kheaders: substituting --sort in archive creation"
  (git-fixes).
- linux/netfilter.h: fix kernel-doc warnings (git-fixes).
- selftests: mm: remove wrong kernel header inclusion (git-fixes).
- selftests: damon: add config file (git-fixes).
- rust: arc: fix intra-doc link in `Arc<T>::init` (git-fixes).
- commit 588cb89
* Thu Aug 31 2023 tiwai@suse.de
- bus: ti-sysc: Fix cast to enum warning (git-fixes).
- wifi: mwifiex: Fix missed return in oob checks failed path
  (git-fixes).
- selinux: keep context struct members in sync (git-fixes).
- commit 5dd241f
* Thu Aug 31 2023 tiwai@suse.de
- wifi: ath10k: Use RMW accessors for changing LNKCTL (git-fixes).
- wifi: ath12k: Use RMW accessors for changing LNKCTL (git-fixes).
- wifi: ath11k: Use RMW accessors for changing LNKCTL (git-fixes).
- wifi: ath9k: use IS_ERR() with debugfs_create_dir() (git-fixes).
- wifi: ath11k: Cleanup mac80211 references on failure during
  tx_complete (git-fixes).
- wifi: ath11k: Don't drop tx_status when peer cannot be found
  (git-fixes).
- wifi: ath9k: protect WMI command response buffer replacement
  with a lock (git-fixes).
- wifi: ath9k: fix races between ath9k_wmi_cmd and
  ath9k_wmi_ctrl_rx (git-fixes).
- wifi: mwifiex: avoid possible NULL skb pointer dereference
  (git-fixes).
- wifi: mac80211: fix kernel-doc notation warning (git-fixes).
- wifi: radiotap: fix kernel-doc notation warnings (git-fixes).
- wifi: cfg80211: remove dead/unused enum value (git-fixes).
- wifi: nl80211/cfg80211: add forgotten nla_policy for BSS color
  attribute (git-fixes).
- wifi: mac80211: fix puncturing bitmap handling in CSA
  (git-fixes).
- wifi: rtw89: 8852b: rfk: fine tune IQK parameters to improve
  performance on 2GHz band (git-fixes).
- wifi: mwifiex: fix memory leak in mwifiex_histogram_read()
  (git-fixes).
- wifi: ath12k: fix memcpy array overflow in
  ath12k_peer_assoc_h_he() (git-fixes).
- wifi: ath11k: fix band selection for ppdu received in channel
  177 of 5 GHz (git-fixes).
- wifi: mwifiex: fix error recovery in PCIE buffer descriptor
  management (git-fixes).
- wifi: mt76: mt7915: fix power-limits while chan_switch
  (git-fixes).
- wifi: mt76: mt7915: fix tlv length of
  mt7915_mcu_get_chan_mib_info (git-fixes).
- wifi: mt76: testmode: add nla_policy for MT76_TM_ATTR_TX_LENGTH
  (git-fixes).
- wifi: mt76: mt7915: remove VHT160 capability on MT7915
  (git-fixes).
- wifi: mt76: mt7996: fix WA event ring size (git-fixes).
- wifi: mt76: mt7996: use correct phy for background radar event
  (git-fixes).
- wifi: mt76: mt7996: fix bss wlan_idx when sending bss_info
  command (git-fixes).
- wifi: mt76: mt7921: fix non-PSC channel scan fail (git-fixes).
- wifi: mt76: mt7921: fix skb leak by txs missing in AMSDU
  (git-fixes).
- commit 621a6cf
* Thu Aug 31 2023 tiwai@suse.de
- pinctrl: cherryview: fix address_space_handler() argument
  (git-fixes).
- pinctrl: mlxbf3: Remove gpio_disable_free() (git-fixes).
- soc: qcom: qmi_encdec: Restrict string length in decode
  (git-fixes).
- soc: qcom: smem: Fix incompatible types in comparison
  (git-fixes).
- soc: qcom: ocmem: Fix NUM_PORTS & NUM_MACROS macros (git-fixes).
- r8169: fix ASPM-related issues on a number of systems with
  NIC version from RTL8168h (git-fixes).
- wifi: mt76: mt7921: do not support one stream on secondary
  antenna only (git-fixes).
- wifi: mt76: mt7915: rework tx bytes counting when WED is active
  (git-fixes).
- wifi: mt76: mt7915: rework tx packets counting when WED is
  active (git-fixes).
- wifi: mt76: mt7915: fix background radar event being blocked
  (git-fixes).
- wifi: mt76: mt7996: fix header translation logic (git-fixes).
- wifi: mwifiex: Fix OOB and integer underflow when rx packets
  (git-fixes).
- wifi: rtw89: debug: Fix error handling in
  rtw89_debug_priv_btc_manual_set() (git-fixes).
- spi: tegra114: Remove unnecessary NULL-pointer checks
  (git-fixes).
- spi: mpc5xxx-psc: Fix unsigned expression compared with zero
  (git-fixes).
- spi: tegra20-sflash: fix to check return value of
  platform_get_irq() in tegra_sflash_probe() (git-fixes).
- regulator: dt-bindings: qcom,rpm: fix pattern for children
  (git-fixes).
- regmap: rbtree: Use alloc_flags for memory allocations
  (git-fixes).
- regmap: cache: Revert "Add 64-bit mode support" (git-fixes).
- regmap: Revert "add 64-bit mode support" and Co (git-fixes).
- thermal/of: Fix potential uninitialized value access
  (git-fixes).
- PM / devfreq: Fix leak in devfreq_dev_release() (git-fixes).
- powercap: arm_scmi: Remove recursion while parsing zones
  (git-fixes).
- platform/chrome: chromeos_acpi: print hex string for
  ACPI_TYPE_BUFFER (git-fixes).
- pstore/ram: Check start of empty przs during init (git-fixes).
- procfs: block chmod on /proc/thread-self/comm (git-fixes).
- proc: use generic setattr() for /proc/$PID/net (git-fixes).
- Revert "wifi: ath6k: silence false positive
  - Wno-dangling-pointer warning on GCC 12" (git-fixes).
- Revert "wifi: ath11k: Enable threaded NAPI" (git-fixes).
- staging: vchiq_arm: Remove extra struct vchiq_instance
  declaration (git-fixes).
- soc: rockchip: dtpm: use C99 array init syntax (git-fixes).
- selinux: make labeled NFS work when mounted before policy load
  (git-fixes).
- selinux: do not leave dangling pointer behind (git-fixes).
- thermal/drivers/qcom/tsens: Drop unused legacy structs
  (git-fixes).
- powercap: intel_rapl: Remove unused field in struct rapl_if_priv
  (git-fixes).
- commit 333ae48
* Thu Aug 31 2023 tiwai@suse.de
- PCI/DOE: Fix destroy_work_on_stack() race (git-fixes).
- PCI: microchip: Remove cast between incompatible function type
  (git-fixes).
- PCI: keembay: Remove cast between incompatible function type
  (git-fixes).
- PCI: meson: Remove cast between incompatible function type
  (git-fixes).
- Revert "PCI: tegra194: Enable support for 256 Byte payload"
  (git-fixes).
- PCI: rockchip: Use 64-bit mask on MSI 64-bit PCI address
  (git-fixes).
- PCI: qcom-ep: Switch MHI bus master clock off during L1SS
  (git-fixes).
- PCI: microchip: Correct the DED and SEC interrupt bit offsets
  (git-fixes).
- PCI: apple: Initialize pcie->nvecs before use (git-fixes).
- PCI: Mark NVIDIA T4 GPUs to avoid bus reset (git-fixes).
- PCI/PM: Only read PCI_PM_CTRL register when available
  (git-fixes).
- PCI: pciehp: Use RMW accessors for changing LNKCTL (git-fixes).
- PCI: Add locking to RMW PCI Express Capability Register
  accessors (git-fixes).
- pinctrl: mediatek: assign functions to configure pin bias on
  MT7986 (git-fixes).
- pinctrl: mediatek: fix pull_type data for MT7981 (git-fixes).
- pinctrl: mcp23s08: check return value of devm_kasprintf()
  (git-fixes).
- ipmi_si: fix a memleak in try_smi_init() (git-fixes).
- ipmi:ssif: Fix a memory leak when scanning for an adapter
  (git-fixes).
- ipmi:ssif: Add check for kstrdup (git-fixes).
- of: unittest: Restore indentation in overlay_bad_add_dup_prop
  test (git-fixes).
- of: unittest: Fix overlay type in apply/revert check
  (git-fixes).
- of: overlay: Call of_changeset_init() early (git-fixes).
- of: unittest: fix null pointer dereferencing in
  of_unittest_find_node_by_name() (git-fixes).
- of: fix htmldocs build warnings (git-fixes).
- module/decompress: use vmalloc() for zstd decompression
  workspace (git-fixes).
- nilfs2: fix WARNING in mark_buffer_dirty due to discarded
  buffer reuse (git-fixes).
- lib/test_meminit: allocate pages up to order MAX_ORDER
  (git-fixes).
- HWPOISON: offline support: fix spelling in Documentation/ABI/
  (git-fixes).
- mac80211: make ieee80211_tx_info padding explicit (git-fixes).
- hwrng: iproc-rng200 - Implement suspend and resume calls
  (git-fixes).
- hwrng: pic32 - use devm_clk_get_enabled (git-fixes).
- hwrng: nomadik - keep clock enabled while hwrng is registered
  (git-fixes).
- hwmon: (tmp513) Fix the channel number in tmp51x_is_visible()
  (git-fixes).
- irqchip/loongson-eiointc: Fix return value checking of
  eiointc_index (git-fixes).
- Revert "media: uvcvideo: Limit power line control for Acer
  EasyCamera" (git-fixes).
- media: Revert "media: exynos4-is: Remove dependency on obsolete
  SoC support" (git-fixes).
- PCI: rcar-host: Remove unused static pcie_base and pcie_dev
  (git-fixes).
- irqchip/mmp: Remove non-DT codepath (git-fixes).
- commit 2974f21
* Thu Aug 31 2023 tiwai@suse.de
- drm/radeon: Use RMW accessors for changing LNKCTL (git-fixes).
- drm/amdgpu: Use RMW accessors for changing LNKCTL (git-fixes).
- dt-bindings: clocks: imx8mp: make sai4 a dummy clock
  (git-fixes).
- dt-bindings: clock: xlnx,versal-clk: drop select:false
  (git-fixes).
- dt-bindings: pinctrl: qcom,pmic-gpio: document PMC8180 and
  PMC8180C (git-fixes).
- dt-bindings: pinctrl: amlogic,meson-pinctrl-common: allow gpio
  hogs (git-fixes).
- dt-bindings: pinctrl: amlogic,meson-pinctrl: allow
  gpio-line-names (git-fixes).
- EDAC/igen6: Fix the issue of no error events (git-fixes).
- EDAC/i10nm: Skip the absent memory controllers (git-fixes).
- dt-bindings: thermal: lmh: update maintainer address
  (git-fixes).
- dt-bindings: qcom: Allow SoC names ending in "pro" (git-fixes).
- dt-bindings: clock: qcom,gcc-sc8280xp: Add missing GDSCs
  (git-fixes).
- dt-bindings: crypto: ti,sa2ul: make power-domains conditional
  (git-fixes).
- dt-bindings: arm: msm: kpss-acc: Make the optional reg truly
  optional (git-fixes).
- firmware: ti_sci: Use system_state to determine polling
  (git-fixes).
- firmware: meson_sm: fix to avoid potential NULL pointer
  dereference (git-fixes).
- firmware: cs_dsp: Fix new control name check (git-fixes).
- drm/msm/a6xx: Fix GMU lockdep splat (git-fixes).
- drm/msm/a2xx: Call adreno_gpu_init() earlier (git-fixes).
- drm/msm/dpu: fix the irq index in
  dpu_encoder_phys_wb_wait_for_commit_done (git-fixes).
- drm/msm/mdp5: Don't leak some plane state (git-fixes).
- dt-bindings: clock: qcom, dispcc-sm6125: Require GCC PLL0 DIV
  clock (git-fixes).
- drm/msm: Update dev core dump to not print backwards
  (git-fixes).
- fbdev/ep93xx-fb: Do not assign to struct fb_info.dev
  (git-fixes).
- dt-bindings: net: mediatek,net: add missing mediatek,mt7621-eth
  (git-fixes).
- gpio: pca9570: fix kerneldoc (git-fixes).
- dt-bindings: net: rockchip-dwmac: fix {tx|rx}-delay
  defaults/range in schema (git-fixes).
- dt-bindings: hwmon: moortec,mr75203: fix multipleOf for
  coefficients (git-fixes).
- dt-bindings: phy: mixel,mipi-dsi-phy: Remove assigned-clock*
  properties (git-fixes).
- dt-bindings: clock: qcom,gcc-sm8250: add missing bi_tcxo_ao
  clock (git-fixes).
- dt-bindings: usb: usb251xb: correct swap-dx-lanes type to uint32
  (git-fixes).
- dt-bindings: pm8941-misc: Fix usb_id and usb_vbus definitions
  (git-fixes).
- dt-bindings: backlight: pwm: Make power-supply not required
  (git-fixes).
- dt-bindings: leds: Drop redundant cpus enum match (git-fixes).
- dt-bindings: gpio: Remove FSI domain ports on Tegra234
  (git-fixes).
- dt-bindings: display: msm: sm8350-mdss: Fix DSI compatible
  (git-fixes).
- dt-bindings: samsung,mipi-dsim: Use port-base reference
  (git-fixes).
- dt-bindings: mtd: qcom: Fix a property position (git-fixes).
- dt-bindings: nand: meson: Fix 'nand-rb' property (git-fixes).
- commit 1352d14
* Thu Aug 31 2023 tiwai@suse.de
- docs: kernel-parameters: Refer to the correct bitmap function
  (git-fixes).
- drm/etnaviv: fix dumping of active MMU context (git-fixes).
- drm/amd/pm: fix variable dereferenced issue in
  amdgpu_device_attr_create() (git-fixes).
- drm/mediatek: Fix void-pointer-to-enum-cast warning (git-fixes).
- drm/mediatek: Fix potential memory leak if vmap() fail
  (git-fixes).
- drm/mediatek: Fix dereference before null check (git-fixes).
- drm/mediatek: Add cnt checking for coverity issue (git-fixes).
- drm/mediatek: Remove freeing not dynamic allocated memory
  (git-fixes).
- drm/mediatek: Fix uninitialized symbol (git-fixes).
- drm/panel: simple: Add missing connector type and pixel format
  for AUO T215HVN01 (git-fixes).
- drm: Remove references to removed transitional helpers
  (git-fixes).
- drm/repaper: Reduce temporary buffer size in repaper_fb_dirty()
  (git-fixes).
- drm/armada: Fix off-by-one error in
  armada_overlay_get_property() (git-fixes).
- drm/ast: report connection status on Display Port (git-fixes).
- drm/ast: Add BMC virtual connector (git-fixes).
- drm/atomic-helper: Update reference to
  drm_crtc_force_disable_all() (git-fixes).
- drm/tegra: dpaux: Fix incorrect return value of platform_get_irq
  (git-fixes).
- drm: xlnx: zynqmp_dpsub: Add missing check for dma_set_mask
  (git-fixes).
- drm/amd/display: dc.h: eliminate kernel-doc warnings
  (git-fixes).
- drm/amdgpu: avoid integer overflow warning in
  amdgpu_device_resize_fb_bar() (git-fixes).
- drm/amd/display: Do not set drr on pipe commit (git-fixes).
- drm/bridge: anx7625: Drop device lock before
  drm_helper_hpd_irq_event() (git-fixes).
- drm: adv7511: Fix low refresh rate register for ADV7533/5
  (git-fixes).
- drm/bridge: anx7625: Use common macros for HDCP capabilities
  (git-fixes).
- drm/bridge: anx7625: Use common macros for DP power sequencing
  commands (git-fixes).
- drm/hyperv: Fix a compilation issue because of not including
  screen_info.h (git-fixes).
- drm/ast: Fix DRAM init on AST2200 (git-fixes).
- drm/mxsfb: Disable overlay plane in
  mxsfb_plane_overlay_atomic_disable() (git-fixes).
- drm: bridge: dw-mipi-dsi: Fix enable/disable of DSI controller
  (git-fixes).
- drm/bridge: tc358764: Fix debug print parameter order
  (git-fixes).
- cred: remove unsued extern declaration change_create_files_as()
  (git-fixes).
- crypto: caam - fix unchecked return value error (git-fixes).
- crypto: api - Use work queue in crypto_destroy_instance
  (git-fixes).
- crypto: af_alg - Decrement struct key.usage in
  alg_set_by_key_serial() (git-fixes).
- crypto: stm32 - Properly handle pm_runtime_get failing
  (git-fixes).
- crypto: stm32 - fix MDMAT condition (git-fixes).
- crypto: qat - change value of default idle filter (git-fixes).
- cpufreq: powernow-k8: Use related_cpus instead of cpus in
  driver.exit() (git-fixes).
- cpufreq: brcmstb-avs-cpufreq: Fix -Warray-bounds bug
  (git-fixes).
- cpufreq: amd-pstate-ut: Fix kernel panic when loading the driver
  (git-fixes).
- cpuidle: teo: Update idle duration estimate when choosing
  shallower state (git-fixes).
- crypto: ixp4xx - silence uninitialized variable warning
  (git-fixes).
- drm/msm: provide fb_dirty implemenation (git-fixes).
- drm/vmwgfx: Add unwind hints around RBP clobber (git-fixes).
- Documentation: kunit: Modular tests should not depend on KUNIT=y
  (git-fixes).
- commit becb350
* Thu Aug 31 2023 tiwai@suse.de
- clk: qcom: gcc-qdu1000: Fix clkref clocks handling (git-fixes).
- clk: qcom: gcc-qdu1000: Fix gcc_pcie_0_pipe_clk_src clock
  handling (git-fixes).
- clk: qcom: gcc-sm8450: Use floor ops for SDCC RCGs (git-fixes).
- clk: qcom: gcc-sm6350: Fix gcc_sdcc2_apps_clk_src (git-fixes).
- clk: qcom: reset: Use the correct type of sleep/delay based
  on length (git-fixes).
- clk: qcom: gcc-sm8250: Fix gcc_sdcc2_apps_clk_src (git-fixes).
- clk: qcom: gcc-sc7180: Fix up gcc_sdcc2_apps_clk_src
  (git-fixes).
- clk: qcom: gcc-mdm9615: use proper parent for pll0_vote clock
  (git-fixes).
- clk: qcom: dispcc-sc8280xp: Use ret registers on GDSCs
  (git-fixes).
- clk: qcom: turingcc-qcs404: fix missing resume during probe
  (git-fixes).
- clk: qcom: mss-sc7180: fix missing resume during probe
  (git-fixes).
- clk: qcom: q6sstop-qcs404: fix missing resume during probe
  (git-fixes).
- clk: qcom: lpasscc-sc7280: fix missing resume during probe
  (git-fixes).
- clk: qcom: dispcc-sm8550: fix runtime PM imbalance on probe
  errors (git-fixes).
- clk: qcom: dispcc-sm8450: fix runtime PM imbalance on probe
  errors (git-fixes).
- clk: qcom: camcc-sc7180: fix async resume during probe
  (git-fixes).
- clk: qcom: gcc-sm7150: Add CLK_OPS_PARENT_ENABLE to sdcc2 rcg
  (git-fixes).
- clk: qcom: gcc-sc8280xp: Add missing GDSC flags (git-fixes).
- clk: imx: pll14xx: dynamically configure PLL for
  393216000/361267200Hz (git-fixes).
- clk: imx: pll14xx: align pdiv with reference manual (git-fixes).
- clk: imx: composite-8m: fix clock pauses when set_rate would
  be a no-op (git-fixes).
- clk: imx8mp: fix sai4 clock (git-fixes).
- clk: imx: imx8ulp: update SPLL2 type (git-fixes).
- clk: imx: pllv4: Fix SPLL2 MULT range (git-fixes).
- clk: rockchip: rk3568: Fix PLL rate setting for 78.75MHz
  (git-fixes).
- clk: sunxi-ng: Modify mismatched function name (git-fixes).
- drivers: clk: keystone: Fix parameter judgment in
  _of_pll_clk_init() (git-fixes).
- bus: ti-sysc: Fix build warning for 64-bit build (git-fixes).
- Bluetooth: btusb: Do not call kfree_skb() under
  spin_lock_irqsave() (git-fixes).
- Bluetooth: Fix potential use-after-free when clear keys
  (git-fixes).
- can: tcan4x5x: Remove reserved register 0x814 from writable
  table (git-fixes).
- can: gs_usb: gs_usb_receive_bulk_callback(): count RX overflow
  errors also in case of OOM (git-fixes).
- cpufreq: amd-pstate-ut: Remove module parameter access
  (git-fixes).
- clocksource: Handle negative skews in "skew is too large"
  messages (git-fixes).
- clk: samsung: Re-add support for Exynos4212 CPU clock
  (git-fixes).
- can: m_can: fix coding style (git-fixes).
- commit d40bf6b
* Thu Aug 31 2023 tiwai@suse.de
- arm64: dts: qcom: sc8280xp-x13s: Unreserve NC pins (git-fixes).
- arm64: dts: qcom: msm8996: Fix dsi1 interrupts (git-fixes).
- arm64: dts: qcom: msm8998: Add missing power domain to MMSS SMMU
  (git-fixes).
- arm64: dts: qcom: msm8998: Drop bus clock reference from MMSS
  SMMU (git-fixes).
- arm64: dts: qcom: apq8016-sbc: Fix ov5640 regulator supply names
  (git-fixes).
- arm64: dts: qcom: sm8550-mtp: Add missing supply for L1B
  regulator (git-fixes).
- arm64: dts: qcom: sm8150: Fix the I2C7 interrupt (git-fixes).
- arm64: dts: qcom: msm8996-gemini: fix touchscreen VIO supply
  (git-fixes).
- arm64: dts: qcom: msm8953-vince: drop duplicated touschreen
  parent interrupt (git-fixes).
- arm64: dts: qcom: sdm845: Fix the min frequency of
  "ice_core_clk" (git-fixes).
- arm64: dts: qcom: sdm845: Add missing RPMh power domain to GCC
  (git-fixes).
- arm64: dts: qcom: pmi8994: Add missing OVP interrupt
  (git-fixes).
- arm64: dts: qcom: pmi8950: Add missing OVP interrupt
  (git-fixes).
- arm64: dts: qcom: pm660l: Add missing short interrupt
  (git-fixes).
- arm64: dts: qcom: pm6150l: Add missing short interrupt
  (git-fixes).
- arm64: dts: qcom: sm8250: Mark PCIe hosts as DMA coherent
  (git-fixes).
- arm64: dts: qcom: sm8450-hdk: remove pmr735b PMIC inclusion
  (git-fixes).
- arm64: dts: qcom: pmk8350: fix ADC-TM compatible string
  (git-fixes).
- arm64: dts: qcom: pmr735b: fix thermal zone name (git-fixes).
- arm64: dts: qcom: pm8350b: fix thermal zone name (git-fixes).
- arm64: dts: qcom: pm8350: fix thermal zone name (git-fixes).
- arm64: dts: qcom: sm8350: Use proper CPU compatibles
  (git-fixes).
- arm64: dts: qcom: sm8350: Add missing LMH interrupts to cpufreq
  (git-fixes).
- arm64: dts: qcom: sm8350: Fix CPU idle state residency times
  (git-fixes).
- arm64: dts: qcom: sdm845-tama: Set serial indices and
  stdout-path (git-fixes).
- arm64: dts: qcom: msm8996: Add missing interrupt to the USB2
  controller (git-fixes).
- arm64: dts: qcom: sc8280xp: Add missing SCM interconnect
  (git-fixes).
- arm64: dts: qcom: sc8280xp-crd: Correct vreg_misc_3p3 GPIO
  (git-fixes).
- arm64: dts: qcom: msm8916-l8150: correct light sensor VDDIO
  supply (git-fixes).
- arm64: dts: qcom: sm8250: correct dynamic power coefficients
  (git-fixes).
- arm64: dts: qcom: sm6350: Fix ZAP region (git-fixes).
- arm64: dts: qcom: sm8150: use proper DSI PHY compatible
  (git-fixes).
- arm64: dts: rockchip: Enable SATA on Radxa E25 (git-fixes).
- arm64: dts: rockchip: Fix PCIe regulators on Radxa E25
  (git-fixes).
- arm64: dts: ti: k3-am62x-sk-common: Update main-i2c1 frequency
  (git-fixes).
- arm64: dts: ti: k3-j784s4: Fix interrupt ranges for wkup &
  main gpio (git-fixes).
- arm64: dts: ti: k3-am62-main: Remove power-domains from crypto
  node (git-fixes).
- arm64: dts: imx8mp-debix: remove unused fec pinctrl node
  (git-fixes).
- arm64: dts: renesas: rzg2l: Fix txdv-skew-psec typos
  (git-fixes).
- arm64: tegra: Fix HSUART for Smaug (git-fixes).
- arm64: tegra: Fix HSUART for Jetson AGX Orin (git-fixes).
- arm64: tegra: Update AHUB clock parent and rate (git-fixes).
- arm64: tegra: Update AHUB clock parent and rate on Tegra234
  (git-fixes).
- ARM: OMAP2+: Fix -Warray-bounds warning in _pwrdm_state_switch()
  (git-fixes).
- arm64: defconfig: enable Qualcomm MSM8996 Global Clock
  Controller as built-in (git-fixes).
- ALSA: pcm: Fix missing fixup call in compat hw_refine ioctl
  (git-fixes).
- ASoC: tegra: Fix SFC conversion for few rates (git-fixes).
- ASoC: cs43130: Fix numerator/denominator mixup (git-fixes).
- ASoC: soc-compress: Fix deadlock in soc_compr_open_fe
  (git-fixes).
- ASoC: SOF: amd: clear dsp to host interrupt status (git-fixes).
- ASoC: SOF: Intel: fix u16/32 confusion in LSDIID (git-fixes).
- ASoC: SOF: Intel: hda-mlink: fix off-by-one error (git-fixes).
- ASoC: fsl: fsl_qmc_audio: Fix snd_pcm_format_t values handling
  (git-fixes).
- ALSA: ac97: Fix possible error value of *rac97 (git-fixes).
- ASoC: stac9766: fix build errors with REGMAP_AC97 (git-fixes).
- backlight/lv5207lp: Compare against struct fb_info.device
  (git-fixes).
- backlight/gpio_backlight: Compare against struct fb_info.device
  (git-fixes).
- backlight/bd6107: Compare against struct fb_info.device
  (git-fixes).
- audit: fix possible soft lockup in __audit_inode_child()
  (git-fixes).
- ARM: module: Use module_init_layout_section() to spot init
  sections (git-fixes).
- module: Expose module_init_layout_section() (git-fixes).
- arm64: mm: use ptep_clear() instead of pte_clear() in
  clear_flush() (git-fixes).
- Bluetooth: hci_conn: Fix not allowing valid CIS ID (git-fixes).
- Bluetooth: ISO: Fix not checking for valid CIG/CIS IDs
  (git-fixes).
- Bluetooth: Remove unused declaration amp_read_loc_info()
  (git-fixes).
- Bluetooth: nokia: fix value check in
  nokia_bluetooth_serdev_probe() (git-fixes).
- ACPI: x86: s2idle: Fix a logic error parsing AMD constraints
  table (git-fixes).
- ACPI: thermal: Drop nocrt parameter (git-fixes).
- arm64: sdei: abort running SDEI handlers during crash
  (git-fixes).
- arm64: vdso: remove two .altinstructions related symbols
  (git-fixes).
- arm64/ptrace: Clean up error handling path in sve_set_common()
  (git-fixes).
- arm64/fpsimd: Only provide the length to cpufeature for xCR
  registers (git-fixes).
- arm_pmu: Add PERF_PMU_CAP_EXTENDED_HW_TYPE capability
  (git-fixes).
- ARM: ptrace: Restore syscall skipping for tracers (git-fixes).
- ARM: ptrace: Restore syscall restart tracing (git-fixes).
- Bluetooth: coredump: fix building with coredump disabled
  (git-fixes).
- ACPI: platform: Ignore SMB0001 only when it has resources
  (git-fixes).
- ACPI: bus: Introduce acpi_match_acpi_device() helper
  (git-fixes).
- ACPI: bus: Constify acpi_companion_match() returned value
  (git-fixes).
- accessibility: use C99 array init (git-fixes).
- ARM: versatile: mark mmc_status() static (git-fixes).
- ARM: dts: BCM5301X: MR26: MR32: remove bogus nand-ecc-algo
  property (git-fixes).
- ARM: dts: exynos: Re-introduce Exynos4212 DTSI (git-fixes).
- ARM: 9314/1: tcm: move tcm_init() prototype to asm/tcm.h
  (git-fixes).
- commit 6febe3e
* Thu Aug 31 2023 jack@suse.cz
- md/raid0: Fix performance regression for large sequential writes
  (bsc#1213916).
- commit 7ba95b5
* Thu Aug 31 2023 jack@suse.cz
- md/raid0: Factor out helper for mapping and submitting a bio
  (bsc#1213916).
- commit f2d9299
* Thu Aug 31 2023 denis.kirjanov@suse.com
- bnx2x: new flag for track HW resource allocation (jsc#PED-5057).
- commit d1a4bac
* Thu Aug 31 2023 denis.kirjanov@suse.com
- bnx2x: Remove unnecessary ternary operators (jsc#PED-5057).
- commit ccf8576
* Thu Aug 31 2023 oneukum@suse.com
- usb: dwc3: Add error logs for unknown endpoint events
  (jsc#PED-4296).
- commit e632528
* Thu Aug 31 2023 tiwai@suse.de
- Update config files: disable CONFIG_LIVEPATCH on kvmsmall flavors more consistently
- commit 95df0d9
* Thu Aug 31 2023 denis.kirjanov@suse.com
- igc: Decrease PTM short interval from 10 us to 1 us (jsc#PED-4075).
- commit 19c485c
* Thu Aug 31 2023 denis.kirjanov@suse.com
- igc: Add support for multiple in-flight TX timestamps (jsc#PED-4075).
- commit c4d3fce
* Thu Aug 31 2023 tiwai@suse.de
- Move upstreamed BT and pinctrl patches into sorted section
- commit ff3c429
* Thu Aug 31 2023 tiwai@suse.de
- firmware: qemu_fw_cfg: Do not hard depend on
  CONFIG_HAS_IOPORT_MAP (bsc#1214773).
- Update config files: enable CONFIG_FW_CFG_SYSFS for armv7hl
- commit 5a5093f
* Thu Aug 31 2023 tiwai@suse.de
- mm/gup: reintroduce FOLL_NUMA as FOLL_HONOR_NUMA_FAULT
  (bsc#1012628).
- Refresh
  patches.suse/mm-gup-add-missing-gup_must_unshare-check-to-gup_huge_pgd.patch.
- commit 3766f26
* Thu Aug 31 2023 tiwai@suse.de
- nfsd: Fix race to FREE_STATEID and cl_revoked (bsc#1012628).
- Refresh
  patches.suse/nfsd-allow-delegation-state-ids-to-be-revoked-and-th.patch.
- commit c83219a
* Thu Aug 31 2023 mwilck@suse.com
- Refresh patches.suse/dm-mpath-leastpending-path-update.
  Fix warning about STATUSTYPE_IMA.
- commit caca08f
* Thu Aug 31 2023 mwilck@suse.com
- Refresh and enable patches.suse/fcoe-reduce-max_sectors.
- commit 6b3df50
* Thu Aug 31 2023 tiwai@suse.de
- Moved upstreamed DRM and opal patches into sorted section
- commit e879562
* Thu Aug 31 2023 tiwai@suse.de
- Update config files: only version changes to 6.4.13
- commit f6cd6ea
* Thu Aug 31 2023 tiwai@suse.de
- sched/cpuset: Bring back cpuset_mutex (bsc#1012628).
  Dropped patches.suse/sched-cpuset-Bring-back-cpuset_mutex.patch
- commit 5ab50d0
* Thu Aug 31 2023 tiwai@suse.de
- Linux 6.4.13 (bsc#1012628).
- netfilter: nf_tables: fix kdoc warnings after gc rework
  (bsc#1012628).
- TIOCSTI: Document CAP_SYS_ADMIN behaviour in Kconfig
  (bsc#1012628).
- ASoC: amd: vangogh: select CONFIG_SND_AMD_ACP_CONFIG
  (bsc#1012628).
  Dropped patches.suse/ASoC-amd-vangogh-select-CONFIG_SND_AMD_ACP_CONFIG.patch
- maple_tree: disable mas_wr_append() when other readers are
  possible (bsc#1012628).
- ASoC: amd: yc: Fix a non-functional mic on Lenovo 82SJ
  (bsc#1012628).
- gpio: sim: pass the GPIO device's software node to irq domain
  (bsc#1012628).
- gpio: sim: dispose of irq mappings before destroying the
  irq_sim domain (bsc#1012628).
- dma-buf/sw_sync: Avoid recursive lock during fence signal
  (bsc#1012628).
- pinctrl: renesas: rza2: Add lock around
  pinctrl_generic{{add,remove}_group,{add,remove}_function}
  (bsc#1012628).
- pinctrl: renesas: rzv2m: Fix NULL pointer dereference in
  rzv2m_dt_subnode_to_map() (bsc#1012628).
- pinctrl: renesas: rzg2l: Fix NULL pointer dereference in
  rzg2l_dt_subnode_to_map() (bsc#1012628).
- ASoC: cs35l56: Read firmware uuid from a device property
  instead of _SUB (bsc#1012628).
- ASoC: SOF: ipc4-pcm: fix possible null pointer deference
  (bsc#1012628).
- clk: Fix undefined reference to `clk_rate_exclusive_{get,put}'
  (bsc#1012628).
- scsi: core: raid_class: Remove raid_component_add()
  (bsc#1012628).
- scsi: ufs: ufs-qcom: Clear qunipro_g4_sel for HW major version >
  5 (bsc#1012628).
- scsi: snic: Fix double free in snic_tgt_create() (bsc#1012628).
- madvise:madvise_free_pte_range(): don't use mapcount() against
  large folio for sharing check (bsc#1012628).
- madvise:madvise_cold_or_pageout_pte_range(): don't use
  mapcount() against large folio for sharing check (bsc#1012628).
- drm/i915: Fix error handling if driver creation fails during
  probe (bsc#1012628).
- can: raw: add missing refcount for memory leak fix
  (bsc#1012628).
- thunderbolt: Fix Thunderbolt 3 display flickering issue on
  2nd hot plug onwards (bsc#1012628).
- PCI: acpiphp: Use pci_assign_unassigned_bridge_resources()
  only for non-root bus (bsc#1012628).
- media: vcodec: Fix potential array out-of-bounds in encoder
  queue_setup (bsc#1012628).
- pinctrl: amd: Mask wake bits on probe again (bsc#1012628).
- of: dynamic: Refactor action prints to not use "%%pOF" inside
  devtree_lock (bsc#1012628).
- of: unittest: Fix EXPECT for parse_phandle_with_args_map()
  test (bsc#1012628).
- radix tree: remove unused variable (bsc#1012628).
- riscv: Fix build errors using binutils2.37 toolchains
  (bsc#1012628).
- riscv: Handle zicsr/zifencei issue between gcc and binutils
  (bsc#1012628).
- lib/clz_ctz.c: Fix __clzdi2() and __ctzdi2() for 32-bit kernels
  (bsc#1012628).
- ACPI: resource: Fix IRQ override quirk for PCSpecialist Elimina
  Pro 16 M (bsc#1012628).
- batman-adv: Hold rtnl lock during MTU update via netlink
  (bsc#1012628).
- batman-adv: Fix batadv_v_ogm_aggr_send memory leak
  (bsc#1012628).
- batman-adv: Fix TT global entry leak when client roamed back
  (bsc#1012628).
- batman-adv: Do not get eth header before
  batadv_check_management_packet (bsc#1012628).
- batman-adv: Don't increase MTU when set by user (bsc#1012628).
- batman-adv: Trigger events for auto adjusted MTU (bsc#1012628).
- selinux: set next pointer before attaching to list
  (bsc#1012628).
- NFS: Fix a use after free in nfs_direct_join_group()
  (bsc#1012628).
- nilfs2: fix general protection fault in
  nilfs_lookup_dirty_data_buffers() (bsc#1012628).
- mm: multi-gen LRU: don't spin during memcg release
  (bsc#1012628).
- mm: memory-failure: fix unexpected return value in
  soft_offline_page() (bsc#1012628).
- mm: add a call to flush_cache_vmap() in vmap_pfn()
  (bsc#1012628).
- cgroup/cpuset: Free DL BW in case can_attach() fails
  (bsc#1012628).
  Drop patches.suse/cgroup-cpuset-Free-DL-BW-in-case-can_attach-fails.patch
- sched/deadline: Create DL BW alloc, free & check overflow
  interface (bsc#1012628).
  Drop patches.suse/sched-deadline-Create-DL-BW-alloc-free-check-overflow-interface.patch
- cgroup/cpuset: Iterate only if DEADLINE tasks are present
  (bsc#1012628).
- sched/cpuset: Keep track of SCHED_DEADLINE task in cpusets
  (bsc#1012628).
  Drop patches.suse/sched-cpuset-Keep-track-of-SCHED_DEADLINE-task-in-cpusets.patch
- cgroup/cpuset: Rename functions dealing with DEADLINE accounting
  (bsc#1012628).
- drm/i915: fix display probe for IVB Q and IVB D GT2 server
  (bsc#1012628).
- drm/i915/display: Handle GMD_ID identification in display code
  (bsc#1012628).
- x86/fpu: Set X86_FEATURE_OSXSAVE feature after enabling OSXSAVE
  in CR4 (bsc#1012628).
- x86/fpu: Invalidate FPU state correctly on exec() (bsc#1012628).
- LoongArch: Fix hw_breakpoint_control() for watchpoints
  (bsc#1012628).
- drm/i915: Fix HPD polling, reenabling the output poll work as
  needed (bsc#1012628).
- drm/display/dp: Fix the DP DSC Receiver cap size (bsc#1012628).
- drm/i915/dgfx: Enable d3cold at s2idle (bsc#1012628).
- drm/panfrost: Skip speed binning on EOPNOTSUPP (bsc#1012628).
- drm: Add an HPD poll helper to reschedule the poll work
  (bsc#1012628).
- drm/vmwgfx: Fix possible invalid drm gem put calls
  (bsc#1012628).
- drm/vmwgfx: Fix shader stage validation (bsc#1012628).
- mm/gup: handle cont-PTE hugetlb pages correctly in
  gup_must_unshare() via GUP-fast (bsc#1012628).
- mm: enable page walking API to lock vmas during the walk
  (bsc#1012628).
- selftests/mm: FOLL_LONGTERM need to be updated to 0x100
  (bsc#1012628).
- ALSA: ymfpci: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- shmem: fix smaps BUG sleeping while atomic (bsc#1012628).
- mm,ima,kexec,of: use memblock_free_late from
  ima_free_kexec_buffer (bsc#1012628).
- clk: Fix slab-out-of-bounds error in devm_clk_release()
  (bsc#1012628).
- NFSv4: Fix dropped lock for racing OPEN and delegation return
  (bsc#1012628).
- platform/x86: ideapad-laptop: Add support for new hotkeys
  found on ThinkBook 14s Yoga ITL (bsc#1012628).
- platform/x86: lenovo-ymc: Add Lenovo Yoga 7 14ACN6 to
  ec_trigger_quirk_dmi_table (bsc#1012628).
- wifi: mac80211: limit reorder_buf_filtered to avoid UBSAN
  warning (bsc#1012628).
- ibmveth: Use dcbf rather than dcbfl (bsc#1012628).
- spi: spi-cadence: Fix data corruption issues in slave mode
  (bsc#1012628).
- ASoC: cs35l41: Correct amp_gain_tlv values (bsc#1012628).
- ASoC: amd: yc: Add VivoBook Pro 15 to quirks list for acp6x
  (bsc#1012628).
- bonding: fix macvlan over alb bond support (bsc#1012628).
- rtnetlink: Reject negative ifindexes in RTM_NEWLINK
  (bsc#1012628).
- netfilter: nf_tables: defer gc run if previous batch is still
  pending (bsc#1012628).
- netfilter: nf_tables: fix out of memory error handling
  (bsc#1012628).
- netfilter: nf_tables: use correct lock to protect gc_list
  (bsc#1012628).
- netfilter: nf_tables: GC transaction race with abort path
  (bsc#1012628).
- netfilter: nf_tables: flush pending destroy work before netlink
  notifier (bsc#1012628).
- netfilter: nf_tables: validate all pending tables (bsc#1012628).
- i40e: fix potential NULL pointer dereferencing of pf->vf
  i40e_sync_vsi_filters() (bsc#1012628).
- net/sched: fix a qdisc modification with ambiguous command
  request (bsc#1012628).
- igc: Fix the typo in the PTM Control macro (bsc#1012628).
- igb: Avoid starting unnecessary workqueues (bsc#1012628).
- can: isotp: fix support for transmission of SF without flow
  control (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix NULL pointer on hw reset
  (bsc#1012628).
- tg3: Use slab_build_skb() when needed (bsc#1012628).
- selftests: bonding: do not set port down before adding to bond
  (bsc#1012628).
- ice: Fix NULL pointer deref during VF reset (bsc#1012628).
- Revert "ice: Fix ice VF reset during iavf initialization"
  (bsc#1012628).
- ice: fix receive buffer size miscalculation (bsc#1012628).
- ipv4: fix data-races around inet->inet_id (bsc#1012628).
- net: validate veth and vxcan peer ifindexes (bsc#1012628).
- net: bcmgenet: Fix return value check for fixed_phy_register()
  (bsc#1012628).
- net: bgmac: Fix return value check for fixed_phy_register()
  (bsc#1012628).
- net: mdio: mdio-bitbang: Fix C45 read/write protocol
  (bsc#1012628).
- net: dsa: mt7530: fix handling of 802.1X PAE frames
  (bsc#1012628).
- selftests: mlxsw: Fix test failure on Spectrum-4 (bsc#1012628).
- mlxsw: Fix the size of 'VIRT_ROUTER_MSB' (bsc#1012628).
- mlxsw: reg: Fix SSPR register layout (bsc#1012628).
- mlxsw: pci: Set time stamp fields also when its type is
  MIRROR_UTC (bsc#1012628).
- ipvlan: Fix a reference count leak warning in ipvlan_ns_exit()
  (bsc#1012628).
- dccp: annotate data-races in dccp_poll() (bsc#1012628).
- sock: annotate data-races around prot->memory_pressure
  (bsc#1012628).
- net: dsa: felix: fix oversize frame dropping for always closed
  tc-taprio gates (bsc#1012628).
- devlink: add missing unregister linecard notification
  (bsc#1012628).
- octeontx2-af: SDP: fix receive link config (bsc#1012628).
- tracing: Fix memleak due to race between current_tracer and
  trace (bsc#1012628).
- tracing/synthetic: Allocate one additional element for size
  (bsc#1012628).
- tracing/synthetic: Skip first entry for stack traces
  (bsc#1012628).
- tracing/synthetic: Use union instead of casts (bsc#1012628).
- tracing: Fix cpu buffers unavailable due to 'record_disabled'
  missed (bsc#1012628).
- wifi: iwlwifi: mvm: add dependency for PTP clock (bsc#1012628).
- can: raw: fix lockdep issue in raw_release() (bsc#1012628).
- can: raw: fix receiver memory leak (bsc#1012628).
- jbd2: fix a race when checking checkpoint buffer busy
  (bsc#1012628).
- jbd2: remove journal_clean_one_cp_list() (bsc#1012628).
- jbd2: remove t_checkpoint_io_list (bsc#1012628).
- PCI: acpiphp: Reassign resources on bridge if necessary
  (bsc#1012628).
- xprtrdma: Remap Receive buffers after a reconnect (bsc#1012628).
- NFSv4: fix out path in __nfs4_get_acl_uncached (bsc#1012628).
- NFSv4.2: fix error handling in nfs42_proc_getxattr
  (bsc#1012628).
- commit 1bfff59
* Thu Aug 31 2023 jlee@suse.com
- Refresh
  patches.suse/0004-MODSIGN-checking-the-blacklisted-hash-before-loading.patch.
  Fixed backporting issue of
  0004-MODSIGN-checking-the-blacklisted-hash-before-loading.patch, the
  issue causes that all kernel module can NOT pass the hash blacklist
  checking. System boot will hang when security boot is enabled.
  The kernel/module_signing.c be moved to kernel/module/signing.c. When
  backporting the original patch to new C source file, I lost one
  statement for setting the value of wholelen. It causes that the
  value of wholelen is zero.
- commit 23db872
* Wed Aug 30 2023 fweisbecker@suse.de
- Delete downstream arm64 CONFIG_PREEMPT_DYNAMIC support
  Upstream has a proper solution now.
  Remove:
  patches.suse/static_call-Use-non-function-types-to-refer-to-the-t.patch
  patches.suse/arm64-implement-support-for-static-call-trampolines.patch
  patches.suse/sched-preempt-Prepare-for-supporting-CONFIG_GENERIC_.patch
  patches.suse/arm64-Implement-IRQ-exit-preemption-static-call-for-.patch
  patches.suse/arm64-Implement-HAVE_PREEMPT_DYNAMIC.patch
  patches.suse/static_call-Fix-tools_headers.patch
  patches.suse/sched-preempt-Tell-about-PREEMPT_DYNAMIC-on-kernel-h.patch
- commit 544b42e
* Wed Aug 30 2023 jlee@suse.com
- Remove SP6-NEED-REVIEW tag of
  patches.suse/0001-efi-do-not-automatically-generate-secret-key.patch
- commit bee5a51
* Wed Aug 30 2023 mwilck@suse.com
- Delete patches.suse/dm-table-switch-to-readonly.
  This patch is ancient, and upstream multipath-tools has taken
  a lot of care to improve handling of read-only devices in the
  meantime.
- commit 414f55e
* Wed Aug 30 2023 mwilck@suse.com
- Refresh and enable patches.suse/dm-mpath-no-partitions-feature.
- commit 5c355e7
* Wed Aug 30 2023 mwilck@suse.com
- Enable patches.suse/dm-mpath-leastpending-path-update
- commit 931db33
* Wed Aug 30 2023 mbenes@suse.cz
- Keep and refresh live patching OOT patches
- Refresh
  patches.suse/Revert-Revert-kbuild-use-flive-patching-when-CONFIG_LIVEPATCH-is-enabled.patch.
- Refresh
  patches.suse/Revert-kallsyms-unexport-kallsyms_lookup_name-and-kallsyms_on_each_symbol.patch.
- Refresh patches.suse/livepatch-dump-ipa-clones.patch.
  Refresh configs appropriately.
- commit d9c04f0
* Wed Aug 30 2023 jlee@suse.com
- Refresh
  patches.suse/0011-PM-hibernate-require-hibernate-snapshot-image-to-be-.patch.
  Respin and remove SP6-NEED-REVIEW tag
- commit bdade2f
* Wed Aug 30 2023 mbenes@suse.cz
- Keep and refresh patches.suse/prepare-arm64-klp.
  Having a live patching support on arm64 arch is still in future but
  better be prepared than sorry.
- commit ce951ea
* Wed Aug 30 2023 vbabka@suse.cz
- Refresh
  patches.kernel.org/6.4.3-006-fork-lock-VMAs-of-the-parent-process-when-forki.patch.
  Mark duplicate Alt-commit.
- commit d42a7e3
* Wed Aug 30 2023 mwilck@suse.com
- Refresh and enable
  patches.suse/sd-always-retry-READ-CAPACITY-for-ALUA-state-transit.patch.
- commit ef20ec6
* Wed Aug 30 2023 mwilck@suse.com
- Refresh and enable
  patches.suse/scsi-do-not-print-reservation-conflict-for-TEST-UNIT.patch.
- commit f191f06
* Wed Aug 30 2023 mwilck@suse.com
- Refresh and enable
  patches.suse/scsi-do-not-put-scsi_common-in-a-separate-module.patch.
- commit 7f0ed1b
* Wed Aug 30 2023 mwilck@suse.com
- Refresh and enable
  patches.suse/scsi-add-disable_async_probing-module-argument.patch.
- commit 3d3db3a
* Wed Aug 30 2023 mwilck@suse.com
- Refresh and enable patches.suse/drivers-base-implement-dev_enable_async_probe.patch.
- commit c77fab8
* Wed Aug 30 2023 mwilck@suse.com
- Refresh and enable patches.suse/0012-nvme-add-TCP-TSAS-definitions.patch.
- commit 3fded15
* Wed Aug 30 2023 mwilck@suse.com
- Refresh and enable patches.suse/scsi_probe_lun-retry-after-timeout.patch.
  We had expected upstream to come up with a generic solution for this issue,
  but the patch set from Mike Christie ("scsi: Allow scsi_execute users to
  control retries") hasn't been merged yet.
- commit a7b4538
* Wed Aug 30 2023 jlee@suse.com
- Refresh
  patches.suse/0010-PM-hibernate-a-option-to-request-that-snapshot-image.patch.
- Respin and remove SP6-NEED-REVIEW tag
- Update config files.
  Add "CONFIG_HIBERNATE_VERIFICATION_FORCE is not set" to x86_64/default
- commit d54d8a5
* Wed Aug 30 2023 jslaby@suse.cz
- rpm/mkspec-dtb: dtbs have moved to vendor sub-directories in 6.5
  By commit 724ba6751532 ("ARM: dts: Move .dts files to vendor
  sub-directories").
  So switch to them.
- rpm/mkspec-dtb: support for nested subdirs
  Commit 724ba6751532 ("ARM: dts: Move .dts files to vendor
  sub-directories") moved the dts to nested subdirs, add a support for
  that. That is, generate a %%dir entry in %%files for them.
- commit 7aee36a
* Wed Aug 30 2023 jlee@suse.com
- Remove SP6-NEED-REVIEW tag of
  patches.suse/0009-PM-hibernate-prevent-EFI-secret-key-to-be-regenerate.patch
- commit b17726b
* Wed Aug 30 2023 jlee@suse.com
- Refresh
  patches.suse/0008-PM-hibernate-Generate-and-verify-signature-for-snaps.patch.
- Respin and remove SP6-NEED-REVIEW tag
- Update config files.
  Add CONFIG_HIBERNATE_VERIFICATION=y to x86_64/default
- commit 6734d6b
* Wed Aug 30 2023 mhocko@suse.com
- Update
  patches.kernel.org/6.4.8-233-mm-mempolicy-Take-VMA-lock-before-replacing-pol.patch
  (bsc#1012628, bsc#1214772, CVE-2023-4611).
- commit 6826347
* Wed Aug 30 2023 jlee@suse.com
- Refresh
  patches.suse/0007-PM-hibernate-encrypt-hidden-area.patch.
  Respin and remove SP6-NEED-REVIEW tag
- commit 1387f3a
* Wed Aug 30 2023 jlee@suse.com
- Refresh
  patches.suse/0006-efi-allow-user-to-regenerate-secret-key.patch.
  Respin and remove SP6-NEED-REVIEW tag
- commit ac459a4
* Wed Aug 30 2023 jlee@suse.com
- Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch.
- Respin and remove SP6-NEED-REVIEW tag
- Update config files.
  Add CONFIG_EFI_SECRET_KEY=y and CONFIG_HIDDEN_AREA=y to x86_64/default
- commit 71d7282
* Tue Aug 29 2023 jlee@suse.com
- Remove SP6-NEED-REVIEW tag of
  patches.suse/0002-hibernate-avoid-the-data-in-hidden-area-to-be-snapsh.patch
- commit 3e6ea23
* Tue Aug 29 2023 vbabka@suse.cz
- Delete patches.suse/mm-khugepaged-disable-thp-for-fs.patch.
  CONFIG_READ_ONLY_THP_FOR_FS is now disabled properly (bsc#1195774).
- commit 01da5a1
* Tue Aug 29 2023 vbabka@suse.cz
- Update config files. Disable CONFIG_READ_ONLY_THP_FOR_FS (bsc#1195774).
- commit da35a7b
* Tue Aug 29 2023 tiwai@suse.de
- Move upstreamed powerpc patches into sorted section
- commit 8dc244c
* Tue Aug 29 2023 tiwai@suse.de
- Move upstreamed ACPI patch into sorted section
- commit f6c39ca
* Tue Aug 29 2023 tiwai@suse.de
- i2c: i801: Add support for Intel Meteor Lake PCH-S (jsc#PED-4696
  jsc#PED-4698).
- i2c: i801: Add support for Intel Meteor Lake SoC-S (jsc#PED-4696
  jsc#PED-4698).
- i2c: i801: Enlarge device name field in i801_ids table
  (jsc#PED-4696 jsc#PED-4698).
- commit b2dab8e
* Tue Aug 29 2023 jslaby@suse.cz
- platform/x86:intel/pmc: Add Meteor Lake IOE-M PMC related maps
  (jsc#PED-6091).
- platform/x86:intel/pmc: Add Meteor Lake IOE-P PMC related maps
  (jsc#PED-6091).
- platform/x86:intel/pmc: Use SSRAM to discover pwrm base address
  of primary PMC (jsc#PED-6091).
- platform/x86:intel/pmc: Discover PMC devices (jsc#PED-6091).
- platform/x86:intel/pmc: Enable debugfs multiple PMC support
  (jsc#PED-6091).
- platform/x86:intel/pmc: Add support to handle multiple PMCs
  (jsc#PED-6091).
- platform/x86:intel/pmc: Combine core_init() and core_configure()
  (jsc#PED-6091).
- commit c417bbb
* Tue Aug 29 2023 jslaby@suse.cz
- Update
  patches.kernel.org/6.4.4-485-platform-x86-intel-pmc-Update-maps-for-Meteor-L.patch
  (bsc#1012628 jsc#PED-6091).
- commit c13a250
* Tue Aug 29 2023 iivanov@suse.de
- Refresh patches.suse/lan78xx-Enable-LEDs-and-auto-negotiation.patch
  Remove SP6-NEED-REVIEW tag.
- commit a73dd2f
* Tue Aug 29 2023 iivanov@suse.de
- Refresh patches.suse/kabi-arm64-reserve-space-in-cpu_hwcaps-and-cpu_hwcap.patch.
  Remove SP6-NEED-REVIEW tag.
- commit 7ad5e63
* Tue Aug 29 2023 iivanov@suse.de
- Delete patches.suse/soc-bcm-bcm2835-pm-add-support-for-bcm2711.patch
  Implemented by upstream commit:
  commit df76234276e22136b2468825c18407fdfbb2076a
  Author: Stefan Wahren <stefan.wahren@i2se.com>
  Date:   Sat Jun 25 13:36:15 2022 +0200
    mfd: bcm2835-pm: Add support for BCM2711
- commit 8483810
* Tue Aug 29 2023 iivanov@suse.de
- Delete patches.suse/reset-raspberrypi-don-t-reset-usb-if-already-up.patch
  As per my comment#47 in bsc#1180336 tested with TW at that moment.
  Briefly tested kernel with above kernel workaround
  reverted, using USB keyboard. It was detected during boot
  and plugging it in and out seems to properly detected and
  handled.
  raspberrypi-firmware          - 2022.01.24-1.1
  raspberrypi-eeprom[-firmware] - 2021.04.29-2.1
  u-boot-rpiarm64               - 2022.01-2.1
- commit 34fe1ed
* Tue Aug 29 2023 iivanov@suse.de
- Delete patches.suse/drm-v3d-add-support-for-bcm2711.patch.
  Merged upstream.
  commit e5a068983cf41bfee2c15656e62f401c5f8b0437
  Author: Peter Robinson <pbrobinson@gmail.com>
  Date:   Fri Jun 3 10:26:07 2022 +0100
    drm/v3d: Add support for bcm2711
- commit dfe2489
* Tue Aug 29 2023 petr.pavlu@suse.com
- Delete
  patches.suse/oracleasm-reinstate-bio_map_user_iov-declaration-in-.patch.
  Patches oracleasm-reinstate-bio_map_user_iov-declaration-in-.patch and
  0001-oracleasm-4.0-compat-changes.patch together previously exported
  function bio_map_user_iov() for use in the oracleasm KMP.
  This downstream change is no longer necessary because oracleasm in
  15-SP6 has a patch which avoids its use:
  oracleasm-asm_bio_map_user_iov-and-asm_bio_unmap-update-for-5.15+-kernel.patch.
  Kernel patch 0001-oracleasm-4.0-compat-changes.patch was already dropped
  in 15-SP6 by commit 67f601c4765. Remove the associated patch
  oracleasm-reinstate-bio_map_user_iov-declaration-in-.patch too.
- commit 893eaeb
* Tue Aug 29 2023 jlee@suse.com
- Refresh
  patches.suse/0001-security-create-hidden-area-to-keep-sensitive-data.patch.
- Respin and remove SP6-NEED-REVIEW tag
- Update config files.
  Add # CONFIG_HIDDEN_AREA is not set
- commit c7bc13d
* Tue Aug 29 2023 jlee@suse.com
- Refresh
  patches.suse/Bluetooth-hci_ldisc-check-HCI_UART_PROTO_READY-flag-.patch.
- Respin and remove SP6-NEED-REVIEW tag
- Change Git-commit id to 9c33663af9ad115f90c076a1828129a3fbadea98
- commit d45a993
* Tue Aug 29 2023 oneukum@suse.com
- Delete patches.suse/nxp-nci-add-NXP1002-id.patch.
  gone upstream
- commit b030abb
* Tue Aug 29 2023 jlee@suse.com
- Refresh
  patches.suse/0004-MODSIGN-checking-the-blacklisted-hash-before-loading.patch.
  Respin and remove SP6-NEED-REVIEW tag
- commit f2aed69
* Tue Aug 29 2023 jlee@suse.com
- Delete
  patches.suse/0001-MODSIGN-do-not-load-mok-when-secure-boot-disabled.patch.
  Removed 0001-MODSIGN-do-not-load-mok-when-secure-boot-disabled.patch
  because it be merged on upstream since v5.17-rc1. The commit id is
  92ad19559ea9a8ec6f158480934ae26ebfe2c14f.
- commit d1df84c
* Tue Aug 29 2023 jlee@suse.com
- Refresh
  patches.suse/acpi-Disable-APEI-error-injection-if-the-kernel-is-lockeddown.patch.
  Respin and remove SP6-NEED-REVIEW tag
- commit 19b185d
* Mon Aug 28 2023 jack@suse.cz
- patches.suse/add-suse-supported-flag.patch: Add CONFIG_MODULES dependency
- commit 045364c
* Mon Aug 28 2023 ematsumiya@suse.de
- supported.conf: update fs/cifs -> fs/smb/client
  Also update fs/smbfs_common -> fs/smb/common.
  (changes introduced by upstream 38c8a9a5208).
- commit 6514fbf
* Mon Aug 28 2023 ematsumiya@suse.de
- Update config files.
  Unset CONFIG_SMB_SERVER*.
- commit 4e9535f
* Mon Aug 28 2023 oneukum@suse.com
- reenabling our NFC fix for SLEPOS
  A clean fix is worked upon, but upstream is difficult
- commit 9351328
* Mon Aug 28 2023 oneukum@suse.com
- Refresh
  patches.suse/0001-kvm-Reintroduce-nopvspin-kernel-parameter.patch.
  We cannot drop a kernel parameter without warning.
  So teh restoration needs to be restored.
- commit 90496d6
* Mon Aug 28 2023 tzimmermann@suse.com
- Enable patches.suse/0001-Reserve-64MiB-of-CMA-for-RPi3-s-VC4.patch
  Re-enable the patch on SLE15-SP6. We need the extra CMA memory to
  OOM errors in graphics code.
- commit 19f6c08
* Mon Aug 28 2023 tzimmermann@suse.com
- Enable patches/patches.suse/0001-firmware-sysfb-Add-parameter-to-enable-sysfb-support.patch
  Refresh the patch and re-enable it on SLE15-SP6. We'll need this patch until
  Nvidia provides decent console emulation.
- commit f568f53
* Mon Aug 28 2023 tzimmermann@suse.com
- Remove patches.suse/0001-drm-vmwgfx-Avoid-NULL-ptr-deref-in-vmw_cmd_dx_define.patch
  The patch is identical to patches.suse/drm-vmwgfx-Avoid-NULL-ptr-deref-in-vmw_cmd_dx_define.patch,
  hence remove it.
- commit a2f6396
* Mon Aug 28 2023 mgorman@suse.de
- mm: avoid 'might_sleep()' in get_mmap_lock_carefully()
  (bsc#1212886 (MM functional and performance backports)).
- mm: compaction: fix endless looping over same migrate block
  (bsc#1212886 (MM functional and performance backports)).
- mm: compaction: convert to use a folio in
  isolate_migratepages_block() (bsc#1212886 (MM functional and
  performance backports)).
- commit e867814
* Mon Aug 28 2023 oneukum@suse.com
- Delete patches.suse/kABI-padding-for-qat.patch.
  No longer applicable. Should be redone after qat updates
- commit c6645e0
* Mon Aug 28 2023 oneukum@suse.com
- Refresh patches.suse/kABI-padding-for-generic-crypto.patch.
  reworked. Structure much changed in v6.4
- commit 530349c
* Mon Aug 28 2023 oneukum@suse.com
- reenabled kABI padding for FPGA
  minimal cost, high potential utility
- commit 964471a
* Mon Aug 28 2023 oneukum@suse.com
- reenabled kABI padding for the generic crypto layer
  cost is minimal, but if we need it we will really need it
- commit 113e068
* Mon Aug 28 2023 oneukum@suse.com
- reenable kABI padding for rfkill
  needed in SP6, too
- commit 88c90bc
* Mon Aug 28 2023 oneukum@suse.com
- Refresh patches.suse/paddings-for-mediatek-802.11.patch.
- Refresh patches.suse/paddings-for-realtik-802.11.patch.
  reenabled WiFi kABI placeholders for SP6
- commit eb82166
* Mon Aug 28 2023 neilb@suse.de
- Refresh patches.suse/md-display-timeout-error.patch.
  Enable this patch which is still needed for SP6
- commit dd44ffd
* Mon Aug 28 2023 neilb@suse.de
- Refresh
  patches.suse/0001-NFS-flush-out-dirty-data-on-file-fput.patch.
- Refresh
  patches.suse/NFS-Handle-missing-attributes-in-OPEN-reply.patch.
- Refresh patches.suse/NFS-flush-dirty-data-on-fput-fix.patch.
- Refresh
  patches.suse/NFS-only-invalidate-dentrys-that-are-clearly-invalid.patch.
- Refresh patches.suse/mvfs-workaround.patch.
- Refresh patches.suse/nfs-access-cache-no-negative.patch.
- Refresh patches.suse/nfs-set-acl-perm.patch.
- Refresh
  patches.suse/nfsd-allow-delegation-state-ids-to-be-revoked-and-th.patch.
- Refresh
  patches.suse/nfsd-allow-lock-state-ids-to-be-revoked-and-then-fre.patch.
- Refresh
  patches.suse/nfsd-allow-open-state-ids-to-be-revoked-and-then-fre.patch.
- Refresh patches.suse/nfsd-dont-revoke-v4-0-states.patch.
- Refresh
  patches.suse/nfsd-prepare-for-supporting-admin-revocation-of-stat.patch.
  Enable multiple NFS patches which are still needed.
- commit 143db46
* Mon Aug 28 2023 neilb@suse.de
- Delete patches.suse/NFSv3-handle-out-of-order-write-replies.patch.
  Fixed in v6.4 by
  Commit: 3db63daabe21 ("NFSv3: handle out-of-order write replies.")
- commit 3e2542b
* Mon Aug 28 2023 neilb@suse.de
- Delete patches.suse/NFS-do-not-take-i_rwsem-for-swap-IO.patch.
  and patches.suse/NFS-move-generic_write_checks-call-from-nfs_file_dir.patch
  Both fixed in 5.18 by
  Commit: 64158668ac8b ("NFS: swap IO handling is slightly different for O_DIRECT IO")
- commit 6dbdada
* Mon Aug 28 2023 neilb@suse.de
- Delete patches.suse/MM-reclaim-mustn-t-enter-FS-for-swap-over-NFS.patch.
  Fixed in 5.19 by
  Commit: d791ea676b66 ("mm: reclaim mustn't enter FS for SWP_FS_OPS swap-space")
- commit 15ce6a7
* Mon Aug 28 2023 neilb@suse.de
- Delete patches.suse/NFSv4.1-bc-request-hold-xprt-ref.patch.
  Fixed in 5.4 by
  Commit: 875f0706accd ("SUNRPC: The TCP back channel mustn't disappear while requests are outstanding")
- commit 4d05deb
* Sat Aug 26 2023 jslaby@suse.cz
- Refresh
  patches.suse/x86-alternative-Make-debug-alternative-selective.patch.
- Refresh
  patches.suse/x86-alternative-Support-relocations-in-alternatives.patch.
- Refresh
  patches.suse/x86-lib-memmove-Decouple-ERMS-from-FSRM.patch.
  Update for SLE15-SP6 (upstream versions apply cleanly now) and move to
  sorted section.
- commit b13a7e4
* Fri Aug 25 2023 jeffm@suse.com
- Refresh patches.suse/reiserfs-mark-read-write-mode-unsupported.patch.
  This is still needed for migrations.
- commit 3960d8d
* Fri Aug 25 2023 jeffm@suse.com
- Delete reiserfs fixes that can only be triggered in read-write mode.
- Delete patches.suse/reiserfs-add-check-to-detect-corrupted-directory-entry.patch.
- Delete patches.suse/reiserfs-don-t-panic-on-bad-directory-entries.patch.
  We haven't supported read-write reiserfs at all in SLE15, so we can drop these.
- commit a4a758e
* Fri Aug 25 2023 jeffm@suse.com
- Refresh patches.suse/procfs-add-tunable-for-fd-fdinfo-dentry-retention.patch.
  This patch is still needed to avoid stalls while freeing
  /proc/pid/task/tid/fd{,info} dentries on huge systems.
- commit 6c2d081
* Fri Aug 25 2023 jeffm@suse.com
- Refresh patches.suse/oracleasm-reinstate-bio_map_user_iov-declaration-in-.patch.
  This patch is still required for the oracleasm KMP to work.
- commit f45d5f5
* Fri Aug 25 2023 tiwai@suse.de
- Update config files: back to CONFIG_PREEMPTY_NONE=y for x86_64 & arm64 default
  Unlike SLE15-SP5, CONFIG_PREEMPT_NONE, _VOLUNTARY and CONFIG_PREEMPT
  specify the default scheduler while the dynamic preemption switch is
  enabled via CONFIG_PREEMPT_DYNAMIC=y.  It was set to a wrong scheduler
  mistakenly while converting to the 6.4-based configs.
- commit 3e4023b
* Fri Aug 25 2023 tiwai@suse.de
- Update 6.5-rc patch references (bsc#1213666 CVE-2023-3772 CVE-2023-31248 bsc#1213061 CVE-2023-35001 bsc#1213059 CVE-2023-3776 bsc#1213588 CVE-2023-3611 bsc#1213585 bsc#1213812 CVE-2023-4004 CVE-2023-4147 bsc#1213968 bsc#1213287 CVE-2023-20569 CVE-2023-34319 XSA-432 bsc#1213546)
- commit 36505d8
* Fri Aug 25 2023 ohering@suse.de
- drop obsolete Hyper-V TDX patch
- commit 4a2ee7b
* Fri Aug 25 2023 ohering@suse.de
- reenable Hyper-V guest-os-id for accurate telemetry (bsc#1189965)
- commit d456d31
* Fri Aug 25 2023 tiwai@suse.de
- Update config files: CONFIG_SUSE_KERNEL_SUPPORTED=n for s390x/zfcpdump
  Otherwise it breaks the build.
- commit ae0c00b
* Fri Aug 25 2023 tiwai@suse.de
- Delete patches.suse/revert-modpost-remove-get_next_text-and-make-grab-release_-file-s.patch
  The revert is already included in patches.suse/add-suse-supported-flag.patch
- commit e7660e5
* Fri Aug 25 2023 tbogendoerfer@suse.de
- Update
  patches.kernel.org/6.4.12-140-xfrm-add-forgotten-nla_policy-for-XFRMA_MTIMER.patch
  (bsc#1012628 bsc#1213667 CVE-2023-3773).
  Added CVE reference.
- commit 250df45
* Fri Aug 25 2023 tbogendoerfer@suse.de
- Update
  patches.kernel.org/6.4.12-139-xfrm-add-NULL-check-in-xfrm_update_ae_params.patch
  (bsc#1012628 #1213666 CVE-2023-3772).
  Added CVE reference.
- commit 5b6ca7b
* Fri Aug 25 2023 tiwai@suse.de
- Add missing x86 fixes from SLE15-SP5 (bsc#1206578 bsc#1213287 CVE-2023-20569)
  Still disabled, to be reviewed
- commit a9a725a
* Fri Aug 25 2023 tiwai@suse.de
- ASoC: lower "no backend DAIs enabled for ... Port" log severity
  (git-fixes).
- ALSA: hda/cs8409: Support new Dell Dolphin Variants (git-fixes).
- arm64: xor-neon: mark xor_arm64_neon_*() static (git-fixes).
- commit 16c12e7
* Fri Aug 25 2023 tiwai@suse.de
- ALSA: hda/realtek: Switch Dell Oasis models to use SPI
  (git-fixes).
- commit 30e64ff
* Fri Aug 25 2023 tiwai@suse.de
- Documentation: devices.txt: reconcile serial/ucc_uart minor
  numers (git-fixes).
- Revert "debugfs, coccinelle: check for obsolete
  DEFINE_SIMPLE_ATTRIBUTE() usage" (git-fixes).
- cifs: add missing return value check for cifs_sb_tlink
  (bsc#1193629).
- ASoC: atmel: Fix the 8K sample parameter in I2SC master
  (git-fixes).
- ASoC: rt711-sdca: fix for JD event handling in ClockStop Mode0
  (git-fixes).
- ASoC: rt711: fix for JD event handling in ClockStop Mode0
  (git-fixes).
- ASoc: codecs: ES8316: Fix DMIC config (git-fixes).
- ASoC: rt5682-sdw: fix for JD event handling in ClockStop Mode0
  (git-fixes).
- ASoC: da7219: Check for failure reading AAD IRQ events
  (git-fixes).
- ASoC: da7219: Flush pending AAD IRQ when suspending (git-fixes).
- ALSA: usb-audio: Update for native DSD support quirks
  (git-fixes).
- cifs: update internal module version number for cifs.ko
  (bsc#1193629).
- cifs: allow dumping keys for directories too (bsc#1193629).
- ALSA: hda/realtek: Add support for DELL Oasis 13/14/16 laptops
  (git-fixes).
- Revert "iavf: Do not restart Tx queues after reset task failure"
  (git-fixes).
- Revert "iavf: Detach device during reset task" (git-fixes).
- rsi: remove kernel-doc comment marker (git-fixes).
- pie: fix kernel-doc notation warning (git-fixes).
- devlink: fix kernel-doc notation warnings (git-fixes).
- codel: fix kernel-doc notation warnings (git-fixes).
- cifs: is_network_name_deleted should return a bool
  (bsc#1193629).
- scsi: qla2xxx: Use vmalloc_array() and vcalloc() (bsc#1213747).
- scsi: qla2xxx: Silence a static checker warning (bsc#1213747).
- scsi: lpfc: Fix a possible data race in
  lpfc_unregister_fcf_rescan() (bsc#1213756).
- gve: unify driver name usage (git-fixes).
- smb: client: remove redundant pointer 'server' (bsc#1193629).
- cifs: fix session state transition to avoid use-after-free issue
  (bsc#1193629).
- scsi: lpfc: Fix lpfc_name struct packing (bsc#1213756).
- ALSA: hda/realtek: Whitespace fix (git-fixes).
- ALSA: fireface: make read-only const array for model names
  static (git-fixes).
- ALSA: oxfw: make read-only const array models static
  (git-fixes).
- Fix documentation of panic_on_warn (git-fixes).
- dt-bindings: phy: brcm,brcmstb-usb-phy: Fix error in
  "compatible" conditional schema (git-fixes).
- phy: Revert "phy: Remove SOC_EXYNOS4212 dep. from
  PHY_EXYNOS4X12_USB" (git-fixes).
- Documentation: ABI: sysfs-class-net-qmi: pass_through contact
  update (git-fixes).
- docs: networking: Update codeaurora references for rmnet
  (git-fixes).
- Bluetooth: hci_bcm: do not mark valid bd_addr as invalid
  (git-fixes).
- Bluetooth: fix use-bdaddr-property quirk (git-fixes).
- xfs: fix logdev fsmap query result filtering (git-fixes).
- xfs: clean up the rtbitmap fsmap backend (git-fixes).
- xfs: fix getfsmap reporting past the last rt extent (git-fixes).
- xfs: fix integer overflows in the fsmap rtbitmap and logdev
  backends (git-fixes).
- xfs: fix interval filtering in multi-step fsmap queries
  (git-fixes).
- xfs: don't reverse order of items in bulk AIL insertion
  (git-fixes).
- KVM: VMX: Inject #GP, not #UD, if SGX2 ENCLS leafs are
  unsupported (git-fixes).
- KVM: VMX: Inject #GP on ENCLS if vCPU has paging disabled
  (CR0.PG==0) (git-fixes).
- KVM: VMX: restore vmx_vmexit alignment (git-fixes).
- usb: xhci: Remove unused udev from xhci_log_ctx trace event
  (git-fixes).
- Revert "NFSv4: Retry LOCK on OLD_STATEID during delegation
  return" (git-fixes).
- cifs: new dynamic tracepoint to track ses not found errors
  (bsc#1193629).
- cifs: log session id when a matching ses is not found
  (bsc#1193629).
- cifs: print client_guid in DebugData (bsc#1193629).
- PCI: endpoint: Add missing documentation about the MSI/MSI-X
  range (git-fixes).
- scsi: qla2xxx: Update version to 10.02.08.400-k (bsc#1213747).
- scsi: qla2xxx: Drop useless LIST_HEAD (bsc#1213747).
- scsi: qla2xxx: Replace one-element array with
  DECLARE_FLEX_ARRAY() helper (bsc#1213747).
- scsi: lpfc: Avoid -Wstringop-overflow warning (bsc#1213756).
- scsi: lpfc: Use struct_size() helper (bsc#1213756).
- scsi: lpfc: Fix incorrect big endian type assignments in FDMI
  and VMID paths (bsc#1213756).
- lpfc: Copyright updates for 14.2.0.13 patches (bsc#1211852).
- lpfc: Update lpfc version to 14.2.0.13 (bsc#1211852).
- lpfc: Enhance congestion statistics collection (bsc#1211852).
- lpfc: Clean up SLI-4 CQE status handling (bsc#1211852).
- lpfc: Change firmware upgrade logging to KERN_NOTICE instead
  of TRACE_EVENT (bsc#1211852).
- lpfc: Account for fabric domain ctlr device loss recovery
  (bsc#1211346, bsc#1211852).
- lpfc: Clear NLP_IN_DEV_LOSS flag if already in rediscovery
  (bsc#1211852).
- lpfc: Fix use-after-free rport memory access in
  lpfc_register_remote_port (bsc#1211852, bsc#1208410,
  bsc#1211346).
- scsi: lpfc: Replace all non-returning strlcpy() with strscpy()
  (bsc#1213756).
- scsi: lpfc: Replace one-element array with flexible-array member
  (bsc#1213756).
- scsi: qla2xxx: Replace all non-returning strlcpy() with
  strscpy() (bsc#1211960).
- scsi: qla2xxx: Update version to 10.02.08.300-k (bsc#1211960).
- scsi: lpfc: Update lpfc version to 14.2.0.12 (bsc#1211847).
- scsi: lpfc: Replace blk_irq_poll intr handler with threaded IRQ
  (bsc#1211847).
- scsi: lpfc: Add new RCQE status for handling DMA failures
  (bsc#1211847).
- scsi: lpfc: Update congestion warning notification period
  (bsc#1211847).
- scsi: lpfc: Match lock ordering of lpfc_cmd->buf_lock and
  hbalock for abort paths (bsc#1211847).
- scsi: lpfc: Fix verbose logging for SCSI commands issued to
  SES devices (bsc#1211847).
- RDMA/vmw_pvrdma: Remove unnecessary check on wr->opcode
  (git-fixes).
- RDMA/rxe: Remove dangling declaration of rxe_cq_disable()
  (git-fixes).
- RDMA/bnxt_re: Remove unnecessary checks (git-fixes).
- RDMA/bnxt_re: Return directly without goto jumps (git-fixes).
- bus: fsl-mc: fsl-mc-allocator: Drop a write-only variable
  (git-fixes).
- soc: samsung: exynos-pmu: Re-introduce Exynos4212 support
  (git-fixes).
- Revert "arm64: dts: zynqmp: Add address-cells property to
  interrupt controllers" (git-fixes).
- drm/msm/adreno: fix sparse warnings in a6xx code (git-fixes).
- drm/msm/dpu: clean up dpu_kms_get_clk_rate() returns
  (git-fixes).
- drm/i915/gvt: remove unused variable gma_bottom in command
  parser (git-fixes).
- drm/amd/display: drop redundant memset() in
  get_available_dsc_slices() (git-fixes).
- Input: drv260x - remove unused .reg_defaults (git-fixes).
- Input: drv260x - fix typo in register value define (git-fixes).
- clk: samsung: Add Exynos4212 compatible to CLKOUT driver
  (git-fixes).
- can: kvaser_pciefd: Remove handler for unused
  KVASER_PCIEFD_PACK_TYPE_EFRAME_ACK (git-fixes).
- can: kvaser_pciefd: Remove useless write to interrupt register
  (git-fixes).
- can: length: fix description of the RRS field (git-fixes).
- net: mana: Add support for vlan tagging (bsc#1212301).
- can: length: make header self contained (git-fixes).
- Revert "mtd: rawnand: arasan: Prevent an unsupported
  configuration" (git-fixes).
- regulator: helper: Document ramp_delay parameter of
  regulator_set_ramp_delay_regmap() (git-fixes).
- elf: correct note name comment (git-fixes).
- cpufreq: amd-pstate: Set a fallback policy based on
  preferred_profile (bsc#1212445).
- ACPI: CPPC: Add definition for undefined FADT preferred PM
  profile value (bsc#1212445).
- cpufreq: amd-pstate: Write CPPC enable bit per-socket
  (bsc#1212445).
- x86/build: Avoid relocation information in final vmlinux
  (bsc#1187829).
- irqchip/clps711x: Remove unused clps711x_intc_init() function
  (git-fixes).
- irqchip/ftintc010: Mark all function static (git-fixes).
- commit 2da661e
* Fri Aug 25 2023 wqu@suse.com
- Delete
  patches.suse/btrfs-relocation-Work-around-dead-relocation-stage-l.patch.
- commit 4b9fcd4
* Thu Aug 24 2023 msuchanek@suse.de
- Update ppc64 config
  - CONFIG_COMPAT_32BIT_TIME=n
  - CONFIG_IMA_ARCH_POLICY=y
  - CONFIG_IMA_DISABLE_HTABLE=y
  - CONFIG_IMA_KEXEC=y
  - CONFIG_IMA_KEYRINGS_PERMIT_SIGNED_BY_BUILTIN_OR_SECONDARY=y
  - CONFIG_LOAD_PPC_KEYS=y
  - CONFIG_PPC_SECURE_BOOT=y
  - CONFIG_PPC_SECVAR_SYSFS=y
- commit cf6570f
* Thu Aug 24 2023 ailiop@suse.com
- Refresh
  patches.suse/xfs-repair-malformed-inode-items-during-log-recovery.patch.
- commit f3dc77b
* Thu Aug 24 2023 ailiop@suse.com
- xfs: fix bounds check in xfs_defer_agfl_block() (git-fixes).
- commit 49dca73
* Thu Aug 24 2023 ailiop@suse.com
- xfs: AGF length has never been bounds checked (git-fixes).
- commit 97239d8
* Thu Aug 24 2023 ailiop@suse.com
- xfs: don't block in busy flushing when freeing extents
  (git-fixes).
- commit 825f791
* Thu Aug 24 2023 ailiop@suse.com
- xfs: pass alloc flags through to xfs_extent_busy_flush()
  (git-fixes).
- commit 62eef81
* Thu Aug 24 2023 ailiop@suse.com
- xfs: use deferred frees for btree block freeing (git-fixes).
- commit e83db44
* Thu Aug 24 2023 lduncan@suse.com
- Delete
  patches.suse/uapi-add-a-compatibility-layer-between-linux-uio-h-and-glibc.
  This patch no longer needed, and never made it upstream.
- commit da31059
* Thu Aug 24 2023 ailiop@suse.com
- xfs: don't deplete the reserve pool when trying to shrink the fs
  (git-fixes).
- commit c817b91
* Thu Aug 24 2023 clin@suse.com
- Refresh
  patches.suse/s390-lock-down-kernel-in-secure-boot-mode.patch.
- commit b29f3d3
* Thu Aug 24 2023 clin@suse.com
- Delete patches.suse/arm64-dts-s32g2-add-USDHC-support.patch.
- commit 68a6036
* Thu Aug 24 2023 oneukum@suse.com
- Refresh patches.suse/0001-kABI-more-hooks-for-PCI-changes.patch.
  Reenabled kABI placeholders in PCI for SP6
- commit a538cc2
* Thu Aug 24 2023 jack@suse.cz
- Enable support for "unsupported filesystem features".
- commit 979adc3
* Thu Aug 24 2023 oneukum@suse.com
- Refresh
  patches.suse/0002-Add-a-void-suse_kabi_padding-placeholder-to-some-USB.patch.
- Refresh patches.suse/paddings-add-for-type-C-new-in-SP5.patch.
- Refresh
  patches.suse/paddings-for-TB-and-USB4-XDomain-structures.patch.
- Refresh patches.suse/paddings-for-gadgets.patch.
- Refresh
  patches.suse/paddings-for-the-inter-DMN-tunnel-stuff-of-TB.patch.
  Reenabling kABI placeholders for SP6 in USB and TB
- commit 64c5e3b
* Thu Aug 24 2023 mgorman@suse.de
- mm/slab: correct return values in comment for
  _kmem_cache_create() (bsc#1212886 (MM functional and performance
  backports)).
- bpf: Remove in_atomic() from bpf_link_put() (bsc#1213179
  (PREEMPT_RT functional and performance backports)).
- module: Remove preempt_disable() from module reference counting
  (bsc#1213179 (PREEMPT_RT functional and performance backports)).
- mm: page_alloc: use the correct type of list for free pages
  (bsc#1212886 (MM functional and performance backports)).
- mm: fix shmem THP counters on migration (bsc#1212886 (MM
  functional and performance backports)).
- mm: compaction: skip memory hole rapidly when isolating
  migratable pages (bsc#1212886 (MM functional and performance
  backports)).
- percpu-internal/pcpu_chunk: re-layout pcpu_chunk structure
  to reduce false sharing (bsc#1212886 (MM functional and
  performance backports)).
- mm: compaction: mark kcompactd_run() and kcompactd_stop()
  __meminit (bsc#1212886 (MM functional and performance
  backports)).
- mm/vmalloc: replace the ternary conditional operator with min()
  (bsc#1212886 (MM functional and performance backports)).
- vmstat: skip periodic vmstat update for isolated CPUs
  (bsc#1212886 (MM functional and performance backports)).
- mm/mm_init.c: drop 'nid' parameter from check_for_memory()
  (bsc#1212886 (MM functional and performance backports)).
- mm/hugetlb: use a folio in hugetlb_fault() (bsc#1212886 (MM
  functional and performance backports)).
- mm/hugetlb: use a folio in hugetlb_wp() (bsc#1212886 (MM
  functional and performance backports)).
- mm/hugetlb: use a folio in copy_hugetlb_page_range()
  (bsc#1212886 (MM functional and performance backports)).
- mm: vmscan: mark kswapd_run() and kswapd_stop() __meminit
  (bsc#1212886 (MM functional and performance backports)).
- mm: skip CMA pages when they are not available (bsc#1212886
  (MM functional and performance backports)).
- mm: page_isolation: write proper kerneldoc (bsc#1212886 (MM
  functional and performance backports)).
- mm: fix failure to unmap pte on highmem systems (bsc#1212886
  (MM functional and performance backports)).
- mm/damon/ops-common: refactor to use
  {pte|pmd}p_clear_young_notify() (bsc#1212886 (MM functional
  and performance backports)).
- mm: vmalloc must set pte via arch code (bsc#1212886 (MM
  functional and performance backports)).
- vmstat: allow_direct_reclaim should use zone_page_state_snapshot
  (bsc#1212886 (MM functional and performance backports)).
- mm: zswap: shrink until can accept (bsc#1212886 (MM functional
  and performance backports)).
- mm/mm_init.c: move set_pageblock_order() to free_area_init()
  (bsc#1212886 (MM functional and performance backports)).
- mm: khugepaged: avoid pointless allocation for "struct mm_slot"
  (bsc#1212886 (MM functional and performance backports)).
- mm/page_alloc: don't wake kswapd from rmqueue() unless
  __GFP_KSWAPD_RECLAIM is specified (bsc#1212886 (MM functional
  and performance backports)).
- mm/mm_init.c: remove free_area_init_memoryless_node()
  (bsc#1212886 (MM functional and performance backports)).
- THP: avoid lock when check whether THP is in deferred list
  (bsc#1212886 (MM functional and performance backports)).
- mm/mm_init.c: do not calculate zone_start_pfn/zone_end_pfn in
  zone_absent_pages_in_node() (bsc#1212886 (MM functional and
  performance backports)).
- mm/mm_init.c: introduce reset_memoryless_node_totalpages()
  (bsc#1212886 (MM functional and performance backports)).
- mm: shmem: fix UAF bug in shmem_show_options() (bsc#1212886
  (MM functional and performance backports)).
- mm: compaction: skip fast freepages isolation if enough
  freepages are isolated (bsc#1212886 (MM functional and
  performance backports)).
- mm: compaction: add trace event for fast freepages isolation
  (bsc#1212886 (MM functional and performance backports)).
- mm: compaction: only set skip flag if cc->no_set_skip_hint is
  false (bsc#1212886 (MM functional and performance backports)).
- mm: compaction: skip more fully scanned pageblock (bsc#1212886
  (MM functional and performance backports)).
- mm: compaction: change fast_isolate_freepages() to void type
  (bsc#1212886 (MM functional and performance backports)).
- mm: compaction: drop the redundant page validation in
  update_pageblock_skip() (bsc#1212886 (MM functional and
  performance backports)).
- mm/vmalloc: dont purge usable blocks unnecessarily (bsc#1212886
  (MM functional and performance backports)).
- mm/vmalloc: add missing READ/WRITE_ONCE() annotations
  (bsc#1212886 (MM functional and performance backports)).
- mm/vmalloc: check free space in vmap_block lockless (bsc#1212886
  (MM functional and performance backports)).
- mm/vmalloc: prevent flushing dirty space over and over
  (bsc#1212886 (MM functional and performance backports)).
- mm/vmalloc: avoid iterating over per CPU vmap blocks twice
  (bsc#1212886 (MM functional and performance backports)).
- mm/vmalloc: prevent stale TLBs in fully utilized blocks
  (bsc#1212886 (MM functional and performance backports)).
- mm/memcontrol: fix typo in comment (bsc#1212886 (MM functional
  and performance backports)).
- mm/mlock: rename mlock_future_check() to mlock_future_ok()
  (bsc#1212886 (MM functional and performance backports)).
- mm/mmap: refactor mlock_future_check() (bsc#1212886 (MM
  functional and performance backports)).
- mm: compaction: avoid GFP_NOFS ABBA deadlock (bsc#1212886
  (MM functional and performance backports)).
- mm: compaction: have compaction_suitable() return bool
  (bsc#1212886 (MM functional and performance backports)).
- mm: compaction: drop redundant watermark check in
  compaction_zonelist_suitable() (bsc#1212886 (MM functional
  and performance backports)).
- mm: compaction: remove unnecessary is_via_compact_memory()
  checks (bsc#1212886 (MM functional and performance backports)).
- mm: compaction: refactor __compaction_suitable() (bsc#1212886
  (MM functional and performance backports)).
- mm: compaction: simplify should_compact_retry() (bsc#1212886
  (MM functional and performance backports)).
- mm: compaction: remove compaction result helpers (bsc#1212886
  (MM functional and performance backports)).
- mm: page_alloc: set sysctl_lowmem_reserve_ratio
  storage-class-specifier to static (bsc#1212886 (MM functional
  and performance backports)).
- mm: convert migrate_pages() to work on folios (bsc#1212886
  (MM functional and performance backports)).
- mm: page_alloc: move sysctls into it own fils (bsc#1212886
  (MM functional and performance backports)).
- mm: page_alloc: move pm_* function into power (bsc#1212886
  (MM functional and performance backports)).
- mm: page_alloc: move mark_free_page() into snapshot.c
  (bsc#1212886 (MM functional and performance backports)).
- mm: page_alloc: split out DEBUG_PAGEALLOC (bsc#1212886 (MM
  functional and performance backports)).
- mm: page_alloc: split out FAIL_PAGE_ALLOC (bsc#1212886 (MM
  functional and performance backports)).
- mm: page_alloc: remove alloc_contig_dump_pages() stub
  (bsc#1212886 (MM functional and performance backports)).
- mm: page_alloc: squash page_is_consistent() (bsc#1212886
  (MM functional and performance backports)).
- mm: page_alloc: collect mem statistic into show_mem.c
  (bsc#1212886 (MM functional and performance backports)).
- mm: page_alloc: move set_zone_contiguous() into mm_init.c
  (bsc#1212886 (MM functional and performance backports)).
- mm: page_alloc: move init_on_alloc/free() into mm_init.c
  (bsc#1212886 (MM functional and performance backports)).
- mm: page_alloc: move mirrored_kernelcore into mm_init.c
  (bsc#1212886 (MM functional and performance backports)).
- Revert "Revert "mm/compaction: fix set skip in
  fast_find_migrateblock"" (bsc#1212886 (MM functional and
  performance backports)).
- mm: compaction: update pageblock skip when first migration
  candidate is not at the start (bsc#1212886 (MM functional and
  performance backports)).
- mm: compaction: only force pageblock scan completion when skip
  hints are obeyed (bsc#1212886 (MM functional and performance
  backports)).
- mm: compaction: ensure rescanning only happens on partially
  scanned pageblocks (bsc#1212886 (MM functional and performance
  backports)).
- mm, oom: do not check 0 mask in out_of_memory() (bsc#1212886
  (MM functional and performance backports)).
- mm: memory-failure: move sysctl register in
  memory_failure_init() (bsc#1212886 (MM functional and
  performance backports)).
- mm: hugetlb_vmemmap: provide stronger vmemmap allocation
  guarantees (bsc#1212886 (MM functional and performance
  backports)).
- migrate_pages_batch: simplify retrying and failure counting
  of large folios (bsc#1212886 (MM functional and performance
  backports)).
- mm/gup: add missing gup_must_unshare() check to gup_huge_pgd()
  (bsc#1212886 (MM functional and performance backports)).
- fs: hugetlbfs: set vma policy only when needed for allocating
  folio (bsc#1212886 (MM functional and performance backports)).
- memcg, oom: remove explicit wakeup in
  mem_cgroup_oom_synchronize() (bsc#1212886 (MM functional and
  performance backports)).
- memcg, oom: remove unnecessary check in
  mem_cgroup_oom_synchronize() (bsc#1212886 (MM functional and
  performance backports)).
- memcg: remove mem_cgroup_flush_stats_atomic() (bsc#1212886
  (MM functional and performance backports)).
- memcg: calculate root usage from global state (bsc#1212886
  (MM functional and performance backports)).
- memcg: flush stats non-atomically in mem_cgroup_wb_stats()
  (bsc#1212886 (MM functional and performance backports)).
- writeback: move wb_over_bg_thresh() call outside lock section
  (bsc#1212886 (MM functional and performance backports)).
- mm/page_alloc: drop the unnecessary pfn_valid() for start pfn
  (bsc#1212886 (MM functional and performance backports)).
- mm: compaction: optimize compact_memory to comply with the
  admin-guide (bsc#1212886 (MM functional and performance
  backports)).
- migrate_pages: avoid blocking for IO in MIGRATE_SYNC_LIGHT
  (bsc#1212886 (MM functional and performance backports)).
- mm: memcg: use READ_ONCE()/WRITE_ONCE() to access stock->cached
  (bsc#1212886 (MM functional and performance backports)).
- cgroup/cpuset: Free DL BW in case can_attach() fails
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/deadline: Create DL BW alloc, free & check overflow
  interface (bsc#1212887 (Scheduler functional and performance
  backports)).
- sched/cpuset: Keep track of SCHED_DEADLINE task in cpusets
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/cpuset: Bring back cpuset_mutex (bsc#1212887 (Scheduler
  functional and performance backports)).
- Further upgrade queue_work_on() comment (bsc#1212887 (Scheduler
  functional and performance backports)).
- sched/core: Avoid double calling update_rq_clock() in
  __balance_push_cpu_stop() (bsc#1212887 (Scheduler functional
  and performance backports)).
- sched/core: Fixed missing rq clock update before calling
  set_rq_offline() (bsc#1212887 (Scheduler functional and
  performance backports)).
- sched/deadline: Fix bandwidth reclaim equation in GRUB
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/wait: Fix a kthread_park race with wait_woken()
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/topology: Mark set_sched_topology() __init (bsc#1212887
  (Scheduler functional and performance backports)).
- sched/fair: Rename variable cpu_util eff_util (bsc#1212887
  (Scheduler functional and performance backports)).
- sched/fair, cpufreq: Introduce 'runnable boosting' (bsc#1212887
  (Scheduler functional and performance backports)).
- sched/fair: Refactor CPU utilization functions (bsc#1212887
  (Scheduler functional and performance backports)).
- sched: Consider task_struct::saved_state in wait_task_inactive()
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched: Unconditionally use full-fat wait_task_inactive()
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/deadline: remove unused dl_bandwidth (bsc#1212887
  (Scheduler functional and performance backports)).
- sched/fair: Move unused stub functions to header (bsc#1212887
  (Scheduler functional and performance backports)).
- sched: Make task_vruntime_update() prototype visible
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/fair: Hide unused init_cfs_bandwidth() stub (bsc#1212887
  (Scheduler functional and performance backports)).
- sched: Add schedule_user() declaration (bsc#1212887 (Scheduler
  functional and performance backports)).
- sched: Hide unused sched_update_scaling() (bsc#1212887
  (Scheduler functional and performance backports)).
- sched/psi: Avoid resetting the min update period when it is
  unnecessary (bsc#1212887 (Scheduler functional and performance
  backports)).
- sched/debug: Correct printing for rq->nr_uninterruptible
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/topology: Propagate SMT flags when removing degenerate
  domain (bsc#1212887 (Scheduler functional and performance
  backports)).
- psi: remove 500ms min window size limitation for triggers
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/topology: Check SDF_SHARED_CHILD in highest_flag_domain()
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/fair: Do not even the number of busy CPUs via asym_packing
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/fair: Use the busiest group to set prefer_sibling
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/fair: Keep a fully_busy SMT sched group as busiest
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/fair: Let low-priority cores help high-priority busy
  SMT cores (bsc#1212887 (Scheduler functional and performance
  backports)).
- sched/fair: Simplify asym_packing logic for SMT cores
  (bsc#1212887 (Scheduler functional and performance backports)).
- sched/fair: Only do asym_packing load balancing from fully idle
  SMT cores (bsc#1212887 (Scheduler functional and performance
  backports)).
- sched/fair: Move is_core_idle() out of CONFIG_NUMA (bsc#1212887
  (Scheduler functional and performance backports)).
- x86/mm: Add early_memremap_pgprot_adjust() prototype
  (bsc#1212886 (MM functional and performance backports)).
- commit 8861ce3
* Thu Aug 24 2023 mgorman@suse.de
- series.conf: Add note on the removal of deleted sysctls
- commit ea1551b
* Thu Aug 24 2023 mgorman@suse.de
- series.conf: Add note on initial placement during fork, evaluation required
- commit d423863
* Thu Aug 24 2023 mgorman@suse.de
- series.conf: Add note on wakeup_gran boosting, evaluation required
- commit 81b5987
* Thu Aug 24 2023 mgorman@suse.de
- Delete
  patches.suse/sched-optimize-latency-defaults-for-throughput.patch.
- commit f4acb00
* Thu Aug 24 2023 mgorman@suse.de
- Delete
  patches.suse/sched-Disable-sched-domain-debugfs-creation-on-ppc64-unless-sched_verbose-is-specified.patch.
  Upstream has an alternative fix.
- commit 02d9709
* Thu Aug 24 2023 mgorman@suse.de
- series.conf: Add note on frequency boosting for IO, evaluation required
- commit 0acf9ba
* Thu Aug 24 2023 mgorman@suse.de
- series.conf: Add note on up_threshold, evaluation required
- commit 9ec5dac
* Thu Aug 24 2023 mgorman@suse.de
- Delete
  patches.suse/rtmutex-Add-acquire-semantics-for-rtmutex-lock-acquisition-slow-path.patch.
- commit 32566f1
* Thu Aug 24 2023 mgorman@suse.de
- Delete
  patches.suse/mm-page_alloc-skip-regions-with-hugetlbfs-pages-when-allocating-1G-pages.patch.
- commit bf2a4f1
* Thu Aug 24 2023 mgorman@suse.de
- Delete
  patches.suse/locking-rwbase-Mitigate-indefinite-writer-starvation.patch.
  Upstream alternative already included.
- commit a1fa32f
* Thu Aug 24 2023 mgorman@suse.de
- Delete
  patches.suse/intel_idle-Disable-ACPI-_CST-on-Haswell.patch.
  Affected generation of chips is no longer supported by the manufacturer.
- commit f939ab4
* Thu Aug 24 2023 mgorman@suse.de
- Delete
  patches.suse/cpufreq-intel_pstate-Allow-unspecified-FADT-profile-to-probe-PPC.patch.
  Problem has stopped showing up in practice.
- commit d374a9a
* Thu Aug 24 2023 dwagner@suse.de
- series: review/update patches for sle15sp6
- Refresh
  patches.suse/blk-kabi-add-suse_kabi_padding-to-blk-layer-structs.patch.
- Delete
  patches.suse/nvme-multipath-skip-not-ready-namespaces-when-revalidating.patch.
- commit 900c330
* Thu Aug 24 2023 pjakobsson@suse.de
- Refresh
  patches.suse/drm-Add-kabi-placeholders-to-commonly-used-structs.patch.
- commit bd2986f
* Thu Aug 24 2023 tiwai@suse.de
- wifi: rtw88: usb: kill and free rx urbs on probe failure
  (bsc#1214385).
- commit 28f1b80
* Thu Aug 24 2023 colyli@suse.de
- Refresh patches.suse/nvdimm-disable-namespace-on-error.patch.
- commit 0109f83
* Thu Aug 24 2023 colyli@suse.de
- Delete the patch which is already in kernel code base,
  patches.suse/Avoid-deadlock-for-recursive-I-O-on-dm-thin-when-used-as-swap-4905.patch.
- commit 8ae388a
* Thu Aug 24 2023 shung-hsi.yu@suse.com
- Delete patches.suse/make-module-BTF-toggleable.patch.
  No longer required with upstream commit 5e214f2e43e4 "bpf: Add config to
  allow loading modules with BTF mismatches" and
  MODULE_ALLOW_BTF_MISMATCH=y.
- commit fcf9c21
* Thu Aug 24 2023 shung-hsi.yu@suse.com
- Re-enable BPF kABI padding
  Refresh the patch and additionally add padding for struct bpf_prog_aux
  and struct bpf_verifier_env.
- commit 50ddc33
* Thu Aug 24 2023 shung-hsi.yu@suse.com
- Delete
  patches.suse/kbuild-Add-skip_encoding_btf_enum64-option-to-pahole.patch.
  No longer required since the base kernel is 6.4 and BTF_KIND_ENUM64
  support is added in 6.0.
- commit c3cc153
* Thu Aug 24 2023 shung-hsi.yu@suse.com
- Re-enable BPF selftest modification
  This is required because we carry the following downstream patches:
- patches.suse/vfs-add-super_operations-get_inode_dev
- patches.suse/btrfs-provide-super_operations-get_inode_dev
  Also refresh the patch while at it.
- commit 67df713
* Thu Aug 24 2023 tiwai@suse.de
- ASoC: amd: vangogh: select CONFIG_SND_AMD_ACP_CONFIG
  (git-fixes).
- commit 045f0e1
* Thu Aug 24 2023 tiwai@suse.de
- Linux 6.4.12 (bsc#1012628).
- net: fix the RTO timer retransmitting skb every 1ms if linear
  option is enabled (bsc#1012628).
- af_unix: Fix null-ptr-deref in unix_stream_sendpage()
  (bsc#1012628).
- ASoC: SOF: intel: hda: Clean up link DMA for IPC3 during stop
  (bsc#1012628 bsc#1213583).
  Renamed the existing patch to 6.4.12 stable, too.
- Revert "perf report: Append inlines to non-DWARF callchains"
  (bsc#1012628).
- drm/amdgpu: keep irq count in amdgpu_irq_disable_all
  (bsc#1012628).
- drm/amd/pm: skip the RLC stop when S0i3 suspend for SMU
  v13.0.4/11 (bsc#1012628).
- drm/amd/display: disable RCO for DCN314 (bsc#1012628).
- ASoC: amd: vangogh: select CONFIG_SND_AMD_ACP_CONFIG
  (bsc#1012628).
- drm/amdgpu/pm: fix throttle_status for other than MP1 11.0.7
  (bsc#1012628).
- drm/amdgpu: skip fence GFX interrupts disable/enable for S0ix
  (bsc#1012628).
- drm/amd: flush any delayed gfxoff on suspend entry
  (bsc#1012628).
- drm/i915/sdvo: fix panel_type initialization (bsc#1012628).
- Revert "Revert "drm/amdgpu/display: change pipe policy for
  DCN 2.0"" (bsc#1012628).
- Revert "drm/edid: Fix csync detailed mode parsing" (bsc#1012628
  bsc#1213693).
  Renamed the existing patch to 6.4.12 stable, too
- drm/qxl: fix UAF on handle creation (bsc#1012628).
- mmc: sunplus: Fix error handling in spmmc_drv_probe()
  (bsc#1012628).
- mmc: sunplus: fix return value check of mmc_add_host()
  (bsc#1012628).
- mmc: block: Fix in_flight[issue_type] value error (bsc#1012628).
- mmc: wbsd: fix double mmc_free_host() in wbsd_init()
  (bsc#1012628).
- mmc: f-sdh30: fix order of function calls in
  sdhci_f_sdh30_remove (bsc#1012628).
- dt-bindings: pinctrl: qcom,sa8775p-tlmm: add gpio function
  constant (bsc#1012628).
- media: uvcvideo: Fix menu count handling for userspace XU
  mappings (bsc#1012628).
- blk-crypto: dynamically allocate fallback profile (bsc#1012628).
- arm64/ptrace: Ensure that the task sees ZT writes on first use
  (bsc#1012628).
- arm64/ptrace: Ensure that SME is set up for target when writing
  SSVE state (bsc#1012628).
- arm64: dts: rockchip: Fix Wifi/Bluetooth on ROCK Pi 4 boards
  (bsc#1012628).
- virtio-net: Zero max_tx_vq field for
  VIRTIO_NET_CTRL_MQ_HASH_CONFIG case (bsc#1012628).
- regulator: da9063: better fix null deref with partial DT
  (bsc#1012628).
- smb: client: fix null auth (bsc#1012628).
- parisc: Fix CONFIG_TLB_PTLOCK to work with lightweight spinlock
  checks (bsc#1012628).
- cifs: Release folio lock on fscache read hit (bsc#1012628).
- ALSA: usb-audio: Add support for Mythware XA001AU capture and
  playback interfaces (bsc#1012628).
- serial: 8250: Fix oops for port->pm on uart_change_pm()
  (bsc#1012628).
- riscv: uaccess: Return the number of bytes effectively not
  copied (bsc#1012628).
- riscv: correct riscv_insn_is_c_jr() and riscv_insn_is_c_jalr()
  (bsc#1012628).
- riscv: entry: set a0 = -ENOSYS only when syscall != -1
  (bsc#1012628).
- ALSA: hda/realtek - Remodified 3k pull low procedure
  (bsc#1012628).
- soc: aspeed: socinfo: Add kfree for kstrdup (bsc#1012628).
- soc: aspeed: uart-routing: Use __sysfs_match_string
  (bsc#1012628).
- pinctrl: qcom: Add intr_target_width field to support increased
  number of interrupt targets (bsc#1012628).
- ALSA: hda/realtek: Add quirks for HP G11 Laptops (bsc#1012628).
- ASoC: meson: axg-tdm-formatter: fix channel slot allocation
  (bsc#1012628).
- ASoC: rt5665: add missed regulator_bulk_disable (bsc#1012628).
- arm64: dts: imx93: Fix anatop node size (bsc#1012628).
- ASoC: max98363: don't return on success reading revision ID
  (bsc#1012628).
- ARM: dts: imx: Set default tuning step for imx6sx usdhc
  (bsc#1012628).
- arm64: dts: imx8mm: Drop CSI1 PHY reference clock configuration
  (bsc#1012628).
- ARM: dts: imx: Set default tuning step for imx7d usdhc
  (bsc#1012628).
- ARM: dts: imx: Adjust dma-apbh node name (bsc#1012628).
- ARM: dts: imx6: phytec: fix RTC interrupt level (bsc#1012628).
- arm64: dts: rockchip: Disable HS400 for eMMC on ROCK 4C+
  (bsc#1012628).
- arm64: dts: rockchip: Disable HS400 for eMMC on ROCK Pi 4
  (bsc#1012628).
- arm64: dts: qcom: qrb5165-rb5: fix thermal zone conflict
  (bsc#1012628).
- bus: ti-sysc: Flush posted write on enable before reset
  (bsc#1012628).
- ice: Block switchdev mode when ADQ is active and vice versa
  (bsc#1012628).
- qede: fix firmware halt over suspend and resume (bsc#1012628).
- net: do not allow gso_size to be set to GSO_BY_FRAGS
  (bsc#1012628).
- sock: Fix misuse of sk_under_memory_pressure() (bsc#1012628).
- sfc: don't fail probe if MAE/TC setup fails (bsc#1012628).
- sfc: don't unregister flow_indr if it was never registered
  (bsc#1012628).
- sfc: add fallback action-set-lists for TC offload (bsc#1012628).
- net: dsa: mv88e6xxx: Wait for EEPROM done before HW reset
  (bsc#1012628).
- drm/nouveau/disp: fix use-after-free in error handling of
  nouveau_connector_create (bsc#1012628 bsc#1214073).
  Renamed the existing patch to 6.4.12 stable, too.
- net/mlx5e: XDP, Fix fifo overrun on XDP_REDIRECT (bsc#1012628).
- i40e: fix misleading debug logs (bsc#1012628).
- iavf: fix FDIR rule fields masks validation (bsc#1012628).
- net: openvswitch: reject negative ifindex (bsc#1012628).
- team: Fix incorrect deletion of ETH_P_8021AD protocol vid from
  slaves (bsc#1012628).
- net: phy: broadcom: stub c45 read/write for 54810 (bsc#1012628).
- netfilter: nft_dynset: disallow object maps (bsc#1012628).
- netfilter: nf_tables: GC transaction race with netns dismantle
  (bsc#1012628).
- netfilter: nf_tables: fix GC transaction races with netns and
  netlink event exit path (bsc#1012628).
- ipvs: fix racy memcpy in proc_do_sync_threshold (bsc#1012628).
- netfilter: set default timeout to 3 secs for sctp shutdown
  send and recv state (bsc#1012628).
- netfilter: nf_tables: don't fail inserts if duplicate has
  expired (bsc#1012628).
- netfilter: nf_tables: deactivate catchall elements in next
  generation (bsc#1012628).
- netfilter: nf_tables: fix false-positive lockdep splat
  (bsc#1012628).
- accel/qaic: Clean up integer overflow checking in
  map_user_pages() (bsc#1012628).
- accel/qaic: Fix slicing memory leak (bsc#1012628).
- net: veth: Page pool creation error handling for existing
  pools only (bsc#1012628).
- octeon_ep: cancel queued works in probe error path
  (bsc#1012628).
- octeon_ep: cancel ctrl_mbox_task after intr_poll_task
  (bsc#1012628).
- octeon_ep: cancel tx_timeout_task later in remove sequence
  (bsc#1012628).
- octeon_ep: fix timeout value for waiting on mbox response
  (bsc#1012628).
- net: macb: In ZynqMP resume always configure PS GTR for
  non-wakeup source (bsc#1012628).
- drm/i915/guc/slpc: Restore efficient freq earlier (bsc#1012628).
- drm/panel: simple: Fix AUO G121EAN01 panel timings according
  to the docs (bsc#1012628).
- selftests: mirror_gre_changes: Tighten up the TTL test match
  (bsc#1012628).
- net: phy: fix IRQ-based wake-on-lan over hibernate / power off
  (bsc#1012628).
- net: pcs: Add missing put_device call in miic_create
  (bsc#1012628).
- virtio-net: set queues after driver_ok (bsc#1012628).
- xfrm: don't skip free of empty state in acquire policy
  (bsc#1012628).
- xfrm: delete offloaded policy (bsc#1012628).
- xfrm: add forgotten nla_policy for XFRMA_MTIMER_THRESH
  (bsc#1012628).
- xfrm: add NULL check in xfrm_update_ae_params (bsc#1012628).
- ip_vti: fix potential slab-use-after-free in decode_session6
  (bsc#1012628).
- ip6_vti: fix slab-use-after-free in decode_session6
  (bsc#1012628).
- xfrm: fix slab-use-after-free in decode_session6 (bsc#1012628).
- xfrm: Silence warnings triggerable by bad packets (bsc#1012628).
- net: xfrm: Amend XFRMA_SEC_CTX nla_policy structure
  (bsc#1012628).
- net: af_key: fix sadb_x_filter validation (bsc#1012628).
- net: xfrm: Fix xfrm_address_filter OOB read (bsc#1012628).
- x86/srso: Correct the mitigation status when SMT is disabled
  (bsc#1012628).
- x86/retpoline,kprobes: Skip optprobe check for indirect jumps
  with retpolines and IBT (bsc#1012628).
- x86/retpoline,kprobes: Fix position of thunk sections with
  CONFIG_LTO_CLANG (bsc#1012628).
- x86/srso: Disable the mitigation on unaffected configurations
  (bsc#1012628).
- x86/CPU/AMD: Fix the DIV(0) initial fix attempt (bsc#1012628).
- x86/retpoline: Don't clobber RFLAGS during srso_safe_ret()
  (bsc#1012628).
- x86/static_call: Fix __static_call_fixup() (bsc#1012628).
- objtool/x86: Fixup frame-pointer vs rethunk (bsc#1012628).
- x86/srso: Explain the untraining sequences a bit more
  (bsc#1012628).
- x86/cpu/kvm: Provide UNTRAIN_RET_VM (bsc#1012628).
- x86/cpu: Cleanup the untrain mess (bsc#1012628).
- x86/cpu: Rename srso_(.*)_alias to srso_alias_\1 (bsc#1012628).
- x86/cpu: Rename original retbleed methods (bsc#1012628).
- x86/cpu: Clean up SRSO return thunk mess (bsc#1012628).
- x86/alternative: Make custom return thunk unconditional
  (bsc#1012628).
- objtool/x86: Fix SRSO mess (bsc#1012628).
- x86/cpu: Fix up srso_safe_ret() and __x86_return_thunk()
  (bsc#1012628).
- x86/cpu: Fix __x86_return_thunk symbol type (bsc#1012628).
- i2c: designware: Handle invalid SMBus block data response
  length value (bsc#1012628).
- i2c: designware: Correct length byte validation logic
  (bsc#1012628).
- btrfs: only subtract from len_to_oe_boundary when it is tracking
  an extent (bsc#1012628).
- btrfs: fix replace/scrub failure with metadata_uuid
  (bsc#1012628).
- btrfs: fix BUG_ON condition in btrfs_cancel_balance
  (bsc#1012628).
- btrfs: fix incorrect splitting in btrfs_drop_extent_map_range
  (bsc#1012628).
- btrfs: fix infinite directory reads (bsc#1012628).
- tty: serial: fsl_lpuart: Clear the error flags by writing 1
  for lpuart32 platforms (bsc#1012628).
- tty: n_gsm: fix the UAF caused by race condition in
  gsm_cleanup_mux (bsc#1012628).
- smb3: display network namespace in debug information
  (bsc#1012628).
- vdpa: Enable strict validation for netlinks ops (bsc#1012628).
- vdpa: Add max vqp attr to vdpa_nl_policy for nlattr length check
  (bsc#1012628).
- vdpa: Add queue index attr to vdpa_nl_policy for nlattr length
  check (bsc#1012628).
- vdpa: Add features attr to vdpa_nl_policy for nlattr length
  check (bsc#1012628).
- powerpc/rtas_flash: allow user copy to flash block cache objects
  (bsc#1012628 bsc#1194869).
  Renamed the existing patch to 6.4.12 stable, too
- media: mtk-jpeg: Set platform driver data earlier (bsc#1012628).
- fbdev: mmp: fix value check in mmphw_probe() (bsc#1012628).
- blk-cgroup: hold queue_lock when removing blkg->q_node
  (bsc#1012628).
- i2c: tegra: Fix i2c-tegra DMA config option processing
  (bsc#1012628).
- i2c: hisi: Only handle the interrupt of the driver's transfer
  (bsc#1012628).
- i2c: bcm-iproc: Fix bcm_iproc_i2c_isr deadlock issue
  (bsc#1012628).
- rust: macros: vtable: fix `HAS_*` redefinition
  (`gen_const_name`) (bsc#1012628).
- cifs: fix potential oops in cifs_oplock_break (bsc#1012628).
- vdpa/mlx5: Delete control vq iotlb in destroy_mr only when
  necessary (bsc#1012628).
- vdpa/mlx5: Fix mr->initialized semantics (bsc#1012628).
- virtio-vdpa: Fix cpumask memory leak in virtio_vdpa_find_vqs()
  (bsc#1012628).
- vduse: Use proper spinlock for IRQ injection (bsc#1012628).
- virtio-mmio: don't break lifecycle of vm_dev (bsc#1012628).
- regulator: qcom-rpmh: Fix LDO 12 regulator for PM8550
  (bsc#1012628).
- btrfs: fix use-after-free of new block group that became unused
  (bsc#1012628).
- btrfs: move out now unused BG from the reclaim list
  (bsc#1012628).
- ring-buffer: Do not swap cpu_buffer during resize process
  (bsc#1012628).
- Bluetooth: MGMT: Use correct address for memcpy() (bsc#1012628).
- powerpc/kasan: Disable KCOV in KASAN code (bsc#1012628).
- ALSA: hda/realtek: Add quirk for ASUS ROG GZ301V (bsc#1012628).
- ALSA: hda/realtek: Add quirk for ASUS ROG G614Jx (bsc#1012628).
- ALSA: hda/realtek: Amend G634 quirk to enable rear speakers
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for ASUS ROG GA402X (bsc#1012628).
- ALSA: hda/realtek: Add quirk for ASUS ROG GX650P (bsc#1012628).
- ALSA: hda: fix a possible null-pointer dereference due to data
  race in snd_hdac_regmap_sync() (bsc#1012628).
- ALSA: hda/realtek: Add quirks for Unis H3C Desktop B760 & Q760
  (bsc#1012628).
- fs/ntfs3: Alternative boot if primary boot is corrupted
  (bsc#1012628).
- fs/ntfs3: Mark ntfs dirty when on-disk struct is corrupted
  (bsc#1012628).
- fs: ntfs3: Fix possible null-pointer dereferences in mi_read()
  (bsc#1012628).
- fs/ntfs3: Return error for inconsistent extended attributes
  (bsc#1012628).
- fs/ntfs3: Enhance sanity check while generating attr_list
  (bsc#1012628).
- drm/amdgpu: Fix potential fence use-after-free v2 (bsc#1012628).
- ceph: try to dump the msgs when decoding fails (bsc#1012628).
- Bluetooth: btusb: Add MT7922 bluetooth ID for the Asus Ally
  (bsc#1012628).
- Bluetooth: L2CAP: Fix use-after-free (bsc#1012628).
- watchdog: sp5100_tco: support Hygon FCH/SCH (Server Controller
  Hub) (bsc#1012628).
- firewire: net: fix use after free in
  fwnet_finish_incoming_packet() (bsc#1012628).
- thunderbolt: Limit Intel Barlow Ridge USB3 bandwidth
  (bsc#1012628).
- thunderbolt: Add Intel Barlow Ridge PCI ID (bsc#1012628).
- pcmcia: rsrc_nonstatic: Fix memory leak in
  nonstatic_release_resource_db() (bsc#1012628).
- gfs2: Fix possible data races in gfs2_show_options()
  (bsc#1012628).
- usb: chipidea: imx: add missing USB PHY DPDM wakeup setting
  (bsc#1012628).
- usb: chipidea: imx: turn off vbus comparator when suspend
  (bsc#1012628).
- usb: chipidea: imx: don't request QoS for imx8ulp (bsc#1012628).
- xhci: get rid of XHCI_PLAT quirk that used to prevent MSI setup
  (bsc#1012628).
- thunderbolt: Read retimer NVM authentication status prior
  tb_retimer_set_inbound_sbtx() (bsc#1012628).
- media: platform: mediatek: vpu: fix NULL ptr dereference
  (bsc#1012628).
- usb: gadget: uvc: queue empty isoc requests if no video buffer
  is available (bsc#1012628).
- usb: gadget: u_serial: Avoid spinlock recursion in
  __gs_console_push (bsc#1012628).
- media: camss: set VFE bpl_alignment to 16 for sdm845 and sm8250
  (bsc#1012628).
- media: v4l2-mem2mem: add lock to protect parameter num_rdy
  (bsc#1012628).
- led: qcom-lpg: Fix resource leaks in
  for_each_available_child_of_node() loops (bsc#1012628).
- serial: stm32: Ignore return value of uart_remove_one_port()
  in .remove() (bsc#1012628).
- cifs: fix session state check in reconnect to avoid
  use-after-free issue (bsc#1012628).
- smb: client: fix warning in cifs_smb3_do_mount() (bsc#1012628).
- Revert "[PATCH] uml: export symbols added by GCC hardened"
  (bsc#1012628).
- HID: intel-ish-hid: ipc: Add Arrow Lake PCI device ID
  (bsc#1012628).
- ASoC: SOF: core: Free the firmware trace before calling
  snd_sof_shutdown() (bsc#1012628).
- drm/amd/display: Enable dcn314 DPP RCO (bsc#1012628).
- drm/amd/display: Skip DPP DTO update if root clock is gated
  (bsc#1012628).
- RDMA/bnxt_re: consider timeout of destroy ah as success
  (bsc#1012628).
- RDMA/mlx5: Return the firmware result upon destroying QP/RQ
  (bsc#1012628).
- drm/amdgpu: unmap and remove csa_va properly (bsc#1012628).
- drm/amd/display: Apply 60us prefetch for DCFCLK <= 300Mhz
  (bsc#1012628).
- drm/amd/display: Remove v_startup workaround for dcn3+
  (bsc#1012628).
- drm/amdgpu: install stub fence into potential unused fence
  pointers (bsc#1012628).
- iommu/amd: Introduce Disable IRTE Caching Support (bsc#1012628).
- HID: logitech-hidpp: Add USB and Bluetooth IDs for the Logitech
  G915 TKL Keyboard (bsc#1012628).
- HID: i2c-hid: goodix: Add support for
  "goodix,no-reset-during-suspend" property (bsc#1012628).
- dt-bindings: input: goodix: Add "goodix,no-reset-during-suspend"
  property (bsc#1012628).
- accel/habanalabs: fix mem leak in capture user mappings
  (bsc#1012628).
- accel/habanalabs: add pci health check during heartbeat
  (bsc#1012628).
- dma-remap: use kvmalloc_array/kvfree for larger dma memory remap
  (bsc#1012628).
- ASoC: SOF: Intel: fix SoundWire/HDaudio mutual exclusion
  (bsc#1012628).
- iopoll: Call cpu_relax() in busy loops (bsc#1012628).
- ASoC: Intel: sof_sdw: Add support for Rex soundwire
  (bsc#1012628).
- ASoC: Intel: sof_sdw: add quick for Dell SKU 0BDA (bsc#1012628).
- ASoC: Intel: sof_sdw_rt_sdca_jack_common: test SOF_JACK_JDSRC
  in _exit (bsc#1012628).
- ARM: dts: imx6dl: prtrvt, prtvt7, prti6q, prtwd2: fix USB
  related warnings (bsc#1012628).
- RDMA/mana_ib: Use v2 version of cfg_rx_steer_req to enable RX
  coalescing (bsc#1012628).
- ASoC: amd: vangogh: Add check for acp config flags in vangogh
  platform (bsc#1012628).
- drm: rcar-du: remove R-Car H3 ES1.* workarounds (bsc#1012628).
- arm64: dts: qcom: ipq5332: add QFPROM node (bsc#1012628).
- drm/stm: ltdc: fix late dereference check (bsc#1012628).
- ASoC: SOF: amd: Add pci revision id check (bsc#1012628).
- ASoC: cs35l56: Move DSP part string generation so that it is
  done only once (bsc#1012628).
- PCI: tegra194: Fix possible array out of bounds access
  (bsc#1012628).
- ASoC: Intel: sof_sdw: add quirk for LNL RVP (bsc#1012628).
- ASoC: Intel: sof_sdw: add quirk for MTL RVP (bsc#1012628).
- Revert "drm/amd/display: disable SubVP + DRR to prevent
  underflow" (bsc#1012628).
- drm/amdgpu: fix memory leak in mes self test (bsc#1012628).
- drm/amdgpu: Fix integer overflow in amdgpu_cs_pass1
  (bsc#1012628).
- drm/amdgpu: fix calltrace warning in amddrm_buddy_fini
  (bsc#1012628).
- drm/scheduler: set entity to NULL in drm_sched_entity_pop_job()
  (bsc#1012628).
- drm/amd/display: Update DTBCLK for DCN32 (bsc#1012628).
- net: phy: at803x: fix the wol setting functions (bsc#1012628).
- net: phy: at803x: Use devm_regulator_get_enable_optional()
  (bsc#1012628).
- crypto, cifs: fix error handling in extract_iter_to_sg()
  (bsc#1012628).
- commit c12060a
* Thu Aug 24 2023 tiwai@suse.de
- Re-enable kABI placeholder patch for core structs
  Also rename the patch without the number prefix
- commit 8e3d5a7
* Thu Aug 24 2023 tiwai@suse.de
- Delete patches.suse/0001-oracleasm-4.0-compat-changes.patch
  No longer needed workaround.
- commit 67f601c
* Wed Aug 23 2023 msuchanek@suse.de
- Keep patches.suse/powerpc-security-mitigation-patching.sh-Support-X-ta.patch
  The X taint flag is still used
- commit a920896
* Wed Aug 23 2023 msuchanek@suse.de
- Keep patches.suse/powerpc-Add-kABI-placeholder-to-struct-pci_controlle.patch
- commit 2975c39
* Wed Aug 23 2023 msuchanek@suse.de
- Keep patches.suse/scsi-blacklist-add-VMware-ESXi-cdrom-broken-tray-emu.patch
  No sign of VMware even acknowledging the problem, much less fixing it.
- commit e09edd4
* Wed Aug 23 2023 msuchanek@suse.de
- Keep ppc and s390 lockdown patches - they are needed as much as the
  other architectures.
- Update config files
- commit f6a51bf
* Wed Aug 23 2023 msuchanek@suse.de
- Keep patches.suse/powerpc-tm-Flip-the-HTM-switch-default-to-disabled.patch
  Needed until HTM is disabled completely
- commit 2710607
* Wed Aug 23 2023 msuchanek@suse.de
- Keep patches.suse/powerpc-kexec_file-Add-KEXEC_SIG-support.patch
  Should be revisited after kexec option cleanup is merged upstream
- Update config files
- commit 5359722
* Wed Aug 23 2023 msuchanek@suse.de
- Keep patches.suse/powerpc-pseries-mobility-notify-network-peers-after-.patch
  Upstream network notification framework still not avaialble
- commit f496138
* Wed Aug 23 2023 msuchanek@suse.de
- Delete patches.rpmify/arm64-make-STACKPROTECTOR_PER_TASK-configurable.patch.
  No effect anymore
- commit 334f200
* Wed Aug 23 2023 tbogendoerfer@suse.de
- Delete patches.suse/rtl8188eu-fix-const-dev_addr_fallout.patch.
  Patch is longer needed.
- commit 6c9e4e5
* Wed Aug 23 2023 tbogendoerfer@suse.de
- Enable mlx5 S390 patch and still not upstreamed change for ixgbe
- commit 321b2db
* Wed Aug 23 2023 msuchanek@suse.de
- Delete patches.rpmify/powerpc-Blacklist-GCC-5.4-6.1-and-6.2.patch.
  Unlikely to encounter these compilers anymore.
- commit 3daa0f4
* Wed Aug 23 2023 jack@suse.cz
- Delete patches.suse/ext4-fixup-pages-without-buffers.patch: Not needed
  after commit d824ec2a154 ("mm: do not reclaim private data from pinned
  page") merged into 6.4-rc1.
- commit 11e5155
* Wed Aug 23 2023 jack@suse.cz
- Delete patches.suse/ext4-dont-warn-when-enabling-DAX.patch: Warning got
  removed by commit 6e47a3cc68f ("ext4: get rid of super block and sbi
  from handle_mount_ops()") in 5.17-rc1.
- commit 74d1133
* Wed Aug 23 2023 jack@suse.cz
- Enable patches.suse/ext4-unsupported-features.patch. We still want
  the ability to declare some ext4 features unsupported.
- commit e745607
* Wed Aug 23 2023 krisman@suse.de
- Delete
  patches.suse/io_uring-disable-polling-signalfd-pollfree-files.patch.
- commit 103eea6
* Wed Aug 23 2023 jack@suse.cz
- Delete
  patches.suse/fs-Avoid-leaving-freed-inode-on-dirty-list.patch: The fix
  was never 100%% proven to be necessary (followup ext4 changes were the
  real fix) and upstream was unconvinced. Let's drop it.
- commit 45cf4a8
* Wed Aug 23 2023 jack@suse.cz
- Delete
  patches.suse/md-raid5-Improve-performance-for-sequential-IO.patch: Got
  merged into 6.4-rc1 as commit fc05e06e6098c.
- commit 03eba77
* Wed Aug 23 2023 jack@suse.cz
- Delete
  patches.suse/sbitmap-avoid-lockups-when-waker-gets-preempted.patch:
  Current sbitmap code in 6.4 doesn't have the race.
- commit 88c81f0
* Wed Aug 23 2023 ailiop@suse.com
- Delete
  patches.suse/mount-warn-only-once-about-timestamp-range-expiratio.patch.
  Upstreamed via commit a128b054ce02 ("mount: warn only once about
  timestamp range expiration") in v5.18-rc1.
- commit 1eda8fd
* Wed Aug 23 2023 ailiop@suse.com
- Refresh
  patches.suse/xfs-allow-mount-remount-when-stripe-width-alignment-.patch.
- commit de9c3d8
* Wed Aug 23 2023 ailiop@suse.com
- Refresh
  patches.suse/xfs-remove-experimental-tag-for-dax-support.patch.
- commit 207884d
* Wed Aug 23 2023 tiwai@suse.de
- Revert "misc: rtsx: judge ASPM Mode to set PETXCFG Reg"
  (bsc#1214397,bsc#1214428).
- commit 0816489
* Wed Aug 23 2023 mhocko@suse.com
- Delete patches.suse/setuid-dumpable-wrongdir.
  Dropped as per jsc#PED-6319
- commit c9ee1be
* Wed Aug 23 2023 jgross@suse.com
- Refresh patches.suse/Restore-kABI-for-NVidia-vGPU-driver.patch.
- commit 3b82441
* Wed Aug 23 2023 tiwai@suse.de
- Re-enable kABI placeholder patches for ASoC and HD-audio
- commit 5f24bf4
* Wed Aug 23 2023 tiwai@suse.de
- Re-enable nouveau blacklist for Turing and Ampere
  The situation about nouveau hasn't been changed.
- commit 693f494
* Wed Aug 23 2023 tiwai@suse.de
- Re-enable synaptics and ata fix patches
  Those workarounds are still valid.
- commit d797d34
* Wed Aug 23 2023 mhocko@suse.com
- Refresh
  patches.suse/mm-Warn-users-of-node-memory-hot-remove-if-the-memory-ratio-is-a-high-risk.patch.
- Refresh
  patches.suse/mm-inform-about-enabling-mirrored-memory.patch.
  re-enable debugability non-upstream improvements.
- commit 6f8f3c5
* Wed Aug 23 2023 tiwai@suse.de
- Delete patches.suse/Revive-usb-audio-Keep-Interface-mixer.patch
  It was a transitional workaround.  No longer needed.
- commit 0766049
* Wed Aug 23 2023 tiwai@suse.de
- Delete patches.suse/thermal-Add-a-sanity-check-for-invalid-state-at-stat.patch
  The old workaround for SLE15-SP4/5.  Should have been obsoleted in 6.4.
- commit 19a31d1
* Wed Aug 23 2023 tiwai@suse.de
- Delete patches.suse/Fix-null-pointer-dereference-in-drm_dp_atomic_find_time_slots.patch
  It's a temporary workaround that was applied for SLE15-SP5.  Let's drop.
- commit e4825d8
* Wed Aug 23 2023 tiwai@suse.de
- Delete patches.suse/char-pcmcia-synclink_cs-Fix-use-after-free-in-mgslpc.patch
  It's for PCMCIA and already disabled on all flavors.
- commit c1a3353
* Wed Aug 23 2023 jgross@suse.com
- Delete
  patches.suse/0002-kernel-smp-make-csdlock-timeout-depend-on-boot-param.patch.
- commit e4b9f75
* Wed Aug 23 2023 tiwai@suse.de
- Delete patches.suse/ath11k-pci-Add-more-MODULE_FIRMWARE-entries.patch
  It's already included in 6.4 kernel.
- commit 7e548aa
* Wed Aug 23 2023 mhocko@suse.com
- Delete patches.suse/smaps_rollup-fix-no-vmas-null-deref.patch.
  c4c84f06285e ("fs/proc/task_mmu: stop using linked list and
  highest_vm_end") which is the proper fix is already included in the base
  kernel.
- commit 0a8b09e
* Wed Aug 23 2023 tiwai@suse.de
- Drop obsoleted arm64 patches
  Deleted the changes that have been obsoleted / become invalid in the upstream:
  patches.suse/arch-arm64-mm_context-t-placeholder.patch
  patches.suse/arm64-select-CPUMASK_OFFSTACK-if-NUMA.patch
  patches.suse/arm64-set-UXN-on-swapper-page-tables.patch
- commit 51ba575
* Wed Aug 23 2023 mhocko@suse.com
- Delete
  patches.suse/binfmt_elf-takethe-mmap_lock-when-walking-the-VMA-list.patch.
  2aa362c49c31 ("coredump: extend core dump note section to contain file
  names of mapped files") is the proper fix already included in the base
  kernel
- commit d280d0f
* Wed Aug 23 2023 tiwai@suse.de
- Delete patches.suse/ahci-Add-Intel-Emmitsburg-PCH-RAID-PCI-IDs.patch
  8086:282f has been already included in the upstream, while 8086:282b
  is never released.
- commit 3276e1e
* Wed Aug 23 2023 msuchanek@suse.de
- powerpc: Move DMA64_PROPNAME define to a header (bsc#1214297 ltc#197503).
- commit 20076ce
* Wed Aug 23 2023 mkoutny@suse.com
- Delete
  patches.suse/0001-net-sched-tcindex-Do-not-use-perfect-hashing.patch.
  Replaced with upstream commit 8c710f75256b ("net/sched: Retire tcindex classifier").
- commit 8e7e62a
* Wed Aug 23 2023 msuchanek@suse.de
- powerpc/fadump: invoke ibm,os-term with rtas_call_unlocked()
  (bsc#1210421 ltc#202733).
- commit 395c794
* Wed Aug 23 2023 msuchanek@suse.de
- powerpc/idle: Add support for nohlt (bac#1214529).
  Update config files.
- commit 1309479
* Wed Aug 23 2023 msuchanek@suse.de
- old-flavors: Drop 2.6 kernels.
  2.6 based kernels are EOL, upgrading from them is no longer suported.
- commit 7bb5087
* Wed Aug 23 2023 tiwai@suse.de
- Merge SLE15-SP6 branch: patches, series.conf, supported.conf,
  kabi/severities and blacklist.conf are synced with SLE15-SP6 while
  config and others are kept as is.
* Wed Aug 23 2023 msuchanek@suse.de
- powerpc/pseries: new character devices for RTAS functions
  (jsc#PED-4486).
- commit 01242f0
* Tue Aug 22 2023 msuchanek@suse.de
- block: sed-opal: keyring support for SED keys (jsc#PED-3545).
- Update config files.
- block: sed-opal: Implement IOC_OPAL_REVERT_LSP (jsc#PED-3545).
- block: sed-opal: Implement IOC_OPAL_DISCOVERY (jsc#PED-3545).
- commit c8bb675
* Tue Aug 22 2023 tiwai@suse.de
- supported.conf: mark reiserfs, quota_v1 and ufs as unsupported again
  It was changed at SLE15-SP6 merge.
- commit 960966d
* Tue Aug 22 2023 tiwai@suse.de
- rpm/kernel-source.changes.old: update for the SLE15-SP6 merge
  SLE15-* changelogs are truncated as irrelevant for ALP.
- commit 53cd0b3
* Tue Aug 22 2023 jslaby@suse.cz
- Refresh
  patches.suse/ASoC-SOF-intel-hda-Clean-up-link-DMA-for-IPC3-during.patch.
  Update to upstream version and move to sorted section.
- commit 58e4b74
* Tue Aug 22 2023 jslaby@suse.cz
- Refresh
  patches.suse/drm-nouveau-disp-fix-use-after-free-in-error-handlin.patch.
  Update to upstream version and move to sorted section.
- commit 28ed2c1
* Tue Aug 22 2023 jslaby@suse.cz
- Refresh
  patches.suse/Revert-drm-edid-Fix-csync-detailed-mode-parsing.patch.
  Update to upstream version and move to sorted section.
- commit edfd280
* Mon Aug 21 2023 msuchanek@suse.de
- Switch s390x CPU type to z14 (jsc#PED-253)
- commit 2c77a1e
* Mon Aug 21 2023 msuchanek@suse.de
- powerpc/rtas_flash: allow user copy to flash block cache objects
  (bsc#1194869).
- commit 7902b43
* Fri Aug 18 2023 tiwai@suse.de
- supported.conf: Correcte reiserfs-kmp as unsupported (bsc#1214386)
- commit d423b7a
* Fri Aug 18 2023 msuchanek@suse.de
- mkspec: Allow unsupported KMPs (bsc#1214386)
- commit 55d8b82
* Fri Aug 18 2023 msuchanek@suse.de
- check-for-config-changes: ignore BUILTIN_RETURN_ADDRESS_STRIPS_PAC (bsc#1214380).
  gcc7 on SLE 15 does not support this while later gcc does.
- commit 5b41c27
* Thu Aug 17 2023 msuchanek@suse.de
- Switch ppc64le CPU type to Power9 (jsc#PED-2006)
- commit 58f81f3
* Thu Aug 17 2023 jslaby@suse.cz
- Linux 6.4.11 (bsc#1012628).
- tpm: Disable RNG for all AMD fTPMs (bsc#1012628).
- tpm: Add a helper for checking hwrng enabled (bsc#1012628).
- ksmbd: validate command request size (bsc#1012628).
- ksmbd: fix wrong next length validation of ea buffer in
  smb2_set_ea() (bsc#1012628).
- KVM: SEV: snapshot the GHCB before accessing it (bsc#1012628).
- KVM: SEV: only access GHCB fields once (bsc#1012628).
- wifi: nl80211: fix integer overflow in
  nl80211_parse_mbssid_elems() (bsc#1012628).
- wifi: rtw89: fix 8852AE disconnection caused by RX full flags
  (bsc#1012628).
- selftests: forwarding: Set default IPv6 traceroute utility
  (bsc#1012628).
- wireguard: allowedips: expand maximum node depth (bsc#1012628).
- mmc: moxart: read scr register without changing byte order
  (bsc#1012628).
- mmc: sdhci-f-sdh30: Replace with sdhci_pltfm (bsc#1012628).
- ipv6: adjust ndisc_is_useropt() to also return true for PIO
  (bsc#1012628).
- selftests: mptcp: join: fix 'delete and re-add' test
  (bsc#1012628).
- selftests: mptcp: join: fix 'implicit EP' test (bsc#1012628).
- mptcp: avoid bogus reset on fallback close (bsc#1012628).
- mptcp: fix disconnect vs accept race (bsc#1012628).
- dmaengine: pl330: Return DMA_PAUSED when transaction is paused
  (bsc#1012628).
- dmaengine: xilinx: xdma: Fix interrupt vector setting
  (bsc#1012628).
- net: mana: Fix MANA VF unload when hardware is unresponsive
  (bsc#1012628).
- ACPI: resource: Add IRQ override quirk for PCSpecialist Elimina
  Pro 16 M (bsc#1012628).
- zram: take device and not only bvec offset into account
  (bsc#1012628).
- io_uring/parisc: Adjust pgoff in io_uring mmap() for parisc
  (bsc#1012628).
- parisc: Fix lightweight spinlock checks to not break futexes
  (bsc#1012628).
- riscv: Start of DRAM should at least be aligned on PMD size
  for the direct mapping (bsc#1012628).
- riscv/kexec: load initrd high in available memory (bsc#1012628).
- riscv,mmio: Fix readX()-to-delay() ordering (bsc#1012628).
- riscv/kexec: handle R_RISCV_CALL_PLT relocation type
  (bsc#1012628).
- riscv: mm: fix 2 instances of -Wmissing-variable-declarations
  (bsc#1012628).
- nvme: fix possible hang when removing a controller during
  error recovery (bsc#1012628).
- nvme-tcp: fix potential unbalanced freeze & unfreeze
  (bsc#1012628).
- nvme-rdma: fix potential unbalanced freeze & unfreeze
  (bsc#1012628).
- nvme-pci: add NVME_QUIRK_BOGUS_NID for Samsung PM9B1 256G and
  512G (bsc#1012628).
- drm/nouveau/gr: enable memory loads on helper invocation on
  all channels (bsc#1012628).
- drm/nouveau/nvkm/dp: Add workaround to fix DP 1.3+ DPCD issues
  (bsc#1012628).
- drm/shmem-helper: Reset vma->vm_ops before calling
  dma_buf_mmap() (bsc#1012628).
- drm/amdgpu: fix possible UAF in amdgpu_cs_pass1() (bsc#1012628).
- drm/amd/pm: correct the pcie width for smu 13.0.0 (bsc#1012628).
- drm/amd/display: check attr flag before set cursor degamma on
  DCN3+ (bsc#1012628).
- tpm: tpm_tis: Fix UPX-i11 DMI_MATCH condition (bsc#1012628).
- cpuidle: dt_idle_genpd: Add helper function to remove genpd
  topology (bsc#1012628).
- cpuidle: psci: Move enabling OSI mode after power domains
  creation (bsc#1012628).
- io_uring: correct check for O_TMPFILE (bsc#1012628).
- zsmalloc: fix races between modifications of fullness and
  isolated (bsc#1012628).
- hwmon: (pmbus/bel-pfe) Enable PMBUS_SKIP_STATUS_CHECK for
  pfe1100 (bsc#1012628).
- radix tree test suite: fix incorrect allocation size for
  pthreads (bsc#1012628).
- cpufreq: amd-pstate: fix global sysfs attribute type
  (bsc#1012628).
- fs/proc/kcore: reinstate bounce buffer for KCORE_TEXT regions
  (bsc#1012628).
- nilfs2: fix use-after-free of nilfs_root in dirtying inodes
  via iput (bsc#1012628).
- accel/ivpu: Add set_pages_array_wc/uc for internal buffers
  (bsc#1012628).
- hugetlb: do not clear hugetlb dtor until allocating vmemmap
  (bsc#1012628).
- mm/damon/core: initialize damo_filter->list from
  damos_new_filter() (bsc#1012628).
- selftests: mm: ksm: fix incorrect evaluation of parameter
  (bsc#1012628).
- mm: memory-failure: fix potential unexpected return value from
  unpoison_memory() (bsc#1012628).
- mm: memory-failure: avoid false hwpoison page mapped error info
  (bsc#1012628).
- drm/amd/pm: expose swctf threshold setting for legacy powerplay
  (bsc#1012628).
- drm/amd/pm: avoid unintentional shutdown due to temperature
  momentary fluctuation (bsc#1012628).
- iio: cros_ec: Fix the allocation size for cros_ec_command
  (bsc#1012628).
- iio: frequency: admv1013: propagate errors from
  regulator_get_voltage() (bsc#1012628).
- iio: adc: ad7192: Fix ac excitation feature (bsc#1012628).
- iio: adc: meson: fix core clock enable/disable moment
  (bsc#1012628).
- iio: adc: ina2xx: avoid NULL pointer dereference on OF device
  match (bsc#1012628).
- binder: fix memory leak in binder_init() (bsc#1012628).
- misc: rtsx: judge ASPM Mode to set PETXCFG Reg (bsc#1012628).
- thunderbolt: Fix memory leak in tb_handle_dp_bandwidth_request()
  (bsc#1012628).
- usb-storage: alauda: Fix uninit-value in alauda_check_media()
  (bsc#1012628).
- usb: dwc3: Properly handle processing of pending events
  (bsc#1012628).
- USB: Gadget: core: Help prevent panic during UVC unconfigure
  (bsc#1012628).
- usb: common: usb-conn-gpio: Prevent bailing out if initial
  role is none (bsc#1012628).
- usb: typec: tcpm: Fix response to vsafe0V event (bsc#1012628).
- usb: typec: altmodes/displayport: Signal hpd when configuring
  pin assignment (bsc#1012628).
- x86/srso: Fix build breakage with the LLVM linker (bsc#1012628).
- x86/vdso: Choose the right GDT_ENTRY_CPUNODE for 32-bit getcpu()
  on 64-bit kernel (bsc#1012628).
- x86/cpu/amd: Enable Zenbleed fix for AMD Custom APU 0405
  (bsc#1012628).
- x86/mm: Fix VDSO and VVAR placement on 5-level paging machines
  (bsc#1012628).
- x86/sev: Do not try to parse for the CC blob on non-AMD hardware
  (bsc#1012628).
- x86/linkage: Fix typo of BUILD_VDSO in asm/linkage.h
  (bsc#1012628).
- x86/speculation: Add cpu_show_gds() prototype (bsc#1012628).
- x86: Move gds_ucode_mitigated() declaration to header
  (bsc#1012628).
- Revert "PCI: mvebu: Mark driver as BROKEN" (bsc#1012628).
- drm/nouveau/disp: Revert a NULL check inside
  nouveau_connector_get_modes (bsc#1012628).
- netfilter: nf_tables: don't skip expired elements during walk
  (bsc#1012628).
- netfilter: nf_tables: GC transaction API to avoid race with
  control plane (bsc#1012628).
- netfilter: nf_tables: adapt set backend to use GC transaction
  API (bsc#1012628).
- netfilter: nft_set_hash: mark set element as dead when deleting
  from packet path (bsc#1012628).
- iio: imu: lsm6dsx: Fix mount matrix retrieval (bsc#1012628).
- iio: core: Prevent invalid memory access when there is no parent
  (bsc#1012628).
- iio: light: bu27034: Fix scale format (bsc#1012628).
- interconnect: qcom: Add support for mask-based BCMs
  (bsc#1012628).
- interconnect: qcom: sa8775p: add enable_mask for bcm nodes
  (bsc#1012628).
- interconnect: qcom: sm8450: add enable_mask for bcm nodes
  (bsc#1012628).
- interconnect: qcom: sm8550: add enable_mask for bcm nodes
  (bsc#1012628).
- selftests: forwarding: tc_tunnel_key: Make filters more specific
  (bsc#1012628).
- selftests: forwarding: ethtool_mm: Skip when MAC Merge is not
  supported (bsc#1012628).
- selftests: forwarding: bridge_mdb_max: Check iproute2 version
  (bsc#1012628).
- selftests: forwarding: bridge_mdb: Check iproute2 version
  (bsc#1012628).
- KVM: arm64: Fix hardware enable/disable flows for pKVM
  (bsc#1012628).
- dmaengine: xilinx: xdma: Fix typo (bsc#1012628).
- dmaengine: xilinx: xdma: Fix Judgment of the return value
  (bsc#1012628).
- selftests/bpf: fix a CI failure caused by vsock sockmap test
  (bsc#1012628).
- selftests/rseq: Fix build with undefined __weak (bsc#1012628).
- selftests: forwarding: Add a helper to skip test when using
  veth pairs (bsc#1012628).
- selftests: forwarding: ethtool: Skip when using veth pairs
  (bsc#1012628).
- selftests: forwarding: ethtool_extended_state: Skip when using
  veth pairs (bsc#1012628).
- selftests: forwarding: hw_stats_l3_gre: Skip when using veth
  pairs (bsc#1012628).
- selftests: forwarding: Skip test when no interfaces are
  specified (bsc#1012628).
- selftests: forwarding: Switch off timeout (bsc#1012628).
- selftests: forwarding: tc_actions: Use ncat instead of nc
  (bsc#1012628).
- selftests: forwarding: tc_flower: Relax success criterion
  (bsc#1012628).
- selftests: forwarding: bridge_mdb_max: Fix failing test with
  old libnet (bsc#1012628).
- selftests: forwarding: bridge_mdb: Fix failing test with old
  libnet (bsc#1012628).
- selftests: forwarding: bridge_mdb: Make test more robust
  (bsc#1012628).
- net: core: remove unnecessary frame_sz check in
  bpf_xdp_adjust_tail() (bsc#1012628).
- bpf, sockmap: Fix map type error in sock_map_del_link
  (bsc#1012628).
- bpf, sockmap: Fix bug that strp_done cannot be called
  (bsc#1012628).
- hwmon: (aquacomputer_d5next) Add selective 200ms delay after
  sending ctrl report (bsc#1012628).
- mISDN: Update parameter type of dsp_cmx_send() (bsc#1012628).
- macsec: use DEV_STATS_INC() (bsc#1012628).
- mptcp: fix the incorrect judgment for msk->cb_flags
  (bsc#1012628).
- igc: Add lock to safeguard global Qbv variables (bsc#1012628).
- ionic: Add missing err handling for queue reconfig
  (bsc#1012628).
- net/packet: annotate data-races around tp->status (bsc#1012628).
- net/smc: Fix setsockopt and sysctl to specify same buffer size
  again (bsc#1012628).
- net/smc: Use correct buffer sizes when switching between TCP
  and SMC (bsc#1012628).
- PCI: move OF status = "disabled" detection to dev->match_driver
  (bsc#1012628).
- tcp: add missing family to tcp_set_ca_state() tracepoint
  (bsc#1012628).
- tunnels: fix kasan splat when generating ipv4 pmtu error
  (bsc#1012628).
- xsk: fix refcount underflow in error path (bsc#1012628).
- bonding: Fix incorrect deletion of ETH_P_8021AD protocol vid
  from slaves (bsc#1012628).
- dccp: fix data-race around dp->dccps_mss_cache (bsc#1012628).
- drivers: net: prevent tun_build_skb() to exceed the packet
  size limit (bsc#1012628).
- drivers: vxlan: vnifilter: free percpu vni stats on error path
  (bsc#1012628).
- iavf: fix potential races for FDIR filters (bsc#1012628).
- IB/hfi1: Fix possible panic during hotplug remove (bsc#1012628).
- drm/amd/display: Don't show stack trace for missing eDP
  (bsc#1012628).
- drm/bridge: it6505: Check power state with it6505->powered in
  IRQ handler (bsc#1012628).
- drm/nouveau: remove unused tu102_gr_load() function
  (bsc#1012628).
- drm/rockchip: Don't spam logs in atomic check (bsc#1012628).
- wifi: brcm80211: handle params_v1 allocation failure
  (bsc#1012628).
- wifi: cfg80211: fix sband iftype data lookup for AP_VLAN
  (bsc#1012628).
- RDMA/umem: Set iova in ODP flow (bsc#1012628).
- RDMA/bnxt_re: Properly order ib_device_unalloc() to avoid UAF
  (bsc#1012628).
- RDMA/bnxt_re: Fix error handling in probe failure path
  (bsc#1012628).
- net: tls: avoid discarding data on record close (bsc#1012628).
- net: marvell: prestera: fix handling IPv4 routes with nhid
  (bsc#1012628).
- net: phy: at803x: remove set/get wol callbacks for AR8032
  (bsc#1012628).
- net: dsa: ocelot: call dsa_tag_8021q_unregister() under
  rtnl_lock() on driver remove (bsc#1012628).
- net: hns3: refactor hclge_mac_link_status_wait for interface
  reuse (bsc#1012628).
- net: hns3: add wait until mac link down (bsc#1012628).
- net: hns3: fix deadlock issue when externel_lb and reset are
  executed together (bsc#1012628).
- net: enetc: reimplement RFS/RSS memory clearing as PCI quirk
  (bsc#1012628).
- nexthop: Fix infinite nexthop dump when using maximum nexthop ID
  (bsc#1012628).
- nexthop: Make nexthop bucket dump more efficient (bsc#1012628).
- nexthop: Fix infinite nexthop bucket dump when using maximum
  nexthop ID (bsc#1012628).
- net: hns3: fix strscpy causing content truncation issue
  (bsc#1012628).
- dmaengine: mcf-edma: Fix a potential un-allocated memory access
  (bsc#1012628).
- dmaengine: idxd: Clear PRS disable flag when disabling IDXD
  device (bsc#1012628).
- dmaengine: owl-dma: Modify mismatched function name
  (bsc#1012628).
- net/mlx5e: Take RTNL lock when needed before calling
  xdp_set_features() (bsc#1012628).
- net/mlx5e: TC, Fix internal port memory leak (bsc#1012628).
- net/mlx5: DR, Fix wrong allocation of modify hdr pattern
  (bsc#1012628).
- net/mlx5: Allow 0 for total host VFs (bsc#1012628).
- net/mlx5e: Unoffload post act rule when handling FIB events
  (bsc#1012628).
- net/mlx5: LAG, Check correct bucket when modifying LAG
  (bsc#1012628).
- net/mlx5: Skip clock update work when device is in error state
  (bsc#1012628).
- net/mlx5: Reload auxiliary devices in pci error handlers
  (bsc#1012628).
- ibmvnic: Enforce stronger sanity checks on login response
  (bsc#1012628).
- ibmvnic: Unmap DMA login rsp buffer on send login fail
  (bsc#1012628).
- ibmvnic: Handle DMA unmapping of login buffs in release
  functions (bsc#1012628).
- ibmvnic: Do partial reset on login failure (bsc#1012628).
- ibmvnic: Ensure login failure recovery is safe from other resets
  (bsc#1012628).
- gpio: ws16c48: Fix off-by-one error in WS16C48 resource region
  extent (bsc#1012628).
- gpio: sim: mark the GPIO chip as a one that can sleep
  (bsc#1012628).
- btrfs: wait for actual caching progress during allocation
  (bsc#1012628).
- btrfs: don't stop integrity writeback too early (bsc#1012628).
- btrfs: don't wait for writeback on clean pages in
  extent_write_cache_pages (bsc#1012628).
- btrfs: properly clear end of the unreserved range in
  cow_file_range (bsc#1012628).
- btrfs: exit gracefully if reloc roots don't match (bsc#1012628).
- btrfs: reject invalid reloc tree root keys with stack dump
  (bsc#1012628).
- btrfs: set cache_block_group_error if we find an error
  (bsc#1012628).
- scsi: core: Fix legacy /proc parsing buffer overflow
  (bsc#1012628).
- scsi: storvsc: Fix handling of virtual Fibre Channel timeouts
  (bsc#1012628).
- scsi: ufs: renesas: Fix private allocation (bsc#1012628).
- scsi: 53c700: Check that command slot is not NULL (bsc#1012628).
- scsi: snic: Fix possible memory leak if device_add() fails
  (bsc#1012628).
- scsi: core: Fix possible memory leak if device_add() fails
  (bsc#1012628).
- scsi: fnic: Replace return codes in fnic_clean_pending_aborts()
  (bsc#1012628).
- scsi: qedi: Fix firmware halt over suspend and resume
  (bsc#1012628).
- scsi: qedf: Fix firmware halt over suspend and resume
  (bsc#1012628).
- platform/x86: msi-ec: Fix the build (bsc#1012628).
- platform/x86: lenovo-ymc: Only bind on machines with a
  convertible DMI chassis-type (bsc#1012628).
- platform: mellanox: Change register offset addresses
  (bsc#1012628).
- platform: mellanox: mlx-platform: Fix signals polarity and
  latch mask (bsc#1012628).
- platform: mellanox: mlx-platform: Modify graceful shutdown
  callback and power down mask (bsc#1012628).
- platform: mellanox: Fix order in exit flow (bsc#1012628).
- platform/x86: serial-multi-instantiate: Auto detect IRQ resource
  for CSC3551 (bsc#1012628).
- ACPI: scan: Create platform device for CS35L56 (bsc#1012628).
- alpha: remove __init annotation from exported page_is_ram()
  (bsc#1012628).
- Update config files.
- commit 2a5b3f6
* Wed Aug 16 2023 msuchanek@suse.de
- kernel-binary: Common dependencies cleanup
  Common dependencies are copied to a subpackage, there is no need for
  copying defines or build dependencies there.
- commit 254b03c
* Wed Aug 16 2023 msuchanek@suse.de
- kernel-binary: Drop code for kerntypes support
  Kerntypes was a SUSE-specific feature dropped before SLE 12.
- commit 2c37773
* Wed Aug 16 2023 msuchanek@suse.de
- powerpc/iommu: TCEs are incorrectly manipulated with DLPAR
  add/remove of memory (bsc#1212091 ltc#199106).
- commit 011a0f3
* Wed Aug 16 2023 msuchanek@suse.de
- Update patches.kernel.org/6.4.10-154-powerpc-mm-altmap-Fix-altmap-boundary-check.patch
  (bsc#1012628 bsc#1120059 git-fixes).
- commit 453d9fe
* Tue Aug 15 2023 palcantara@suse.de
- Update
  patches.kernel.org/6.4.5-008-ksmbd-fix-out-of-bounds-read-in-smb2_sess_setup.patch
  (bsc#1012628 bsc#1213545).
- commit d8f70b2
* Tue Aug 15 2023 msuchanek@suse.de
- powerpc/pseries: Honour current SMT state when DLPAR onlining
  CPUs (bsc#1214285 bsc#1205462 ltc#200161 ltc#200588).
- powerpc: Add HOTPLUG_SMT support (bsc#1214285 bsc#1205462
  ltc#200161 ltc#200588).
  Update config files.
- powerpc/pseries: Initialise CPU hotplug callbacks earlier
  (bsc#1214285 bsc#1205462 ltc#200161 ltc#200588).
- cpu/SMT: Allow enabling partial SMT states via sysfs
  (bsc#1214285 bsc#1205462 ltc#200161 ltc#200588).
- cpu/SMT: Create topology_smt_thread_allowed() (bsc#1214285
  bsc#1205462 ltc#200161 ltc#200588).
- cpu/SMT: Remove topology_smt_supported() (bsc#1214285
  bsc#1205462 ltc#200161 ltc#200588).
- cpu/SMT: Store the current/max number of threads (bsc#1214285
  bsc#1205462 ltc#200161 ltc#200588).
- cpu/SMT: Move smt/control simple exit cases earlier (bsc#1214285
  bsc#1205462 ltc#200161 ltc#200588).
- cpu/SMT: Move SMT prototypes into cpu_smt.h (bsc#1214285
  bsc#1205462 ltc#200161 ltc#200588).
- commit 5654017
* Mon Aug 14 2023 tiwai@suse.de
- drm/nouveau/disp: fix use-after-free in error handling of
  nouveau_connector_create (bsc#1214073).
- Delete
  patches.suse/Revert-drm-nouveau-disp-PIOR-DP-uses-GPIO-for-HPD-no.patch.
- commit 1b3aee5
* Mon Aug 14 2023 tiwai@suse.de
- tpm_tis: Opt-in interrupts (bsc#1213779)
  Also dropped the obsoleted patch:
  patches.suse/tpm-tpm_tis-Disable-interrupts-categorically-for-Len.patch
- commit 80aa18d
* Mon Aug 14 2023 jslaby@suse.cz
- Refresh
  patches.suse/ACPI-resource-Always-use-MADT-override-IRQ-settings-.patch.
- Refresh
  patches.suse/ACPI-resource-Honor-MADT-INT_SRC_OVR-settings-for-IR.patch.
- Refresh
  patches.suse/ACPI-resource-revert-Remove-Zen-specific-match-and-q.patch.
  Update upstream status and move to sorted section.
- commit d0aa45f
* Mon Aug 14 2023 jslaby@suse.cz
- Refresh
  patches.suse/drm-amd-display-Fix-a-regression-on-Polaris-cards.patch.
  Update upstream status and move to sorted section.
- commit e1f43a2
* Mon Aug 14 2023 jslaby@suse.cz
- Linux 6.4.10 (bsc#1012628).
- iommu/arm-smmu-v3: Work around MMU-600 erratum 1076982
  (bsc#1012628).
- iommu/arm-smmu-v3: Document MMU-700 erratum 2812531
  (bsc#1012628).
- iommu/arm-smmu-v3: Add explicit feature for nesting
  (bsc#1012628).
- iommu/arm-smmu-v3: Document nesting-related errata
  (bsc#1012628).
- arm64: dts: imx8mm-venice-gw7903: disable disp_blk_ctrl
  (bsc#1012628).
- arm64: dts: imx8mm-venice-gw7904: disable disp_blk_ctrl
  (bsc#1012628).
- arm64: dts: phycore-imx8mm: Label typo-fix of VPU (bsc#1012628).
- arm64: dts: phycore-imx8mm: Correction in gpio-line-names
  (bsc#1012628).
- arm64: dts: imx8mn-var-som: add missing pull-up for onboard
  PHY reset pinmux (bsc#1012628).
- arm64: dts: freescale: Fix VPU G2 clock (bsc#1012628).
- firmware: smccc: Fix use of uninitialised results structure
  (bsc#1012628).
- firmware: arm_scmi: Fix signed error return values handling
  (bsc#1012628).
- lib/bitmap: workaround const_eval test build failure
  (bsc#1012628).
- ARM: dts: nxp/imx: limit sk-imx53 supported frequencies
  (bsc#1012628).
- soc: imx: imx8mp-blk-ctrl: register HSIO PLL clock as
  bus_power_dev child (bsc#1012628).
- firmware: arm_scmi: Fix chan_free cleanup on SMC (bsc#1012628).
- ARM: dts: at91: use clock-controller name for PMC nodes
  (bsc#1012628).
- ARM: dts: at91: use clock-controller name for sckc nodes
  (bsc#1012628).
- ARM: dts: at91: use generic name for shutdown controller
  (bsc#1012628).
- ARM: dts: at91: sam9x60: fix the SOC detection (bsc#1012628).
- word-at-a-time: use the same return type for has_zero regardless
  of endianness (bsc#1012628).
- s390/vmem: split pages when debug pagealloc is enabled
  (bsc#1012628).
- KVM: s390: fix sthyi error handling (bsc#1012628).
- erofs: fix wrong primary bvec selection on deduplicated extents
  (bsc#1012628).
- perf pmu arm64: Fix reading the PMU cpu slots in sysfs
  (bsc#1012628).
- wifi: cfg80211: Fix return value in scan logic (bsc#1012628).
- net/mlx5e: fix double free in
  macsec_fs_tx_create_crypto_table_groups (bsc#1012628).
- net/mlx5: DR, fix memory leak in mlx5dr_cmd_create_reformat_ctx
  (bsc#1012628).
- net/mlx5: fix potential memory leak in mlx5e_init_rep_rx
  (bsc#1012628).
- net/mlx5e: fix return value check in
  mlx5e_ipsec_remove_trailer() (bsc#1012628).
- net/mlx5: Honor user input for migratable port fn attr
  (bsc#1012628).
- net/mlx5e: Don't hold encap tbl lock if there is no encap action
  (bsc#1012628).
- net/mlx5e: Fix crash moving to switchdev mode when ntuple
  offload is set (bsc#1012628).
- net/mlx5e: Move representor neigh cleanup to profile cleanup_tx
  (bsc#1012628).
- net/mlx5e: xsk: Fix invalid buffer access for legacy rq
  (bsc#1012628).
- net/mlx5e: xsk: Fix crash on regular rq reactivation
  (bsc#1012628).
- net/mlx5e: kTLS, Fix protection domain in use syndrome when
  devlink reload (bsc#1012628).
- net/mlx5: fs_chains: Fix ft prio if ignore_flow_level is not
  supported (bsc#1012628).
- net/mlx5: Unregister devlink params in case interface is down
  (bsc#1012628).
- bpf: Add length check for SK_DIAG_BPF_STORAGE_REQ_MAP_FD parsing
  (bsc#1012628).
- rtnetlink: let rtnl_bridge_setlink checks IFLA_BRIDGE_MODE
  length (bsc#1012628).
- net: dsa: fix value check in bcm_sf2_sw_probe() (bsc#1012628).
- perf test uprobe_from_different_cu: Skip if there is no gcc
  (bsc#1012628).
- net: sched: cls_u32: Fix match key mis-addressing (bsc#1012628).
- mISDN: hfcpci: Fix potential deadlock on &hc->lock
  (bsc#1012628).
- net: stmmac: tegra: Properly allocate clock bulk data
  (bsc#1012628).
- qed: Fix scheduling in a tasklet while getting stats
  (bsc#1012628).
- net: move gso declarations and functions to their own files
  (bsc#1012628).
- net: gro: fix misuse of CB in udp socket lookup (bsc#1012628).
- net: annotate data-races around sk->sk_reserved_mem
  (bsc#1012628).
- net: annotate data-race around sk->sk_txrehash (bsc#1012628).
- net: annotate data-races around sk->sk_max_pacing_rate
  (bsc#1012628).
- net: add missing READ_ONCE(sk->sk_rcvlowat) annotation
  (bsc#1012628).
- net: add missing READ_ONCE(sk->sk_sndbuf) annotation
  (bsc#1012628).
- net: add missing READ_ONCE(sk->sk_rcvbuf) annotation
  (bsc#1012628).
- net: annotate data-races around sk->sk_mark (bsc#1012628).
- net: add missing data-race annotations around sk->sk_peek_off
  (bsc#1012628).
- net: add missing data-race annotation for sk_ll_usec
  (bsc#1012628).
- net: annotate data-races around sk->sk_priority (bsc#1012628).
- net/sched: taprio: Limit TCA_TAPRIO_ATTR_SCHED_CYCLE_TIME to
  INT_MAX (bsc#1012628).
- net: usb: lan78xx: reorder cleanup operations to avoid UAF bugs
  (bsc#1012628).
- ice: Fix RDMA VSI removal during queue rebuild (bsc#1012628).
- bnxt: don't handle XDP in netpoll (bsc#1012628).
- octeon_ep: initialize mbox mutexes (bsc#1012628).
- bpf: Move unprivileged checks into map_create() and
  bpf_prog_load() (bsc#1012628).
- bpf: Inline map creation logic in map_create() function
  (bsc#1012628).
- bpf: Centralize permissions checks for all BPF map types
  (bsc#1012628).
- bpf, cpumap: Make sure kthread is running before map update
  returns (bsc#1012628).
- bpf, cpumap: Handle skb as well when clean up ptr_ring
  (bsc#1012628).
- net/sched: cls_u32: No longer copy tcf_result on update to
  avoid use-after-free (bsc#1012628).
- net/sched: cls_fw: No longer copy tcf_result on update to
  avoid use-after-free (bsc#1012628).
- net/sched: cls_route: No longer copy tcf_result on update to
  avoid use-after-free (bsc#1012628).
- bpf: sockmap: Remove preempt_disable in sock_map_sk_acquire
  (bsc#1012628).
- net: ll_temac: fix error checking of irq_of_parse_and_map()
  (bsc#1012628).
- net: korina: handle clk prepare error in korina_probe()
  (bsc#1012628).
- net: netsec: Ignore 'phy-mode' on SynQuacer in DT mode
  (bsc#1012628).
- selftest: net: Assert on a proper value in so_incoming_cpu.c
  (bsc#1012628).
- bnxt_en: Fix page pool logic for page size >= 64K (bsc#1012628).
- bnxt_en: Fix max_mtu setting for multi-buf XDP (bsc#1012628).
- net: dcb: choose correct policy to parse DCB_ATTR_BCN
  (bsc#1012628).
- s390/qeth: Don't call dev_close/dev_open (DOWN/UP)
  (bsc#1012628).
- ip6mr: Fix skb_under_panic in ip6mr_cache_report()
  (bsc#1012628).
- vxlan: Fix nexthop hash size (bsc#1012628).
- net/mlx5: fs_core: Make find_closest_ft more generic
  (bsc#1012628).
- net/mlx5: fs_core: Skip the FTs in the same FS_TYPE_PRIO_CHAINS
  fs_prio (bsc#1012628).
- net/mlx5e: Set proper IPsec source port in L4 selector
  (bsc#1012628).
- prestera: fix fallback to previous version on same major version
  (bsc#1012628).
- tcp_metrics: fix addr_same() helper (bsc#1012628).
- tcp_metrics: annotate data-races around tm->tcpm_stamp
  (bsc#1012628).
- tcp_metrics: annotate data-races around tm->tcpm_lock
  (bsc#1012628).
- tcp_metrics: annotate data-races around tm->tcpm_vals[]
  (bsc#1012628).
- tcp_metrics: annotate data-races around tm->tcpm_net
  (bsc#1012628).
- tcp_metrics: fix data-race in tcpm_suck_dst() vs fastopen
  (bsc#1012628).
- test/vsock: remove vsock_perf executable on `make clean`
  (bsc#1012628).
- rust: allocator: Prevent mis-aligned allocation (bsc#1012628).
- scsi: zfcp: Defer fc_rport blocking until after ADISC response
  (bsc#1012628).
- scsi: storvsc: Limit max_sectors for virtual Fibre Channel
  devices (bsc#1012628).
- Documentation: kdump: Add va_kernel_pa_offset for RISCV64
  (bsc#1012628).
- libceph: fix potential hang in ceph_osdc_notify() (bsc#1012628).
- USB: zaurus: Add ID for A-300/B-500/C-700 (bsc#1012628).
- ceph: defer stopping mdsc delayed_work (bsc#1012628).
- firmware: arm_scmi: Drop OF node reference in the transport
  channel setup (bsc#1012628).
- exfat: use kvmalloc_array/kvfree instead of kmalloc_array/kfree
  (bsc#1012628).
- exfat: check if filename entries exceeds max filename length
  (bsc#1012628).
- exfat: release s_lock before calling dir_emit() (bsc#1012628).
- mtd: spinand: toshiba: Fix ecc_get_status (bsc#1012628).
- mtd: spinand: winbond: Fix ecc_get_status (bsc#1012628).
- mtd: rawnand: meson: fix OOB available bytes for ECC
  (bsc#1012628).
- riscv: Export va_kernel_pa_offset in vmcoreinfo (bsc#1012628).
- bpf: Disable preemption in bpf_perf_event_output (bsc#1012628).
- arm64: dts: stratix10: fix incorrect I2C property for SCL signal
  (bsc#1012628).
- wifi: mt76: mt7615: do not advertise 5 GHz on first phy of
  MT7615D (DBDC) (bsc#1012628).
- x86/hyperv: Disable IBT when hypercall page lacks ENDBR
  instruction (bsc#1012628).
- rbd: prevent busy loop when requesting exclusive lock
  (bsc#1012628).
- bpf: Disable preemption in bpf_event_output (bsc#1012628).
- smb: client: fix dfs link mount against w2k8 (bsc#1012628).
- powerpc/ftrace: Create a dummy stackframe to fix stack unwind
  (bsc#1012628).
- parisc/mm: preallocate fixmap page tables at init (bsc#1012628).
- arm64/fpsimd: Sync and zero pad FPSIMD state for streaming SVE
  (bsc#1012628).
- arm64/fpsimd: Clear SME state in the target task when setting
  the VL (bsc#1012628).
- arm64/fpsimd: Sync FPSIMD state with SVE for SME only systems
  (bsc#1012628).
- arm64/ptrace: Flush FP state when setting ZT0 (bsc#1012628).
- arm64/ptrace: Don't enable SVE when setting streaming SVE
  (bsc#1012628).
- open: make RESOLVE_CACHED correctly test for O_TMPFILE
  (bsc#1012628).
- drm/ttm: check null pointer before accessing when swapping
  (bsc#1012628).
- drm/i915: Fix premature release of request's reusable memory
  (bsc#1012628).
- drm/i915/gt: Cleanup aux invalidation registers (bsc#1012628).
- Revert "page cache: fix page_cache_next/prev_miss off by one"
  (bsc#1012628).
- sunvnet: fix sparc64 build error after gso code split
  (bsc#1012628).
- clk: imx93: Propagate correct error in imx93_clocks_probe()
  (bsc#1012628).
- file: reinstate f_pos locking optimization for regular files
  (bsc#1012628).
- mm: kmem: fix a NULL pointer dereference in
  obj_stock_flush_required() (bsc#1012628).
- fs/ntfs3: Use __GFP_NOWARN allocation at ntfs_load_attr_list()
  (bsc#1012628).
- kasan,kmsan: remove __GFP_KSWAPD_RECLAIM usage from kasan/kmsan
  (bsc#1012628).
- fs/sysv: Null check to prevent null-ptr-deref bug (bsc#1012628).
- Bluetooth: L2CAP: Fix use-after-free in l2cap_sock_ready_cb
  (bsc#1012628).
- debugobjects: Recheck debug_objects_enabled before reporting
  (bsc#1012628).
- net: usbnet: Fix WARNING in usbnet_start_xmit/usb_submit_urb
  (bsc#1012628).
- fs: Protect reconfiguration of sb read-write from racing writes
  (bsc#1012628).
- mm/gup: do not return 0 from pin_user_pages_fast() for bad args
  (bsc#1012628).
- ext2: Drop fragment support (bsc#1012628).
- btrfs: remove BUG_ON()'s in add_new_free_space() (bsc#1012628).
- f2fs: fix to do sanity check on direct node in truncate_dnode()
  (bsc#1012628).
- io_uring: annotate offset timeout races (bsc#1012628).
- mtd: rawnand: omap_elm: Fix incorrect type in assignment
  (bsc#1012628).
- mtd: rawnand: rockchip: fix oobfree offset and description
  (bsc#1012628).
- mtd: rawnand: rockchip: Align hwecc vs. raw page helper layouts
  (bsc#1012628).
- clk: mediatek: mt8183: Add back SSPM related clocks
  (bsc#1012628).
- mtd: spi-nor: avoid holes in struct spi_mem_op (bsc#1012628).
- mtd: rawnand: fsl_upm: Fix an off-by one test in fun_exec_op()
  (bsc#1012628).
- powerpc/mm/altmap: Fix altmap boundary check (bsc#1012628).
- drm/imx/ipuv3: Fix front porch adjustment upon hactive aligning
  (bsc#1012628).
- drm/amdgpu: Use apt name for FW reserved region (bsc#1012628).
- selftests/rseq: Play nice with binaries statically linked
  against glibc 2.35+ (bsc#1012628).
- ARM: dts: nxp/imx6sll: fix wrong property name in usbphy node
  (bsc#1012628).
- drm/i915: Add the gen12_needs_ccs_aux_inv helper (bsc#1012628).
- drm/i915/gt: Ensure memory quiesced before invalidation
  (bsc#1012628).
- drm/i915/gt: Add workaround 14016712196 (bsc#1012628).
- drm/i915/gt: Rename flags with bit_group_X according to the
  datasheet (bsc#1012628).
- drm/i915/gt: Poll aux invalidation register bit on invalidation
  (bsc#1012628).
- drm/i915/gt: Support aux invalidation on all engines
  (bsc#1012628).
- drm/i915/gt: Enable the CCS_FLUSH bit in the pipe control and
  in the CS (bsc#1012628).
- x86/CPU/AMD: Do not leak quotient data after a division by 0
  (bsc#1012628).
- commit eb77301
* Sat Aug 12 2023 tiwai@suse.de
- drm/amd: Disable S/G for APUs when 64GB or more host memory
  (bsc#1213787).
- commit 1b8ce3e
* Sat Aug 12 2023 tiwai@suse.de
- pinctrl: amd: Don't show `Invalid config param` errors
  (bsc#1214212).
- commit bc782ff
* Fri Aug 11 2023 ematsumiya@suse.de
- Update config files. Unset CONFIG_SMB_SERVER* (jsc#PED-5484)
- commit 35aaffa
* Fri Aug 11 2023 ddiss@suse.de
- exfat: check if filename entries exceeds max filename length
  (bsc#1214120 CVE-2023-4273).
- commit 58952f2
* Fri Aug 11 2023 tiwai@suse.de
- supported.conf: add brcmfmac-* modules as supported (bsc#1214193)
- commit 8dab9db
* Fri Aug 11 2023 vkarasulli@suse.de
- net/sched: cls_route: No longer copy tcf_result on update  to
  avoid use-after-free (bsc#1214149 CVE-2023-4128).
- net/sched: cls_fw: No longer copy tcf_result on update to
  avoid use-after-free (bsc#1214149 CVE-2023-4128).
- net/sched: cls_u32: No longer copy tcf_result on update  to
  avoid use-after-free (bsc#1214149 CVE-2023-4128).
- commit 4368d3a
* Fri Aug 11 2023 tiwai@suse.de
- Revert "drm/nouveau/disp: PIOR DP uses GPIO for HPD, not PMGR
  AUX interrupts" (bsc#1214073).
- commit db7e8f0
* Fri Aug 11 2023 tiwai@suse.de
- tpm/tpm_tis: Disable interrupts categorically for Lenovo
  (bsc#1213779).
  Replaced the obsoleted fix patch:
  patches.suse/tpm-tpm_tis-Disable-interrupts-for-Lenovo-Thinkpad-E.patch
- commit efae9ac
* Fri Aug 11 2023 tiwai@suse.de
- tpm/tpm_tis: Disable interrupts for Lenovo P620 devices
  (bsc#1213779).
- commit 4f44748
* Fri Aug 11 2023 tiwai@suse.de
- Move upstreamed tpm_tis patch into sorted section
- commit 693df97
* Thu Aug 10 2023 jslaby@suse.cz
- mm: lock_vma_under_rcu() must check vma->anon_vma under vma lock
  (per-VMA_lock_fix).
- commit c5c7c45
* Thu Aug 10 2023 jslaby@suse.cz
- ACPI: resource: Honor MADT INT_SRC_OVR settings for IRQ1 on
  AMD Zen (20230809085526.84913-1-hdegoede@redhat.com).
- ACPI: resource: Always use MADT override
  IRQ settings for all legacy non i8042 IRQs
  (20230809085526.84913-1-hdegoede@redhat.com).
- ACPI: resource: revert "Remove "Zen" specific match and quirks"
  (20230809085526.84913-1-hdegoede@redhat.com).
- commit 17e449f
* Wed Aug  9 2023 rgoldwyn@suse.com
- supported.conf: mark reiserfs, hfsplus, quota_v1 and ufs as unsupported
  fs/ufs/ufs was marked as supported during merge commit
  37695a7d6d2 ("supported.conf: Update from SLE15-SP5")
- commit 07f332c
* Wed Aug  9 2023 jslaby@suse.cz
- Linux 6.4.9 (bsc#1012628).
- Update config files.
  Set:
  * CONFIG_GDS_FORCE_MITIGATION=n
  * CONFIG_CPU_SRSO=y
  as per default.
- x86: fix backwards merge of GDS/SRSO bit (bsc#1012628).
- xen/netback: Fix buffer overrun triggered by unusual packet
  (bsc#1012628).
- x86/srso: Tie SBPB bit setting to microcode patch detection
  (bsc#1012628).
- x86/srso: Add a forgotten NOENDBR annotation (bsc#1012628).
- x86/srso: Fix return thunks in generated code (bsc#1012628).
- x86/srso: Add IBPB on VMEXIT (bsc#1012628).
- x86/srso: Add IBPB (bsc#1012628).
- x86/srso: Add SRSO_NO support (bsc#1012628).
- x86/srso: Add IBPB_BRTYPE support (bsc#1012628).
- x86/srso: Add a Speculative RAS Overflow mitigation (bsc#1012628
  bsc#1213287 CVE-2023-20569).
- x86/bugs: Increase the x86 bugs vector size to two u32s
  (bsc#1012628).
- Documentation/x86: Fix backwards on/off logic about YMM support
  (bsc#1012628).
- x86/xen: Fix secondary processors' FPU initialization
  (bsc#1012628).
- x86/mem_encrypt: Unbreak the AMD_MEM_ENCRYPT=n build
  (bsc#1012628).
- KVM: Add GDS_NO support to KVM (bsc#1012628).
- x86/speculation: Add Kconfig option for GDS (bsc#1012628).
- x86/speculation: Add force option to GDS mitigation
  (bsc#1012628).
- x86/speculation: Add Gather Data Sampling mitigation
  (bsc#1012628 bsc#1206418 CVE-2022-40982).
- x86/fpu: Move FPU initialization into arch_cpu_finalize_init()
  (bsc#1012628).
- x86/fpu: Mark init functions __init (bsc#1012628).
- x86/fpu: Remove cpuinfo argument from init functions
  (bsc#1012628).
- x86/init: Initialize signal frame size late (bsc#1012628).
- init, x86: Move mem_encrypt_init() into arch_cpu_finalize_init()
  (bsc#1012628).
- init: Invoke arch_cpu_finalize_init() earlier (bsc#1012628).
- init: Remove check_bugs() leftovers (bsc#1012628).
- um/cpu: Switch to arch_cpu_finalize_init() (bsc#1012628).
- sparc/cpu: Switch to arch_cpu_finalize_init() (bsc#1012628).
- sh/cpu: Switch to arch_cpu_finalize_init() (bsc#1012628).
- mips/cpu: Switch to arch_cpu_finalize_init() (bsc#1012628).
- m68k/cpu: Switch to arch_cpu_finalize_init() (bsc#1012628).
- loongarch/cpu: Switch to arch_cpu_finalize_init() (bsc#1012628).
- ia64/cpu: Switch to arch_cpu_finalize_init() (bsc#1012628).
- ARM: cpu: Switch to arch_cpu_finalize_init() (bsc#1012628).
- x86/cpu: Switch to arch_cpu_finalize_init() (bsc#1012628).
- init: Provide arch_cpu_finalize_init() (bsc#1012628).
- commit 5b9ad20
* Tue Aug  8 2023 tiwai@suse.de
- rpm/config.sh: update OBS_PROJECT pointing to ALP target
- commit d928fc3
* Mon Aug  7 2023 tiwai@suse.de
- tpm/tpm_tis: Disable interrupts for Lenovo Thinkpad E14 Gen
  2 and 13s-IML (bsc#1213779).
- commit c4adffc
* Mon Aug  7 2023 mfranc@suse.cz
- net: tun_chr_open(): set sk_uid from current_fsuid()
  (CVE-2023-4194 bsc#1214019).
- commit 8967829
* Mon Aug  7 2023 mfranc@suse.cz
- net: tap_open(): set sk_uid from current_fsuid() (CVE-2023-4194
  bsc#1214019).
- commit e5a2ecb
* Mon Aug  7 2023 tiwai@suse.de
- drm/amd/display: Fix a regression on Polaris cards
  (bsc#1212874).
- commit 9764e05
* Mon Aug  7 2023 jslaby@suse.cz
- rpm/config.sh: remove IBS repos completely
  The commit 21cafd1f (rpm/config.sh: switch to openSUSE.org repos for
  IBS) duplicated the OBS repos in openSUSE.org: space. But this is done
  automatically in MyBS.pm. So drop all of them instead of duplicating.
- commit 294d541
* Fri Aug  4 2023 jslaby@suse.cz
- rpm/config.sh: switch to openSUSE.org repos for IBS
  SUSE:Factory:HEAD is currently (and often) broken. Switch to
  openSUSE.org: repositories. They are up-to-date and provide the same
  archs plus armv6.
- commit 21cafd1
* Thu Aug  3 2023 jslaby@suse.cz
- Linux 6.4.8 (bsc#1012628).
- platform/x86/amd/pmf: Notify OS power slider update
  (bsc#1012628).
- platform/x86/amd/pmf: reduce verbosity of apmf_get_system_params
  (bsc#1012628).
- drm/amd: Move helper for dynamic speed switch check out of smu13
  (bsc#1012628).
- drm/amd: Align SMU11 SMU_MSG_OverridePcieParameters
  implementation with SMU13 (bsc#1012628).
- jbd2: Fix wrongly judgement for buffer head removing while
  doing checkpoint (bsc#1012628).
- KVM: arm64: Handle kvm_arm_init failure correctly in
  finalize_pkvm (bsc#1012628).
- blk-mq: Fix stall due to recursive flush plug (bsc#1012628).
- powerpc/pseries/vas: Hold mmap_mutex after mmap lock during
  window close (bsc#1012628).
- KVM: s390: pv: simplify shutdown and fix race (bsc#1012628).
- KVM: s390: pv: fix index value of replaced ASCE (bsc#1012628).
- s390/mm: fix per vma lock fault handling (bsc#1012628).
- io_uring: don't audit the capability check in io_uring_create()
  (bsc#1012628).
- gpio: tps68470: Make tps68470_gpio_output() always set the
  initial value (bsc#1012628).
- gpio: mvebu: Make use of devm_pwmchip_add (bsc#1012628).
- gpio: mvebu: fix irq domain leak (bsc#1012628).
- regmap: Disable locking for RBTREE and MAPLE unit tests
  (bsc#1012628).
- btrfs: factor out a btrfs_verify_page helper (bsc#1012628).
- btrfs: fix fsverify read error handling in end_page_read
  (bsc#1012628).
- btrfs: fix race between quota disable and relocation
  (bsc#1012628).
- i2c: Delete error messages for failed memory allocations
  (bsc#1012628).
- i2c: Improve size determinations (bsc#1012628).
- i2c: nomadik: Remove unnecessary goto label (bsc#1012628).
- i2c: nomadik: Use devm_clk_get_enabled() (bsc#1012628).
- i2c: nomadik: Remove a useless call in the remove function
  (bsc#1012628).
- PCI/ASPM: Return 0 or -ETIMEDOUT from pcie_retrain_link()
  (bsc#1012628).
- PCI/ASPM: Factor out pcie_wait_for_retrain() (bsc#1012628).
- PCI/ASPM: Avoid link retraining race (bsc#1012628).
- PCI: rockchip: Remove writes to unused registers (bsc#1012628).
- PCI: rockchip: Fix window mapping and address translation for
  endpoint (bsc#1012628).
- PCI: rockchip: Don't advertise MSI-X in PCIe capabilities
  (bsc#1012628).
- drm/amd/display: Convert Delaying Aux-I Disable To Monitor Patch
  (bsc#1012628).
- drm/amd/display: Keep disable aux-i delay as 0 (bsc#1012628).
- drm/amd/display: add pixel rate based CRB allocation support
  (bsc#1012628).
- drm/amd/display: fix dcn315 single stream crb allocation
  (bsc#1012628).
- drm/amd/display: Update correct DCN314 register header
  (bsc#1012628).
- drm/amd/display: Set minimum requirement for using PSR-SU on
  Rembrandt (bsc#1012628).
- drm/amd/display: Set minimum requirement for using PSR-SU on
  Phoenix (bsc#1012628).
- drm/ttm: never consider pinned BOs for eviction&swap
  (bsc#1012628).
- maple_tree: add __init and __exit to test module (bsc#1012628).
- maple_tree: fix 32 bit mas_next testing (bsc#1012628).
- drm/amd/display: Add FAMS validation before trying to use it
  (bsc#1012628).
- drm/amd/display: update extended blank for dcn314 onwards
  (bsc#1012628).
- drm/amd/display: Fix possible underflow for displays with
  large vblank (bsc#1012628).
- drm/amd/display: Prevent vtotal from being set to 0
  (bsc#1012628).
- ext4: add EXT4_MB_HINT_GOAL_ONLY test in
  ext4_mb_use_preallocated (bsc#1012628).
- ext4: mballoc: Remove useless setting of ac_criteria
  (bsc#1012628).
- ext4: fix rbtree traversal bug in ext4_mb_use_preallocated
  (bsc#1012628).
- phy: phy-mtk-dp: Fix an error code in probe() (bsc#1012628).
- phy: mediatek: hdmi: mt8195: fix prediv bad upper limit test
  (bsc#1012628).
- phy: qcom-snps-femto-v2: keep cfg_ahb_clk enabled during
  runtime suspend (bsc#1012628).
- phy: qcom-snps-femto-v2: properly enable ref clock
  (bsc#1012628).
- soundwire: qcom: update status correctly with mask
  (bsc#1012628).
- soundwire: amd: Fix a check for errors in probe() (bsc#1012628).
- media: tc358746: Address compiler warnings (bsc#1012628).
- media: staging: atomisp: select V4L2_FWNODE (bsc#1012628).
- media: amphion: Fix firmware path to match linux-firmware
  (bsc#1012628).
- media: mtk-jpeg: move data/code inside CONFIG_OF blocks
  (bsc#1012628).
- media: mtk_jpeg_core: avoid unused-variable warning
  (bsc#1012628).
- i40e: Fix an NULL vs IS_ERR() bug for debugfs_create_dir()
  (bsc#1012628).
- iavf: fix potential deadlock on allocation failure
  (bsc#1012628).
- iavf: check for removal state before IAVF_FLAG_PF_COMMS_FAILED
  (bsc#1012628).
- net: phy: marvell10g: fix 88x3310 power up (bsc#1012628).
- net: hns3: fix the imp capability bit cannot exceed 32 bits
  issue (bsc#1012628).
- net: hns3: fix wrong tc bandwidth weight data issue
  (bsc#1012628).
- net: hns3: fix wrong bw weight of disabled tc issue
  (bsc#1012628).
- vxlan: calculate correct header length for GPE (bsc#1012628).
- vxlan: generalize vxlan_parse_gpe_hdr and remove unused args
  (bsc#1012628).
- vxlan: fix GRO with VXLAN-GPE (bsc#1012628).
- phy: hisilicon: Fix an out of bounds check in
  hisi_inno_phy_probe() (bsc#1012628).
- atheros: fix return value check in atl1_tso() (bsc#1012628).
- ethernet: atheros: fix return value check in atl1e_tso_csum()
  (bsc#1012628).
- ipv6 addrconf: fix bug where deleting a mngtmpaddr can create
  a new temporary address (bsc#1012628).
- net: fec: avoid tx queue timeout when XDP is enabled
  (bsc#1012628).
- tcp: Reduce chance of collisions in inet6_hashfn()
  (bsc#1012628).
- ice: Fix memory management in ice_ethtool_fdir.c (bsc#1012628).
- bonding: reset bond's flags when down link is P2P device
  (bsc#1012628).
- team: reset team's flags when down link is P2P device
  (bsc#1012628).
- octeontx2-af: Fix hash extraction enable configuration
  (bsc#1012628).
- net: stmmac: Apply redundant write work around on 4.xx too
  (bsc#1012628).
- platform/x86: msi-laptop: Fix rfkill out-of-sync on MSI Wind
  U100 (bsc#1012628).
- x86/traps: Fix load_unaligned_zeropad() handling for shared
  TDX memory (bsc#1012628).
- macvlan: add forgotten nla_policy for IFLA_MACVLAN_BC_CUTOFF
  (bsc#1012628).
- igc: Fix Kernel Panic during ndo_tx_timeout callback
  (bsc#1012628).
- netfilter: nft_set_rbtree: fix overlap expiration walk
  (bsc#1012628).
- netfilter: nf_tables: skip immediate deactivate in
  _PREPARE_ERROR (bsc#1012628).
- netfilter: nf_tables: disallow rule addition to bound chain
  via NFTA_RULE_CHAIN_ID (bsc#1012628).
- mm: suppress mm fault logging if fatal signal already pending
  (bsc#1012628).
- tools: ynl-gen: fix enum index in
  _decode_enum(..) (bsc#1012628).
- net: fec: tx processing does not call XDP APIs if budget is 0
  (bsc#1012628).
- net/sched: mqprio: Add length check for
  TCA_MQPRIO_{MAX/MIN}_RATE64 (bsc#1012628).
- benet: fix return value check in be_lancer_xmit_workarounds()
  (bsc#1012628).
- tipc: check return value of pskb_trim() (bsc#1012628).
- tipc: stop tipc crypto on failure in tipc_node_create
  (bsc#1012628).
- fs/9p: Fix a datatype used with V9FS_DIRECT_IO (bsc#1012628).
- RDMA/mlx4: Make check for invalid flags stricter (bsc#1012628).
- drm/msm/mdss: correct UBWC programming for SM8550 (bsc#1012628).
- drm/msm/dpu: add missing flush and fetch bits for DMA4/DMA5
  planes (bsc#1012628).
- drm/msm/dpu: drop enum dpu_core_perf_data_bus_id (bsc#1012628).
- drm/msm/dsi: Drop unused regulators from QCM2290 14nm DSI PHY
  config (bsc#1012628).
- drm/msm/adreno: Fix snapshot BINDLESS_DATA size (bsc#1012628).
- RDMA/irdma: Add missing read barriers (bsc#1012628).
- RDMA/irdma: Fix data race on CQP completion stats (bsc#1012628).
- RDMA/irdma: Fix data race on CQP request done (bsc#1012628).
- RDMA/core: Update CMA destination address on rdma_resolve_addr
  (bsc#1012628).
- RDMA/mthca: Fix crash when polling CQ for shared QPs
  (bsc#1012628).
- RDMA/bnxt_re: Prevent handling any completions after qp destroy
  (bsc#1012628).
- RDMA/bnxt_re: Enhance the existing functions that wait for FW
  responses (bsc#1012628).
- RDMA/bnxt_re: Avoid the command wait if firmware is inactive
  (bsc#1012628).
- RDMA/bnxt_re: use shadow qd while posting non blocking rcfw
  command (bsc#1012628).
- RDMA/bnxt_re: Simplify the function that sends the FW commands
  (bsc#1012628).
- RDMA/bnxt_re: add helper function __poll_for_resp (bsc#1012628).
- RDMA/bnxt_re: Fix hang during driver unload (bsc#1012628).
- drm/msm: Fix IS_ERR_OR_NULL() vs NULL check in
  a5xx_submit_in_rb() (bsc#1012628).
- drm/msm: Fix hw_fence error path cleanup (bsc#1012628).
- cxl/acpi: Fix a use-after-free in cxl_parse_cfmws()
  (bsc#1012628).
- cxl/acpi: Return 'rc' instead of '0' in cxl_parse_cfmws()
  (bsc#1012628).
- ASoC: fsl_spdif: Silence output on stop (bsc#1012628).
- block: Fix a source code comment in
  include/uapi/linux/blkzoned.h (bsc#1012628).
- smb3: do not set NTLMSSP_VERSION flag for negotiate not auth
  request (bsc#1012628).
- drm/i915: Fix an error handling path in igt_write_huge()
  (bsc#1012628).
- xenbus: check xen_domain in xenbus_probe_initcall (bsc#1012628).
- dm raid: fix missing reconfig_mutex unlock in raid_ctr()
  error paths (bsc#1012628).
- dm raid: clean up four equivalent goto tags in raid_ctr()
  (bsc#1012628).
- dm raid: protect md_stop() with 'reconfig_mutex' (bsc#1012628).
- drm/amd: Fix an error handling mistake in psp_sw_init()
  (bsc#1012628).
- drm/amd/display: Unlock on error path in
  dm_handle_mst_sideband_msg_ready_event() (bsc#1012628).
- RDMA/irdma: Fix op_type reporting in CQEs (bsc#1012628).
- RDMA/irdma: Report correct WC error (bsc#1012628).
- drm/msm: Disallow submit with fence id 0 (bsc#1012628).
- ublk: fail to start device if queue setup is interrupted
  (bsc#1012628).
- ublk: fail to recover device if queue setup is interrupted
  (bsc#1012628).
- ublk: return -EINTR if breaking from waiting for existed users
  in DEL_DEV (bsc#1012628).
- iommufd: IOMMUFD_DESTROY should not increase the refcount
  (bsc#1012628).
- tmpfs: fix Documentation of noswap and huge mount options
  (bsc#1012628).
- ata: pata_ns87415: mark ns87560_tf_read static (bsc#1012628).
- ring-buffer: Fix wrong stat of cpu_buffer->read (bsc#1012628).
- tracing: Fix warning in trace_buffered_event_disable()
  (bsc#1012628).
- Revert "usb: gadget: tegra-xudc: Fix error check in
  tegra_xudc_powerdomain_init()" (bsc#1012628).
- usb: gadget: call usb_gadget_check_config() to verify UDC
  capability (bsc#1012628).
- USB: gadget: Fix the memory leak in raw_gadget driver
  (bsc#1012628).
- usb: gadget: core: remove unbalanced mutex_unlock in
  usb_gadget_activate (bsc#1012628).
- KVM: Grab a reference to KVM for VM and vCPU stats file
  descriptors (bsc#1012628).
- KVM: VMX: Don't fudge CR0 and CR4 for restricted L2 guest
  (bsc#1012628).
- KVM: x86: Disallow KVM_SET_SREGS{2} if incoming CR0 is invalid
  (bsc#1012628).
- serial: qcom-geni: drop bogus runtime pm state update
  (bsc#1012628).
- tty: serial: sh-sci: Fix sleeping in atomic context
  (bsc#1012628).
- serial: 8250_dw: Preserve original value of DLF register
  (bsc#1012628).
- serial: sifive: Fix sifive_serial_console_setup() section
  (bsc#1012628).
- USB: serial: option: support Quectel EM060K_128 (bsc#1012628).
- USB: serial: option: add Quectel EC200A module support
  (bsc#1012628).
- USB: serial: simple: add Kaufmann RKS+CAN VCP (bsc#1012628).
- USB: serial: simple: sort driver entries (bsc#1012628).
- can: gs_usb: gs_can_close(): add missing set of CAN state to
  CAN_STATE_STOPPED (bsc#1012628).
- TIOCSTI: always enable for CAP_SYS_ADMIN (bsc#1012628).
- usb: typec: Set port->pd before adding device for typec_port
  (bsc#1012628).
- usb: typec: Iterate pds array when showing the pd list
  (bsc#1012628).
- usb: typec: Use sysfs_emit_at when concatenating the string
  (bsc#1012628).
- Revert "usb: dwc3: core: Enable AutoRetry feature in the
  controller" (bsc#1012628).
- usb: dwc3: pci: skip BYT GPIO lookup table for hardwired phy
  (bsc#1012628).
- usb: dwc3: don't reset device side if dwc3 was configured as
  host-only (bsc#1012628).
- usb: misc: ehset: fix wrong if condition (bsc#1012628).
- usb: ohci-at91: Fix the unhandle interrupt when resume
  (bsc#1012628).
- USB: quirks: add quirk for Focusrite Scarlett (bsc#1012628).
- usb: cdns3: fix incorrect calculation of ep_buf_size when more
  than one config (bsc#1012628).
- usb: xhci-mtk: set the dma max_seg_size (bsc#1012628).
- Revert "usb: xhci: tegra: Fix error check" (bsc#1012628).
- Documentation: security-bugs.rst: update preferences when
  dealing with the linux-distros group (bsc#1012628).
- Documentation: security-bugs.rst: clarify CVE handling
  (bsc#1012628).
- staging: r8712: Fix memory leak in _r8712_init_xmit_priv()
  (bsc#1012628).
- staging: ks7010: potential buffer overflow in
  ks_wlan_set_encode_ext() (bsc#1012628).
- tty: n_gsm: fix UAF in gsm_cleanup_mux (bsc#1012628).
- Revert "xhci: add quirk for host controllers that don't update
  endpoint DCS" (bsc#1012628).
- ALSA: hda/realtek: Support ASUS G713PV laptop (bsc#1012628).
- ALSA: hda/relatek: Enable Mute LED on HP 250 G8 (bsc#1012628).
- hwmon: (k10temp) Enable AMD3255 Proc to show negative
  temperature (bsc#1012628).
- hwmon: (nct7802) Fix for temp6 (PECI1) processed even if PECI1
  disabled (bsc#1012628).
- hwmon: (aquacomputer_d5next) Fix incorrect PWM value readout
  (bsc#1012628).
- hwmon: (pmbus_core) Fix pmbus_is_enabled() (bsc#1012628).
- hwmon: (pmbus_core) Fix NULL pointer dereference (bsc#1012628).
- hwmon: (pmbus_core) Fix Deadlock in pmbus_regulator_get_status
  (bsc#1012628).
- btrfs: zoned: do not enable async discard (bsc#1012628).
- btrfs: account block group tree when calculating global reserve
  size (bsc#1012628).
- btrfs: check if the transaction was aborted at
  btrfs_wait_for_commit() (bsc#1012628).
- btrfs: check for commit error at
  btrfs_attach_transaction_barrier() (bsc#1012628).
- x86/MCE/AMD: Decrement threshold_bank refcount when removing
  threshold blocks (bsc#1012628).
- x86/cpu: Enable STIBP on AMD if Automatic IBRS is enabled
  (bsc#1012628).
- file: always lock position for FMODE_ATOMIC_POS (bsc#1012628).
- nfsd: Remove incorrect check in nfsd4_validate_stateid
  (bsc#1012628).
- ksmbd: check if a mount point is crossed during path lookup
  (bsc#1012628).
- ACPI/IORT: Remove erroneous id_count check in
  iort_node_get_rmr_info() (bsc#1012628).
- tpm_tis: Explicitly check for error code (bsc#1012628).
- irq-bcm6345-l1: Do not assume a fixed block to cpu mapping
  (bsc#1012628).
- irqchip/gic-v4.1: Properly lock VPEs when doing a directLPI
  invalidation (bsc#1012628).
- locking/rtmutex: Fix task->pi_waiters integrity (bsc#1012628).
- proc/vmcore: fix signedness bug in read_from_oldmem()
  (bsc#1012628).
- xen: speed up grant-table reclaim (bsc#1012628).
- virtio-net: fix race between set queues and probe (bsc#1012628).
- net: ipa: only reset hashed tables when supported (bsc#1012628).
- net: dsa: qca8k: enable use_single_write for qca8xxx
  (bsc#1012628).
- net: dsa: qca8k: fix search_and_insert wrong handling of new
  rule (bsc#1012628).
- net: dsa: qca8k: fix broken search_and_del (bsc#1012628).
- net: dsa: qca8k: fix mdb add/del case with 0 VID (bsc#1012628).
- io_uring: gate iowait schedule on having pending requests
  (bsc#1012628).
- iommufd: Set end correctly when doing batch carry (bsc#1012628).
- selftests: mptcp: join: only check for ip6tables if needed
  (bsc#1012628).
- soundwire: fix enumeration completion (bsc#1012628).
- Revert "um: Use swap() to make code cleaner" (bsc#1012628).
- LoongArch: Fix return value underflow in exception path
  (bsc#1012628).
- LoongArch: BPF: Fix check condition to call lu32id in move_imm()
  (bsc#1012628).
- LoongArch: BPF: Enable bpf_probe_read{, str}() on LoongArch
  (bsc#1012628).
- 9p: fix ignored return value in v9fs_dir_release (bsc#1012628).
- fs/9p: remove unnecessary and overrestrictive check
  (bsc#1012628).
- fs/9p: fix typo in comparison logic for cache mode
  (bsc#1012628).
- fs/9p: fix type mismatch in file cache mode helper
  (bsc#1012628).
- fs/9p: remove unnecessary invalidate_inode_pages2 (bsc#1012628).
- s390/dasd: fix hanging device after quiesce/resume
  (bsc#1012628).
- s390/dasd: print copy pair message only for the correct error
  (bsc#1012628).
- mptcp: more accurate NL event generation (bsc#1012628).
- ASoC: wm8904: Fill the cache for WM8904_ADC_TEST_0 register
  (bsc#1012628).
- arm64/sme: Set new vector length before reallocating
  (bsc#1012628).
- PM: sleep: wakeirq: fix wake irq arming (bsc#1012628).
- thermal: of: fix double-free on unregistration (bsc#1012628).
- ceph: never send metrics if disable_send_metrics is set
  (bsc#1012628).
- drm/i915/dpt: Use shmem for dpt objects (bsc#1012628).
- dm cache policy smq: ensure IO doesn't prevent cleaner policy
  progress (bsc#1012628).
- rbd: make get_lock_owner_info() return a single locker or NULL
  (bsc#1012628).
- rbd: harden get_lock_owner_info() a bit (bsc#1012628).
- rbd: retrieve and check lock owner twice before blocklisting
  (bsc#1012628).
- mm: lock VMA in dup_anon_vma() before setting ->anon_vma
  (bsc#1012628).
- mm: fix memory ordering for mm_lock_seq and vm_lock_seq
  (bsc#1012628).
- mm/memory-failure: fix hardware poison check in
  unpoison_memory() (bsc#1012628).
- mm/mempolicy: Take VMA lock before replacing policy
  (bsc#1012628).
- dma-buf: keep the signaling time of merged fences v3
  (bsc#1012628).
- dma-buf: fix an error pointer vs NULL bug (bsc#1012628).
- commit c24ac79
* Tue Aug  1 2023 jslaby@suse.cz
- Refresh
  patches.suse/ALSA-usb-audio-Add-quirk-for-Microsoft-Modern-Wirele.patch.
  Update upstream status.
- commit cba3fa8
* Sun Jul 30 2023 tiwai@suse.de
- Revert "drm/edid: Fix csync detailed mode parsing"
  (bsc#1213693).
- commit 8de9301
* Fri Jul 28 2023 tiwai@suse.de
- Update MHI and ath11k hibernation fix patches (bsc#1207948)
  Upstream updated / cleaned up the patch set slightly
- commit 5da2543
* Fri Jul 28 2023 msuchanek@suse.de
- kernel-binary.spec.in: Remove superfluous %%%% in Supplements
  Fixes: 02b7735e0caf ("rpm/kernel-binary.spec.in: Add Enhances and Supplements tags to in-tree KMPs")
- commit 264db74
* Thu Jul 27 2023 tiwai@suse.de
- wifi: rtw89: Fix loading of compressed firmware (bsc#1212808).
- commit 79df9c7
* Thu Jul 27 2023 tiwai@suse.de
- ASoC: SOF: intel: hda: Clean up link DMA for IPC3 during stop
  (bsc#1213583).
- commit e67f54f
* Thu Jul 27 2023 jslaby@suse.cz
- Linux 6.4.7 (bsc#1012628).
- io_uring: treat -EAGAIN for REQ_F_NOWAIT as final for io-wq
  (bsc#1012628).
- ALSA: hda/realtek - remove 3k pull low procedure (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Clevo NS70AU (bsc#1012628).
- ALSA: hda/realtek: Enable Mute LED on HP Laptop 15s-eq2xxx
  (bsc#1012628).
- maple_tree: set the node limit when creating a new root node
  (bsc#1012628).
- mm/mlock: fix vma iterator conversion of apply_vma_lock_flags()
  (bsc#1012628).
- maple_tree: fix node allocation testing on 32 bit (bsc#1012628).
- selftests/mm: mkdirty: fix incorrect position of #endif
  (bsc#1012628).
- keys: Fix linking a duplicate key to a keyring's assoc_array
  (bsc#1012628).
- prctl: move PR_GET_AUXV out of PR_MCE_KILL (bsc#1012628).
- perf probe: Add test for regression introduced by switch to
  die_get_decl_file() (bsc#1012628).
- perf probe: Read DWARF files from the correct CU (bsc#1012628).
- btrfs: fix iput() on error pointer after error during orphan
  cleanup (bsc#1012628).
- btrfs: fix warning when putting transaction with qgroups
  enabled after abort (bsc#1012628).
- fuse: revalidate: don't invalidate if interrupted (bsc#1012628).
- fuse: add feature flag for expire-only (bsc#1012628).
- fuse: Apply flags2 only when userspace set the FUSE_INIT_EXT
  (bsc#1012628).
- btrfs: raid56: always verify the P/Q contents for scrub
  (bsc#1012628).
- btrfs: set_page_extent_mapped after read_folio in
  btrfs_cont_expand (bsc#1012628).
- btrfs: fix double iput() on inode after an error during orphan
  cleanup (bsc#1012628).
- btrfs: zoned: fix memory leak after finding block group with
  super blocks (bsc#1012628).
- fuse: ioctl: translate ENOSYS in outarg (bsc#1012628).
- btrfs: fix race between balance and cancel/pause (bsc#1012628).
- selftests: tc: set timeout to 15 minutes (bsc#1012628).
- accel/qaic: Fix a leak in map_user_pages() (bsc#1012628).
- selftests: tc: add 'ct' action kconfig dep (bsc#1012628).
- regmap: Drop initial version of maximum transfer length fixes
  (bsc#1012628).
- s390/zcrypt: fix reply buffer calculations for CCA replies
  (bsc#1012628).
- regmap: Account for register length in SMBus I/O limits
  (bsc#1012628).
- ia64: mmap: Consider pgoff when searching for free mapping
  (bsc#1012628).
- arm64/fpsimd: Ensure SME storage is allocated after SVE VL
  changes (bsc#1012628).
- can: mcp251xfd: __mcp251xfd_chip_set_mode(): increase poll
  timeout (bsc#1012628).
- can: bcm: Fix UAF in bcm_proc_show() (bsc#1012628).
- can: gs_usb: gs_can_open(): improve error handling
  (bsc#1012628).
- can: gs_usb: fix time stamp counter initialization
  (bsc#1012628).
- selftests: tc: add ConnTrack procfs kconfig (bsc#1012628).
- accel/qaic: tighten bounds checking in encode_message()
  (bsc#1012628).
- accel/qaic: tighten bounds checking in decode_message()
  (bsc#1012628).
- accel/qaic: Add consistent integer overflow checks
  (bsc#1012628).
- dma-buf/dma-resv: Stop leaking on krealloc() failure
  (bsc#1012628).
- drm/amdgpu/vkms: relax timer deactivation by
  hrtimer_try_to_cancel (bsc#1012628).
- drm/amdgpu/pm: make gfxclock consistent for sienna cichlid
  (bsc#1012628).
- drm/amdgpu/pm: make mclk consistent for smu 13.0.7
  (bsc#1012628).
- drm/nouveau/disp: PIOR DP uses GPIO for HPD, not PMGR AUX
  interrupts (bsc#1012628).
- drm/nouveau/kms/nv50-: init hpd_irq_lock for PIOR DP
  (bsc#1012628).
- drm/nouveau/i2c: fix number of aux event slots (bsc#1012628).
- drm/client: Fix memory leak in drm_client_target_cloned
  (bsc#1012628).
- drm/client: Fix memory leak in drm_client_modeset_probe
  (bsc#1012628).
- drm/amd/display: only accept async flips for fast updates
  (bsc#1012628).
- drm/amd/display: Disable MPC split by default on special asic
  (bsc#1012628).
- drm/amd/display: check TG is non-null before checking if enabled
  (bsc#1012628).
- drm/amd/display: Keep PHY active for DP displays on DCN31
  (bsc#1012628).
- ASoC: fsl_sai: Disable bit clock with transmitter (bsc#1012628).
- ASoC: fsl_sai: Revert "ASoC: fsl_sai: Enable MCTL_MCLK_EN bit
  for master mode" (bsc#1012628).
- ASoC: tegra: Fix ADX byte map (bsc#1012628).
- ASoC: rt5640: Fix sleep in atomic context (bsc#1012628).
- ASoC: cs42l51: fix driver to properly autoload with automatic
  module loading (bsc#1012628).
- ASoC: codecs: wcd938x: fix missing clsh ctrl error handling
  (bsc#1012628).
- ASoC: cs35l45: Select REGMAP_IRQ (bsc#1012628).
- ASoC: codecs: wcd-mbhc-v2: fix resource leaks on component
  remove (bsc#1012628).
- ASoC: qdsp6: audioreach: fix topology probe deferral
  (bsc#1012628).
- ASoC: tegra: Fix AMX byte map (bsc#1012628).
- ASoC: codecs: wcd938x: fix resource leaks on component remove
  (bsc#1012628).
- ASoC: codecs: wcd938x: fix missing mbhc init error handling
  (bsc#1012628).
- ASoC: codecs: wcd934x: fix resource leaks on component remove
  (bsc#1012628).
- ASoC: codecs: wcd938x: fix codec initialisation race
  (bsc#1012628).
- ASoC: codecs: wcd938x: fix soundwire initialisation race
  (bsc#1012628).
- KVM: arm64: timers: Use CNTHCTL_EL2 when setting non-CNTKCTL_EL1
  bits (bsc#1012628).
- KVM: arm64: Correctly handle page aging notifiers for unaligned
  memslot (bsc#1012628).
- KVM: arm64: Disable preemption in kvm_arch_hardware_enable()
  (bsc#1012628).
- KVM: arm64: vgic-v4: Make the doorbell request robust w.r.t
  preemption (bsc#1012628).
- ext4: correct inline offset when handling xattrs in inode body
  (bsc#1012628).
- drm/radeon: Fix integer overflow in radeon_cs_parser_init
  (bsc#1012628).
- ALSA: emu10k1: roll up loops in DSP setup code for Audigy
  (bsc#1012628).
- quota: Properly disable quotas when add_dquot_ref() fails
  (bsc#1012628).
- quota: fix warning in dqgrab() (bsc#1012628).
- HID: add quirk for 03f0:464a HP Elite Presenter Mouse
  (bsc#1012628).
- ovl: check type and offset of struct vfsmount in ovl_entry
  (bsc#1012628).
- udf: Fix uninitialized array access for some pathnames
  (bsc#1012628).
- ALSA: hda/realtek: Add quirks for ROG ALLY CS35l41 audio
  (bsc#1012628).
- fs: jfs: Fix UBSAN: array-index-out-of-bounds in dbAllocDmapLev
  (bsc#1012628).
- MIPS: dec: prom: Address -Warray-bounds warning (bsc#1012628).
- FS: JFS: Fix null-ptr-deref Read in txBegin (bsc#1012628).
- FS: JFS: Check for read-only mounted filesystem in txBegin
  (bsc#1012628).
- md: fix data corruption for raid456 when reshape restart while
  grow up (bsc#1012628).
- md/raid10: prevent soft lockup while flush writes (bsc#1012628).
- scsi: sg: fix blktrace debugfs entries leakage (bsc#1012628).
- blk-mq: fix NULL dereference on q->elevator in
  blk_mq_elv_switch_none (bsc#1012628).
- posix-timers: Ensure timer ID search-loop limit is valid
  (bsc#1012628).
- btrfs: add xxhash to fast checksum implementations
  (bsc#1012628).
- btrfs: don't check PageError in __extent_writepage
  (bsc#1012628).
- btrfs: abort transaction at update_ref_for_cow() when ref
  count is zero (bsc#1012628).
- erofs: Fix detection of atomic context (bsc#1012628).
- ACPI: x86: Add skip i2c clients quirk for Nextbook Ares 8A
  (bsc#1012628).
- ACPI: button: Add lid disable DMI quirk for Nextbook Ares 8A
  (bsc#1012628).
- ACPI: x86: Add ACPI_QUIRK_UART1_SKIP for Lenovo Yoga Book
  yb1-x90f/l (bsc#1012628).
- ACPI: video: Add backlight=native DMI quirk for Apple iMac11,3
  (bsc#1012628).
- ACPI: video: Add backlight=native DMI quirk for Lenovo ThinkPad
  X131e (3371 AMD version) (bsc#1012628).
- ACPI: resource: Remove "Zen" specific match and quirks
  (bsc#1012628).
- arm64: set __exception_irq_entry with __irq_entry as a default
  (bsc#1012628).
- arm64: mm: fix VA-range sanity check (bsc#1012628).
- ACPI: video: Add backlight=native DMI quirk for Dell Studio 1569
  (bsc#1012628).
- rcu-tasks: Avoid pr_info() with spin lock in
  cblist_init_generic() (bsc#1012628).
- rcu: Mark additional concurrent load from ->cpu_no_qs.b.exp
  (bsc#1012628).
- tools/nolibc: ensure stack protector guard is never zero
  (bsc#1012628).
- sched/fair: Don't balance task to its current running CPU
  (bsc#1012628).
- wifi: ath11k: fix registration of 6Ghz-only phy without the
  full channel range (bsc#1012628).
- bpf: Print a warning only if writing to
  unprivileged_bpf_disabled (bsc#1012628).
- bpf: Address KCSAN report on bpf_lru_list (bsc#1012628).
- spi: cadence-quadspi: Add compatible for AMD Pensando Elba SoC
  (bsc#1012628).
- bpf: drop unnecessary user-triggerable WARN_ONCE in verifierl
  log (bsc#1012628).
- bpf: tcp: Avoid taking fast sock lock in iterator (bsc#1012628).
- wifi: rtw88: sdio: Check the HISR RX_REQUEST bit in
  rtw_sdio_rx_isr() (bsc#1012628).
- bpf: Silence a warning in btf_type_id_size() (bsc#1012628).
- devlink: make health report on unregistered instance warn just
  once (bsc#1012628).
- wifi: ath11k: add support default regdb while searching
  board-2.bin for WCN6855 (bsc#1012628).
- wifi: mac80211_hwsim: Fix possible NULL dereference
  (bsc#1012628).
- spi: dw: Add compatible for Intel Mount Evans SoC (bsc#1012628).
- wifi: ath12k: Avoid NULL pointer access during management
  transmit cleanup (bsc#1012628).
- wifi: ath11k: fix memory leak in WMI firmware stats
  (bsc#1012628).
- wifi: iwlwifi: mvm: fix potential array out of bounds access
  (bsc#1012628).
- net: ethernet: litex: add support for 64 bit stats
  (bsc#1012628).
- devlink: report devlink_port_type_warn source device
  (bsc#1012628).
- wifi: iwlwifi: mvm: Add NULL check before dereferencing the
  pointer (bsc#1012628).
- wifi: wext-core: Fix -Wstringop-overflow warning in
  ioctl_standard_iw_point() (bsc#1012628).
- wifi: iwlwifi: Add support for new PCI Id (bsc#1012628).
- wifi: iwlwifi: mvm: avoid baid size integer overflow
  (bsc#1012628).
- wifi: iwlwifi: pcie: add device id 51F1 for killer 1675
  (bsc#1012628).
- igb: Fix igb_down hung on surprise removal (bsc#1012628).
- net: hns3: fix strncpy() not using dest-buf length as length
  issue (bsc#1012628).
- ASoC: amd: acp: fix for invalid dai id handling in
  acp_get_byte_count() (bsc#1012628).
- ASoC: codecs: wcd938x: fix mbhc impedance loglevel
  (bsc#1012628).
- ASoC: codecs: wcd938x: fix dB range for HPHL and HPHR
  (bsc#1012628).
- ASoC: qcom: q6apm: do not close GPR port before closing graph
  (bsc#1012628).
- iov_iter: Mark copy_iovec_from_user() noclone (bsc#1012628).
- sched/fair: Use recent_used_cpu to test p->cpus_ptr
  (bsc#1012628).
- sched/psi: use kernfs polling functions for PSI trigger polling
  (bsc#1012628).
- pinctrl: renesas: rzv2m: Handle non-unique subnode names
  (bsc#1012628).
- pinctrl: renesas: rzg2l: Handle non-unique subnode names
  (bsc#1012628).
- spi: bcm63xx: fix max prepend length (bsc#1012628).
- fbdev: imxfb: warn about invalid left/right margin
  (bsc#1012628).
- fbdev: imxfb: Removed unneeded release_mem_region (bsc#1012628).
- perf build: Fix library not found error when using CSLIBS
  (bsc#1012628).
- btrfs: be a bit more careful when setting mirror_num_ret in
  btrfs_map_block (bsc#1012628).
- spi: s3c64xx: clear loopback bit after loopback test
  (bsc#1012628).
- kallsyms: strip LTO-only suffixes from promoted global functions
  (bsc#1012628).
- smb: client: fix missed ses refcounting (bsc#1012628).
- arm64: Fix HFGxTR_EL2 field naming (bsc#1012628).
- dsa: mv88e6xxx: Do a final check before timing out
  (bsc#1012628).
- net: ethernet: ti: cpsw_ale: Fix
  cpsw_ale_get_field()/cpsw_ale_set_field() (bsc#1012628).
- bridge: Add extack warning when enabling STP in netns
  (bsc#1012628).
- net: ethernet: mtk_eth_soc: handle probe deferral (bsc#1012628).
- gso: fix dodgy bit handling for GSO_UDP_L4 (bsc#1012628).
- iommu/sva: Fix signedness bug in iommu_sva_alloc_pasid()
  (bsc#1012628).
- cifs: fix mid leak during reconnection after timeout threshold
  (bsc#1012628).
- ice: Unregister netdev and devlink_port only once (bsc#1012628).
- ice: prevent NULL pointer deref during reload (bsc#1012628).
- ASoC: SOF: ipc3-dtrace: uninitialized data in
  dfsentry_trace_filter_write() (bsc#1012628).
- regulator: da9063: fix null pointer deref with partial DT config
  (bsc#1012628).
- net: sched: cls_matchall: Undo tcf_bind_filter in case of
  failure after mall_set_parms (bsc#1012628).
- net: sched: cls_u32: Undo tcf_bind_filter if
  u32_replace_hw_knode (bsc#1012628).
- net: sched: cls_u32: Undo refcount decrement in case update
  failed (bsc#1012628).
- net: sched: cls_bpf: Undo tcf_bind_filter in case of an error
  (bsc#1012628).
- net: dsa: microchip: correct KSZ8795 static MAC table access
  (bsc#1012628).
- drm/i915/perf: add sentinel to xehp_oa_b_counters (bsc#1012628).
- iavf: Fix use-after-free in free_netdev (bsc#1012628).
- iavf: Fix out-of-bounds when setting channels on remove
  (bsc#1012628).
- iavf: use internal state to free traffic IRQs (bsc#1012628).
- iavf: make functions static where possible (bsc#1012628).
- iavf: Wait for reset in callbacks which trigger it
  (bsc#1012628).
- iavf: fix a deadlock caused by rtnl and driver's lock circular
  dependencies (bsc#1012628).
- iavf: fix reset task race with iavf_remove() (bsc#1012628).
- security: keys: Modify mismatched function name (bsc#1012628).
- vrf: Fix lockdep splat in output path (bsc#1012628).
- octeontx2-pf: Dont allocate BPIDs for LBK interfaces
  (bsc#1012628).
- bpf: Fix subprog idx logic in check_max_stack_depth
  (bsc#1012628).
- bpf: Repeat check_max_stack_depth for async callbacks
  (bsc#1012628).
- bpf, arm64: Fix BTI type used for freplace attached functions
  (bsc#1012628).
- igc: Avoid transmit queue timeout for XDP (bsc#1012628).
- igc: Prevent garbled TX queue with XDP ZEROCOPY (bsc#1012628).
- net: ipv4: use consistent txhash in TIME_WAIT and SYN_RECV
  (bsc#1012628).
- tcp: annotate data-races around tcp_rsk(req)->txhash
  (bsc#1012628).
- tcp: annotate data-races around tcp_rsk(req)->ts_recent
  (bsc#1012628).
- net: ipv4: Use kfree_sensitive instead of kfree (bsc#1012628).
- net:ipv6: check return value of pskb_trim() (bsc#1012628).
- Revert "tcp: avoid the lookup process failing to get sk in
  ehash table" (bsc#1012628).
- net: ethernet: mtk_eth_soc: always mtk_get_ib1_pkt_type
  (bsc#1012628).
- fbdev: au1200fb: Fix missing IRQ check in au1200fb_drv_probe
  (bsc#1012628).
- llc: Don't drop packet from non-root netns (bsc#1012628).
- ALSA: hda/realtek: Fix generic fixup definition for cs35l41 amp
  (bsc#1012628).
- netfilter: nf_tables: fix spurious set element insertion failure
  (bsc#1012628).
- netfilter: nf_tables: can't schedule in nft_chain_validate
  (bsc#1012628).
- netfilter: nft_set_pipapo: fix improper element removal
  (bsc#1012628).
- netfilter: nf_tables: skip bound chain in netns release path
  (bsc#1012628).
- netfilter: nf_tables: skip bound chain on rule flush
  (bsc#1012628).
- Bluetooth: use RCU for hci_conn_params and iterate safely in
  hci_sync (bsc#1012628).
- Bluetooth: hci_event: call disconnect callback before deleting
  conn (bsc#1012628).
- Bluetooth: ISO: fix iso_conn related locking and validity issues
  (bsc#1012628).
- Bluetooth: hci_sync: Avoid use-after-free in dbg for
  hci_remove_adv_monitor() (bsc#1012628).
- Bluetooth: hci_conn: return ERR_PTR instead of NULL when there
  is no link (bsc#1012628).
- Bluetooth: SCO: fix sco_conn related locking and validity issues
  (bsc#1012628).
- Bluetooth: btusb: Fix bluetooth on Intel Macbook 2014
  (bsc#1012628).
- tcp: annotate data-races around tp->tcp_tx_delay (bsc#1012628).
- tcp: annotate data-races around tp->tsoffset (bsc#1012628).
- tcp: annotate data-races around tp->keepalive_time
  (bsc#1012628).
- tcp: annotate data-races around tp->keepalive_intvl
  (bsc#1012628).
- tcp: annotate data-races around tp->keepalive_probes
  (bsc#1012628).
- tcp: annotate data-races around icsk->icsk_syn_retries
  (bsc#1012628).
- tcp: annotate data-races around tp->linger2 (bsc#1012628).
- tcp: annotate data-races around rskq_defer_accept (bsc#1012628).
- tcp: annotate data-races around tp->notsent_lowat (bsc#1012628).
- tcp: annotate data-races around icsk->icsk_user_timeout
  (bsc#1012628).
- tcp: annotate data-races around fastopenq.max_qlen
  (bsc#1012628).
- net: phy: prevent stale pointer dereference in phy_init()
  (bsc#1012628).
- jbd2: recheck chechpointing non-dirty buffer (bsc#1012628).
- kbuild: rust: avoid creating temporary files (bsc#1012628).
- tracing/histograms: Return an error if we fail to add histogram
  to hist_vars list (bsc#1012628).
- drm/ttm: fix bulk_move corruption when adding a entry
  (bsc#1012628).
- spi: dw: Remove misleading comment for Mount Evans SoC
  (bsc#1012628).
- scsi/sg: don't grab scsi host module reference (bsc#1012628).
- scsi: sg: Fix checking return value of blk_get_queue()
  (bsc#1012628).
- drm/amd/display: Clean up errors & warnings in amdgpu_dm.c
  (bsc#1012628).
- drm/amd/display: Add polling method to handle MST reply packet
  (bsc#1012628).
- Revert "drm/amd/display: edp do not add non-edid timings"
  (bsc#1012628).
- commit 90999e4
* Wed Jul 26 2023 tiwai@suse.de
- tpm/tpm_tis: Disable interrupts for TUXEDO InfinityBook S
  15/17 Gen7 (bsc#1213645).
- commit 74a8144
* Wed Jul 26 2023 tiwai@suse.de
- bus: mhi: host: add destroy_device argument to mhi_power_down()
  (bsc#1207948).
- commit 0731cb1
* Wed Jul 26 2023 tiwai@suse.de
- wifi: ath11k: remove MHI LOOPBACK channels (bsc#1207948).
- wifi: ath11k: handle thermal device registeration together
  with MAC (bsc#1207948).
- wifi: ath11k: handle irq enable/disable in several code path
  (bsc#1207948).
- wifi: ath11k: add support for suspend in power down state
  (bsc#1207948).
- bus: mhi: add new interfaces to handle MHI channels directly
  (bsc#1207948).
- commit 02597d2
* Wed Jul 26 2023 jlee@suse.com
- Update References tag
  patches.kernel.org/6.4.4-212-net-nfc-Fix-use-after-free-caused-by-nfc_llcp_f.patch
  (bsc#1012628 bsc#1213601 CVE-2023-3863).
- commit 06d33b5
* Tue Jul 25 2023 tiwai@suse.de
- ALSA: usb-audio: Add quirk for Microsoft Modern Wireless Headset
  (bsc#1207129).
- commit 24fe873
* Tue Jul 25 2023 jslaby@suse.cz
- Update
  patches.kernel.org/6.4.6-002-x86-cpu-amd-Add-a-Zenbleed-fix.patch
  (bsc#1012628 bsc#1213286 CVE-2023-20593).
  Add references.
- commit 55520bc
* Tue Jul 25 2023 jslaby@suse.cz
- Linux 6.4.6 (bsc#1012628).
- x86/cpu/amd: Add a Zenbleed fix (bsc#1012628).
- x86/cpu/amd: Move the errata checking functionality up
  (bsc#1012628).
- commit cd14b53
* Mon Jul 24 2023 jslaby@suse.cz
- Update config files. (bsc#1213592)
  Disable old unmaintained serial drivers
- commit ac1bf5a
* Mon Jul 24 2023 jslaby@suse.cz
- io_uring: Fix io_uring mmap() by using architecture-provided
  get_unmapped_area() (bsc#1212773).
- Delete
  patches.suse/Revert-io_uring-Adjust-mapping-wrt-architecture-alia.patch.
  Replace the temporary fix by an upstream fix.
- commit 2f220f8
* Mon Jul 24 2023 jslaby@suse.cz
- Refresh
  patches.suse/of-Preserve-of-display-device-name-for-compatibility.patch.
  Update upstream status.
- commit 8817ac3
* Mon Jul 24 2023 jslaby@suse.cz
- Linux 6.4.5 (bsc#1012628).
- security/integrity: fix pointer to ESL data and its size on
  pseries (bsc#1012628).
- HID: input: fix mapping for camera access keys (bsc#1012628).
- HID: amd_sfh: Rename the float32 variable (bsc#1012628).
- HID: amd_sfh: Fix for shift-out-of-bounds (bsc#1012628).
- net: lan743x: Don't sleep in atomic context (bsc#1012628).
- net: lan743x: select FIXED_PHY (bsc#1012628).
- ksmbd: add missing compound request handing in some commands
  (bsc#1012628).
- ksmbd: fix out of bounds read in smb2_sess_setup (bsc#1012628).
- drm/panel: simple: Add connector_type for innolux_at043tn24
  (bsc#1012628).
- drm: bridge: dw_hdmi: fix connector access for scdc
  (bsc#1012628).
- drm/bridge: ti-sn65dsi86: Fix auxiliary bus lifetime
  (bsc#1012628).
- swiotlb: always set the number of areas before allocating the
  pool (bsc#1012628).
- swiotlb: reduce the number of areas to match actual memory
  pool size (bsc#1012628).
- drm/panel: simple: Add Powertip PH800480T013 drm_display_mode
  flags (bsc#1012628).
- xen/virtio: Fix NULL deref when a bridge of PCI root bus has
  no parent (bsc#1012628).
- netfilter: nf_tables: report use refcount overflow
  (bsc#1012628).
- netfilter: conntrack: don't fold port numbers into addresses
  before hashing (bsc#1012628).
- ice: Fix max_rate check while configuring TX rate limits
  (bsc#1012628).
- ice: Fix tx queue rate limit when TCs are configured
  (bsc#1012628).
- igc: Add condition for qbv_config_change_errors counter
  (bsc#1012628).
- igc: Remove delay during TX ring configuration (bsc#1012628).
- igc: Add igc_xdp_buff wrapper for xdp_buff in driver
  (bsc#1012628).
- igc: Add XDP hints kfuncs for RX hash (bsc#1012628).
- igc: Fix TX Hang issue when QBV Gate is closed (bsc#1012628).
- net/mlx5e: fix double free in mlx5e_destroy_flow_table
  (bsc#1012628).
- net/mlx5e: fix memory leak in mlx5e_fs_tt_redirect_any_create
  (bsc#1012628).
- net/mlx5e: fix memory leak in mlx5e_ptp_open (bsc#1012628).
- net/mlx5e: RX, Fix flush and close release flow of regular rq
  for legacy rq (bsc#1012628).
- net/mlx5: Register a unique thermal zone per device
  (bsc#1012628).
- net/mlx5e: Check for NOT_READY flag state after locking
  (bsc#1012628).
- net/mlx5e: TC, CT: Offload ct clear only once (bsc#1012628).
- net/mlx5: Query hca_cap_2 only when supported (bsc#1012628).
- net/mlx5e: RX, Fix page_pool page fragment tracking for XDP
  (bsc#1012628).
- igc: set TP bit in 'supported' and 'advertising' fields of
  ethtool_link_ksettings (bsc#1012628).
- igc: Include the length/type field and VLAN tag in queueMaxSDU
  (bsc#1012628).
- igc: Handle PPS start time programming for past time values
  (bsc#1012628).
- blk-crypto: use dynamic lock class for blk_crypto_profile::lock
  (bsc#1012628).
- scsi: qla2xxx: Fix error code in qla2x00_start_sp()
  (bsc#1012628).
- scsi: ufs: ufs-mediatek: Add dependency for RESET_CONTROLLER
  (bsc#1012628).
- bpf: Fix max stack depth check for async callbacks
  (bsc#1012628).
- net: mvneta: fix txq_map in case of txq_number==1 (bsc#1012628).
- net: dsa: felix: make vsc9959_tas_guard_bands_update() visible
  to ocelot->ops (bsc#1012628).
- net: mscc: ocelot: fix oversize frame dropping for preemptible
  TCs (bsc#1012628).
- net/sched: cls_fw: Fix improper refcount update leads to
  use-after-free (bsc#1012628).
- gve: Set default duplex configuration to full (bsc#1012628).
- drm/fbdev-dma: Fix documented default preferred_bpp value
  (bsc#1012628).
- octeontx2-af: Promisc enable/disable through mbox (bsc#1012628).
- octeontx2-af: Move validation of ptp pointer before its usage
  (bsc#1012628).
- ionic: remove WARN_ON to prevent panic_on_warn (bsc#1012628).
- udp6: add a missing call into udp_fail_queue_rcv_skb tracepoint
  (bsc#1012628).
- net: bgmac: postpone turning IRQs off to avoid SoC hangs
  (bsc#1012628).
- net: prevent skb corruption on frag list segmentation
  (bsc#1012628).
- s390/ism: Fix locking for forwarding of IRQs and events to
  clients (bsc#1012628).
- s390/ism: Fix and simplify add()/remove() callback handling
  (bsc#1012628).
- s390/ism: Do not unregister clients with registered DMBs
  (bsc#1012628).
- icmp6: Fix null-ptr-deref of ip6_null_entry->rt6i_idev in
  icmp6_dev() (bsc#1012628).
- udp6: fix udp6_ehashfn() typo (bsc#1012628).
- ntb: idt: Fix error handling in idt_pci_driver_init()
  (bsc#1012628).
- NTB: amd: Fix error handling in amd_ntb_pci_driver_init()
  (bsc#1012628).
- ntb: intel: Fix error handling in intel_ntb_pci_driver_init()
  (bsc#1012628).
- NTB: ntb_transport: fix possible memory leak while
  device_register() fails (bsc#1012628).
- NTB: ntb_tool: Add check for devm_kcalloc (bsc#1012628).
- ipv6/addrconf: fix a potential refcount underflow for idev
  (bsc#1012628).
- HID: hyperv: avoid struct memcpy overrun warning (bsc#1012628).
- net: dsa: qca8k: Add check for skb_copy (bsc#1012628).
- platform/x86: wmi: Break possible infinite loop when parsing
  GUID (bsc#1012628).
- net/sched: taprio: replace tc_taprio_qopt_offload :: enable
  with a "cmd" enum (bsc#1012628).
- igc: Rename qbv_enable to taprio_offload_enable (bsc#1012628).
- igc: Do not enable taprio offload for invalid arguments
  (bsc#1012628).
- igc: Handle already enabled taprio offload for basetime 0
  (bsc#1012628).
- kernel/trace: Fix cleanup logic of enable_trace_eprobe
  (bsc#1012628).
- fprobe: add unlock to match a succeeded
  ftrace_test_recursion_trylock (bsc#1012628).
- igc: No strict mode in pure launchtime/CBS offload
  (bsc#1012628).
- igc: Fix launchtime before start of cycle (bsc#1012628).
- igc: Fix inserting of empty frame for launchtime (bsc#1012628).
- nvme: fix the NVME_ID_NS_NVM_STS_MASK definition (bsc#1012628).
- openrisc: Union fpcsr and oldmask in sigcontext to unbreak
  userspace ABI (bsc#1012628).
- riscv, bpf: Fix inconsistent JIT image generation (bsc#1012628).
- net: fec: remove useless fec_enet_reset_skb() (bsc#1012628).
- net: fec: remove last_bdp from fec_enet_txq_xmit_frame()
  (bsc#1012628).
- net: fec: recycle pages for transmitted XDP frames
  (bsc#1012628).
- net: fec: increase the size of tx ring and update
  tx_wake_threshold (bsc#1012628).
- drm/i915: Don't preserve dpll_hw_state for slave crtc in
  Bigjoiner (bsc#1012628).
- drm/i915: Fix one wrong caching mode enum usage (bsc#1012628).
- net: dsa: Removed unneeded of_node_put in felix_parse_ports_node
  (bsc#1012628).
- octeontx2-pf: Add additional check for MCAM rules (bsc#1012628).
- erofs: avoid useless loops in z_erofs_pcluster_readmore()
  when reading beyond EOF (bsc#1012628).
- erofs: avoid infinite loop in z_erofs_do_read_page() when
  reading beyond EOF (bsc#1012628).
- erofs: fix fsdax unavailability for chunk-based regular files
  (bsc#1012628).
- wifi: airo: avoid uninitialized warning in airo_get_rate()
  (bsc#1012628).
- bpf: cpumap: Fix memory leak in cpu_map_update_elem
  (bsc#1012628).
- xdp: use trusted arguments in XDP hints kfuncs (bsc#1012628).
- net/sched: flower: Ensure both minimum and maximum ports are
  specified (bsc#1012628).
- riscv: mm: fix truncation warning on RV32 (bsc#1012628).
- drm/nouveau/disp: fix HDMI on gt215+ (bsc#1012628).
- drm/nouveau/disp/g94: enable HDMI (bsc#1012628).
- netdevsim: fix uninitialized data in
  nsim_dev_trap_fa_cookie_write() (bsc#1012628).
- drm/nouveau/acr: Abort loading ACR if no firmware was found
  (bsc#1012628).
- drm/nouveau: bring back blit subchannel for pre nv50 GPUs
  (bsc#1012628).
- net/sched: make psched_mtu() RTNL-less safe (bsc#1012628).
- net: txgbe: fix eeprom calculation error (bsc#1012628).
- wifi: rtw89: debug: fix error code in
  rtw89_debug_priv_send_h2c_set() (bsc#1012628).
- net/sched: sch_qfq: reintroduce lmax bound check for MTU
  (bsc#1012628).
- net/sched: sch_qfq: account for stab overhead in qfq_enqueue
  (bsc#1012628).
- nvme-pci: fix DMA direction of unmapping integrity data
  (bsc#1012628).
- smb: client: improve DFS mount check (bsc#1012628).
- cifs: fix session state check in smb2_find_smb_ses
  (bsc#1012628).
- smb: client: fix parsing of source mount option (bsc#1012628).
- drm/client: Send hotplug event after registering a client
  (bsc#1012628).
- f2fs: don't reset unchangable mount option in f2fs_remount()
  (bsc#1012628).
- f2fs: fix deadlock in i_xattr_sem and inode page lock
  (bsc#1012628).
- kbuild: make modules_install copy modules.builtin(.modinfo)
  (bsc#1012628).
- tpm: Do not remap from ACPI resources again for Pluton TPM
  (bsc#1012628).
- tpm: tpm_vtpm_proxy: fix a race condition in /dev/vtpmx creation
  (bsc#1012628).
- tpm: tpm_tis: Disable interrupts *only* for AEON UPX-i11
  (bsc#1012628).
- tpm: tis_i2c: Limit read bursts to I2C_SMBUS_BLOCK_MAX (32)
  bytes (bsc#1012628).
- tpm/tpm_tis: Disable interrupts for Framework Laptop Intel
  12th gen (bsc#1012628).
- tpm: tis_i2c: Limit write bursts to I2C_SMBUS_BLOCK_MAX (32)
  bytes (bsc#1012628).
- tpm: return false from tpm_amd_is_rng_defective on non-x86
  platforms (bsc#1012628).
- tpm/tpm_tis: Disable interrupts for Framework Laptop Intel
  13th gen (bsc#1012628).
- tpm,tpm_tis: Disable interrupts after 1000 unhandled IRQs
  (bsc#1012628).
- tpm/tpm_tis: Disable interrupts for Lenovo L590 devices
  (bsc#1012628).
- mtd: rawnand: meson: fix unaligned DMA buffers handling
  (bsc#1012628).
- net: bcmgenet: Ensure MDIO unregistration has clocks enabled
  (bsc#1012628).
- net: phy: dp83td510: fix kernel stall during netboot in
  DP83TD510E PHY driver (bsc#1012628).
- kasan: add kasan_tag_mismatch prototype (bsc#1012628).
- kasan: use internal prototypes matching gcc-13 builtins
  (bsc#1012628).
- kasan, slub: fix HW_TAGS zeroing with slub_debug (bsc#1012628).
- kasan: fix type cast in memory_is_poisoned_n (bsc#1012628).
- tracing/user_events: Fix incorrect return value for writing
  operation when events are disabled (bsc#1012628).
- powerpc: Fail build if using recordmcount with binutils v2.37
  (bsc#1012628).
- misc: fastrpc: Create fastrpc scalar with correct buffer count
  (bsc#1012628).
- powerpc/security: Fix Speculation_Store_Bypass reporting on
  Power10 (bsc#1012628).
- powerpc/64s: Fix native_hpte_remove() to be irq-safe
  (bsc#1012628).
- MIPS: cpu-features: Use boot_cpu_type for CPU type based
  features (bsc#1012628).
- MIPS: Loongson: Fix cpu_probe_loongson() again (bsc#1012628).
- MIPS: Loongson: Fix build error when make modules_install
  (bsc#1012628).
- MIPS: KVM: Fix NULL pointer dereference (bsc#1012628).
- ext4: Fix reusing stale buffer heads from last failed mounting
  (bsc#1012628).
- ext4: fix wrong unit use in ext4_mb_clear_bb (bsc#1012628).
- ext4: get block from bh in ext4_free_blocks for fast commit
  replay (bsc#1012628).
- ext4: fix wrong unit use in ext4_mb_new_blocks (bsc#1012628).
- ext4: avoid updating the superblock on a r/o mount if not needed
  (bsc#1012628).
- ext4: fix to check return value of freeze_bdev() in
  ext4_shutdown() (bsc#1012628).
- ext4: turn quotas off if mount failed after enabling quotas
  (bsc#1012628).
- ext4: only update i_reserved_data_blocks on successful block
  allocation (bsc#1012628).
- fs: dlm: revert check required context while close
  (bsc#1012628).
- mm/mmap: Fix error return in do_vmi_align_munmap()
  (bsc#1012628).
- soc: qcom: mdt_loader: Fix unconditional call to
  scm_pas_mem_setup (bsc#1012628).
- ext2/dax: Fix ext2_setsize when len is page aligned
  (bsc#1012628).
- jfs: jfs_dmap: Validate db_l2nbperpage while mounting
  (bsc#1012628).
- arm64: dts: mt7986: use size of reserved partition for bl2
  (bsc#1012628).
- arm64: dts: ti: k3-j721s2: Fix wkup pinmux range (bsc#1012628).
- hwrng: imx-rngc - fix the timeout for init and self check
  (bsc#1012628).
- dm integrity: reduce vmalloc space footprint on 32-bit
  architectures (bsc#1012628).
- scsi: mpi3mr: Propagate sense data for admin queue SCSI I/O
  (bsc#1012628).
- s390/zcrypt: do not retry administrative requests (bsc#1012628).
- PCI/PM: Avoid putting EloPOS E2/S2/H2 PCIe Ports in D3cold
  (bsc#1012628).
- PCI: Release resource invalidated by coalescing (bsc#1012628).
- PCI: Add function 1 DMA alias quirk for Marvell 88SE9235
  (bsc#1012628).
- PCI: qcom: Disable write access to read only registers for IP
  v2.3.3 (bsc#1012628).
- PCI: epf-test: Fix DMA transfer completion initialization
  (bsc#1012628).
- PCI: epf-test: Fix DMA transfer completion detection
  (bsc#1012628).
- PCI: rockchip: Assert PCI Configuration Enable bit after probe
  (bsc#1012628).
- PCI: rockchip: Write PCI Device ID to correct register
  (bsc#1012628).
- PCI: rockchip: Add poll and timeout to wait for PHY PLLs to
  be locked (bsc#1012628).
- PCI: rockchip: Fix legacy IRQ generation for RK3399 PCIe
  endpoint core (bsc#1012628).
- PCI: rockchip: Use u32 variable to access 32-bit registers
  (bsc#1012628).
- PCI: rockchip: Set address alignment for endpoint mode
  (bsc#1012628).
- misc: pci_endpoint_test: Free IRQs before removing the device
  (bsc#1012628).
- misc: pci_endpoint_test: Re-init completion for every test
  (bsc#1012628).
- mfd: pm8008: Fix module autoloading (bsc#1012628).
- md/raid0: add discard support for the 'original' layout
  (bsc#1012628).
- fs: dlm: return positive pid value for F_GETLK (bsc#1012628).
- fs: dlm: fix cleanup pending ops when interrupted (bsc#1012628).
- fs: dlm: interrupt posix locks only when process is killed
  (bsc#1012628).
- fs: dlm: make F_SETLK use unkillable wait_event (bsc#1012628).
- fs: dlm: fix mismatch of plock results from userspace
  (bsc#1012628).
- fs: dlm: clear pending bit when queue was empty (bsc#1012628).
- fs: dlm: fix missing pending to false (bsc#1012628).
- scsi: lpfc: Fix double free in lpfc_cmpl_els_logo_acc() caused
  by lpfc_nlp_not_used() (bsc#1012628).
- drm/atomic: Allow vblank-enabled + self-refresh "disable"
  (bsc#1012628).
- drm/rockchip: vop: Leave vblank enabled in self-refresh
  (bsc#1012628).
- drm/dp_mst: Clear MSG_RDY flag before sending new message
  (bsc#1012628).
- drm/amd/display: Limit DCN32 8 channel or less parts to DPM1
  for FPO (bsc#1012628).
- drm/amd/display: Fix in secure display context creation
  (bsc#1012628).
- drm/amd/display: fix seamless odm transitions (bsc#1012628).
- drm/amd/display: edp do not add non-edid timings (bsc#1012628).
- drm/amd/display: Remove Phantom Pipe Check When Calculating
  K1 and K2 (bsc#1012628).
- drm/amd/display: Correct `DMUB_FW_VERSION` macro (bsc#1012628).
- drm/amd/display: Add monitor specific edid quirk (bsc#1012628).
- drm/amdgpu: avoid restore process run into dead loop
  (bsc#1012628).
- drm/amd/pm: fix smu i2c data read risk (bsc#1012628).
- drm/ttm: Don't leak a resource on eviction error (bsc#1012628).
- drm/ttm: Don't leak a resource on swapout move error
  (bsc#1012628).
- serial: atmel: don't enable IRQs prematurely (bsc#1012628).
- tty: serial: samsung_tty: Fix a memory leak in
  s3c24xx_serial_getclk() in case of error (bsc#1012628).
- tty: serial: samsung_tty: Fix a memory leak in
  s3c24xx_serial_getclk() when iterating clk (bsc#1012628).
- tty: serial: imx: fix rs485 rx after tx (bsc#1012628).
- tty: fix hang on tty device with no_room set (bsc#1012628).
- firmware: stratix10-svc: Fix a potential resource leak in
  svc_create_memory_pool() (bsc#1012628).
- libceph: harden msgr2.1 frame segment length checks
  (bsc#1012628).
- ceph: add a dedicated private data for netfs rreq (bsc#1012628).
- ceph: fix blindly expanding the readahead windows (bsc#1012628).
- ceph: don't let check_caps skip sending responses for revoke
  msgs (bsc#1012628).
- nfp: clean mc addresses in application firmware when closing
  port (bsc#1012628).
- arm64: errata: Mitigate Ampere1 erratum AC03_CPU_38 at stage-2
  (bsc#1012628).
- xhci: Fix resume issue of some ZHAOXIN hosts (bsc#1012628).
- xhci: Fix TRB prefetch issue of ZHAOXIN hosts (bsc#1012628).
- xhci: Show ZHAOXIN xHCI root hub speed correctly (bsc#1012628).
- meson saradc: fix clock divider mask length (bsc#1012628).
- opp: Fix use-after-free in lazy_opp_tables after probe deferral
  (bsc#1012628).
- soundwire: qcom: fix storing port config out-of-bounds
  (bsc#1012628).
- media: uapi: Fix [GS]_ROUTING ACTIVE flag value (bsc#1012628).
- Revert "8250: add support for ASIX devices with a FIFO bug"
  (bsc#1012628).
- bus: ixp4xx: fix IXP4XX_EXP_T1_MASK (bsc#1012628).
- s390/decompressor: fix misaligned symbol build error
  (bsc#1012628).
- dm: verity-loadpin: Add NULL pointer check for 'bdev' parameter
  (bsc#1012628).
- tracing/histograms: Add histograms to hist_vars if they have
  referenced variables (bsc#1012628).
- tracing: Fix memory leak of iter->temp when reading trace_pipe
  (bsc#1012628).
- nvme: don't reject probe due to duplicate IDs for single-ported
  PCIe devices (bsc#1012628).
- samples: ftrace: Save required argument registers in sample
  trampolines (bsc#1012628).
- perf: RISC-V: Remove PERF_HES_STOPPED flag checking in
  riscv_pmu_start() (bsc#1012628).
- regmap-irq: Fix out-of-bounds access when allocating config
  buffers (bsc#1012628).
- net: ena: fix shift-out-of-bounds in exponential backoff
  (bsc#1012628).
- ring-buffer: Fix deadloop issue on reading trace_pipe
  (bsc#1012628).
- ftrace: Fix possible warning on checking all pages used in
  ftrace_process_locs() (bsc#1012628).
- drm/amd/pm: share the code around SMU13 pcie parameters update
  (bsc#1012628).
- drm/amd/pm: conditionally disable pcie lane/speed switching
  for SMU13 (bsc#1012628).
- cifs: if deferred close is disabled then close files immediately
  (bsc#1012628).
- xtensa: ISS: fix call to split_if_spec (bsc#1012628).
- perf/x86: Fix lockdep warning in for_each_sibling_event()
  on SPR (bsc#1012628).
- PM: QoS: Restore support for default value on frequency QoS
  (bsc#1012628).
- pwm: meson: modify and simplify calculation in
  meson_pwm_get_state (bsc#1012628).
- pwm: meson: fix handling of period/duty if greater than UINT_MAX
  (bsc#1012628).
- accel/ivpu: Fix VPU register access in irq disable
  (bsc#1012628).
- accel/ivpu: Clear specific interrupt status bits on C0
  (bsc#1012628).
- fprobe: Release rethook after the ftrace_ops is unregistered
  (bsc#1012628).
- fprobe: Ensure running fprobe_exit_handler() finished before
  calling rethook_free() (bsc#1012628).
- tracing: Fix null pointer dereference in tracing_err_log_open()
  (bsc#1012628).
- mptcp: do not rely on implicit state check in mptcp_listen()
  (bsc#1012628).
- mptcp: ensure subflow is unhashed before cleaning the backlog
  (bsc#1012628).
- selftests: mptcp: sockopt: use 'iptables-legacy' if available
  (bsc#1012628).
- selftests: mptcp: connect: fail if nft supposed to work
  (bsc#1012628).
- selftests: mptcp: sockopt: return error if wrong mark
  (bsc#1012628).
- selftests: mptcp: userspace_pm: use correct server port
  (bsc#1012628).
- selftests: mptcp: userspace_pm: report errors with 'remove'
  tests (bsc#1012628).
- selftests: mptcp: depend on SYN_COOKIES (bsc#1012628).
- selftests: mptcp: pm_nl_ctl: fix 32-bit support (bsc#1012628).
- smb: client: Fix -Wstringop-overflow issues (bsc#1012628).
- tracing/probes: Fix to avoid double count of the string length
  on the array (bsc#1012628).
- tracing/probes: Fix not to count error code to total length
  (bsc#1012628).
- tracing/probes: Fix to update dynamic data counter if fetcharg
  uses it (bsc#1012628).
- Revert "tracing: Add "(fault)" name injection to kernel probes"
  (bsc#1012628).
- tracing/probes: Fix to record 0-length data_loc in
  fetch_store_string*() if fails (bsc#1012628).
- tracing/user_events: Fix struct arg size match check
  (bsc#1012628).
- scsi: qla2xxx: Multi-que support for TMF (bsc#1012628).
- scsi: qla2xxx: Fix task management cmd failure (bsc#1012628).
- scsi: qla2xxx: Fix task management cmd fail due to unavailable
  resource (bsc#1012628).
- scsi: qla2xxx: Fix hang in task management (bsc#1012628).
- scsi: qla2xxx: Wait for io return on terminate rport
  (bsc#1012628).
- scsi: qla2xxx: Fix mem access after free (bsc#1012628).
- scsi: qla2xxx: Array index may go out of bound (bsc#1012628).
- scsi: qla2xxx: Avoid fcport pointer dereference (bsc#1012628).
- scsi: qla2xxx: Fix buffer overrun (bsc#1012628).
- scsi: qla2xxx: Fix potential NULL pointer dereference
  (bsc#1012628).
- scsi: qla2xxx: Check valid rport returned by fc_bsg_to_rport()
  (bsc#1012628).
- scsi: qla2xxx: Correct the index of array (bsc#1012628).
- scsi: qla2xxx: Pointer may be dereferenced (bsc#1012628).
- scsi: qla2xxx: Remove unused nvme_ls_waitq wait queue
  (bsc#1012628).
- scsi: qla2xxx: Fix end of loop test (bsc#1012628).
- net: dsa: ocelot: unlock on error in vsc9959_qos_port_tas_set()
  (bsc#1012628).
- MIPS: kvm: Fix build error with KVM_MIPS_DEBUG_COP0_COUNTERS
  enabled (bsc#1012628).
- Revert "drm/amd: Disable PSR-SU on Parade 0803 TCON"
  (bsc#1012628).
- drm/atomic: Fix potential use-after-free in nonblocking commits
  (bsc#1012628).
- net/ncsi: make one oem_gma function for all mfr id
  (bsc#1012628).
- net/ncsi: change from ndo_set_mac_address to dev_set_mac_address
  (bsc#1012628).
- Update config files. Set CONFIG_AMPERE_ERRATUM_AC03_CPU_38=y (the
  default)
- commit 6282d80
* Sun Jul 23 2023 schwab@suse.de
- rpm/mkspec-dtb: add riscv64 dtb-allwinner subpackage
- commit ec82ffc
* Sun Jul 23 2023 tiwai@suse.de
- Revert "r8169: disable ASPM during NAPI poll" (bsc#1213491).
- r8169: revert 2ab19de62d67 ("r8169: remove ASPM restrictions
  now that ASPM is disabled during NAPI poll") (bsc#1213491).
- r8169: fix ASPM-related problem for chip version 42 and 43
  (bsc#1213491).
- commit 8d5ae5f
* Thu Jul 20 2023 jslaby@suse.cz
- Linux 6.4.4 (bsc#1012628).
- start_kernel: Add __no_stack_protector function attribute
  (bsc#1012628).
- USB: serial: option: add LARA-R6 01B PIDs (bsc#1012628).
- usb: dwc3: gadget: Propagate core init errors to UDC during
  pullup (bsc#1012628).
- phy: tegra: xusb: Clear the driver reference in usb-phy dev
  (bsc#1012628).
- extcon: usbc-tusb320: Unregister typec port on driver removal
  (bsc#1012628).
- dt-bindings: iio: ad7192: Add mandatory reference voltage source
  (bsc#1012628).
- iio: addac: ad74413: don't set DIN_SINK for functions other
  than digital input (bsc#1012628).
- iio: adc: ad7192: Fix null ad7192_state pointer access
  (bsc#1012628).
- iio: adc: ad7192: Fix internal/external clock selection
  (bsc#1012628).
- iio: accel: fxls8962af: errata bug only applicable for
  FXLS8962AF (bsc#1012628).
- iio: accel: fxls8962af: fixup buffer scan element type
  (bsc#1012628).
- Revert "drm/amd/display: edp do not add non-edid timings"
  (bsc#1012628).
- fs: pipe: reveal missing function protoypes (bsc#1012628).
- s390/kasan: fix insecure W+X mapping warning (bsc#1012628).
- blk-mq: don't queue plugged passthrough requests into scheduler
  (bsc#1012628).
- block: Fix the type of the second bdev_op_is_zoned_write()
  argument (bsc#1012628).
- block/rq_qos: protect rq_qos apis with a new lock (bsc#1012628).
- splice: Fix filemap_splice_read() to use the correct inode
  (bsc#1012628).
- erofs: kill hooked chains to avoid loops on deduplicated
  compressed images (bsc#1012628).
- x86/resctrl: Only show tasks' pid in current pid namespace
  (bsc#1012628).
- fsverity: use shash API instead of ahash API (bsc#1012628).
- fsverity: don't use bio_first_page_all() in
  fsverity_verify_bio() (bsc#1012628).
- blk-iocost: use spin_lock_irqsave in adjust_inuse_and_calc_cost
  (bsc#1012628).
- x86/sev: Fix calculation of end address based on number of pages
  (bsc#1012628).
- blk-cgroup: Reinit blkg_iostat_set after clearing in
  blkcg_reset_stats() (bsc#1012628).
- virt: sevguest: Add CONFIG_CRYPTO dependency (bsc#1012628).
- blk-mq: fix potential io hang by wrong 'wake_batch'
  (bsc#1012628).
- lockd: drop inappropriate svc_get() from locked_get()
  (bsc#1012628).
- nvme-core: fix memory leak in dhchap_secret_store (bsc#1012628).
- nvme-core: fix memory leak in dhchap_ctrl_secret (bsc#1012628).
- nvme-core: add missing fault-injection cleanup (bsc#1012628).
- nvme-core: fix dev_pm_qos memleak (bsc#1012628).
- md/raid10: check slab-out-of-bounds in md_bitmap_get_counter
  (bsc#1012628).
- md/raid10: fix overflow of md/safe_mode_delay (bsc#1012628).
- md/raid10: fix wrong setting of max_corr_read_errors
  (bsc#1012628).
- md/raid10: fix null-ptr-deref of mreplace in raid10_sync_request
  (bsc#1012628).
- md/raid10: fix io loss while replacement replace rdev
  (bsc#1012628).
- md/raid1-10: factor out a helper to add bio to plug
  (bsc#1012628).
- md/raid1-10: factor out a helper to submit normal write
  (bsc#1012628).
- md/raid1-10: submit write io directly if bitmap is not enabled
  (bsc#1012628).
- block: fix blktrace debugfs entries leakage (bsc#1012628).
- irqchip/loongson-eiointc: Fix irq affinity setting during resume
  (bsc#1012628).
- splice: don't call file_accessed in copy_splice_read
  (bsc#1012628).
- irqchip/stm32-exti: Fix warning on initialized field overwritten
  (bsc#1012628).
- irqchip/jcore-aic: Fix missing allocation of IRQ descriptors
  (bsc#1012628).
- svcrdma: Prevent page release when nothing was received
  (bsc#1012628).
- erofs: fix compact 4B support for 16k block size (bsc#1012628).
- posix-timers: Prevent RT livelock in itimer_delete()
  (bsc#1012628).
- tick/rcu: Fix bogus ratelimit condition (bsc#1012628).
- tracing/timer: Add missing hrtimer modes to
  decode_hrtimer_mode() (bsc#1012628).
- btrfs: always read the entire extent_buffer (bsc#1012628).
- btrfs: don't use btrfs_bio_ctrl for extent buffer reading
  (bsc#1012628).
- btrfs: return bool from lock_extent_buffer_for_io (bsc#1012628).
- btrfs: submit a writeback bio per extent_buffer (bsc#1012628).
- btrfs: fix range_end calculation in extent_write_locked_range
  (bsc#1012628).
- btrfs: don't fail writeback when allocating the compression
  context fails (bsc#1012628).
- btrfs: only call __extent_writepage_io from
  extent_write_locked_range (bsc#1012628).
- btrfs: don't treat zoned writeback as being from an async
  helper thread (bsc#1012628).
- btrfs: fix file_offset for REQ_BTRFS_ONE_ORDERED bios that
  get split (bsc#1012628).
- blk-mq: don't insert passthrough request into sw queue
  (bsc#1012628).
- clocksource/drivers/cadence-ttc: Fix memory leak in
  ttc_timer_probe (bsc#1012628).
- PM: domains: fix integer overflow issues in genpd_parse_state()
  (bsc#1012628).
- perf/arm-cmn: Fix DTC reset (bsc#1012628).
- drivers/perf: apple_m1: Force 63bit counters for M2 CPUs
  (bsc#1012628).
- x86/mm: Allow guest.enc_status_change_prepare() to fail
  (bsc#1012628).
- x86/tdx: Fix race between set_memory_encrypted() and
  load_unaligned_zeropad() (bsc#1012628).
- drivers/perf: hisi: Don't migrate perf to the CPU going to
  teardown (bsc#1012628).
- perf: arm_cspmu: Set irq affinitiy only if overflow interrupt
  is used (bsc#1012628).
- perf/arm_cspmu: Fix event attribute type (bsc#1012628).
- APEI: GHES: correctly return NULL for ghes_get_devices()
  (bsc#1012628).
- powercap: RAPL: fix invalid initialization for pl4_supported
  field (bsc#1012628).
- powercap: RAPL: Fix CONFIG_IOSF_MBI dependency (bsc#1012628).
- PM: domains: Move the verification of in-params from
  genpd_add_device() (bsc#1012628).
- ARM: 9303/1: kprobes: avoid missing-declaration warnings
  (bsc#1012628).
- cpufreq: intel_pstate: Fix energy_performance_preference for
  passive (bsc#1012628).
- thermal/drivers/qcom/tsens-v0_1: Add support for MSM8226
  (bsc#1012628).
- thermal/drivers/qcom/tsens-v0_1: Fix mdm9607 slope values
  (bsc#1012628).
- thermal/drivers/qcom/tsens-v0_1: Add mdm9607 correction offsets
  (bsc#1012628).
- thermal/drivers/sun8i: Fix some error handling paths in
  sun8i_ths_probe() (bsc#1012628).
- thermal/drivers/qoriq: Only enable supported sensors
  (bsc#1012628).
- kunit: tool: undo type subscripts for subprocess.Popen
  (bsc#1012628).
- rcu: Make rcu_cpu_starting() rely on interrupts being disabled
  (bsc#1012628).
- rcu-tasks: Stop rcu_tasks_invoke_cbs() from using never-onlined
  CPUs (bsc#1012628).
- rcutorture: Correct name of use_softirq module parameter
  (bsc#1012628).
- rcu/rcuscale: Move rcu_scale_*() after kfree_scale_cleanup()
  (bsc#1012628).
- rcu/rcuscale: Stop kfree_scale_thread thread(s) after unloading
  rcuscale (bsc#1012628).
- x86/mtrr: Remove physical address size calculation
  (bsc#1012628).
- x86/mtrr: Support setting MTRR state for software defined MTRRs
  (bsc#1012628).
- x86/hyperv: Set MTRR state when running as SEV-SNP Hyper-V guest
  (bsc#1012628).
- x86/mtrr: Replace size_or_mask and size_and_mask with a much
  easier concept (bsc#1012628).
- x86/xen: Set MTRR state when running as Xen PV initial domain
  (bsc#1012628).
- tools/nolibc: ensure fast64 integer types have 64 bits
  (bsc#1012628).
- kselftest: vDSO: Fix accumulation of uninitialized ret when
  CLOCK_REALTIME is undefined (bsc#1012628).
- selftests/ftace: Fix KTAP output ordering (bsc#1012628).
- perf/ibs: Fix interface via core pmu events (bsc#1012628).
- x86/mm: Fix __swp_entry_to_pte() for Xen PV guests
  (bsc#1012628).
- reiserfs: Initialize sec->length in reiserfs_security_init()
  (bsc#1012628).
- locking/atomic: arm: fix sync ops (bsc#1012628).
- evm: Complete description of evm_inode_setattr() (bsc#1012628).
- evm: Fix build warnings (bsc#1012628).
- ima: Fix build warnings (bsc#1012628).
- pstore/ram: Add check for kstrdup (bsc#1012628).
- sched/core: Avoid multiple calling update_rq_clock() in
  __cfsb_csd_unthrottle() (bsc#1012628).
- igc: Enable and fix RX hash usage by netstack (bsc#1012628).
- wifi: ath9k: fix AR9003 mac hardware hang check register offset
  calculation (bsc#1012628).
- wifi: ath9k: avoid referencing uninit memory in
  ath9k_wmi_ctrl_rx (bsc#1012628).
- libbpf: btf_dump_type_data_check_overflow needs to consider
  BTF_MEMBER_BITFIELD_SIZE (bsc#1012628).
- bpf: encapsulate precision backtracking bookkeeping
  (bsc#1012628).
- bpf: improve precision backtrack logging (bsc#1012628).
- bpf: maintain bitmasks across all active frames in
  __mark_chain_precision (bsc#1012628).
- bpf: fix propagate_precision() logic for inner frames
  (bsc#1012628).
- wifi: rtw89: fix rtw89_read_chip_ver() for RTL8852B and RTL8851B
  (bsc#1012628).
- samples/bpf: Fix buffer overflow in tcp_basertt (bsc#1012628).
- spi: spi-geni-qcom: Correct CS_TOGGLE bit in SPI_TRANS_CFG
  (bsc#1012628).
- wifi: wilc1000: fix for absent RSN capabilities WFA testcase
  (bsc#1012628).
- wifi: rtw88: unlock on error path in rtw_ops_add_interface()
  (bsc#1012628).
- wifi: mwifiex: Fix the size of a memory allocation in
  mwifiex_ret_802_11_scan() (bsc#1012628).
- sctp: add bpf_bypass_getsockopt proto callback (bsc#1012628).
- sfc: release encap match in efx_tc_flow_free() (bsc#1012628).
- libbpf: fix offsetof() and container_of() to work with CO-RE
  (bsc#1012628).
- bpf: Don't EFAULT for {g,s}setsockopt with wrong optlen
  (bsc#1012628).
- spi: dw: Round of n_bytes to power of 2 (bsc#1012628).
- nfc: llcp: fix possible use of uninitialized variable in
  nfc_llcp_send_connect() (bsc#1012628).
- bpftool: JIT limited misreported as negative value on aarch64
  (bsc#1012628).
- bpf: Remove bpf trampoline selector (bsc#1012628).
- bpf: Fix memleak due to fentry attach failure (bsc#1012628).
- selftests/bpf: Do not use sign-file as testcase (bsc#1012628).
- regulator: rk808: fix asynchronous probing (bsc#1012628).
- regulator: core: Fix more error checking for
  debugfs_create_dir() (bsc#1012628).
- regulator: core: Streamline debugfs operations (bsc#1012628).
- wifi: orinoco: Fix an error handling path in spectrum_cs_probe()
  (bsc#1012628).
- wifi: orinoco: Fix an error handling path in orinoco_cs_probe()
  (bsc#1012628).
- wifi: atmel: Fix an error handling path in atmel_probe()
  (bsc#1012628).
- wifi: wl3501_cs: Fix an error handling path in wl3501_probe()
  (bsc#1012628).
- wifi: ray_cs: Fix an error handling path in ray_probe()
  (bsc#1012628).
- wifi: ath9k: don't allow to overwrite ENDPOINT0 attributes
  (bsc#1012628).
- wifi: rtw88: usb: silence log flooding error message
  (bsc#1012628).
- samples/bpf: xdp1 and xdp2 reduce XDPBUFSIZE to 60
  (bsc#1012628).
- wifi: ath10k: Trigger STA disconnect after reconfig complete
  on hardware restart (bsc#1012628).
- bpf: Remove anonymous union in bpf_kfunc_call_arg_meta
  (bsc#1012628).
- bpf: Set kptr_struct_meta for node param to list and rbtree
  insert funcs (bsc#1012628).
- bpf: Fix __bpf_{list,rbtree}_add's beginning-of-node calculation
  (bsc#1012628).
- bpf: Make bpf_refcount_acquire fallible for non-owning refs
  (bsc#1012628).
- tools/resolve_btfids: Fix setting HOSTCFLAGS (bsc#1012628).
- wifi: iwlwifi: mvm: send time sync only if needed (bsc#1012628).
- wifi: mac80211: recalc min chandef for new STA links
  (bsc#1012628).
- selftests/bpf: Fix check_mtu using wrong variable type
  (bsc#1012628).
- soc: qcom: geni-se: Add interfaces geni_se_tx_init_dma()
  and geni_se_rx_init_dma() (bsc#1012628).
- spi: spi-geni-qcom: Do not do DMA map/unmap inside driver,
  use framework instead (bsc#1012628).
- wifi: rsi: Do not configure WoWlan in shutdown hook if not
  enabled (bsc#1012628).
- wifi: rsi: Do not set MMC_PM_KEEP_POWER in shutdown
  (bsc#1012628).
- ice: handle extts in the miscellaneous interrupt thread
  (bsc#1012628).
- selftests: cgroup: fix unexpected failure on test_memcg_low
  (bsc#1012628).
- watchdog/perf: define dummy watchdog_update_hrtimer_threshold()
  on correct config (bsc#1012628).
- watchdog/perf: more properly prevent false positives with
  turbo modes (bsc#1012628).
- kexec: fix a memory leak in crash_shrink_memory() (bsc#1012628).
- mmc: mediatek: Avoid ugly error message when SDIO wakeup IRQ
  isn't used (bsc#1012628).
- memstick r592: make memstick_debug_get_tpc_name() static
  (bsc#1012628).
- selftests/bpf: Fix invalid pointer check in get_xlated_program()
  (bsc#1012628).
- wifi: ath9k: Fix possible stall on ath9k_txq_list_has_key()
  (bsc#1012628).
- bpf: Use scalar ids in mark_chain_precision() (bsc#1012628).
- bpf: Verify scalar ids mapping in regsafe() using check_ids()
  (bsc#1012628).
- wifi: mac80211: Fix permissions for valid_links debugfs entry
  (bsc#1012628).
- wifi: iwlwifi: mvm: Handle return value for iwl_mvm_sta_init
  (bsc#1012628).
- wifi: iwlwifi: fw: print PC register value instead of address
  (bsc#1012628).
- rtnetlink: extend RTEXT_FILTER_SKIP_STATS to IFLA_VF_INFO
  (bsc#1012628).
- wifi: ath11k: Add missing check for ioremap (bsc#1012628).
- wifi: ath11k: Add missing ops config for IPQ5018 in
  ath11k_ahb_probe() (bsc#1012628).
- wifi: ath11k: Restart firmware after cold boot calibration
  for IPQ5018 (bsc#1012628).
- wifi: ath11k: Add missing hw_ops->get_ring_selector() for
  IPQ5018 (bsc#1012628).
- wifi: mac80211: add helpers to access sband iftype data
  (bsc#1012628).
- wifi: iwlwifi: mvm: add support for Extra EHT LTF (bsc#1012628).
- wifi: iwlwifi: mvm: correctly access HE/EHT sband capa
  (bsc#1012628).
- wifi: iwlwifi: pull from TXQs with softirqs disabled
  (bsc#1012628).
- wifi: iwlwifi: pcie: fix NULL pointer dereference in
  iwl_pcie_irq_rx_msix_handler() (bsc#1012628).
- wifi: mac80211: Remove "Missing iftype sband data/EHT cap"
  spam (bsc#1012628).
- wifi: cfg80211: rewrite merging of inherited elements
  (bsc#1012628).
- wifi: cfg80211: drop incorrect nontransmitted BSS update code
  (bsc#1012628).
- wifi: cfg80211: fix regulatory disconnect with OCB/NAN
  (bsc#1012628).
- wifi: ieee80211: Fix the common size calculation for
  reconfiguration ML (bsc#1012628).
- mm: move mm_count into its own cache line (bsc#1012628).
- watchdog: remove WATCHDOG_DEFAULT (bsc#1012628).
- watchdog/hardlockup: change watchdog_nmi_enable() to void
  (bsc#1012628).
- watchdog/hardlockup: move perf hardlockup checking/panic to
  common watchdog.c (bsc#1012628).
- watchdog/hardlockup: rename some "NMI watchdog"
  constants/function (bsc#1012628).
- watchdog/perf: adapt the watchdog_perf interface for async model
  (bsc#1012628).
- watchdog/hardlockup: keep kernel.nmi_watchdog sysctl as 0444
  if probe fails (bsc#1012628).
- mmc: Add MMC_QUIRK_BROKEN_SD_CACHE for Kingston Canvas Go Plus
  from 11/2019 (bsc#1012628).
- wifi: iwlwifi: mvm: indicate HW decrypt for beacon protection
  (bsc#1012628).
- wifi: iwlwifi: mvm: check only affected links (bsc#1012628).
- wifi: ath9k: convert msecs to jiffies where needed
  (bsc#1012628).
- bpf: Factor out socket lookup functions for the TC hookpoint
  (bsc#1012628).
- bpf: Call __bpf_sk_lookup()/__bpf_skc_lookup() directly via
  TC hookpoint (bsc#1012628).
- bpf: Fix bpf socket lookup from tc/xdp to respect socket VRF
  bindings (bsc#1012628).
- can: length: fix bitstuffing count (bsc#1012628).
- can: kvaser_pciefd: Add function to set skb hwtstamps
  (bsc#1012628).
- can: kvaser_pciefd: Set hardware timestamp on transmitted
  packets (bsc#1012628).
- igc: Fix race condition in PTP tx code (bsc#1012628).
- igc: Check if hardware TX timestamping is enabled earlier
  (bsc#1012628).
- igc: Retrieve TX timestamp during interrupt handling
  (bsc#1012628).
- igc: Work around HW bug causing missing timestamps
  (bsc#1012628).
- net: stmmac: fix double serdes powerdown (bsc#1012628).
- netlink: fix potential deadlock in netlink_set_err()
  (bsc#1012628).
- netlink: do not hard code device address lenth in fdb dumps
  (bsc#1012628).
- bonding: do not assume skb mac_header is set (bsc#1012628).
- sch_netem: fix issues in netem_change() vs get_dist_table()
  (bsc#1012628).
- selftests: rtnetlink: remove netdevsim device after ipsec
  offload test (bsc#1012628).
- gtp: Fix use-after-free in __gtp_encap_destroy() (bsc#1012628).
- net: axienet: Move reset before 64-bit DMA detection
  (bsc#1012628).
- ocfs2: Fix use of slab data with sendpage (bsc#1012628).
- sfc: fix crash when reading stats while NIC is resetting
  (bsc#1012628).
- net: nfc: Fix use-after-free caused by nfc_llcp_find_local
  (bsc#1012628).
- lib/ts_bm: reset initial match offset for every block of text
  (bsc#1012628).
- netfilter: conntrack: dccp: copy entire header to stack buffer,
  not just basic one (bsc#1012628).
- netfilter: nf_conntrack_sip: fix the
  ct_sip_parse_numerical_param() return value (bsc#1012628).
- netfilter: nf_tables: unbind non-anonymous set if rule
  construction fails (bsc#1012628).
- netfilter: nf_tables: fix underflow in chain reference counter
  (bsc#1012628).
- ipvlan: Fix return value of ipvlan_queue_xmit() (bsc#1012628).
- net: dsa: avoid suspicious RCU usage for synced VLAN-aware
  MAC addresses (bsc#1012628).
- netlink: Add __sock_i_ino() for __netlink_diag_dump()
  (bsc#1012628).
- drm/imx/lcdc: fix a NULL vs IS_ERR() bug in probe (bsc#1012628).
- drm/amd/display: Unconditionally print when DP sink power
  state fails (bsc#1012628).
- drm/amd/display: Add logging for display MALL refresh setting
  (bsc#1012628).
- drm/amd/display: fix is_timing_changed() prototype
  (bsc#1012628).
- radeon: avoid double free in ci_dpm_init() (bsc#1012628).
- drm/amd/display: Explicitly specify update type per plane info
  change (bsc#1012628).
- drm/i915/guc/slpc: Provide sysfs for efficient freq
  (bsc#1012628).
- drm/bridge: it6505: Move a variable assignment behind a null
  pointer check in receive_timing_debugfs_show() (bsc#1012628).
- Input: drv260x - sleep between polling GO bit (bsc#1012628).
- Input: cyttsp4_core - change del_timer_sync() to
  timer_shutdown_sync() (bsc#1012628).
- Input: tests - fix use-after-free and refcount underflow in
  input_test_exit() (bsc#1012628).
- Input: tests - modular KUnit tests should not depend on KUNIT=y
  (bsc#1012628).
- drm/bridge: ti-sn65dsi83: Fix enable error path (bsc#1012628).
- drm/bridge: tc358768: always enable HS video mode (bsc#1012628).
- drm/bridge: tc358768: fix PLL parameters computation
  (bsc#1012628).
- drm/bridge: tc358768: fix PLL target frequency (bsc#1012628).
- drm/bridge: tc358768: fix TCLK_ZEROCNT computation
  (bsc#1012628).
- drm/bridge: tc358768: Add atomic_get_input_bus_fmts()
  implementation (bsc#1012628).
- drm/bridge: tc358768: fix TCLK_TRAILCNT computation
  (bsc#1012628).
- drm/bridge: tc358768: fix THS_ZEROCNT computation (bsc#1012628).
- drm/bridge: tc358768: fix TXTAGOCNT computation (bsc#1012628).
- drm/bridge: tc358768: fix THS_TRAILCNT computation
  (bsc#1012628).
- Input: tests - fix input_test_match_device_id test
  (bsc#1012628).
- drm/vram-helper: fix function names in vram helper doc
  (bsc#1012628).
- ARM: dts: BCM5301X: Drop "clock-names" from the SPI node
  (bsc#1012628).
- ARM: dts: meson8b: correct uart_B and uart_C clock references
  (bsc#1012628).
- clk: vc5: Fix .driver_data content in i2c_device_id
  (bsc#1012628).
- clk: vc7: Fix .driver_data content in i2c_device_id
  (bsc#1012628).
- clk: rs9: Fix .driver_data content in i2c_device_id
  (bsc#1012628).
- Input: adxl34x - do not hardcode interrupt trigger type
  (bsc#1012628).
- drm: sun4i_tcon: use devm_clk_get_enabled in
  `sun4i_tcon_init_clocks` (bsc#1012628).
- drm/panel: sharp-ls043t1le01: adjust mode settings
  (bsc#1012628).
- driver: soc: xilinx: use _safe loop iterator to avoid a use
  after free (bsc#1012628).
- ASoC: dt-bindings: mediatek,mt8188-afe: correct clock name
  (bsc#1012628).
- ASoC: Intel: sof_sdw: remove SOF_SDW_TGL_HDMI for MeteorLake
  devices (bsc#1012628).
- ASoC: Intel: sof_sdw: start set codec init function with an
  adr index (bsc#1012628).
- drm/vkms: isolate pixel conversion functionality (bsc#1012628).
- drm: Add fixed-point helper to get rounded integer values
  (bsc#1012628).
- drm/vkms: Fix RGB565 pixel conversion (bsc#1012628).
- ARM: dts: stm32: Move ethernet MAC EEPROM from SoM to carrier
  boards (bsc#1012628).
- bus: ti-sysc: Fix dispc quirk masking bool variables
  (bsc#1012628).
- arm64: dts: microchip: sparx5: do not use PSCI on reference
  boards (bsc#1012628).
- drm/bridge: tc358767: Switch to devm MIPI-DSI helpers
  (bsc#1012628).
- arm64: dts: qcom: ipq9574: Update the size of GICC & GICV
  regions (bsc#1012628).
- clk: imx: scu: use _safe list iterator to avoid a use after free
  (bsc#1012628).
- hwmon: (f71882fg) prevent possible division by zero
  (bsc#1012628).
- RDMA/bnxt_re: Disable/kill tasklet only if it is enabled
  (bsc#1012628).
- RDMA/bnxt_re: Fix to remove unnecessary return labels
  (bsc#1012628).
- RDMA/bnxt_re: Use unique names while registering interrupts
  (bsc#1012628).
- RDMA/bnxt_re: Remove a redundant check inside bnxt_re_update_gid
  (bsc#1012628).
- RDMA/bnxt_re: Fix to remove an unnecessary log (bsc#1012628).
- drm/msm/dpu: enable DSPP_2/3 for LM_2/3 on sm8450 (bsc#1012628).
- drm/msm/dsi: don't allow enabling 14nm VCO with unprogrammed
  rate (bsc#1012628).
- drm/msm/dpu: fix cursor block register bit offset in msm8998
  hw catalog (bsc#1012628).
- drm/msm/dpu: Use V4.0 PCC DSPP sub-block in SC7[12]80
  (bsc#1012628).
- drm/msm/dpu: Set DPU_DATA_HCTL_EN for in INTF_SC7180_MASK
  (bsc#1012628).
- drm/nouveau: dispnv50: fix missing-prototypes warning
  (bsc#1012628).
- iommu/virtio: Detach domain on endpoint release (bsc#1012628).
- iommu/virtio: Return size mapped for a detached domain
  (bsc#1012628).
- clk: renesas: rzg2l: Fix CPG_SIPLL5_CLK1 register write
  (bsc#1012628).
- ARM: dts: gta04: Move model property out of pinctrl node
  (bsc#1012628).
- arm64: dts: qcom: qrb4210-rb2: Fix CD gpio for SDHC2
  (bsc#1012628).
- drm/bridge: anx7625: Prevent endless probe loop (bsc#1012628).
- ARM/mfd/gpio: Fixup TPS65010 regression on OMAP1 OSK1
  (bsc#1012628).
- ARM: omap1: Drop header on AMS Delta (bsc#1012628).
- ARM: omap1: Remove reliance on GPIO numbers from PalmTE
  (bsc#1012628).
- ARM: omap1: Remove reliance on GPIO numbers from SX1
  (bsc#1012628).
- Input: ads7846 - Convert to use software nodes (bsc#1012628).
- ARM/mmc: Convert old mmci-omap to GPIO descriptors
  (bsc#1012628).
- ARM: omap1: Fix up the Nokia 770 board device IRQs
  (bsc#1012628).
- ARM: omap1: Make serial wakeup GPIOs use descriptors
  (bsc#1012628).
- ARM: omap1: Exorcise the legacy GPIO header (bsc#1012628).
- ARM/gpio: Push OMAP2 quirk down into TWL4030 driver
  (bsc#1012628).
- ARM: omap2: Get USB hub reset GPIO from descriptor
  (bsc#1012628).
- ARM: omap2: Rewrite WLAN quirk to use GPIO descriptors
  (bsc#1012628).
- ARM/musb: omap2: Remove global GPIO numbers from TUSB6010
  (bsc#1012628).
- ARM: dts: qcom: msm8974: do not use underscore in node name
  (again) (bsc#1012628).
- arm64: dts: qcom: pm8998: don't use GIC_SPI for SPMI interrupts
  (bsc#1012628).
- arm64: dts: qcom: ipq6018: correct qrng unit address
  (bsc#1012628).
- arm64: dts: qcom: msm8916: correct camss unit address
  (bsc#1012628).
- arm64: dts: qcom: msm8916: correct MMC unit address
  (bsc#1012628).
- arm64: dts: qcom: msm8916: correct WCNSS unit address
  (bsc#1012628).
- arm64: dts: qcom: msm8953: correct IOMMU unit address
  (bsc#1012628).
- arm64: dts: qcom: msm8953: correct WCNSS unit address
  (bsc#1012628).
- arm64: dts: qcom: msm8976: correct MMC unit address
  (bsc#1012628).
- arm64: dts: qcom: msm8994: correct SPMI unit address
  (bsc#1012628).
- arm64: dts: qcom: msm8996: correct camss unit address
  (bsc#1012628).
- arm64: dts: qcom: sdm630: correct camss unit address
  (bsc#1012628).
- arm64: dts: qcom: sdm845: correct camss unit address
  (bsc#1012628).
- arm64: dts: qcom: sm6115: correct thermal-sensor unit address
  (bsc#1012628).
- arm64: dts: qcom: sm8350: correct DMA controller unit address
  (bsc#1012628).
- arm64: dts: qcom: sm8350: correct PCI phy unit address
  (bsc#1012628).
- arm64: dts: qcom: sm8350: correct USB phy unit address
  (bsc#1012628).
- arm64: dts: qcom: sm8550: correct crypto unit address
  (bsc#1012628).
- arm64: dts: qcom: sm8550: correct pinctrl unit address
  (bsc#1012628).
- arm64: dts: qcom: sdm845-polaris: add missing touchscreen
  child node reg (bsc#1012628).
- arm64: dts: qcom: apq8016-sbc: Fix regulator constraints
  (bsc#1012628).
- arm64: dts: qcom: apq8016-sbc: Fix 1.8V power rail on LS
  expansion (bsc#1012628).
- drm/bridge: ti-sn65dsi83: Fix enable/disable flow to meet spec
  (bsc#1012628).
- drm: bridge: samsung-dsim: Fix PMS Calculator on imx8m[mnp]
  (bsc#1012628).
- drm/panel: simple: fix active size for Ampire
  AM-480272H3TMQW-T01H (bsc#1012628).
- ARM: ep93xx: fix missing-prototype warnings (bsc#1012628).
- ARM: omap2: fix missing tick_broadcast() prototype
  (bsc#1012628).
- arm64: dts: qcom: pm7250b: add missing spmi-vadc include
  (bsc#1012628).
- arm64: dts: qcom: apq8096: fix fixed regulator name property
  (bsc#1012628).
- arm64: dts: mediatek: mt8183: Add
  mediatek,broken-save-restore-fw to kukui (bsc#1012628).
- arm64: dts: mediatek: mt8192: Add
  mediatek,broken-save-restore-fw to asurada (bsc#1012628).
- arm64: dts: mediatek: mt8195: Add
  mediatek,broken-save-restore-fw to cherry (bsc#1012628).
- ARM: dts: stm32: Shorten the AV96 HDMI sound card name
  (bsc#1012628).
- memory: brcmstb_dpfe: fix testing array offset after use
  (bsc#1012628).
- ARM: dts: qcom: apq8074-dragonboard: Set DMA as remotely
  controlled (bsc#1012628).
- ASoC: es8316: Increment max value for ALC Capture Target Volume
  control (bsc#1012628).
- ASoC: es8316: Do not set rate constraints for unsupported MCLKs
  (bsc#1012628).
- ARM: dts: meson8: correct uart_B and uart_C clock references
  (bsc#1012628).
- soc/fsl/qe: fix usb.c build errors (bsc#1012628).
- RDMA/irdma: avoid fortify-string warning in irdma_clr_wqes
  (bsc#1012628).
- IB/hfi1: Fix wrong mmu_node used for user SDMA packet after
  invalidate (bsc#1012628).
- RDMA/hns: Fix hns_roce_table_get return value (bsc#1012628).
- ARM: dts: iwg20d-q7-common: Fix backlight pwm specifier
  (bsc#1012628).
- arm64: dts: renesas: ulcb-kf: Remove flow control for SCIF1
  (bsc#1012628).
- drm/msm/dpu: set DSC flush bit correctly at MDP CTL flush
  register (bsc#1012628).
- drm/msm/dpu: always clear every individual pending flush mask
  (bsc#1012628).
- fbdev: omapfb: lcd_mipid: Fix an error handling path in
  mipid_spi_probe() (bsc#1012628).
- dt-bindings: arm-smmu: Fix SC8280XP Adreno binding
  (bsc#1012628).
- drm/i915: Fix limited range csc matrix (bsc#1012628).
- drm/i915: hide mkwrite_device_info() better (bsc#1012628).
- drm/i915/display: Move display device info to header under
  display/ (bsc#1012628).
- drm/i915: Convert INTEL_INFO()->display to a pointer
  (bsc#1012628).
- drm/i915/display: Move display runtime info to display structure
  (bsc#1012628).
- drm/i915/display: Make display responsible for probing its
  own IP (bsc#1012628).
- drm/i915: No 10bit gamma on desktop gen3 parts (bsc#1012628).
- arm64: dts: rockchip: Assign ES8316 MCLK rate on rk3588-rock-5b
  (bsc#1012628).
- arm64: dts: ti: k3-j7200: Fix physical address of pin
  (bsc#1012628).
- Input: pm8941-powerkey - fix debounce on gen2+ PMICs
  (bsc#1012628).
- arm64: dts: rockchip: Fix compatible for Bluetooth on
  rk3566-anbernic (bsc#1012628).
- ARM: dts: stm32: Fix audio routing on STM32MP15xx DHCOM PDK2
  (bsc#1012628).
- accel/habanalabs: fix gaudi2_get_tpc_idle_status() return
  (bsc#1012628).
- ARM: dts: stm32: fix i2s endpoint format property for
  stm32mp15xx-dkx (bsc#1012628).
- hwmon: (gsc-hwmon) fix fan pwm temperature scaling
  (bsc#1012628).
- hwmon: (pmbus/adm1275) Fix problems with temperature monitoring
  on ADM1272 (bsc#1012628).
- ARM: dts: BCM5301X: fix duplex-full => full-duplex
  (bsc#1012628).
- clk: Export clk_hw_forward_rate_request() (bsc#1012628).
- drm/amd/display: Fix a test CalculatePrefetchSchedule()
  (bsc#1012628).
- drm/amd/display: Fix a test dml32_rq_dlg_get_rq_reg()
  (bsc#1012628).
- drm/amdkfd: Fix potential deallocation of previously deallocated
  memory (bsc#1012628).
- soc: mediatek: SVS: Fix MT8192 GPU node name (bsc#1012628).
- drm/amd/display: Fix artifacting on eDP panels when engaging
  freesync video mode (bsc#1012628).
- drm/radeon: fix possible division-by-zero errors (bsc#1012628).
- HID: uclogic: Modular KUnit tests should not depend on KUNIT=y
  (bsc#1012628).
- RDMA/rxe: Fix access checks in rxe_check_bind_mw (bsc#1012628).
- amdgpu: validate offset_in_bo of drm_amdgpu_gem_va
  (bsc#1012628).
- drm/msm/a6xx: don't set IO_PGTABLE_QUIRK_ARM_OUTER_WBWA with
  coherent SMMU (bsc#1012628).
- drm/msm/a5xx: really check for A510 in a5xx_gpu_init
  (bsc#1012628).
- RDMA/bnxt_re: wraparound mbox producer index (bsc#1012628).
- RDMA/bnxt_re: Avoid calling wake_up threads from spin_lock
  context (bsc#1012628).
- clk: imx: composite-8m: Add imx8m_divider_determine_rate
  (bsc#1012628).
- clk: imx: clk-imxrt1050: fix memory leak in
  imxrt1050_clocks_probe (bsc#1012628).
- clk: imx: clk-imx8mn: fix memory leak in imx8mn_clocks_probe
  (bsc#1012628).
- clk: imx93: fix memory leak and missing unwind goto in
  imx93_clocks_probe (bsc#1012628).
- clk: imx: clk-imx8mp: improve error handling in
  imx8mp_clocks_probe() (bsc#1012628).
- clk: mediatek: fix of_iomap memory leak (bsc#1012628).
- arm64: dts: qcom: qdu1000: Flush RSC sleep & wake votes
  (bsc#1012628).
- arm64: dts: qcom: sdm670: Flush RSC sleep & wake votes
  (bsc#1012628).
- arm64: dts: qcom: sdm845: Flush RSC sleep & wake votes
  (bsc#1012628).
- arm64: dts: qcom: sm8550: Flush RSC sleep & wake votes
  (bsc#1012628).
- arm64: dts: qcom: sm8250-edo: Panel framebuffer is 2.5k instead
  of 4k (bsc#1012628).
- arm64: dts: qcom: sm8550: Add missing interconnect path to
  USB HC (bsc#1012628).
- clk: bcm: rpi: Fix off by one in raspberrypi_discover_clocks()
  (bsc#1012628).
- clk: clocking-wizard: Fix Oops in clk_wzrd_register_divider()
  (bsc#1012628).
- clk: tegra: tegra124-emc: Fix potential memory leak
  (bsc#1012628).
- arm64: dts: ti: k3-j721e-beagleboneai64: Fix mailbox node status
  (bsc#1012628).
- arm64: dts: ti: k3-j784s4-evm: Fix main_i2c0 alias
  (bsc#1012628).
- arm64: dts: ti: k3-j784s4: Fix wakeup pinmux range and pinctrl
  node offsets (bsc#1012628).
- arm64: dts: ti: k3-am69-sk: Fix main_i2c0 alias (bsc#1012628).
- ALSA: ac97: Fix possible NULL dereference in snd_ac97_mixer
  (bsc#1012628).
- drm/msm/dpu: do not enable color-management if DSPPs are not
  available (bsc#1012628).
- drm/msm/dpu: Fix slice_last_group_size calculation
  (bsc#1012628).
- drm/msm/dsi: Remove incorrect references to slice_count
  (bsc#1012628).
- drm/msm/dp: Drop aux devices together with DP controller
  (bsc#1012628).
- drm/msm/dp: Free resources after unregistering them
  (bsc#1012628).
- arm64: dts: mediatek: Add cpufreq nodes for MT8192
  (bsc#1012628).
- arm64: dts: mediatek: mt8192: Fix CPUs capacity-dmips-mhz
  (bsc#1012628).
- arm64: dts: mt7986: increase bl2 partition on NAND of Bananapi
  R3 (bsc#1012628).
- drm/amdgpu: Fix memcpy() in
  sienna_cichlid_append_powerplay_table function (bsc#1012628).
- drm/amdgpu: Fix usage of UMC fill record in RAS (bsc#1012628).
- drm/msm/dpu: Drop unused poll_timeout_wr_ptr PINGPONG callback
  (bsc#1012628).
- drm/msm/dpu: Move autorefresh disable from CMD encoder to
  pingpong (bsc#1012628).
- drm/msm/dpu: Disable pingpong TE on DPU 5.0.0 and above
  (bsc#1012628).
- drm/msm/dpu: fix sc7280 and sc7180 PINGPONG done interrupts
  (bsc#1012628).
- drm/msm/dpu: correct MERGE_3D length (bsc#1012628).
- clk: mediatek: clk-mtk: Grab iomem pointer for divider clocks
  (bsc#1012628).
- clk: mediatek: clk-mt8173-apmixedsys: Fix return value for
  of_iomap() error (bsc#1012628).
- clk: mediatek: clk-mt8173-apmixedsys: Fix iomap not released
  issue (bsc#1012628).
- clk: vc5: check memory returned by kasprintf() (bsc#1012628).
- clk: cdce925: check return value of kasprintf() (bsc#1012628).
- clk: si5341: return error if one synth clock registration fails
  (bsc#1012628).
- clk: si5341: check return value of {devm_}kasprintf()
  (bsc#1012628).
- clk: si5341: free unused memory on probe failure (bsc#1012628).
- clk: keystone: sci-clk: check return value of kasprintf()
  (bsc#1012628).
- clk: ti: clkctrl: check return value of kasprintf()
  (bsc#1012628).
- clk: clocking-wizard: check return value of devm_kasprintf()
  (bsc#1012628).
- drivers: meson: secure-pwrc: always enable DMA domain
  (bsc#1012628).
- ovl: update of dentry revalidate flags after copy up
  (bsc#1012628).
- ASoC: imx-audmix: check return value of devm_kasprintf()
  (bsc#1012628).
- clk: Fix memory leak in devm_clk_notifier_register()
  (bsc#1012628).
- ARM: dts: lan966x: kontron-d10: fix board reset (bsc#1012628).
- ARM: dts: lan966x: kontron-d10: fix SPI CS (bsc#1012628).
- ASoC: amd: acp: clear pdm dma interrupt mask (bsc#1012628).
- iommufd: Do not access the area pointer after unlocking
  (bsc#1012628).
- iommufd: Call iopt_area_contig_done() under the lock
  (bsc#1012628).
- PCI: cadence: Fix Gen2 Link Retraining process (bsc#1012628).
- PCI: vmd: Reset VMD config register between soft reboots
  (bsc#1012628).
- scsi: qedf: Fix NULL dereference in error handling
  (bsc#1012628).
- pinctrl: bcm2835: Handle gpiochip_add_pin_range() errors
  (bsc#1012628).
- platform/x86: lenovo-yogabook: Fix work race on remove()
  (bsc#1012628).
- platform/x86: lenovo-yogabook: Reprobe devices on remove()
  (bsc#1012628).
- platform/x86: lenovo-yogabook: Set default keyboard backligh
  brightness on probe() (bsc#1012628).
- PCI/ASPM: Disable ASPM on MFD function removal to avoid
  use-after-free (bsc#1012628).
- scsi: 3w-xxxx: Add error handling for initialization failure
  in tw_probe() (bsc#1012628).
- pinctrl: at91: fix a couple NULL vs IS_ERR() checks
  (bsc#1012628).
- PCI: pciehp: Cancel bringup sequence if card is not present
  (bsc#1012628).
- perf evsel: Don't let for_each_group() treat the head of the
  list as one of its nodes (bsc#1012628).
- PCI: ftpci100: Release the clock resources (bsc#1012628).
- pinctrl: sunplus: Add check for kmalloc (bsc#1012628).
- scsi: ufs: Declare ufshcd_{hold,release}() once (bsc#1012628).
- PCI: Add pci_clear_master() stub for non-CONFIG_PCI
  (bsc#1012628).
- scsi: lpfc: Revise NPIV ELS unsol rcv cmpl logic to drop ndlp
  based on nlp_state (bsc#1012628).
- scsi: ufs: core: Increase the START STOP UNIT timeout from
  one to ten seconds (bsc#1012628).
- scsi: ufs: core: Fix handling of lrbp->cmd (bsc#1012628).
- pinctrl: tegra: Duplicate pinmux functions table (bsc#1012628).
- perf bench: Add missing setlocale() call to allow usage of
  %%'d style formatting (bsc#1012628).
- pinctrl: cherryview: Return correct value if pin in push-pull
  mode (bsc#1012628).
- platform/x86:intel/pmc: Remove Meteor Lake S platform support
  (bsc#1012628).
- platform/x86: think-lmi: mutex protection around multiple WMI
  calls (bsc#1012628).
- platform/x86: think-lmi: Correct System password interface
  (bsc#1012628).
- platform/x86: think-lmi: Correct NVME password handling
  (bsc#1012628).
- pinctrl:sunplus: Add check for kmalloc (bsc#1012628).
- pinctrl: npcm7xx: Add missing check for ioremap (bsc#1012628).
- kcsan: Don't expect 64 bits atomic builtins from 32 bits
  architectures (bsc#1012628).
- powerpc/interrupt: Don't read MSR from
  interrupt_exit_kernel_prepare() (bsc#1012628).
- powerpc/signal32: Force inlining of __unsafe_save_user_regs()
  and save_tm_user_regs_unsafe() (bsc#1012628).
- perf script: Fix allocation of evsel->priv related to per-event
  dump files (bsc#1012628).
- platform/x86: thinkpad_acpi: Fix lkp-tests warnings for platform
  profiles (bsc#1012628).
- platform/x86/intel/pmc: Add resume callback (bsc#1012628).
- platform/x86/intel/pmc/mtl: Put devices in D3 during resume
  (bsc#1012628).
- perf dwarf-aux: Fix off-by-one in die_get_varname()
  (bsc#1012628).
- perf metric: Fix no group check (bsc#1012628).
- perf tests task_analyzer: Fix bad substitution ${$1}
  (bsc#1012628).
- perf tests task_analyzer: Skip tests if no libtraceevent support
  (bsc#1012628).
- platform/x86/dell/dell-rbtn: Fix resources leaking on error path
  (bsc#1012628).
- perf tool x86: Consolidate is_amd check into single function
  (bsc#1012628).
- perf tool x86: Fix perf_env memory leak (bsc#1012628).
- powerpc/64s: Fix VAS mm use after free (bsc#1012628).
- pinctrl: freescale: Fix a memory out of bounds when num_configs
  is 1 (bsc#1012628).
- pinctrl: microchip-sgpio: check return value of devm_kasprintf()
  (bsc#1012628).
- pinctrl: at91-pio4: check return value of devm_kasprintf()
  (bsc#1012628).
- perf stat: Reset aggr stats for each run (bsc#1012628).
- scsi: ufs: core: Remove a ufshcd_add_command_trace() call
  (bsc#1012628).
- scsi: ufs: core: mcq: Fix the incorrect OCS value for the
  device command (bsc#1012628).
- powerpc/powernv/sriov: perform null check on iov before
  dereferencing iov (bsc#1012628).
- powerpc: update ppc_save_regs to save current r1 in pt_regs
  (bsc#1012628).
- riscv: hibernation: Remove duplicate call of
  suspend_restore_csrs (bsc#1012628).
- PCI: qcom: Use DWC helpers for modifying the read-only DBI
  registers (bsc#1012628).
- PCI: qcom: Disable write access to read only registers for IP
  v2.9.0 (bsc#1012628).
- platform/x86:intel/pmc: Update maps for Meteor Lake P/M
  platforms (bsc#1012628).
- riscv: uprobes: Restore thread.bad_cause (bsc#1012628).
- powerpc/book3s64/mm: Fix DirectMap stats in /proc/meminfo
  (bsc#1012628).
- powerpc/mm/dax: Fix the condition when checking if altmap
  vmemap can cross-boundary (bsc#1012628).
- perf test: Set PERF_EXEC_PATH for script execution
  (bsc#1012628).
- riscv: hibernate: remove WARN_ON in save_processor_state
  (bsc#1012628).
- PCI: endpoint: Fix a Kconfig prompt of vNTB driver
  (bsc#1012628).
- PCI: endpoint: functions/pci-epf-test: Fix dma_chan direction
  (bsc#1012628).
- PCI: vmd: Fix uninitialized variable usage in
  vmd_enable_domain() (bsc#1012628).
- vfio/mdev: Move the compat_class initialization to module init
  (bsc#1012628).
- hwrng: virtio - Fix race on data_avail and actual data
  (bsc#1012628).
- modpost: remove broken calculation of exception_table_entry size
  (bsc#1012628).
- crypto: nx - fix build warnings when DEBUG_FS is not enabled
  (bsc#1012628).
- modpost: fix section mismatch message for R_ARM_ABS32
  (bsc#1012628).
- modpost: fix section mismatch message for
  R_ARM_{PC24,CALL,JUMP24} (bsc#1012628).
- crypto: marvell/cesa - Fix type mismatch warning (bsc#1012628).
- crypto: jitter - correct health test during initialization
  (bsc#1012628).
- dt-bindings: qcom-qce: Fix compatible combinations for SM8150
  and IPQ4019 SoCs (bsc#1012628).
- scripts/mksysmap: Fix badly escaped '$' (bsc#1012628).
- modpost: fix off by one in is_executable_section()
  (bsc#1012628).
- ARC: define ASM_NL and __ALIGN(_STR) outside #ifdef __ASSEMBLY__
  guard (bsc#1012628).
- crypto: qat - unmap buffer before free for DH (bsc#1012628).
- crypto: qat - unmap buffers before free for RSA (bsc#1012628).
- NFSv4.2: fix wrong shrinker_id (bsc#1012628).
- NFSv4.1: freeze the session table upon receiving
  NFS4ERR_BADSESSION (bsc#1012628).
- SMB3: Do not send lease break acknowledgment if all file
  handles have been closed (bsc#1012628).
- dax: Fix dax_mapping_release() use after free (bsc#1012628).
- dax: Introduce alloc_dev_dax_id() (bsc#1012628).
- dax/kmem: Pass valid argument to memory_group_register_static
  (bsc#1012628).
- hwrng: st - keep clock enabled while hwrng is registered
  (bsc#1012628).
- ALSA: hda/realtek: Enable mute/micmute LEDs and limit mic
  boost on EliteBook (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Clevo NPx0SNx (bsc#1012628).
- ALSA: jack: Fix mutex call in snd_jack_report() (bsc#1012628).
- ALSA: pcm: Fix potential data race at PCM memory allocation
  helpers (bsc#1012628).
- apparmor: fix: kzalloc perms tables for shared dfas
  (bsc#1012628).
- block: fix signed int overflow in Amiga partition support
  (bsc#1012628).
- block: add overflow checks for Amiga partition support
  (bsc#1012628).
- block: change all __u32 annotations to __be32 in
  affs_hardblocks.h (bsc#1012628).
- block: increment diskseq on all media change events
  (bsc#1012628).
- mmc: block: ioctl: do write error check for spi (bsc#1012628).
- btrfs: fix race when deleting free space root from the dirty
  cow roots list (bsc#1012628).
- btrfs: do not BUG_ON() on tree mod log failure at
  balance_level() (bsc#1012628).
- SUNRPC: Fix UAF in svc_tcp_listen_data_ready() (bsc#1012628).
- kbuild: Fix CFI failures with GCOV (bsc#1012628).
- kbuild: Disable GCOV for *.mod.o (bsc#1012628).
- cxl/region: Move cache invalidation before region teardown,
  and before setup (bsc#1012628).
- cxl/region: Flag partially torn down regions as unusable
  (bsc#1012628).
- cxl/region: Fix state transitions after reset failure
  (bsc#1012628).
- tools/testing/cxl: Fix command effects for inject/clear poison
  (bsc#1012628).
- kbuild: builddeb: always make modules_install, to install
  modules.builtin* (bsc#1012628).
- kbuild: deb-pkg: remove the CONFIG_MODULES check in buildeb
  (bsc#1012628).
- efi/libstub: Disable PCI DMA before grabbing the EFI memory map
  (bsc#1012628).
- cifs: prevent use-after-free by freeing the cfile later
  (bsc#1012628).
- cifs: do all necessary checks for credits within or before
  locking (bsc#1012628).
- smb: client: fix broken file attrs with nodfs mounts
  (bsc#1012628).
- smb: client: fix shared DFS root mounts with different prefixes
  (bsc#1012628).
- ksmbd: avoid field overflow warning (bsc#1012628).
- arm64: sme: Use STR P to clear FFR context field in streaming
  SVE mode (bsc#1012628).
- x86/efi: Make efi_set_virtual_address_map IBT safe
  (bsc#1012628).
- w1: w1_therm: fix locking behavior in convert_t (bsc#1012628).
- w1: fix loop in w1_fini() (bsc#1012628).
- dt-bindings: power: reset: qcom-pon: Only allow reboot-mode
  pre-pmk8350 (bsc#1012628).
- f2fs: do not allow to defragment files have FI_COMPRESS_RELEASED
  (bsc#1012628).
- sh: j2: Use ioremap() to translate device tree address into
  kernel memory (bsc#1012628).
- cpufreq: tegra194: Fix an error handling path in
  tegra194_cpufreq_probe() (bsc#1012628).
- USB: Extend pci resume function to handle PM events
  (bsc#1012628).
- xhci: Improve the XHCI system resume time (bsc#1012628).
- usb: dwc2: Fix some error handling paths (bsc#1012628).
- serial: 8250: omap: Fix freeing of resources on failed register
  (bsc#1012628).
- interconnect: qcom: rpm: Rename icc provider num_clocks to
  num_bus_clocks (bsc#1012628).
- interconnect: qcom: rpm: Don't use clk_get_optional for bus
  clocks anymore (bsc#1012628).
- clk: qcom: gcc: ipq5332: Use floor ops for SDCC clocks
  (bsc#1012628).
- clk: qcom: mmcc-msm8974: remove oxili_ocmemgx_clk (bsc#1012628).
- clk: qcom: camcc-sc7180: Add parent dependency to all camera
  GDSCs (bsc#1012628).
- clk: qcom: gcc-ipq6018: Use floor ops for sdcc clocks
  (bsc#1012628).
- clk: qcom: gcc-qcm2290: Mark RCGs shared where applicable
  (bsc#1012628).
- media: usb: Check az6007_read() return value (bsc#1012628).
- media: amphion: drop repeated codec data for vc1l format
  (bsc#1012628).
- media: amphion: drop repeated codec data for vc1g format
  (bsc#1012628).
- media: common: saa7146: Avoid a leak in vmalloc_to_sg()
  (bsc#1012628).
- media: videodev2.h: Fix p_s32 and p_s64 pointer types
  (bsc#1012628).
- media: amphion: initiate a drain of the capture queue in
  dynamic resolution change (bsc#1012628).
- media: videodev2.h: Fix struct v4l2_input tuner index comment
  (bsc#1012628).
- media: usb: siano: Fix warning due to null work_func_t function
  pointer (bsc#1012628).
- media: i2c: imx296: fix error checking in
  imx296_read_temperature() (bsc#1012628).
- media: i2c: Correct format propagation for st-mipid02
  (bsc#1012628).
- media: renesas: fdp1: Identify R-Car Gen2 versions
  (bsc#1012628).
- media: hi846: fix usage of pm_runtime_get_if_in_use()
  (bsc#1012628).
- media: mediatek: vcodec: using decoder status instead of core
  work count (bsc#1012628).
- clk: qcom: ipq6018: fix networking resets (bsc#1012628).
- clk: qcom: dispcc-qcm2290: Fix BI_TCXO_AO handling
  (bsc#1012628).
- clk: qcom: dispcc-qcm2290: Fix GPLL0_OUT_DIV handling
  (bsc#1012628).
- clk: qcom: ipq5332: fix the src parameter in
  ftbl_gcc_apss_axi_clk_src (bsc#1012628).
- clk: qcom: ipq5332: fix the order of SLEEP_CLK and XO clock
  (bsc#1012628).
- clk: qcom: mmcc-msm8974: use clk_rcg2_shared_ops for mdp_clk_src
  clock (bsc#1012628).
- staging: vchiq_arm: mark vchiq_platform_init() static
  (bsc#1012628).
- soundwire: qcom: use consistently 'ctrl' as state variable name
  (bsc#1012628).
- soundwire: qcom: fix unbalanced pm_runtime_put() (bsc#1012628).
- soundwire: debugfs: fix unbalanced pm_runtime_put()
  (bsc#1012628).
- usb: dwc3: qcom: Fix potential memory leak (bsc#1012628).
- usb: gadget: u_serial: Add null pointer check in gserial_suspend
  (bsc#1012628).
- extcon: Fix kernel doc of property fields to avoid warnings
  (bsc#1012628).
- extcon: Fix kernel doc of property capability fields to avoid
  warnings (bsc#1012628).
- usb: phy: phy-tahvo: fix memory leak in tahvo_usb_probe()
  (bsc#1012628).
- usb: hide unused usbfs_notify_suspend/resume functions
  (bsc#1012628).
- usb: misc: eud: Fix eud sysfs path (use 'qcom_eud')
  (bsc#1012628).
- serial: core: lock port for stop_rx() in uart_suspend_port()
  (bsc#1012628).
- serial: 8250: lock port for stop_rx() in omap8250_irq()
  (bsc#1012628).
- serial: core: lock port for start_rx() in uart_resume_port()
  (bsc#1012628).
- serial: 8250: lock port for UART_IER access in omap8250_irq()
  (bsc#1012628).
- kernfs: fix missing kernfs_idr_lock to remove an ID from the
  IDR (bsc#1012628).
- lkdtm: replace ll_rw_block with submit_bh (bsc#1012628).
- i3c: master: svc: fix cpu schedule in spin lock (bsc#1012628).
- coresight: Fix loss of connection info when a module is unloaded
  (bsc#1012628).
- coresight: etm4x: Fix missing trctraceidr file in sysfs
  (bsc#1012628).
- power: supply: rt9467: Make charger-enable control as logic
  level (bsc#1012628).
- mfd: rt5033: Drop rt5033-battery sub-device (bsc#1012628).
- media: venus: helpers: Fix ALIGN() of non power of two
  (bsc#1012628).
- media: atomisp: gc0310: Fix double free in gc0310_remove()
  (bsc#1012628).
- media: atomisp: gmin_platform: fix out_len in
  gmin_get_config_dsm_var() (bsc#1012628).
- media: atomisp: ov2680: Stop using half pixelclock for binned
  modes (bsc#1012628).
- sh: Avoid using IRQ0 on SH3 and SH4 (bsc#1012628).
- gfs2: Fix duplicate should_fault_in_pages() call (bsc#1012628).
- f2fs: fix potential deadlock due to unpaired node_write lock
  use (bsc#1012628).
- f2fs: fix to avoid NULL pointer dereference f2fs_write_end_io()
  (bsc#1012628).
- f2fs: support errors=remount-ro|continue|panic mountoption
  (bsc#1012628).
- f2fs: fix the wrong condition to determine atomic context
  (bsc#1012628).
- f2fs: flush error flags in workqueue (bsc#1012628).
- KVM: s390: fix KVM_S390_GET_CMMA_BITS for GFNs in memslot holes
  (bsc#1012628).
- usb: dwc3: qcom: Release the correct resources in
  dwc3_qcom_remove() (bsc#1012628).
- usb: dwc3: qcom: Fix an error handling path in dwc3_qcom_probe()
  (bsc#1012628).
- usb: common: usb-conn-gpio: Set last role to unknown before
  initial detection (bsc#1012628).
- usb: dwc3-meson-g12a: Fix an error handling path in
  dwc3_meson_g12a_probe() (bsc#1012628).
- rtla/hwnoise: Reduce runtime to 75%% (bsc#1012628).
- mfd: wcd934x: Fix an error handling path in wcd934x_slim_probe()
  (bsc#1012628).
- mfd: intel-lpss: Add missing check for platform_get_resource
  (bsc#1012628).
- Revert "usb: common: usb-conn-gpio: Set last role to unknown
  before initial detection" (bsc#1012628).
- serial: 8250_omap: Use force_suspend and resume for system
  suspend (bsc#1012628).
- drivers: fwnode: fix fwnode_irq_get[_byname]() (bsc#1012628).
- cdx: fix driver managed dma support (bsc#1012628).
- nvmem: sunplus-ocotp: release otp->clk before return
  (bsc#1012628).
- nvmem: imx-ocotp: Reverse MAC addresses on all i.MX derivates
  (bsc#1012628).
- test_firmware: return ENOMEM instead of ENOSPC on failed memory
  allocation (bsc#1012628).
- nvmem: rmem: Use NVMEM_DEVID_AUTO (bsc#1012628).
- bus: fsl-mc: don't assume child devices are all fsl-mc devices
  (bsc#1012628).
- mfd: stmfx: Fix error path in stmfx_chip_init (bsc#1012628).
- mfd: stmfx: Nullify stmfx->vdd in case of error (bsc#1012628).
- KVM: s390: vsie: fix the length of APCB bitmap (bsc#1012628).
- KVM: s390/diag: fix racy access of physical cpu number in diag
  9c handler (bsc#1012628).
- cpufreq: mediatek: correct voltages for MT7622 and MT7623
  (bsc#1012628).
- misc: fastrpc: check return value of devm_kasprintf()
  (bsc#1012628).
- clk: qcom: mmcc-msm8974: fix MDSS_GDSC power flags
  (bsc#1012628).
- hwtracing: hisi_ptt: Fix potential sleep in atomic context
  (bsc#1012628).
- phy: qcom: qmp-combo: fix Display Port PHY configuration for
  SM8550 (bsc#1012628).
- mfd: stmpe: Only disable the regulators if they are enabled
  (bsc#1012628).
- phy: tegra: xusb: check return value of devm_kzalloc()
  (bsc#1012628).
- lib/bitmap: drop optimization of bitmap_{from,to}_arr64
  (bsc#1012628).
- pwm: imx-tpm: force 'real_period' to be zero in suspend
  (bsc#1012628).
- pwm: sysfs: Do not apply state to already disabled PWMs
  (bsc#1012628).
- pwm: ab8500: Fix error code in probe() (bsc#1012628).
- pwm: mtk_disp: Fix the disable flow of disp_pwm (bsc#1012628).
- md/raid10: fix the condition to call bio_end_io_acct()
  (bsc#1012628).
- perf bpf: Move the declaration of struct rq (bsc#1012628).
- blk-throttle: Fix io statistics for cgroup v1 (bsc#1012628).
- rtc: st-lpc: Release some resources in st_rtc_probe() in case
  of error (bsc#1012628).
- drm/i915/psr: Use hw.adjusted mode when calculating io/fast
  wake times (bsc#1012628).
- drm/i915/guc/slpc: Apply min softlimit correctly (bsc#1012628).
- f2fs: check return value of freeze_super() (bsc#1012628).
- virtio-vdpa: Fix unchecked call to NULL set_vq_affinity
  (bsc#1012628).
- tools/virtio: fix build break for aarch64 (bsc#1012628).
- media: tc358746: select CONFIG_GENERIC_PHY (bsc#1012628).
- media: cec: i2c: ch7322: also select REGMAP (bsc#1012628).
- sctp: fix potential deadlock on &net->sctp.addr_wq_lock
  (bsc#1012628).
- net/sched: act_ipt: add sanity checks on table name and hook
  locations (bsc#1012628).
- net/sched: act_ipt: add sanity checks on skb before calling
  target (bsc#1012628).
- net/sched: act_ipt: zero skb->cb before calling target
  (bsc#1012628).
- spi: spi-geni-qcom: enable SPI_CONTROLLER_MUST_TX for GPI DMA
  mode (bsc#1012628).
- net: mscc: ocelot: don't report that RX timestamping is enabled
  by default (bsc#1012628).
- net: mscc: ocelot: don't keep PTP configuration of all ports
  in single structure (bsc#1012628).
- net: dsa: felix: don't drop PTP frames with tag_8021q when RX
  timestamping is disabled (bsc#1012628).
- net: dsa: sja1105: always enable the INCL_SRCPT option
  (bsc#1012628).
- net: dsa: tag_sja1105: always prefer source port information
  from INCL_SRCPT (bsc#1012628).
- Add MODULE_FIRMWARE() for FIRMWARE_TG357766 (bsc#1012628).
- Bluetooth: fix invalid-bdaddr quirk for non-persistent setup
  (bsc#1012628).
- Bluetooth: ISO: use hci_sync for setting CIG parameters
  (bsc#1012628).
- Bluetooth: MGMT: Fix marking SCAN_RSP as not connectable
  (bsc#1012628).
- sfc: support for devlink port requires MAE access (bsc#1012628).
- ibmvnic: Do not reset dql stats on NON_FATAL err (bsc#1012628).
- net: dsa: vsc73xx: fix MTU configuration (bsc#1012628).
- mlxsw: minimal: fix potential memory leak in
  mlxsw_m_linecards_init (bsc#1012628).
- spi: bcm-qspi: return error if neither hif_mspi nor mspi is
  available (bsc#1012628).
- mailbox: ti-msgmgr: Fill non-message tx data fields with 0x0
  (bsc#1012628).
- f2fs: fix error path handling in truncate_dnode() (bsc#1012628).
- octeontx2-af: cn10kb: fix interrupt csr addresses (bsc#1012628).
- octeontx2-af: Fix mapping for NIX block from CGX connection
  (bsc#1012628).
- octeontx2-af: Add validation before accessing cgx and lmac
  (bsc#1012628).
- octeontx2-af: Reset MAC features in FLR (bsc#1012628).
- ntfs: Fix panic about slab-out-of-bounds caused by
  ntfs_listxattr() (bsc#1012628).
- powerpc: allow PPC_EARLY_DEBUG_CPM only when SERIAL_CPM=y
  (bsc#1012628).
- powerpc: dts: turris1x.dts: Fix PCIe MEM size for pci2 node
  (bsc#1012628).
- net: bridge: keep ports without IFF_UNICAST_FLT in BR_PROMISC
  mode (bsc#1012628).
- net: dsa: tag_sja1105: fix source port decoding in
  vlan_filtering=0 bridge mode (bsc#1012628).
- net: fix net_dev_start_xmit trace event vs
  skb_transport_offset() (bsc#1012628).
- tcp: annotate data races in __tcp_oow_rate_limited()
  (bsc#1012628).
- vduse: fix NULL pointer dereference (bsc#1012628).
- bpf, btf: Warn but return no error for NULL btf from
  __register_btf_kfunc_id_set() (bsc#1012628).
- xsk: Honor SO_BINDTODEVICE on bind (bsc#1012628).
- net/sched: act_pedit: Add size check for TCA_PEDIT_PARMS_EX
  (bsc#1012628).
- drm/i915/psr: Fix BDW PSR AUX CH data register offsets
  (bsc#1012628).
- fanotify: disallow mount/sb marks on kernel internal pseudo fs
  (bsc#1012628).
- riscv: move memblock_allow_resize() after linear mapping is
  ready (bsc#1012628).
- pptp: Fix fib lookup calls (bsc#1012628).
- net: dsa: tag_sja1105: fix MAC DA patching from meta frames
  (bsc#1012628).
- net: dsa: sja1105: always enable the send_meta options
  (bsc#1012628).
- octeontx-af: fix hardware timestamp configuration (bsc#1012628).
- afs: Fix accidental truncation when storing data (bsc#1012628).
- s390/qeth: Fix vipa deletion (bsc#1012628).
- risc-v: Fix order of IPI enablement vs RCU startup
  (bsc#1012628).
- sh: dma: Fix DMA channel offset calculation (bsc#1012628).
- apparmor: fix missing error check for rhashtable_insert_fast
  (bsc#1012628).
- apparmor: add missing failure check in compute_xmatch_perms
  (bsc#1012628).
- apparmor: fix policy_compat permission remap with extended
  permissions (bsc#1012628).
- apparmor: fix profile verification and enable it (bsc#1012628).
- i2c: xiic: Don't try to handle more interrupt events after error
  (bsc#1012628).
- writeback: account the number of pages written back
  (bsc#1012628).
- lib: dhry: fix sleeping allocations inside non-preemptable
  section (bsc#1012628).
- Revert "drm/amd/display: Move DCN314 DOMAIN power control to
  DMCUB" (bsc#1012628).
- arm64/signal: Restore TPIDR2 register rather than memory state
  (bsc#1012628).
- irqchip/loongson-liointc: Fix IRQ trigger polarity
  (bsc#1012628).
- nfsd: move init of percpu reply_cache_stats counters back to
  nfsd_init_net (bsc#1012628).
- irqchip/loongson-pch-pic: Fix potential incorrect hwirq
  assignment (bsc#1012628).
- NFSD: add encoding of op_recall flag for write delegation
  (bsc#1012628).
- irqchip/loongson-pch-pic: Fix initialization of HT vector
  register (bsc#1012628).
- io_uring: wait interruptibly for request completions on exit
  (bsc#1012628).
- mm/mglru: make memcg_lru->lock irq safe (bsc#1012628).
- mmc: core: disable TRIM on Kingston EMMC04G-M627 (bsc#1012628).
- mmc: core: disable TRIM on Micron MTFC4GACAJCN-1M (bsc#1012628).
- mmc: mmci: Set PROBE_PREFER_ASYNCHRONOUS (bsc#1012628).
- mmc: sdhci: fix DMA configure compatibility issue when 64bit
  DMA mode is used (bsc#1012628).
- wifi: cfg80211: fix regulatory disconnect for non-MLO
  (bsc#1012628).
- wifi: ath10k: Serialize wake_tx_queue ops (bsc#1012628).
- wifi: cfg80211: fix receiving mesh packets without RFC1042
  header (bsc#1012628).
- wifi: mt76: mt7921e: fix init command fail with enabled device
  (bsc#1012628).
- bcache: fixup btree_cache_wait list damage (bsc#1012628).
- bcache: Remove unnecessary NULL point check in node allocations
  (bsc#1012628).
- bcache: Fix __bch_btree_node_alloc to make the failure behavior
  consistent (bsc#1012628).
- watch_queue: prevent dangling pipe pointer (bsc#1012628).
- um: Use HOST_DIR for mrproper (bsc#1012628).
- integrity: Fix possible multiple allocation in
  integrity_inode_get() (bsc#1012628).
- autofs: use flexible array in ioctl structure (bsc#1012628).
- mm/damon/ops-common: atomically test and clear young on ptes
  and pmds (bsc#1012628).
- shmem: use ramfs_kill_sb() for kill_sb method of ramfs-based
  tmpfs (bsc#1012628).
- nfsd: use vfs setgid helper (bsc#1012628).
- jffs2: reduce stack usage in jffs2_build_xattr_subsystem()
  (bsc#1012628).
- fs: avoid empty option when generating legacy mount string
  (bsc#1012628).
- ext4: Remove ext4 locking of moved directory (bsc#1012628).
- Revert "f2fs: fix potential corruption when moving a directory"
  (bsc#1012628).
- Revert "udf: Protect rename against modification of moved
  directory" (bsc#1012628).
- fs: Establish locking order for unrelated directories
  (bsc#1012628).
- fs: Lock moved directories (bsc#1012628).
- usb: typec: ucsi: Mark dGPUs as DEVICE scope (bsc#1012628).
- ipvs: increase ip_vs_conn_tab_bits range for 64BIT
  (bsc#1012628).
- btrfs: add handling for RAID1C23/DUP to
  btrfs_reduce_alloc_profile (bsc#1012628).
- btrfs: fix dirty_metadata_bytes for redirtied buffers
  (bsc#1012628).
- btrfs: insert tree mod log move in push_node_left (bsc#1012628).
- btrfs: warn on invalid slot in tree mod log rewind
  (bsc#1012628).
- btrfs: delete unused BGs while reclaiming BGs (bsc#1012628).
- btrfs: bail out reclaim process if filesystem is read-only
  (bsc#1012628).
- btrfs: add block-group tree to lockdep classes (bsc#1012628).
- btrfs: reinsert BGs failed to reclaim (bsc#1012628).
- btrfs: fix race when deleting quota root from the dirty cow
  roots list (bsc#1012628).
- btrfs: add missing error handling when logging operation while
  COWing extent buffer (bsc#1012628).
- btrfs: fix extent buffer leak after tree mod log failure at
  split_node() (bsc#1012628).
- btrfs: do not BUG_ON() on tree mod log failure at
  __btrfs_cow_block() (bsc#1012628).
- ASoC: mediatek: mt8173: Fix irq error path (bsc#1012628).
- ASoC: mediatek: mt8173: Fix snd_soc_component_initialize error
  path (bsc#1012628).
- regulator: tps65219: Fix matching interrupts for their
  regulators (bsc#1012628).
- ARM: dts: qcom: msm8660: Fix regulator node names (bsc#1012628).
- ARM: dts: qcom: ipq4019: fix broken NAND controller properties
  override (bsc#1012628).
- ARM: orion5x: fix d2net gpio initialization (bsc#1012628).
- leds: trigger: netdev: Recheck NETDEV_LED_MODE_LINKUP on dev
  rename (bsc#1012628).
- blktrace: use inline function for blk_trace_remove() while
  blktrace is disabled (bsc#1012628).
- Input: ads7846 - Fix usage of match data (bsc#1012628).
- md/raid1-10: fix casting from randomized structure in
  raid1_submit_write() (bsc#1012628).
- fs: no need to check source (bsc#1012628).
- Input: ads7846 - fix pointer cast warning (bsc#1012628).
- mips: Include KBUILD_CPPFLAGS in CHECKFLAGS invocation
  (bsc#1012628).
- powerpc/vdso: Include CLANG_FLAGS explicitly in ldflags-y
  (bsc#1012628).
- kbuild: Add CLANG_FLAGS to as-instr (bsc#1012628).
- kbuild: Add KBUILD_CPPFLAGS to as-option invocation
  (bsc#1012628).
- kbuild: add $(CLANG_FLAGS) to KBUILD_CPPFLAGS (bsc#1012628).
- ovl: fix null pointer dereference in ovl_permission()
  (bsc#1012628).
- ovl: let helper ovl_i_path_real() return the realinode
  (bsc#1012628).
- ovl: fix null pointer dereference in ovl_get_acl_rcu()
  (bsc#1012628).
- LoongArch: Include KBUILD_CPPFLAGS in CHECKFLAGS invocation
  (bsc#1012628).
- netfilter: conntrack: Avoid nf_ct_helper_hash uses after free
  (bsc#1012628).
- netfilter: nf_tables: do not ignore genmask when looking up
  chain by id (bsc#1012628).
- netfilter: nf_tables: prevent OOB access in nft_byteorder_eval
  (bsc#1012628).
- wireguard: queueing: use saner cpu selection wrapping
  (bsc#1012628).
- wireguard: netlink: send staged packets when setting initial
  private key (bsc#1012628).
- tty: serial: fsl_lpuart: add earlycon for imx8ulp platform
  (bsc#1012628).
- io_uring: Use io_schedule* in cqring wait (bsc#1012628).
- block/partition: fix signedness issue for Amiga partitions
  (bsc#1012628).
- sh: mach-r2d: Handle virq offset in cascaded IRL demux
  (bsc#1012628).
- sh: mach-highlander: Handle virq offset in cascaded IRL demux
  (bsc#1012628).
- sh: mach-dreamcast: Handle virq offset in cascaded IRQ demux
  (bsc#1012628).
- sh: hd64461: Handle virq offset for offchip IRQ base and
  HD64461 IRQ (bsc#1012628).
- commit 919c802
* Tue Jul 18 2023 msuchanek@suse.de
- Revert "kbuild: Hack for depmod not handling X.Y versions" (bsc#1212835).
- Refresh patches.rpmify/usrmerge-Adjust-module-path-in-the-kernel-sources.patch.
- commit a73f479
* Tue Jul 18 2023 jslaby@suse.cz
- ACPI: video: Add backlight=native DMI quirk for Lenovo Ideapad
  Z470 (bsc#1208724).
- commit c835efa
* Tue Jul 18 2023 jslaby@suse.cz
- pinctrl: amd: Unify debounce handling into amd_pinconf_set()
  (bko#217336).
- pinctrl: amd: Drop pull up select configuration (bko#217336).
- pinctrl: amd: Use amd_pinconf_set() for all config options
  (bko#217336).
- pinctrl: amd: Only use special debounce behavior for GPIO 0
  (bko#217336).
- pinctrl: amd: Revert "pinctrl: amd: disable and mask interrupts
  on probe" (bko#217336).
- pinctrl: amd: Detect and mask spurious interrupts (bko#217336).
- pinctrl: amd: Fix mistake in handling clearing pins at startup
  (bko#217336).
- pinctrl: amd: Detect internal GPIO0 debounce handling
  (bko#217336).
- commit a3dbbc0
* Mon Jul 17 2023 msuchanek@suse.de
- rpm: Update dependency to match current kmod.
- Refresh patches.rpmify/usrmerge-Adjust-module-path-in-the-kernel-sources.patch.
  Update to match current kmod (bsc#1212835).
- commit d687dc3
* Mon Jul 17 2023 jslaby@suse.cz
- Refresh
  patches.suse/drm-amdgpu-sdma4-set-align-mask-to-255.patch.
  Update to upstream version. 6.4 already contains 4_4_2.
- commit 48f7169
* Fri Jul 14 2023 nik.borisov@suse.com
- x86/sev: Add SNP-specific unaccepted memory support  (jsc#PED-4747).
- commit 5c42f70
* Fri Jul 14 2023 nik.borisov@suse.com
- x86/sev: Use large PSC requests if applicable (jsc#PED-4747).
- commit 0856765
* Fri Jul 14 2023 nik.borisov@suse.com
- x86/sev: Allow for use of the early boot GHCB for PSC requests (jsc#PED-4747).
- commit 60199fa
* Fri Jul 14 2023 nik.borisov@suse.com
- x86/sev: Put PSC struct on the stack in prep for unaccepted memory  support (jsc#PED-4747).
- commit 97e9c3a
* Fri Jul 14 2023 nik.borisov@suse.com
- x86/tdx: Add unaccepted memory support (jsc#PED-4747).
- commit f20d514
* Fri Jul 14 2023 nik.borisov@suse.com
- x86/tdx: Refactor try_accept_one() (jsc#PED-4747).
- commit 1ecd7d0
* Fri Jul 14 2023 nik.borisov@suse.com
- x86/tdx: Make _tdx_hypercall() and __tdx_module_call() available in  boot stub (jsc#PED-4747).
- commit c232bda
* Fri Jul 14 2023 nik.borisov@suse.com
- x86/boot/compressed: Handle unaccepted memory (jsc#PED-4747).
- commit 4bd0435
* Fri Jul 14 2023 nik.borisov@suse.com
- mm: Add support for unaccepted memory (jsc#PED-4747).
- commit a1a31b1
* Thu Jul 13 2023 msuchanek@suse.de
- of: Preserve "of-display" device name for compatibility
  (bsc#1212405).
- commit 58e8dc0
* Thu Jul 13 2023 msuchanek@suse.de
- depmod: Handle installing modules under a prefix (bsc#1212835).
- commit ffe4bcb
* Thu Jul 13 2023 jlee@suse.com
- Documentation/admin-guide/module-signing.rst: add openssl
  command option example for CodeSign EKU (bsc#1177353,
  bsc#1179076, bsc#1213270).
- modsign: Add codeSigning EKU when generating X.509 key
  generation config (bsc#1177353, bsc#1179076, bsc#1213270).
- PKCS#7: Check codeSigning EKU for kernel module and kexec pe
  verification (bsc#1177353, bsc#1213270).
  Update config files.
- Add CONFIG_CHECK_CODESIGN_EKU=y to x86_64, arm64, ppc64le, s390x
- X.509: Add CodeSigning extended key usage parsing (bsc#1177353,
  bsc#1213270).
- commit fd54341
* Wed Jul 12 2023 tiwai@suse.de
- Move upstreamed AMDGPU patches into sorted section
- commit f6ca0bc
* Tue Jul 11 2023 jslaby@suse.cz
- Linux 6.4.3 (bsc#1012628).
- mm: call arch_swap_restore() from do_swap_page() (bsc#1012628).
- bootmem: remove the vmemmap pages from kmemleak in
  free_bootmem_page (bsc#1012628).
- commit 5fb5b21
* Mon Jul 10 2023 schwab@suse.de
- rpm/check-for-config-changes: ignore also RISCV_ISA_* and DYNAMIC_SIGFRAME
  They depend on CONFIG_TOOLCHAIN_HAS_*.
- commit 1007103
* Mon Jul 10 2023 jslaby@suse.cz
- Refresh
  patches.suse/fork-lock-VMAs-of-the-parent-process-when-forking.patch.
  Replace by the correct one. It was merged to upstream twice. And this is
  the right version.
- commit b97b894
* Mon Jul 10 2023 jslaby@suse.cz
- Update vanilla config files.
  Just run oldconfig for vanillas too. No actual changes.
- commit dcdca04
* Mon Jul 10 2023 jslaby@suse.cz
- Update
  patches.kernel.org/6.4.1-021-mm-always-expand-the-stack-with-the-mmap-write-.patch
  (bsc#1012628 bsc#1212395 CVE-2023-3269).
  Add references to CVE.
- commit 5a45f18
* Mon Jul 10 2023 jslaby@suse.cz
- Update config files.
  Only run_oldconfig.
- commit 37ad463
* Mon Jul 10 2023 jslaby@suse.cz
- fork: lock VMAs of the parent process when forking
  (bsc#1212775).
- mm: lock a vma before stack expansion (bsc#1212775).
- mm: lock newly mapped VMA which can be modified after it
  becomes visible (bsc#1212775).
- mm: lock newly mapped VMA with corrected ordering (bsc#1212775).
- Update config files.
- Delete
  patches.suse/Revert-x86-mm-try-VMA-lock-based-page-fault-handling.patch.
  Drop the downstream revert in favor of upstream fixes above and reset
  the configs -- leave STATS off as per default.
- commit e2dafc9
* Sun Jul  9 2023 jslaby@suse.cz
- Linux 6.4.2 (bsc#1012628).
- arch/arm64/mm/fault: Fix undeclared variable error in
  do_page_fault() (bsc#1012628).
- drm/amdgpu: Validate VM ioctl flags (bsc#1012628).
- dm ioctl: Avoid double-fetch of version (bsc#1012628).
- docs: Set minimal gtags / GNU GLOBAL version to 6.6.5
  (bsc#1012628).
- scripts/tags.sh: Resolve gtags empty index generation
  (bsc#1012628).
- hugetlb: revert use of page_cache_next_miss() (bsc#1012628).
- nubus: Partially revert proc_create_single_data() conversion
  (bsc#1012628).
- Revert "cxl/port: Enable the HDM decoder capability for switch
  ports" (bsc#1012628).
- nfs: don't report STATX_BTIME in ->getattr (bsc#1012628).
- execve: always mark stack as growing down during early stack
  setup (bsc#1012628).
- PCI/ACPI: Call _REG when transitioning D-states (bsc#1012628).
- PCI/ACPI: Validate acpi_pci_set_power_state() parameter
  (bsc#1012628).
- tools/nolibc: x86_64: disable stack protector for _start
  (bsc#1012628).
- xtensa: fix lock_mm_and_find_vma in case VMA not found
  (bsc#1012628).
- commit 648ac3b
* Fri Jul  7 2023 duwe@suse.de
- regulator: axp20x: Add AXP15060 support.
- commit db7b000
* Wed Jul  5 2023 jslaby@suse.cz
- Revert "Refresh patches.rpmify/usrmerge-Adjust-module-path-in-the-kernel-sources.patch."
  This reverts commit b8411965e8341c82ba2e01bb38698945be2390a0. It breaks
  the build:
  + ln -s /usr/src/linux-6.4.1-1 /home/abuild/rpmbuild/BUILDROOT/kernel-default-6.4.1-1.1.x86_64/usr/lib/modules/6.4.1-1-default/source
  ln: failed to create symbolic link '/home/abuild/rpmbuild/BUILDROOT/kernel-default-6.4.1-1.1.x86_64/usr/lib/modules/6.4.1-1-default/source': No such file or directory
- commit 3561b10
* Wed Jul  5 2023 tiwai@suse.de
- drm/amd: Don't try to enable secure display TA multiple times
  (bsc#1212848).
- drm/amdgpu: fix number of fence calculations (bsc#1212848).
- drm/amd/display: perform a bounds check before filling dirty
  rectangles (bsc#1212848).
- drm/amdgpu: check RAS irq existence for VCN/JPEG (bsc#1212848).
- drm/amd/pm: add abnormal fan detection for smu 13.0.0
  (bsc#1212848).
- drm/amd: Disable PSR-SU on Parade 0803 TCON (bsc#1212848).
- drm/amd/pm: update the LC_L1_INACTIVITY setting to address
  possible noise issue (bsc#1212848).
- drm/amd/display: Fix 128b132b link loss handling (bsc#1212848).
- drm/amd/display: disable seamless boot if force_odm_combine
  is enabled (bsc#1212848).
- drm/amd/display: add a NULL pointer check (bsc#1212848).
- drm/amd/pm: revise the ASPM settings for thunderbolt attached
  scenario (bsc#1212848).
- drm/amdgpu: fix clearing mappings for BOs that are always
  valid in VM (bsc#1212848).
- drm/amdgpu: Skip mark offset for high priority rings
  (bsc#1212848).
- drm/amdgpu: make sure that BOs have a backing store
  (bsc#1212848).
- drm/amdgpu: make sure BOs are locked in amdgpu_vm_get_memory
  (bsc#1212848).
- commit a695138
* Mon Jul  3 2023 msuchanek@suse.de
- Remove more packaging cruft for SLE < 12 SP3
- commit a16781c
* Mon Jul  3 2023 jslaby@suse.cz
- Linux 6.4.1 (bsc#1012628).
- x86/microcode/AMD: Load late on both threads too (bsc#1012628).
- x86/smp: Make stop_other_cpus() more robust (bsc#1012628).
- x86/smp: Dont access non-existing CPUID leaf (bsc#1012628).
- x86/smp: Remove pointless wmb()s from native_stop_other_cpus()
  (bsc#1012628).
- x86/smp: Use dedicated cache-line for mwait_play_dead()
  (bsc#1012628).
- x86/smp: Cure kexec() vs. mwait_play_dead() breakage
  (bsc#1012628).
- cpufreq: amd-pstate: Make amd-pstate EPP driver name hyphenated
  (bsc#1012628).
- can: isotp: isotp_sendmsg(): fix return error fix on TX path
  (bsc#1012628).
- maple_tree: fix potential out-of-bounds access in
  mas_wr_end_piv() (bsc#1012628).
- mm: introduce new 'lock_mm_and_find_vma()' page fault helper
  (bsc#1012628).
- mm: make the page fault mmap locking killable (bsc#1012628).
- arm64/mm: Convert to using lock_mm_and_find_vma() (bsc#1012628).
- powerpc/mm: Convert to using lock_mm_and_find_vma()
  (bsc#1012628).
- mips/mm: Convert to using lock_mm_and_find_vma() (bsc#1012628).
- riscv/mm: Convert to using lock_mm_and_find_vma() (bsc#1012628).
- arm/mm: Convert to using lock_mm_and_find_vma() (bsc#1012628).
- mm/fault: convert remaining simple cases to
  lock_mm_and_find_vma() (bsc#1012628).
- powerpc/mm: convert coprocessor fault to lock_mm_and_find_vma()
  (bsc#1012628).
- mm: make find_extend_vma() fail if write lock not held
  (bsc#1012628).
- execve: expand new process stack manually ahead of time
  (bsc#1012628).
- mm: always expand the stack with the mmap write lock held
  (bsc#1012628).
- HID: wacom: Use ktime_t rather than int when dealing with
  timestamps (bsc#1012628).
- gup: add warning if some caller would seem to want stack
  expansion (bsc#1012628).
- mm/khugepaged: fix regression in collapse_file() (bsc#1012628).
- fbdev: fix potential OOB read in fast_imageblit() (bsc#1012628).
- HID: hidraw: fix data race on device refcount (bsc#1012628).
- HID: logitech-hidpp: add HIDPP_QUIRK_DELAYED_INIT for the T651
  (bsc#1012628).
- Revert "thermal/drivers/mediatek: Use devm_of_iomap to avoid
  resource leak in mtk_thermal_probe" (bsc#1012628).
- sparc32: fix lock_mm_and_find_vma() conversion (bsc#1012628).
- parisc: fix expand_stack() conversion (bsc#1012628).
- csky: fix up lock_mm_and_find_vma() conversion (bsc#1012628).
- xtensa: fix NOMMU build with lock_mm_and_find_vma() conversion
  (bsc#1012628).
- Refresh
  patches.suse/Revert-x86-mm-try-VMA-lock-based-page-fault-handling.patch.
- Update config files (CONFIG_LOCK_MM_AND_FIND_VMA=y).
  There is no choice.
- commit eb53035
* Fri Jun 30 2023 msuchanek@suse.de
- Refresh patches.rpmify/usrmerge-Adjust-module-path-in-the-kernel-sources.patch.
  Get module prefix from kmod (bsc#1212835).
  Uses jq to parse 'kmod config' output.
- Get module prefix from kmod (bsc#1212835).
- Refresh patches.rpmify/usrmerge-Adjust-module-path-in-the-kernel-sources.patch.
  Get module prefix from kmod (bsc#1212835).
- commit 75e1d32
* Fri Jun 30 2023 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and move into sorted section:
  - patches.suse/HID-microsoft-Add-rumble-support-to-latest-xbox-cont.patch
- commit ce0878a
* Fri Jun 30 2023 mkubecek@suse.cz
- rpm/check-for-config-changes: ignore also PAHOLE_HAS_*
  We now also have options like CONFIG_PAHOLE_HAS_LANG_EXCLUDE.
- commit 86b52c1
* Thu Jun 29 2023 msuchanek@suse.de
- Update vanilla config files.
- commit 94a0f63
* Thu Jun 29 2023 msuchanek@suse.de
- usrmerge: Adjust module path in the kernel sources (bsc#1212835).
  With the module path adjustment applied as source patch only
  ALP/Tumbleweed kernel built on SLE/Leap needs the path changed back to
  non-usrmerged.
- commit bde5158
* Thu Jun 29 2023 jslaby@suse.cz
- Revert "x86/mm: try VMA lock-based page fault handling first"
  (bsc#1212775).
- Update config files.
- commit 43c9b6b
* Thu Jun 29 2023 tiwai@suse.de
- supported.conf: fix dependency, mark intel_vsec_tpmi as supported
- commit 42e08dd
* Wed Jun 28 2023 jslaby@suse.cz
- Revert "io_uring: Adjust mapping wrt architecture aliasing
  requirements" (bsc#1212773).
- commit d2e19af
* Tue Jun 27 2023 lduncan@suse.com
- Update config files. Unset CONFIG_SYSV68_PARTITION. (jsc#PED-3186)
- commit 9e03e5c
* Tue Jun 27 2023 lduncan@suse.com
- Update config files. Unset CONFIG_KARMA_PARTITION. (jsc#PED-3186)
- commit 852f8c0
* Tue Jun 27 2023 lduncan@suse.com
- Update config files. Unset CONFIG_SUN_PARTITION. (jsc#PED-3186)
- commit f95ac33
* Tue Jun 27 2023 lduncan@suse.com
- Update config files. Unset CONFIG_ULTRIX_PARTITION. (jsc#PED-3186)
- commit 83bffa7
* Tue Jun 27 2023 lduncan@suse.com
- Update config files. Unset CONFIG_SGI_PARTITION. (jsc#PED-3186)
- commit c962ed2
* Tue Jun 27 2023 lduncan@suse.com
- Update config files. Unset CONFIG_SOLARIS_X86_PARTITION. (jsc#PED-3186)
- commit 89a4ce4
* Tue Jun 27 2023 lduncan@suse.com
- Update config files. Unset CONFIG_AMIGA_PARTITION. (jsc#PED-3186)
- commit 3475c60
* Tue Jun 27 2023 lduncan@suse.com
- Update config files. Unset CONFIG_ATARI_PARTITION. (jsc#PED-3186)
- commit f5d97e9
* Mon Jun 26 2023 msuchanek@suse.de
- kernel-docs: Use python3 together with python3-Sphinx (bsc#1212741).
- commit 95a40a6
* Mon Jun 26 2023 tzimmermann@suse.com
- drm/prime: Unexport helpers for fd/handle conversion (bsc#1212533)
  Backporting notes:
  * fix context changes
- commit a0fd2fe
* Mon Jun 26 2023 tzimmermann@suse.com
- drm: Clear fd/handle callbacks in struct drm_driver (bsc#1212533)
  Backporting notes:
  * fix context changes
- commit a211d15
* Mon Jun 26 2023 tzimmermann@suse.com
- drm: Enable PRIME import/export for all drivers (bsc#1212533)
- commit 247c3ef
* Mon Jun 26 2023 jslaby@suse.cz
- Refresh
  patches.suse/HID-microsoft-Add-rumble-support-to-latest-xbox-cont.patch.
  Update upstream status and move to upstream-soon section.
- commit 1a327c7
* Mon Jun 26 2023 mkubecek@suse.cz
- Update to 6.4 final
- refresh configs (headers only)
- commit 4b7bbac
* Thu Feb  9 2023 ykaukab@suse.de
- README.BRANCH: Add RT maintainers
- commit a163bcc
* Thu May  5 2022 jslaby@suse.cz
- Revert "build initrd without systemd" (bsc#1195775)"
  This reverts commit 3a2140fa2acded48224e1438ac9b4775340c94c2. Again,
  this breaks many packages as:
  * iproute2 is missing, and
  * kernel-obs-qa fails with:
  Timed out waiting for device /dev/disk/by-id/virtio-0.
- commit 15dd151
* Tue Apr 19 2022 fvogt@suse.de
- rpm/kernel-obs-build.spec.in: Include algif_hash, aegis128 and xts modules
  afgif_hash is needed by some packages (e.g. iwd) for tests, xts is used for
  LUKS2 volumes by default and aegis128 is useful as AEAD cipher for LUKS2.
  Wrap the long line to make it readable.
- commit bfd7db4
* Fri Apr 23 2021 mwilck@suse.com
- dm: dm_blk_ioctl: implement path failover for SG_IO (bsc#1183045, bsc#1216776).
- commit 41f0e96
* Fri Aug 17 2018 mkubecek@suse.cz
- rpm/constraints.in: raise memory constraints
  Build statistics show that most architectures already need more than 2 GB.
  Require 4 GB except s390x where the memory usage is much lower and we might
  have trouble finding any compliant worker.
- commit 71aefb3
* Tue Mar 31 2009 jeffm@suse.de
- doc/README.KSYMS: Add to repo.
- commit 04ec451
